#include <stdio.h>
#include "uninameslist-fr.h"
#include "nameslist-dll.h"

/* This file was generated using the program 'buildnameslist.c' */


/*
; Date : 2025-10-04, 11:41:38 UTC
;
; Standard Unicode 17.0.0
; Liste des noms des caractères (version en langue française)
;
; Le Consortium Unicode entretient une collaboration étroite
;	et une liaison officielle avec le groupe de travail qui élabore
;	la norme internationale ISO/CEI 10646. La version 17.0 du standard Unicode
;	intègre 4.803 nouveaux caractères (dont 4.316 idéogrammes CJC),
;	portant le total à 159.801 caractères.
;
; Le présent fichier peut être utilisé librement. Toutefois, aucune
;	modification n’y est autorisée ; toutes les copies doivent être
;	rigoureusement identiques au fichier original.
;
; Le Consortium Unicode n’est pas responsable des erreurs ou omissions
;	dans ce fichier.
;
; Version originale (en anglais) de la liste des noms des caractères :
;	https://www.unicode.org/Public/17.0.0/ucd/NamesList.txt
;
; Contributions à la version en langue française :
;
;	Jacques André, France
;	Patrick Andries, Canada (Québec)
;	Bernard Chauvois, France
;	Karljürgen Feuerherm, Canada (Ontario)
;	Alain LaBonté, Canada (Québec)
;	Marc Lodewijck, Belgique
;	Michel Suignard, États-Unis d’Amérique
;	François Yergeau, Canada (Québec)
*/

/* Retrieve a pointer to the name of a Unicode codepoint. */
UN_DLL_EXPORT
const char *uniNamesList_nameFR(unsigned long uni) {
	const char *pt=NULL;

	if ( uni<0x110000 )
		pt=UnicodeNameAnnotFR[uni>>16][(uni>>8)&0xff][uni&0xff].name;
	return( pt );
}

/* Retrieve a pointer to annotation details of a Unicode codepoint. */
UN_DLL_EXPORT
const char *uniNamesList_annotFR(unsigned long uni) {
	const char *pt=NULL;

	if ( uni<0x110000 )
		pt=UnicodeNameAnnotFR[uni>>16][(uni>>8)&0xff][uni&0xff].annot;
	return( pt );
}

/* Retrieve Nameslist.txt version number. */
UN_DLL_EXPORT
const char *uniNamesList_NamesListVersionFR(void) {
	return( "Nameslist-Version: 17.0" );
}


/* These functions are available in libuninameslist-0.4.20140731 and higher */

/* Return number of blocks in this NamesList. */
UN_DLL_EXPORT
int uniNamesList_blockCountFR(void) {
	return( UNICODE_FR_BLOCK_MAX );
}

/* Return block number for this unicode value, -1 if unlisted unicode value */
UN_DLL_EXPORT
int uniNamesList_blockNumberFR(unsigned long uni) {
	int i;

	if ( uni<0x110000 ) {
		for (i=0; i<UNICODE_FR_BLOCK_MAX; i++) {
			if ( uni<(unsigned long)(UnicodeBlockFR[i].start) ) break;
			if ( uni<=(unsigned long)(UnicodeBlockFR[i].end) ) return( i );
		}
	}
	return( -1 );
}

/* Return unicode value starting this Unicode block (-1 if bad uniBlock). */
UN_DLL_EXPORT
long uniNamesList_blockStartFR(int uniBlock) {
	if ( uniBlock<0 || uniBlock>=UNICODE_FR_BLOCK_MAX )
		return( -1 );
	return( (long)(UnicodeBlockFR[uniBlock].start) );
}

/* Return unicode value ending this Unicode block (-1 if bad uniBlock). */
UN_DLL_EXPORT
long uniNamesList_blockEndFR(int uniBlock) {
	if ( uniBlock<0 || uniBlock>=UNICODE_FR_BLOCK_MAX )
		return( -1 );
	return( (long)(UnicodeBlockFR[uniBlock].end) );
}

/* Return a pointer to the blockname for this unicode block. */
UN_DLL_EXPORT
const char * uniNamesList_blockNameFR(int uniBlock) {
	if ( uniBlock<0 || uniBlock>=UNICODE_FR_BLOCK_MAX )
		return( NULL );
	return( UnicodeBlockFR[uniBlock].name );
}


/* These functions are available in libuninameslist-20171118 and higher */

/* Return count of how many names2 are found in this version of library */
UN_DLL_EXPORT
int uniNamesList_names2cntFR(void) {
	return( 0 );
}

/* Return unicode value with names2 (0<=count<uniNamesList_names2cnt(). */
UN_DLL_EXPORT
long uniNamesList_names2valFR(int count) {
	return( -1 );
}

/* Return list location for this unicode value. Return -1 if not found. */
UN_DLL_EXPORT
int uniNamesList_names2getUFR(unsigned long uni) {
	return( -1 );
}

/* Stringlength of names2. Use this if you want to truncate annotations */
UN_DLL_EXPORT
int uniNamesList_names2lnCFR(int count) {
	return( -1 );
}

UN_DLL_EXPORT
int uniNamesList_names2lnUFR(unsigned long uni) {
	return( -1 );
}

/* Return pointer to start of normalized alias names2 within annotation */
UN_DLL_EXPORT
const char *uniNamesList_names2anCFR(int count) {
	return( NULL );
}

UN_DLL_EXPORT
const char *uniNamesList_names2anUFR(unsigned long uni) {
	return( NULL );
}

UN_DLL_LOCAL
static const struct unicode_nameannot nullarrayFR[] = {
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL }
};

UN_DLL_LOCAL
static const struct unicode_nameannot nullarray2FR[] = {
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL }, { NULL, NULL }, { NULL, NULL },
	{ NULL, NULL }, { NULL, NULL },
	{ NULL, "	* on est assuré que la valeur ?FFFE n'est en aucune façon un caractère Unicode" },
	{ NULL, "	* on est assuré que la valeur ?FFFF n'est en aucune façon un caractère Unicode" },
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const nullnullarrayFR[] = {
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR,
	nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarrayFR, nullarray2FR
};

UN_DLL_EXPORT
const struct unicode_block UnicodeBlockFR[] = {
	{ 0x0, 0x7f, "Commandes C0 et latin de base (Latin de base)" },
	{ 0x80, 0xff, "Commandes C1 et supplément Latin-1 (Supplément Latin-1)" },
	{ 0x100, 0x17f, "Latin étendu A" },
	{ 0x180, 0x24f, "Latin étendu B" },
	{ 0x250, 0x2af, "Supplément pour l’API" },
	{ 0x2b0, 0x2ff, "Lettres modificatives à chasse" },
	{ 0x300, 0x36f, "Diacritiques" },
	{ 0x370, 0x3ff, "Grec et copte" },
	{ 0x400, 0x4ff, "Cyrillique" },
	{ 0x500, 0x52f, "Supplément cyrillique" },
	{ 0x530, 0x58f, "Arménien" },
	{ 0x590, 0x5ff, "Hébreu" },
	{ 0x600, 0x6ff, "Arabe" },
	{ 0x700, 0x74f, "Syriaque" },
	{ 0x750, 0x77f, "Supplément arabe" },
	{ 0x780, 0x7bf, "Thâna" },
	{ 0x7c0, 0x7ff, "N’ko" },
	{ 0x800, 0x83f, "Samaritain" },
	{ 0x840, 0x85f, "Mandéen" },
	{ 0x860, 0x86f, "Supplément syriaque" },
	{ 0x870, 0x89f, "Arabe étendu B" },
	{ 0x8a0, 0x8ff, "Arabe étendu A" },
	{ 0x900, 0x97f, "Dévanâgarî" },
	{ 0x980, 0x9ff, "Bengali" },
	{ 0xa00, 0xa7f, "Gourmoukhî" },
	{ 0xa80, 0xaff, "Goudjarati" },
	{ 0xb00, 0xb7f, "Oriya" },
	{ 0xb80, 0xbff, "Tamoul" },
	{ 0xc00, 0xc7f, "Télougou" },
	{ 0xc80, 0xcff, "Kannara" },
	{ 0xd00, 0xd7f, "Malayalam" },
	{ 0xd80, 0xdff, "Singhalais" },
	{ 0xe00, 0xe7f, "Thaï" },
	{ 0xe80, 0xeff, "Lao" },
	{ 0xf00, 0xfff, "Tibétain" },
	{ 0x1000, 0x109f, "Birman" },
	{ 0x10a0, 0x10ff, "Géorgien" },
	{ 0x1100, 0x11ff, "Jamos hangûl" },
	{ 0x1200, 0x137f, "Éthiopien" },
	{ 0x1380, 0x139f, "Supplément éthiopien" },
	{ 0x13a0, 0x13ff, "Chérokie" },
	{ 0x1400, 0x167f, "Syllabaires autochtones canadiens" },
	{ 0x1680, 0x169f, "Ogam" },
	{ 0x16a0, 0x16ff, "Runes" },
	{ 0x1700, 0x171f, "Tagalog" },
	{ 0x1720, 0x173f, "Hanounóo" },
	{ 0x1740, 0x175f, "Bouhid" },
	{ 0x1760, 0x177f, "Tagbanoua" },
	{ 0x1780, 0x17ff, "Khmer" },
	{ 0x1800, 0x18af, "Mongol" },
	{ 0x18b0, 0x18ff, "Syllabaires autochtones canadiens étendus" },
	{ 0x1900, 0x194f, "Limbu" },
	{ 0x1950, 0x197f, "Taï-le" },
	{ 0x1980, 0x19df, "Nouveau taï lü" },
	{ 0x19e0, 0x19ff, "Symboles khmers" },
	{ 0x1a00, 0x1a1f, "Bougui" },
	{ 0x1a20, 0x1aaf, "Taï-tham" },
	{ 0x1ab0, 0x1aff, "Diacritiques complémentaires" },
	{ 0x1b00, 0x1b7f, "Balinais" },
	{ 0x1b80, 0x1bbf, "Soundanais" },
	{ 0x1bc0, 0x1bff, "Batak" },
	{ 0x1c00, 0x1c4f, "Leptcha" },
	{ 0x1c50, 0x1c7f, "Ol tchiki" },
	{ 0x1c80, 0x1c8f, "Cyrillique étendu C" },
	{ 0x1c90, 0x1cbf, "Géorgien étendu" },
	{ 0x1cc0, 0x1ccf, "Supplément soundanais" },
	{ 0x1cd0, 0x1cff, "Supplément védique" },
	{ 0x1d00, 0x1d7f, "Supplément phonétique" },
	{ 0x1d80, 0x1dbf, "Supplément phonétique étendu" },
	{ 0x1dc0, 0x1dff, "Supplément de diacritiques" },
	{ 0x1e00, 0x1eff, "Latin étendu additionnel" },
	{ 0x1f00, 0x1fff, "Grec étendu" },
	{ 0x2000, 0x206f, "Ponctuation générale" },
	{ 0x2070, 0x209f, "Exposants et indices" },
	{ 0x20a0, 0x20cf, "Symboles monétaires" },
	{ 0x20d0, 0x20ff, "Signes combinatoires pour des symboles" },
	{ 0x2100, 0x214f, "Symboles de type lettre" },
	{ 0x2150, 0x218f, "Formes numérales" },
	{ 0x2190, 0x21ff, "Flèches" },
	{ 0x2200, 0x22ff, "Opérateurs mathématiques" },
	{ 0x2300, 0x23ff, "Signes techniques divers" },
	{ 0x2400, 0x243f, "Pictogrammes de commande" },
	{ 0x2440, 0x245f, "Reconnaissance optique de caractères" },
	{ 0x2460, 0x24ff, "Symboles alphanumériques délimités" },
	{ 0x2500, 0x257f, "Filets" },
	{ 0x2580, 0x259f, "Pavés" },
	{ 0x25a0, 0x25ff, "Formes géométriques" },
	{ 0x2600, 0x26ff, "Symboles divers" },
	{ 0x2700, 0x27bf, "Casseau" },
	{ 0x27c0, 0x27ef, "Divers symboles mathématiques - A" },
	{ 0x27f0, 0x27ff, "Supplément A de flèches" },
	{ 0x2800, 0x28ff, "Combinaisons braille" },
	{ 0x2900, 0x297f, "Supplément B de flèches" },
	{ 0x2980, 0x29ff, "Divers symboles mathématiques - B" },
	{ 0x2a00, 0x2aff, "Opérateurs mathématiques supplémentaires" },
	{ 0x2b00, 0x2bff, "Divers symboles et flèches" },
	{ 0x2c00, 0x2c5f, "Glagolitique" },
	{ 0x2c60, 0x2c7f, "Latin étendu C" },
	{ 0x2c80, 0x2cff, "Copte" },
	{ 0x2d00, 0x2d2f, "Supplément géorgien" },
	{ 0x2d30, 0x2d7f, "Tifinaghe" },
	{ 0x2d80, 0x2ddf, "Éthiopien étendu" },
	{ 0x2de0, 0x2dff, "Cyrillique étendu A" },
	{ 0x2e00, 0x2e7f, "Ponctuation complémentaire" },
	{ 0x2e80, 0x2eff, "Formes supplémentaires des clés CJC" },
	{ 0x2f00, 0x2fdf, "Clés du Kangxi" },
	{ 0x2ff0, 0x2fff, "Caractères de description idéographique" },
	{ 0x3000, 0x303f, "Symboles et ponctuation CJC" },
	{ 0x3040, 0x309f, "Hiragana" },
	{ 0x30a0, 0x30ff, "Katakana" },
	{ 0x3100, 0x312f, "Bopomofo" },
	{ 0x3130, 0x318f, "Jamos hangûl de compatibilité" },
	{ 0x3190, 0x319f, "Kanboun" },
	{ 0x31a0, 0x31bf, "Bopomofo étendu" },
	{ 0x31c0, 0x31ef, "Traits CJC" },
	{ 0x31f0, 0x31ff, "Supplément phonétique katakana" },
	{ 0x3200, 0x32ff, "Lettres et mois CJC délimités" },
	{ 0x3300, 0x33ff, "Compatibilité CJC" },
	{ 0x3400, 0x4dbf, "Supplément A aux idéogrammes unifiés CJC" },
	{ 0x4dc0, 0x4dff, "Hexagrammes du Classique des mutations ou Yi-king" },
	{ 0x4e00, 0x9fff, "Idéogrammes unifiés CJC" },
	{ 0xa000, 0xa48f, "Syllabaire yi des Monts frais" },
	{ 0xa490, 0xa4cf, "Clés yi" },
	{ 0xa4d0, 0xa4ff, "Lissou" },
	{ 0xa500, 0xa63f, "Vaï" },
	{ 0xa640, 0xa69f, "Cyrillique étendu B" },
	{ 0xa6a0, 0xa6ff, "Bamoum" },
	{ 0xa700, 0xa71f, "Lettres modificatives de ton" },
	{ 0xa720, 0xa7ff, "Latin étendu D" },
	{ 0xa800, 0xa82f, "Sylotî nâgrî" },
	{ 0xa830, 0xa83f, "Formes numériques communes indiennes" },
	{ 0xa840, 0xa87f, "Phags-pa" },
	{ 0xa880, 0xa8df, "Saurachtra" },
	{ 0xa8e0, 0xa8ff, "Dévanâgarî étendue" },
	{ 0xa900, 0xa92f, "Kayah li" },
	{ 0xa930, 0xa95f, "Rejang" },
	{ 0xa960, 0xa97f, "Jamos hangûl complémentaires A" },
	{ 0xa980, 0xa9df, "Javanais" },
	{ 0xa9e0, 0xa9ff, "Birman étendu B" },
	{ 0xaa00, 0xaa5f, "Tcham" },
	{ 0xaa60, 0xaa7f, "Birman étendu A" },
	{ 0xaa80, 0xaadf, "Taï-viet" },
	{ 0xaae0, 0xaaff, "Supplément meitei mayek" },
	{ 0xab00, 0xab2f, "Éthiopien étendu A" },
	{ 0xab30, 0xab6f, "Latin étendu E" },
	{ 0xab70, 0xabbf, "Supplément chérokie" },
	{ 0xabc0, 0xabff, "Meitei mayek" },
	{ 0xac00, 0xd7a3, "Syllabes hangûl" },
	{ 0xd7b0, 0xd7ff, "Jamos hangûl complémentaires B" },
	{ 0xd800, 0xdb7f, "Demi-zone haute" },
	{ 0xdb80, 0xdbff, "Partie à usage privé de la demi-zone haute" },
	{ 0xdc00, 0xdfff, "Demi-zone basse" },
	{ 0xe000, 0xf8ff, "Zone à usage privé" },
	{ 0xf900, 0xfaff, "Idéogrammes de compatibilité CJC" },
	{ 0xfb00, 0xfb4f, "Formes de présentation alphabétiques" },
	{ 0xfb50, 0xfdff, "Formes A de présentation arabes" },
	{ 0xfe00, 0xfe0f, "Sélecteurs de variante" },
	{ 0xfe10, 0xfe1f, "Formes verticales" },
	{ 0xfe20, 0xfe2f, "Demi-signes combinatoires" },
	{ 0xfe30, 0xfe4f, "Formes de compatibilité CJC" },
	{ 0xfe50, 0xfe6f, "Petites variantes de forme" },
	{ 0xfe70, 0xfeff, "Formes B de présentation arabes" },
	{ 0xff00, 0xffef, "Formes de demi-chasse et de pleine chasse" },
	{ 0xfff0, 0xffff, "Caractères spéciaux" },
	{ 0x10000, 0x1007f, "Syllabaire linéaire B" },
	{ 0x10080, 0x100ff, "Idéogrammes du linéaire B" },
	{ 0x10100, 0x1013f, "Nombres égéens" },
	{ 0x10140, 0x1018f, "Nombres grecs anciens" },
	{ 0x10190, 0x101cf, "Symboles de l’Antiquité" },
	{ 0x101d0, 0x101ff, "Disque de Phaïstos" },
	{ 0x10280, 0x1029f, "Lycien" },
	{ 0x102a0, 0x102df, "Carien" },
	{ 0x102e0, 0x102ff, "Nombres épactes coptes" },
	{ 0x10300, 0x1032f, "Vieil italique" },
	{ 0x10330, 0x1034f, "Gotique" },
	{ 0x10350, 0x1037f, "Permien" },
	{ 0x10380, 0x1039f, "Ougaritique" },
	{ 0x103a0, 0x103df, "Vieux perse" },
	{ 0x10400, 0x1044f, "Déséret" },
	{ 0x10450, 0x1047f, "Shavien" },
	{ 0x10480, 0x104af, "Osmanya" },
	{ 0x104b0, 0x104ff, "Osage" },
	{ 0x10500, 0x1052f, "Elbasan" },
	{ 0x10530, 0x1056f, "Albanien" },
	{ 0x10570, 0x105bf, "Vithkuqi" },
	{ 0x105c0, 0x105ff, "Todhri" },
	{ 0x10600, 0x1077f, "Linéaire A" },
	{ 0x10780, 0x107bf, "Latin étendu F" },
	{ 0x10800, 0x1083f, "Syllabaire chypriote" },
	{ 0x10840, 0x1085f, "Araméen impérial" },
	{ 0x10860, 0x1087f, "Palmyréen" },
	{ 0x10880, 0x108af, "Nabatéen" },
	{ 0x108e0, 0x108ff, "Hatréen" },
	{ 0x10900, 0x1091f, "Phénicien" },
	{ 0x10920, 0x1093f, "Lydien" },
	{ 0x10940, 0x1095f, "Sidétique" },
	{ 0x10980, 0x1099f, "Hiéroglyphes méroïtiques" },
	{ 0x109a0, 0x109ff, "Cursif méroïtique" },
	{ 0x10a00, 0x10a5f, "Kharochthî" },
	{ 0x10a60, 0x10a7f, "Sud-arabique" },
	{ 0x10a80, 0x10a9f, "Vieil arabe du Nord" },
	{ 0x10ac0, 0x10aff, "Manichéen" },
	{ 0x10b00, 0x10b3f, "Avestique" },
	{ 0x10b40, 0x10b5f, "Parthe des inscriptions" },
	{ 0x10b60, 0x10b7f, "Pehlvi des inscriptions" },
	{ 0x10b80, 0x10baf, "Pehlvi des psautiers" },
	{ 0x10c00, 0x10c4f, "Vieux-turc" },
	{ 0x10c80, 0x10cff, "Runes hongroises" },
	{ 0x10d00, 0x10d3f, "Rohingya hanifi" },
	{ 0x10d40, 0x10d8f, "Garay" },
	{ 0x10e60, 0x10e7f, "Symboles numéraux rûmî" },
	{ 0x10e80, 0x10ebf, "Yézidi" },
	{ 0x10ec0, 0x10eff, "Arabe étendu C" },
	{ 0x10f00, 0x10f2f, "Vieux-sogdien" },
	{ 0x10f30, 0x10f6f, "Sogdien" },
	{ 0x10f70, 0x10faf, "Vieil-ouïgour" },
	{ 0x10fb0, 0x10fdf, "Chorasmien" },
	{ 0x10fe0, 0x10fff, "Élyméen" },
	{ 0x11000, 0x1107f, "Brahmi" },
	{ 0x11080, 0x110cf, "Kayathi" },
	{ 0x110d0, 0x110ff, "Sora sompeng" },
	{ 0x11100, 0x1114f, "Chakma" },
	{ 0x11150, 0x1117f, "Mahajani" },
	{ 0x11180, 0x111df, "Charada" },
	{ 0x111e0, 0x111ff, "Nombres archaïques singhalais" },
	{ 0x11200, 0x1124f, "Khojki" },
	{ 0x11280, 0x112af, "Multanais" },
	{ 0x112b0, 0x112ff, "Khudawadi" },
	{ 0x11300, 0x1137f, "Grantha" },
	{ 0x11380, 0x113ff, "Toulou-tigalari" },
	{ 0x11400, 0x1147f, "Néwar" },
	{ 0x11480, 0x114df, "Tirhuta" },
	{ 0x11580, 0x115ff, "Siddham" },
	{ 0x11600, 0x1165f, "Modi" },
	{ 0x11660, 0x1167f, "Supplément mongol" },
	{ 0x11680, 0x116cf, "Takri" },
	{ 0x116d0, 0x116ff, "Birman étendu C" },
	{ 0x11700, 0x1174f, "Âhom" },
	{ 0x11800, 0x1184f, "Dogra" },
	{ 0x118a0, 0x118ff, "Varang kchiti" },
	{ 0x11900, 0x1195f, "Dives akuru" },
	{ 0x119a0, 0x119ff, "Nandinâgarî" },
	{ 0x11a00, 0x11a4f, "Zanabazar carré" },
	{ 0x11a50, 0x11aaf, "Soyombo" },
	{ 0x11ab0, 0x11abf, "Syllabaires autochtones canadiens étendus A" },
	{ 0x11ac0, 0x11aff, "Pau cin hau" },
	{ 0x11b00, 0x11b5f, "Dévanâgarî étendue A" },
	{ 0x11b60, 0x11b7f, "Supplément charada" },
	{ 0x11bc0, 0x11bff, "Sounwar" },
	{ 0x11c00, 0x11c6f, "Bhaiksuki" },
	{ 0x11c70, 0x11cbf, "Marchen" },
	{ 0x11d00, 0x11d5f, "Gondi de Masaram" },
	{ 0x11d60, 0x11daf, "Gondi de Gunjala" },
	{ 0x11db0, 0x11def, "Tolong siki" },
	{ 0x11ee0, 0x11eff, "Macassar" },
	{ 0x11f00, 0x11f5f, "Kawi" },
	{ 0x11fb0, 0x11fbf, "Supplément lissou" },
	{ 0x11fc0, 0x11fff, "Supplément tamoul" },
	{ 0x12000, 0x123ff, "Cunéiforme" },
	{ 0x12400, 0x1247f, "Ponctuation et nombres cunéiformes" },
	{ 0x12480, 0x1254f, "Cunéiforme proto-dynastique" },
	{ 0x12f90, 0x12fff, "Chypro-minoen" },
	{ 0x13000, 0x1342f, "Hiéroglyphes égyptiens" },
	{ 0x13430, 0x1345f, "Caractères de formatage des hiéroglyphes égyptiens" },
	{ 0x13460, 0x143ff, "Hiéroglyphes égyptiens étendus A" },
	{ 0x14400, 0x1467f, "Hiéroglyphes anatoliens" },
	{ 0x16100, 0x1613f, "Gouroung khema" },
	{ 0x16800, 0x16a3f, "Supplément bamoum" },
	{ 0x16a40, 0x16a6f, "Mro" },
	{ 0x16a70, 0x16acf, "Tangsa" },
	{ 0x16ad0, 0x16aff, "Vah bassa" },
	{ 0x16b00, 0x16b8f, "Pahawh hmong" },
	{ 0x16d40, 0x16d7f, "Kirat rai" },
	{ 0x16e40, 0x16e9f, "Médéfaïdrine" },
	{ 0x16ea0, 0x16edf, "Béria erfé" },
	{ 0x16f00, 0x16f9f, "Miao" },
	{ 0x16fe0, 0x16fff, "Symboles et ponctuation idéographiques" },
	{ 0x17000, 0x187ff, "Tangoute" },
	{ 0x18800, 0x18aff, "Composants tangoutes" },
	{ 0x18b00, 0x18cff, "Petite écriture khitane" },
	{ 0x18d00, 0x18d1e, "Supplément tangoute" },
	{ 0x18d80, 0x18dff, "Supplément de composants tangoutes" },
	{ 0x1aff0, 0x1afff, "Kana complémentaires B" },
	{ 0x1b000, 0x1b0ff, "Supplément de kana" },
	{ 0x1b100, 0x1b12f, "Kana complémentaires A" },
	{ 0x1b130, 0x1b16f, "Supplément de petits kana" },
	{ 0x1b170, 0x1b2ff, "Nüshu" },
	{ 0x1bc00, 0x1bc9f, "Sténographie Duployé" },
	{ 0x1bca0, 0x1bcaf, "Formatage de sténographie" },
	{ 0x1cc00, 0x1cebf, "Supplément de symboles informatiques patrimoniaux" },
	{ 0x1cec0, 0x1ceff, "Supplément de symboles divers" },
	{ 0x1cf00, 0x1cfcf, "Notation musicale znamenny" },
	{ 0x1d000, 0x1d0ff, "Symboles musicaux byzantins" },
	{ 0x1d100, 0x1d1ff, "Symboles musicaux" },
	{ 0x1d200, 0x1d24f, "Notation musicale grecque ancienne" },
	{ 0x1d2c0, 0x1d2df, "Chiffres de Kaktovik" },
	{ 0x1d2e0, 0x1d2ff, "Chiffres mayas" },
	{ 0x1d300, 0x1d35f, "Symboles du Classique du mystère suprême" },
	{ 0x1d360, 0x1d37f, "Barres numérales" },
	{ 0x1d400, 0x1d7ff, "Symboles mathématiques alphanumériques" },
	{ 0x1d800, 0x1daaf, "SignWriting de Sutton" },
	{ 0x1df00, 0x1dfff, "Latin étendu G" },
	{ 0x1e000, 0x1e02f, "Supplément glagolitique" },
	{ 0x1e030, 0x1e08f, "Cyrillique étendu D" },
	{ 0x1e100, 0x1e14f, "Nyiakeng puachue hmong" },
	{ 0x1e290, 0x1e2bf, "Toto" },
	{ 0x1e2c0, 0x1e2ff, "Wantcho" },
	{ 0x1e4d0, 0x1e4ff, "Nag mundari" },
	{ 0x1e5d0, 0x1e5ff, "Ol onal" },
	{ 0x1e6c0, 0x1e6ff, "Taï-yo" },
	{ 0x1e7e0, 0x1e7ff, "Éthiopien étendu B" },
	{ 0x1e800, 0x1e8df, "Mendé kikakui" },
	{ 0x1e900, 0x1e95f, "Adlam" },
	{ 0x1ec70, 0x1ecbf, "Nombres siyaq indiens" },
	{ 0x1ed00, 0x1ed4f, "Nombres siyaq ottomans" },
	{ 0x1ee00, 0x1eeff, "Symboles mathématiques alphabétiques arabes" },
	{ 0x1f000, 0x1f02f, "Tuiles de majong" },
	{ 0x1f030, 0x1f09f, "Dominos" },
	{ 0x1f0a0, 0x1f0ff, "Cartes à jouer" },
	{ 0x1f100, 0x1f1ff, "Supplément de symboles alphanumériques délimités" },
	{ 0x1f200, 0x1f2ff, "Supplément d’idéogrammes délimités" },
	{ 0x1f300, 0x1f5ff, "Divers symboles et pictogrammes" },
	{ 0x1f600, 0x1f64f, "Émoticônes" },
	{ 0x1f650, 0x1f67f, "Casseau ornemental" },
	{ 0x1f680, 0x1f6ff, "Symboles cartographiques ou liés au transport" },
	{ 0x1f700, 0x1f77f, "Symboles alchimiques" },
	{ 0x1f780, 0x1f7ff, "Supplément de formes géométriques" },
	{ 0x1f800, 0x1f8ff, "Supplément C de flèches" },
	{ 0x1f900, 0x1f9ff, "Supplément de symboles et de pictogrammes" },
	{ 0x1fa00, 0x1fa6f, "Symboles des échecs" },
	{ 0x1fa70, 0x1faff, "Symboles et pictogrammes complémentaires A" },
	{ 0x1fb00, 0x1fbff, "Symboles informatiques patrimoniaux" },
	{ 0x1ff80, 0x1ffff, "Points de code non attribués" },
	{ 0x20000, 0x2a6df, "Supplément B aux idéogrammes unifiés CJC" },
	{ 0x2a700, 0x2b73f, "Supplément C aux idéogrammes unifiés CJC" },
	{ 0x2b740, 0x2b81d, "Supplément D aux idéogrammes unifiés CJC" },
	{ 0x2b820, 0x2cead, "Supplément E aux idéogrammes unifiés CJC" },
	{ 0x2ceb0, 0x2ebe0, "Supplément F aux idéogrammes unifiés CJC" },
	{ 0x2ebf0, 0x2ee5d, "Supplément I aux idéogrammes unifiés CJC" },
	{ 0x2f800, 0x2fa1f, "Supplément aux idéogrammes de compatibilité CJC" },
	{ 0x2ff80, 0x2ffff, "Points de code non attribués" },
	{ 0x30000, 0x3134a, "Supplément G aux idéogrammes unifiés CJC" },
	{ 0x31350, 0x323af, "Supplément H aux idéogrammes unifiés CJC" },
	{ 0x323b0, 0x33479, "Supplément J aux idéogrammes unifiés CJC" },
	{ 0x3ff80, 0x3ffff, "Points de code non attribués" },
	{ 0x4ff80, 0x4ffff, "Points de code non attribués" },
	{ 0x5ff80, 0x5ffff, "Points de code non attribués" },
	{ 0x6ff80, 0x6ffff, "Points de code non attribués" },
	{ 0x7ff80, 0x7ffff, "Points de code non attribués" },
	{ 0x8ff80, 0x8ffff, "Points de code non attribués" },
	{ 0x9ff80, 0x9ffff, "Points de code non attribués" },
	{ 0xaff80, 0xaffff, "Points de code non attribués" },
	{ 0xbff80, 0xbffff, "Points de code non attribués" },
	{ 0xcff80, 0xcffff, "Points de code non attribués" },
	{ 0xdff80, 0xdffff, "Points de code non attribués" },
	{ 0xe0000, 0xe007f, "Étiquettes" },
	{ 0xe0100, 0xe01ef, "Supplément de sélecteurs de variante" },
	{ 0xeff80, 0xeffff, "Points de code non attribués" },
	{ 0xfff80, 0xfffff, "Zone supplémentaire A à usage privé" },
	{ 0x10ff80, 0x10ffff, "Zone supplémentaire B à usage privé" }
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_00[] = {
/* 0000 */ { NULL,"	= NUL"},
/* 0001 */ { NULL,"	= DÉBUT D'EN-TÊTE"},
/* 0002 */ { NULL,"	= DÉBUT DE TEXTE"},
/* 0003 */ { NULL,"	= FIN DE TEXTE"},
/* 0004 */ { NULL,"	= FIN DE TRANSMISSION"},
/* 0005 */ { NULL,"	= DEMANDE"},
/* 0006 */ { NULL,"	= ACCUSÉ DE RÉCEPTION\n"
	"	= accusé de réception positif"},
/* 0007 */ { NULL,"	= SONNERIE"},
/* 0008 */ { NULL,"	= ESPACE ARRIÈRE"},
/* 0009 */ { NULL,"	= TABULATION HORIZONTALE"},
/* 000A */ { NULL,"	= CHANGEMENT DE LIGNE\n"
	"	= passage à la ligne\n"
	"	= fin de ligne"},
/* 000B */ { NULL,"	= TABULATION VERTICALE"},
/* 000C */ { NULL,"	= SAUT DE PAGE\n"
	"	= page suivante"},
/* 000D */ { NULL,"	= RETOUR DE CHARIOT"},
/* 000E */ { NULL,"	= HORS CODE\n"
	"	* connu comme « REMPLACEMENT VERROUILLÉ UN » dans les environnements 8 bits"},
/* 000F */ { NULL,"	= EN CODE\n"
	"	* connu comme « REMPLACEMENT VERROUILLÉ ZÉRO » dans les environnements 8 bits"},
/* 0010 */ { NULL,"	= ÉCHAPPEMENT TRANSMISSION"},
/* 0011 */ { NULL,"	= COMMANDE DE DISPOSITIF UN\n"
	"	= commande d'appareil un"},
/* 0012 */ { NULL,"	= COMMANDE DE DISPOSITIF DEUX\n"
	"	= commande d'appareil deux"},
/* 0013 */ { NULL,"	= COMMANDE DE DISPOSITIF TROIS\n"
	"	= commande d'appareil trois"},
/* 0014 */ { NULL,"	= COMMANDE DE DISPOSITIF QUATRE\n"
	"	= commande d'appareil quatre"},
/* 0015 */ { NULL,"	= ACCUSÉ DE RÉCEPTION NÉGATIF"},
/* 0016 */ { NULL,"	= SYNCHRONISATION"},
/* 0017 */ { NULL,"	= FIN DE BLOC DE TRANSMISSION"},
/* 0018 */ { NULL,"	= ANNULATION"},
/* 0019 */ { NULL,"	= FIN DE SUPPORT"},
/* 001A */ { NULL,"	= SUBSTITUTION\n"
	"	x (caractère de remplacement - FFFD)"},
/* 001B */ { NULL,"	= ÉCHAPPEMENT"},
/* 001C */ { NULL,"	= SÉPARATEUR DE FICHIERS\n"
	"	= séparateur d'information quatre"},
/* 001D */ { NULL,"	= SÉPARATEUR DE GROUPES\n"
	"	= séparateur d'information trois"},
/* 001E */ { NULL,"	= SÉPARATEUR D'ENREGISTREMENTS\n"
	"	= séparateur d'information deux"},
/* 001F */ { NULL,"	= SÉPARATEUR DE SOUS-ARTICLES\n"
	"	= séparateur d'information un"},
/* 0020 */ { "ESPACE","	* le mot « espace » est féminin en typographie\n"
	"	* parfois considérée comme un caractère de commande\n"
	"	* autres espaces : 2000-200A\n"
	"	x (espace insécable - 00A0)\n"
	"	x (espace sans chasse - 200B)\n"
	"	x (espace insécable étroite - 202F)\n"
	"	x (gluon de mots - 2060)\n"
	"	x (symbole pour espace - 2420)\n"
	"	x (symbole blanc - 2422)\n"
	"	x (boîte ouverte - 2423)\n"
	"	x (espace idéographique - 3000)\n"
	"	x (indicateur d'ordre des octets - FEFF)"},
/* 0021 */ { "POINT D'EXCLAMATION","	= factorielle\n"
	"	x (point d'exclamation renversé - 00A1)\n"
	"	x (lettre latine clic rétroflexe - 01C3)\n"
	"	x (double point d'exclamation - 203C)\n"
	"	x (point exclarrogatif - 203D)\n"
	"	x (signal de danger - 26A0)\n"
	"	x (symbole point d'exclamation épais - 2757)\n"
	"	x (point d'exclamation de fantaisie épais - 2762)\n"
	"	x (point d'exclamation médiéval - 2E53)\n"
	"	x (lettre modificative point d'exclamation haut - A71D)"},
/* 0022 */ { "GUILLEMET ANGLAIS","	= guillemet dactylographique, petit guillemet\n"
	"	* neutre (vertical), utilisé comme guillemet ouvrant ou fermant\n"
	"	* les caractères recommandés pour les guillemets « doubles » appariés en anglais sont 201C et 201D\n"
	"	* 05F4 est recommandé pour le gerchâïm dans l'écriture de l'hébreu\n"
	"	x (lettre modificative seconde - 02BA)\n"
	"	x (double accent aigu - 02DD)\n"
	"	x (lettre modificative double apostrophe - 02EE)\n"
	"	x (diacritique double accent aigu - 030B)\n"
	"	x (diacritique double ligne verticale en chef - 030E)\n"
	"	x (ponctuation hébraïque gerchâïm - 05F4)\n"
	"	x (guillemet-apostrophe double culbuté - 201C)\n"
	"	x (guillemet-apostrophe double - 201D)\n"
	"	x (double prime - 2033)\n"
	"	x (guillemet de répétition - 3003)"},
/* 0023 */ { "CROISILLON","	= carré, chemin de fer, ducat\n"
	"	= cardinal d'un ensemble (dans la théorie des ensembles)\n"
	"	= somme connexe de variétés (en topologie)\n"
	"	* ce symbole représente le numéro dans l'usage américain\n"
	"	* pour représenter un dièse musical, 266F est à privilégier\n"
	"	x (symbole l b barré - 2114)\n"
	"	x (symbole numéro - 2116)\n"
	"	x (carré de visualisation - 2317)\n"
	"	x (dièse - 266F)\n"
	"	x (signe égal et parallèle incliné - 29E3)"},
/* 0024 */ { "SYMBOLE DOLLAR","	= milreis, escudo, piastre\n"
	"	* utilisé pour de nombreuses monnaies portant le nom de « peso » en Amérique latine\n"
	"	* le glyphe peut comporter une ou deux barres verticales\n"
	"	* d'autres caractères de symboles monétaires sont codés à partir de la valeur 20A0\n"
	"	x (symbole centime - 00A2)\n"
	"	x (symbole monétaire - 00A4)\n"
	"	x (symbole peso - 20B1)\n"
	"	x (gros symbole dollar - 1F4B2)"},
/* 0025 */ { "SYMBOLE POUR CENT","	x (symbole arabe pour cent - 066A)\n"
	"	x (symbole pour mille - 2030)\n"
	"	x (symbole pour dix mille - 2031)\n"
	"	x (signe moins commercial - 2052)"},
/* 0026 */ { "PERLUÈTE","	= esperluète/esperluette, et commercial, et\n"
	"	* originellement dérivée d'une ligature du « e » et du « t »\n"
	"	x (note tironienne et - 204A)\n"
	"	x (perluète culbutée - 214B)\n"
	"	x (ornement perluète au trait fort - 1F674)"},
/* 0027 */ { "APOSTROPHE","	= apostrophe droite, apostrophe dactylographique\n"
	"	= guillemet APL\n"
	"	* glyphe neutre (vertical) à usages variés\n"
	"	* le caractère recommandé pour indiquer l'apostrophe est 2019\n"
	"	* les caractères recommandés pour les guillemets « simples » appariés en anglais sont 2018 et 2019\n"
	"	* 05F3 est recommandé pour le gerich dans l'écriture de l'hébreu\n"
	"	x (lettre modificative prime - 02B9)\n"
	"	x (lettre modificative apostrophe - 02BC)\n"
	"	x (lettre modificative ligne verticale - 02C8)\n"
	"	x (diacritique accent aigu - 0301)\n"
	"	x (diacritique ligne verticale en chef - 030D)\n"
	"	x (ponctuation hébraïque gerich - 05F3)\n"
	"	x (guillemet-apostrophe culbuté - 2018)\n"
	"	x (guillemet-apostrophe - 2019)\n"
	"	x (prime - 2032)\n"
	"	x (lettre minuscule latine saltillo - A78C)"},
/* 0028 */ { "PARENTHÈSE GAUCHE","	= parenthèse ouvrante (1.0)"},
/* 0029 */ { "PARENTHÈSE DROITE","	= parenthèse fermante (1.0)\n"
	"	* se référer à la discussion sur la signification des caractères appariés"},
/* 002A */ { "ASTÉRISQUE","	= étoile\n"
	"	* peut avoir cinq ou six branches\n"
	"	x (étoile à cinq branches arabe - 066D)\n"
	"	x (marque de référence - 203B)\n"
	"	x (astérisme - 2042)\n"
	"	x (astérisque baissé - 204E)\n"
	"	x (deux astérisques alignés verticalement - 2051)\n"
	"	x (diacritique astérisque suscrit - 20F0)\n"
	"	x (opérateur astérisque - 2217)\n"
	"	x (sextile - 26B9)\n"
	"	x (gros astérisque - 2731)\n"
	"	x (astérisque slavon - A673)\n"
	"	x (astérisque à six branches demi-gras - 1F7B6)"},
/* 002B */ { "SIGNE PLUS","	x (lettre modificative signe plus - 02D6)\n"
	"	x (signe moins - 2212)\n"
	"	x (signe plus épais - 2795)\n"
	"	x (lettre hébraïque alternative signe plus - FB29)\n"
	"	x (croix grecque fine - 1F7A2)"},
/* 002C */ { "VIRGULE","	= son emploi comme séparateur décimal ou comme séparateur de milliers est lié aux paramètres régionaux\n"
	"	x (virgule arabe - 060C)\n"
	"	x (séparateur décimal arabe - 066B)\n"
	"	x (guillemet-virgule inférieur - 201A)\n"
	"	x (hypodiastole - 2E12)\n"
	"	x (virgule réfléchie - 2E41)\n"
	"	x (virgule médiévale - 2E4C)\n"
	"	x (virgule idéographique - 3001)"},
/* 002D */ { "TRAIT D'UNION-SIGNE MOINS","	= trait d'union, tiret\n"
	"	= signe moins\n"
	"	* appelé « division » par les typographes\n"
	"	* utilisé de manière générique pour le trait d'union, le signe moins ou le tiret demi-cadratin, qui ont chacun un caractère dédié\n"
	"	x (trait d'union conditionnel - 00AD)\n"
	"	x (lettre modificative signe moins - 02D7)\n"
	"	x (trait d'union - 2010)\n"
	"	x (trait d'union insécable - 2011)\n"
	"	x (tiret numérique - 2012)\n"
	"	x (tiret demi-cadratin - 2013)\n"
	"	x (point de coupure de mot - 2027)\n"
	"	x (puce trait d'union - 2043)\n"
	"	x (signe moins - 2212)\n"
	"	x (symbole romain once - 10191)"},
/* 002E */ { "POINT","	= point final, séparateur de milliers, point décimal anglo-saxon\n"
	"	* son emploi comme point décimal ou comme séparateur de milliers est lié aux paramètres régionaux\n"
	"	* peut apparaître haussé pour les chiffres elzéviriens\n"
	"	x (point médian - 00B7)\n"
	"	x (point arabe - 06D4)\n"
	"	x (point de conduite simple - 2024)\n"
	"	x (points de suspension - 2026)\n"
	"	x (point élevé - 2E33)\n"
	"	x (point sténographique - 2E3C)\n"
	"	x (point idéographique - 3002)"},
/* 002F */ { "BARRE OBLIQUE","	= oblique, cotice\n"
	"	x (diacritique barre oblique longue couvrante - 0338)\n"
	"	x (barre de fraction - 2044)\n"
	"	x (barre oblique de division - 2215)\n"
	"	x (diagonale mathématique ascendante - 27CB)\n"
	"	x (grande barre oblique - 29F8)\n"
	"	x (barre oblique pointée - 2E4A)"},
/* 0030 */ { "CHIFFRE ZÉRO","	~ 0030 FE00 forme à barre diagonale courte"},
/* 0031 */ { "CHIFFRE UN",NULL},
/* 0032 */ { "CHIFFRE DEUX","	x (lettre latine deux barré - 01BB)\n"
	"	x (chiffre deux culbuté - 218A)"},
/* 0033 */ { "CHIFFRE TROIS","	x (chiffre trois culbuté - 218B)\n"
	"	x (lettre majuscule latine e ouvert réfléchi - A7AB)"},
/* 0034 */ { "CHIFFRE QUATRE","	x (lettre majuscule latine cuatrillo - A72C)"},
/* 0035 */ { "CHIFFRE CINQ","	x (lettre majuscule latine cinquième ton - 01BC)"},
/* 0036 */ { "CHIFFRE SIX",NULL},
/* 0037 */ { "CHIFFRE SEPT",NULL},
/* 0038 */ { "CHIFFRE HUIT",NULL},
/* 0039 */ { "CHIFFRE NEUF",NULL},
/* 003A */ { "DEUX-POINTS","	* également utilisé comme signe de division ou d'échelle ; pour ces emplois mathématiques, 2236 est recommandé\n"
	"	* en finnois et en suédois, également utilisé comme ponctuation interne au mot (signe d'abréviation)\n"
	"	x (lettre modificative deux points triangulaires - 02D0)\n"
	"	x (lettre modificative deux-points élevé - 02F8)\n"
	"	x (point arménien - 0589)\n"
	"	x (ponctuation hébraïque sof pasouq - 05C3)\n"
	"	x (espace éthiopienne - 1361)\n"
	"	x (deux-points éthiopien - 1365)\n"
	"	x (deux-points en capitale - 205A)\n"
	"	x (trois-points vertical - 205D)\n"
	"	x (rapport - 2236)\n"
	"	x (lettre modificative deux-points - A789)\n"
	"	x (forme de présentation de point de conduite double vertical - FE30)"},
/* 003B */ { "POINT-VIRGULE","	* c'est ce caractère, et non 037E, qui est recommandé pour représenter le « point d'interrogation grec »\n"
	"	x (point d'interrogation grec - 037E)\n"
	"	x (point-virgule arabe - 061B)\n"
	"	x (point-virgule réfléchi - 204F)\n"
	"	x (point-virgule culbuté - 2E35)"},
/* 003C */ { "SIGNE INFÉRIEUR À","	= crochet brisé ouvrant, crochet oblique ouvrant\n"
	"	* jumelé avec 003E dans les balises conçues à l'aide de crochets obliques (ou chevrons)\n"
	"	x (lettre modificative pointe de flèche vers la gauche - 02C2)\n"
	"	x (guillemet simple vers la gauche - 2039)\n"
	"	x (chevron pointant à gauche - 2329)\n"
	"	x (chevron mathématique gauche - 27E8)\n"
	"	x (chevron gauche - 3008)"},
/* 003D */ { "SIGNE ÉGAL","	= égalité\n"
	"	* caractères connexes : 2241-2263\n"
	"	x (trait d'union syllabe canadienne - 1400)\n"
	"	x (presque égal à - 2248)\n"
	"	x (pas égal à - 2260)\n"
	"	x (identique à - 2261)\n"
	"	x (trait d'union double - 2E40)\n"
	"	x (double trait katakana-hiragana - 30A0)\n"
	"	x (lettre modificative signe égal court - A78A)\n"
	"	x (signe égal minuscule - FE66)\n"
	"	x (symbole romain sextant - 10190)\n"
	"	x (signe égal épais - 1F7F0)"},
/* 003E */ { "SIGNE SUPÉRIEUR À","	= crochet brisé fermant, crochet oblique fermant\n"
	"	x (lettre modificative pointe de flèche vers la droite - 02C3)\n"
	"	x (guillemet simple vers la droite - 203A)\n"
	"	x (chevron pointant à droite - 232A)\n"
	"	x (chevron mathématique droit - 27E9)\n"
	"	x (chevron droit - 3009)"},
/* 003F */ { "POINT D'INTERROGATION","	x (point d'interrogation renversé - 00BF)\n"
	"	x (point d'interrogation grec - 037E)\n"
	"	x (point d'interrogation arabe - 061F)\n"
	"	x (point exclarrogatif - 203D)\n"
	"	x (double point d'interrogation - 2047)\n"
	"	x (point d'interrogation noir de fantaisie - 2753)\n"
	"	x (signe d'incertitude - 2BD1)\n"
	"	x (point d'interrogation réfléchi - 2E2E)\n"
	"	x (point d'interrogation médiéval - 2E54)\n"
	"	x (caractère de remplacement - FFFD)"},
/* 0040 */ { "ARROBE","	= arobase, arobas/arrobas, à commercial\n"
	"	= arroba (ancienne mesure de poids espagnole)\n"
	"	* a reçu des dénominations imagées dans de nombreuses langues\n"
	"	x (lettre minuscule latine a cerclée - 24D0)"},
/* 0041 */ { "LETTRE MAJUSCULE LATINE A",NULL},
/* 0042 */ { "LETTRE MAJUSCULE LATINE B","	x (majuscule b de ronde - 212C)"},
/* 0043 */ { "LETTRE MAJUSCULE LATINE C","	x (symbole grec sigma lunaire majuscule - 03F9)\n"
	"	x (majuscule c ajouré - 2102)\n"
	"	x (degré celsius - 2103)\n"
	"	x (majuscule c gothique - 212D)\n"
	"	x (chiffre romain cent - 216D)"},
/* 0044 */ { "LETTRE MAJUSCULE LATINE D","	x (chiffre romain cinq cents - 216E)"},
/* 0045 */ { "LETTRE MAJUSCULE LATINE E","	x (lettre majuscule latine e ouvert - 0190)\n"
	"	x (constante d'euler - 2107)\n"
	"	x (majuscule e de ronde - 2130)"},
/* 0046 */ { "LETTRE MAJUSCULE LATINE F","	x (degré fahrenheit - 2109)\n"
	"	x (majuscule f de ronde - 2131)\n"
	"	x (majuscule f culbuté - 2132)"},
/* 0047 */ { "LETTRE MAJUSCULE LATINE G",NULL},
/* 0048 */ { "LETTRE MAJUSCULE LATINE H","	x (majuscule h de ronde - 210B)\n"
	"	x (majuscule h gothique - 210C)\n"
	"	x (majuscule h ajouré - 210D)"},
/* 0049 */ { "LETTRE MAJUSCULE LATINE I","	* le turc et l'azéri utilisent 0131 pour la minuscule\n"
	"	x (lettre majuscule latine i point en chef - 0130)\n"
	"	x (majuscule i de ronde - 2110)\n"
	"	x (majuscule i gothique - 2111)\n"
	"	x (chiffre romain un - 2160)"},
/* 004A */ { "LETTRE MAJUSCULE LATINE J",NULL},
/* 004B */ { "LETTRE MAJUSCULE LATINE K","	x (symbole kelvin - 212A)"},
/* 004C */ { "LETTRE MAJUSCULE LATINE L","	x (majuscule l de ronde - 2112)"},
/* 004D */ { "LETTRE MAJUSCULE LATINE M","	x (majuscule m de ronde - 2133)\n"
	"	x (chiffre romain mille - 216F)"},
/* 004E */ { "LETTRE MAJUSCULE LATINE N","	x (majuscule n ajouré - 2115)"},
/* 004F */ { "LETTRE MAJUSCULE LATINE O",NULL},
/* 0050 */ { "LETTRE MAJUSCULE LATINE P","	x (symbole fonction elliptique de weierstrass - 2118)\n"
	"	x (majuscule p ajouré - 2119)"},
/* 0051 */ { "LETTRE MAJUSCULE LATINE Q","	x (lettre majuscule cyrillique qa - 051A)\n"
	"	x (majuscule q ajouré - 211A)\n"
	"	x (majuscule q couché - 213A)"},
/* 0052 */ { "LETTRE MAJUSCULE LATINE R","	x (majuscule r de ronde - 211B)\n"
	"	x (majuscule r gothique - 211C)\n"
	"	x (majuscule r ajouré - 211D)"},
/* 0053 */ { "LETTRE MAJUSCULE LATINE S",NULL},
/* 0054 */ { "LETTRE MAJUSCULE LATINE T",NULL},
/* 0055 */ { "LETTRE MAJUSCULE LATINE U",NULL},
/* 0056 */ { "LETTRE MAJUSCULE LATINE V","	x (chiffre romain cinq - 2164)"},
/* 0057 */ { "LETTRE MAJUSCULE LATINE W","	x (lettre majuscule cyrillique wé - 051C)"},
/* 0058 */ { "LETTRE MAJUSCULE LATINE X","	x (chiffre romain dix - 2169)"},
/* 0059 */ { "LETTRE MAJUSCULE LATINE Y",NULL},
/* 005A */ { "LETTRE MAJUSCULE LATINE Z","	x (majuscule z ajouré - 2124)\n"
	"	x (majuscule z gothique - 2128)"},
/* 005B */ { "CROCHET GAUCHE","	= crochet ouvrant (1.0)\n"
	"	* autres crochets et signes de la même espèce : 27E6-27EB, 2983-2998, 3008-301B"},
/* 005C */ { "BARRE OBLIQUE INVERSÉE","	= contre-oblique, contre-cotice\n"
	"	x (diacritique barre oblique inversée couvrante - 20E5)\n"
	"	x (différence d'ensembles - 2216)\n"
	"	x (diagonale mathématique descendante - 27CD)\n"
	"	x (grande barre oblique inversée - 29F9)"},
/* 005D */ { "CROCHET DROIT","	= crochet fermant (1.0)"},
/* 005E */ { "ACCENT CIRCONFLEXE","	* ce caractère chasse\n"
	"	* utilisé pour la représentation de l'exponentiation en ASCII\n"
	"	x (lettre modificative pointe de flèche vers le haut - 02C4)\n"
	"	x (lettre modificative accent circonflexe - 02C6)\n"
	"	x (diacritique accent circonflexe - 0302)\n"
	"	x (chevron d'insertion - 2038)\n"
	"	x (et logique - 2227)\n"
	"	x (pointe de flèche vers le haut - 2303)"},
/* 005F */ { "TIRET BAS","	= trait de soulignement, souligné\n"
	"	* ce caractère chasse\n"
	"	* les occurrences adjacentes de ce caractère se rejoignent\n"
	"	x (lettre modificative macron bas - 02CD)\n"
	"	x (diacritique macron souscrit - 0331)\n"
	"	x (diacritique trait souscrit - 0332)\n"
	"	x (double tiret bas - 2017)\n"
	"	x (diacritique macron souscrit jointif - FE2D)"},
/* 0060 */ { "ACCENT GRAVE","	* ce caractère chasse\n"
	"	* dans certains contextes techniques, sert de guillemet ouvrant, couplé avec une apostrophe\n"
	"	x (accent aigu - 00B4)\n"
	"	x (lettre modificative accent grave - 02CB)\n"
	"	x (diacritique accent grave - 0300)\n"
	"	x (accent grave grec - 1FEF)\n"
	"	x (guillemet-apostrophe culbuté - 2018)\n"
	"	x (prime réfléchi - 2035)"},
/* 0061 */ { "LETTRE MINUSCULE LATINE A","	x (lettre minuscule latine alpha - 0251)"},
/* 0062 */ { "LETTRE MINUSCULE LATINE B",NULL},
/* 0063 */ { "LETTRE MINUSCULE LATINE C","	x (symbole grec sigma lunaire - 03F2)\n"
	"	x (lettre latine petite capitale c - 1D04)"},
/* 0064 */ { "LETTRE MINUSCULE LATINE D","	x (lettre minuscule cyrillique dé komi - 0501)"},
/* 0065 */ { "LETTRE MINUSCULE LATINE E","	x (symbole estimé - 212E)\n"
	"	x (minuscule e de ronde - 212F)\n"
	"	x (lettre minuscule latine e gothique - AB32)"},
/* 0066 */ { "LETTRE MINUSCULE LATINE F","	x (lettre minuscule latine f hameçon - 0192)\n"
	"	x (lettre minuscule latine f doux - AB35)"},
/* 0067 */ { "LETTRE MINUSCULE LATINE G","	x (lettre minuscule latine g cursif - 0261)\n"
	"	x (minuscule g de ronde - 210A)"},
/* 0068 */ { "LETTRE MINUSCULE LATINE H","	x (lettre minuscule cyrillique hé - 04BB)\n"
	"	x (constante de planck - 210E)"},
/* 0069 */ { "LETTRE MINUSCULE LATINE I","	* le turc et l'azéri utilisent 0130 pour la majuscule\n"
	"	x (lettre minuscule latine i sans point - 0131)\n"
	"	x (exposant lettre minuscule latine i - 2071)\n"
	"	x (minuscule mathématique italique i sans point - 1D6A4)"},
/* 006A */ { "LETTRE MINUSCULE LATINE J","	x (lettre minuscule latine j sans point - 0237)\n"
	"	x (lettre grecque yot - 03F3)\n"
	"	x (minuscule mathématique italique j sans point - 1D6A5)"},
/* 006B */ { "LETTRE MINUSCULE LATINE K",NULL},
/* 006C */ { "LETTRE MINUSCULE LATINE L","	x (minuscule l de ronde - 2113)\n"
	"	x (minuscule mathématique l de ronde - 1D4C1)"},
/* 006D */ { "LETTRE MINUSCULE LATINE M",NULL},
/* 006E */ { "LETTRE MINUSCULE LATINE N","	x (exposant lettre minuscule latine n - 207F)"},
/* 006F */ { "LETTRE MINUSCULE LATINE O","	x (lettre latine petite capitale o - 1D0F)\n"
	"	x (minuscule o de ronde - 2134)\n"
	"	x (lettre minuscule latine o gothique - AB3D)"},
/* 0070 */ { "LETTRE MINUSCULE LATINE P",NULL},
/* 0071 */ { "LETTRE MINUSCULE LATINE Q","	x (lettre minuscule cyrillique qa - 051B)"},
/* 0072 */ { "LETTRE MINUSCULE LATINE R",NULL},
/* 0073 */ { "LETTRE MINUSCULE LATINE S","	x (lettre minuscule latine s long - 017F)\n"
	"	x (lettre latine petite capitale s - A731)"},
/* 0074 */ { "LETTRE MINUSCULE LATINE T",NULL},
/* 0075 */ { "LETTRE MINUSCULE LATINE U",NULL},
/* 0076 */ { "LETTRE MINUSCULE LATINE V",NULL},
/* 0077 */ { "LETTRE MINUSCULE LATINE W","	x (lettre minuscule cyrillique wé - 051D)\n"
	"	x (lettre latine petite capitale w - 1D21)"},
/* 0078 */ { "LETTRE MINUSCULE LATINE X","	x (signe de multiplication - 00D7)"},
/* 0079 */ { "LETTRE MINUSCULE LATINE Y",NULL},
/* 007A */ { "LETTRE MINUSCULE LATINE Z","	x (lettre minuscule latine z barré - 01B6)\n"
	"	x (lettre latine petite capitale z - 1D22)"},
/* 007B */ { "ACCOLADE GAUCHE","	= accolade ouvrante (1.0)"},
/* 007C */ { "BARRE VERTICALE","	* utilisée par paire pour indiquer une valeur absolue\n"
	"	* également utilisée comme séparateur non apparié ou comme clôture\n"
	"	x (barre brisée - 00A6)\n"
	"	x (lettre latine clic dental - 01C0)\n"
	"	x (ponctuation hébraïque paseq - 05C0)\n"
	"	x (danda dévanâgarî - 0964)\n"
	"	x (diacritique ligne verticale longue couvrante - 20D2)\n"
	"	x (est un diviseur de - 2223)\n"
	"	x (barre verticale fine - 2758)"},
/* 007D */ { "ACCOLADE DROITE","	= accolade fermante (1.0)"},
/* 007E */ { "TILDE","	* ce caractère chasse\n"
	"	x (petit tilde - 02DC)\n"
	"	x (diacritique tilde - 0303)\n"
	"	x (diacritique tilde couvrant - 0334)\n"
	"	x (tiret ondé - 2053)\n"
	"	x (opérateur tilde - 223C)\n"
	"	x (tilde à cercle suscrit - 2E1B)\n"
	"	x (tilde vertical - 2E2F)\n"
	"	x (tiret en esse - 301C)\n"
	"	x (tilde pleine chasse - FF5E)"},
/* 007F */ { NULL,"	= SUPPRESSION"},
/* 0080 */ { NULL,"	= caractère de bourre"},
/* 0081 */ { NULL,"	= octet supérieur prédéfini"},
/* 0082 */ { NULL,"	= ARRÊT PERMIS ICI\n"
	"	x (espace sans chasse - 200B)"},
/* 0083 */ { NULL,"	= AUCUN ARRÊT ICI\n"
	"	x (gluon de mots - 2060)"},
/* 0084 */ { NULL,"	* anciennement dénommé « index »"},
/* 0085 */ { NULL,"	= À LA LIGNE\n"
	"	= ligne suivante"},
/* 0086 */ { NULL,"	= DÉBUT DE ZONE SÉLECTIONNÉE"},
/* 0087 */ { NULL,"	= FIN DE ZONE SÉLECTIONNÉE"},
/* 0088 */ { NULL,"	= TAQUET DE TABULATEUR HORIZONTAL\n"
	"	= arrêt de tabulateur horizontal"},
/* 0089 */ { NULL,"	= TABULATEUR HORIZONTAL AVEC JUSTIFICATION"},
/* 008A */ { NULL,"	= TAQUET DE TABULATEUR VERTICAL\n"
	"	= arrêt de tabulateur vertical"},
/* 008B */ { NULL,"	= INTERLIGNE PARTIEL VERS LE BAS\n"
	"	= interligne partiel avant"},
/* 008C */ { NULL,"	= INTERLIGNE PARTIEL VERS LE HAUT\n"
	"	= interligne partiel arrière"},
/* 008D */ { NULL,"	= INDEX RENVERSÉ\n"
	"	= interligne inversé"},
/* 008E */ { NULL,"	= REMPLACEMENT UNIQUE DEUX"},
/* 008F */ { NULL,"	= REMPLACEMENT UNIQUE TROIS"},
/* 0090 */ { NULL,"	= CHAÎNE DE COMMANDE D'APPAREILS"},
/* 0091 */ { NULL,"	= USAGE PRIVÉ UN"},
/* 0092 */ { NULL,"	= USAGE PRIVÉ DEUX"},
/* 0093 */ { NULL,"	= MISE EN MODE TRANSMISSION"},
/* 0094 */ { NULL,"	= ANNULATION DU CARACTÈRE PRÉCÉDENT"},
/* 0095 */ { NULL,"	= MESSAGE EN ATTENTE"},
/* 0096 */ { NULL,"	= DÉBUT DE ZONE PROTÉGÉE"},
/* 0097 */ { NULL,"	= FIN DE ZONE PROTÉGÉE"},
/* 0098 */ { NULL,"	= DÉBUT DE CHAÎNE"},
/* 0099 */ { NULL,"	= introducteur de caractère graphique unique"},
/* 009A */ { NULL,"	= INTRODUCTEUR DE CARACTÈRE UNIQUE"},
/* 009B */ { NULL,"	= INTRODUCTEUR DE SÉQUENCE DE COMMANDES"},
/* 009C */ { NULL,"	= FIN DE CHAÎNE"},
/* 009D */ { NULL,"	= COMMANDE DE SYSTÈME D'EXPLOITATION"},
/* 009E */ { NULL,"	= MESSAGE PRIVÉ"},
/* 009F */ { NULL,"	= COMMANDE DE PROGICIEL"},
/* 00A0 */ { "ESPACE INSÉCABLE","	= espace imposée, espace sans coupure, espace liante\n"
	"	* communément abrégée en NBSP (no-break space)\n"
	"	* devrait avoir la même chasse que l'espace 0020\n"
	"	x (espace - 0020)\n"
	"	x (espace tabulaire - 2007)\n"
	"	x (espace insécable étroite - 202F)\n"
	"	x (gluon de mots - 2060)\n"
	"	x (boîte ouverte à épaulement - 237D)\n"
	"	x (indicateur d'ordre des octets - FEFF)\n"
	"	# <insécable> 0020"},
/* 00A1 */ { "POINT D'EXCLAMATION RENVERSÉ","	= point d'exclamation inversé\n"
	"	* castillan, asturien, galicien\n"
	"	* utilisé dans l'API étendu pour représenter le clic percussif sous-alvéolaire sublaminal (claquement de la langue)\n"
	"	x (point d'exclamation - 0021)\n"
	"	x (lettre modificative point d'exclamation renversé haut - A71E)"},
/* 00A2 */ { "SYMBOLE CENTIME","	= symbole cent américain\n"
	"	x (lettre minuscule latine c barré - 023C)\n"
	"	x (symbole millième - 20A5)\n"
	"	x (symbole cedi - 20B5)\n"
	"	x (symbole musical mesure à deux-deux - 1D135)"},
/* 00A3 */ { "SYMBOLE LIVRE","	= livre sterling, punt irlandaise, lire, etc.\n"
	"	* à ne pas confondre avec l'unité de poids\n"
	"	* le glyphe peut comporter une ou deux barres transversales, ce qui le distingue de 20A4\n"
	"	x (symbole lire - 20A4)\n"
	"	x (symbole lire turque - 20BA)\n"
	"	x (symbole romain demi-once - 10192)"},
/* 00A4 */ { "SYMBOLE MONÉTAIRE","	* devise générique ou inconnue\n"
	"	* d'autres caractères de symboles monétaires sont codés à partir de la valeur 20A0\n"
	"	x (symbole dollar - 0024)"},
/* 00A5 */ { "SYMBOLE YEN","	= symbole yuan (renminbi)\n"
	"	* il n'y a pas d'autre caractère défini pour distinguer le yuan et le yen\n"
	"	* le glyphe peut comporter une ou deux barres transversales, mais le symbole officiel au Japon et en Chine en comporte deux\n"
	"	* dans le contexte local, des idéogrammes spécifiques peuvent être utilisés pour les unités de ces monnaies\n"
	"	x (lettre majuscule latine y barré - 024E)\n"
	"	x (lettre majuscule cyrillique ou droit barré - 04B0)\n"
	"	x 5143\n"
	"	x 5186"},
/* 00A6 */ { "BARRE BRISÉE","	= barre verticale brisée (1.0)\n"
	"	= barre discontinue, barre déjointe, barre à trou\n"
	"	x (barre verticale - 007C)"},
/* 00A7 */ { "PARAGRAPHE","	* symbole typographique qui sert à désigner la subdivision d'un alinéa ou d'un article\n"
	"	* pourrait être issu de « SS », abréviation de « signum sectionis »\n"
	"	x (moitié supérieure de paragraphe - 2E39)"},
/* 00A8 */ { "TRÉMA","	* ce caractère chasse\n"
	"	x (diacritique tréma - 0308)\n"
	"	# 0020 0308"},
/* 00A9 */ { "SYMBOLE COPYRIGHT","	= mention de réserve\n"
	"	x (copyright de phonogramme - 2117)\n"
	"	x (lettre majuscule latine c cerclée - 24B8)\n"
	"	x (symbole copyleft - 1F12F)\n"
	"	x (symbole de topographie de circuit intégré - 1F1AD)"},
/* 00AA */ { "INDICATEUR ORDINAL FÉMININ","	* castillan\n"
	"	x (lettre modificative minuscule a - 1D43)\n"
	"	# <exp> 0061"},
/* 00AB */ { "GUILLEMET GAUCHE","	= guillemet chevron pointant vers la gauche\n"
	"	* habituellement ouvrant, mais dans certaines langues fermant\n"
	"	x (très inférieur à - 226A)\n"
	"	x (double chevron gauche - 300A)"},
/* 00AC */ { "SIGNE NÉGATION","	= symbole non\n"
	"	x (signe négation réfléchi - 2310)\n"
	"	x (signe négation culbuté - 2319)"},
/* 00AD */ { "TRAIT D'UNION CONDITIONNEL","	= trait d'union virtuel\n"
	"	* communément abrégé en SHY (soft hyphen)\n"
	"	* un caractère de formatage invisible indiquant un emplacement possible pour une coupure de mot"},
/* 00AE */ { "SYMBOLE MARQUE DÉPOSÉE","	x (symbole marque de commerce - 2122)\n"
	"	x (lettre majuscule latine r cerclée - 24C7)\n"
	"	x (symbole md élevé - 1F16B)\n"
	"	x (symbole mr élevé - 1F16C)"},
/* 00AF */ { "MACRON","	= tiret haut, barre supérieure APL\n"
	"	* ce caractère chasse\n"
	"	* contrairement à 203E, les occurrences adjacentes de ce caractère ne se rejoignent pas\n"
	"	x (lettre modificative macron - 02C9)\n"
	"	x (diacritique macron - 0304)\n"
	"	x (diacritique tiret haut - 0305)\n"
	"	x (tiret haut - 203E)\n"
	"	x (diacritique macron jointif - FE26)\n"
	"	# 0020 0304"},
/* 00B0 */ { "SYMBOLE DEGRÉ","	* ce caractère chasse\n"
	"	x (rond en chef - 02DA)\n"
	"	x (diacritique rond en chef - 030A)\n"
	"	x (exposant zéro - 2070)\n"
	"	x (degré celsius - 2103)\n"
	"	x (degré fahrenheit - 2109)\n"
	"	x (opérateur rond - 2218)"},
/* 00B1 */ { "SIGNE PLUS-OU-MOINS","	= biquintile (aspect astrologique de 144 degrés)\n"
	"	x (signe moins-ou-plus - 2213)\n"
	"	x (divisé multiplié - 22C7)"},
/* 00B2 */ { "EXPOSANT DEUX","	= élevé au carré\n"
	"	* autres exposants : 2070-2079\n"
	"	x (exposant un - 00B9)\n"
	"	# <exp> 0032"},
/* 00B3 */ { "EXPOSANT TROIS","	= élevé au cube\n"
	"	x (exposant un - 00B9)\n"
	"	# <exp> 0033"},
/* 00B4 */ { "ACCENT AIGU","	* ce caractère chasse\n"
	"	x (accent grave - 0060)\n"
	"	x (lettre modificative prime - 02B9)\n"
	"	x (lettre modificative accent aigu - 02CA)\n"
	"	x (double accent aigu - 02DD)\n"
	"	x (diacritique accent aigu - 0301)\n"
	"	x (accent grec - 0384)\n"
	"	x (accent aigu grec - 1FFD)\n"
	"	x (prime - 2032)\n"
	"	# 0020 0301"},
/* 00B5 */ { "SYMBOLE MICRO","	# 03BC lettre minuscule grecque mu"},
/* 00B6 */ { "PIED-DE-MOUCHE","	= fin de paragraphe\n"
	"	* symbole typographique désuet qui pouvait être utilisé pour marquer la fin d'un paragraphe\n"
	"	* parfois encore employé à des fins esthétiques dans certaines publications\n"
	"	* en informatique, caractère non imprimable qui marque la présence d'un code de fin de paragraphe\n"
	"	x (pied-de-mouche réfléchi - 204B)\n"
	"	x (pied-de-mouche de fantaisie à jambage courbé - 2761)\n"
	"	x (capitule - 2E3F)"},
/* 00B7 */ { "POINT MÉDIAN","	= point central, point milieu\n"
	"	= virgule géorgienne\n"
	"	= point médian grec (ano teleia)\n"
	"	* également utilisé comme point décimal élevé ou pour indiquer la multiplication ; 22C5 est recommandé pour la multiplication\n"
	"	* utilisé comme signe de longueur de voyelle (dans certaines parties des mots) dans de nombreuses orthographes amérindiennes\n"
	"	x (point - 002E)\n"
	"	x (point en chef - 02D9)\n"
	"	x (ano teleia grec - 0387)\n"
	"	x (puce - 2022)\n"
	"	x (point de conduite simple - 2024)\n"
	"	x (point de coupure de mot - 2027)\n"
	"	x (opérateur puce - 2219)\n"
	"	x (opérateur point - 22C5)\n"
	"	x (point médian séparateur de mots - 2E31)\n"
	"	x (point élevé - 2E33)\n"
	"	x (point médian katakana - 30FB)\n"
	"	x (lettre latine point sinologique - A78F)"},
/* 00B8 */ { "CÉDILLE","	* ce caractère chasse\n"
	"	* autres diacritiques à chasse : 02D8-02DB\n"
	"	x (diacritique cédille - 0327)\n"
	"	# 0020 0327"},
/* 00B9 */ { "EXPOSANT UN","	x (exposant deux - 00B2)\n"
	"	x (exposant trois - 00B3)\n"
	"	x (exposant zéro - 2070)\n"
	"	# <exp> 0031"},
/* 00BA */ { "INDICATEUR ORDINAL MASCULIN","	* castillan\n"
	"	x (lettre modificative minuscule o - 1D52)\n"
	"	x (exposant zéro - 2070)\n"
	"	x (symbole numéro - 2116)\n"
	"	# <exp> 006F"},
/* 00BB */ { "GUILLEMET DROIT","	= guillemet chevron pointant vers la droite\n"
	"	* habituellement fermant, mais dans certaines langues ouvrant\n"
	"	x (très supérieur à - 226B)\n"
	"	x (double chevron droit - 300B)"},
/* 00BC */ { "FRACTION ORDINAIRE UN QUART","	# <fraction> 0031 2044 0034"},
/* 00BD */ { "FRACTION ORDINAIRE UN DEMI","	# <fraction> 0031 2044 0032"},
/* 00BE */ { "FRACTION ORDINAIRE TROIS QUARTS","	# <fraction> 0033 2044 0034"},
/* 00BF */ { "POINT D'INTERROGATION RENVERSÉ","	= point d'interrogation inversé\n"
	"	* castillan\n"
	"	x (point d'interrogation - 003F)\n"
	"	x (point exclarrogatif culbuté - 2E18)\n"
	"	x (point d'interrogation réfléchi - 2E2E)"},
/* 00C0 */ { "LETTRE MAJUSCULE LATINE A ACCENT GRAVE","	: 0041 0300"},
/* 00C1 */ { "LETTRE MAJUSCULE LATINE A ACCENT AIGU","	: 0041 0301"},
/* 00C2 */ { "LETTRE MAJUSCULE LATINE A ACCENT CIRCONFLEXE","	: 0041 0302"},
/* 00C3 */ { "LETTRE MAJUSCULE LATINE A TILDE","	: 0041 0303"},
/* 00C4 */ { "LETTRE MAJUSCULE LATINE A TRÉMA","	: 0041 0308"},
/* 00C5 */ { "LETTRE MAJUSCULE LATINE A ROND EN CHEF","	x (symbole angström - 212B)\n"
	"	: 0041 030A"},
/* 00C6 */ { "LETTRE MAJUSCULE LATINE AE","	= digramme soudé ae majuscule, ligature ae majuscule\n"
	"	= e dans l'a majuscule\n"
	"	= ash majuscule (du vieil anglais « æsc »)\n"
	"	x (ligature majuscule cyrillique a ié - 04D4)"},
/* 00C7 */ { "LETTRE MAJUSCULE LATINE C CÉDILLE","	: 0043 0327"},
/* 00C8 */ { "LETTRE MAJUSCULE LATINE E ACCENT GRAVE","	: 0045 0300"},
/* 00C9 */ { "LETTRE MAJUSCULE LATINE E ACCENT AIGU","	: 0045 0301"},
/* 00CA */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE","	: 0045 0302"},
/* 00CB */ { "LETTRE MAJUSCULE LATINE E TRÉMA","	: 0045 0308"},
/* 00CC */ { "LETTRE MAJUSCULE LATINE I ACCENT GRAVE","	: 0049 0300"},
/* 00CD */ { "LETTRE MAJUSCULE LATINE I ACCENT AIGU","	: 0049 0301"},
/* 00CE */ { "LETTRE MAJUSCULE LATINE I ACCENT CIRCONFLEXE","	: 0049 0302"},
/* 00CF */ { "LETTRE MAJUSCULE LATINE I TRÉMA","	: 0049 0308"},
/* 00D0 */ { "LETTRE MAJUSCULE LATINE ED","	= eth majuscule\n"
	"	* la minuscule est 00F0\n"
	"	x (lettre majuscule latine d barré - 0110)\n"
	"	x (lettre majuscule latine d africain - 0189)\n"
	"	x (lettre majuscule latine d à petit trait couvrant - A7C7)"},
/* 00D1 */ { "LETTRE MAJUSCULE LATINE N TILDE","	: 004E 0303"},
/* 00D2 */ { "LETTRE MAJUSCULE LATINE O ACCENT GRAVE","	: 004F 0300"},
/* 00D3 */ { "LETTRE MAJUSCULE LATINE O ACCENT AIGU","	: 004F 0301"},
/* 00D4 */ { "LETTRE MAJUSCULE LATINE O ACCENT CIRCONFLEXE","	: 004F 0302"},
/* 00D5 */ { "LETTRE MAJUSCULE LATINE O TILDE","	: 004F 0303"},
/* 00D6 */ { "LETTRE MAJUSCULE LATINE O TRÉMA","	: 004F 0308"},
/* 00D7 */ { "SIGNE DE MULTIPLICATION","	= produit cartésien en notation Z\n"
	"	x (lettre minuscule latine x - 0078)\n"
	"	x (sautoir - 2613)\n"
	"	x (x de multiplication - 2715)\n"
	"	x (x de vote épais - 2718)\n"
	"	x (signe en forme de croix - 274C)\n"
	"	x (produit vectoriel - 2A2F)\n"
	"	x (x d'annulation - 1F5D9)\n"
	"	x (sautoir fin - 1F7A9)"},
/* 00D8 */ { "LETTRE MAJUSCULE LATINE O BARRÉ OBLIQUEMENT","	x (lettre majuscule latine o tilde médian - 019F)\n"
	"	x (ensemble vide - 2205)\n"
	"	x (lettre majuscule latine o à trait long couvrant - A74A)"},
/* 00D9 */ { "LETTRE MAJUSCULE LATINE U ACCENT GRAVE","	: 0055 0300"},
/* 00DA */ { "LETTRE MAJUSCULE LATINE U ACCENT AIGU","	: 0055 0301"},
/* 00DB */ { "LETTRE MAJUSCULE LATINE U ACCENT CIRCONFLEXE","	: 0055 0302"},
/* 00DC */ { "LETTRE MAJUSCULE LATINE U TRÉMA","	: 0055 0308"},
/* 00DD */ { "LETTRE MAJUSCULE LATINE Y ACCENT AIGU","	: 0059 0301"},
/* 00DE */ { "LETTRE MAJUSCULE LATINE THORN",NULL},
/* 00DF */ { "LETTRE MINUSCULE LATINE S DUR","	= Eszett\n"
	"	* allemand\n"
	"	* inutilisée en allemand standard suisse (« haut-allemand » suisse)\n"
	"	* la majuscule est « SS » ou 1E9E\n"
	"	* typographiquement, le glyphe de ce caractère peut reposer sur une ligature de 017F avec 0073 ou avec un glyphe de style ancien pour 007A (semblable en apparence à 0292) ; les deux formes existent de façon interchangeable aujourd'hui\n"
	"	x (lettre minuscule latine s long - 017F)\n"
	"	x (lettre minuscule latine ej - 0292)\n"
	"	x (lettre minuscule grecque bêta - 03B2)\n"
	"	x (lettre majuscule latine s dur - 1E9E)\n"
	"	x (lettre minuscule latine bêta - A7B5)\n"
	"	x (lettre minuscule latine s moyen scots - A7D7)"},
/* 00E0 */ { "LETTRE MINUSCULE LATINE A ACCENT GRAVE","	: 0061 0300"},
/* 00E1 */ { "LETTRE MINUSCULE LATINE A ACCENT AIGU","	: 0061 0301"},
/* 00E2 */ { "LETTRE MINUSCULE LATINE A ACCENT CIRCONFLEXE","	: 0061 0302"},
/* 00E3 */ { "LETTRE MINUSCULE LATINE A TILDE","	* portugais\n"
	"	: 0061 0303"},
/* 00E4 */ { "LETTRE MINUSCULE LATINE A TRÉMA","	: 0061 0308"},
/* 00E5 */ { "LETTRE MINUSCULE LATINE A ROND EN CHEF","	* danois, norvégien, suédois, wallon\n"
	"	: 0061 030A"},
/* 00E6 */ { "LETTRE MINUSCULE LATINE AE","	= digramme soudé ae minuscule, ligature ae minuscule\n"
	"	= e dans l'a minuscule\n"
	"	= ash minuscule (du vieil anglais « æsc »)\n"
	"	* danois, norvégien, islandais, féroïen, vieil anglais, français, API\n"
	"	x (digramme soudé minuscule latin oe - 0153)\n"
	"	x (ligature minuscule cyrillique a ié - 04D5)\n"
	"	x (lettre minuscule latine ae culbuté - 1D02)\n"
	"	x (lettre minuscule latine a schwa réfléchi - AB31)"},
/* 00E7 */ { "LETTRE MINUSCULE LATINE C CÉDILLE","	: 0063 0327"},
/* 00E8 */ { "LETTRE MINUSCULE LATINE E ACCENT GRAVE","	: 0065 0300"},
/* 00E9 */ { "LETTRE MINUSCULE LATINE E ACCENT AIGU","	: 0065 0301"},
/* 00EA */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE","	: 0065 0302"},
/* 00EB */ { "LETTRE MINUSCULE LATINE E TRÉMA","	: 0065 0308"},
/* 00EC */ { "LETTRE MINUSCULE LATINE I ACCENT GRAVE","	* italien, malgache\n"
	"	: 0069 0300"},
/* 00ED */ { "LETTRE MINUSCULE LATINE I ACCENT AIGU","	: 0069 0301"},
/* 00EE */ { "LETTRE MINUSCULE LATINE I ACCENT CIRCONFLEXE","	: 0069 0302"},
/* 00EF */ { "LETTRE MINUSCULE LATINE I TRÉMA","	: 0069 0308"},
/* 00F0 */ { "LETTRE MINUSCULE LATINE ED","	= eth minuscule\n"
	"	* islandais, féroïen, vieil anglais, API\n"
	"	* la majuscule est 00D0\n"
	"	x (lettre minuscule latine d barré - 0111)\n"
	"	x (lettre minuscule grecque delta - 03B4)\n"
	"	x (lettre minuscule latine delta - 1E9F)\n"
	"	x (dérivée partielle - 2202)\n"
	"	x (lettre minuscule latine d insulaire - A77A)"},
/* 00F1 */ { "LETTRE MINUSCULE LATINE N TILDE","	: 006E 0303"},
/* 00F2 */ { "LETTRE MINUSCULE LATINE O ACCENT GRAVE","	: 006F 0300"},
/* 00F3 */ { "LETTRE MINUSCULE LATINE O ACCENT AIGU","	: 006F 0301"},
/* 00F4 */ { "LETTRE MINUSCULE LATINE O ACCENT CIRCONFLEXE","	: 006F 0302"},
/* 00F5 */ { "LETTRE MINUSCULE LATINE O TILDE","	* portugais, estonien, live\n"
	"	: 006F 0303"},
/* 00F6 */ { "LETTRE MINUSCULE LATINE O TRÉMA","	: 006F 0308"},
/* 00F7 */ { "SIGNE DE DIVISION","	* parfois utilisé comme une variante d'un trait d'union, plus différenciée visuellement dans certains contextes\n"
	"	* autrefois utilisé comme un signe de ponctuation pour indiquer des passages douteux dans les manuscrits\n"
	"	x (obèle syriaque héracléen - 070B)\n"
	"	x (signe moins commercial - 2052)\n"
	"	x (barre oblique de division - 2215)\n"
	"	x (est un diviseur de - 2223)\n"
	"	x (rapport - 2236)\n"
	"	x (signe de division épais - 2797)\n"
	"	x (potence de division - 27CC)\n"
	"	x (obèle pointé - 2E13)"},
/* 00F8 */ { "LETTRE MINUSCULE LATINE O BARRÉ OBLIQUEMENT","	* danois, norvégien, féroïen, API\n"
	"	x (lettre minuscule latine o barré - 0275)\n"
	"	x (symbole diamètre - 2300)\n"
	"	x (lettre minuscule latine o à trait long couvrant - A74B)\n"
	"	x (lettre minuscule latine o polonais ancien - A7C1)\n"
	"	x (lettre minuscule latine o gothique barré - AB3E)"},
/* 00F9 */ { "LETTRE MINUSCULE LATINE U ACCENT GRAVE","	* français, italien\n"
	"	: 0075 0300"},
/* 00FA */ { "LETTRE MINUSCULE LATINE U ACCENT AIGU","	: 0075 0301"},
/* 00FB */ { "LETTRE MINUSCULE LATINE U ACCENT CIRCONFLEXE","	: 0075 0302"},
/* 00FC */ { "LETTRE MINUSCULE LATINE U TRÉMA","	: 0075 0308"},
/* 00FD */ { "LETTRE MINUSCULE LATINE Y ACCENT AIGU","	* tchèque, slovaque, islandais, féroïen, gallois, malgache\n"
	"	: 0079 0301"},
/* 00FE */ { "LETTRE MINUSCULE LATINE THORN","	* islandais, vieil anglais, phonétique\n"
	"	* lettre latine empruntée à l'alphabet runique\n"
	"	* remplacée par « th » en anglais moderne\n"
	"	x (lettre minuscule grecque cho - 03F8)\n"
	"	x (lettre runique thurisaz thorn thurs th - 16A6)\n"
	"	x (lettre minuscule latine double thorn - A7D3)"},
/* 00FF */ { "LETTRE MINUSCULE LATINE Y TRÉMA","	* français, orthographe hongroise médiévale\n"
	"	* la majuscule est 0178\n"
	"	: 0079 0308"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_01[] = {
/* 0100 */ { "LETTRE MAJUSCULE LATINE A MACRON","	: 0041 0304"},
/* 0101 */ { "LETTRE MINUSCULE LATINE A MACRON","	* letton, latin, etc.\n"
	"	: 0061 0304"},
/* 0102 */ { "LETTRE MAJUSCULE LATINE A BRÈVE","	: 0041 0306"},
/* 0103 */ { "LETTRE MINUSCULE LATINE A BRÈVE","	* roumain, vietnamien, latin, etc.\n"
	"	: 0061 0306"},
/* 0104 */ { "LETTRE MAJUSCULE LATINE A OGONEK","	: 0041 0328"},
/* 0105 */ { "LETTRE MINUSCULE LATINE A OGONEK","	* polonais, lituanien, etc.\n"
	"	: 0061 0328"},
/* 0106 */ { "LETTRE MAJUSCULE LATINE C ACCENT AIGU","	: 0043 0301"},
/* 0107 */ { "LETTRE MINUSCULE LATINE C ACCENT AIGU","	* polonais, croate, serbe, etc.\n"
	"	x (lettre minuscule cyrillique tié - 045B)\n"
	"	: 0063 0301"},
/* 0108 */ { "LETTRE MAJUSCULE LATINE C ACCENT CIRCONFLEXE","	: 0043 0302"},
/* 0109 */ { "LETTRE MINUSCULE LATINE C ACCENT CIRCONFLEXE","	* espéranto\n"
	"	: 0063 0302"},
/* 010A */ { "LETTRE MAJUSCULE LATINE C POINT EN CHEF","	: 0043 0307"},
/* 010B */ { "LETTRE MINUSCULE LATINE C POINT EN CHEF","	* maltais, gaélique irlandais (ancienne orthographe)\n"
	"	: 0063 0307"},
/* 010C */ { "LETTRE MAJUSCULE LATINE C CARON","	: 0043 030C"},
/* 010D */ { "LETTRE MINUSCULE LATINE C CARON","	= c chevron, c accent hirondelle\n"
	"	* tchèque, slovaque, slovène et de nombreuses autres langues\n"
	"	: 0063 030C"},
/* 010E */ { "LETTRE MAJUSCULE LATINE D CARON","	* on préfère la forme avec un caron dans tous les contextes\n"
	"	: 0044 030C"},
/* 010F */ { "LETTRE MINUSCULE LATINE D CARON","	= d chevron, d accent hirondelle\n"
	"	* tchèque, slovaque\n"
	"	* pour la composition, on recommande la forme avec l'apostrophe\n"
	"	: 0064 030C"},
/* 0110 */ { "LETTRE MAJUSCULE LATINE D BARRÉ","	x (lettre majuscule latine ed - 00D0)\n"
	"	x (lettre majuscule latine d africain - 0189)\n"
	"	x (lettre majuscule latine d à petit trait couvrant - A7C7)"},
/* 0111 */ { "LETTRE MINUSCULE LATINE D BARRÉ","	* croate, serbe, vietnamien, same, moro\n"
	"	* les américanistes utilisent une variante de glyphe avec une barre traversant la panse\n"
	"	x (lettre minuscule latine ed - 00F0)\n"
	"	x (lettre minuscule cyrillique dié - 0452)\n"
	"	x (lettre minuscule latine d tilde médian - 1D6D)\n"
	"	x (symbole dong - 20AB)\n"
	"	x (lettre minuscule latine d à petit trait couvrant - A7C8)"},
/* 0112 */ { "LETTRE MAJUSCULE LATINE E MACRON","	: 0045 0304"},
/* 0113 */ { "LETTRE MINUSCULE LATINE E MACRON","	* letton, latin, etc.\n"
	"	: 0065 0304"},
/* 0114 */ { "LETTRE MAJUSCULE LATINE E BRÈVE","	: 0045 0306"},
/* 0115 */ { "LETTRE MINUSCULE LATINE E BRÈVE","	* letton, latin, etc.\n"
	"	: 0065 0306"},
/* 0116 */ { "LETTRE MAJUSCULE LATINE E POINT EN CHEF","	: 0045 0307"},
/* 0117 */ { "LETTRE MINUSCULE LATINE E POINT EN CHEF","	* lituanien\n"
	"	: 0065 0307"},
/* 0118 */ { "LETTRE MAJUSCULE LATINE E OGONEK","	: 0045 0328"},
/* 0119 */ { "LETTRE MINUSCULE LATINE E OGONEK","	* polonais, lituanien, etc.\n"
	"	: 0065 0328"},
/* 011A */ { "LETTRE MAJUSCULE LATINE E CARON","	: 0045 030C"},
/* 011B */ { "LETTRE MINUSCULE LATINE E CARON","	= e chevron, e accent hirondelle\n"
	"	* tchèque, sorabe, etc.\n"
	"	: 0065 030C"},
/* 011C */ { "LETTRE MAJUSCULE LATINE G ACCENT CIRCONFLEXE","	: 0047 0302"},
/* 011D */ { "LETTRE MINUSCULE LATINE G ACCENT CIRCONFLEXE","	* espéranto\n"
	"	: 0067 0302"},
/* 011E */ { "LETTRE MAJUSCULE LATINE G BRÈVE","	: 0047 0306"},
/* 011F */ { "LETTRE MINUSCULE LATINE G BRÈVE","	* turc, azéri\n"
	"	x (lettre minuscule latine g caron - 01E7)\n"
	"	: 0067 0306"},
/* 0120 */ { "LETTRE MAJUSCULE LATINE G POINT EN CHEF","	: 0047 0307"},
/* 0121 */ { "LETTRE MINUSCULE LATINE G POINT EN CHEF","	* maltais, gaélique irlandais (ancienne orthographe)\n"
	"	: 0067 0307"},
/* 0122 */ { "LETTRE MAJUSCULE LATINE G CÉDILLE","	: 0047 0327"},
/* 0123 */ { "LETTRE MINUSCULE LATINE G CÉDILLE","	* letton\n"
	"	* il existe trois variantes principales de glyphe\n"
	"	: 0067 0327"},
/* 0124 */ { "LETTRE MAJUSCULE LATINE H ACCENT CIRCONFLEXE","	* la minuscule en nawdm est 0266\n"
	"	: 0048 0302"},
/* 0125 */ { "LETTRE MINUSCULE LATINE H ACCENT CIRCONFLEXE","	* espéranto\n"
	"	: 0068 0302"},
/* 0126 */ { "LETTRE MAJUSCULE LATINE H BARRÉ","	x (lettre modificative majuscule h barré - A7F8)"},
/* 0127 */ { "LETTRE MINUSCULE LATINE H BARRÉ","	* maltais, API, etc.\n"
	"	x (lettre minuscule cyrillique tié - 045B)\n"
	"	x (constante de planck sur deux pi - 210F)"},
/* 0128 */ { "LETTRE MAJUSCULE LATINE I TILDE","	: 0049 0303"},
/* 0129 */ { "LETTRE MINUSCULE LATINE I TILDE","	* groenlandais (ancienne orthographe), kikouyou\n"
	"	: 0069 0303"},
/* 012A */ { "LETTRE MAJUSCULE LATINE I MACRON","	: 0049 0304"},
/* 012B */ { "LETTRE MINUSCULE LATINE I MACRON","	* letton, latin, etc.\n"
	"	: 0069 0304"},
/* 012C */ { "LETTRE MAJUSCULE LATINE I BRÈVE","	: 0049 0306"},
/* 012D */ { "LETTRE MINUSCULE LATINE I BRÈVE","	* latin, etc.\n"
	"	: 0069 0306"},
/* 012E */ { "LETTRE MAJUSCULE LATINE I OGONEK","	: 0049 0328"},
/* 012F */ { "LETTRE MINUSCULE LATINE I OGONEK","	* lituanien, etc.\n"
	"	: 0069 0328"},
/* 0130 */ { "LETTRE MAJUSCULE LATINE I POINT EN CHEF","	= i point\n"
	"	* turc, azéri\n"
	"	* la minuscule est 0069\n"
	"	x (lettre majuscule latine i - 0049)\n"
	"	: 0049 0307"},
/* 0131 */ { "LETTRE MINUSCULE LATINE I SANS POINT","	* turc, azéri\n"
	"	* la majuscule est 0049\n"
	"	x (lettre minuscule latine i - 0069)\n"
	"	x (lettre minuscule latine iota - 0269)\n"
	"	x (lettre latine petite capitale i - 026A)\n"
	"	x (lettre minuscule cyrillique i biélorusse-ukrainien - 0456)\n"
	"	x (minuscule mathématique italique i sans point - 1D6A4)"},
/* 0132 */ { "DIGRAMME SOUDÉ MAJUSCULE LATIN IJ","	# 0049 004A"},
/* 0133 */ { "DIGRAMME SOUDÉ MINUSCULE LATIN IJ","	= ligature ij\n"
	"	* néerlandais\n"
	"	# 0069 006A"},
/* 0134 */ { "LETTRE MAJUSCULE LATINE J ACCENT CIRCONFLEXE","	: 004A 0302"},
/* 0135 */ { "LETTRE MINUSCULE LATINE J ACCENT CIRCONFLEXE","	* espéranto\n"
	"	: 006A 0302"},
/* 0136 */ { "LETTRE MAJUSCULE LATINE K CÉDILLE","	: 004B 0327"},
/* 0137 */ { "LETTRE MINUSCULE LATINE K CÉDILLE","	* letton\n"
	"	* en dépit de leurs noms, ces deux caractères devraient normalement être affichés avec une virgule souscrite\n"
	"	: 006B 0327"},
/* 0138 */ { "LETTRE MINUSCULE LATINE KRA","	* groenlandais (ancienne orthographe), inuttut du Labrador\n"
	"	x (lettre minuscule cyrillique ka - 043A)\n"
	"	x (lettre latine petite capitale k - 1D0B)"},
/* 0139 */ { "LETTRE MAJUSCULE LATINE L ACCENT AIGU","	: 004C 0301"},
/* 013A */ { "LETTRE MINUSCULE LATINE L ACCENT AIGU","	* slovaque\n"
	"	: 006C 0301"},
/* 013B */ { "LETTRE MAJUSCULE LATINE L CÉDILLE","	: 004C 0327"},
/* 013C */ { "LETTRE MINUSCULE LATINE L CÉDILLE","	* letton\n"
	"	* en dépit de leurs noms, ces deux caractères devraient normalement être affichés avec une virgule souscrite\n"
	"	: 006C 0327"},
/* 013D */ { "LETTRE MAJUSCULE LATINE L CARON","	* pour la composition, on recommande la forme avec l'apostrophe\n"
	"	: 004C 030C"},
/* 013E */ { "LETTRE MINUSCULE LATINE L CARON","	= l chevron, l accent hirondelle\n"
	"	* slovaque\n"
	"	* pour la composition, on recommande la forme avec l'apostrophe\n"
	"	: 006C 030C"},
/* 013F */ { "LETTRE MAJUSCULE LATINE L POINT MÉDIAN","	* certaines polices affichent le point médian à l'intérieur du L, mais la forme avec le point qui suit le L est recommandée\n"
	"	# 004C 00B7"},
/* 0140 */ { "LETTRE MINUSCULE LATINE L POINT MÉDIAN","	* caractère de compatibilité catalan hérité de la norme ISO/CEI 6937\n"
	"	* représentation recommandée pour le catalan : 006C 00B7\n"
	"	# 006C 00B7"},
/* 0141 */ { "LETTRE MAJUSCULE LATINE L BARRÉ","	x (lettre majuscule latine l rayé - 023D)\n"
	"	x (lettre latine petite capitale l barré obliquement - 1D0C)\n"
	"	x (lettre majuscule latine l tilde médian - 2C62)\n"
	"	x (lettre majuscule latine l à trait élevé - A748)"},
/* 0142 */ { "LETTRE MINUSCULE LATINE L BARRÉ","	* polonais, sorabe, inupiaq, etc.\n"
	"	* également utilisée pour les orthographes latines du biélorusse et de l'ukrainien\n"
	"	x (lettre minuscule latine l rayé - 019A)\n"
	"	x (lettre minuscule latine l tilde médian - 026B)"},
/* 0143 */ { "LETTRE MAJUSCULE LATINE N ACCENT AIGU","	: 004E 0301"},
/* 0144 */ { "LETTRE MINUSCULE LATINE N ACCENT AIGU","	* polonais, etc.\n"
	"	: 006E 0301"},
/* 0145 */ { "LETTRE MAJUSCULE LATINE N CÉDILLE","	: 004E 0327"},
/* 0146 */ { "LETTRE MINUSCULE LATINE N CÉDILLE","	* letton\n"
	"	* en dépit de leurs noms, ces deux caractères devraient normalement être affichés avec une virgule souscrite\n"
	"	: 006E 0327"},
/* 0147 */ { "LETTRE MAJUSCULE LATINE N CARON","	: 004E 030C"},
/* 0148 */ { "LETTRE MINUSCULE LATINE N CARON","	= n chevron, n accent hirondelle\n"
	"	* tchèque, slovaque\n"
	"	: 006E 030C"},
/* 0149 */ { "LETTRE MINUSCULE LATINE N PRÉCÉDÉE D'UNE APOSTROPHE","	= lettre minuscule apostrophe n (1.0)\n"
	"	* ce caractère est obsolète et son utilisation est fortement déconseillée\n"
	"	* afrikaans\n"
	"	* il ne s'agit pas en fait d'une lettre unique, mais d'une forme typographique courante de l'article indéfini\n"
	"	* caractère de compatibilité hérité de la norme ISO/CEI 6937\n"
	"	* la majuscule est 02BC 004E\n"
	"	# 02BC 006E"},
/* 014A */ { "LETTRE MAJUSCULE LATINE ENG","	* le glyphe peut aussi avoir l'apparence d'une grande minuscule\n"
	"	x (lettre majuscule latine n à long fût à droite - 0220)\n"
	"	x (lettre majuscule latine n crampon - A790)"},
/* 014B */ { "LETTRE MINUSCULE LATINE ENG","	* same, mendé, API, etc.\n"
	"	* nasale vélaire, nasalisation\n"
	"	x (lettre minuscule latine n à long fût à droite - 019E)\n"
	"	x (lettre minuscule latine n hameçon palatal - 1D87)\n"
	"	x (lettre minuscule latine n crampon - A791)"},
/* 014C */ { "LETTRE MAJUSCULE LATINE O MACRON","	: 004F 0304"},
/* 014D */ { "LETTRE MINUSCULE LATINE O MACRON","	* letton, latin, etc.\n"
	"	: 006F 0304"},
/* 014E */ { "LETTRE MAJUSCULE LATINE O BRÈVE","	: 004F 0306"},
/* 014F */ { "LETTRE MINUSCULE LATINE O BRÈVE","	* latin\n"
	"	: 006F 0306"},
/* 0150 */ { "LETTRE MAJUSCULE LATINE O DOUBLE ACCENT AIGU","	: 004F 030B"},
/* 0151 */ { "LETTRE MINUSCULE LATINE O DOUBLE ACCENT AIGU","	* hongrois\n"
	"	: 006F 030B"},
/* 0152 */ { "DIGRAMME SOUDÉ MAJUSCULE LATIN OE",NULL},
/* 0153 */ { "DIGRAMME SOUDÉ MINUSCULE LATIN OE","	= ligature oe\n"
	"	= e dans l'o\n"
	"	= ethel (du vieil anglais « eðel »)\n"
	"	* français, API, vieil islandais, vieil anglais, etc.\n"
	"	x (lettre minuscule latine ae - 00E6)\n"
	"	x (lettre latine petite capitale oe - 0276)\n"
	"	x (lettre minuscule latine oe culbuté - 1D14)\n"
	"	x (lettre modificative minuscule ligature oe - A7F9)\n"
	"	x (lettre minuscule latine oe renversé - AB40)\n"
	"	x (lettre latine minuscule oe ouvert - AB62)"},
/* 0154 */ { "LETTRE MAJUSCULE LATINE R ACCENT AIGU","	: 0052 0301"},
/* 0155 */ { "LETTRE MINUSCULE LATINE R ACCENT AIGU","	* slovaque, etc.\n"
	"	: 0072 0301"},
/* 0156 */ { "LETTRE MAJUSCULE LATINE R CÉDILLE","	: 0052 0327"},
/* 0157 */ { "LETTRE MINUSCULE LATINE R CÉDILLE","	* live\n"
	"	* en dépit de leurs noms, ces deux caractères devraient normalement être affichés avec une virgule souscrite\n"
	"	: 0072 0327"},
/* 0158 */ { "LETTRE MAJUSCULE LATINE R CARON","	: 0052 030C"},
/* 0159 */ { "LETTRE MINUSCULE LATINE R CARON","	= r chevron, r accent hirondelle\n"
	"	* tchèque, sorabe, etc.\n"
	"	: 0072 030C"},
/* 015A */ { "LETTRE MAJUSCULE LATINE S ACCENT AIGU","	: 0053 0301"},
/* 015B */ { "LETTRE MINUSCULE LATINE S ACCENT AIGU","	* polonais, translittération des écritures indiennes, etc.\n"
	"	: 0073 0301"},
/* 015C */ { "LETTRE MAJUSCULE LATINE S ACCENT CIRCONFLEXE","	: 0053 0302"},
/* 015D */ { "LETTRE MINUSCULE LATINE S ACCENT CIRCONFLEXE","	* espéranto\n"
	"	: 0073 0302"},
/* 015E */ { "LETTRE MAJUSCULE LATINE S CÉDILLE","	: 0053 0327"},
/* 015F */ { "LETTRE MINUSCULE LATINE S CÉDILLE","	* turc, azéri, etc.\n"
	"	* le caractère 0219 doit être utilisé pour le roumain\n"
	"	x (lettre minuscule latine s virgule souscrite - 0219)\n"
	"	: 0073 0327"},
/* 0160 */ { "LETTRE MAJUSCULE LATINE S CARON","	: 0053 030C"},
/* 0161 */ { "LETTRE MINUSCULE LATINE S CARON","	= s chevron, s accent hirondelle\n"
	"	* tchèque, estonien, finnois, slovaque et de nombreuses autres langues\n"
	"	: 0073 030C"},
/* 0162 */ { "LETTRE MAJUSCULE LATINE T CÉDILLE","	: 0054 0327"},
/* 0163 */ { "LETTRE MINUSCULE LATINE T CÉDILLE","	* translittération des écritures sémitiques, etc.\n"
	"	* le caractère 021B doit être utilisé pour le roumain\n"
	"	x (lettre minuscule latine t virgule souscrite - 021B)\n"
	"	: 0074 0327"},
/* 0164 */ { "LETTRE MAJUSCULE LATINE T CARON","	* on préfère la forme avec un caron dans tous les contextes\n"
	"	: 0054 030C"},
/* 0165 */ { "LETTRE MINUSCULE LATINE T CARON","	= t chevron, t accent hirondelle\n"
	"	* tchèque, slovaque\n"
	"	* pour la composition, on recommande la forme avec l'apostrophe\n"
	"	: 0074 030C"},
/* 0166 */ { "LETTRE MAJUSCULE LATINE T BARRÉ",NULL},
/* 0167 */ { "LETTRE MINUSCULE LATINE T BARRÉ","	* same\n"
	"	x (lettre minuscule latine t tilde médian - 1D75)"},
/* 0168 */ { "LETTRE MAJUSCULE LATINE U TILDE","	: 0055 0303"},
/* 0169 */ { "LETTRE MINUSCULE LATINE U TILDE","	* groenlandais (ancienne orthographe), kikouyou\n"
	"	: 0075 0303"},
/* 016A */ { "LETTRE MAJUSCULE LATINE U MACRON","	: 0055 0304"},
/* 016B */ { "LETTRE MINUSCULE LATINE U MACRON","	* letton, lituanien, latin, etc.\n"
	"	: 0075 0304"},
/* 016C */ { "LETTRE MAJUSCULE LATINE U BRÈVE","	: 0055 0306"},
/* 016D */ { "LETTRE MINUSCULE LATINE U BRÈVE","	* latin, espéranto, etc.\n"
	"	: 0075 0306"},
/* 016E */ { "LETTRE MAJUSCULE LATINE U ROND EN CHEF","	: 0055 030A"},
/* 016F */ { "LETTRE MINUSCULE LATINE U ROND EN CHEF","	* tchèque, sorabe, etc.\n"
	"	: 0075 030A"},
/* 0170 */ { "LETTRE MAJUSCULE LATINE U DOUBLE ACCENT AIGU","	: 0055 030B"},
/* 0171 */ { "LETTRE MINUSCULE LATINE U DOUBLE ACCENT AIGU","	* hongrois\n"
	"	: 0075 030B"},
/* 0172 */ { "LETTRE MAJUSCULE LATINE U OGONEK","	: 0055 0328"},
/* 0173 */ { "LETTRE MINUSCULE LATINE U OGONEK","	* lituanien\n"
	"	: 0075 0328"},
/* 0174 */ { "LETTRE MAJUSCULE LATINE W ACCENT CIRCONFLEXE","	: 0057 0302"},
/* 0175 */ { "LETTRE MINUSCULE LATINE W ACCENT CIRCONFLEXE","	* gallois\n"
	"	: 0077 0302"},
/* 0176 */ { "LETTRE MAJUSCULE LATINE Y ACCENT CIRCONFLEXE","	: 0059 0302"},
/* 0177 */ { "LETTRE MINUSCULE LATINE Y ACCENT CIRCONFLEXE","	* gallois\n"
	"	: 0079 0302"},
/* 0178 */ { "LETTRE MAJUSCULE LATINE Y TRÉMA","	* français, igbo\n"
	"	* la minuscule est 00FF\n"
	"	: 0059 0308"},
/* 0179 */ { "LETTRE MAJUSCULE LATINE Z ACCENT AIGU","	: 005A 0301"},
/* 017A */ { "LETTRE MINUSCULE LATINE Z ACCENT AIGU","	* polonais, etc.\n"
	"	: 007A 0301"},
/* 017B */ { "LETTRE MAJUSCULE LATINE Z POINT EN CHEF","	: 005A 0307"},
/* 017C */ { "LETTRE MINUSCULE LATINE Z POINT EN CHEF","	* polonais, etc.\n"
	"	: 007A 0307"},
/* 017D */ { "LETTRE MAJUSCULE LATINE Z CARON","	: 005A 030C"},
/* 017E */ { "LETTRE MINUSCULE LATINE Z CARON","	= z chevron, z accent hirondelle\n"
	"	* tchèque, estonien, finnois, slovaque, slovène et de nombreuses autres langues\n"
	"	: 007A 030C"},
/* 017F */ { "LETTRE MINUSCULE LATINE S LONG","	* fréquemment utilisée avec les caractères romains et italiques jusqu'au XVIIIe siècle\n"
	"	* utilisée aujourd'hui avec les caractères gothiques et gaéliques\n"
	"	x (lettre minuscule latine s dur - 00DF)\n"
	"	x (ligature minuscule latine s long t - FB05)\n"
	"	# 0073 lettre minuscule latine s"},
/* 0180 */ { "LETTRE MINUSCULE LATINE B BARRÉ","	* forme américaniste et indo-européaniste pour le bêta phonétique\n"
	"	* les américanistes utilisent une variante de glyphe avec une barre traversant la panse\n"
	"	* également utilisée dans des manuscrits en vieux saxon\n"
	"	* sa majuscule est 0243\n"
	"	x (lettre minuscule grecque bêta - 03B2)\n"
	"	x (lettre minuscule latine b tilde médian - 1D6C)\n"
	"	x (symbole blanc - 2422)"},
/* 0181 */ { "LETTRE MAJUSCULE LATINE B CROSSE","	* langues africaines\n"
	"	* la minuscule est 0253"},
/* 0182 */ { "LETTRE MAJUSCULE LATINE B POTENCE","	x (lettre majuscule cyrillique bé - 0411)"},
/* 0183 */ { "LETTRE MINUSCULE LATINE B POTENCE","	* ancienne graphie du tchouang (zhuang)\n"
	"	* écritures de langues minoritaires dans l'ancienne Union soviétique\n"
	"	x (lettre minuscule latine b crosse - 0253)\n"
	"	x (lettre minuscule cyrillique bé - 0431)"},
/* 0184 */ { "LETTRE MAJUSCULE LATINE SIXIÈME TON",NULL},
/* 0185 */ { "LETTRE MINUSCULE LATINE SIXIÈME TON","	* ancienne graphie du tchouang (zhuang)\n"
	"	* le troisième ton tchouang correspond au cyrillique zé\n"
	"	* le quatrième ton tchouang correspond au cyrillique tché\n"
	"	x (lettre minuscule latine deuxième ton - 01A8)\n"
	"	x (lettre minuscule latine cinquième ton - 01BD)\n"
	"	x (lettre minuscule cyrillique zé - 0437)\n"
	"	x (lettre minuscule cyrillique tché - 0447)\n"
	"	x (lettre minuscule cyrillique signe mou - 044C)"},
/* 0186 */ { "LETTRE MAJUSCULE LATINE O OUVERT","	* typographiquement, un C réfléchi\n"
	"	* langues africaines\n"
	"	* la minuscule est 0254\n"
	"	x (lettre latine petite capitale o ouvert - 1D10)\n"
	"	x (chiffre romain cent réfléchi - 2183)"},
/* 0187 */ { "LETTRE MAJUSCULE LATINE C CROSSE",NULL},
/* 0188 */ { "LETTRE MINUSCULE LATINE C CROSSE","	* langues africaines"},
/* 0189 */ { "LETTRE MAJUSCULE LATINE D AFRICAIN","	* éwé\n"
	"	* la minuscule est 0256\n"
	"	x (lettre majuscule latine ed - 00D0)\n"
	"	x (lettre majuscule latine d barré - 0110)"},
/* 018A */ { "LETTRE MAJUSCULE LATINE D CROSSE","	* alphabet pan-nigérian\n"
	"	* la minuscule est 0257"},
/* 018B */ { "LETTRE MAJUSCULE LATINE D POTENCE",NULL},
/* 018C */ { "LETTRE MINUSCULE LATINE D POTENCE","	* écritures de langues minoritaires dans l'ancienne Union soviétique\n"
	"	* ancienne graphie du tchouang (zhuang)"},
/* 018D */ { "LETTRE MINUSCULE LATINE DELTA CULBUTÉ","	= o crochet polonais réfléchi, o hameçon réfléchi\n"
	"	* symbole phonétique désuet de la fricative alvéolaire labialisée\n"
	"	* orthographe recommandée : 007A 02B7 ou 007A 032B"},
/* 018E */ { "LETTRE MAJUSCULE LATINE E CULBUTÉ","	= e majuscule réfléchi\n"
	"	* alphabet pan-nigérian\n"
	"	* la minuscule est 01DD\n"
	"	x (il existe - 2203)\n"
	"	x (lettre latine petite capitale e culbuté - 2C7B)"},
/* 018F */ { "LETTRE MAJUSCULE LATINE SCHWA","	* azéri, etc.\n"
	"	* la minuscule est 0259\n"
	"	x (lettre majuscule cyrillique schwa - 04D8)"},
/* 0190 */ { "LETTRE MAJUSCULE LATINE E OUVERT","	= epsilon majuscule\n"
	"	* langues africaines\n"
	"	* la minuscule est 025B\n"
	"	* à ne pas confondre avec des variantes de glyphes de la majuscule E\n"
	"	x (constante d'euler - 2107)\n"
	"	x (chiffre trois culbuté - 218B)\n"
	"	x (lettre majuscule latine tresillo - A72A)"},
/* 0191 */ { "LETTRE MAJUSCULE LATINE F HAMEÇON","	* langues africaines\n"
	"	x (lettre majuscule latine f barré - A798)"},
/* 0192 */ { "LETTRE MINUSCULE LATINE F HAMEÇON","	= f cursif\n"
	"	= symbole monétaire du florin (Pays-Bas)\n"
	"	= symbole de fonction"},
/* 0193 */ { "LETTRE MAJUSCULE LATINE G CROSSE","	* langues africaines\n"
	"	* la minuscule est 0260"},
/* 0194 */ { "LETTRE MAJUSCULE LATINE GAMMA","	* langues africaines\n"
	"	* la minuscule est 0263"},
/* 0195 */ { "LETTRE MINUSCULE LATINE HV","	= hwair\n"
	"	* translittération du gotique\n"
	"	* la majuscule est 01F6\n"
	"	x (lettre gotique hw - 10348)"},
/* 0196 */ { "LETTRE MAJUSCULE LATINE IOTA","	* langues africaines\n"
	"	* la minuscule est 0269\n"
	"	x (lettre majuscule cyrillique iota - A646)"},
/* 0197 */ { "LETTRE MAJUSCULE LATINE I BARRÉ","	= i barre\n"
	"	* langues africaines\n"
	"	* la minuscule est 0268\n"
	"	* ISO 6438 indique comme minuscule 026A, non 0268\n"
	"	x (lettre latine petite capitale i - 026A)\n"
	"	x (lettre latine petite capitale i barré - 1D7B)"},
/* 0198 */ { "LETTRE MAJUSCULE LATINE K CROSSE",NULL},
/* 0199 */ { "LETTRE MINUSCULE LATINE K CROSSE","	* haoussa, alphabet pan-nigérian"},
/* 019A */ { "LETTRE MINUSCULE LATINE L RAYÉ","	= l barré, l barre, l barre horizontale\n"
	"	* usage phonétique américaniste pour le caractère API ɬ\n"
	"	* la majuscule est 023D\n"
	"	x (lettre minuscule latine l barré - 0142)\n"
	"	x (lettre minuscule latine l sanglé - 026C)\n"
	"	x (lettre minuscule latine l à double barre - 2C61)\n"
	"	x (lettre minuscule latine l à trait élevé - A749)"},
/* 019B */ { "LETTRE MINUSCULE LATINE LAMBDA BARRÉ","	= lambda barre\n"
	"	* usage phonétique américaniste pour le caractère API tɬ\n"
	"	* la majuscule est A7DC\n"
	"	x (lettre minuscule grecque lambda - 03BB)"},
/* 019C */ { "LETTRE MAJUSCULE LATINE M CULBUTÉ","	* ancienne graphie du tchouang (zhuang)\n"
	"	* la minuscule est 026F\n"
	"	x (lettre latine petite capitale m culbuté - A7FA)\n"
	"	x (lettre latine épigraphique m culbuté - A7FD)"},
/* 019D */ { "LETTRE MAJUSCULE LATINE N HAMEÇON À GAUCHE","	* langues africaines\n"
	"	* la minuscule est 0272"},
/* 019E */ { "LETTRE MINUSCULE LATINE N À LONG FÛT À DROITE","	* symbole désuet du signe japonais 3093\n"
	"	* orthographe recommandée du « n » syllabique : 006E 0329\n"
	"	* lakota (indique la nasalisation de la voyelle), supplantée par 014B\n"
	"	* la majuscule est 0220\n"
	"	x (lettre minuscule latine eng - 014B)\n"
	"	x (caractère hiragana n - 3093)"},
/* 019F */ { "LETTRE MAJUSCULE LATINE O TILDE MÉDIAN","	= o barré, o barre\n"
	"	* langues africaines\n"
	"	* le nom officiel ne décrit pas le glyphe\n"
	"	* la minuscule est 0275\n"
	"	x (lettre majuscule cyrillique o barré - 04E8)"},
/* 01A0 */ { "LETTRE MAJUSCULE LATINE O CORNU","	: 004F 031B"},
/* 01A1 */ { "LETTRE MINUSCULE LATINE O CORNU","	* vietnamien\n"
	"	: 006F 031B"},
/* 01A2 */ { "LETTRE MAJUSCULE LATINE GHA","	* le nom formel de ce caractère en anglais est erroné"},
/* 01A3 */ { "LETTRE MINUSCULE LATINE GHA","	* le nom formel de ce caractère en anglais est erroné\n"
	"	* alphabets latins panturcs, tadjik"},
/* 01A4 */ { "LETTRE MAJUSCULE LATINE P CROSSE",NULL},
/* 01A5 */ { "LETTRE MINUSCULE LATINE P CROSSE","	* langues africaines"},
/* 01A6 */ { "LETTRE LATINE YR","	* norrois\n"
	"	* tiré de la norme allemande DIN 31624 et de la norme ISO 5426-2\n"
	"	* la minuscule est 0280"},
/* 01A7 */ { "LETTRE MAJUSCULE LATINE DEUXIÈME TON","	x (lettre latine spirante laryngale sonore - 1D24)\n"
	"	x (lettre majuscule cyrillique dzé réfléchi - A644)\n"
	"	x (symbole romain sextule - 10193)"},
/* 01A8 */ { "LETTRE MINUSCULE LATINE DEUXIÈME TON","	* ancienne graphie du tchouang (zhuang)\n"
	"	* typographiquement, un S réfléchi\n"
	"	x (lettre minuscule latine sixième ton - 0185)\n"
	"	x (lettre minuscule cyrillique dzé réfléchi - A645)"},
/* 01A9 */ { "LETTRE MAJUSCULE LATINE ECH","	* langues africaines\n"
	"	* la minuscule est 0283\n"
	"	x (lettre majuscule grecque sigma - 03A3)\n"
	"	x (sommation de la famille - 2211)"},
/* 01AA */ { "LETTRE LATINE ECH RÉFLÉCHI BOUCLÉ","	* symbole phonétique désuet de la fricative palato-alvéolaire sourde labialisée\n"
	"	* twi\n"
	"	* orthographes recommandées : 0283 02B7, 00E7 02B7, 0068 0265, etc."},
/* 01AB */ { "LETTRE MINUSCULE LATINE T HAMEÇON PALATAL","	* symbole phonétique désuet de la dentale ou de l'alvéolaire palatalisée\n"
	"	* orthographe recommandée : 0074 02B2"},
/* 01AC */ { "LETTRE MAJUSCULE LATINE T CROSSE","	* il existe également une variante avec la crosse à droite"},
/* 01AD */ { "LETTRE MINUSCULE LATINE T CROSSE","	* langues africaines"},
/* 01AE */ { "LETTRE MAJUSCULE LATINE T HAMEÇON RÉTROFLEXE","	* langues africaines\n"
	"	* la minuscule est 0288"},
/* 01AF */ { "LETTRE MAJUSCULE LATINE U CORNU","	: 0055 031B"},
/* 01B0 */ { "LETTRE MINUSCULE LATINE U CORNU","	* vietnamien\n"
	"	: 0075 031B"},
/* 01B1 */ { "LETTRE MAJUSCULE LATINE UPSILON","	* langues africaines\n"
	"	* typographiquement, oméga grec majuscule 03A9 culbuté\n"
	"	* la minuscule est 028A\n"
	"	x (symbole ohm renversé - 2127)"},
/* 01B2 */ { "LETTRE MAJUSCULE LATINE V CROSSE","	= v cursif\n"
	"	* langues africaines\n"
	"	* la minuscule est 028B"},
/* 01B3 */ { "LETTRE MAJUSCULE LATINE Y CROSSE","	* il existe également une variante avec la crosse à gauche"},
/* 01B4 */ { "LETTRE MINUSCULE LATINE Y CROSSE","	* bini, ésoko et autres langues édo d'Afrique occidentale"},
/* 01B5 */ { "LETTRE MAJUSCULE LATINE Z BARRÉ",NULL},
/* 01B6 */ { "LETTRE MINUSCULE LATINE Z BARRÉ","	= z barre\n"
	"	* orthographe latine panturque\n"
	"	* aussi une variante manuscrite du « z » latin\n"
	"	x (lettre minuscule latine z - 007A)\n"
	"	x (lettre minuscule latine z tilde médian - 1D76)"},
/* 01B7 */ { "LETTRE MAJUSCULE LATINE EJ","	* langues africaines, same skolt\n"
	"	* la minuscule est 0292\n"
	"	x (lettre majuscule latine yogh - 021C)\n"
	"	x (lettre majuscule cyrillique dzé abkhaze - 04E0)\n"
	"	x (lettre latine petite capitale ej - 1D23)\n"
	"	x (lettre majuscule latine e ouvert réfléchi - A7AB)"},
/* 01B8 */ { "LETTRE MAJUSCULE LATINE EJ RÉFLÉCHI","	x (lettre majuscule latine e ouvert - 0190)"},
/* 01B9 */ { "LETTRE MINUSCULE LATINE EJ RÉFLÉCHI","	* symbole phonétique désuet de la fricative pharyngale sonore\n"
	"	* sur le plan typographique, parfois restitué comme un 3 culbuté\n"
	"	* orthographe recommandée : 0295\n"
	"	x (lettre latine fricative pharyngale sonore - 0295)\n"
	"	x (lettre arabe 'aïn - 0639)"},
/* 01BA */ { "LETTRE MINUSCULE LATINE EJ À JAMBAGE","	* symbole désuet de la fricative palato-alvéolaire sonore ou de la fricative palatale sonore\n"
	"	* twi\n"
	"	* orthographes recommandées : 0292 02B7 ou 006A 02B7"},
/* 01BB */ { "LETTRE LATINE DEUX BARRÉ","	* symbole désuet de l'affriquée [dz]\n"
	"	* orthographes recommandées : 0292 ou 0064 007A\n"
	"	x (lettre majuscule latine deuxième ton - 01A7)"},
/* 01BC */ { "LETTRE MAJUSCULE LATINE CINQUIÈME TON",NULL},
/* 01BD */ { "LETTRE MINUSCULE LATINE CINQUIÈME TON","	* ancienne graphie du tchouang (zhuang)\n"
	"	x (lettre minuscule latine sixième ton - 0185)"},
/* 01BE */ { "LETTRE LATINE COUP DE GLOTTE BARRÉ RÉFLÉCHI","	* symbole phonétique désuet de l'affriquée [ts]\n"
	"	* orthographe recommandée : 0074 0073\n"
	"	* la forme de la lettre dérive de la ligature du ts plutôt que du coup de glotte réfléchi\n"
	"	x (lettre latine coup de glotte réfléchi - 0296)\n"
	"	x (lettre minuscule latine digramme ts - 02A6)"},
/* 01BF */ { "LETTRE LATINE WYNN","	= wen\n"
	"	* lettre latine empruntée à l'alphabet runique\n"
	"	* remplacée par « w » dans les transcriptions modernes du vieil anglais\n"
	"	* la majuscule est 01F7\n"
	"	x (lettre runique wunjo wynn w - 16B9)"},
/* 01C0 */ { "LETTRE LATINE CLIC DENTAL","	= barre verticale\n"
	"	* « c » en zoulou\n"
	"	x (barre oblique - 002F)\n"
	"	x (barre verticale - 007C)\n"
	"	x (lettre minuscule latine t culbuté - 0287)\n"
	"	x (est un diviseur de - 2223)"},
/* 01C1 */ { "LETTRE LATINE CLIC LATÉRAL","	= double barre verticale\n"
	"	* « x » en zoulou\n"
	"	x (lettre latine coup de glotte réfléchi - 0296)\n"
	"	x (double ligne verticale - 2016)\n"
	"	x (parallèle à - 2225)"},
/* 01C2 */ { "LETTRE LATINE CLIC ALVÉOLAIRE","	= barre verticale doublement barrée\n"
	"	* clic palato-alvéolaire (API)\n"
	"	x (pas égal à - 2260)\n"
	"	x (thermodynamique - 29E7)"},
/* 01C3 */ { "LETTRE LATINE CLIC RÉTROFLEXE","	= lettre latine point d'exclamation (1.0)\n"
	"	* clic (post-)alvéolaire (API)\n"
	"	* « q » en zoulou\n"
	"	x (point d'exclamation - 0021)\n"
	"	x (lettre latine c étiré - 0297)\n"
	"	x (lettre modificative point d'exclamation haut - A71D)\n"
	"	x (lettre latine clic rétroflexe avec hameçon rétroflexe - 1DF0A)"},
/* 01C4 */ { "LETTRE MAJUSCULE LATINE DZ CARON","	# 0044 017D"},
/* 01C5 */ { "LETTRE MAJUSCULE LATINE D AVEC LETTRE MINUSCULE Z CARON","	# 0044 017E"},
/* 01C6 */ { "LETTRE MINUSCULE LATINE DZ CARON","	x (lettre minuscule cyrillique djé - 045F)\n"
	"	# 0064 017E"},
/* 01C7 */ { "LETTRE MAJUSCULE LATINE LJ","	# 004C 004A"},
/* 01C8 */ { "LETTRE MAJUSCULE LATINE L AVEC LETTRE MINUSCULE J","	# 004C 006A"},
/* 01C9 */ { "LETTRE MINUSCULE LATINE LJ","	= digramme soudé lj\n"
	"	x (lettre minuscule cyrillique lié - 0459)\n"
	"	# 006C 006A"},
/* 01CA */ { "LETTRE MAJUSCULE LATINE NJ","	# 004E 004A"},
/* 01CB */ { "LETTRE MAJUSCULE LATINE N AVEC LETTRE MINUSCULE J","	# 004E 006A"},
/* 01CC */ { "LETTRE MINUSCULE LATINE NJ","	= digramme soudé nj\n"
	"	x (lettre minuscule cyrillique nié - 045A)\n"
	"	# 006E 006A"},
/* 01CD */ { "LETTRE MAJUSCULE LATINE A CARON","	: 0041 030C"},
/* 01CE */ { "LETTRE MINUSCULE LATINE A CARON","	= a chevron, a accent hirondelle\n"
	"	* troisième ton pinyin\n"
	"	: 0061 030C"},
/* 01CF */ { "LETTRE MAJUSCULE LATINE I CARON","	: 0049 030C"},
/* 01D0 */ { "LETTRE MINUSCULE LATINE I CARON","	= i chevron, i accent hirondelle\n"
	"	* troisième ton pinyin\n"
	"	: 0069 030C"},
/* 01D1 */ { "LETTRE MAJUSCULE LATINE O CARON","	: 004F 030C"},
/* 01D2 */ { "LETTRE MINUSCULE LATINE O CARON","	= o chevron, o accent hirondelle\n"
	"	* troisième ton pinyin\n"
	"	: 006F 030C"},
/* 01D3 */ { "LETTRE MAJUSCULE LATINE U CARON","	: 0055 030C"},
/* 01D4 */ { "LETTRE MINUSCULE LATINE U CARON","	= u chevron, u accent hirondelle\n"
	"	* troisième ton pinyin\n"
	"	: 0075 030C"},
/* 01D5 */ { "LETTRE MAJUSCULE LATINE U TRÉMA ET MACRON","	: 00DC 0304"},
/* 01D6 */ { "LETTRE MINUSCULE LATINE U TRÉMA ET MACRON","	* premier ton pinyin\n"
	"	: 00FC 0304"},
/* 01D7 */ { "LETTRE MAJUSCULE LATINE U TRÉMA ET ACCENT AIGU","	: 00DC 0301"},
/* 01D8 */ { "LETTRE MINUSCULE LATINE U TRÉMA ET ACCENT AIGU","	* deuxième ton pinyin\n"
	"	: 00FC 0301"},
/* 01D9 */ { "LETTRE MAJUSCULE LATINE U TRÉMA ET CARON","	: 00DC 030C"},
/* 01DA */ { "LETTRE MINUSCULE LATINE U TRÉMA ET CARON","	* troisième ton pinyin\n"
	"	: 00FC 030C"},
/* 01DB */ { "LETTRE MAJUSCULE LATINE U TRÉMA ET ACCENT GRAVE","	: 00DC 0300"},
/* 01DC */ { "LETTRE MINUSCULE LATINE U TRÉMA ET ACCENT GRAVE","	* quatrième ton pinyin\n"
	"	: 00FC 0300"},
/* 01DD */ { "LETTRE MINUSCULE LATINE E CULBUTÉ","	* alphabet pan-nigérian\n"
	"	* il faut utiliser 0259 pour tous les autres emplois du schwa\n"
	"	* la majuscule est 018E\n"
	"	x (lettre minuscule latine schwa - 0259)"},
/* 01DE */ { "LETTRE MAJUSCULE LATINE A TRÉMA ET MACRON","	: 00C4 0304"},
/* 01DF */ { "LETTRE MINUSCULE LATINE A TRÉMA ET MACRON","	* live, tradition ouraliciste\n"
	"	: 00E4 0304"},
/* 01E0 */ { "LETTRE MAJUSCULE LATINE A POINT EN CHEF ET MACRON","	: 0226 0304"},
/* 01E1 */ { "LETTRE MINUSCULE LATINE A POINT EN CHEF ET MACRON","	* tradition ouraliciste\n"
	"	: 0227 0304"},
/* 01E2 */ { "LETTRE MAJUSCULE LATINE AE MACRON","	: 00C6 0304"},
/* 01E3 */ { "LETTRE MINUSCULE LATINE AE MACRON","	= digramme soudé ae macron, ash macron\n"
	"	* norrois, vieil anglais\n"
	"	: 00E6 0304"},
/* 01E4 */ { "LETTRE MAJUSCULE LATINE G BARRÉ",NULL},
/* 01E5 */ { "LETTRE MINUSCULE LATINE G BARRÉ","	* same skolt"},
/* 01E6 */ { "LETTRE MAJUSCULE LATINE G CARON","	: 0047 030C"},
/* 01E7 */ { "LETTRE MINUSCULE LATINE G CARON","	= g chevron, g accent hirondelle\n"
	"	* same skolt\n"
	"	x (lettre minuscule latine g brève - 011F)\n"
	"	: 0067 030C"},
/* 01E8 */ { "LETTRE MAJUSCULE LATINE K CARON","	: 004B 030C"},
/* 01E9 */ { "LETTRE MINUSCULE LATINE K CARON","	= k chevron, k accent hirondelle\n"
	"	* same skolt\n"
	"	: 006B 030C"},
/* 01EA */ { "LETTRE MAJUSCULE LATINE O OGONEK","	: 004F 0328"},
/* 01EB */ { "LETTRE MINUSCULE LATINE O OGONEK","	* same, iroquoien, vieil islandais\n"
	"	: 006F 0328"},
/* 01EC */ { "LETTRE MAJUSCULE LATINE O OGONEK ET MACRON","	: 01EA 0304"},
/* 01ED */ { "LETTRE MINUSCULE LATINE O OGONEK ET MACRON","	* vieil islandais, live (dans des travaux linguistiques récents)\n"
	"	: 01EB 0304"},
/* 01EE */ { "LETTRE MAJUSCULE LATINE EJ CARON","	: 01B7 030C"},
/* 01EF */ { "LETTRE MINUSCULE LATINE EJ CARON","	= ej chevron, ej accent hirondelle\n"
	"	* same skolt\n"
	"	: 0292 030C"},
/* 01F0 */ { "LETTRE MINUSCULE LATINE J CARON","	= j chevron, j accent hirondelle\n"
	"	* API et de nombreuses langues\n"
	"	: 006A 030C"},
/* 01F1 */ { "LETTRE MAJUSCULE LATINE DZ","	# 0044 005A"},
/* 01F2 */ { "LETTRE MAJUSCULE LATINE D AVEC LETTRE MINUSCULE Z","	# 0044 007A"},
/* 01F3 */ { "LETTRE MINUSCULE LATINE DZ","	= digramme soudé dz\n"
	"	# 0064 007A"},
/* 01F4 */ { "LETTRE MAJUSCULE LATINE G ACCENT AIGU","	: 0047 0301"},
/* 01F5 */ { "LETTRE MINUSCULE LATINE G ACCENT AIGU","	* translittération du macédonien et du serbe\n"
	"	: 0067 0301"},
/* 01F6 */ { "LETTRE MAJUSCULE LATINE HWAIR","	* la minuscule est 0195\n"
	"	x (lettre majuscule cyrillique nié komi - 050A)\n"
	"	x (lettre gotique hw - 10348)"},
/* 01F7 */ { "LETTRE MAJUSCULE LATINE WYNN","	= wen\n"
	"	* la minuscule est 01BF"},
/* 01F8 */ { "LETTRE MAJUSCULE LATINE N ACCENT GRAVE","	: 004E 0300"},
/* 01F9 */ { "LETTRE MINUSCULE LATINE N ACCENT GRAVE","	* pinyin\n"
	"	: 006E 0300"},
/* 01FA */ { "LETTRE MAJUSCULE LATINE A ROND EN CHEF ET ACCENT AIGU","	: 00C5 0301"},
/* 01FB */ { "LETTRE MINUSCULE LATINE A ROND EN CHEF ET ACCENT AIGU","	: 00E5 0301"},
/* 01FC */ { "LETTRE MAJUSCULE LATINE AE ACCENT AIGU","	: 00C6 0301"},
/* 01FD */ { "LETTRE MINUSCULE LATINE AE ACCENT AIGU","	= digramme soudé ae accent aigu, ash accent aigu\n"
	"	: 00E6 0301"},
/* 01FE */ { "LETTRE MAJUSCULE LATINE O BARRÉ ACCENT AIGU","	: 00D8 0301"},
/* 01FF */ { "LETTRE MINUSCULE LATINE O BARRÉ ACCENT AIGU","	: 00F8 0301"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_02[] = {
/* 0200 */ { "LETTRE MAJUSCULE LATINE A DOUBLE ACCENT GRAVE","	: 0041 030F"},
/* 0201 */ { "LETTRE MINUSCULE LATINE A DOUBLE ACCENT GRAVE","	: 0061 030F"},
/* 0202 */ { "LETTRE MAJUSCULE LATINE A BRÈVE RENVERSÉE","	: 0041 0311"},
/* 0203 */ { "LETTRE MINUSCULE LATINE A BRÈVE RENVERSÉE","	: 0061 0311"},
/* 0204 */ { "LETTRE MAJUSCULE LATINE E DOUBLE ACCENT GRAVE","	: 0045 030F"},
/* 0205 */ { "LETTRE MINUSCULE LATINE E DOUBLE ACCENT GRAVE","	: 0065 030F"},
/* 0206 */ { "LETTRE MAJUSCULE LATINE E BRÈVE RENVERSÉE","	: 0045 0311"},
/* 0207 */ { "LETTRE MINUSCULE LATINE E BRÈVE RENVERSÉE","	: 0065 0311"},
/* 0208 */ { "LETTRE MAJUSCULE LATINE I DOUBLE ACCENT GRAVE","	: 0049 030F"},
/* 0209 */ { "LETTRE MINUSCULE LATINE I DOUBLE ACCENT GRAVE","	: 0069 030F"},
/* 020A */ { "LETTRE MAJUSCULE LATINE I BRÈVE RENVERSÉE","	: 0049 0311"},
/* 020B */ { "LETTRE MINUSCULE LATINE I BRÈVE RENVERSÉE","	: 0069 0311"},
/* 020C */ { "LETTRE MAJUSCULE LATINE O DOUBLE ACCENT GRAVE","	: 004F 030F"},
/* 020D */ { "LETTRE MINUSCULE LATINE O DOUBLE ACCENT GRAVE","	: 006F 030F"},
/* 020E */ { "LETTRE MAJUSCULE LATINE O BRÈVE RENVERSÉE","	: 004F 0311"},
/* 020F */ { "LETTRE MINUSCULE LATINE O BRÈVE RENVERSÉE","	: 006F 0311"},
/* 0210 */ { "LETTRE MAJUSCULE LATINE R DOUBLE ACCENT GRAVE","	: 0052 030F"},
/* 0211 */ { "LETTRE MINUSCULE LATINE R DOUBLE ACCENT GRAVE","	: 0072 030F"},
/* 0212 */ { "LETTRE MAJUSCULE LATINE R BRÈVE RENVERSÉE","	: 0052 0311"},
/* 0213 */ { "LETTRE MINUSCULE LATINE R BRÈVE RENVERSÉE","	: 0072 0311"},
/* 0214 */ { "LETTRE MAJUSCULE LATINE U DOUBLE ACCENT GRAVE","	: 0055 030F"},
/* 0215 */ { "LETTRE MINUSCULE LATINE U DOUBLE ACCENT GRAVE","	: 0075 030F"},
/* 0216 */ { "LETTRE MAJUSCULE LATINE U BRÈVE RENVERSÉE","	: 0055 0311"},
/* 0217 */ { "LETTRE MINUSCULE LATINE U BRÈVE RENVERSÉE","	: 0075 0311"},
/* 0218 */ { "LETTRE MAJUSCULE LATINE S VIRGULE SOUSCRITE","	: 0053 0326"},
/* 0219 */ { "LETTRE MINUSCULE LATINE S VIRGULE SOUSCRITE","	x (lettre minuscule latine s cédille - 015F)\n"
	"	: 0073 0326"},
/* 021A */ { "LETTRE MAJUSCULE LATINE T VIRGULE SOUSCRITE","	: 0054 0326"},
/* 021B */ { "LETTRE MINUSCULE LATINE T VIRGULE SOUSCRITE","	x (lettre minuscule latine t cédille - 0163)\n"
	"	: 0074 0326"},
/* 021C */ { "LETTRE MAJUSCULE LATINE YOGH","	x (lettre majuscule latine ej - 01B7)\n"
	"	x (lettre majuscule cyrillique zé - 0417)\n"
	"	x (lettre majuscule latine e ouvert réfléchi - A7AB)"},
/* 021D */ { "LETTRE MINUSCULE LATINE YOGH","	* moyen anglais, scots\n"
	"	x (lettre minuscule latine ej - 0292)\n"
	"	x (lettre minuscule latine g insulaire - 1D79)\n"
	"	x (lettre minuscule latine et - A76B)"},
/* 021E */ { "LETTRE MAJUSCULE LATINE H CARON","	: 0048 030C"},
/* 021F */ { "LETTRE MINUSCULE LATINE H CARON","	= h chevron, h accent hirondelle\n"
	"	* romani finlandais\n"
	"	: 0068 030C"},
/* 0220 */ { "LETTRE MAJUSCULE LATINE N À LONG FÛT À DROITE","	* lakota (nasalisation), supplantée par 014A\n"
	"	* la minuscule est 019E\n"
	"	x (lettre majuscule latine eng - 014A)"},
/* 0221 */ { "LETTRE MINUSCULE LATINE D BOUCLÉ","	* emploi phonétique en sinologie"},
/* 0222 */ { "LETTRE MAJUSCULE LATINE OU","	x (lettre latine petite capitale ou - 1D15)"},
/* 0223 */ { "LETTRE MINUSCULE LATINE OU","	* algonquien, huron\n"
	"	x (chiffre huit - 0038)"},
/* 0224 */ { "LETTRE MAJUSCULE LATINE Z HAMEÇON","	x (lettre majuscule latine z crampon - 2C6B)"},
/* 0225 */ { "LETTRE MINUSCULE LATINE Z HAMEÇON","	* moyen haut-allemand"},
/* 0226 */ { "LETTRE MAJUSCULE LATINE A POINT EN CHEF","	: 0041 0307"},
/* 0227 */ { "LETTRE MINUSCULE LATINE A POINT EN CHEF","	* tradition ouraliciste\n"
	"	: 0061 0307"},
/* 0228 */ { "LETTRE MAJUSCULE LATINE E CÉDILLE","	: 0045 0327"},
/* 0229 */ { "LETTRE MINUSCULE LATINE E CÉDILLE","	: 0065 0327"},
/* 022A */ { "LETTRE MAJUSCULE LATINE O TRÉMA ET MACRON","	: 00D6 0304"},
/* 022B */ { "LETTRE MINUSCULE LATINE O TRÉMA ET MACRON","	: 00F6 0304"},
/* 022C */ { "LETTRE MAJUSCULE LATINE O TILDE ET MACRON","	: 00D5 0304"},
/* 022D */ { "LETTRE MINUSCULE LATINE O TILDE ET MACRON","	: 00F5 0304"},
/* 022E */ { "LETTRE MAJUSCULE LATINE O POINT EN CHEF","	: 004F 0307"},
/* 022F */ { "LETTRE MINUSCULE LATINE O POINT EN CHEF","	: 006F 0307"},
/* 0230 */ { "LETTRE MAJUSCULE LATINE O POINT EN CHEF ET MACRON","	: 022E 0304"},
/* 0231 */ { "LETTRE MINUSCULE LATINE O POINT EN CHEF ET MACRON","	: 022F 0304"},
/* 0232 */ { "LETTRE MAJUSCULE LATINE Y MACRON","	: 0059 0304"},
/* 0233 */ { "LETTRE MINUSCULE LATINE Y MACRON","	* également en cornique\n"
	"	: 0079 0304"},
/* 0234 */ { "LETTRE MINUSCULE LATINE L BOUCLÉ",NULL},
/* 0235 */ { "LETTRE MINUSCULE LATINE N BOUCLÉ",NULL},
/* 0236 */ { "LETTRE MINUSCULE LATINE T BOUCLÉ",NULL},
/* 0237 */ { "LETTRE MINUSCULE LATINE J SANS POINT","	* lettre à casse unique\n"
	"	x (lettre grecque yot - 03F3)\n"
	"	x (lettre minuscule cyrillique yé - 0458)\n"
	"	x (minuscule mathématique italique j sans point - 1D6A5)"},
/* 0238 */ { "LIGATURE MINUSCULE LATINE DB",NULL},
/* 0239 */ { "LIGATURE MINUSCULE LATINE QP",NULL},
/* 023A */ { "LETTRE MAJUSCULE LATINE A BARRÉ","	* la minuscule est 2C65"},
/* 023B */ { "LETTRE MAJUSCULE LATINE C BARRÉ","	x (symbole cedi - 20B5)"},
/* 023C */ { "LETTRE MINUSCULE LATINE C BARRÉ","	* utilisée en linguistique américaniste\n"
	"	x (symbole centime - 00A2)"},
/* 023D */ { "LETTRE MAJUSCULE LATINE L RAYÉ","	* la minuscule est 019A\n"
	"	x (lettre majuscule latine l barré - 0141)\n"
	"	x (lettre majuscule latine l à double barre - 2C60)\n"
	"	x (lettre majuscule latine l tilde médian - 2C62)\n"
	"	x (lettre majuscule latine l à trait élevé - A748)"},
/* 023E */ { "LETTRE MAJUSCULE LATINE T BARRÉ DIAGONALEMENT","	* la minuscule est 2C66"},
/* 023F */ { "LETTRE MINUSCULE LATINE S À PARAPHE","	* fricative labio-alvéolaire sourde\n"
	"	* la majuscule est 2C7E\n"
	"	x (lettre minuscule latine s hameçon rétroflexe - 0282)"},
/* 0240 */ { "LETTRE MINUSCULE LATINE Z À PARAPHE","	* fricative labio-alvéolaire sonore\n"
	"	* la majuscule est 2C7F\n"
	"	x (lettre minuscule latine z hameçon rétroflexe - 0290)"},
/* 0241 */ { "LETTRE MAJUSCULE LATINE COUP DE GLOTTE",NULL},
/* 0242 */ { "LETTRE MINUSCULE LATINE COUP DE GLOTTE","	* lettre bicamérale utilisée en tchipéwayan, flanc-de-chien, esclave (systèmes d'écriture autochtones canadiens)\n"
	"	x (lettre latine coup de glotte - 0294)\n"
	"	x (lettre modificative coup de glotte - 02C0)"},
/* 0243 */ { "LETTRE MAJUSCULE LATINE B BARRÉ","	* la minuscule est 0180\n"
	"	x (lettre latine petite capitale b barré - 1D03)"},
/* 0244 */ { "LETTRE MAJUSCULE LATINE U BARRÉ","	* la minuscule est 0289"},
/* 0245 */ { "LETTRE MAJUSCULE LATINE V CULBUTÉ","	* la minuscule est 028C\n"
	"	x (lettre majuscule grecque lambda - 039B)"},
/* 0246 */ { "LETTRE MAJUSCULE LATINE E BARRÉ",NULL},
/* 0247 */ { "LETTRE MINUSCULE LATINE E BARRÉ",NULL},
/* 0248 */ { "LETTRE MAJUSCULE LATINE J BARRÉ",NULL},
/* 0249 */ { "LETTRE MINUSCULE LATINE J BARRÉ",NULL},
/* 024A */ { "LETTRE MAJUSCULE LATINE PETIT Q HAMEÇON RÉTROFLEXE",NULL},
/* 024B */ { "LETTRE MINUSCULE LATINE Q HAMEÇON RÉTROFLEXE",NULL},
/* 024C */ { "LETTRE MAJUSCULE LATINE R BARRÉ",NULL},
/* 024D */ { "LETTRE MINUSCULE LATINE R BARRÉ","	x (lettre minuscule latine r tilde médian - 1D72)"},
/* 024E */ { "LETTRE MAJUSCULE LATINE Y BARRÉ",NULL},
/* 024F */ { "LETTRE MINUSCULE LATINE Y BARRÉ",NULL},
/* 0250 */ { "LETTRE MINUSCULE LATINE A CULBUTÉ","	* voyelle pré-ouverte centrale\n"
	"	* la majuscule est 2C6F"},
/* 0251 */ { "LETTRE MINUSCULE LATINE ALPHA","	= lettre minuscule latine a cursif (1.0)\n"
	"	* voyelle ouverte postérieure non arrondie\n"
	"	* le glyphe représentatif apparaît comme un allographe du « a » latin, mais parfois le caractère est rendu plutôt comme un « α » grec\n"
	"	* la majuscule est 2C6D\n"
	"	x (lettre minuscule grecque alpha - 03B1)"},
/* 0252 */ { "LETTRE MINUSCULE LATINE ALPHA CULBUTÉ","	* voyelle ouverte postérieure arrondie\n"
	"	* la majuscule est 2C70\n"
	"	x (lettre minuscule latine alpha renversé - AB64)"},
/* 0253 */ { "LETTRE MINUSCULE LATINE B CROSSE","	* occlusive injective bilabiale sonore\n"
	"	* la majuscule est 0181\n"
	"	x (lettre minuscule cyrillique bé - 0431)"},
/* 0254 */ { "LETTRE MINUSCULE LATINE O OUVERT","	* typographiquement, un c réfléchi\n"
	"	* voyelle mi-ouverte postérieure arrondie\n"
	"	* dans un usage danois ancien, « ɔ: » correspond à « c'est-à-dire »\n"
	"	* la majuscule est 0186\n"
	"	x (lettre latine petite capitale o ouvert - 1D10)\n"
	"	x (lettre minuscule latine c réfléchi - 2184)"},
/* 0255 */ { "LETTRE MINUSCULE LATINE C BOUCLÉ","	* fricative alvéolo-palatale sourde\n"
	"	* utilisée dans les transcriptions du mandarin\n"
	"	* ce son est écrit à l'aide de 015B en polonais"},
/* 0256 */ { "LETTRE MINUSCULE LATINE D HAMEÇON RÉTROFLEXE","	* occlusive rétroflexe sonore\n"
	"	* la majuscule est 0189"},
/* 0257 */ { "LETTRE MINUSCULE LATINE D CROSSE","	* occlusive injective alvéolaire\n"
	"	* éwé, alphabet pan-nigérian\n"
	"	* la majuscule est 018A"},
/* 0258 */ { "LETTRE MINUSCULE LATINE E RÉFLÉCHI","	* voyelle mi-fermée centrale non arrondie"},
/* 0259 */ { "LETTRE MINUSCULE LATINE SCHWA","	* voyelle moyenne centrale\n"
	"	* la majuscule est 018F\n"
	"	* la variante majuscule 018E est associée avec 01DD\n"
	"	x (lettre minuscule latine e culbuté - 01DD)\n"
	"	x (lettre minuscule cyrillique schwa - 04D9)"},
/* 025A */ { "LETTRE MINUSCULE LATINE SCHWA CROCHET","	* schwa rhotacisé"},
/* 025B */ { "LETTRE MINUSCULE LATINE E OUVERT","	= epsilon\n"
	"	* voyelle mi-ouverte antérieure non arrondie\n"
	"	* la majuscule est 0190\n"
	"	x (lettre minuscule grecque epsilon - 03B5)\n"
	"	x (lettre minuscule cyrillique zé réfléchi - 0511)"},
/* 025C */ { "LETTRE MINUSCULE LATINE E OUVERT RÉFLÉCHI","	= epsilon réfléchi\n"
	"	* voyelle mi-ouverte centrale non arrondie\n"
	"	* la majuscule est A7AB\n"
	"	x (lettre minuscule cyrillique zé - 0437)\n"
	"	x (lettre minuscule latine e ouvert culbuté - 1D08)"},
/* 025D */ { "LETTRE MINUSCULE LATINE E OUVERT RÉFLÉCHI CROCHET","	* voyelle mi-ouverte centrale non arrondie rhotacisée"},
/* 025E */ { "LETTRE MINUSCULE LATINE E OUVERT RÉFLÉCHI FERMÉ","	= epsilon réfléchi fermé\n"
	"	* voyelle mi-ouverte centrale arrondie\n"
	"	x (lettre minuscule latine e ouvert fermé - 029A)"},
/* 025F */ { "LETTRE MINUSCULE LATINE J SANS POINT BARRÉ","	* occlusive palatale sonore\n"
	"	* typographiquement un f culbuté, mais mieux perçue comme une forme de j\n"
	"	* transcrite par « gy » en hongrois\n"
	"	* également le symbole désuet de l'affriquée palato-alvéolaire 02A4"},
/* 0260 */ { "LETTRE MINUSCULE LATINE G CROSSE","	* occlusive injective vélaire\n"
	"	* la majuscule est 0193"},
/* 0261 */ { "LETTRE MINUSCULE LATINE G CURSIF","	* occlusive vélaire sonore\n"
	"	* la majuscule est A7AC\n"
	"	x (lettre minuscule latine g - 0067)\n"
	"	x (minuscule g de ronde - 210A)"},
/* 0262 */ { "LETTRE LATINE PETITE CAPITALE G","	* occlusive uvulaire sonore"},
/* 0263 */ { "LETTRE MINUSCULE LATINE GAMMA","	* fricative vélaire sonore\n"
	"	* la majuscule est 0194\n"
	"	x (lettre minuscule grecque gamma - 03B3)"},
/* 0264 */ { "LETTRE MINUSCULE LATINE CORNES DE BÉLIER","	= lettre minuscule latine petit gamma (1.0)\n"
	"	* voyelle mi-fermée postérieure non arrondie\n"
	"	* la majuscule est A7CB"},
/* 0265 */ { "LETTRE MINUSCULE LATINE H CULBUTÉ","	* spirante labio-palatale sonore\n"
	"	* la majuscule est A78D"},
/* 0266 */ { "LETTRE MINUSCULE LATINE H CROSSE","	* fricative glottale sonore\n"
	"	* la majuscule est A7AA\n"
	"	* la majuscule en nawdm est 0124\n"
	"	x (lettre modificative minuscule h crosse - 02B1)"},
/* 0267 */ { "LETTRE MINUSCULE LATINE HENG CROSSE","	* fricative post-alvéolo-vélaire sourde\n"
	"	* la plupart des dialectes du suédois possèdent cette consonne, connue comme le « son sj » (« sj-ljudet », en suédois)\n"
	"	x (lettre minuscule latine heng - A727)"},
/* 0268 */ { "LETTRE MINUSCULE LATINE I BARRÉ","	= i barre\n"
	"	* voyelle fermée centrale non arrondie\n"
	"	* la majuscule est 0197\n"
	"	* ISO 6438 indique que la minuscule de 0197 est 026A, et non 0268\n"
	"	x (lettre latine petite capitale i barré - 1D7B)"},
/* 0269 */ { "LETTRE MINUSCULE LATINE IOTA","	* voyelle pré-fermée antérieure non arrondie\n"
	"	* rendue obsolète par l'API en 1989\n"
	"	* l'API recommande l'emploi de 026A (lettre latine petite capitale i)\n"
	"	* la majuscule est 0196\n"
	"	x (lettre minuscule latine i sans point - 0131)\n"
	"	x (lettre minuscule grecque iota - 03B9)\n"
	"	x (lettre minuscule cyrillique iota - A647)\n"
	"	x (minuscule mathématique italique i sans point - 1D6A4)"},
/* 026A */ { "LETTRE LATINE PETITE CAPITALE I","	* voyelle pré-fermée antérieure non arrondie\n"
	"	* forme recommandée par l'API en lieu et place de 0269\n"
	"	* la majuscule est A7AE\n"
	"	* ISO 6438 donne comme minuscule 0197 au lieu de 0268\n"
	"	* le glyphe devrait présenter des empattements y compris dans des polices API sans empattements, pour éviter la confusion avec la minuscule « l »\n"
	"	x (lettre minuscule latine i sans point - 0131)"},
/* 026B */ { "LETTRE MINUSCULE LATINE L TILDE MÉDIAN","	* spirante latérale alvéolaire vélarisée sonore\n"
	"	* « l » anglais dans « table », une variété du 0142 polonais\n"
	"	* la majuscule est 2C62\n"
	"	x (lettre minuscule latine l barré - 0142)\n"
	"	x (lettre minuscule latine l traversé d'un s renversé couché - AB37)\n"
	"	x (lettre minuscule latine l double tilde médian - AB38)"},
/* 026C */ { "LETTRE MINUSCULE LATINE L SANGLÉ","	* fricative latérale alvéolaire sourde\n"
	"	* la majuscule est A7AD\n"
	"	x (lettre minuscule latine l rayé - 019A)"},
/* 026D */ { "LETTRE MINUSCULE LATINE L HAMEÇON RÉTROFLEXE","	* spirante latérale rétroflexe sonore\n"
	"	x (lettre minuscule latine l sanglé hameçon rétroflexe - A78E)"},
/* 026E */ { "LETTRE MINUSCULE LATINE LEJ","	* fricative latérale alvéolaire sonore\n"
	"	* « dl » dans l'écriture du zoulou (« dhl » avant une réforme de l'orthographe)"},
/* 026F */ { "LETTRE MINUSCULE LATINE M CULBUTÉ","	* voyelle fermée postérieure non arrondie\n"
	"	* la majuscule est 019C\n"
	"	x (lettre latine petite capitale m culbuté - A7FA)"},
/* 0270 */ { "LETTRE MINUSCULE LATINE M CULBUTÉ À LONG FÛT","	* spirante vélaire sonore"},
/* 0271 */ { "LETTRE MINUSCULE LATINE M HAMEÇON","	* nasale labio-dentale sonore\n"
	"	* la majuscule est 2C6E\n"
	"	x (lettre minuscule latine m hameçon palatal - 1D86)"},
/* 0272 */ { "LETTRE MINUSCULE LATINE N HAMEÇON À GAUCHE","	* nasale palatale sonore\n"
	"	* « gn » en français et en italien, « ñ » en castillan\n"
	"	* la majuscule est 019D"},
/* 0273 */ { "LETTRE MINUSCULE LATINE N HAMEÇON RÉTROFLEXE","	* nasale rétroflexe sonore"},
/* 0274 */ { "LETTRE LATINE PETITE CAPITALE N","	* nasale uvulaire sonore"},
/* 0275 */ { "LETTRE MINUSCULE LATINE O BARRÉ","	= o barre\n"
	"	* voyelle mi-fermée centrale arrondie, c'est-à-dire un schwa arrondi\n"
	"	* la majuscule est 019F\n"
	"	x (lettre minuscule grecque thêta - 03B8)\n"
	"	x (lettre minuscule cyrillique fita - 0473)\n"
	"	x (lettre minuscule cyrillique o barré - 04E9)"},
/* 0276 */ { "LETTRE LATINE PETITE CAPITALE OE","	* voyelle ouverte antérieure arrondie\n"
	"	x (digramme soudé minuscule latin oe - 0153)"},
/* 0277 */ { "LETTRE MINUSCULE LATINE OMÉGA FERMÉ","	* voyelle pré-fermée postérieure arrondie\n"
	"	* rendue obsolète par l'API en 1989\n"
	"	* l'API recommande l'emploi de 028A (lettre minuscule latine upsilon)\n"
	"	x (lettre minuscule latine oméga - A7B7)\n"
	"	x (lettre grecque petite capitale oméga - AB65)"},
/* 0278 */ { "LETTRE MINUSCULE LATINE PHI","	* fricative bilabiale sourde\n"
	"	* lettre à casse unique\n"
	"	x (lettre minuscule grecque phi - 03C6)\n"
	"	x (symbole grec phi - 03D5)\n"
	"	x (lettre minuscule latine phi sans queue - 2C77)"},
/* 0279 */ { "LETTRE MINUSCULE LATINE R CULBUTÉ","	* spirante alvéolaire sonore\n"
	"	x (lettre modificative minuscule r culbuté - 02B4)"},
/* 027A */ { "LETTRE MINUSCULE LATINE R CULBUTÉ À LONG FÛT","	* battue latérale alvéolaire sonore"},
/* 027B */ { "LETTRE MINUSCULE LATINE R CROSSE CULBUTÉ","	* spirante rétroflexe sonore\n"
	"	x (lettre modificative minuscule r crosse culbuté - 02B5)"},
/* 027C */ { "LETTRE MINUSCULE LATINE R À LONG FÛT","	* vibrante alvéolaire sonore rehaussée\n"
	"	* rendue obsolète par l'API en 1989\n"
	"	* en tchèque, ce son est orthographié avec 0159\n"
	"	* la représentation phonétique privilégiée pour le son tchèque est 0072 031D\n"
	"	* en usage dans les polices d'écriture gaélique, ou écriture irlandaise insulaire, comme variante de glyphe de 0072\n"
	"	x (lettre minuscule latine r insulaire - A783)\n"
	"	x (lettre minuscule latine s insulaire - A785)"},
/* 027D */ { "LETTRE MINUSCULE LATINE R HAMEÇON RÉTROFLEXE","	* battue rétroflexe sonore\n"
	"	* la majuscule est 2C64\n"
	"	x (lettre minuscule latine r hameçon culbuté - 2C79)"},
/* 027E */ { "LETTRE MINUSCULE LATINE R SANS OBIT","	* battue alvéolaire sonore\n"
	"	x (lettre minuscule latine s long - 017F)"},
/* 027F */ { "LETTRE MINUSCULE LATINE R SANS OBIT RÉFLÉCHI","	= i long à crochet gauche\n"
	"	= iota culbuté à long fût (appellation trompeuse)\n"
	"	* voyelle apico-dentale\n"
	"	* l'API recommande 007A 0329\n"
	"	* ce caractère n'est en réalité pas un 027E réfléchi\n"
	"	* la représentation recommandée préconise une hampe descendante"},
/* 0280 */ { "LETTRE LATINE PETITE CAPITALE R","	* vibrante uvulaire sonore\n"
	"	* R « grasseyé » (langues germaniques, norrois)\n"
	"	* la majuscule est 01A6"},
/* 0281 */ { "LETTRE LATINE PETITE CAPITALE R RENVERSÉ","	* fricative uvulaire sonore\n"
	"	x (lettre modificative petite capitale r renversé - 02B6)"},
/* 0282 */ { "LETTRE MINUSCULE LATINE S HAMEÇON RÉTROFLEXE","	* fricative rétroflexe sourde\n"
	"	* la majuscule est A7C5"},
/* 0283 */ { "LETTRE MINUSCULE LATINE ECH","	* fricative palato-alvéolaire sourde\n"
	"	* la majuscule est 01A9\n"
	"	x (intégrale - 222B)\n"
	"	x (lettre minuscule latine ech sur la ligne - AB4D)"},
/* 0284 */ { "LETTRE MINUSCULE LATINE J SANS POINT BARRÉ CROSSE","	* occlusive injective palatale\n"
	"	* sur le plan typographique, repose sur 025F, non sur 0283"},
/* 0285 */ { "LETTRE MINUSCULE LATINE R SANS OBIT RÉFLÉCHI HAMEÇON RÉTROFLEXE","	= i long à crochet gauche et queue\n"
	"	* voyelle rétroflexe apicale\n"
	"	* l'API recommande 0290 0329\n"
	"	* ce caractère ne correspond pas à un ech réfléchi\n"
	"	* la représentation recommandée préconise une hampe descendante"},
/* 0286 */ { "LETTRE MINUSCULE LATINE ECH BOUCLÉ","	* fricative palato-alvéolaire sourde palatalisée\n"
	"	* écriture recommandée : 0283 02B2"},
/* 0287 */ { "LETTRE MINUSCULE LATINE T CULBUTÉ","	* clic dental\n"
	"	* l'onomatopée « tss-tss » utilisée par les francophones pour exprimer la désapprobation ou le désaccord retranscrit de façon approximative un clic dental\n"
	"	* la majuscule est A7B1\n"
	"	x (lettre latine clic dental - 01C0)"},
/* 0288 */ { "LETTRE MINUSCULE LATINE T HAMEÇON RÉTROFLEXE","	* occlusive rétroflexe sourde\n"
	"	* la majuscule est 01AE\n"
	"	x (lettre minuscule latine t crosse - 01AD)\n"
	"	x (lettre minuscule latine t crosse et hameçon rétroflexe - 1DF09)"},
/* 0289 */ { "LETTRE MINUSCULE LATINE U BARRÉ","	* voyelle fermée centrale arrondie\n"
	"	* la majuscule est 0244\n"
	"	x (lettre latine petite capitale u barré - 1D7E)"},
/* 028A */ { "LETTRE MINUSCULE LATINE UPSILON","	* voyelle pré-fermée postérieure arrondie\n"
	"	* typographiquement, une petite capitale oméga grec 03A9 culbuté\n"
	"	* forme recommandée par l'API en lieu et place de 0277\n"
	"	* la majuscule est 01B1\n"
	"	x (lettre minuscule grecque upsilon - 03C5)"},
/* 028B */ { "LETTRE MINUSCULE LATINE V CROSSE","	= lettre minuscule latine v cursif (1.0)\n"
	"	* spirante labio-dentale sonore\n"
	"	* la majuscule est 01B2\n"
	"	x (lettre minuscule grecque upsilon - 03C5)"},
/* 028C */ { "LETTRE MINUSCULE LATINE V CULBUTÉ","	= chevron\n"
	"	* voyelle mi-ouverte postérieure non arrondie\n"
	"	* la majuscule est 0245\n"
	"	x (lettre majuscule grecque lambda - 039B)\n"
	"	x (lettre grecque petite capitale lambda - 1D27)\n"
	"	x (et logique - 2227)"},
/* 028D */ { "LETTRE MINUSCULE LATINE W CULBUTÉ","	* spirante labio-vélaire sourde\n"
	"	x (lettre modificative minuscule w réfléchi - AB69)"},
/* 028E */ { "LETTRE MINUSCULE LATINE Y CULBUTÉ","	* spirante latérale palatale sonore"},
/* 028F */ { "LETTRE LATINE PETITE CAPITALE Y","	* voyelle pré-fermée antérieure arrondie"},
/* 0290 */ { "LETTRE MINUSCULE LATINE Z HAMEÇON RÉTROFLEXE","	* fricative rétroflexe sonore"},
/* 0291 */ { "LETTRE MINUSCULE LATINE Z BOUCLÉ","	* fricative alvéolo-palatale sonore\n"
	"	* son écrit à l'aide de 017A en polonais"},
/* 0292 */ { "LETTRE MINUSCULE LATINE EJ","	= symbole dram\n"
	"	* fricative palato-alvéolaire sonore\n"
	"	* portait le nom erroné de « yogh » dans Unicode 1.0\n"
	"	* la majuscule est 01B7\n"
	"	* same skolt\n"
	"	x (lettre minuscule latine yogh - 021D)\n"
	"	x (lettre minuscule cyrillique dzé abkhaze - 04E1)\n"
	"	x (symbole once - 2125)\n"
	"	x (symbole alchimique du demi-gros - 1F772)\n"
	"	x 2CF01"},
/* 0293 */ { "LETTRE MINUSCULE LATINE EJ BOUCLÉ","	* fricative palato-alvéolaire sonore palatalisée"},
/* 0294 */ { "LETTRE LATINE COUP DE GLOTTE","	* lettre unicamérale\n"
	"	* utilisée en API, dans d'autres notations phonétiques et dans les systèmes d'écriture qui utilisent un coup de glotte unicaméral\n"
	"	x (lettre majuscule latine coup de glotte - 0241)\n"
	"	x (lettre modificative coup de glotte - 02C0)"},
/* 0295 */ { "LETTRE LATINE FRICATIVE PHARYNGALE SONORE","	= coup de glotte renversé\n"
	"	* fricative pharyngale sonore\n"
	"	* ʿaïn\n"
	"	x (lettre minuscule latine ej réfléchi - 01B9)\n"
	"	x (lettre modificative coup de glotte renversé - 02C1)\n"
	"	x (lettre minuscule latine fricative pharyngale sonore - A7CF)"},
/* 0296 */ { "LETTRE LATINE COUP DE GLOTTE RÉFLÉCHI","	* clic latéral\n"
	"	x (lettre latine clic latéral - 01C1)"},
/* 0297 */ { "LETTRE LATINE C ÉTIRÉ","	* clic post-alvéolaire\n"
	"	x (lettre latine clic rétroflexe - 01C3)\n"
	"	x (complément - 2201)"},
/* 0298 */ { "LETTRE LATINE CLIC BILABIAL","	= œil-de-bœuf\n"
	"	* lettre à casse unique\n"
	"	x (opérateur point cerclé - 2299)\n"
	"	x (lettre majuscule cyrillique o monoculaire - A668)"},
/* 0299 */ { "LETTRE LATINE PETITE CAPITALE B","	* consonne roulée bilabiale sonore\n"
	"	x (lettre minuscule cyrillique vé - 0432)"},
/* 029A */ { "LETTRE MINUSCULE LATINE E OUVERT FERMÉ","	= epsilon fermé\n"
	"	* voyelle mi-ouverte antérieure arrondie\n"
	"	* forme non API pour la représentation recommandée 0153\n"
	"	x (lettre minuscule latine e ouvert réfléchi fermé - 025E)"},
/* 029B */ { "LETTRE LATINE PETITE CAPITALE G CROSSE","	* occlusive injective uvulaire"},
/* 029C */ { "LETTRE LATINE PETITE CAPITALE H","	* fricative épiglottale sourde\n"
	"	x (lettre minuscule cyrillique enne - 043D)\n"
	"	x (lettre modificative majuscule h - 1D34)\n"
	"	x (lettre modificative majuscule h barré - A7F8)"},
/* 029D */ { "LETTRE MINUSCULE LATINE J À QUEUE CROISÉE","	* fricative palatale sonore\n"
	"	* la majuscule est A7B2"},
/* 029E */ { "LETTRE MINUSCULE LATINE K CULBUTÉ","	* proposée pour le clic vélaire\n"
	"	* la majuscule est A7B0\n"
	"	* retirée par l'API en 1970\n"
	"	x (lettre latine petite capitale k culbuté - 1DF10)"},
/* 029F */ { "LETTRE LATINE PETITE CAPITALE L","	* spirante latérale vélaire sonore"},
/* 02A0 */ { "LETTRE MINUSCULE LATINE Q CROSSE","	* occlusive injective uvulaire sourde"},
/* 02A1 */ { "LETTRE LATINE COUP DE GLOTTE BARRÉ","	* occlusive épiglottale"},
/* 02A2 */ { "LETTRE LATINE COUP DE GLOTTE BARRÉ RENVERSÉ","	* fricative épiglottale sonore"},
/* 02A3 */ { "LETTRE MINUSCULE LATINE DIGRAMME DZ","	* affriquée alvéolaire sonore\n"
	"	x (lettre minuscule latine digramme dz hameçon rétroflexe - AB66)"},
/* 02A4 */ { "LETTRE MINUSCULE LATINE DIGRAMME DEJ","	* affriquée palato-alvéolaire sonore"},
/* 02A5 */ { "LETTRE MINUSCULE LATINE DIGRAMME DZ BOUCLÉ","	* affriquée alvéolo-palatale sonore"},
/* 02A6 */ { "LETTRE MINUSCULE LATINE DIGRAMME TS","	* affriquée alvéolaire sourde\n"
	"	x (lettre latine coup de glotte barré réfléchi - 01BE)\n"
	"	x (lettre minuscule latine digramme ts hameçon rétroflexe - AB67)"},
/* 02A7 */ { "LETTRE MINUSCULE LATINE DIGRAMME TECH","	* affriquée palato-alvéolaire sourde\n"
	"	x (lettre minuscule latine tz - A729)"},
/* 02A8 */ { "LETTRE MINUSCULE LATINE DIGRAMME TC BOUCLÉ","	* affriquée alvéolo-palatale sourde"},
/* 02A9 */ { "LETTRE MINUSCULE LATINE DIGRAMME FENG","	* fricative vélopharyngale"},
/* 02AA */ { "LETTRE MINUSCULE LATINE DIGRAMME LS","	* fricative alvéolaire latérale (zézaiement)"},
/* 02AB */ { "LETTRE MINUSCULE LATINE DIGRAMME LZ","	* fricative alvéolaire latérale sonore"},
/* 02AC */ { "LETTRE LATINE PERCUSSION BILABIALE","	* baiser audible"},
/* 02AD */ { "LETTRE LATINE PERCUSSION BIDENTALE","	* grincement de dents audible"},
/* 02AE */ { "LETTRE MINUSCULE LATINE H HAMEÇON RÉTROFLEXE CULBUTÉ","	= h culbuté à crochet gauche\n"
	"	* voyelle apico-dentale labialisée"},
/* 02AF */ { "LETTRE MINUSCULE LATINE H HAMEÇON RÉTROFLEXE ET CROSSE CULBUTÉ","	= h culbuté à crochet gauche et queue\n"
	"	* voyelle rétroflexe apicale labialisée"},
/* 02B0 */ { "LETTRE MODIFICATIVE MINUSCULE H","	* aspiré\n"
	"	# <exp> 0068"},
/* 02B1 */ { "LETTRE MODIFICATIVE MINUSCULE H CROSSE","	* soufflé sonore, murmuré\n"
	"	x (lettre minuscule latine h crosse - 0266)\n"
	"	x (diacritique tréma souscrit - 0324)\n"
	"	# <exp> 0266"},
/* 02B2 */ { "LETTRE MODIFICATIVE MINUSCULE J","	* palatalisé\n"
	"	x (diacritique hameçon palatal souscrit - 0321)\n"
	"	# <exp> 006A"},
/* 02B3 */ { "LETTRE MODIFICATIVE MINUSCULE R","	# <exp> 0072"},
/* 02B4 */ { "LETTRE MODIFICATIVE MINUSCULE R CULBUTÉ","	x (lettre minuscule latine r culbuté - 0279)\n"
	"	# <exp> 0279"},
/* 02B5 */ { "LETTRE MODIFICATIVE MINUSCULE R CROSSE CULBUTÉ","	x (lettre minuscule latine r crosse culbuté - 027B)\n"
	"	# <exp> 027B"},
/* 02B6 */ { "LETTRE MODIFICATIVE PETITE CAPITALE R RENVERSÉ","	* les quatre diacritiques ci-dessus servent à marquer une coloration en r\n"
	"	x (lettre latine petite capitale r renversé - 0281)\n"
	"	# <exp> 0281"},
/* 02B7 */ { "LETTRE MODIFICATIVE MINUSCULE W","	* labialisé\n"
	"	x (diacritique oméga souscrit - 032B)\n"
	"	# <exp> 0077"},
/* 02B8 */ { "LETTRE MODIFICATIVE MINUSCULE Y","	* palatalisé\n"
	"	* utilisée par les américanistes à la place de 02B2\n"
	"	# <exp> 0079"},
/* 02B9 */ { "LETTRE MODIFICATIVE PRIME","	* accentuation\n"
	"	* translittération du signe mou cyrillique (palatalisation)\n"
	"	* translittération du gerich hébreu\n"
	"	x (apostrophe - 0027)\n"
	"	x (accent aigu - 00B4)\n"
	"	x (lettre modificative accent aigu - 02CA)\n"
	"	x (diacritique accent aigu - 0301)\n"
	"	x (signe numéral grec - 0374)\n"
	"	x (ponctuation hébraïque gerich - 05F3)\n"
	"	x (prime - 2032)"},
/* 02BA */ { "LETTRE MODIFICATIVE SECONDE","	* accent tonique exagéré, accent contrastif\n"
	"	* translittération du signe dur cyrillique (absence de palatalisation)\n"
	"	x (guillemet anglais - 0022)\n"
	"	x (diacritique double accent aigu - 030B)\n"
	"	x (double prime - 2033)"},
/* 02BB */ { "LETTRE MODIFICATIVE VIRGULE CULBUTÉE","	* autre forme typographique pour 02BD ou 02BF\n"
	"	* utilisée dans quelques orthographes polynésiennes pour le coup de glotte\n"
	"	* hawaïen : ʻokina\n"
	"	* tongien : fakauʻa\n"
	"	x (diacritique virgule culbutée en chef - 0312)\n"
	"	x (apostrophe n'ko de ton bas - 07F5)\n"
	"	x (guillemet-apostrophe culbuté - 2018)"},
/* 02BC */ { "LETTRE MODIFICATIVE APOSTROPHE","	= apostrophe\n"
	"	* coup de glotte, glottalisation, éjectif\n"
	"	* clone à chasse de l'esprit doux grec\n"
	"	* beaucoup de langues considèrent ce caractère comme une lettre de leur alphabet\n"
	"	* utilisée comme signe de ton en bodo et en dogri\n"
	"	* indique un allongement de voyelle ou diverses troncatures et ellipses en maïthili\n"
	"	* utilisée comme une lettre modificative en lissou\n"
	"	* 2019 est le caractère privilégié pour noter une apostrophe de ponctuation\n"
	"	x (apostrophe - 0027)\n"
	"	x (diacritique virgule en chef - 0313)\n"
	"	x (diacritique virgule en chef à droite - 0315)\n"
	"	x (apostrophe arménienne - 055A)\n"
	"	x (apostrophe n'ko de ton haut - 07F4)\n"
	"	x (esprit doux grec - 1FBF)\n"
	"	x (guillemet-apostrophe - 2019)"},
/* 02BD */ { "LETTRE MODIFICATIVE VIRGULE RÉFLÉCHIE","	* légèrement aspiré\n"
	"	x (diacritique virgule réfléchie en chef - 0314)\n"
	"	x (lettre modificative arménienne demi-rond gauche - 0559)\n"
	"	x (esprit rude grec - 1FFE)\n"
	"	x (guillemet-virgule supérieur culbuté - 201B)"},
/* 02BE */ { "LETTRE MODIFICATIVE DEMI-ROND DROIT","	* clone à chasse de l'esprit rude grec\n"
	"	* translittération de la hamza arabe (coup de glotte)\n"
	"	* translittération de l'alef hébreu\n"
	"	x (apostrophe arménienne - 055A)\n"
	"	x (lettre hébraïque alef - 05D0)\n"
	"	x (lettre arabe hamza - 0621)"},
/* 02BF */ { "LETTRE MODIFICATIVE DEMI-ROND GAUCHE","	* translittération du ʿaïn arabe (fricative pharyngale sonore)\n"
	"	* translittération du ʿaïn hébreu\n"
	"	x (lettre modificative arménienne demi-rond gauche - 0559)\n"
	"	x (lettre hébraïque 'aïn - 05E2)\n"
	"	x (lettre arabe 'aïn - 0639)"},
/* 02C0 */ { "LETTRE MODIFICATIVE COUP DE GLOTTE","	* éjectif ou glottalisé\n"
	"	* autre forme typographique pour 02BC ou 02BE\n"
	"	x (lettre latine coup de glotte - 0294)\n"
	"	x (diacritique crochet en chef - 0309)"},
/* 02C1 */ { "LETTRE MODIFICATIVE COUP DE GLOTTE RENVERSÉ","	* autre forme typographique pour 02BF\n"
	"	x (lettre latine fricative pharyngale sonore - 0295)"},
/* 02C2 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LA GAUCHE","	* articulation antérieure, avancée, protractée"},
/* 02C3 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LA DROITE","	* articulation postérieure, rétractée"},
/* 02C4 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LE HAUT","	* articulation vers le haut\n"
	"	x (accent circonflexe - 005E)\n"
	"	x (pointe de flèche vers le haut - 2303)"},
/* 02C5 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LE BAS","	* articulation vers le bas"},
/* 02C6 */ { "LETTRE MODIFICATIVE ACCENT CIRCONFLEXE","	* ton montant-descendant, contour descendant, accent secondaire\n"
	"	x (accent circonflexe - 005E)\n"
	"	x (diacritique accent circonflexe - 0302)\n"
	"	x (lettre modificative accent circonflexe bas - A788)"},
/* 02C7 */ { "CARON","	= hatchek, chevron\n"
	"	* ton descendant-montant\n"
	"	* troisième ton du mandarin\n"
	"	x (diacritique caron - 030C)"},
/* 02C8 */ { "LETTRE MODIFICATIVE LIGNE VERTICALE","	* accent principal\n"
	"	* précède la lettre ou la syllabe modifiée\n"
	"	x (apostrophe - 0027)\n"
	"	x (diacritique ligne verticale en chef - 030D)"},
/* 02C9 */ { "LETTRE MODIFICATIVE MACRON","	* ton haut\n"
	"	* précède ou suit la lettre ou la syllabe modifiée\n"
	"	* premier ton du mandarin\n"
	"	x (macron - 00AF)\n"
	"	x (diacritique macron - 0304)"},
/* 02CA */ { "LETTRE MODIFICATIVE ACCENT AIGU","	* contour haut montant (API), ton haut, accent principal\n"
	"	* deuxième ton du mandarin\n"
	"	x (accent aigu - 00B4)\n"
	"	x (lettre modificative prime - 02B9)\n"
	"	x (diacritique accent aigu - 0301)\n"
	"	x (signe numéral grec - 0374)\n"
	"	x (signe d'accentuation arménien - 055B)"},
/* 02CB */ { "LETTRE MODIFICATIVE ACCENT GRAVE","	* contour haut descendant (API), ton bas, accent secondaire ou tertiaire\n"
	"	* quatrième ton du mandarin\n"
	"	x (accent grave - 0060)\n"
	"	x (diacritique accent grave - 0300)\n"
	"	x (virgule arménienne - 055D)"},
/* 02CC */ { "LETTRE MODIFICATIVE LIGNE VERTICALE BASSE","	* accent secondaire\n"
	"	* précède la lettre ou la syllabe modifiée\n"
	"	x (diacritique ligne verticale souscrite - 0329)"},
/* 02CD */ { "LETTRE MODIFICATIVE MACRON BAS","	* ton bas\n"
	"	* utilisée comme une lettre modificative en lissou\n"
	"	x (tiret bas - 005F)\n"
	"	x (diacritique macron souscrit - 0331)"},
/* 02CE */ { "LETTRE MODIFICATIVE ACCENT GRAVE BAS","	* contour bas descendant, ton bas descendant"},
/* 02CF */ { "LETTRE MODIFICATIVE ACCENT AIGU BAS","	* contour bas montant, ton bas montant\n"
	"	x (signe numéral grec souscrit - 0375)"},
/* 02D0 */ { "LETTRE MODIFICATIVE DEUX POINTS TRIANGULAIRES","	= chrone\n"
	"	* marque de longueur\n"
	"	x (deux-points - 003A)"},
/* 02D1 */ { "LETTRE MODIFICATIVE POINT TRIANGULAIRE","	= demi-chrone\n"
	"	* indique une prononciation mi-longue\n"
	"	x (point médian - 00B7)"},
/* 02D2 */ { "LETTRE MODIFICATIVE DEMI-ROND DROIT CENTRÉ","	* articulation plus arrondie"},
/* 02D3 */ { "LETTRE MODIFICATIVE DEMI-ROND GAUCHE CENTRÉ","	* articulation moins arrondie"},
/* 02D4 */ { "LETTRE MODIFICATIVE TAQUET VERS LE HAUT","	* fermeture de voyelle, élévation de voyelle\n"
	"	x (diacritique taquet vers le haut souscrit - 031D)\n"
	"	x (diacritique point souscrit - 0323)"},
/* 02D5 */ { "LETTRE MODIFICATIVE TAQUET VERS LE BAS","	* ouverture de voyelle, abaissement de voyelle\n"
	"	x (diacritique demi-rond gauche souscrit - 031C)\n"
	"	x (diacritique taquet vers le bas souscrit - 031E)"},
/* 02D6 */ { "LETTRE MODIFICATIVE SIGNE PLUS","	* articulation avancée ou antérieure, protractée\n"
	"	x (diacritique signe plus souscrit - 031F)"},
/* 02D7 */ { "LETTRE MODIFICATIVE SIGNE MOINS","	* articulation rétractée ou postérieure\n"
	"	* ce glyphe peut présenter de petits empattements\n"
	"	x (diacritique signe moins souscrit - 0320)\n"
	"	x (signe moins - 2212)"},
/* 02D8 */ { "BRÈVE","	x (diacritique brève - 0306)\n"
	"	# 0020 0306"},
/* 02D9 */ { "POINT EN CHEF","	* cinquième ton du mandarin (léger ou neutre)\n"
	"	x (diacritique point en chef - 0307)\n"
	"	# 0020 0307"},
/* 02DA */ { "ROND EN CHEF","	x (symbole degré - 00B0)\n"
	"	x (diacritique rond en chef - 030A)\n"
	"	# 0020 030A"},
/* 02DB */ { "OGONEK","	x (diacritique ogonek - 0328)\n"
	"	# 0020 0328"},
/* 02DC */ { "PETIT TILDE","	x (tilde - 007E)\n"
	"	x (diacritique tilde - 0303)\n"
	"	x (opérateur tilde - 223C)\n"
	"	# 0020 0303"},
/* 02DD */ { "DOUBLE ACCENT AIGU","	x (diacritique double accent aigu - 030B)\n"
	"	# 0020 030B"},
/* 02DE */ { "LETTRE MODIFICATIVE CROCHET DE RHOTACISME","	* rhotacisation de voyelle\n"
	"	* souvent ligaturée : 025A = 0259 + 02DE ; 025D = 025C + 02DE"},
/* 02DF */ { "LETTRE MODIFICATIVE ACCENT EN CROIX","	= accent cruciforme, accent croix de saint André\n"
	"	* accent grave suédois"},
/* 02E0 */ { "LETTRE MODIFICATIVE MINUSCULE GAMMA","	* ces lettres modificatives sont parfois utilisées dans la transcription des affriquées\n"
	"	# <exp> 0263"},
/* 02E1 */ { "LETTRE MODIFICATIVE MINUSCULE L","	# <exp> 006C"},
/* 02E2 */ { "LETTRE MODIFICATIVE MINUSCULE S","	# <exp> 0073"},
/* 02E3 */ { "LETTRE MODIFICATIVE MINUSCULE X","	# <exp> 0078"},
/* 02E4 */ { "LETTRE MODIFICATIVE MINUSCULE COUP DE GLOTTE RENVERSÉ","	# <exp> 0295"},
/* 02E5 */ { "LETTRE MODIFICATIVE BARRE DE TON TRÈS HAUT",NULL},
/* 02E6 */ { "LETTRE MODIFICATIVE BARRE DE TON HAUT",NULL},
/* 02E7 */ { "LETTRE MODIFICATIVE BARRE DE TON MOYEN",NULL},
/* 02E8 */ { "LETTRE MODIFICATIVE BARRE DE TON BAS",NULL},
/* 02E9 */ { "LETTRE MODIFICATIVE BARRE DE TON TRÈS BAS",NULL},
/* 02EA */ { "LETTRE MODIFICATIVE SIGNE DE TON DE DÉPART YIN",NULL},
/* 02EB */ { "LETTRE MODIFICATIVE SIGNE DE TON DE DÉPART YANG",NULL},
/* 02EC */ { "LETTRE MODIFICATIVE VOISÉE",NULL},
/* 02ED */ { "LETTRE MODIFICATIVE NON ASPIRÉE","	x (lettre modificative signe égal court - A78A)"},
/* 02EE */ { "LETTRE MODIFICATIVE DOUBLE APOSTROPHE","	* nénetse"},
/* 02EF */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LE BAS BASSE",NULL},
/* 02F0 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LE HAUT BASSE",NULL},
/* 02F1 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LA GAUCHE BASSE",NULL},
/* 02F2 */ { "LETTRE MODIFICATIVE POINTE DE FLÈCHE VERS LA DROITE BASSE",NULL},
/* 02F3 */ { "LETTRE MODIFICATIVE ROND BAS","	x (diacritique rond souscrit - 0325)"},
/* 02F4 */ { "LETTRE MODIFICATIVE ACCENT GRAVE MÉDIAN",NULL},
/* 02F5 */ { "LETTRE MODIFICATIVE DOUBLE ACCENT GRAVE MÉDIAN",NULL},
/* 02F6 */ { "LETTRE MODIFICATIVE DOUBLE ACCENT AIGU MÉDIAN",NULL},
/* 02F7 */ { "LETTRE MODIFICATIVE TILDE BAS",NULL},
/* 02F8 */ { "LETTRE MODIFICATIVE DEUX-POINTS ÉLEVÉ",NULL},
/* 02F9 */ { "LETTRE MODIFICATIVE DÉBUT TON HAUT",NULL},
/* 02FA */ { "LETTRE MODIFICATIVE FIN TON HAUT",NULL},
/* 02FB */ { "LETTRE MODIFICATIVE DÉBUT TON BAS",NULL},
/* 02FC */ { "LETTRE MODIFICATIVE FIN TON BAS",NULL},
/* 02FD */ { "LETTRE MODIFICATIVE PLATEAU",NULL},
/* 02FE */ { "LETTRE MODIFICATIVE PLATEAU OUVERT",NULL},
/* 02FF */ { "LETTRE MODIFICATIVE FLÈCHE VERS LA GAUCHE BASSE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_03[] = {
/* 0300 */ { "DIACRITIQUE ACCENT GRAVE","	= accent grave grec (varia)\n"
	"	* pinyin : marque le quatrième ton du chinois mandarin\n"
	"	x (accent grave - 0060)\n"
	"	x (lettre modificative accent grave - 02CB)"},
/* 0301 */ { "DIACRITIQUE ACCENT AIGU","	= accent tonique\n"
	"	= accent aigu grec (du système polytonique)\n"
	"	= accent grec (du système monotonique)\n"
	"	* pinyin : marque le deuxième ton du chinois mandarin\n"
	"	x (apostrophe - 0027)\n"
	"	x (accent aigu - 00B4)\n"
	"	x (lettre modificative prime - 02B9)\n"
	"	x (lettre modificative accent aigu - 02CA)\n"
	"	x (accent grec - 0384)"},
/* 0302 */ { "DIACRITIQUE ACCENT CIRCONFLEXE","	= chapeau\n"
	"	x (accent circonflexe - 005E)\n"
	"	x (lettre modificative accent circonflexe - 02C6)"},
/* 0303 */ { "DIACRITIQUE TILDE","	* API : nasalisation\n"
	"	* marque de ton vietnamienne\n"
	"	* à distinguer du diacritique « apex » du moyen vietnamien\n"
	"	x (tilde - 007E)\n"
	"	x (petit tilde - 02DC)\n"
	"	x (diacritique macron-aigu - 1DC4)"},
/* 0304 */ { "DIACRITIQUE MACRON","	= long\n"
	"	* pinyin : marque le premier ton du chinois mandarin\n"
	"	* à distinguer du caractère suivant\n"
	"	x (macron - 00AF)\n"
	"	x (lettre modificative macron - 02C9)\n"
	"	x (diacritique signe moins en chef - 1AE2)"},
/* 0305 */ { "DIACRITIQUE TIRET HAUT","	= trait suscrit, vinculum\n"
	"	* se lie à gauche et à droite\n"
	"	* dans l'écriture d'une expression mathématique, il relie graphiquement des symboles qui doivent être considérés comme formant un tout\n"
	"	x (macron - 00AF)"},
/* 0306 */ { "DIACRITIQUE BRÈVE","	= bref\n"
	"	= brève grecque, brakhus grec\n"
	"	x (brève - 02D8)\n"
	"	x (diacritique cyrillique kavyka - A67C)"},
/* 0307 */ { "DIACRITIQUE POINT EN CHEF","	= dérivée (notation newtonienne)\n"
	"	* API (retiré en 1976) : palatalisation\n"
	"	x (point en chef - 02D9)"},
/* 0308 */ { "DIACRITIQUE TRÉMA","	= double point en chef, umlaut\n"
	"	= tréma grec\n"
	"	= dérivée seconde\n"
	"	x (tréma - 00A8)"},
/* 0309 */ { "DIACRITIQUE CROCHET EN CHEF","	= hoï\n"
	"	* crène à la gauche ou à la droite du diacritique au-dessus des voyelles\n"
	"	* marque de ton vietnamienne\n"
	"	x (lettre modificative coup de glotte - 02C0)"},
/* 030A */ { "DIACRITIQUE ROND EN CHEF","	x (symbole degré - 00B0)\n"
	"	x (rond en chef - 02DA)"},
/* 030B */ { "DIACRITIQUE DOUBLE ACCENT AIGU","	* hongrois, tchouvache\n"
	"	x (guillemet anglais - 0022)\n"
	"	x (lettre modificative seconde - 02BA)\n"
	"	x (double accent aigu - 02DD)"},
/* 030C */ { "DIACRITIQUE CARON","	= hatchek, chevron suscrit, accent hirondelle\n"
	"	* pinyin : marque le troisième ton du chinois mandarin\n"
	"	x (caron - 02C7)"},
/* 030D */ { "DIACRITIQUE LIGNE VERTICALE EN CHEF","	* il ne s'agit pas de l'accent grec (tonos)\n"
	"	* marshallais\n"
	"	x (lettre modificative ligne verticale - 02C8)"},
/* 030E */ { "DIACRITIQUE DOUBLE LIGNE VERTICALE EN CHEF","	* marshallais\n"
	"	x (guillemet anglais - 0022)"},
/* 030F */ { "DIACRITIQUE DOUBLE ACCENT GRAVE","	* phonétique serbe et croate"},
/* 0310 */ { "DIACRITIQUE TCHANDRABINDOU","	= candrabindu\n"
	"	x (diacritique dévanâgarî tchandrabindou - 0901)"},
/* 0311 */ { "DIACRITIQUE BRÈVE RENVERSÉE","	x (diacritique cyrillique de palatalisation - 0484)\n"
	"	x (diacritique cyrillique pokrytié - 0487)"},
/* 0312 */ { "DIACRITIQUE VIRGULE CULBUTÉE EN CHEF","	= cédille suscrite, cédille en chef\n"
	"	* letton (mais pas utilisé dans les décompositions)\n"
	"	x (lettre modificative virgule culbutée - 02BB)"},
/* 0313 */ { "DIACRITIQUE VIRGULE EN CHEF","	= esprit doux grec (psili)\n"
	"	* éjective ou glottalisation des américanistes\n"
	"	x (lettre modificative apostrophe - 02BC)\n"
	"	x (diacritique cyrillique psili pneumata - 0486)\n"
	"	x (apostrophe arménienne - 055A)"},
/* 0314 */ { "DIACRITIQUE VIRGULE RÉFLÉCHIE EN CHEF","	= esprit rude grec (dasia)\n"
	"	x (lettre modificative virgule réfléchie - 02BD)\n"
	"	x (diacritique cyrillique dasia pneumata - 0485)\n"
	"	x (lettre modificative arménienne demi-rond gauche - 0559)"},
/* 0315 */ { "DIACRITIQUE VIRGULE EN CHEF À DROITE","	x (lettre modificative apostrophe - 02BC)"},
/* 0316 */ { "DIACRITIQUE ACCENT GRAVE SOUSCRIT",NULL},
/* 0317 */ { "DIACRITIQUE ACCENT AIGU SOUSCRIT",NULL},
/* 0318 */ { "DIACRITIQUE TAQUET À GAUCHE SOUSCRIT","	x (diacritique taquet à gauche en chef - 1AE0)\n"
	"	x (lettre modificative taquet à gauche - AB6A)"},
/* 0319 */ { "DIACRITIQUE TAQUET À DROITE SOUSCRIT","	x (diacritique taquet á droite en chef - 1AE1)\n"
	"	x (lettre modificative taquet à droite - AB6B)"},
/* 031A */ { "DIACRITIQUE ANGLE GAUCHE EN CHEF","	* API : pas de détente audible"},
/* 031B */ { "DIACRITIQUE CORNU","	* vietnamien"},
/* 031C */ { "DIACRITIQUE DEMI-ROND GAUCHE SOUSCRIT","	* API : voyelle arrondie\n"
	"	x (lettre modificative taquet vers le bas - 02D5)"},
/* 031D */ { "DIACRITIQUE TAQUET VERS LE HAUT SOUSCRIT","	* API : élévation ou fermeture de voyelle\n"
	"	x (lettre modificative taquet vers le haut - 02D4)\n"
	"	x (diacritique taquet vers le haut en chef - 1DF5)"},
/* 031E */ { "DIACRITIQUE TAQUET VERS LE BAS SOUSCRIT","	* API : abaissement ou ouverture de voyelle\n"
	"	x (lettre modificative taquet vers le bas - 02D5)\n"
	"	x (diacritique taquet vers le bas en chef - 1ADB)"},
/* 031F */ { "DIACRITIQUE SIGNE PLUS SOUSCRIT","	* API : articulation avancée ou protractée\n"
	"	x (lettre modificative signe plus - 02D6)\n"
	"	x (diacritique signe plus en chef - 1AC8)"},
/* 0320 */ { "DIACRITIQUE SIGNE MOINS SOUSCRIT","	* API : articulation rétractée ou postérieure\n"
	"	* ce glyphe peut présenter de petits empattements\n"
	"	x (lettre modificative signe moins - 02D7)\n"
	"	x (diacritique signe moins en chef - 1AE2)"},
/* 0321 */ { "DIACRITIQUE HAMEÇON PALATAL SOUSCRIT","	* API : palatalisation\n"
	"	x (lettre modificative minuscule j - 02B2)"},
/* 0322 */ { "DIACRITIQUE HAMEÇON RÉTROFLEXE SOUSCRIT","	* API : rétroflexion"},
/* 0323 */ { "DIACRITIQUE POINT SOUSCRIT","	= nang\n"
	"	* API : voyelle fermée\n"
	"	* américanistes et indo-européanistes : rétraction ou rétroflexion\n"
	"	* arabisants : vélarisation ou pharyngalisation\n"
	"	* marque de ton vietnamienne\n"
	"	x (lettre modificative taquet vers le haut - 02D4)"},
/* 0324 */ { "DIACRITIQUE TRÉMA SOUSCRIT","	* API : voix soufflée ou murmure\n"
	"	x (lettre modificative minuscule h crosse - 02B1)"},
/* 0325 */ { "DIACRITIQUE ROND SOUSCRIT","	* API : sourd, non voisé (dévoisement, dévocalisation)\n"
	"	* vocalique (dans les translittérations latines des sonantes indiennes)\n"
	"	* madurais\n"
	"	x (lettre modificative rond bas - 02F3)"},
/* 0326 */ { "DIACRITIQUE VIRGULE SOUSCRITE","	* roumain, letton, live"},
/* 0327 */ { "DIACRITIQUE CÉDILLE","	* français, turc, azéri\n"
	"	x (cédille - 00B8)"},
/* 0328 */ { "DIACRITIQUE OGONEK","	= crochet nasal\n"
	"	* américanistes : nasalisation\n"
	"	* polonais, lituanien\n"
	"	x (ogonek - 02DB)\n"
	"	x (diacritique ouverture souscrite - 1AB7)"},
/* 0329 */ { "DIACRITIQUE LIGNE VERTICALE SOUSCRITE","	* API : syllabique\n"
	"	* yorouba\n"
	"	* dialectologie allemande\n"
	"	* peut s'attacher ou non ; la forme peut varier selon les préférences\n"
	"	x (lettre modificative ligne verticale basse - 02CC)"},
/* 032A */ { "DIACRITIQUE PONTET SOUSCRIT","	* API : dentale"},
/* 032B */ { "DIACRITIQUE OMÉGA SOUSCRIT","	= diacritique double voûte inversée souscrite\n"
	"	= diacritique w souscrit\n"
	"	* API : labialisation\n"
	"	x (lettre modificative minuscule w - 02B7)\n"
	"	x (diacritique oméga en chef - 1AC7)"},
/* 032C */ { "DIACRITIQUE CARON SOUSCRIT","	= diacritique chevron souscrit\n"
	"	* API : sonore, voisé"},
/* 032D */ { "DIACRITIQUE ACCENT CIRCONFLEXE SOUSCRIT","	* américanistes : articulation protractée"},
/* 032E */ { "DIACRITIQUE BRÈVE SOUSCRITE","	* transcription du hittite"},
/* 032F */ { "DIACRITIQUE BRÈVE RENVERSÉE SOUSCRITE","	* américanistes : articulation protractée (variante de 032D)\n"
	"	* indo-européanistes : semi-voyelle"},
/* 0330 */ { "DIACRITIQUE TILDE SOUSCRIT","	* API : voix cassée, traquée, Knarrstimme"},
/* 0331 */ { "DIACRITIQUE MACRON SOUSCRIT","	x (tiret bas - 005F)\n"
	"	x (lettre modificative macron bas - 02CD)"},
/* 0332 */ { "DIACRITIQUE TRAIT SOUSCRIT","	= souligné, tiret bas\n"
	"	* se lie à gauche et à droite\n"
	"	x (tiret bas - 005F)"},
/* 0333 */ { "DIACRITIQUE DOUBLE TRAIT SOUSCRIT","	= double souligné, double tiret bas\n"
	"	* se lie à gauche et à droite\n"
	"	x (diacritique signe égal souscrit - 0347)\n"
	"	x (double tiret bas - 2017)"},
/* 0334 */ { "DIACRITIQUE TILDE COUVRANT","	* API : vélarisation ou pharyngalisation"},
/* 0335 */ { "DIACRITIQUE BARRE COURTE COUVRANTE",NULL},
/* 0336 */ { "DIACRITIQUE BARRE LONGUE COUVRANTE","	= biffure\n"
	"	* se lie à gauche et à droite"},
/* 0337 */ { "DIACRITIQUE BARRE OBLIQUE COURTE COUVRANTE","	= diacritique courte oblique couvrante, diacritique courte cotice couvrante"},
/* 0338 */ { "DIACRITIQUE BARRE OBLIQUE LONGUE COUVRANTE","	= diacritique longue oblique couvrante, diacritique longue cotice couvrante"},
/* 0339 */ { "DIACRITIQUE DEMI-ROND DROIT SOUSCRIT",NULL},
/* 033A */ { "DIACRITIQUE PONTET RENVERSÉ SOUSCRIT","	* API : apicale\n"
	"	x (diacritique pontet renversé en chef - 1AE3)\n"
	"	x (diacritique pont renversé souscrit - 1DF9)"},
/* 033B */ { "DIACRITIQUE CARRÉ SOUSCRIT","	* API : laminale\n"
	"	* pour un usage API, la forme recommandée du glyphe est un rectangle horizontal\n"
	"	x (diacritique carré en chef - 1AE4)"},
/* 033C */ { "DIACRITIQUE MOUETTE SOUSCRITE","	* API : linguo-labiale\n"
	"	x (diacritique mouette en chef - 1AE5)"},
/* 033D */ { "DIACRITIQUE X EN CHEF",NULL},
/* 033E */ { "DIACRITIQUE TILDE VERTICAL","	= yérik (yérok)\n"
	"	* utilisé pour le yérik cyrillique, indique l'omission du yer\n"
	"	* il ne s'agit pas d'un signe de palatisation\n"
	"	x (diacritique cyrillique de palatalisation - 0484)\n"
	"	x (tilde vertical - 2E2F)\n"
	"	x (diacritique cyrillique payérok - A67D)"},
/* 033F */ { "DIACRITIQUE DOUBLE TRAIT EN CHEF","	* se lie à gauche et à droite"},
/* 0340 */ { "DIACRITIQUE TON GRAVE","	: 0300 diacritique accent grave"},
/* 0341 */ { "DIACRITIQUE TON AIGU","	: 0301 diacritique accent aigu"},
/* 0342 */ { "DIACRITIQUE GREC ACCENT CIRCONFLEXE","	* son tracé représente la modulation vocale montante puis descendante\n"
	"	* le glyphe peut prendre des formes proches d'une brève renversée, d'un accent circonflexe, d'un tilde ou parfois d'un macron\n"
	"	x (diacritique tilde - 0303)\n"
	"	x (diacritique brève renversée - 0311)"},
/* 0343 */ { "DIACRITIQUE GREC CORONIS","	= corônis (littéralement : « petit crochet »)\n"
	"	* la coronis est portée par la syllabe qui résulte d'une crase\n"
	"	* signe graphique semblable à l'esprit doux\n"
	"	: 0313 diacritique virgule en chef"},
/* 0344 */ { "DIACRITIQUE GREC TRÉMA ACCENT","	* l'utilisation de ce caractère est déconseillée\n"
	"	: 0308 0301"},
/* 0345 */ { "DIACRITIQUE GREC IOTA SOUSCRIT","	= iota grec sans chasse souscrit (1.0)\n"
	"	* présente des particularités liées à la casse\n"
	"	x (caractère grec iota souscrit - 037A)\n"
	"	x (lettre majuscule grecque iota - 0399)"},
/* 0346 */ { "DIACRITIQUE PONTET EN CHEF","	* extensions de l'API : dento-labial\n"
	"	x (diacritique pont en chef - 20E9)"},
/* 0347 */ { "DIACRITIQUE SIGNE ÉGAL SOUSCRIT","	* API : alvéolaire\n"
	"	x (diacritique signe égal en chef - 1AE8)"},
/* 0348 */ { "DIACRITIQUE DOUBLE LIGNE VERTICALE SOUSCRITE","	* API : forte articulation"},
/* 0349 */ { "DIACRITIQUE ANGLE GAUCHE SOUSCRIT","	* API : faible articulation\n"
	"	x (diacritique angle gauche centré en chef - 1AE9)"},
/* 034A */ { "DIACRITIQUE TILDE BARRÉ EN CHEF","	* API : dénasale"},
/* 034B */ { "DIACRITIQUE HOMOTHÉTIQUE EN CHEF","	* API : nasillement"},
/* 034C */ { "DIACRITIQUE PRESQUE ÉGAL À EN CHEF","	* API : friction vélopharyngale"},
/* 034D */ { "DIACRITIQUE FLÈCHE GAUCHE-DROITE SOUSCRITE","	* API : écartement labial\n"
	"	x (diacritique flèche gauche-droite en chef - 20E1)"},
/* 034E */ { "DIACRITIQUE FLÈCHE VERS LE HAUT SOUSCRITE","	* API : articulation sifflée\n"
	"	x (diacritique flèche vers le haut en chef - 1AEA)"},
/* 034F */ { "DIACRITIQUE INVISIBLE BLOQUANT","	* communément abrégé en CGJ (combining grapheme joiner)\n"
	"	* il ne possède pas de représentation visible"},
/* 0350 */ { "DIACRITIQUE POINTE DE FLÈCHE VERS LA DROITE EN CHEF",NULL},
/* 0351 */ { "DIACRITIQUE DEMI-ROND GAUCHE EN CHEF",NULL},
/* 0352 */ { "DIACRITIQUE POINT D'ORGUE",NULL},
/* 0353 */ { "DIACRITIQUE X SOUSCRIT",NULL},
/* 0354 */ { "DIACRITIQUE POINTE DE FLÈCHE VERS LA GAUCHE SOUSCRITE","	x (diacritique pointe de flèche vers la gauche en chef - 1DFE)"},
/* 0355 */ { "DIACRITIQUE POINTE DE FLÈCHE VERS LA DROITE SOUSCRITE",NULL},
/* 0356 */ { "DIACRITIQUE POINTES DE FLÈCHE VERS LA DROITE ET VERS LE HAUT SOUSCRITES",NULL},
/* 0357 */ { "DIACRITIQUE DEMI-ROND DROIT EN CHEF",NULL},
/* 0358 */ { "DIACRITIQUE POINT EN CHEF À DROITE","	* translittérations latines des dialectes chinois minnan\n"
	"	x (diacritique point en chef à gauche - 1DF8)"},
/* 0359 */ { "DIACRITIQUE ASTÉRISQUE SOUSCRIT","	x (astérisque baissé - 204E)"},
/* 035A */ { "DIACRITIQUE DOUBLE ROND SOUSCRIT","	* translittération du kharochthî"},
/* 035B */ { "DIACRITIQUE ZIGZAG EN CHEF","	* abréviation latine, phonétique lituanienne et transcriptions médiévistes"},
/* 035C */ { "DIACRITIQUE DOUBLE BRÈVE SOUSCRITE","	= tirant souscrit, trait d'union papyrologique\n"
	"	* un autre glyphe courant relie les caractères voisins à mi-hauteur\n"
	"	x (diacritique double brève - 035D)\n"
	"	x (diacritique double brève renversée - 0361)\n"
	"	x (diacritique moitié gauche de ligature souscrite - FE27)"},
/* 035D */ { "DIACRITIQUE DOUBLE BRÈVE",NULL},
/* 035E */ { "DIACRITIQUE DOUBLE MACRON",NULL},
/* 035F */ { "DIACRITIQUE DOUBLE MACRON SOUSCRIT",NULL},
/* 0360 */ { "DIACRITIQUE DOUBLE TILDE","	x (diacritique moitié gauche de tilde double - FE22)"},
/* 0361 */ { "DIACRITIQUE DOUBLE BRÈVE RENVERSÉE","	= tirant\n"
	"	x (diacritique moitié gauche de ligature - FE20)"},
/* 0362 */ { "DIACRITIQUE DOUBLE FLÈCHE VERS LA DROITE SOUSCRITE","	* API : articulation glissante\n"
	"	x (diacritique double flèche vers la droite en chef - 1AEB)"},
/* 0363 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE A",NULL},
/* 0364 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE E",NULL},
/* 0365 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE I",NULL},
/* 0366 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE O",NULL},
/* 0367 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE U",NULL},
/* 0368 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE C",NULL},
/* 0369 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE D",NULL},
/* 036A */ { "DIACRITIQUE LETTRE MINUSCULE LATINE H",NULL},
/* 036B */ { "DIACRITIQUE LETTRE MINUSCULE LATINE M",NULL},
/* 036C */ { "DIACRITIQUE LETTRE MINUSCULE LATINE R",NULL},
/* 036D */ { "DIACRITIQUE LETTRE MINUSCULE LATINE T",NULL},
/* 036E */ { "DIACRITIQUE LETTRE MINUSCULE LATINE V",NULL},
/* 036F */ { "DIACRITIQUE LETTRE MINUSCULE LATINE X",NULL},
/* 0370 */ { "LETTRE MAJUSCULE GRECQUE HÊTA","	x (lettre majuscule latine moitié de h - 2C75)"},
/* 0371 */ { "LETTRE MINUSCULE GRECQUE HÊTA","	x (lettre minuscule latine moitié de h - 2C76)"},
/* 0372 */ { "LETTRE MAJUSCULE GRECQUE SAMPI ARCHAÏQUE",NULL},
/* 0373 */ { "LETTRE MINUSCULE GRECQUE SAMPI ARCHAÏQUE",NULL},
/* 0374 */ { "SIGNE NUMÉRAL GREC","	= dexia keréa\n"
	"	* signe se plaçant à droite des lettres\n"
	"	* pour les nombres inférieurs à 1.000\n"
	"	x (lettre modificative accent aigu - 02CA)\n"
	"	: 02B9 lettre modificative prime"},
/* 0375 */ { "SIGNE NUMÉRAL GREC SOUSCRIT","	= aristerí keréa\n"
	"	* signe se plaçant à gauche des lettres\n"
	"	* pour les nombres supérieurs à 999\n"
	"	x (lettre modificative accent aigu bas - 02CF)"},
/* 0376 */ { "LETTRE MAJUSCULE GRECQUE DIGAMMA PAMPHYLIEN",NULL},
/* 0377 */ { "LETTRE MINUSCULE GRECQUE DIGAMMA PAMPHYLIEN",NULL},
/* 0378 */ { NULL,NULL},
/* 0379 */ { NULL,NULL},
/* 037A */ { "CARACTÈRE GREC IOTA SOUSCRIT","	x (diacritique grec iota souscrit - 0345)\n"
	"	# 0020 0345"},
/* 037B */ { "SYMBOLE GREC SIGMA LUNAIRE MINUSCULE RÉFLÉCHI",NULL},
/* 037C */ { "SYMBOLE GREC SIGMA LUNAIRE MINUSCULE POINTÉ",NULL},
/* 037D */ { "SYMBOLE GREC SIGMA LUNAIRE MINUSCULE POINTÉ RÉFLÉCHI",NULL},
/* 037E */ { "POINT D'INTERROGATION GREC","	= érotimatiko\n"
	"	* ponctuation de fin de phrase\n"
	"	* 003B est le caractère recommandé\n"
	"	x (point d'interrogation - 003F)\n"
	"	: 003B point-virgule"},
/* 037F */ { "LETTRE MAJUSCULE GRECQUE YOT","	* la minuscule est 03F3"},
/* 0380 */ { NULL,NULL},
/* 0381 */ { NULL,NULL},
/* 0382 */ { NULL,NULL},
/* 0383 */ { NULL,NULL},
/* 0384 */ { "ACCENT GREC","	= caractère grec accent\n"
	"	= tonos\n"
	"	x (accent aigu - 00B4)\n"
	"	x (diacritique ligne verticale en chef - 030D)\n"
	"	# 0020 0301"},
/* 0385 */ { "TRÉMA ACCENT GREC","	* décomposition par équivalence de compatibilité : 0020 0308 0301\n"
	"	: 00A8 0301"},
/* 0386 */ { "LETTRE MAJUSCULE GRECQUE ALPHA ACCENT","	: 0391 0301"},
/* 0387 */ { "ANO TELEIA GREC","	= point haut\n"
	"	* équivalent grec du point-virgule\n"
	"	* 00B7 est le caractère recommandé\n"
	"	: 00B7 point médian"},
/* 0388 */ { "LETTRE MAJUSCULE GRECQUE EPSILON ACCENT","	: 0395 0301"},
/* 0389 */ { "LETTRE MAJUSCULE GRECQUE ÊTA ACCENT","	: 0397 0301"},
/* 038A */ { "LETTRE MAJUSCULE GRECQUE IOTA ACCENT","	: 0399 0301"},
/* 038B */ { NULL,NULL},
/* 038C */ { "LETTRE MAJUSCULE GRECQUE OMICRON ACCENT","	: 039F 0301"},
/* 038D */ { NULL,NULL},
/* 038E */ { "LETTRE MAJUSCULE GRECQUE UPSILON ACCENT","	: 03A5 0301"},
/* 038F */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ACCENT","	: 03A9 0301"},
/* 0390 */ { "LETTRE MINUSCULE GRECQUE IOTA TRÉMA ET ACCENT","	: 03CA 0301"},
/* 0391 */ { "LETTRE MAJUSCULE GRECQUE ALPHA",NULL},
/* 0392 */ { "LETTRE MAJUSCULE GRECQUE BÊTA",NULL},
/* 0393 */ { "LETTRE MAJUSCULE GRECQUE GAMMA","	= fonction gamma\n"
	"	x (majuscule gamma ajouré - 213E)"},
/* 0394 */ { "LETTRE MAJUSCULE GRECQUE DELTA","	x (incrément - 2206)"},
/* 0395 */ { "LETTRE MAJUSCULE GRECQUE EPSILON",NULL},
/* 0396 */ { "LETTRE MAJUSCULE GRECQUE DZÊTA",NULL},
/* 0397 */ { "LETTRE MAJUSCULE GRECQUE ÊTA",NULL},
/* 0398 */ { "LETTRE MAJUSCULE GRECQUE THÊTA",NULL},
/* 0399 */ { "LETTRE MAJUSCULE GRECQUE IOTA","	= iota adscrit"},
/* 039A */ { "LETTRE MAJUSCULE GRECQUE KAPPA",NULL},
/* 039B */ { "LETTRE MAJUSCULE GRECQUE LAMBDA",NULL},
/* 039C */ { "LETTRE MAJUSCULE GRECQUE MU",NULL},
/* 039D */ { "LETTRE MAJUSCULE GRECQUE NU",NULL},
/* 039E */ { "LETTRE MAJUSCULE GRECQUE XI",NULL},
/* 039F */ { "LETTRE MAJUSCULE GRECQUE OMICRON",NULL},
/* 03A0 */ { "LETTRE MAJUSCULE GRECQUE PI","	x (majuscule pi ajouré - 213F)\n"
	"	x (produit de la famille - 220F)"},
/* 03A1 */ { "LETTRE MAJUSCULE GRECQUE RHÔ",NULL},
/* 03A2 */ { NULL,NULL},
/* 03A3 */ { "LETTRE MAJUSCULE GRECQUE SIGMA","	x (lettre majuscule latine ech - 01A9)\n"
	"	x (sommation de la famille - 2211)"},
/* 03A4 */ { "LETTRE MAJUSCULE GRECQUE TAU",NULL},
/* 03A5 */ { "LETTRE MAJUSCULE GRECQUE UPSILON",NULL},
/* 03A6 */ { "LETTRE MAJUSCULE GRECQUE PHI",NULL},
/* 03A7 */ { "LETTRE MAJUSCULE GRECQUE KHI",NULL},
/* 03A8 */ { "LETTRE MAJUSCULE GRECQUE PSI",NULL},
/* 03A9 */ { "LETTRE MAJUSCULE GRECQUE OMÉGA","	x (symbole ohm - 2126)\n"
	"	x (symbole ohm renversé - 2127)"},
/* 03AA */ { "LETTRE MAJUSCULE GRECQUE IOTA TRÉMA","	: 0399 0308"},
/* 03AB */ { "LETTRE MAJUSCULE GRECQUE UPSILON TRÉMA","	: 03A5 0308"},
/* 03AC */ { "LETTRE MINUSCULE GRECQUE ALPHA ACCENT","	: 03B1 0301"},
/* 03AD */ { "LETTRE MINUSCULE GRECQUE EPSILON ACCENT","	: 03B5 0301"},
/* 03AE */ { "LETTRE MINUSCULE GRECQUE ÊTA ACCENT","	: 03B7 0301"},
/* 03AF */ { "LETTRE MINUSCULE GRECQUE IOTA ACCENT","	: 03B9 0301"},
/* 03B0 */ { "LETTRE MINUSCULE GRECQUE UPSILON TRÉMA ET ACCENT","	: 03CB 0301"},
/* 03B1 */ { "LETTRE MINUSCULE GRECQUE ALPHA","	x (lettre minuscule latine alpha - 0251)\n"
	"	x (proportionnel à - 221D)"},
/* 03B2 */ { "LETTRE MINUSCULE GRECQUE BÊTA","	x (lettre minuscule latine s dur - 00DF)\n"
	"	x (lettre minuscule latine b barré - 0180)\n"
	"	x (lettre minuscule latine bêta - A7B5)"},
/* 03B3 */ { "LETTRE MINUSCULE GRECQUE GAMMA","	x (lettre minuscule latine gamma - 0263)\n"
	"	x (minuscule gamma ajouré - 213D)"},
/* 03B4 */ { "LETTRE MINUSCULE GRECQUE DELTA",NULL},
/* 03B5 */ { "LETTRE MINUSCULE GRECQUE EPSILON","	x (lettre minuscule latine e ouvert - 025B)"},
/* 03B6 */ { "LETTRE MINUSCULE GRECQUE DZÊTA",NULL},
/* 03B7 */ { "LETTRE MINUSCULE GRECQUE ÊTA",NULL},
/* 03B8 */ { "LETTRE MINUSCULE GRECQUE THÊTA","	x (lettre minuscule latine o barré - 0275)\n"
	"	x (lettre minuscule cyrillique fita - 0473)"},
/* 03B9 */ { "LETTRE MINUSCULE GRECQUE IOTA","	x (lettre minuscule latine iota - 0269)\n"
	"	x (lettre minuscule grecque iota culbuté - 2129)"},
/* 03BA */ { "LETTRE MINUSCULE GRECQUE KAPPA",NULL},
/* 03BB */ { "LETTRE MINUSCULE GRECQUE LAMBDA","	x (lettre minuscule latine lambda - A7DB)"},
/* 03BC */ { "LETTRE MINUSCULE GRECQUE MU","	x (symbole micro - 00B5)"},
/* 03BD */ { "LETTRE MINUSCULE GRECQUE NU",NULL},
/* 03BE */ { "LETTRE MINUSCULE GRECQUE XI",NULL},
/* 03BF */ { "LETTRE MINUSCULE GRECQUE OMICRON",NULL},
/* 03C0 */ { "LETTRE MINUSCULE GRECQUE PI","	* la constante mathématique 3,141592..."},
/* 03C1 */ { "LETTRE MINUSCULE GRECQUE RHÔ",NULL},
/* 03C2 */ { "LETTRE MINUSCULE GRECQUE SIGMA FINAL","	= stigma (nom en grec moderne pour cette forme de la lettre)\n"
	"	* à ne pas confondre avec la vraie lettre stigma\n"
	"	x (lettre minuscule grecque stigma - 03DB)"},
/* 03C3 */ { "LETTRE MINUSCULE GRECQUE SIGMA","	* lettre numérale pour noter le nombre 200 dans le système de numération grecque"},
/* 03C4 */ { "LETTRE MINUSCULE GRECQUE TAU",NULL},
/* 03C5 */ { "LETTRE MINUSCULE GRECQUE UPSILON","	x (lettre minuscule latine upsilon - 028A)\n"
	"	x (lettre minuscule latine v crosse - 028B)"},
/* 03C6 */ { "LETTRE MINUSCULE GRECQUE PHI","	* la lettre grecque habituelle, dont la représentation graphique varie considérablement\n"
	"	* en mathématique, on préfère la forme bouclée pour la distinguer de 03D5\n"
	"	x (lettre minuscule latine phi - 0278)\n"
	"	x (symbole grec phi - 03D5)"},
/* 03C7 */ { "LETTRE MINUSCULE GRECQUE KHI","	x (lettre minuscule latine khi - AB53)"},
/* 03C8 */ { "LETTRE MINUSCULE GRECQUE PSI",NULL},
/* 03C9 */ { "LETTRE MINUSCULE GRECQUE OMÉGA","	x (lettre minuscule latine oméga - A7B7)"},
/* 03CA */ { "LETTRE MINUSCULE GRECQUE IOTA TRÉMA","	: 03B9 0308"},
/* 03CB */ { "LETTRE MINUSCULE GRECQUE UPSILON TRÉMA","	: 03C5 0308"},
/* 03CC */ { "LETTRE MINUSCULE GRECQUE OMICRON ACCENT","	: 03BF 0301"},
/* 03CD */ { "LETTRE MINUSCULE GRECQUE UPSILON ACCENT","	: 03C5 0301"},
/* 03CE */ { "LETTRE MINUSCULE GRECQUE OMÉGA ACCENT","	: 03C9 0301"},
/* 03CF */ { "SYMBOLE GREC KAI MAJUSCULE","	x (symbole grec kai - 03D7)"},
/* 03D0 */ { "SYMBOLE GREC BÊTA","	= bêta courbé, bêta bouclé\n"
	"	# 03B2 lettre minuscule grecque bêta"},
/* 03D1 */ { "SYMBOLE GREC THÊTA","	= thêta cursif\n"
	"	* utilisé comme symbole technique\n"
	"	# 03B8 lettre minuscule grecque thêta"},
/* 03D2 */ { "SYMBOLE GREC UPSILON CROCHET","	# 03A5 lettre majuscule grecque upsilon"},
/* 03D3 */ { "SYMBOLE GREC UPSILON ACCENT AIGU ET CROCHET","	: 03D2 0301"},
/* 03D4 */ { "SYMBOLE GREC UPSILON TRÉMA ET CROCHET","	= lettre majuscule grecque upsilon tréma et crochet\n"
	"	: 03D2 0308"},
/* 03D5 */ { "SYMBOLE GREC PHI","	* utilisé comme symbole technique à l'aide d'un glyphe droit\n"
	"	* correspond aux entités de symbole « phi1 »\n"
	"	# 03C6 lettre minuscule grecque phi"},
/* 03D6 */ { "SYMBOLE GREC PI","	= pi dorien, pi cursif, oméga pi\n"
	"	* utilisé comme symbole technique\n"
	"	* une variante du pi, ressemblant à un oméga\n"
	"	# 03C0 lettre minuscule grecque pi"},
/* 03D7 */ { "SYMBOLE GREC KAI","	= ligature kai\n"
	"	* utilisé comme perluète\n"
	"	x (symbole copte kai - 2CE4)"},
/* 03D8 */ { "LETTRE GRECQUE KOPPA ARCHAÏQUE",NULL},
/* 03D9 */ { "LETTRE MINUSCULE GRECQUE KOPPA ARCHAÏQUE","	* les koppas archaïques en Q constituent les lettres alphabétiques habituelles et peuvent être utilisés aussi comme symboles pour noter le nombre 90 dans les textes classiques et préclassiques"},
/* 03DA */ { "LETTRE GRECQUE STIGMA","	* le nom « stigma » s'appliquait à l'origine à une ligature sigma-tau médiévale, dont la forme pouvait être méprise pour celle d'une forme cursive du digamma\n"
	"	* sert à la numération alphabétique grecque avec la valeur 6\n"
	"	x (chiffre romain six forme tardive - 2185)"},
/* 03DB */ { "LETTRE MINUSCULE GRECQUE STIGMA","	x (lettre minuscule grecque sigma final - 03C2)"},
/* 03DC */ { "LETTRE GRECQUE DIGAMMA","	= waw"},
/* 03DD */ { "LETTRE MINUSCULE GRECQUE DIGAMMA","	= waw minuscule\n"
	"	* sert à la numération alphabétique grecque avec la valeur 6"},
/* 03DE */ { "LETTRE GRECQUE KOPPA",NULL},
/* 03DF */ { "LETTRE MINUSCULE GRECQUE KOPPA","	* utilisée en grec moderne pour noter le nombre 90, par exemple dans la datation de documents juridiques"},
/* 03E0 */ { "LETTRE GRECQUE SAMPI","	= san"},
/* 03E1 */ { "LETTRE MINUSCULE GRECQUE SAMPI","	= san minuscule\n"
	"	* sert dans la numération alphabétique pour noter le nombre 900"},
/* 03E2 */ { "LETTRE MAJUSCULE COPTE CHAÏ",NULL},
/* 03E3 */ { "LETTRE MINUSCULE COPTE CHAÏ",NULL},
/* 03E4 */ { "LETTRE MAJUSCULE COPTE FAÏ",NULL},
/* 03E5 */ { "LETTRE MINUSCULE COPTE FAÏ",NULL},
/* 03E6 */ { "LETTRE MAJUSCULE COPTE KHAÏ",NULL},
/* 03E7 */ { "LETTRE MINUSCULE COPTE KHAÏ",NULL},
/* 03E8 */ { "LETTRE MAJUSCULE COPTE HORI",NULL},
/* 03E9 */ { "LETTRE MINUSCULE COPTE HORI",NULL},
/* 03EA */ { "LETTRE MAJUSCULE COPTE DJANDJA",NULL},
/* 03EB */ { "LETTRE MINUSCULE COPTE DJANDJA",NULL},
/* 03EC */ { "LETTRE MAJUSCULE COPTE TCHIMA",NULL},
/* 03ED */ { "LETTRE MINUSCULE COPTE TCHIMA",NULL},
/* 03EE */ { "LETTRE MAJUSCULE COPTE TI",NULL},
/* 03EF */ { "LETTRE MINUSCULE COPTE TI",NULL},
/* 03F0 */ { "SYMBOLE GREC KAPPA","	= kappa cursif\n"
	"	* utilisé comme symbole technique\n"
	"	# 03BA lettre minuscule grecque kappa"},
/* 03F1 */ { "SYMBOLE GREC RHÔ","	= rhô à queue\n"
	"	* utilisé comme symbole technique\n"
	"	# 03C1 lettre minuscule grecque rhô"},
/* 03F2 */ { "SYMBOLE GREC SIGMA LUNAIRE","	= lettre minuscule grecque sigma lunaire (1.0)\n"
	"	# 03C2 lettre minuscule grecque sigma final"},
/* 03F3 */ { "LETTRE GRECQUE YOT","	* la majuscule est 037F"},
/* 03F4 */ { "SYMBOLE GREC THÊTA MAJUSCULE","	x (lettre majuscule cyrillique fita - 0472)\n"
	"	# 0398 lettre majuscule grecque thêta"},
/* 03F5 */ { "SYMBOLE GREC EPSILON LUNAIRE","	= epsilon droit\n"
	"	x (petit appartient à - 220A)\n"
	"	# 03B5 lettre minuscule grecque epsilon"},
/* 03F6 */ { "SYMBOLE GREC EPSILON LUNAIRE RÉFLÉCHI","	= epsilon droit réfléchi\n"
	"	x (petit contient comme élément - 220D)"},
/* 03F7 */ { "LETTRE MAJUSCULE GRECQUE CHO",NULL},
/* 03F8 */ { "LETTRE MINUSCULE GRECQUE CHO",NULL},
/* 03F9 */ { "SYMBOLE GREC SIGMA LUNAIRE MAJUSCULE","	# 03A3 lettre majuscule grecque sigma"},
/* 03FA */ { "LETTRE MAJUSCULE GRECQUE SAN",NULL},
/* 03FB */ { "LETTRE MINUSCULE GRECQUE SAN",NULL},
/* 03FC */ { "SYMBOLE GREC RHÔ BARRÉ","	* utilisé avec des abréviations qui contiennent 03C1"},
/* 03FD */ { "SYMBOLE GREC SIGMA LUNAIRE MAJUSCULE RÉFLÉCHI","	= antisigma\n"
	"	* indique qu'une ligne d'un texte se trouve à une position incorrecte"},
/* 03FE */ { "SYMBOLE GREC SIGMA LUNAIRE MAJUSCULE POINTÉ","	= sigma périestigmenon\n"
	"	* indique qu'un réarrangement doit être effectué"},
/* 03FF */ { "SYMBOLE GREC SIGMA LUNAIRE MAJUSCULE POINTÉ RÉFLÉCHI","	= antisigma périestigmenon\n"
	"	* indique que les lignes qui succèdent à ce symbole doivent être déplacées à l'endroit marqué par 03FE"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_04[] = {
/* 0400 */ { "LETTRE MAJUSCULE CYRILLIQUE IÉ ACCENT GRAVE","	: 0415 0300"},
/* 0401 */ { "LETTRE MAJUSCULE CYRILLIQUE IO","	: 0415 0308"},
/* 0402 */ { "LETTRE MAJUSCULE CYRILLIQUE DIÉ",NULL},
/* 0403 */ { "LETTRE MAJUSCULE CYRILLIQUE GUIÉ","	: 0413 0301"},
/* 0404 */ { "LETTRE MAJUSCULE CYRILLIQUE IÉ UKRAINIEN",NULL},
/* 0405 */ { "LETTRE MAJUSCULE CYRILLIQUE DZÉ",NULL},
/* 0406 */ { "LETTRE MAJUSCULE CYRILLIQUE I BIÉLORUSSE-UKRAINIEN","	x (lettre majuscule latine i - 0049)\n"
	"	x (lettre minuscule cyrillique i biélorusse-ukrainien - 0456)\n"
	"	x (lettre cyrillique palotchka - 04C0)"},
/* 0407 */ { "LETTRE MAJUSCULE CYRILLIQUE YI","	: 0406 0308"},
/* 0408 */ { "LETTRE MAJUSCULE CYRILLIQUE YÉ",NULL},
/* 0409 */ { "LETTRE MAJUSCULE CYRILLIQUE LIÉ",NULL},
/* 040A */ { "LETTRE MAJUSCULE CYRILLIQUE NIÉ",NULL},
/* 040B */ { "LETTRE MAJUSCULE CYRILLIQUE TIÉ",NULL},
/* 040C */ { "LETTRE MAJUSCULE CYRILLIQUE KIÉ","	: 041A 0301"},
/* 040D */ { "LETTRE MAJUSCULE CYRILLIQUE I ACCENT GRAVE","	: 0418 0300"},
/* 040E */ { "LETTRE MAJUSCULE CYRILLIQUE OU BREF","	: 0423 0306"},
/* 040F */ { "LETTRE MAJUSCULE CYRILLIQUE DJÉ",NULL},
/* 0410 */ { "LETTRE MAJUSCULE CYRILLIQUE A",NULL},
/* 0411 */ { "LETTRE MAJUSCULE CYRILLIQUE BÉ","	x (lettre minuscule latine b potence - 0183)"},
/* 0412 */ { "LETTRE MAJUSCULE CYRILLIQUE VÉ",NULL},
/* 0413 */ { "LETTRE MAJUSCULE CYRILLIQUE GUÉ",NULL},
/* 0414 */ { "LETTRE MAJUSCULE CYRILLIQUE DÉ",NULL},
/* 0415 */ { "LETTRE MAJUSCULE CYRILLIQUE IÉ",NULL},
/* 0416 */ { "LETTRE MAJUSCULE CYRILLIQUE JÉ",NULL},
/* 0417 */ { "LETTRE MAJUSCULE CYRILLIQUE ZÉ",NULL},
/* 0418 */ { "LETTRE MAJUSCULE CYRILLIQUE I","		Cette lettre est également utilisée pour représenter la phonation électrolaryngée dans les symboles de qualité vocale pour l'API étendu."},
/* 0419 */ { "LETTRE MAJUSCULE CYRILLIQUE I BREF","	: 0418 0306"},
/* 041A */ { "LETTRE MAJUSCULE CYRILLIQUE KA",NULL},
/* 041B */ { "LETTRE MAJUSCULE CYRILLIQUE ELLE",NULL},
/* 041C */ { "LETTRE MAJUSCULE CYRILLIQUE EMME",NULL},
/* 041D */ { "LETTRE MAJUSCULE CYRILLIQUE ENNE",NULL},
/* 041E */ { "LETTRE MAJUSCULE CYRILLIQUE O",NULL},
/* 041F */ { "LETTRE MAJUSCULE CYRILLIQUE PÉ",NULL},
/* 0420 */ { "LETTRE MAJUSCULE CYRILLIQUE ERRE",NULL},
/* 0421 */ { "LETTRE MAJUSCULE CYRILLIQUE ESSE",NULL},
/* 0422 */ { "LETTRE MAJUSCULE CYRILLIQUE TÉ",NULL},
/* 0423 */ { "LETTRE MAJUSCULE CYRILLIQUE OU","	x (lettre majuscule cyrillique ouk - 0478)\n"
	"	x (lettre minuscule cyrillique ou droit - 04AF)\n"
	"	x (lettre majuscule cyrillique monogramme ouk - A64A)"},
/* 0424 */ { "LETTRE MAJUSCULE CYRILLIQUE EFFE",NULL},
/* 0425 */ { "LETTRE MAJUSCULE CYRILLIQUE KHA",NULL},
/* 0426 */ { "LETTRE MAJUSCULE CYRILLIQUE TSÉ",NULL},
/* 0427 */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ",NULL},
/* 0428 */ { "LETTRE MAJUSCULE CYRILLIQUE CHA",NULL},
/* 0429 */ { "LETTRE MAJUSCULE CYRILLIQUE CHTCHA",NULL},
/* 042A */ { "LETTRE MAJUSCULE CYRILLIQUE SIGNE DUR",NULL},
/* 042B */ { "LETTRE MAJUSCULE CYRILLIQUE YÉROU","	= i dur majuscule"},
/* 042C */ { "LETTRE MAJUSCULE CYRILLIQUE SIGNE MOU",NULL},
/* 042D */ { "LETTRE MAJUSCULE CYRILLIQUE É",NULL},
/* 042E */ { "LETTRE MAJUSCULE CYRILLIQUE IOU",NULL},
/* 042F */ { "LETTRE MAJUSCULE CYRILLIQUE IA",NULL},
/* 0430 */ { "LETTRE MINUSCULE CYRILLIQUE A",NULL},
/* 0431 */ { "LETTRE MINUSCULE CYRILLIQUE BÉ",NULL},
/* 0432 */ { "LETTRE MINUSCULE CYRILLIQUE VÉ",NULL},
/* 0433 */ { "LETTRE MINUSCULE CYRILLIQUE GUÉ",NULL},
/* 0434 */ { "LETTRE MINUSCULE CYRILLIQUE DÉ",NULL},
/* 0435 */ { "LETTRE MINUSCULE CYRILLIQUE IÉ",NULL},
/* 0436 */ { "LETTRE MINUSCULE CYRILLIQUE JÉ",NULL},
/* 0437 */ { "LETTRE MINUSCULE CYRILLIQUE ZÉ",NULL},
/* 0438 */ { "LETTRE MINUSCULE CYRILLIQUE I",NULL},
/* 0439 */ { "LETTRE MINUSCULE CYRILLIQUE I BREF","	: 0438 0306"},
/* 043A */ { "LETTRE MINUSCULE CYRILLIQUE KA",NULL},
/* 043B */ { "LETTRE MINUSCULE CYRILLIQUE ELLE",NULL},
/* 043C */ { "LETTRE MINUSCULE CYRILLIQUE EMME",NULL},
/* 043D */ { "LETTRE MINUSCULE CYRILLIQUE ENNE",NULL},
/* 043E */ { "LETTRE MINUSCULE CYRILLIQUE O",NULL},
/* 043F */ { "LETTRE MINUSCULE CYRILLIQUE PÉ",NULL},
/* 0440 */ { "LETTRE MINUSCULE CYRILLIQUE ERRE",NULL},
/* 0441 */ { "LETTRE MINUSCULE CYRILLIQUE ESSE",NULL},
/* 0442 */ { "LETTRE MINUSCULE CYRILLIQUE TÉ",NULL},
/* 0443 */ { "LETTRE MINUSCULE CYRILLIQUE OU",NULL},
/* 0444 */ { "LETTRE MINUSCULE CYRILLIQUE EFFE",NULL},
/* 0445 */ { "LETTRE MINUSCULE CYRILLIQUE KHA",NULL},
/* 0446 */ { "LETTRE MINUSCULE CYRILLIQUE TSÉ",NULL},
/* 0447 */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ",NULL},
/* 0448 */ { "LETTRE MINUSCULE CYRILLIQUE CHA",NULL},
/* 0449 */ { "LETTRE MINUSCULE CYRILLIQUE CHTCHA",NULL},
/* 044A */ { "LETTRE MINUSCULE CYRILLIQUE SIGNE DUR",NULL},
/* 044B */ { "LETTRE MINUSCULE CYRILLIQUE YÉROU","	= i dur minuscule\n"
	"	x (lettre minuscule cyrillique yérou à yer postérieur - A651)"},
/* 044C */ { "LETTRE MINUSCULE CYRILLIQUE SIGNE MOU","	x (lettre minuscule latine sixième ton - 0185)\n"
	"	x (lettre minuscule cyrillique yer neutre - A64F)"},
/* 044D */ { "LETTRE MINUSCULE CYRILLIQUE É",NULL},
/* 044E */ { "LETTRE MINUSCULE CYRILLIQUE IOU","	x (lettre minuscule cyrillique iou réfléchi - A655)"},
/* 044F */ { "LETTRE MINUSCULE CYRILLIQUE IA",NULL},
/* 0450 */ { "LETTRE MINUSCULE CYRILLIQUE IÉ ACCENT GRAVE","	* macédonien\n"
	"	: 0435 0300"},
/* 0451 */ { "LETTRE MINUSCULE CYRILLIQUE IO","	* russe, etc.\n"
	"	: 0435 0308"},
/* 0452 */ { "LETTRE MINUSCULE CYRILLIQUE DIÉ","	* serbe\n"
	"	* équivalent dans l'alphabet latin de Gaj : đ\n"
	"	* couramment transcrite par « dj » en français et dans d'autres langues\n"
	"	x (lettre minuscule latine d barré - 0111)"},
/* 0453 */ { "LETTRE MINUSCULE CYRILLIQUE GUIÉ","	* macédonien\n"
	"	: 0433 0301"},
/* 0454 */ { "LETTRE MINUSCULE CYRILLIQUE IÉ UKRAINIEN","	= ieste vieux cyrillique"},
/* 0455 */ { "LETTRE MINUSCULE CYRILLIQUE DZÉ","	* macédonien\n"
	"	x (lettre minuscule cyrillique dzélo - A643)"},
/* 0456 */ { "LETTRE MINUSCULE CYRILLIQUE I BIÉLORUSSE-UKRAINIEN","	= i vieux cyrillique"},
/* 0457 */ { "LETTRE MINUSCULE CYRILLIQUE YI","	* ukrainien\n"
	"	: 0456 0308"},
/* 0458 */ { "LETTRE MINUSCULE CYRILLIQUE YÉ","	* serbe, azéri, altaï"},
/* 0459 */ { "LETTRE MINUSCULE CYRILLIQUE LIÉ","	* serbe, macédonien\n"
	"	x (lettre minuscule latine lj - 01C9)"},
/* 045A */ { "LETTRE MINUSCULE CYRILLIQUE NIÉ","	* serbe, macédonien\n"
	"	x (lettre minuscule latine nj - 01CC)"},
/* 045B */ { "LETTRE MINUSCULE CYRILLIQUE TIÉ","	* serbe\n"
	"	x (lettre minuscule latine c accent aigu - 0107)\n"
	"	x (lettre minuscule latine h barré - 0127)\n"
	"	x (lettre majuscule cyrillique tié - 040B)\n"
	"	x (constante de planck sur deux pi - 210F)\n"
	"	x (lettre minuscule cyrillique dierv - A649)"},
/* 045C */ { "LETTRE MINUSCULE CYRILLIQUE KIÉ","	* macédonien\n"
	"	: 043A 0301"},
/* 045D */ { "LETTRE MINUSCULE CYRILLIQUE I ACCENT GRAVE","	* macédonien, bulgare\n"
	"	: 0438 0300"},
/* 045E */ { "LETTRE MINUSCULE CYRILLIQUE OU BREF","	* biélorusse, ouzbek\n"
	"	: 0443 0306"},
/* 045F */ { "LETTRE MINUSCULE CYRILLIQUE DJÉ","	* serbe, macédonien, abkhaze\n"
	"	* équivalent dans l'alphabet latin de Gaj : dž\n"
	"	* couramment transcrite par « dz » en français et dans d'autres langues\n"
	"	x (lettre minuscule latine dz caron - 01C6)"},
/* 0460 */ { "LETTRE MAJUSCULE CYRILLIQUE OMÉGA",NULL},
/* 0461 */ { "LETTRE MINUSCULE CYRILLIQUE OMÉGA","	x (lettre minuscule cyrillique oméga large - A64D)"},
/* 0462 */ { "LETTRE MAJUSCULE CYRILLIQUE IAT",NULL},
/* 0463 */ { "LETTRE MINUSCULE CYRILLIQUE IAT","	x (lettre minuscule cyrillique iat yodisé - A653)\n"
	"	x (lettre latine minuscule iat sakha - AB60)"},
/* 0464 */ { "LETTRE MAJUSCULE CYRILLIQUE É YODISÉ",NULL},
/* 0465 */ { "LETTRE MINUSCULE CYRILLIQUE É YODISÉ","	x (lettre latine minuscule é yodisé - AB61)"},
/* 0466 */ { "LETTRE MAJUSCULE CYRILLIQUE PETIT IOUSSE",NULL},
/* 0467 */ { "LETTRE MINUSCULE CYRILLIQUE PETIT IOUSSE","	x (lettre minuscule cyrillique petit iousse fermé - A659)\n"
	"	x (lettre minuscule cyrillique iousse fusionné - A65B)"},
/* 0468 */ { "LETTRE MAJUSCULE CYRILLIQUE PETIT IOUSSE YODISÉ",NULL},
/* 0469 */ { "LETTRE MINUSCULE CYRILLIQUE PETIT IOUSSE YODISÉ","	x (lettre minuscule cyrillique ia - 044F)\n"
	"	x (lettre minuscule cyrillique petit iousse yodisé fermé - A65D)"},
/* 046A */ { "LETTRE MAJUSCULE CYRILLIQUE GRAND IOUSSE",NULL},
/* 046B */ { "LETTRE MINUSCULE CYRILLIQUE GRAND IOUSSE","	x (lettre minuscule cyrillique iousse fusionné - A65B)"},
/* 046C */ { "LETTRE MAJUSCULE CYRILLIQUE GRAND IOUSSE YODISÉ",NULL},
/* 046D */ { "LETTRE MINUSCULE CYRILLIQUE GRAND IOUSSE YODISÉ",NULL},
/* 046E */ { "LETTRE MAJUSCULE CYRILLIQUE KSI",NULL},
/* 046F */ { "LETTRE MINUSCULE CYRILLIQUE KSI",NULL},
/* 0470 */ { "LETTRE MAJUSCULE CYRILLIQUE PSI",NULL},
/* 0471 */ { "LETTRE MINUSCULE CYRILLIQUE PSI",NULL},
/* 0472 */ { "LETTRE MAJUSCULE CYRILLIQUE FITA",NULL},
/* 0473 */ { "LETTRE MINUSCULE CYRILLIQUE FITA","	x (lettre minuscule latine o barré - 0275)\n"
	"	x (lettre minuscule grecque thêta - 03B8)"},
/* 0474 */ { "LETTRE MAJUSCULE CYRILLIQUE IJITSA",NULL},
/* 0475 */ { "LETTRE MINUSCULE CYRILLIQUE IJITSA",NULL},
/* 0476 */ { "LETTRE MAJUSCULE CYRILLIQUE IJITSA DOUBLE ACCENT GRAVE","	: 0474 030F"},
/* 0477 */ { "LETTRE MINUSCULE CYRILLIQUE IJITSA DOUBLE ACCENT GRAVE","	: 0475 030F"},
/* 0478 */ { "LETTRE MAJUSCULE CYRILLIQUE OUK","	* pour le « digramme onik », l'orthographe recommandée est 041E 0443\n"
	"	* pour le « monogramme ouk », le caractère recommandé est A64A\n"
	"	x (lettre majuscule cyrillique ou - 0423)"},
/* 0479 */ { "LETTRE MINUSCULE CYRILLIQUE OUK","	* pour le « digramme onik », l'orthographe recommandée est 043E 0443\n"
	"	* pour le « monogramme ouk », le caractère recommandé est A64B"},
/* 047A */ { "LETTRE MAJUSCULE CYRILLIQUE OMÉGA ROND",NULL},
/* 047B */ { "LETTRE MINUSCULE CYRILLIQUE OMÉGA ROND",NULL},
/* 047C */ { "LETTRE MAJUSCULE CYRILLIQUE OMÉGA TITLO","	= « bel oméga » cyrillique\n"
	"	* en dépit de son nom, ce caractère n'a pas de titlo et n'est pas constitué d'un oméga muni d'un diacritique\n"
	"	x (lettre majuscule cyrillique oméga large - A64C)"},
/* 047D */ { "LETTRE MINUSCULE CYRILLIQUE OMÉGA TITLO","	x (lettre minuscule grecque oméga esprit doux et circonflexe - 1F66)"},
/* 047E */ { "LETTRE MAJUSCULE CYRILLIQUE OMÉGA TÉ",NULL},
/* 047F */ { "LETTRE MINUSCULE CYRILLIQUE OMÉGA TÉ","	= lettre cyrillique ot"},
/* 0480 */ { "LETTRE MAJUSCULE CYRILLIQUE KOPPA",NULL},
/* 0481 */ { "LETTRE MINUSCULE CYRILLIQUE KOPPA",NULL},
/* 0482 */ { "SIGNE CYRILLIQUE MILLIERS",NULL},
/* 0483 */ { "DIACRITIQUE CYRILLIQUE TITLO","	* n'est pas utilisé avec les lettres 047C et 047D\n"
	"	x (diacritique cyrillique vzmet - A66F)"},
/* 0484 */ { "DIACRITIQUE CYRILLIQUE DE PALATALISATION","	* n'est pas utilisé pour le signe kamora (accent circonflexe cyrillique)\n"
	"	x (lettre modificative apostrophe - 02BC)\n"
	"	x (diacritique brève renversée - 0311)"},
/* 0485 */ { "DIACRITIQUE CYRILLIQUE DASIA PNEUMATA","	x (diacritique virgule réfléchie en chef - 0314)\n"
	"	x (diacritique taquet á droite en chef - 1AE1)\n"
	"	x (diacritique copte esprit rude - 2CF0)"},
/* 0486 */ { "DIACRITIQUE CYRILLIQUE PSILI PNEUMATA","	x (diacritique virgule en chef - 0313)\n"
	"	x (diacritique taquet à gauche en chef - 1AE0)\n"
	"	x (diacritique copte esprit doux - 2CF1)"},
/* 0487 */ { "DIACRITIQUE CYRILLIQUE POKRYTIÉ","	* utilisé seulement avec les lettres 047C et 047D\n"
	"	* attesté également en glagolitique\n"
	"	x (diacritique brève renversée - 0311)\n"
	"	x (diacritique cyrillique vzmet - A66F)"},
/* 0488 */ { "DIACRITIQUE CYRILLIQUE CENTAINES DE MILLIERS","	* utilisez 20DD pour le signe dizaines de milliers"},
/* 0489 */ { "DIACRITIQUE CYRILLIQUE MILLIONS","	x (diacritique cyrillique dizaines de millions - A670)"},
/* 048A */ { "LETTRE MAJUSCULE CYRILLIQUE I BREF À QUEUE",NULL},
/* 048B */ { "LETTRE MINUSCULE CYRILLIQUE I BREF À QUEUE","	* same de Kildin"},
/* 048C */ { "LETTRE MAJUSCULE CYRILLIQUE SIGNE SEMI-MOU",NULL},
/* 048D */ { "LETTRE MINUSCULE CYRILLIQUE SIGNE SEMI-MOU","	* same de Kildin"},
/* 048E */ { "LETTRE MAJUSCULE CYRILLIQUE ERRE AGRAFÉ",NULL},
/* 048F */ { "LETTRE MINUSCULE CYRILLIQUE ERRE AGRAFÉ","	* same de Kildin"},
/* 0490 */ { "LETTRE MAJUSCULE CYRILLIQUE GUÉ HAMPÉ",NULL},
/* 0491 */ { "LETTRE MINUSCULE CYRILLIQUE GUÉ HAMPÉ","	* ukrainien"},
/* 0492 */ { "LETTRE MAJUSCULE CYRILLIQUE GUÉ BARRÉ",NULL},
/* 0493 */ { "LETTRE MINUSCULE CYRILLIQUE GUÉ BARRÉ","	* azéri, bachkir, etc.\n"
	"	* la forme à barre transversale est recommandée au détriment de celle à demi-barre ressemblant à un F"},
/* 0494 */ { "LETTRE MAJUSCULE CYRILLIQUE GUÉ CROCHET MÉDIAN",NULL},
/* 0495 */ { "LETTRE MINUSCULE CYRILLIQUE GUÉ CROCHET MÉDIAN","	* iakoute, formes anciennes de l'abkhaze"},
/* 0496 */ { "LETTRE MAJUSCULE CYRILLIQUE JÉ CRAMPON",NULL},
/* 0497 */ { "LETTRE MINUSCULE CYRILLIQUE JÉ CRAMPON","	* tatar, etc."},
/* 0498 */ { "LETTRE MAJUSCULE CYRILLIQUE ZÉ CRAMPON",NULL},
/* 0499 */ { "LETTRE MINUSCULE CYRILLIQUE ZÉ CRAMPON","	* bachkir\n"
	"	* les formes à crochet vers la droite sont privilégiées, bien que l'on rencontre parfois des formes à crochet vers la gauche"},
/* 049A */ { "LETTRE MAJUSCULE CYRILLIQUE KA CRAMPON",NULL},
/* 049B */ { "LETTRE MINUSCULE CYRILLIQUE KA CRAMPON","	* abkhaze, tadjik, etc."},
/* 049C */ { "LETTRE MAJUSCULE CYRILLIQUE KA BARRE VERTICALE",NULL},
/* 049D */ { "LETTRE MINUSCULE CYRILLIQUE KA BARRE VERTICALE","	* azéri"},
/* 049E */ { "LETTRE MAJUSCULE CYRILLIQUE KA BARRÉ",NULL},
/* 049F */ { "LETTRE MINUSCULE CYRILLIQUE KA BARRÉ","	* abkhaze"},
/* 04A0 */ { "LETTRE MAJUSCULE CYRILLIQUE KA BACHKIR",NULL},
/* 04A1 */ { "LETTRE MINUSCULE CYRILLIQUE KA BACHKIR",NULL},
/* 04A2 */ { "LETTRE MAJUSCULE CYRILLIQUE ENNE CRAMPON",NULL},
/* 04A3 */ { "LETTRE MINUSCULE CYRILLIQUE ENNE CRAMPON","	* bachkir, etc."},
/* 04A4 */ { "LIGATURE MAJUSCULE CYRILLIQUE ENG",NULL},
/* 04A5 */ { "LIGATURE MINUSCULE CYRILLIQUE ENG","	* altaï, mari (ou tchérémisse), iakoute\n"
	"	* également utilisée pour le enne doux en vieux slave\n"
	"	* il s'agit d'une ligature non décomposable"},
/* 04A6 */ { "LETTRE MAJUSCULE CYRILLIQUE PÉ CROCHET MÉDIAN",NULL},
/* 04A7 */ { "LETTRE MINUSCULE CYRILLIQUE PÉ CROCHET MÉDIAN","	* formes anciennes de l'abkhaze"},
/* 04A8 */ { "LETTRE MAJUSCULE CYRILLIQUE KHA ABKHAZE",NULL},
/* 04A9 */ { "LETTRE MINUSCULE CYRILLIQUE KHA ABKHAZE",NULL},
/* 04AA */ { "LETTRE MAJUSCULE CYRILLIQUE ESSE CRAMPON",NULL},
/* 04AB */ { "LETTRE MINUSCULE CYRILLIQUE ESSE CRAMPON","	* bachkir, tchouvache\n"
	"	* les formes à crochet vers la droite sont privilégiées, bien que l'on rencontre parfois des formes à crochet vers la gauche\n"
	"	* en Tchouvachie, on rencontre souvent des formes identiques ou similaires à 00E7"},
/* 04AC */ { "LETTRE MAJUSCULE CYRILLIQUE TÉ CRAMPON",NULL},
/* 04AD */ { "LETTRE MINUSCULE CYRILLIQUE TÉ CRAMPON","	* abkhaze"},
/* 04AE */ { "LETTRE MAJUSCULE CYRILLIQUE OU DROIT",NULL},
/* 04AF */ { "LETTRE MINUSCULE CYRILLIQUE OU DROIT","	* le jambage est droit, contrairement à celui de la LETTRE OU\n"
	"	* azéri, bachkir, etc.\n"
	"	x (lettre majuscule cyrillique ou - 0423)"},
/* 04B0 */ { "LETTRE MAJUSCULE CYRILLIQUE OU DROIT BARRÉ",NULL},
/* 04B1 */ { "LETTRE MINUSCULE CYRILLIQUE OU DROIT BARRÉ","	* kazakh"},
/* 04B2 */ { "LETTRE MAJUSCULE CYRILLIQUE KHA CRAMPON",NULL},
/* 04B3 */ { "LETTRE MINUSCULE CYRILLIQUE KHA CRAMPON","	* abkhaze, tadjik, ouzbek"},
/* 04B4 */ { "LIGATURE MAJUSCULE CYRILLIQUE TÉ TSÉ",NULL},
/* 04B5 */ { "LIGATURE MINUSCULE CYRILLIQUE TÉ TSÉ","	* abkhaze\n"
	"	* il s'agit d'une ligature non décomposable"},
/* 04B6 */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ CRAMPON",NULL},
/* 04B7 */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ CRAMPON","	* abkhaze, tadjik"},
/* 04B8 */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ BARRE VERTICALE",NULL},
/* 04B9 */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ BARRE VERTICALE","	* azéri"},
/* 04BA */ { "LETTRE MAJUSCULE CYRILLIQUE HÉ",NULL},
/* 04BB */ { "LETTRE MINUSCULE CYRILLIQUE HÉ","	* dérivé à l'origine d'un « h » latin, mais la majuscule 04BA est plus proche d'un tché renversé (0427)\n"
	"	* azéri, bachkir, etc.\n"
	"	x (lettre minuscule latine h - 0068)"},
/* 04BC */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ ABKHAZE",NULL},
/* 04BD */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ ABKHAZE",NULL},
/* 04BE */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ CRAMPON ABKHAZE",NULL},
/* 04BF */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ CRAMPON ABKHAZE","	* certaines polices abkhazes anciennes montrent un appendice représenté comme un ogonek ou une virgule réfléchie"},
/* 04C0 */ { "LETTRE CYRILLIQUE PALOTCHKA","	* signe d'aspiration pour de nombreuses langues caucasiennes\n"
	"	* n'a habituellement pas de variante de casse, mais sa minuscule officielle est 04CF\n"
	"	x (lettre majuscule latine i - 0049)\n"
	"	x (lettre majuscule cyrillique i biélorusse-ukrainien - 0406)"},
/* 04C1 */ { "LETTRE MAJUSCULE CYRILLIQUE JÉ BRÈVE","	: 0416 0306"},
/* 04C2 */ { "LETTRE MINUSCULE CYRILLIQUE JÉ BRÈVE","	* moldave\n"
	"	: 0436 0306"},
/* 04C3 */ { "LETTRE MAJUSCULE CYRILLIQUE KA HAMEÇON",NULL},
/* 04C4 */ { "LETTRE MINUSCULE CYRILLIQUE KA HAMEÇON","	* tchouktche"},
/* 04C5 */ { "LETTRE MAJUSCULE CYRILLIQUE ELLE À QUEUE",NULL},
/* 04C6 */ { "LETTRE MINUSCULE CYRILLIQUE ELLE À QUEUE","	* same de Kildin"},
/* 04C7 */ { "LETTRE MAJUSCULE CYRILLIQUE ENNE HAMEÇON",NULL},
/* 04C8 */ { "LETTRE MINUSCULE CYRILLIQUE ENNE HAMEÇON","	* tchouktche"},
/* 04C9 */ { "LETTRE MAJUSCULE CYRILLIQUE ENNE À QUEUE",NULL},
/* 04CA */ { "LETTRE MINUSCULE CYRILLIQUE ENNE À QUEUE","	* same de Kildin"},
/* 04CB */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ KHAKASSE",NULL},
/* 04CC */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ KHAKASSE",NULL},
/* 04CD */ { "LETTRE MAJUSCULE CYRILLIQUE EMME À QUEUE",NULL},
/* 04CE */ { "LETTRE MINUSCULE CYRILLIQUE EMME À QUEUE","	* same de Kildin"},
/* 04CF */ { "LETTRE MINUSCULE CYRILLIQUE PALOTCHKA",NULL},
/* 04D0 */ { "LETTRE MAJUSCULE CYRILLIQUE A BRÈVE","	: 0410 0306"},
/* 04D1 */ { "LETTRE MINUSCULE CYRILLIQUE A BRÈVE","	: 0430 0306"},
/* 04D2 */ { "LETTRE MAJUSCULE CYRILLIQUE A TRÉMA","	: 0410 0308"},
/* 04D3 */ { "LETTRE MINUSCULE CYRILLIQUE A TRÉMA","	: 0430 0308"},
/* 04D4 */ { "LIGATURE MAJUSCULE CYRILLIQUE A IÉ",NULL},
/* 04D5 */ { "LIGATURE MINUSCULE CYRILLIQUE A IÉ","	= ié dans l'a\n"
	"	* il s'agit d'une ligature non décomposable\n"
	"	x (lettre minuscule latine ae - 00E6)"},
/* 04D6 */ { "LETTRE MAJUSCULE CYRILLIQUE IÉ BRÈVE","	: 0415 0306"},
/* 04D7 */ { "LETTRE MINUSCULE CYRILLIQUE IÉ BRÈVE","	: 0435 0306"},
/* 04D8 */ { "LETTRE MAJUSCULE CYRILLIQUE SCHWA",NULL},
/* 04D9 */ { "LETTRE MINUSCULE CYRILLIQUE SCHWA","	x (lettre minuscule latine schwa - 0259)"},
/* 04DA */ { "LETTRE MAJUSCULE CYRILLIQUE SCHWA TRÉMA","	: 04D8 0308"},
/* 04DB */ { "LETTRE MINUSCULE CYRILLIQUE SCHWA TRÉMA","	: 04D9 0308"},
/* 04DC */ { "LETTRE MAJUSCULE CYRILLIQUE JÉ TRÉMA","	: 0416 0308"},
/* 04DD */ { "LETTRE MINUSCULE CYRILLIQUE JÉ TRÉMA","	: 0436 0308"},
/* 04DE */ { "LETTRE MAJUSCULE CYRILLIQUE ZÉ TRÉMA","	: 0417 0308"},
/* 04DF */ { "LETTRE MINUSCULE CYRILLIQUE ZÉ TRÉMA","	: 0437 0308"},
/* 04E0 */ { "LETTRE MAJUSCULE CYRILLIQUE DZÉ ABKHAZE",NULL},
/* 04E1 */ { "LETTRE MINUSCULE CYRILLIQUE DZÉ ABKHAZE","	x (lettre minuscule latine ej - 0292)"},
/* 04E2 */ { "LETTRE MAJUSCULE CYRILLIQUE I MACRON","	: 0418 0304"},
/* 04E3 */ { "LETTRE MINUSCULE CYRILLIQUE I MACRON","	: 0438 0304"},
/* 04E4 */ { "LETTRE MAJUSCULE CYRILLIQUE I TRÉMA","	: 0418 0308"},
/* 04E5 */ { "LETTRE MINUSCULE CYRILLIQUE I TRÉMA","	: 0438 0308"},
/* 04E6 */ { "LETTRE MAJUSCULE CYRILLIQUE O TRÉMA","	: 041E 0308"},
/* 04E7 */ { "LETTRE MINUSCULE CYRILLIQUE O TRÉMA","	: 043E 0308"},
/* 04E8 */ { "LETTRE MAJUSCULE CYRILLIQUE O BARRÉ",NULL},
/* 04E9 */ { "LETTRE MINUSCULE CYRILLIQUE O BARRÉ","	x (lettre minuscule latine o barré - 0275)"},
/* 04EA */ { "LETTRE MAJUSCULE CYRILLIQUE O BARRÉ TRÉMA","	: 04E8 0308"},
/* 04EB */ { "LETTRE MINUSCULE CYRILLIQUE O BARRÉ TRÉMA","	: 04E9 0308"},
/* 04EC */ { "LETTRE MAJUSCULE CYRILLIQUE É TRÉMA","	: 042D 0308"},
/* 04ED */ { "LETTRE MINUSCULE CYRILLIQUE É TRÉMA","	* same de Kildin\n"
	"	: 044D 0308"},
/* 04EE */ { "LETTRE MAJUSCULE CYRILLIQUE OU MACRON","	: 0423 0304"},
/* 04EF */ { "LETTRE MINUSCULE CYRILLIQUE OU MACRON","	: 0443 0304"},
/* 04F0 */ { "LETTRE MAJUSCULE CYRILLIQUE OU TRÉMA","	: 0423 0308"},
/* 04F1 */ { "LETTRE MINUSCULE CYRILLIQUE OU TRÉMA","	: 0443 0308"},
/* 04F2 */ { "LETTRE MAJUSCULE CYRILLIQUE OU DOUBLE ACCENT AIGU","	: 0423 030B"},
/* 04F3 */ { "LETTRE MINUSCULE CYRILLIQUE OU DOUBLE ACCENT AIGU","	: 0443 030B"},
/* 04F4 */ { "LETTRE MAJUSCULE CYRILLIQUE TCHÉ TRÉMA","	: 0427 0308"},
/* 04F5 */ { "LETTRE MINUSCULE CYRILLIQUE TCHÉ TRÉMA","	: 0447 0308"},
/* 04F6 */ { "LETTRE MAJUSCULE CYRILLIQUE GUÉ CRAMPON",NULL},
/* 04F7 */ { "LETTRE MINUSCULE CYRILLIQUE GUÉ CRAMPON","	* youpik"},
/* 04F8 */ { "LETTRE MAJUSCULE CYRILLIQUE YÉROU TRÉMA","	: 042B 0308"},
/* 04F9 */ { "LETTRE MINUSCULE CYRILLIQUE YÉROU TRÉMA","	: 044B 0308"},
/* 04FA */ { "LETTRE MAJUSCULE CYRILLIQUE GUÉ BARRÉ HAMEÇON",NULL},
/* 04FB */ { "LETTRE MINUSCULE CYRILLIQUE GUÉ BARRÉ HAMEÇON",NULL},
/* 04FC */ { "LETTRE MAJUSCULE CYRILLIQUE KHA HAMEÇON",NULL},
/* 04FD */ { "LETTRE MINUSCULE CYRILLIQUE KHA HAMEÇON",NULL},
/* 04FE */ { "LETTRE MAJUSCULE CYRILLIQUE KHA BARRÉ",NULL},
/* 04FF */ { "LETTRE MINUSCULE CYRILLIQUE KHA BARRÉ",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_05[] = {
/* 0500 */ { "LETTRE MAJUSCULE CYRILLIQUE DÉ KOMI",NULL},
/* 0501 */ { "LETTRE MINUSCULE CYRILLIQUE DÉ KOMI",NULL},
/* 0502 */ { "LETTRE MAJUSCULE CYRILLIQUE DIÉ KOMI",NULL},
/* 0503 */ { "LETTRE MINUSCULE CYRILLIQUE DIÉ KOMI",NULL},
/* 0504 */ { "LETTRE MAJUSCULE CYRILLIQUE ZIÉ KOMI",NULL},
/* 0505 */ { "LETTRE MINUSCULE CYRILLIQUE ZIÉ KOMI",NULL},
/* 0506 */ { "LETTRE MAJUSCULE CYRILLIQUE DZIÉ KOMI",NULL},
/* 0507 */ { "LETTRE MINUSCULE CYRILLIQUE DZIÉ KOMI",NULL},
/* 0508 */ { "LETTRE MAJUSCULE CYRILLIQUE LIÉ KOMI",NULL},
/* 0509 */ { "LETTRE MINUSCULE CYRILLIQUE LIÉ KOMI",NULL},
/* 050A */ { "LETTRE MAJUSCULE CYRILLIQUE NIÉ KOMI",NULL},
/* 050B */ { "LETTRE MINUSCULE CYRILLIQUE NIÉ KOMI",NULL},
/* 050C */ { "LETTRE MAJUSCULE CYRILLIQUE SIÉ KOMI",NULL},
/* 050D */ { "LETTRE MINUSCULE CYRILLIQUE SIÉ KOMI",NULL},
/* 050E */ { "LETTRE MAJUSCULE CYRILLIQUE TIÉ KOMI",NULL},
/* 050F */ { "LETTRE MINUSCULE CYRILLIQUE TIÉ KOMI","	x (lettre minuscule cyrillique té signe mou - 1C8A)\n"
	"		Ces lettres appartiennent à l’alphabet Molodtsov, utilisé dans les années 1920."},
/* 0510 */ { "LETTRE MAJUSCULE CYRILLIQUE ZÉ RÉFLÉCHI",NULL},
/* 0511 */ { "LETTRE MINUSCULE CYRILLIQUE ZÉ RÉFLÉCHI","	* aussi pour l'énetse"},
/* 0512 */ { "LETTRE MAJUSCULE CYRILLIQUE ELLE HAMEÇON",NULL},
/* 0513 */ { "LETTRE MINUSCULE CYRILLIQUE ELLE HAMEÇON","	* aussi pour l'itelmène"},
/* 0514 */ { "LETTRE MAJUSCULE CYRILLIQUE LHA",NULL},
/* 0515 */ { "LETTRE MINUSCULE CYRILLIQUE LHA","	= l sourd"},
/* 0516 */ { "LETTRE MAJUSCULE CYRILLIQUE RHA",NULL},
/* 0517 */ { "LETTRE MINUSCULE CYRILLIQUE RHA","	= r sourd"},
/* 0518 */ { "LETTRE MAJUSCULE CYRILLIQUE YÈ",NULL},
/* 0519 */ { "LETTRE MINUSCULE CYRILLIQUE YÈ",NULL},
/* 051A */ { "LETTRE MAJUSCULE CYRILLIQUE QA",NULL},
/* 051B */ { "LETTRE MINUSCULE CYRILLIQUE QA",NULL},
/* 051C */ { "LETTRE MAJUSCULE CYRILLIQUE WÉ",NULL},
/* 051D */ { "LETTRE MINUSCULE CYRILLIQUE WÉ",NULL},
/* 051E */ { "LETTRE MAJUSCULE CYRILLIQUE KA ALÉOUTE",NULL},
/* 051F */ { "LETTRE MINUSCULE CYRILLIQUE KA ALÉOUTE","	* pour [q] en aléoute"},
/* 0520 */ { "LETTRE MAJUSCULE CYRILLIQUE ELLE CROCHET MÉDIAN",NULL},
/* 0521 */ { "LETTRE MINUSCULE CYRILLIQUE ELLE CROCHET MÉDIAN","	= l palatalisé"},
/* 0522 */ { "LETTRE MAJUSCULE CYRILLIQUE ENNE CROCHET MÉDIAN",NULL},
/* 0523 */ { "LETTRE MINUSCULE CYRILLIQUE ENNE CROCHET MÉDIAN","	= n palatalisé"},
/* 0524 */ { "LETTRE MAJUSCULE CYRILLIQUE PÉ CRAMPON",NULL},
/* 0525 */ { "LETTRE MINUSCULE CYRILLIQUE PÉ CRAMPON","	* aussi dans l'orthographe abkhaze moderne\n"
	"	x (lettre minuscule cyrillique pé crochet médian - 04A7)"},
/* 0526 */ { "LETTRE MAJUSCULE CYRILLIQUE HÉ CRAMPON",NULL},
/* 0527 */ { "LETTRE MINUSCULE CYRILLIQUE HÉ CRAMPON",NULL},
/* 0528 */ { "LETTRE MAJUSCULE CYRILLIQUE ENNE HAMEÇON À GAUCHE",NULL},
/* 0529 */ { "LETTRE MINUSCULE CYRILLIQUE ENNE HAMEÇON À GAUCHE",NULL},
/* 052A */ { "LETTRE MAJUSCULE CYRILLIQUE DJJHÉ",NULL},
/* 052B */ { "LETTRE MINUSCULE CYRILLIQUE DJJHÉ","	* aussi pour l'ossète jusqu'en 1924"},
/* 052C */ { "LETTRE MAJUSCULE CYRILLIQUE DTCHÉ",NULL},
/* 052D */ { "LETTRE MINUSCULE CYRILLIQUE DTCHÉ",NULL},
/* 052E */ { "LETTRE MAJUSCULE CYRILLIQUE ELLE CRAMPON",NULL},
/* 052F */ { "LETTRE MINUSCULE CYRILLIQUE ELLE CRAMPON","	* aussi pour le nénetse"},
/* 0530 */ { NULL,NULL},
/* 0531 */ { "LETTRE MAJUSCULE ARMÉNIENNE AÏP",NULL},
/* 0532 */ { "LETTRE MAJUSCULE ARMÉNIENNE PÈN",NULL},
/* 0533 */ { "LETTRE MAJUSCULE ARMÉNIENNE KIM",NULL},
/* 0534 */ { "LETTRE MAJUSCULE ARMÉNIENNE TA",NULL},
/* 0535 */ { "LETTRE MAJUSCULE ARMÉNIENNE YÈTCH",NULL},
/* 0536 */ { "LETTRE MAJUSCULE ARMÉNIENNE ZA",NULL},
/* 0537 */ { "LETTRE MAJUSCULE ARMÉNIENNE É",NULL},
/* 0538 */ { "LETTRE MAJUSCULE ARMÉNIENNE ETT",NULL},
/* 0539 */ { "LETTRE MAJUSCULE ARMÉNIENNE TÔ",NULL},
/* 053A */ { "LETTRE MAJUSCULE ARMÉNIENNE JÉ",NULL},
/* 053B */ { "LETTRE MAJUSCULE ARMÉNIENNE INI",NULL},
/* 053C */ { "LETTRE MAJUSCULE ARMÉNIENNE LIOUN",NULL},
/* 053D */ { "LETTRE MAJUSCULE ARMÉNIENNE KHÉ",NULL},
/* 053E */ { "LETTRE MAJUSCULE ARMÉNIENNE DZA",NULL},
/* 053F */ { "LETTRE MAJUSCULE ARMÉNIENNE GUÉN",NULL},
/* 0540 */ { "LETTRE MAJUSCULE ARMÉNIENNE HÔ",NULL},
/* 0541 */ { "LETTRE MAJUSCULE ARMÉNIENNE TSA",NULL},
/* 0542 */ { "LETTRE MAJUSCULE ARMÉNIENNE GHAD",NULL},
/* 0543 */ { "LETTRE MAJUSCULE ARMÉNIENNE DJÉ",NULL},
/* 0544 */ { "LETTRE MAJUSCULE ARMÉNIENNE MÈN",NULL},
/* 0545 */ { "LETTRE MAJUSCULE ARMÉNIENNE HÎ",NULL},
/* 0546 */ { "LETTRE MAJUSCULE ARMÉNIENNE NOU",NULL},
/* 0547 */ { "LETTRE MAJUSCULE ARMÉNIENNE CHA",NULL},
/* 0548 */ { "LETTRE MAJUSCULE ARMÉNIENNE VO",NULL},
/* 0549 */ { "LETTRE MAJUSCULE ARMÉNIENNE TCHA",NULL},
/* 054A */ { "LETTRE MAJUSCULE ARMÉNIENNE BÉ",NULL},
/* 054B */ { "LETTRE MAJUSCULE ARMÉNIENNE DCHÉ",NULL},
/* 054C */ { "LETTRE MAJUSCULE ARMÉNIENNE RRA",NULL},
/* 054D */ { "LETTRE MAJUSCULE ARMÉNIENNE SÉ",NULL},
/* 054E */ { "LETTRE MAJUSCULE ARMÉNIENNE VÈV",NULL},
/* 054F */ { "LETTRE MAJUSCULE ARMÉNIENNE DIOUN",NULL},
/* 0550 */ { "LETTRE MAJUSCULE ARMÉNIENNE RÉ",NULL},
/* 0551 */ { "LETTRE MAJUSCULE ARMÉNIENNE TSÔ",NULL},
/* 0552 */ { "LETTRE MAJUSCULE ARMÉNIENNE HIOUN",NULL},
/* 0553 */ { "LETTRE MAJUSCULE ARMÉNIENNE PIOUR",NULL},
/* 0554 */ { "LETTRE MAJUSCULE ARMÉNIENNE KÉ",NULL},
/* 0555 */ { "LETTRE MAJUSCULE ARMÉNIENNE Ô",NULL},
/* 0556 */ { "LETTRE MAJUSCULE ARMÉNIENNE FÉ",NULL},
/* 0557 */ { NULL,NULL},
/* 0558 */ { NULL,NULL},
/* 0559 */ { "LETTRE MODIFICATIVE ARMÉNIENNE DEMI-ROND GAUCHE","	x (lettre modificative virgule réfléchie - 02BD)\n"
	"	x (lettre modificative demi-rond gauche - 02BF)\n"
	"	x (diacritique virgule réfléchie en chef - 0314)"},
/* 055A */ { "APOSTROPHE ARMÉNIENNE","	= lettre modificative arménienne demi-rond droit (1.0)\n"
	"	x (lettre modificative apostrophe - 02BC)\n"
	"	x (lettre modificative demi-rond droit - 02BE)\n"
	"	x (diacritique virgule en chef - 0313)"},
/* 055B */ { "SIGNE D'ACCENTUATION ARMÉNIEN","	= chèchte\n"
	"	x (lettre modificative accent aigu - 02CA)"},
/* 055C */ { "POINT D'EXCLAMATION ARMÉNIEN","	= batsagantchakane nchane\n"
	"	* il marque l'intonation sur un mot plutôt que d'apparaître en fin de phrase"},
/* 055D */ { "VIRGULE ARMÉNIENNE","	= booute\n"
	"	x (lettre modificative accent grave - 02CB)"},
/* 055E */ { "POINT D'INTERROGATION ARMÉNIEN","	= hartsakane nchane\n"
	"	* il marque l'intonation sur un mot plutôt que d'apparaître en fin de phrase"},
/* 055F */ { "SIGNE D'ABRÉVIATION ARMÉNIEN","	= patiou"},
/* 0560 */ { "LETTRE MINUSCULE ARMÉNIENNE AÏP CULBUTÉ","	* utilisée pour la notation phonétique"},
/* 0561 */ { "LETTRE MINUSCULE ARMÉNIENNE AÏP",NULL},
/* 0562 */ { "LETTRE MINUSCULE ARMÉNIENNE PÈN",NULL},
/* 0563 */ { "LETTRE MINUSCULE ARMÉNIENNE KIM",NULL},
/* 0564 */ { "LETTRE MINUSCULE ARMÉNIENNE TA",NULL},
/* 0565 */ { "LETTRE MINUSCULE ARMÉNIENNE YÈTCH",NULL},
/* 0566 */ { "LETTRE MINUSCULE ARMÉNIENNE ZA",NULL},
/* 0567 */ { "LETTRE MINUSCULE ARMÉNIENNE É",NULL},
/* 0568 */ { "LETTRE MINUSCULE ARMÉNIENNE ETT",NULL},
/* 0569 */ { "LETTRE MINUSCULE ARMÉNIENNE TÔ",NULL},
/* 056A */ { "LETTRE MINUSCULE ARMÉNIENNE JÉ",NULL},
/* 056B */ { "LETTRE MINUSCULE ARMÉNIENNE INI",NULL},
/* 056C */ { "LETTRE MINUSCULE ARMÉNIENNE LIOUN",NULL},
/* 056D */ { "LETTRE MINUSCULE ARMÉNIENNE KHÉ",NULL},
/* 056E */ { "LETTRE MINUSCULE ARMÉNIENNE DZA",NULL},
/* 056F */ { "LETTRE MINUSCULE ARMÉNIENNE GUÉN",NULL},
/* 0570 */ { "LETTRE MINUSCULE ARMÉNIENNE HÔ",NULL},
/* 0571 */ { "LETTRE MINUSCULE ARMÉNIENNE TSA",NULL},
/* 0572 */ { "LETTRE MINUSCULE ARMÉNIENNE GHAD",NULL},
/* 0573 */ { "LETTRE MINUSCULE ARMÉNIENNE DJÉ",NULL},
/* 0574 */ { "LETTRE MINUSCULE ARMÉNIENNE MÈN",NULL},
/* 0575 */ { "LETTRE MINUSCULE ARMÉNIENNE HÎ",NULL},
/* 0576 */ { "LETTRE MINUSCULE ARMÉNIENNE NOU",NULL},
/* 0577 */ { "LETTRE MINUSCULE ARMÉNIENNE CHA",NULL},
/* 0578 */ { "LETTRE MINUSCULE ARMÉNIENNE VO",NULL},
/* 0579 */ { "LETTRE MINUSCULE ARMÉNIENNE TCHA",NULL},
/* 057A */ { "LETTRE MINUSCULE ARMÉNIENNE BÉ",NULL},
/* 057B */ { "LETTRE MINUSCULE ARMÉNIENNE DCHÉ",NULL},
/* 057C */ { "LETTRE MINUSCULE ARMÉNIENNE RRA",NULL},
/* 057D */ { "LETTRE MINUSCULE ARMÉNIENNE SÉ",NULL},
/* 057E */ { "LETTRE MINUSCULE ARMÉNIENNE VÈV",NULL},
/* 057F */ { "LETTRE MINUSCULE ARMÉNIENNE DIOUN",NULL},
/* 0580 */ { "LETTRE MINUSCULE ARMÉNIENNE RÉ",NULL},
/* 0581 */ { "LETTRE MINUSCULE ARMÉNIENNE TSÔ",NULL},
/* 0582 */ { "LETTRE MINUSCULE ARMÉNIENNE HIOUN",NULL},
/* 0583 */ { "LETTRE MINUSCULE ARMÉNIENNE PIOUR",NULL},
/* 0584 */ { "LETTRE MINUSCULE ARMÉNIENNE KÉ",NULL},
/* 0585 */ { "LETTRE MINUSCULE ARMÉNIENNE Ô",NULL},
/* 0586 */ { "LETTRE MINUSCULE ARMÉNIENNE FÉ",NULL},
/* 0587 */ { "LIGATURE MINUSCULE ARMÉNIENNE YÈTCH HIOUN","	# 0565 0582"},
/* 0588 */ { "LETTRE MINUSCULE ARMÉNIENNE HÎ BARRÉ","	* utilisée pour la notation phonétique"},
/* 0589 */ { "POINT ARMÉNIEN","	= vertsakète\n"
	"	* peut être utilisé aussi dans des textes historiques géorgiens\n"
	"	x (deux-points - 003A)"},
/* 058A */ { "TRAIT D'UNION ARMÉNIEN","	= yentamna"},
/* 058B */ { NULL,NULL},
/* 058C */ { NULL,NULL},
/* 058D */ { "SIGNE ARMÉNIEN D'ÉTERNITÉ DEXTROGYRE",NULL},
/* 058E */ { "SIGNE ARMÉNIEN D'ÉTERNITÉ LÉVOGYRE","	* correspondance avec AST 34.005:1997"},
/* 058F */ { "SYMBOLE DRAM ARMÉNIEN",NULL},
/* 0590 */ { NULL,NULL},
/* 0591 */ { "ACCENT HÉBREU ATNAH","	= etnahta"},
/* 0592 */ { "ACCENT HÉBREU SEGOLTA","	= sègol"},
/* 0593 */ { "ACCENT HÉBREU CHALCHELET",NULL},
/* 0594 */ { "ACCENT HÉBREU ZAQEF QATON",NULL},
/* 0595 */ { "ACCENT HÉBREU ZAQEF GADOL",NULL},
/* 0596 */ { "ACCENT HÉBREU TARHA","	= tipha\n"
	"	= me'ayla ~ mayla"},
/* 0597 */ { "ACCENT HÉBREU RAVIA","	= revia, revi'i"},
/* 0598 */ { "ACCENT HÉBREU TSINNORIT","	* ce caractère doit être utilisé lorsque le zarqa, ou tsinnor, est suscrit (et centré)\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	x (accent hébreu zarqa - 05AE)"},
/* 0599 */ { "ACCENT HÉBREU PACHTA",NULL},
/* 059A */ { "ACCENT HÉBREU YETIV",NULL},
/* 059B */ { "ACCENT HÉBREU TEVIR",NULL},
/* 059C */ { "ACCENT HÉBREU GERICH","	= gerech, teres"},
/* 059D */ { "ACCENT HÉBREU GERICH MOUQDAM","	= gerech mouqdam"},
/* 059E */ { "ACCENT HÉBREU CHENÉ GRICHINE","	= gerchâïm"},
/* 059F */ { "ACCENT HÉBREU KARNÉ FARAH","	= pazer gadol"},
/* 05A0 */ { "ACCENT HÉBREU TALCHAH","	= telicha-gedolah"},
/* 05A1 */ { "ACCENT HÉBREU PAZER","	= pazer qatan"},
/* 05A2 */ { "ACCENT HÉBREU ATNAH HAFOUKH","	x (accent hébreu yaréah ben yomo - 05AA)"},
/* 05A3 */ { "ACCENT HÉBREU CHOFAR HOLEKH","	= mounah"},
/* 05A4 */ { "ACCENT HÉBREU CHOFAR MEHOUPPAKH","	= mahpakh"},
/* 05A5 */ { "ACCENT HÉBREU MÂRIKH","	= merkha\n"
	"	= yored"},
/* 05A6 */ { "ACCENT HÉBREU TERÉ TÂMÉ","	= merkha khefoulah"},
/* 05A7 */ { "ACCENT HÉBREU DARGA",NULL},
/* 05A8 */ { "ACCENT HÉBREU QADMA","	= azla"},
/* 05A9 */ { "ACCENT HÉBREU TARSA","	= telicha qetannah"},
/* 05AA */ { "ACCENT HÉBREU YARÉAH BEN YOMO","	= galgal\n"
	"	x (accent hébreu atnah hafoukh - 05A2)"},
/* 05AB */ { "ACCENT HÉBREU OLEH",NULL},
/* 05AC */ { "ACCENT HÉBREU ILOUZ",NULL},
/* 05AD */ { "ACCENT HÉBREU DEHI",NULL},
/* 05AE */ { "ACCENT HÉBREU ZARQA","	= tsinnor\n"
	"	* ce caractère doit être utilisé lorsque le zarqa, ou tsinnor, est suscrit à gauche\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	x (accent hébreu tsinnorit - 0598)"},
/* 05AF */ { "DIACRITIQUE HÉBREU CERCLE MASSORÉTIQUE",NULL},
/* 05B0 */ { "POINT HÉBREU CHEVA",NULL},
/* 05B1 */ { "POINT HÉBREU HATAF SEGOL",NULL},
/* 05B2 */ { "POINT HÉBREU HATAF PATAH",NULL},
/* 05B3 */ { "POINT HÉBREU HATAF QAMATS",NULL},
/* 05B4 */ { "POINT HÉBREU HIRIK",NULL},
/* 05B5 */ { "POINT HÉBREU TSÉRÈ",NULL},
/* 05B6 */ { "POINT HÉBREU SEGOL",NULL},
/* 05B7 */ { "POINT HÉBREU PATAH","	* le patah furtif n'est pas un caractère distinct"},
/* 05B8 */ { "POINT HÉBREU QAMATS","	* utilisé de façon générique ou comme un qamats gadol dans une orthographe qui le différencie du qamats qatan\n"
	"	x (point hébreu qamats qatan - 05C7)"},
/* 05B9 */ { "POINT HÉBREU HOLAM",NULL},
/* 05BA */ { "POINT HÉBREU HOLAM HASSER POUR WAW",NULL},
/* 05BB */ { "POINT HÉBREU KOUBOUTS",NULL},
/* 05BC */ { "POINT HÉBREU DAGUÈCH OU MAPIQ","	= ou chourouk\n"
	"	* s'inscrit à l'intérieur de la lettre de base"},
/* 05BD */ { "POINT HÉBREU METEG","	= silouq\n"
	"	* peut être utilisé pour noter l'accent hébreu sof pasouq"},
/* 05BE */ { "PONCTUATION HÉBRAÏQUE MAQAF",NULL},
/* 05BF */ { "POINT HÉBREU RAFE","	x (point hébreu judéo-espagnol varika - FB1E)"},
/* 05C0 */ { "PONCTUATION HÉBRAÏQUE PASEQ","	= pési\n"
	"	= légarméh\n"
	"	* peut être considérée comme une ponctuation à chasse et non comme un point\n"
	"	x (barre verticale - 007C)"},
/* 05C1 */ { "POINT HÉBREU CHINE",NULL},
/* 05C2 */ { "POINT HÉBREU SINE",NULL},
/* 05C3 */ { "PONCTUATION HÉBRAÏQUE SOF PASOUQ","	* peut servir de deux-points hébreu\n"
	"	x (deux-points - 003A)"},
/* 05C4 */ { "DIACRITIQUE HÉBREU POINT SUPÉRIEUR",NULL},
/* 05C5 */ { "DIACRITIQUE HÉBREU POINT INFÉRIEUR","	* punctum extraordinarium (Psaumes 27:13)\n"
	"	x (point hébreu hirik - 05B4)"},
/* 05C6 */ { "PONCTUATION HÉBRAÏQUE NOUN HAFOUKHA","	* sans rapport historique avec la lettre noun\n"
	"	x (lettre hébraïque noun - 05E0)"},
/* 05C7 */ { "POINT HÉBREU QAMATS QATAN","	x (point hébreu qamats - 05B8)"},
/* 05C8 */ { NULL,NULL},
/* 05C9 */ { NULL,NULL},
/* 05CA */ { NULL,NULL},
/* 05CB */ { NULL,NULL},
/* 05CC */ { NULL,NULL},
/* 05CD */ { NULL,NULL},
/* 05CE */ { NULL,NULL},
/* 05CF */ { NULL,NULL},
/* 05D0 */ { "LETTRE HÉBRAÏQUE ALEF","	= aleph\n"
	"	x (symbole alef - 2135)"},
/* 05D1 */ { "LETTRE HÉBRAÏQUE BÈT","	= beth\n"
	"	x (symbole bèt - 2136)"},
/* 05D2 */ { "LETTRE HÉBRAÏQUE GUIMEL","	x (symbole guimel - 2137)"},
/* 05D3 */ { "LETTRE HÉBRAÏQUE DALÈT","	= daleth\n"
	"	x (symbole dalèt - 2138)"},
/* 05D4 */ { "LETTRE HÉBRAÏQUE HÈ",NULL},
/* 05D5 */ { "LETTRE HÉBRAÏQUE WAW",NULL},
/* 05D6 */ { "LETTRE HÉBRAÏQUE ZAÏN",NULL},
/* 05D7 */ { "LETTRE HÉBRAÏQUE HÈT",NULL},
/* 05D8 */ { "LETTRE HÉBRAÏQUE TÈT",NULL},
/* 05D9 */ { "LETTRE HÉBRAÏQUE YOD",NULL},
/* 05DA */ { "LETTRE HÉBRAÏQUE KAF FINAL",NULL},
/* 05DB */ { "LETTRE HÉBRAÏQUE KAF",NULL},
/* 05DC */ { "LETTRE HÉBRAÏQUE LAMÈD",NULL},
/* 05DD */ { "LETTRE HÉBRAÏQUE MÉM FINAL",NULL},
/* 05DE */ { "LETTRE HÉBRAÏQUE MÉM",NULL},
/* 05DF */ { "LETTRE HÉBRAÏQUE NOUN FINAL",NULL},
/* 05E0 */ { "LETTRE HÉBRAÏQUE NOUN",NULL},
/* 05E1 */ { "LETTRE HÉBRAÏQUE SAMÈKH",NULL},
/* 05E2 */ { "LETTRE HÉBRAÏQUE 'AÏN",NULL},
/* 05E3 */ { "LETTRE HÉBRAÏQUE PÉ FINAL",NULL},
/* 05E4 */ { "LETTRE HÉBRAÏQUE PÉ",NULL},
/* 05E5 */ { "LETTRE HÉBRAÏQUE TSADÉ FINAL",NULL},
/* 05E6 */ { "LETTRE HÉBRAÏQUE TSADÉ","	= zadé"},
/* 05E7 */ { "LETTRE HÉBRAÏQUE QOUF",NULL},
/* 05E8 */ { "LETTRE HÉBRAÏQUE RÈCH",NULL},
/* 05E9 */ { "LETTRE HÉBRAÏQUE CHINE",NULL},
/* 05EA */ { "LETTRE HÉBRAÏQUE TAW",NULL},
/* 05EB */ { NULL,NULL},
/* 05EC */ { NULL,NULL},
/* 05ED */ { NULL,NULL},
/* 05EE */ { NULL,NULL},
/* 05EF */ { "TRIANGLE DE YOD HÉBREU",NULL},
/* 05F0 */ { "LIGATURE HÉBRAÏQUE YIDICHE DOUBLE WAW","	= tsvey vovn"},
/* 05F1 */ { "LIGATURE HÉBRAÏQUE YIDICHE WAW YOD",NULL},
/* 05F2 */ { "LIGATURE HÉBRAÏQUE YIDICHE DOUBLE YOD","	= tsvey youdn"},
/* 05F3 */ { "PONCTUATION HÉBRAÏQUE GERICH","	= gerech\n"
	"	x (apostrophe - 0027)"},
/* 05F4 */ { "PONCTUATION HÉBRAÏQUE GERCHÂÏM","	x (guillemet anglais - 0022)"},
/* 05F5 */ { NULL,NULL},
/* 05F6 */ { NULL,NULL},
/* 05F7 */ { NULL,NULL},
/* 05F8 */ { NULL,NULL},
/* 05F9 */ { NULL,NULL},
/* 05FA */ { NULL,NULL},
/* 05FB */ { NULL,NULL},
/* 05FC */ { NULL,NULL},
/* 05FD */ { NULL,NULL},
/* 05FE */ { NULL,NULL},
/* 05FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_06[] = {
/* 0600 */ { "SYMBOLE ARABE NUMÉRO",NULL},
/* 0601 */ { "SIGNE ARABE SANAH",NULL},
/* 0602 */ { "APPEL DE NOTE ARABE",NULL},
/* 0603 */ { "SIGNE ARABE SAFHA",NULL},
/* 0604 */ { "SIGNE ARABE SAMVAT","	* utilisé pour l'écriture des dates de l'ère samvat en ourdou"},
/* 0605 */ { "SIGNE NUMÉRAL ARABE EN CHEF","	* peut être utilisé avec des nombres épactes coptes"},
/* 0606 */ { "RACINE CUBIQUE ARABO-INDIENNE","	x (racine cubique - 221B)"},
/* 0607 */ { "RACINE QUATRIÈME ARABO-INDIENNE","	x (racine quatrième - 221C)"},
/* 0608 */ { "RAYON ARABE",NULL},
/* 0609 */ { "SYMBOLE ARABO-INDIEN POUR MILLE","	x (symbole pour mille - 2030)"},
/* 060A */ { "SYMBOLE ARABO-INDIEN POUR DIX MILLE","	x (symbole pour dix mille - 2031)"},
/* 060B */ { "SYMBOLE AFGHANI",NULL},
/* 060C */ { "VIRGULE ARABE","	* signe également utilisé dans les textes modernes thâna et syriaques\n"
	"	x (virgule - 002C)\n"
	"	x (virgule culbutée - 2E32)\n"
	"	x (virgule réfléchie - 2E41)"},
/* 060D */ { "SÉPARATEUR DE DATE ARABE",NULL},
/* 060E */ { "SIGNE ARABE DE VERS POÉTIQUE",NULL},
/* 060F */ { "SIGNE ARABE MISRA",NULL},
/* 0610 */ { "DIACRITIQUE ARABE SALLALLÂHOU ALAYHI WA-SALLAM","	* représente sallallâhou alayhi wa-sallam « que la paix et la bénédiction de Dieu soient sur lui »"},
/* 0611 */ { "DIACRITIQUE ARABE ALAYHI AS-SALÂM","	* représente alayhi as-salâm « que la paix soit sur lui »\n"
	"	x (ligature arabe alayhi as-salâm - FD47)"},
/* 0612 */ { "DIACRITIQUE ARABE RAHMATOULLAH ALAYHI","	* représente rahmatoullah alayhi « que Dieu lui fasse miséricorde »\n"
	"	x (ligature arabe rahimahou allâh - FD40)"},
/* 0613 */ { "DIACRITIQUE ARABE RADI ALLÂHOU ANHOU","	* représente radi allâhou anhou « que Dieu l'agrée »\n"
	"	x (ligature arabe radi allâhou anh - FD41)"},
/* 0614 */ { "DIACRITIQUE ARABE TAKHALLOUS","	* signe placé au-dessus du nom ou du pseudonyme d'un poète ou, parfois, pour indiquer tous les noms propres"},
/* 0615 */ { "PETIT TA' ARABE EN CHEF","	* indique une pause recommandée dans certains corans publiés en Iran et au Pakistan\n"
	"	* ne doit pas être confondu avec le petit signe TA' utilisé comme diacritique avec certaines lettres comme 0679"},
/* 0616 */ { "PETITE LIGATURE ARABE EN CHEF ALIF YA' BARRÉ","	* persan classique\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 0617 */ { "PETIT ZAÏN ARABE EN CHEF",NULL},
/* 0618 */ { "PETIT FATHA ARABE","	* ne doit pas être confondu avec 064E FATHA"},
/* 0619 */ { "PETIT DAMMA ARABE","	* ne doit pas être confondu avec 064F DAMMA"},
/* 061A */ { "PETIT KASRA ARABE","	* ne doit pas être confondu avec 0650 KASRA"},
/* 061B */ { "POINT-VIRGULE ARABE","	* signe également utilisé dans les textes modernes thâna et syriaques\n"
	"	x (point-virgule - 003B)\n"
	"	x (point-virgule réfléchi - 204F)\n"
	"	x (point-virgule culbuté - 2E35)"},
/* 061C */ { "MARQUE DE LETTRE ARABE","	x (marque droite-à-gauche - 200F)"},
/* 061D */ { "SIGNE DE FIN DE TEXTE ARABE",NULL},
/* 061E */ { "TROIS-POINTS ARABE",NULL},
/* 061F */ { "POINT D'INTERROGATION ARABE","	* signe également utilisé dans les textes modernes thâna et syriaques\n"
	"	x (point d'interrogation - 003F)\n"
	"	x (point d'interrogation réfléchi - 2E2E)"},
/* 0620 */ { "LETTRE ARABE CACHEMIRI YA'","	* utilisée en cachemiri pour représenter le demi-ya"},
/* 0621 */ { "LETTRE ARABE HAMZA","	* attaque vocalique, coup d'éperon\n"
	"	x (lettre modificative demi-rond droit - 02BE)"},
/* 0622 */ { "LETTRE ARABE ALIF MADDA EN CHEF","	: 0627 0653"},
/* 0623 */ { "LETTRE ARABE ALIF HAMZA EN CHEF","	: 0627 0654"},
/* 0624 */ { "LETTRE ARABE WAW HAMZA EN CHEF","	: 0648 0654"},
/* 0625 */ { "LETTRE ARABE ALIF HAMZA SOUSCRITE","	: 0627 0655"},
/* 0626 */ { "LETTRE ARABE YA' HAMZA EN CHEF","	* en kirghize, la hamza est systématiquement placée en haut à droite du caractère dans ses formes isolée et finale\n"
	"	: 064A 0654"},
/* 0627 */ { "LETTRE ARABE ALIF",NULL},
/* 0628 */ { "LETTRE ARABE BA'",NULL},
/* 0629 */ { "LETTRE ARABE TÉ' MARBOUTA","	= tāʾ marbūta (« t lié »)"},
/* 062A */ { "LETTRE ARABE TÉ'","	= tāʾ"},
/* 062B */ { "LETTRE ARABE THÉ'","	= thāʾ"},
/* 062C */ { "LETTRE ARABE DJÎM",NULL},
/* 062D */ { "LETTRE ARABE HA'",NULL},
/* 062E */ { "LETTRE ARABE KHA'",NULL},
/* 062F */ { "LETTRE ARABE DAL",NULL},
/* 0630 */ { "LETTRE ARABE DHAL",NULL},
/* 0631 */ { "LETTRE ARABE RA'",NULL},
/* 0632 */ { "LETTRE ARABE ZAÏN",NULL},
/* 0633 */ { "LETTRE ARABE SÎN",NULL},
/* 0634 */ { "LETTRE ARABE CHÎN",NULL},
/* 0635 */ { "LETTRE ARABE ÇAD","	= sad"},
/* 0636 */ { "LETTRE ARABE DAD",NULL},
/* 0637 */ { "LETTRE ARABE TA'",NULL},
/* 0638 */ { "LETTRE ARABE ZZA'",NULL},
/* 0639 */ { "LETTRE ARABE 'AÏN","	x (lettre minuscule latine ej réfléchi - 01B9)\n"
	"	x (lettre modificative demi-rond gauche - 02BF)"},
/* 063A */ { "LETTRE ARABE GHAÏN",NULL},
/* 063B */ { "LETTRE ARABE KEHA' DEUX POINTS EN CHEF",NULL},
/* 063C */ { "LETTRE ARABE KEHA' TROIS POINTS SOUSCRITS",NULL},
/* 063D */ { "LETTRE ARABE FARSI YA' V RENVERSÉ","	* azéri"},
/* 063E */ { "LETTRE ARABE FARSI YA' DEUX POINTS EN CHEF",NULL},
/* 063F */ { "LETTRE ARABE FARSI YA' TROIS POINTS EN CHEF",NULL},
/* 0640 */ { "TATOUÏL ARABE","	= kachidé, allonge, tatwil\n"
	"	* inséré pour justifier horizontalement les lignes de texte, en étendant la longueur des caractères\n"
	"	* utilisé aussi avec l'adlam, le rohingya hanifi, le mandéen, le manichéen, le pehlvi des psautiers, le sogdien et le syriaque"},
/* 0641 */ { "LETTRE ARABE FA'",NULL},
/* 0642 */ { "LETTRE ARABE QAF",NULL},
/* 0643 */ { "LETTRE ARABE KAF",NULL},
/* 0644 */ { "LETTRE ARABE LAM",NULL},
/* 0645 */ { "LETTRE ARABE MÎM","	* le sindhi utilise une variante avec une queue courte"},
/* 0646 */ { "LETTRE ARABE NOÛN",NULL},
/* 0647 */ { "LETTRE ARABE HÉ'",NULL},
/* 0648 */ { "LETTRE ARABE WAW",NULL},
/* 0649 */ { "LETTRE ARABE ALIF MAKSOURA","	= alif maqsūra\n"
	"	* représente une lettre à double jonction en forme de YA' sans points sous toutes les variantes de position\n"
	"	* elle n'est pas destinée pour une utilisation en combinaison avec 0654\n"
	"	x (lettre arabe ya' hamza en chef - 0626)"},
/* 064A */ { "LETTRE ARABE YA'","	* elle perd ses points quand elle est utilisée en combinaison avec 0654\n"
	"	* elle conserve ses points quand elle est utilisée en combinaison avec d'autres diacritiques\n"
	"	x (lettre arabe ya' deux points souscrits et hamza en chef - 08A8)"},
/* 064B */ { "FATHATAN ARABE",NULL},
/* 064C */ { "DAMMATAN ARABE","	* une autre forme commune se présente comme deux dammas entrelacés, dont l'un est tourné de 180 degrés"},
/* 064D */ { "KASRATAN ARABE","	x (double barre verticale souscrite arabe - 10EFA)"},
/* 064E */ { "FATHA ARABE",NULL},
/* 064F */ { "DAMMA ARABE",NULL},
/* 0650 */ { "KASRA ARABE",NULL},
/* 0651 */ { "CHADDA ARABE","	* indique la gémination (ou le renforcement) de la consonne"},
/* 0652 */ { "SOUKOUN ARABE","	* indique l'absence de voyelle après une consonne de base\n"
	"	* utilisé dans certains corans pour indiquer une voyelle longue à ignorer\n"
	"	* peut prendre une variété de formes, y compris une forme circulaire ou une forme semblable à 06E1\n"
	"	x (petite tête de kha' sans point arabe en chef - 06E1)"},
/* 0653 */ { "MADDA ARABE EN CHEF","	* utilisé pour le madd jāiz dans les orthographes d'Asie du Sud et d'Indonésie\n"
	"	x (pepet arabe - 0897)\n"
	"	x (madda wâdjib arabe - 089C)\n"
	"	x (double madda arabe - 089E)\n"
	"	x (demi-madda sur madda arabe - 089F)"},
/* 0654 */ { "HAMZA ARABE EN CHEF","	* son usage est restreint à la sémantique de la hamza et de l'ezafe\n"
	"	* elle n'est pas utilisée comme un diacritique pour former de nouvelles lettres"},
/* 0655 */ { "HAMZA ARABE SOUSCRITE",NULL},
/* 0656 */ { "ALIF ARABE SOUSCRIT",NULL},
/* 0657 */ { "DAMMA ARABE CULBUTÉ","	* cachemiri, ourdou"},
/* 0658 */ { "DIACRITIQUE ARABE NOÛN GHOUNNA","	* baloutche\n"
	"	* indique la nasalisation en ourdou"},
/* 0659 */ { "ZWARAKAÏ ARABE","	* pachto"},
/* 065A */ { "DIACRITIQUE VOYELLE ARABE PETIT V EN CHEF","	* langues africaines"},
/* 065B */ { "DIACRITIQUE VOYELLE ARABE PIGNON","	* langues africaines"},
/* 065C */ { "DIACRITIQUE VOYELLE ARABE POINT SOUSCRIT","	* langues africaines\n"
	"	* s'emploie aussi dans des textes coraniques utilisant des orthographes africaines et d'autres orthographes"},
/* 065D */ { "DAMMA ARABE RÉFLÉCHI","	* langues africaines"},
/* 065E */ { "FATHA ARABE À DEUX POINTS","	* kohistani de Kalam"},
/* 065F */ { "HAMZA ONDÉE ARABE SOUSCRITE","	* cachemiri"},
/* 0660 */ { "CHIFFRE ARABO-INDIEN ZÉRO",NULL},
/* 0661 */ { "CHIFFRE ARABO-INDIEN UN",NULL},
/* 0662 */ { "CHIFFRE ARABO-INDIEN DEUX",NULL},
/* 0663 */ { "CHIFFRE ARABO-INDIEN TROIS",NULL},
/* 0664 */ { "CHIFFRE ARABO-INDIEN QUATRE",NULL},
/* 0665 */ { "CHIFFRE ARABO-INDIEN CINQ",NULL},
/* 0666 */ { "CHIFFRE ARABO-INDIEN SIX",NULL},
/* 0667 */ { "CHIFFRE ARABO-INDIEN SEPT",NULL},
/* 0668 */ { "CHIFFRE ARABO-INDIEN HUIT",NULL},
/* 0669 */ { "CHIFFRE ARABO-INDIEN NEUF",NULL},
/* 066A */ { "SYMBOLE ARABE POUR CENT","	x (symbole pour cent - 0025)"},
/* 066B */ { "SÉPARATEUR DÉCIMAL ARABE",NULL},
/* 066C */ { "SÉPARATEUR DE MILLIERS ARABE","	x (apostrophe - 0027)\n"
	"	x (guillemet-apostrophe - 2019)"},
/* 066D */ { "ÉTOILE À CINQ BRANCHES ARABE","	* apparence variable\n"
	"	x (astérisque - 002A)"},
/* 066E */ { "LETTRE ARABE BA' SANS POINT",NULL},
/* 066F */ { "LETTRE ARABE QAF SANS POINT",NULL},
/* 0670 */ { "DIACRITIQUE VOYELLE ARABE ALIF EN CHEF","	* le nom formel de ce caractère en anglais est erroné"},
/* 0671 */ { "LETTRE ARABE ALIF WASLA","	= alif ouasl\n"
	"	* arabe coranique"},
/* 0672 */ { "LETTRE ARABE ALIF HAMZA ONDÉE EN CHEF","	* baloutche, cachemiri"},
/* 0673 */ { "LETTRE ARABE ALIF HAMZA ONDÉE SOUSCRITE","	* cachemiri\n"
	"	* ce caractère est obsolète et son utilisation est fortement déconseillée\n"
	"	* il faut utiliser plutôt la séquence 0627 065F"},
/* 0674 */ { "LETTRE ARABE HAMZA ÉLEVÉE","	* kazakh, jawi\n"
	"	* permet de former des digrammes\n"
	"	* en jawi, ce caractère correspond à la forme pleine de la hamza, placée à trois quarts de hauteur"},
/* 0675 */ { "LETTRE ARABE HAMZA ÉLEVÉE ALIF","	* l'orthographe recommandée est 0674 0627\n"
	"	# 0627 0674"},
/* 0676 */ { "LETTRE ARABE HAMZA ÉLEVÉE WAW","	* l'orthographe recommandée est 0674 0648\n"
	"	# 0648 0674"},
/* 0677 */ { "LETTRE ARABE OU HAMZA EN CHEF","	* l'orthographe recommandée est 0674 06C7\n"
	"	# 06C7 0674"},
/* 0678 */ { "LETTRE ARABE HAMZA ÉLEVÉE YA'","	* l'orthographe recommandée est 0674 0649\n"
	"	# 064A 0674"},
/* 0679 */ { "LETTRE ARABE TTA'","	* ourdou"},
/* 067A */ { "LETTRE ARABE TTEHA'","	* sindhi"},
/* 067B */ { "LETTRE ARABE BEA'","	* sindhi"},
/* 067C */ { "LETTRE ARABE TÉ' ROND","	* pachto"},
/* 067D */ { "LETTRE ARABE TÉ' TROIS POINTS EN CHEF POINTANT VERS LE BAS","	* sindhi"},
/* 067E */ { "LETTRE ARABE PA'","	* persan, ourdou, etc."},
/* 067F */ { "LETTRE ARABE TEHA'","	* sindhi"},
/* 0680 */ { "LETTRE ARABE BEHA'","	* sindhi"},
/* 0681 */ { "LETTRE ARABE HA' HAMZA EN CHEF","	* pachto\n"
	"	* représente le phonème /dz/"},
/* 0682 */ { "LETTRE ARABE HA' DEUX POINTS VERTICAUX EN CHEF","	* inusité en pachto moderne"},
/* 0683 */ { "LETTRE ARABE NYA'","	* sindhi"},
/* 0684 */ { "LETTRE ARABE DYA'","	* sindhi, bosnien"},
/* 0685 */ { "LETTRE ARABE HA' TROIS POINTS EN CHEF","	* pachto, chorasmien (khwarezmien)\n"
	"	* représente le phonème /ts/ en pachto"},
/* 0686 */ { "LETTRE ARABE TCHIM'","	* persan, ourdou, etc."},
/* 0687 */ { "LETTRE ARABE TCHEHA'","	* sindhi"},
/* 0688 */ { "LETTRE ARABE DDAL","	* ourdou"},
/* 0689 */ { "LETTRE ARABE DAL ROND","	* pachto"},
/* 068A */ { "LETTRE ARABE DAL POINT SOUSCRIT","	* sindhi, persan classique, pégon, malgache"},
/* 068B */ { "LETTRE ARABE DAL POINT SOUSCRIT ET PETIT TA'","	* langues lahnda"},
/* 068C */ { "LETTRE ARABE DAHAL","	* sindhi"},
/* 068D */ { "LETTRE ARABE DDAHAL","	* sindhi"},
/* 068E */ { "LETTRE ARABE DOUL","	* forme désormais désuète du DOUL en sindhi\n"
	"	* bourouchaski"},
/* 068F */ { "LETTRE ARABE DAL TROIS POINTS EN CHEF POINTANT VERS LE BAS","	* sindhi\n"
	"	* forme actuelle du DOUL"},
/* 0690 */ { "LETTRE ARABE DAL QUATRE POINTS EN CHEF","	* vieil ourdou, inusité"},
/* 0691 */ { "LETTRE ARABE RRA'","	* ourdou"},
/* 0692 */ { "LETTRE ARABE RA' PETIT V","	* kurde"},
/* 0693 */ { "LETTRE ARABE RA' ROND","	* pachto"},
/* 0694 */ { "LETTRE ARABE RA' POINT SOUSCRIT","	* kurde, persan classique"},
/* 0695 */ { "LETTRE ARABE RA' PETIT V SOUSCRIT","	* kurde"},
/* 0696 */ { "LETTRE ARABE RA' POINT SOUSCRIT ET POINT EN CHEF","	* pachto"},
/* 0697 */ { "LETTRE ARABE RA' DEUX POINTS EN CHEF","	* dargwa"},
/* 0698 */ { "LETTRE ARABE JA'","	* persan, ourdou, etc."},
/* 0699 */ { "LETTRE ARABE RA' QUATRE POINTS EN CHEF","	* sindhi"},
/* 069A */ { "LETTRE ARABE SÎN POINT SOUSCRIT ET POINT EN CHEF","	* pachto"},
/* 069B */ { "LETTRE ARABE SÎN TROIS POINTS SOUSCRITS","	* persan classique"},
/* 069C */ { "LETTRE ARABE SÎN TROIS POINTS SOUSCRITS ET TROIS POINTS EN CHEF","	* arabe marocain"},
/* 069D */ { "LETTRE ARABE ÇAD DEUX POINTS SOUSCRITS","	* langues turques"},
/* 069E */ { "LETTRE ARABE ÇAD TROIS POINTS EN CHEF","	* berbère, bourouchaski"},
/* 069F */ { "LETTRE ARABE TA' TROIS POINTS EN CHEF","	* vieil haoussa"},
/* 06A0 */ { "LETTRE ARABE 'AÏN TROIS POINTS EN CHEF","	* jawi"},
/* 06A1 */ { "LETTRE ARABE FA' SANS POINT","	* adighe"},
/* 06A2 */ { "LETTRE ARABE FA' POINT DESCENDU","	* arabe maghrébin"},
/* 06A3 */ { "LETTRE ARABE FA' POINT SOUSCRIT","	* ingouche"},
/* 06A4 */ { "LETTRE ARABE VA'","	* parfois utilisée pour l'écriture de mots d'emprunt en arabe\n"
	"	* kurde, chorasmien (khwarezmien), persan classique, jawi"},
/* 06A5 */ { "LETTRE ARABE FA' TROIS POINTS SOUSCRITS","	* arabe maghrébin dans les mots d'emprunt"},
/* 06A6 */ { "LETTRE ARABE PEHA'","	* sindhi"},
/* 06A7 */ { "LETTRE ARABE QAF POINT EN CHEF","	* arabe maghrébin, ouïgour"},
/* 06A8 */ { "LETTRE ARABE QAF TROIS POINTS EN CHEF","	* arabe tunisien"},
/* 06A9 */ { "LETTRE ARABE KEHA'","	= kaf mashkula\n"
	"	* persan, ourdou, sindhi, etc."},
/* 06AA */ { "LETTRE ARABE KAF ÉCRASÉ","	= kaf de l'impiété, kaf paraphe\n"
	"	* en sindhi, représente une lettre distincte du KAF arabe (0643)"},
/* 06AB */ { "LETTRE ARABE KAF ROND","	* pachto\n"
	"	* peut ressembler à un KAF arabe (0643) avec un rond souscrit"},
/* 06AC */ { "LETTRE ARABE KAF POINT EN CHEF","	* son emploi pour le gaf jawi n'est pas recommandé, même s'il se présente dans certaines sources ; le caractère recommandé pour le gaf jawi est 0762\n"
	"	x (lettre arabe keha' point en chef - 0762)"},
/* 06AD */ { "LETTRE ARABE NG","	* ouïgour, kazakh, arabe marocain, jawi ancien, persan classique, etc."},
/* 06AE */ { "LETTRE ARABE KAF TROIS POINTS SOUSCRITS","	* berbère, persan classique\n"
	"	* variante pégon pour 08B4"},
/* 06AF */ { "LETTRE ARABE GAF","	* persan, ourdou, etc."},
/* 06B0 */ { "LETTRE ARABE GAF ROND","	* langues lahnda"},
/* 06B1 */ { "LETTRE ARABE NGOA'","	* sindhi"},
/* 06B2 */ { "LETTRE ARABE GAF DEUX POINTS SOUSCRITS","	* inusité en sindhi"},
/* 06B3 */ { "LETTRE ARABE GOUA'","	* sindhi"},
/* 06B4 */ { "LETTRE ARABE GAF TROIS POINTS EN CHEF","	* inusité en sindhi"},
/* 06B5 */ { "LETTRE ARABE LAM PETIT V","	* kurde, bosnien"},
/* 06B6 */ { "LETTRE ARABE LAM POINT EN CHEF","	* kurde"},
/* 06B7 */ { "LETTRE ARABE LAM TROIS POINTS EN CHEF","	* kurde"},
/* 06B8 */ { "LETTRE ARABE LAM TROIS POINTS SOUSCRITS",NULL},
/* 06B9 */ { "LETTRE ARABE NOÛN POINT SOUSCRIT",NULL},
/* 06BA */ { "LETTRE ARABE NOÛN GHOUNNA","	* ourdou, arabe archaïque\n"
	"	* n'a de point dans aucune de ses quatre formes"},
/* 06BB */ { "LETTRE ARABE NNOÛN","	* sindhi"},
/* 06BC */ { "LETTRE ARABE NOÛN ROND","	* pachto"},
/* 06BD */ { "LETTRE ARABE NOÛN TROIS POINTS EN CHEF","	* jawi"},
/* 06BE */ { "LETTRE ARABE HÉ' DOATCHACHMI","	= héʾ binoculaire\n"
	"	* forme des digrammes aspirés en ourdou et dans d'autres langues d'Asie du Sud\n"
	"	* représente la fricative glottale /h/ en ouïgour"},
/* 06BF */ { "LETTRE ARABE TCHIM' POINT EN CHEF",NULL},
/* 06C0 */ { "LIGATURE ARABE HÉ' YA' EN CHEF","	= lettre arabe hamza sur hé' (1.0)\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	* pour l'ezafe persan, l'izāfat ourdou ou des cas similaires, utilisez plutôt le caractère 0654 au-dessus de la lettre de base propre à la langue\n"
	"	: 06D5 0654"},
/* 06C1 */ { "LETTRE ARABE HÉ' GÔL","	* ourdou"},
/* 06C2 */ { "LIGATURE ARABE HÉ' GÔL HAMZA EN CHEF","	* ourdou\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	: 06C1 0654"},
/* 06C3 */ { "LETTRE ARABE TÉ' MARBOUTA GÔL","	* ourdou"},
/* 06C4 */ { "LETTRE ARABE WAW ROND","	* cachemiri"},
/* 06C5 */ { "LETTRE ARABE KIRGHIZE EU","	* kirghize\n"
	"	* il existe une variante de glyphe qui remplace la queue en forme de boucle par une queue diacritée d'une barre inscrite"},
/* 06C6 */ { "LETTRE ARABE EU","	* ouïgour, kurde, kazakh, azéri, bosnien"},
/* 06C7 */ { "LETTRE ARABE OU","	* azéri, kazakh, kirghize, ouïgour"},
/* 06C8 */ { "LETTRE ARABE YOU","	* ouïgour"},
/* 06C9 */ { "LETTRE ARABE KIRGHIZE YOU","	* kazakh, kirghize, bosnien"},
/* 06CA */ { "LETTRE ARABE WAW DEUX POINTS EN CHEF","	* kurde"},
/* 06CB */ { "LETTRE ARABE VÉ","	* ouïgour, kazakh"},
/* 06CC */ { "LETTRE ARABE FARSI YA'","	* arabe, persan, ourdou, cachemiri, etc.\n"
	"	* dans les positions initiale et médiale, les formes de cette lettre comportent deux points horizontaux souscrits\n"
	"	* conserve ses points dans les positions initiale et médiale lorsqu'elle est utilisée conjointement avec 0654\n"
	"	x (lettre arabe alif maksoura - 0649)\n"
	"	x (lettre arabe ya' - 064A)"},
/* 06CD */ { "LETTRE ARABE YA' À QUEUE","	* pachto, sindhi\n"
	"	* ne devrait pas être utilisée en cachemiri pour représenter le demi-ya\n"
	"	x (lettre arabe cachemiri ya' - 0620)"},
/* 06CE */ { "LETTRE ARABE YA' PETIT V","	* kurde"},
/* 06CF */ { "LETTRE ARABE WAW POINT EN CHEF",NULL},
/* 06D0 */ { "LETTRE ARABE É","	* pachto, ouïgour\n"
	"	* représente la lettre bbé' en sindhi"},
/* 06D1 */ { "LETTRE ARABE YA' TROIS POINTS SOUSCRITS","	* langues mandées, haoussa"},
/* 06D2 */ { "LETTRE ARABE YA' BARRÉ","	* ourdou"},
/* 06D3 */ { "LIGATURE ARABE YA' BARRÉ HAMZA EN CHEF","	* ourdou\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	: 06D2 0654"},
/* 06D4 */ { "POINT ARABE","	* ourdou"},
/* 06D5 */ { "LETTRE ARABE E","	* ouïgour, kazakh, kirghize"},
/* 06D6 */ { "PETITE LIGATURE ARABE EN CHEF ÇAD LAM ALIF MAKSOURA",NULL},
/* 06D7 */ { "PETITE LIGATURE ARABE EN CHEF QAF LAM ALIF MAKSOURA",NULL},
/* 06D8 */ { "PETIT MÎM INITIAL ARABE EN CHEF",NULL},
/* 06D9 */ { "PETIT LAM ALIF ARABE EN CHEF",NULL},
/* 06DA */ { "PETIT DJÎM ARABE EN CHEF",NULL},
/* 06DB */ { "TROIS POINTS ARABES EN CHEF",NULL},
/* 06DC */ { "PETIT SÎN ARABE EN CHEF",NULL},
/* 06DD */ { "FIN D'AYA ARABE",NULL},
/* 06DE */ { "DÉBUT DE ROUB EL HIZB ARABE","	* indique les limites des parties de section\n"
	"	* généralement représenté sous la forme d'un symbole à huit côtés, qui peut ou non ressembler à une étoile"},
/* 06DF */ { "PETIT ZÉRO ARRONDI ARABE EN CHEF","	* plus petit que la forme circulaire utilisée pour 0652"},
/* 06E0 */ { "PETIT ZÉRO RECTANGULAIRE VERTICAL ARABE EN CHEF","	* le terme « zéro rectangulaire » est une traduction du nom arabe de ce signe"},
/* 06E1 */ { "PETITE TÊTE DE KHA' SANS POINT ARABE EN CHEF","	= djezm arabe\n"
	"	* la forme de présentation de 0652 avec le choix de la forme de variante par le biais de la police est recommandée\n"
	"	* s'utilise dans certains corans pour indiquer l'absence d'une voyelle\n"
	"	x (soukoun arabe - 0652)"},
/* 06E2 */ { "PETIT MÎM ISOLÉ ARABE EN CHEF",NULL},
/* 06E3 */ { "PETIT SÎN ARABE SOUSCRIT",NULL},
/* 06E4 */ { "PETIT MADDA ARABE EN CHEF","	* s'utilise généralement avec 06E5, 06E6, 06E7 et 08F3"},
/* 06E5 */ { "PETIT WAW ARABE","	x (petit waw arabe souscrit - 08D3)\n"
	"	x (petit waw arabe en chef - 08F3)"},
/* 06E6 */ { "PETIT YA' ARABE",NULL},
/* 06E7 */ { "PETIT YA' ARABE EN CHEF",NULL},
/* 06E8 */ { "PETIT NOÛN ARABE EN CHEF",NULL},
/* 06E9 */ { "SIGNE DE PROSTERNATION ARABE","	= sajdah\n"
	"	* une série de glyphes conviennent pour ce caractère"},
/* 06EA */ { "POINT CONTOUR ARABE SOUSCRIT",NULL},
/* 06EB */ { "POINT CONTOUR ARABE EN CHEF",NULL},
/* 06EC */ { "POINT PLEIN ARABE EN CHEF","	* s'emploie aussi dans des textes coraniques utilisant des orthographes africaines et d'autres orthographes pour représenter un wasla, etc."},
/* 06ED */ { "PETIT MÎM ARABE SOUSCRIT",NULL},
/* 06EE */ { "LETTRE ARABE DAL V RENVERSÉ",NULL},
/* 06EF */ { "LETTRE ARABE RA' V RENVERSÉ","	* utilisée aussi en persan classique"},
/* 06F0 */ { "CHIFFRE ARABO-INDIEN ÉTENDU ZÉRO",NULL},
/* 06F1 */ { "CHIFFRE ARABO-INDIEN ÉTENDU UN",NULL},
/* 06F2 */ { "CHIFFRE ARABO-INDIEN ÉTENDU DEUX",NULL},
/* 06F3 */ { "CHIFFRE ARABO-INDIEN ÉTENDU TROIS",NULL},
/* 06F4 */ { "CHIFFRE ARABO-INDIEN ÉTENDU QUATRE","	* l'ourdou et le cachemiri ont un glyphe différent de celui du persan"},
/* 06F5 */ { "CHIFFRE ARABO-INDIEN ÉTENDU CINQ",NULL},
/* 06F6 */ { "CHIFFRE ARABO-INDIEN ÉTENDU SIX","	* le sindhi, l'ourdou et le cachemiri ont un glyphe différent de celui du persan"},
/* 06F7 */ { "CHIFFRE ARABO-INDIEN ÉTENDU SEPT","	* le sindhi, l'ourdou et le cachemiri ont un glyphe différent de celui du persan"},
/* 06F8 */ { "CHIFFRE ARABO-INDIEN ÉTENDU HUIT",NULL},
/* 06F9 */ { "CHIFFRE ARABO-INDIEN ÉTENDU NEUF",NULL},
/* 06FA */ { "LETTRE ARABE CHÎN POINT SOUSCRIT",NULL},
/* 06FB */ { "LETTRE ARABE DAD POINT SOUSCRIT",NULL},
/* 06FC */ { "LETTRE ARABE GHAÏN POINT SOUSCRIT",NULL},
/* 06FD */ { "SIGNE ARABE SINDHI PERLUÈTE",NULL},
/* 06FE */ { "SIGNE ARABE SINDHI MEN DE POSTPOSITION",NULL},
/* 06FF */ { "LETTRE ARABE HÉ' V RENVERSÉ",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_07[] = {
/* 0700 */ { "FIN DE PARAGRAPHE SYRIAQUE","	* marque la fin d'un paragraphe"},
/* 0701 */ { "POINT SYRIAQUE SUPRALINÉAIRE","	* indique une interrogative, l'impératif et les pauses, particulièrement dans les textes bibliques"},
/* 0702 */ { "POINT SYRIAQUE SUBLINÉAIRE","	* indique les propositions subordonnées et les courtes pauses, particulièrement dans les textes bibliques"},
/* 0703 */ { "DEUX-POINTS SYRIAQUE SUPRALINÉAIRE","	* marque l'étonnement"},
/* 0704 */ { "DEUX-POINTS SYRIAQUE SUBLINÉAIRE","	* utilisé à la fin de versets d'imploration"},
/* 0705 */ { "DEUX-POINTS SYRIAQUE HORIZONTAL","	* rapproche deux mots là où un ton montant est adapté"},
/* 0706 */ { "DEUX-POINTS SYRIAQUE EN BIAIS À GAUCHE","	* indique une subordonnée"},
/* 0707 */ { "DEUX-POINTS SYRIAQUE EN BIAIS À DROITE","	* indique la fin d'une subdivision de l'apodose, la dernière partie d'un verset biblique"},
/* 0708 */ { "DEUX-POINTS SYRIAQUE SUPRALINÉAIRE EN BIAIS À GAUCHE","	* indique une division mineure dans une proposition"},
/* 0709 */ { "DEUX-POINTS SYRIAQUE SUBLINÉAIRE EN BIAIS À GAUCHE","	* le nom formel de ce caractère en anglais est erroné\n"
	"	* indique la fin d'une question réelle ou oratoire"},
/* 070A */ { "CONTRACTION SYRIAQUE","	* signe de contraction, utilisé principalement en syriaque oriental\n"
	"	* placée à la fin d'un mot inachevé"},
/* 070B */ { "OBÈLE SYRIAQUE HÉRACLÉEN","	= obèle d'Harqel\n"
	"	* indique le début d'une proposition, d'un mot ou d'un morphème glosé\n"
	"	x (signe de division - 00F7)"},
/* 070C */ { "MÉTOBÈLE SYRIAQUE HÉRACLÉEN","	= métobèle d'Harqel\n"
	"	* indique la fin d'une section glosée"},
/* 070D */ { "ASTÉRISQUE SYRIAQUE HÉRACLÉEN","	= astérisque d'Harqel\n"
	"	* indique le début d'une proposition, d'un mot ou d'un morphème glosé"},
/* 070E */ { NULL,NULL},
/* 070F */ { "SIGNE D'ABRÉVIATION SYRIAQUE","	* indique le début d'une abréviation syriaque"},
/* 0710 */ { "LETTRE SYRIAQUE ÂLAPH",NULL},
/* 0711 */ { "LETTRE SYRIAQUE ÂLAPH EN CHEF","	* utilisée dans les textes syriaques orientaux pour indiquer un âlaph étymologique"},
/* 0712 */ { "LETTRE SYRIAQUE BÊTH",NULL},
/* 0713 */ { "LETTRE SYRIAQUE GÂMAL",NULL},
/* 0714 */ { "LETTRE SYRIAQUE GÂMAL GARCHOUNI","	* utilisée dans les documents garchounis"},
/* 0715 */ { "LETTRE SYRIAQUE DÂLATH",NULL},
/* 0716 */ { "LETTRE SYRIAQUE DÂLATH RÎCH SANS POINT","	* forme ambiguë et non différenciée des dâlath et des rîch primitifs"},
/* 0717 */ { "LETTRE SYRIAQUE HÊ",NULL},
/* 0718 */ { "LETTRE SYRIAQUE WAW",NULL},
/* 0719 */ { "LETTRE SYRIAQUE ZAÏN",NULL},
/* 071A */ { "LETTRE SYRIAQUE HHÊTH",NULL},
/* 071B */ { "LETTRE SYRIAQUE TTÊTH",NULL},
/* 071C */ { "LETTRE SYRIAQUE TTÊTH GARCHOUNI","	* utilisée dans les documents garchounis"},
/* 071D */ { "LETTRE SYRIAQUE YOÛDH",NULL},
/* 071E */ { "LETTRE SYRIAQUE YOÛDH HÊ","	* utilisée principalement dans des textes syriaques orientaux"},
/* 071F */ { "LETTRE SYRIAQUE KÂPH",NULL},
/* 0720 */ { "LETTRE SYRIAQUE LÂMADH",NULL},
/* 0721 */ { "LETTRE SYRIAQUE MÎM",NULL},
/* 0722 */ { "LETTRE SYRIAQUE NOÛN",NULL},
/* 0723 */ { "LETTRE SYRIAQUE SEMKATH",NULL},
/* 0724 */ { "LETTRE SYRIAQUE SEMKATH FINAL",NULL},
/* 0725 */ { "LETTRE SYRIAQUE 'Ê",NULL},
/* 0726 */ { "LETTRE SYRIAQUE PÊ",NULL},
/* 0727 */ { "LETTRE SYRIAQUE PÊ RÉFLÉCHI","	* utilisée en araméen chrétien de Palestine"},
/* 0728 */ { "LETTRE SYRIAQUE SSÂDHÊ","	= çâdhê"},
/* 0729 */ { "LETTRE SYRIAQUE QOÛPH",NULL},
/* 072A */ { "LETTRE SYRIAQUE RÎCH",NULL},
/* 072B */ { "LETTRE SYRIAQUE CHÎN",NULL},
/* 072C */ { "LETTRE SYRIAQUE TAW",NULL},
/* 072D */ { "LETTRE SYRIAQUE PERSANE BHÂTH",NULL},
/* 072E */ { "LETTRE SYRIAQUE PERSANE GHÂMAL",NULL},
/* 072F */ { "LETTRE SYRIAQUE PERSANE DHÂLATH",NULL},
/* 0730 */ { "PETHÂHHÂ SYRIAQUE EN CHEF",NULL},
/* 0731 */ { "PETHÂHHÂ SYRIAQUE SOUSCRIT",NULL},
/* 0732 */ { "PETHÂHHÂ SYRIAQUE POINTÉ",NULL},
/* 0733 */ { "ZEQÂPHÂ SYRIAQUE EN CHEF",NULL},
/* 0734 */ { "ZEQÂPHÂ SYRIAQUE SOUSCRIT",NULL},
/* 0735 */ { "ZEQÂPHÂ SYRIAQUE POINTILLÉ",NULL},
/* 0736 */ { "REVÂSSÂ SYRIAQUE EN CHEF",NULL},
/* 0737 */ { "REVÂSSÂ SYRIAQUE SOUSCRIT",NULL},
/* 0738 */ { "ZELÂMÂ SYRIAQUE POINTILLÉ HORIZONTAL",NULL},
/* 0739 */ { "ZELÂMÂ SYRIAQUE POINTILLÉ OBLIQUE",NULL},
/* 073A */ { "HHEVÂSSÂ SYRIAQUE EN CHEF",NULL},
/* 073B */ { "HHEVÂSSÂ SYRIAQUE SOUSCRIT",NULL},
/* 073C */ { "HHEVÂSSÂ-'ESSÂSÂ SYRIAQUE POINTÉ",NULL},
/* 073D */ { "'ESSÂSÂ SYRIAQUE EN CHEF",NULL},
/* 073E */ { "'ESSÂSÂ SYRIAQUE SOUSCRIT",NULL},
/* 073F */ { "REWÂHHÂ SYRIAQUE",NULL},
/* 0740 */ { "POINT FÉMININ SYRIAQUE","	* marque du féminin utilisée avec la désinence féminine taw\n"
	"	x (diacritique point en chef à gauche - 1DF8)"},
/* 0741 */ { "QOUCHCHÂI SYRIAQUE","	* indique une prononciation plosive"},
/* 0742 */ { "ROUKKÂKH SYRIAQUE","	* indique une prononciation aspirée (spirante)"},
/* 0743 */ { "DEUX POINTS VERTICAUX SYRIAQUES EN CHEF","	* accent utilisé dans des manuscrits anciens"},
/* 0744 */ { "DEUX POINTS VERTICAUX SYRIAQUES SOUSCRITS","	* accent utilisé dans des manuscrits anciens"},
/* 0745 */ { "TROIS POINTS SYRIAQUES EN CHEF","	* diacritique utilisé en touroyo pour les lettres inexistantes en syriaque"},
/* 0746 */ { "TROIS POINTS SYRIAQUES SOUSCRITS","	* diacritique utilisé en touroyo pour les lettres inexistantes en syriaque"},
/* 0747 */ { "LIGNE OBLIQUE SYRIAQUE EN CHEF","	= trait occultant suscrit, abrogateur suscrit\n"
	"	* indique une lettre muette"},
/* 0748 */ { "LIGNE OBLIQUE SYRIAQUE SOUSCRITE","	= trait occultant souscrit, abrogateur souscrit\n"
	"	* indique une lettre muette\n"
	"	* indique également des nombres multipliés par une constante donnée"},
/* 0749 */ { "MUSIQUE SYRIAQUE","	* un signe de musique\n"
	"	* signe également utilisé dans l'Anaphore orthodoxe syrienne pour indiquer la rupture du pain de l'Eucharistie"},
/* 074A */ { "BARREKH SYRIAQUE","	* croix diacritique utilisée dans les textes liturgiques"},
/* 074B */ { NULL,NULL},
/* 074C */ { NULL,NULL},
/* 074D */ { "LETTRE SYRIAQUE SOGDIENNE ZHAÏN",NULL},
/* 074E */ { "LETTRE SYRIAQUE SOGDIENNE KHÂPH",NULL},
/* 074F */ { "LETTRE SYRIAQUE SOGDIENNE FÊ",NULL},
/* 0750 */ { "LETTRE ARABE BA' TROIS POINTS HORIZONTAUX SOUSCRITS",NULL},
/* 0751 */ { "LETTRE ARABE BA' UN POINT SOUSCRIT ET TROIS POINTS EN CHEF",NULL},
/* 0752 */ { "LETTRE ARABE BA' TROIS POINTS SOUSCRITS POINTANT VERS LE HAUT",NULL},
/* 0753 */ { "LETTRE ARABE BA' TROIS POINTS SOUSCRITS POINTANT VERS LE HAUT ET DEUX POINTS EN CHEF",NULL},
/* 0754 */ { "LETTRE ARABE BA' DEUX POINTS SOUSCRITS ET POINT EN CHEF",NULL},
/* 0755 */ { "LETTRE ARABE BA' PIGNON SOUSCRIT",NULL},
/* 0756 */ { "LETTRE ARABE BA' PETIT V",NULL},
/* 0757 */ { "LETTRE ARABE HA' DEUX POINTS EN CHEF",NULL},
/* 0758 */ { "LETTRE ARABE HA' TROIS POINTS SOUSCRITS POINTANT VERS LE HAUT",NULL},
/* 0759 */ { "LETTRE ARABE DAL DEUX POINTS VERTICAUX SOUSCRITS ET PETIT TA'","	* saraïki"},
/* 075A */ { "LETTRE ARABE DAL PIGNON SOUSCRIT",NULL},
/* 075B */ { "LETTRE ARABE RA' BARRÉ",NULL},
/* 075C */ { "LETTRE ARABE SÎN QUATRE POINTS EN CHEF","	* china"},
/* 075D */ { "LETTRE ARABE 'AÏN DEUX POINTS EN CHEF",NULL},
/* 075E */ { "LETTRE ARABE 'AÏN TROIS POINTS EN CHEF POINTANT VERS LE BAS",NULL},
/* 075F */ { "LETTRE ARABE 'AÏN DEUX POINTS VERTICAUX EN CHEF",NULL},
/* 0760 */ { "LETTRE ARABE FA' DEUX POINTS SOUSCRITS",NULL},
/* 0761 */ { "LETTRE ARABE FA' TROIS POINTS SOUSCRITS POINTANT VERS LE HAUT",NULL},
/* 0762 */ { "LETTRE ARABE KEHA' POINT EN CHEF","	* jawi, préférée à 06AC\n"
	"	x (lettre arabe kaf point en chef - 06AC)"},
/* 0763 */ { "LETTRE ARABE KEHA' TROIS POINTS EN CHEF","	* arabe marocain, berbère, bourouchaski\n"
	"	x (lettre arabe ng - 06AD)"},
/* 0764 */ { "LETTRE ARABE KEHA' TROIS POINTS SOUSCRITS POINTANT VERS LE HAUT",NULL},
/* 0765 */ { "LETTRE ARABE MÎM POINT EN CHEF",NULL},
/* 0766 */ { "LETTRE ARABE MÎM POINT SOUSCRIT","	* maba"},
/* 0767 */ { "LETTRE ARABE NOÛN DEUX POINTS SOUSCRITS","	* arwi"},
/* 0768 */ { "LETTRE ARABE NOÛN PETIT TA'","	* saraïki, pathwari"},
/* 0769 */ { "LETTRE ARABE NOÛN PETIT V","	* goudjeri (gojri)"},
/* 076A */ { "LETTRE ARABE LAM BARRÉ",NULL},
/* 076B */ { "LETTRE ARABE RA' DEUX POINTS VERTICAUX EN CHEF","	* torwali, ormouri"},
/* 076C */ { "LETTRE ARABE RA' HAMZA EN CHEF","	* ormouri\n"
	"	* représente une fricative alvéolo-palatale sonore\n"
	"	x (lettre minuscule latine z bouclé - 0291)"},
/* 076D */ { "LETTRE ARABE SÎN DEUX POINTS VERTICAUX EN CHEF","	* kohistani de Kalam, ormouri"},
/* 076E */ { "LETTRE ARABE HA' PETIT TA' SOUSCRIT",NULL},
/* 076F */ { "LETTRE ARABE HA' PETIT TA' ET DEUX POINTS",NULL},
/* 0770 */ { "LETTRE ARABE SÎN PETIT TA' ET DEUX POINTS",NULL},
/* 0771 */ { "LETTRE ARABE RA' PETIT TA' ET DEUX POINTS",NULL},
/* 0772 */ { "LETTRE ARABE HA' PETIT TA' EN CHEF",NULL},
/* 0773 */ { "LETTRE ARABE ALIF AVEC CHIFFRE ARABO-INDIEN ÉTENDU DEUX SUSCRIT",NULL},
/* 0774 */ { "LETTRE ARABE ALIF AVEC CHIFFRE ARABO-INDIEN ÉTENDU TROIS SUSCRIT",NULL},
/* 0775 */ { "LETTRE ARABE FARSI YA' AVEC CHIFFRE ARABO-INDIEN ÉTENDU DEUX SUSCRIT",NULL},
/* 0776 */ { "LETTRE ARABE FARSI YA' AVEC CHIFFRE ARABO-INDIEN ÉTENDU TROIS SUSCRIT",NULL},
/* 0777 */ { "LETTRE ARABE FARSI YA' AVEC CHIFFRE ARABO-INDIEN ÉTENDU QUATRE SOUSCRIT",NULL},
/* 0778 */ { "LETTRE ARABE WAW AVEC CHIFFRE ARABO-INDIEN ÉTENDU DEUX SUSCRIT",NULL},
/* 0779 */ { "LETTRE ARABE WAW AVEC CHIFFRE ARABO-INDIEN ÉTENDU TROIS SUSCRIT",NULL},
/* 077A */ { "LETTRE ARABE YA' BARRÉ AVEC CHIFFRE ARABO-INDIEN ÉTENDU DEUX SUSCRIT",NULL},
/* 077B */ { "LETTRE ARABE YA' BARRÉ AVEC CHIFFRE ARABO-INDIEN ÉTENDU TROIS SUSCRIT",NULL},
/* 077C */ { "LETTRE ARABE HA' AVEC CHIFFRE ARABO-INDIEN ÉTENDU QUATRE SOUSCRIT",NULL},
/* 077D */ { "LETTRE ARABE SÎN AVEC CHIFFRE ARABO-INDIEN ÉTENDU QUATRE SUSCRIT",NULL},
/* 077E */ { "LETTRE ARABE SÎN V RENVERSÉ",NULL},
/* 077F */ { "LETTRE ARABE KAF DEUX POINTS EN CHEF",NULL},
/* 0780 */ { "LETTRE THÂNA HÂ",NULL},
/* 0781 */ { "LETTRE THÂNA CHAVIYANI",NULL},
/* 0782 */ { "LETTRE THÂNA NOÛNOU",NULL},
/* 0783 */ { "LETTRE THÂNA RÂ",NULL},
/* 0784 */ { "LETTRE THÂNA BÂ",NULL},
/* 0785 */ { "LETTRE THÂNA LHAVIYANI",NULL},
/* 0786 */ { "LETTRE THÂNA KÂFOU",NULL},
/* 0787 */ { "LETTRE THÂNA ALIFOU",NULL},
/* 0788 */ { "LETTRE THÂNA VÂVOU",NULL},
/* 0789 */ { "LETTRE THÂNA MÎMOU",NULL},
/* 078A */ { "LETTRE THÂNA FÂFOU",NULL},
/* 078B */ { "LETTRE THÂNA DHÂLOU",NULL},
/* 078C */ { "LETTRE THÂNA THÂ",NULL},
/* 078D */ { "LETTRE THÂNA LÂMOU",NULL},
/* 078E */ { "LETTRE THÂNA GÂFOU",NULL},
/* 078F */ { "LETTRE THÂNA ÑAVIYANI",NULL},
/* 0790 */ { "LETTRE THÂNA SÉÉNOU",NULL},
/* 0791 */ { "LETTRE THÂNA DAVIYANI",NULL},
/* 0792 */ { "LETTRE THÂNA ZAVIYANI",NULL},
/* 0793 */ { "LETTRE THÂNA TAVIYANI",NULL},
/* 0794 */ { "LETTRE THÂNA YÂ",NULL},
/* 0795 */ { "LETTRE THÂNA PAVIYANI",NULL},
/* 0796 */ { "LETTRE THÂNA DJAVIYANI",NULL},
/* 0797 */ { "LETTRE THÂNA TCHHAVIYANI",NULL},
/* 0798 */ { "LETTRE THÂNA TTÂ",NULL},
/* 0799 */ { "LETTRE THÂNA HHÂ",NULL},
/* 079A */ { "LETTRE THÂNA KHÂ",NULL},
/* 079B */ { "LETTRE THÂNA THÂLOU",NULL},
/* 079C */ { "LETTRE THÂNA ZÂ",NULL},
/* 079D */ { "LETTRE THÂNA CHÎNOU",NULL},
/* 079E */ { "LETTRE THÂNA SÂDHOU",NULL},
/* 079F */ { "LETTRE THÂNA DÂDHOU",NULL},
/* 07A0 */ { "LETTRE THÂNA TO",NULL},
/* 07A1 */ { "LETTRE THÂNA ZO",NULL},
/* 07A2 */ { "LETTRE THÂNA AÏNOU",NULL},
/* 07A3 */ { "LETTRE THÂNA GHAÏNOU",NULL},
/* 07A4 */ { "LETTRE THÂNA QÂFOU",NULL},
/* 07A5 */ { "LETTRE THÂNA WÂVOU",NULL},
/* 07A6 */ { "ABAFILI THÂNA",NULL},
/* 07A7 */ { "ÂBÂFILI THÂNA",NULL},
/* 07A8 */ { "IBIFILI THÂNA",NULL},
/* 07A9 */ { "ÎBÎFILI THÂNA",NULL},
/* 07AA */ { "OUBOUFILI THÂNA",NULL},
/* 07AB */ { "OÛBOÛFILI THÂNA",NULL},
/* 07AC */ { "ÉBÉFILI THÂNA",NULL},
/* 07AD */ { "ÉÉBÉÉFILI THÂNA",NULL},
/* 07AE */ { "OBOFILI THÂNA",NULL},
/* 07AF */ { "ÔBÔFILI THÂNA",NULL},
/* 07B0 */ { "SOUKOUN THÂNA",NULL},
/* 07B1 */ { "LETTRE THÂNA NÂ",NULL},
/* 07B2 */ { NULL,NULL},
/* 07B3 */ { NULL,NULL},
/* 07B4 */ { NULL,NULL},
/* 07B5 */ { NULL,NULL},
/* 07B6 */ { NULL,NULL},
/* 07B7 */ { NULL,NULL},
/* 07B8 */ { NULL,NULL},
/* 07B9 */ { NULL,NULL},
/* 07BA */ { NULL,NULL},
/* 07BB */ { NULL,NULL},
/* 07BC */ { NULL,NULL},
/* 07BD */ { NULL,NULL},
/* 07BE */ { NULL,NULL},
/* 07BF */ { NULL,NULL},
/* 07C0 */ { "CHIFFRE N'KO ZÉRO",NULL},
/* 07C1 */ { "CHIFFRE N'KO UN",NULL},
/* 07C2 */ { "CHIFFRE N'KO DEUX",NULL},
/* 07C3 */ { "CHIFFRE N'KO TROIS",NULL},
/* 07C4 */ { "CHIFFRE N'KO QUATRE",NULL},
/* 07C5 */ { "CHIFFRE N'KO CINQ",NULL},
/* 07C6 */ { "CHIFFRE N'KO SIX",NULL},
/* 07C7 */ { "CHIFFRE N'KO SEPT",NULL},
/* 07C8 */ { "CHIFFRE N'KO HUIT",NULL},
/* 07C9 */ { "CHIFFRE N'KO NEUF",NULL},
/* 07CA */ { "LETTRE N'KO A",NULL},
/* 07CB */ { "LETTRE N'KO É",NULL},
/* 07CC */ { "LETTRE N'KO I",NULL},
/* 07CD */ { "LETTRE N'KO È",NULL},
/* 07CE */ { "LETTRE N'KO OU",NULL},
/* 07CF */ { "LETTRE N'KO Ô",NULL},
/* 07D0 */ { "LETTRE N'KO O",NULL},
/* 07D1 */ { "LETTRE N'KO DAGBASIN'NA",NULL},
/* 07D2 */ { "LETTRE N'KO N'","	= n syllabique"},
/* 07D3 */ { "LETTRE N'KO BA",NULL},
/* 07D4 */ { "LETTRE N'KO PA",NULL},
/* 07D5 */ { "LETTRE N'KO TA",NULL},
/* 07D6 */ { "LETTRE N'KO DJA",NULL},
/* 07D7 */ { "LETTRE N'KO TCHA",NULL},
/* 07D8 */ { "LETTRE N'KO DA",NULL},
/* 07D9 */ { "LETTRE N'KO RA",NULL},
/* 07DA */ { "LETTRE N'KO RRA",NULL},
/* 07DB */ { "LETTRE N'KO SA",NULL},
/* 07DC */ { "LETTRE N'KO GBA",NULL},
/* 07DD */ { "LETTRE N'KO FA",NULL},
/* 07DE */ { "LETTRE N'KO KA",NULL},
/* 07DF */ { "LETTRE N'KO LA",NULL},
/* 07E0 */ { "LETTRE N'KO NA WOLOSO",NULL},
/* 07E1 */ { "LETTRE N'KO MA",NULL},
/* 07E2 */ { "LETTRE N'KO GNA","	= lettre n'ko nya"},
/* 07E3 */ { "LETTRE N'KO NA",NULL},
/* 07E4 */ { "LETTRE N'KO HA",NULL},
/* 07E5 */ { "LETTRE N'KO WA",NULL},
/* 07E6 */ { "LETTRE N'KO YA",NULL},
/* 07E7 */ { "LETTRE N'KO GNA WOLOSO","	= lettre n'ko nya woloso"},
/* 07E8 */ { "LETTRE N'KO DJONA DJA","	= lettre archaïque dja"},
/* 07E9 */ { "LETTRE N'KO DJONA TCHA","	= lettre archaïque tcha"},
/* 07EA */ { "LETTRE N'KO DJONA RA","	= lettre archaïque ra\n"
	"	x (lettre n'ko ra - 07D9)"},
/* 07EB */ { "DIACRITIQUE N'KO TON BREF HAUT","	x (diacritique macron - 0304)"},
/* 07EC */ { "DIACRITIQUE N'KO TON BREF BAS","	x (diacritique tilde - 0303)"},
/* 07ED */ { "DIACRITIQUE N'KO TON BREF MONTANT","	x (diacritique point en chef - 0307)"},
/* 07EE */ { "DIACRITIQUE N'KO TON LONG DESCENDANT","	x (diacritique accent circonflexe - 0302)"},
/* 07EF */ { "DIACRITIQUE N'KO TON LONG HAUT",NULL},
/* 07F0 */ { "DIACRITIQUE N'KO TON LONG BAS",NULL},
/* 07F1 */ { "DIACRITIQUE N'KO TON LONG MONTANT",NULL},
/* 07F2 */ { "DIACRITIQUE N'KO DE NASALISATION","	x (diacritique point souscrit - 0323)"},
/* 07F3 */ { "DIACRITIQUE N'KO TRÉMA EXTENSEUR","	x (diacritique tréma - 0308)"},
/* 07F4 */ { "APOSTROPHE N'KO DE TON HAUT","	x (lettre modificative apostrophe - 02BC)"},
/* 07F5 */ { "APOSTROPHE N'KO DE TON BAS","	x (lettre modificative virgule culbutée - 02BB)"},
/* 07F6 */ { "SYMBOLE N'KO Ô DÉNÈN","	* indique que le thème abordé se déroulera dans un futur lointain"},
/* 07F7 */ { "SYMBOLE N'KO GBAKOUROUNÈN","	* indique la fin d'un passage important\n"
	"	* le symbole représente les trois pierres sur lesquelles on pose un pot pour la cuisson"},
/* 07F8 */ { "VIRGULE N'KO",NULL},
/* 07F9 */ { "POINT D'EXCLAMATION N'KO",NULL},
/* 07FA */ { "LADJAGNALAN N'KO","	x (tiret bas - 005F)\n"
	"	x (tatouïl arabe - 0640)"},
/* 07FB */ { NULL,NULL},
/* 07FC */ { NULL,NULL},
/* 07FD */ { "DANTAYALAN N'KO","	* s'emploie pour abréger des unités de mesure\n"
	"	x (diacritique pontet souscrit - 032A)"},
/* 07FE */ { "SYMBOLE N'KO DOROMÈ","	x (lettre n'ko da - 07D8)"},
/* 07FF */ { "SYMBOLE N'KO TAMAN","	x (lettre n'ko ta - 07D5)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_08[] = {
/* 0800 */ { "LETTRE SAMARITAINE ALAF",NULL},
/* 0801 */ { "LETTRE SAMARITAINE BIT",NULL},
/* 0802 */ { "LETTRE SAMARITAINE GAMAN",NULL},
/* 0803 */ { "LETTRE SAMARITAINE DALAT",NULL},
/* 0804 */ { "LETTRE SAMARITAINE IY",NULL},
/* 0805 */ { "LETTRE SAMARITAINE BÂ",NULL},
/* 0806 */ { "LETTRE SAMARITAINE ZEN",NULL},
/* 0807 */ { "LETTRE SAMARITAINE IT",NULL},
/* 0808 */ { "LETTRE SAMARITAINE TIT",NULL},
/* 0809 */ { "LETTRE SAMARITAINE YOUT",NULL},
/* 080A */ { "LETTRE SAMARITAINE KÂF",NULL},
/* 080B */ { "LETTRE SAMARITAINE LABAT",NULL},
/* 080C */ { "LETTRE SAMARITAINE MIM",NULL},
/* 080D */ { "LETTRE SAMARITAINE NOUN",NULL},
/* 080E */ { "LETTRE SAMARITAINE SINGÂT",NULL},
/* 080F */ { "LETTRE SAMARITAINE IN",NULL},
/* 0810 */ { "LETTRE SAMARITAINE FI",NULL},
/* 0811 */ { "LETTRE SAMARITAINE TSÂDIY",NULL},
/* 0812 */ { "LETTRE SAMARITAINE QOUF",NULL},
/* 0813 */ { "LETTRE SAMARITAINE RICH",NULL},
/* 0814 */ { "LETTRE SAMARITAINE CHAN",NULL},
/* 0815 */ { "LETTRE SAMARITAINE TÂF",NULL},
/* 0816 */ { "DIACRITIQUE SAMARITAIN IN",NULL},
/* 0817 */ { "DIACRITIQUE SAMARITAIN IN-ALAF",NULL},
/* 0818 */ { "DIACRITIQUE SAMARITAIN OCCLUSION",NULL},
/* 0819 */ { "DIACRITIQUE SAMARITAIN DAGUÈCH",NULL},
/* 081A */ { "LETTRE MODIFICATIVE SAMARITAINE ÉPENTHÉTIQUE YOUT",NULL},
/* 081B */ { "DIACRITIQUE SAMARITAIN ÉPENTHÉTIQUE YOUT",NULL},
/* 081C */ { "DIACRITIQUE VOYELLE SAMARITAINE É LONG","	= fatha al-nida"},
/* 081D */ { "DIACRITIQUE VOYELLE SAMARITAINE É",NULL},
/* 081E */ { "DIACRITIQUE VOYELLE SAMARITAINE Â TRÈS LONG","	= fatha al-ima"},
/* 081F */ { "DIACRITIQUE VOYELLE SAMARITAINE Â LONG",NULL},
/* 0820 */ { "DIACRITIQUE VOYELLE SAMARITAINE Â",NULL},
/* 0821 */ { "DIACRITIQUE VOYELLE SAMARITAINE A TRÈS LONG","	= fatha al-iha"},
/* 0822 */ { "DIACRITIQUE VOYELLE SAMARITAINE A LONG",NULL},
/* 0823 */ { "DIACRITIQUE VOYELLE SAMARITAINE A",NULL},
/* 0824 */ { "LETTRE MODIFICATIVE SAMARITAINE A BREF",NULL},
/* 0825 */ { "DIACRITIQUE VOYELLE SAMARITAINE A BREF","	= fatha"},
/* 0826 */ { "DIACRITIQUE VOYELLE SAMARITAINE OU LONG","	= damma"},
/* 0827 */ { "DIACRITIQUE VOYELLE SAMARITAINE OU",NULL},
/* 0828 */ { "LETTRE MODIFICATIVE SAMARITAINE I",NULL},
/* 0829 */ { "DIACRITIQUE VOYELLE SAMARITAINE I LONG","	= kasra"},
/* 082A */ { "DIACRITIQUE VOYELLE SAMARITAINE I",NULL},
/* 082B */ { "DIACRITIQUE VOYELLE SAMARITAINE O",NULL},
/* 082C */ { "DIACRITIQUE VOYELLE SAMARITAINE SOUKOUN",NULL},
/* 082D */ { "DIACRITIQUE SAMARITAIN NEQOUDÂ",NULL},
/* 082E */ { NULL,NULL},
/* 082F */ { NULL,NULL},
/* 0830 */ { "PONCTUATION SAMARITAINE NEQOUDÂ","	= séparateur de mots"},
/* 0831 */ { "PONCTUATION SAMARITAINE AFSÂQ","	= interruption"},
/* 0832 */ { "PONCTUATION SAMARITAINE ANGED","	= retenue"},
/* 0833 */ { "PONCTUATION SAMARITAINE BAOU","	= prière"},
/* 0834 */ { "PONCTUATION SAMARITAINE ATMÂOU","	= surprise"},
/* 0835 */ { "PONCTUATION SAMARITAINE SHIYYÂLÂ","	= question"},
/* 0836 */ { "SIGNE D'ABRÉVIATION SAMARITAIN",NULL},
/* 0837 */ { "PONCTUATION SAMARITAINE QITSA MÉLODIQUE",NULL},
/* 0838 */ { "PONCTUATION SAMARITAINE ZIQÂ","	= cris"},
/* 0839 */ { "PONCTUATION SAMARITAINE QITSA","	= fin de paragraphe"},
/* 083A */ { "PONCTUATION SAMARITAINE ZAEF","	= éclat"},
/* 083B */ { "PONCTUATION SAMARITAINE TOUROU","	= enseignement"},
/* 083C */ { "PONCTUATION SAMARITAINE ARKÂNOU","	= soumission"},
/* 083D */ { "PONCTUATION SAMARITAINE SOF MACHFÂT","	= point final"},
/* 083E */ { "PONCTUATION SAMARITAINE ANNÂOU","	= repos"},
/* 083F */ { NULL,NULL},
/* 0840 */ { "LETTRE MANDÉENNE HALQA",NULL},
/* 0841 */ { "LETTRE MANDÉENNE AB",NULL},
/* 0842 */ { "LETTRE MANDÉENNE AG",NULL},
/* 0843 */ { "LETTRE MANDÉENNE AD",NULL},
/* 0844 */ { "LETTRE MANDÉENNE AH",NULL},
/* 0845 */ { "LETTRE MANDÉENNE OUCHENNA",NULL},
/* 0846 */ { "LETTRE MANDÉENNE AZ",NULL},
/* 0847 */ { "LETTRE MANDÉENNE IT",NULL},
/* 0848 */ { "LETTRE MANDÉENNE ATT",NULL},
/* 0849 */ { "LETTRE MANDÉENNE AKSA",NULL},
/* 084A */ { "LETTRE MANDÉENNE AK",NULL},
/* 084B */ { "LETTRE MANDÉENNE AL",NULL},
/* 084C */ { "LETTRE MANDÉENNE AM",NULL},
/* 084D */ { "LETTRE MANDÉENNE AN",NULL},
/* 084E */ { "LETTRE MANDÉENNE AS",NULL},
/* 084F */ { "LETTRE MANDÉENNE IN",NULL},
/* 0850 */ { "LETTRE MANDÉENNE AP",NULL},
/* 0851 */ { "LETTRE MANDÉENNE ASZ",NULL},
/* 0852 */ { "LETTRE MANDÉENNE AQ",NULL},
/* 0853 */ { "LETTRE MANDÉENNE AR",NULL},
/* 0854 */ { "LETTRE MANDÉENNE ASH",NULL},
/* 0855 */ { "LETTRE MANDÉENNE AT",NULL},
/* 0856 */ { "LETTRE MANDÉENNE DOUCHENNA",NULL},
/* 0857 */ { "LETTRE MANDÉENNE KAD",NULL},
/* 0858 */ { "LETTRE MANDÉENNE 'AÏN",NULL},
/* 0859 */ { "DIACRITIQUE MANDÉEN D'AFFRICATION",NULL},
/* 085A */ { "DIACRITIQUE MANDÉEN DE VOCALISATION",NULL},
/* 085B */ { "DIACRITIQUE MANDÉEN DE GÉMINATION",NULL},
/* 085C */ { NULL,NULL},
/* 085D */ { NULL,NULL},
/* 085E */ { "PONCTUATION MANDÉENNE",NULL},
/* 085F */ { NULL,NULL},
/* 0860 */ { "LETTRE SYRIAQUE MALAYALAM NGA","	x (lettre malayalam nga - 0D19)"},
/* 0861 */ { "LETTRE SYRIAQUE MALAYALAM DJA","	x (lettre malayalam dja - 0D1C)"},
/* 0862 */ { "LETTRE SYRIAQUE MALAYALAM ÑA","	x (lettre malayalam ña - 0D1E)"},
/* 0863 */ { "LETTRE SYRIAQUE MALAYALAM TTA","	x (lettre malayalam tta - 0D1F)"},
/* 0864 */ { "LETTRE SYRIAQUE MALAYALAM NNA","	x (lettre malayalam nna - 0D23)"},
/* 0865 */ { "LETTRE SYRIAQUE MALAYALAM NNNA","	x (lettre malayalam nnna - 0D29)"},
/* 0866 */ { "LETTRE SYRIAQUE MALAYALAM BHA","	x (lettre malayalam bha - 0D2D)"},
/* 0867 */ { "LETTRE SYRIAQUE MALAYALAM RA","	x (lettre malayalam ra - 0D30)"},
/* 0868 */ { "LETTRE SYRIAQUE MALAYALAM LLA","	x (lettre malayalam lla - 0D33)"},
/* 0869 */ { "LETTRE SYRIAQUE MALAYALAM LLLA","	x (lettre malayalam llla - 0D34)"},
/* 086A */ { "LETTRE SYRIAQUE MALAYALAM CHA","	x (lettre malayalam cha - 0D37)"},
/* 086B */ { NULL,NULL},
/* 086C */ { NULL,NULL},
/* 086D */ { NULL,NULL},
/* 086E */ { NULL,NULL},
/* 086F */ { NULL,NULL},
/* 0870 */ { "LETTRE ARABE ALIF FATHA ATTACHÉ",NULL},
/* 0871 */ { "LETTRE ARABE ALIF FATHA SUPÉRIEUR DROIT ATTACHÉ",NULL},
/* 0872 */ { "LETTRE ARABE ALIF BARRE CENTRALE À DROITE",NULL},
/* 0873 */ { "LETTRE ARABE ALIF BARRE CENTRALE À GAUCHE",NULL},
/* 0874 */ { "LETTRE ARABE ALIF KASRA ATTACHÉ",NULL},
/* 0875 */ { "LETTRE ARABE ALIF KASRA INFÉRIEUR DROIT ATTACHÉ",NULL},
/* 0876 */ { "LETTRE ARABE ALIF POINT ROND EN CHEF ATTACHÉ",NULL},
/* 0877 */ { "LETTRE ARABE ALIF POINT ROND DROIT ATTACHÉ",NULL},
/* 0878 */ { "LETTRE ARABE ALIF POINT ROND GAUCHE ATTACHÉ",NULL},
/* 0879 */ { "LETTRE ARABE ALIF POINT ROND SOUSCRIT ATTACHÉ",NULL},
/* 087A */ { "LETTRE ARABE ALIF POINT EN CHEF",NULL},
/* 087B */ { "LETTRE ARABE ALIF FATHA SUPÉRIEUR DROIT ATTACHÉ ET POINT EN CHEF",NULL},
/* 087C */ { "LETTRE ARABE ALIF BARRE CENTRALE À DROITE ET POINT EN CHEF",NULL},
/* 087D */ { "LETTRE ARABE ALIF KASRA INFÉRIEUR DROIT ATTACHÉ ET POINT EN CHEF",NULL},
/* 087E */ { "LETTRE ARABE ALIF FATHA SUPÉRIEUR DROIT ATTACHÉ ET ROND À DROITE",NULL},
/* 087F */ { "LETTRE ARABE ALIF BARRE CENTRALE À DROITE ET ROND GAUCHE",NULL},
/* 0880 */ { "LETTRE ARABE ALIF KASRA INFÉRIEUR DROIT ATTACHÉ ET ROND GAUCHE",NULL},
/* 0881 */ { "LETTRE ARABE ALIF HAMZA DROITE ATTACHÉE",NULL},
/* 0882 */ { "LETTRE ARABE ALIF HAMZA GAUCHE ATTACHÉE",NULL},
/* 0883 */ { "TATOUÏL ARABE HAMZA SUPERPOSÉE",NULL},
/* 0884 */ { "TATOUÏL ARABE WAW SUPERPOSÉ",NULL},
/* 0885 */ { "TATOUÏL ARABE DEUX POINTS SOUSCRITS",NULL},
/* 0886 */ { "LETTRE ARABE YA' MINCE","	* aucune forme finale ou isolée n'est attestée"},
/* 0887 */ { "POINT ROND ARABE SUR LA LIGNE",NULL},
/* 0888 */ { "POINT ROND ARABE ÉLEVÉ",NULL},
/* 0889 */ { "LETTRE ARABE NOÛN PIGNON",NULL},
/* 088A */ { "LETTRE ARABE HA' PIGNON SOUSCRIT",NULL},
/* 088B */ { "LETTRE ARABE TA' POINT SOUSCRIT","	* pégon, malgache"},
/* 088C */ { "LETTRE ARABE TA' TROIS POINTS SOUSCRITS","	* variante pégon pour 088B"},
/* 088D */ { "LETTRE ARABE KEHA' DEUX POINTS VERTICAUX SOUSCRITS","	* pégon soundanais"},
/* 088E */ { "QUEUE VERTICALE ARABE","	* signe utilisé pour indiquer des abréviations dans l'impression des premiers textes en caractères mobiles d'Iran\n"
	"	* uniquement attesté dans la forme finale"},
/* 088F */ { "LETTRE ARABE NOÛN ROND EN CHEF","	= arnoûn"},
/* 0890 */ { "SIGNE ARABE LIVRE EN CHEF","	* livre égyptienne"},
/* 0891 */ { "SIGNE ARABE PIASTRE EN CHEF","	* piastre égyptienne"},
/* 0892 */ { NULL,NULL},
/* 0893 */ { NULL,NULL},
/* 0894 */ { NULL,NULL},
/* 0895 */ { NULL,NULL},
/* 0896 */ { NULL,NULL},
/* 0897 */ { "PEPET ARABE","	x (madda arabe en chef - 0653)"},
/* 0898 */ { "PETIT MOT ARABE EN CHEF AL-DJOUZ",NULL},
/* 0899 */ { "PETIT MOT ARABE SOUSCRIT ICHMÂM",NULL},
/* 089A */ { "PETIT MOT ARABE SOUSCRIT IMÂLA",NULL},
/* 089B */ { "PETIT MOT ARABE SOUSCRIT TACHÎL",NULL},
/* 089C */ { "MADDA WÂDJIB ARABE","	x (madda arabe en chef - 0653)"},
/* 089D */ { "ALIF MOKHASSAS EN CHEF ARABE",NULL},
/* 089E */ { "DOUBLE MADDA ARABE",NULL},
/* 089F */ { "DEMI-MADDA SUR MADDA ARABE",NULL},
/* 08A0 */ { "LETTRE ARABE BA' PETIT V SOUSCRIT",NULL},
/* 08A1 */ { "LETTRE ARABE BA' HAMZA EN CHEF","	* foulfouldé d'Adamaoua (Cameroun)\n"
	"	* utilisée pour l'occlusive bilabiale implosive\n"
	"	x (lettre minuscule latine b crosse - 0253)"},
/* 08A2 */ { "LETTRE ARABE DJÎM DEUX POINTS EN CHEF",NULL},
/* 08A3 */ { "LETTRE ARABE TA' DEUX POINTS EN CHEF",NULL},
/* 08A4 */ { "LETTRE ARABE FA' POINT SOUSCRIT ET POINT EN CHEF",NULL},
/* 08A5 */ { "LETTRE ARABE QAF POINT SOUSCRIT",NULL},
/* 08A6 */ { "LETTRE ARABE LAM DOUBLE BARRE",NULL},
/* 08A7 */ { "LETTRE ARABE MÎM TROIS POINTS EN CHEF",NULL},
/* 08A8 */ { "LETTRE ARABE YA' DEUX POINTS SOUSCRITS ET HAMZA EN CHEF","	* foulfouldé d'Adamaoua\n"
	"	* implosive palatale spirante, réalisée par pharyngalisation de la spirante\n"
	"	x (lettre minuscule latine y crosse - 01B4)"},
/* 08A9 */ { "LETTRE ARABE YA' DEUX POINTS SOUSCRITS ET POINT EN CHEF","	* foulfouldé d'Adamaoua\n"
	"	* nasale palatale sonore\n"
	"	x (lettre minuscule latine n hameçon à gauche - 0272)"},
/* 08AA */ { "LETTRE ARABE RA' BOUCLE",NULL},
/* 08AB */ { "LETTRE ARABE WAW POINT INSCRIT",NULL},
/* 08AC */ { "LETTRE ARABE ROHINGYA YA'",NULL},
/* 08AD */ { "LETTRE ARABE ALIF BAS","	* bachkir, tatar"},
/* 08AE */ { "LETTRE ARABE DAL TROIS POINTS SOUSCRITS","	* biélorusse\n"
	"	* variante pégon pour 068A"},
/* 08AF */ { "LETTRE ARABE ÇAD TROIS POINTS SOUSCRITS","	* biélorusse"},
/* 08B0 */ { "LETTRE ARABE GAF TRAIT RENVERSÉ","	* tatar de Crimée, tchétchène, lak"},
/* 08B1 */ { "LETTRE ARABE WAW DROIT","	* tatar"},
/* 08B2 */ { "LETTRE ARABE ZAÏN V RENVERSÉ SUSCRIT",NULL},
/* 08B3 */ { "LETTRE ARABE 'AÏN TROIS POINTS SOUSCRITS",NULL},
/* 08B4 */ { "LETTRE ARABE KAF POINT SOUSCRIT","	* également utilisée en pégon\n"
	"	x (lettre arabe kaf trois points souscrits - 06AE)"},
/* 08B5 */ { "LETTRE ARABE QAF AVEC POINT SOUSCRIT ET SANS POINTS SUSCRITS",NULL},
/* 08B6 */ { "LETTRE ARABE BA' PETIT MÎM EN CHEF",NULL},
/* 08B7 */ { "LETTRE ARABE PA' PETIT MÎM EN CHEF",NULL},
/* 08B8 */ { "LETTRE ARABE TÉ' PETIT TÉ' EN CHEF",NULL},
/* 08B9 */ { "LETTRE ARABE RA' PETIT NOÛN EN CHEF",NULL},
/* 08BA */ { "LETTRE ARABE YA' DEUX POINTS SOUSCRITS ET PETIT NOÛN EN CHEF",NULL},
/* 08BB */ { "LETTRE ARABE AFRICAINE FA'","	* les formes de cette lettre en position initiale et médiale comportent un point souscrit\n"
	"	x (lettre arabe fa' sans point - 06A1)\n"
	"	x (lettre arabe fa' point descendu - 06A2)"},
/* 08BC */ { "LETTRE ARABE AFRICAINE QAF","	* les formes de cette lettre en position initiale et médiale comportent un point suscrit\n"
	"	x (lettre arabe qaf sans point - 066F)\n"
	"	x (lettre arabe qaf point en chef - 06A7)\n"
	"	x (lettre arabe africaine qaf trois points en chef - 08C4)"},
/* 08BD */ { "LETTRE ARABE AFRICAINE NOÛN","	* les formes de cette lettre en position initiale et médiale comportent un point suscrit\n"
	"	x (lettre arabe noûn ghounna - 06BA)\n"
	"	x (lettre arabe noûn - 0646)"},
/* 08BE */ { "LETTRE ARABE PA' PETIT V",NULL},
/* 08BF */ { "LETTRE ARABE TÉ' PETIT V",NULL},
/* 08C0 */ { "LETTRE ARABE TTA PETIT V",NULL},
/* 08C1 */ { "LETTRE ARABE TCHIM' PETIT V",NULL},
/* 08C2 */ { "LETTRE ARABE KEHA' PETIT V",NULL},
/* 08C3 */ { "LETTRE ARABE GHAÏN TROIS POINTS EN CHEF",NULL},
/* 08C4 */ { "LETTRE ARABE AFRICAINE QAF TROIS POINTS EN CHEF","	* cette lettre est surmontée d'un point supplémentaire uniquement dans ses positions initiale et médiale\n"
	"	x (lettre arabe africaine qaf - 08BC)"},
/* 08C5 */ { "LETTRE ARABE DJÎM TROIS POINTS EN CHEF",NULL},
/* 08C6 */ { "LETTRE ARABE DJÎM TROIS POINTS SOUSCRITS",NULL},
/* 08C7 */ { "LETTRE ARABE LAM PETIT TA' EN CHEF",NULL},
/* 08C8 */ { "LETTRE ARABE GRAF",NULL},
/* 08C9 */ { "PETIT YA' ARABE FARSI",NULL},
/* 08CA */ { "PETIT YA' ARABE FARSI EN CHEF",NULL},
/* 08CB */ { "PETIT YA' BARRÉ ARABE EN CHEF DEUX POINTS SOUSCRITS","	x (petit ya' barré arabe deux points souscrits - 10EC5)"},
/* 08CC */ { "PETIT MOT ARABE EN CHEF SAH",NULL},
/* 08CD */ { "PETIT ZAH ARABE EN CHEF",NULL},
/* 08CE */ { "POINT ROND LARGE ARABE EN CHEF",NULL},
/* 08CF */ { "POINT ROND LARGE ARABE SOUSCRIT",NULL},
/* 08D0 */ { "SOUKOUN ARABE SOUSCRIT",NULL},
/* 08D1 */ { "CERCLE LARGE ARABE SOUSCRIT",NULL},
/* 08D2 */ { "POINT ROND LARGE ARABE DANS CERCLE SOUSCRIT",NULL},
/* 08D3 */ { "PETIT WAW ARABE SOUSCRIT",NULL},
/* 08D4 */ { "PETIT MOT ARABE EN CHEF AR-ROUB",NULL},
/* 08D5 */ { "PETIT ÇAD ARABE EN CHEF",NULL},
/* 08D6 */ { "PETIT 'AÏN ARABE EN CHEF",NULL},
/* 08D7 */ { "PETIT QAF ARABE EN CHEF",NULL},
/* 08D8 */ { "PETIT NOÛN ARABE EN CHEF AVEC KASRA",NULL},
/* 08D9 */ { "PETIT NOÛN ARABE SOUSCRIT AVEC KASRA","	x (petit noûn arabe souscrit - 10EFB)"},
/* 08DA */ { "PETIT MOT ARABE EN CHEF ATH-THALATHA",NULL},
/* 08DB */ { "PETIT MOT ARABE EN CHEF AS-SADJDA",NULL},
/* 08DC */ { "PETIT MOT ARABE EN CHEF AN-NISF",NULL},
/* 08DD */ { "PETIT MOT ARABE EN CHEF SAKTA","	x (petit mot arabe souscrit sakta - 10EFD)"},
/* 08DE */ { "PETIT MOT ARABE EN CHEF QIF",NULL},
/* 08DF */ { "PETIT MOT ARABE EN CHEF WAQFA",NULL},
/* 08E0 */ { "PETIT APPEL DE NOTE ARABE EN CHEF",NULL},
/* 08E1 */ { "PETIT SIGNE ARABE EN CHEF SAPHA",NULL},
/* 08E2 */ { "FIN CONTESTÉE D'AYA ARABE",NULL},
/* 08E3 */ { "DAMMA ARABE CULBUTÉ SOUSCRIT",NULL},
/* 08E4 */ { "FATHA ARABE RECOURBÉ",NULL},
/* 08E5 */ { "DAMMA ARABE RECOURBÉ",NULL},
/* 08E6 */ { "KASRA ARABE RECOURBÉ",NULL},
/* 08E7 */ { "FATHATAN ARABE RECOURBÉ",NULL},
/* 08E8 */ { "DAMMATAN ARABE RECOURBÉ",NULL},
/* 08E9 */ { "KASRATAN ARABE RECOURBÉ",NULL},
/* 08EA */ { "TON ARABE POINT EN CHEF",NULL},
/* 08EB */ { "TON ARABE DEUX POINTS EN CHEF",NULL},
/* 08EC */ { "TON ARABE BOUCLE EN CHEF",NULL},
/* 08ED */ { "TON ARABE POINT SOUSCRIT",NULL},
/* 08EE */ { "TON ARABE DEUX POINTS SOUSCRITS",NULL},
/* 08EF */ { "TON ARABE BOUCLE SOUSCRITE",NULL},
/* 08F0 */ { "FATHATAN ARABE OUVERT",NULL},
/* 08F1 */ { "DAMMATAN ARABE OUVERT",NULL},
/* 08F2 */ { "KASRATAN ARABE OUVERT",NULL},
/* 08F3 */ { "PETIT WAW ARABE EN CHEF",NULL},
/* 08F4 */ { "FATHA ARABE AVEC ROND",NULL},
/* 08F5 */ { "FATHA ARABE POINT EN CHEF",NULL},
/* 08F6 */ { "KASRA ARABE POINT SOUSCRIT","	* utilisé aussi dans les langues philippines"},
/* 08F7 */ { "POINTE DE FLÈCHE ARABE EN CHEF VERS LA GAUCHE",NULL},
/* 08F8 */ { "POINTE DE FLÈCHE ARABE EN CHEF VERS LA DROITE","	* s'emploie aussi dans des textes coraniques utilisant des orthographes africaines et d'autres orthographes pour représenter un damma"},
/* 08F9 */ { "POINTE DE FLÈCHE ARABE SOUSCRITE VERS LA GAUCHE",NULL},
/* 08FA */ { "POINTE DE FLÈCHE ARABE SOUSCRITE VERS LA DROITE",NULL},
/* 08FB */ { "DOUBLE POINTE DE FLÈCHE ARABE EN CHEF VERS LA DROITE","	* s'emploie aussi dans des textes coraniques utilisant des orthographes africaines et d'autres orthographes pour représenter un dammatan"},
/* 08FC */ { "DOUBLE POINTE DE FLÈCHE ARABE EN CHEF VERS LA DROITE AVEC POINT",NULL},
/* 08FD */ { "POINTE DE FLÈCHE ARABE EN CHEF VERS LA DROITE AVEC POINT",NULL},
/* 08FE */ { "DAMMA ARABE AVEC POINT","	* langues philippines"},
/* 08FF */ { "DIACRITIQUE ARABE NOÛN GHOUNNA COUCHÉ",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_09[] = {
/* 0900 */ { "DIACRITIQUE DÉVANÂGARÎ TCHANDRABINDOU RENVERSÉ","	= vaïdika adhomoukha tchandrabindou"},
/* 0901 */ { "DIACRITIQUE DÉVANÂGARÎ TCHANDRABINDOU","	= anounassika\n"
	"	x (diacritique tchandrabindou - 0310)"},
/* 0902 */ { "DIACRITIQUE DÉVANÂGARÎ ANOUSVÂRA","	= bindou"},
/* 0903 */ { "DIACRITIQUE DÉVANÂGARÎ VISARGA",NULL},
/* 0904 */ { "LETTRE DÉVANÂGARÎ A BREF","	* utilisée pour le e bref en awadhi\n"
	"	* utilisée aussi dans des translittérations en dévanâgarî de quelques langues de l'Inde du Sud et du Cachemire par un éditeur de Lucknow"},
/* 0905 */ { "LETTRE DÉVANÂGARÎ A",NULL},
/* 0906 */ { "LETTRE DÉVANÂGARÎ Â",NULL},
/* 0907 */ { "LETTRE DÉVANÂGARÎ I",NULL},
/* 0908 */ { "LETTRE DÉVANÂGARÎ Î",NULL},
/* 0909 */ { "LETTRE DÉVANÂGARÎ OU",NULL},
/* 090A */ { "LETTRE DÉVANÂGARÎ OÛ",NULL},
/* 090B */ { "LETTRE DÉVANÂGARÎ R VOCALIQUE",NULL},
/* 090C */ { "LETTRE DÉVANÂGARÎ L VOCALIQUE",NULL},
/* 090D */ { "LETTRE DÉVANÂGARÎ É TCHANDRA",NULL},
/* 090E */ { "LETTRE DÉVANÂGARÎ É BREF","	* cachemiri, bihari\n"
	"	* sert aussi pour transcrire le e bref dravidien"},
/* 090F */ { "LETTRE DÉVANÂGARÎ É",NULL},
/* 0910 */ { "LETTRE DÉVANÂGARÎ AI",NULL},
/* 0911 */ { "LETTRE DÉVANÂGARÎ O TCHANDRA",NULL},
/* 0912 */ { "LETTRE DÉVANÂGARÎ O BREF","	* cachemiri, bihari\n"
	"	* sert aussi pour transcrire le o bref dravidien"},
/* 0913 */ { "LETTRE DÉVANÂGARÎ O",NULL},
/* 0914 */ { "LETTRE DÉVANÂGARÎ AOU",NULL},
/* 0915 */ { "LETTRE DÉVANÂGARÎ KA",NULL},
/* 0916 */ { "LETTRE DÉVANÂGARÎ KHA",NULL},
/* 0917 */ { "LETTRE DÉVANÂGARÎ GA",NULL},
/* 0918 */ { "LETTRE DÉVANÂGARÎ GHA",NULL},
/* 0919 */ { "LETTRE DÉVANÂGARÎ NGA",NULL},
/* 091A */ { "LETTRE DÉVANÂGARÎ TCHA",NULL},
/* 091B */ { "LETTRE DÉVANÂGARÎ TCHHA",NULL},
/* 091C */ { "LETTRE DÉVANÂGARÎ DJA",NULL},
/* 091D */ { "LETTRE DÉVANÂGARÎ DJHA",NULL},
/* 091E */ { "LETTRE DÉVANÂGARÎ ÑA",NULL},
/* 091F */ { "LETTRE DÉVANÂGARÎ TTA",NULL},
/* 0920 */ { "LETTRE DÉVANÂGARÎ TTHA",NULL},
/* 0921 */ { "LETTRE DÉVANÂGARÎ DDA",NULL},
/* 0922 */ { "LETTRE DÉVANÂGARÎ DDHA",NULL},
/* 0923 */ { "LETTRE DÉVANÂGARÎ NNA",NULL},
/* 0924 */ { "LETTRE DÉVANÂGARÎ TA",NULL},
/* 0925 */ { "LETTRE DÉVANÂGARÎ THA",NULL},
/* 0926 */ { "LETTRE DÉVANÂGARÎ DA",NULL},
/* 0927 */ { "LETTRE DÉVANÂGARÎ DHA",NULL},
/* 0928 */ { "LETTRE DÉVANÂGARÎ NA",NULL},
/* 0929 */ { "LETTRE DÉVANÂGARÎ NNNA","	* pour transcrire le n alvéolaire dravidien\n"
	"	: 0928 093C"},
/* 092A */ { "LETTRE DÉVANÂGARÎ PA",NULL},
/* 092B */ { "LETTRE DÉVANÂGARÎ PHA","	= lettre dévanâgarî p'a"},
/* 092C */ { "LETTRE DÉVANÂGARÎ BA",NULL},
/* 092D */ { "LETTRE DÉVANÂGARÎ BHA",NULL},
/* 092E */ { "LETTRE DÉVANÂGARÎ MA",NULL},
/* 092F */ { "LETTRE DÉVANÂGARÎ YA",NULL},
/* 0930 */ { "LETTRE DÉVANÂGARÎ RA",NULL},
/* 0931 */ { "LETTRE DÉVANÂGARÎ RRA","	* pour transcrire le r alvéolaire dravidien\n"
	"	* la demi-forme est représentée par un RA « cil »\n"
	"	: 0930 093C"},
/* 0932 */ { "LETTRE DÉVANÂGARÎ LA",NULL},
/* 0933 */ { "LETTRE DÉVANÂGARÎ LLA",NULL},
/* 0934 */ { "LETTRE DÉVANÂGARÎ LLLA","	* pour transcrire le l dravidien\n"
	"	: 0933 093C"},
/* 0935 */ { "LETTRE DÉVANÂGARÎ VA",NULL},
/* 0936 */ { "LETTRE DÉVANÂGARÎ ÇA",NULL},
/* 0937 */ { "LETTRE DÉVANÂGARÎ CHA",NULL},
/* 0938 */ { "LETTRE DÉVANÂGARÎ SA",NULL},
/* 0939 */ { "LETTRE DÉVANÂGARÎ HA",NULL},
/* 093A */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ E",NULL},
/* 093B */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ EE",NULL},
/* 093C */ { "DIACRITIQUE DÉVANÂGARÎ NOUKTA","	* pour étendre l'alphabet et former de nouvelles lettres"},
/* 093D */ { "SIGNE DÉVANÂGARÎ AVAGRAHA",NULL},
/* 093E */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ Â",NULL},
/* 093F */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ I","	* à gauche de la consonne"},
/* 0940 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ Î",NULL},
/* 0941 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ OU",NULL},
/* 0942 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ OÛ",NULL},
/* 0943 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ R VOCALIQUE",NULL},
/* 0944 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ RR VOCALIQUE",NULL},
/* 0945 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ É TCHANDRA",NULL},
/* 0946 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ É BREF","	* cachemiri, bihari\n"
	"	* sert aussi pour transcrire le e bref dravidien"},
/* 0947 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ É",NULL},
/* 0948 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ AI","	* souvent la monophtongue française « ê »"},
/* 0949 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ O TCHANDRA",NULL},
/* 094A */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ O BREF","	* cachemiri, bihari\n"
	"	* sert aussi pour transcrire le o bref dravidien"},
/* 094B */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ Ô",NULL},
/* 094C */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ AOU",NULL},
/* 094D */ { "DIACRITIQUE DÉVANÂGARÎ VIRÂMA","	= halant (le nom hindi recommandé)\n"
	"	* supprime la voyelle inhérente"},
/* 094E */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ É PRISHTHAMATRA","	* ce caractère a un usage historique uniquement\n"
	"	* se combine avec É pour former AÏ, avec Â pour former O, et avec O pour former AOU"},
/* 094F */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ AW","	* cachemiri, bihari"},
/* 0950 */ { "OM DÉVANÂGARÎ","	x (symbole om - 1F549)"},
/* 0951 */ { "DIACRITIQUE D'ACCENTUATION DÉVANÂGARÎ OUDATTA","	= ton védique oudatta\n"
	"	* utilisé le plus souvent pour le svarita, emploi rare pour l'oudatta\n"
	"	* utilisé aussi dans les textes védiques rédigés avec d'autres écritures\n"
	"	x (diacritique ton védique double svarita - 1CDA)"},
/* 0952 */ { "DIACRITIQUE D'ACCENTUATION DÉVANÂGARÎ ANOUDATTA","	= ton védique anoudatta\n"
	"	* utilisé aussi dans les textes védiques rédigés avec d'autres écritures\n"
	"	x (diacritique ton védique kathaka anoudatta - 1CDC)"},
/* 0953 */ { "ACCENT GRAVE DÉVANÂGARÎ","	x (diacritique accent grave - 0300)"},
/* 0954 */ { "ACCENT AIGU DÉVANÂGARÎ","	x (diacritique accent aigu - 0301)"},
/* 0955 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ É LONG TCHANDRA","	* s'emploie pour la translittération de l'avestique"},
/* 0956 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ U",NULL},
/* 0957 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ Û",NULL},
/* 0958 */ { "LETTRE DÉVANÂGARÎ QA","	: 0915 093C"},
/* 0959 */ { "LETTRE DÉVANÂGARÎ KHHA","	: 0916 093C"},
/* 095A */ { "LETTRE DÉVANÂGARÎ GHHA","	: 0917 093C"},
/* 095B */ { "LETTRE DÉVANÂGARÎ ZA","	: 091C 093C"},
/* 095C */ { "LETTRE DÉVANÂGARÎ DDDHA","	: 0921 093C"},
/* 095D */ { "LETTRE DÉVANÂGARÎ RHA","	: 0922 093C"},
/* 095E */ { "LETTRE DÉVANÂGARÎ FA","	: 092B 093C"},
/* 095F */ { "LETTRE DÉVANÂGARÎ YYA","	: 092F 093C"},
/* 0960 */ { "LETTRE DÉVANÂGARÎ RR VOCALIQUE",NULL},
/* 0961 */ { "LETTRE DÉVANÂGARÎ LL VOCALIQUE",NULL},
/* 0962 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ L VOCALIQUE",NULL},
/* 0963 */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ LL VOCALIQUE",NULL},
/* 0964 */ { "DANDA DÉVANÂGARÎ","	= pourna viram\n"
	"	* séparateur de propositions"},
/* 0965 */ { "DOUBLE DANDA DÉVANÂGARÎ","	= déérgh viram"},
/* 0966 */ { "CHIFFRE DÉVANÂGARÎ ZÉRO","	* sert aussi à représenter un anousvâra après des chiffres indiquant des svâras secondaires dans les textes samavédiques"},
/* 0967 */ { "CHIFFRE DÉVANÂGARÎ UN",NULL},
/* 0968 */ { "CHIFFRE DÉVANÂGARÎ DEUX",NULL},
/* 0969 */ { "CHIFFRE DÉVANÂGARÎ TROIS",NULL},
/* 096A */ { "CHIFFRE DÉVANÂGARÎ QUATRE",NULL},
/* 096B */ { "CHIFFRE DÉVANÂGARÎ CINQ",NULL},
/* 096C */ { "CHIFFRE DÉVANÂGARÎ SIX",NULL},
/* 096D */ { "CHIFFRE DÉVANÂGARÎ SEPT",NULL},
/* 096E */ { "CHIFFRE DÉVANÂGARÎ HUIT",NULL},
/* 096F */ { "CHIFFRE DÉVANÂGARÎ NEUF",NULL},
/* 0970 */ { "SIGNE D'ABRÉVIATION DÉVANÂGARÎ","	* pour des abréviations propres à la dévanâgarî"},
/* 0971 */ { "POINT À CHASSE DÉVANÂGARÎ ÉLEVÉ",NULL},
/* 0972 */ { "LETTRE DÉVANÂGARÎ A TCHANDRA",NULL},
/* 0973 */ { "LETTRE DÉVANÂGARÎ E",NULL},
/* 0974 */ { "LETTRE DÉVANÂGARÎ EE",NULL},
/* 0975 */ { "LETTRE DÉVANÂGARÎ AW",NULL},
/* 0976 */ { "LETTRE DÉVANÂGARÎ U",NULL},
/* 0977 */ { "LETTRE DÉVANÂGARÎ Û",NULL},
/* 0978 */ { "LETTRE DÉVANÂGARÎ MARWARI DDA",NULL},
/* 0979 */ { "LETTRE DÉVANÂGARÎ ZHA","	* s'emploie pour la translittération de l'avestique\n"
	"	x (lettre goudjarati zha - 0AF9)"},
/* 097A */ { "LETTRE DÉVANÂGARÎ YA LOURD","	* utilisée pour une semi-voyelle affriquée DJJYA"},
/* 097B */ { "LETTRE DÉVANÂGARÎ GGA",NULL},
/* 097C */ { "LETTRE DÉVANÂGARÎ DJJA",NULL},
/* 097D */ { "LETTRE DÉVANÂGARÎ COUP DE GLOTTE","	* utilisée dans l'écriture du limbu en dévanâgarî\n"
	"	* une variante est surmontée d'une barre supérieure continue (la ligne de tête)"},
/* 097E */ { "LETTRE DÉVANÂGARÎ DDDA",NULL},
/* 097F */ { "LETTRE DÉVANÂGARÎ BBA",NULL},
/* 0980 */ { "ANDJI BENGALI","	= siddham, siddhirastou\n"
	"	* placé au début d'un texte comme une invocation"},
/* 0981 */ { "DIACRITIQUE BENGALI TCHANDRABINDOU",NULL},
/* 0982 */ { "DIACRITIQUE BENGALI ANOUSVÂRA",NULL},
/* 0983 */ { "DIACRITIQUE BENGALI VISARGA",NULL},
/* 0984 */ { NULL,NULL},
/* 0985 */ { "LETTRE BENGALI A",NULL},
/* 0986 */ { "LETTRE BENGALI Â",NULL},
/* 0987 */ { "LETTRE BENGALI I",NULL},
/* 0988 */ { "LETTRE BENGALI Î",NULL},
/* 0989 */ { "LETTRE BENGALI OU",NULL},
/* 098A */ { "LETTRE BENGALI OÛ",NULL},
/* 098B */ { "LETTRE BENGALI R VOCALIQUE",NULL},
/* 098C */ { "LETTRE BENGALI L VOCALIQUE",NULL},
/* 098D */ { NULL,NULL},
/* 098E */ { NULL,NULL},
/* 098F */ { "LETTRE BENGALI É",NULL},
/* 0990 */ { "LETTRE BENGALI AI",NULL},
/* 0991 */ { NULL,NULL},
/* 0992 */ { NULL,NULL},
/* 0993 */ { "LETTRE BENGALI O",NULL},
/* 0994 */ { "LETTRE BENGALI AOU",NULL},
/* 0995 */ { "LETTRE BENGALI KA",NULL},
/* 0996 */ { "LETTRE BENGALI KHA",NULL},
/* 0997 */ { "LETTRE BENGALI GA",NULL},
/* 0998 */ { "LETTRE BENGALI GHA",NULL},
/* 0999 */ { "LETTRE BENGALI NGA",NULL},
/* 099A */ { "LETTRE BENGALI TCHA",NULL},
/* 099B */ { "LETTRE BENGALI TCHHA",NULL},
/* 099C */ { "LETTRE BENGALI DJA",NULL},
/* 099D */ { "LETTRE BENGALI DJHA",NULL},
/* 099E */ { "LETTRE BENGALI ÑA",NULL},
/* 099F */ { "LETTRE BENGALI TTA",NULL},
/* 09A0 */ { "LETTRE BENGALI TTHA",NULL},
/* 09A1 */ { "LETTRE BENGALI DDA",NULL},
/* 09A2 */ { "LETTRE BENGALI DDHA",NULL},
/* 09A3 */ { "LETTRE BENGALI NNA",NULL},
/* 09A4 */ { "LETTRE BENGALI TA",NULL},
/* 09A5 */ { "LETTRE BENGALI THA",NULL},
/* 09A6 */ { "LETTRE BENGALI DA",NULL},
/* 09A7 */ { "LETTRE BENGALI DHA",NULL},
/* 09A8 */ { "LETTRE BENGALI NA",NULL},
/* 09A9 */ { NULL,NULL},
/* 09AA */ { "LETTRE BENGALI PA",NULL},
/* 09AB */ { "LETTRE BENGALI PHA","	= lettre bengali p'a"},
/* 09AC */ { "LETTRE BENGALI BA","	= lettre bengali va, lettre bengali wa"},
/* 09AD */ { "LETTRE BENGALI BHA",NULL},
/* 09AE */ { "LETTRE BENGALI MA",NULL},
/* 09AF */ { "LETTRE BENGALI YA",NULL},
/* 09B0 */ { "LETTRE BENGALI RA",NULL},
/* 09B1 */ { NULL,NULL},
/* 09B2 */ { "LETTRE BENGALI LA",NULL},
/* 09B3 */ { NULL,NULL},
/* 09B4 */ { NULL,NULL},
/* 09B5 */ { NULL,NULL},
/* 09B6 */ { "LETTRE BENGALI ÇA",NULL},
/* 09B7 */ { "LETTRE BENGALI CHA",NULL},
/* 09B8 */ { "LETTRE BENGALI SA",NULL},
/* 09B9 */ { "LETTRE BENGALI HA",NULL},
/* 09BA */ { NULL,NULL},
/* 09BB */ { NULL,NULL},
/* 09BC */ { "DIACRITIQUE BENGALI NOUKTA","	* pour étendre l'alphabet et former de nouvelles lettres"},
/* 09BD */ { "SIGNE BENGALI AVAGRAHA",NULL},
/* 09BE */ { "DIACRITIQUE VOYELLE BENGALI Â",NULL},
/* 09BF */ { "DIACRITIQUE VOYELLE BENGALI I","	* à gauche de la consonne"},
/* 09C0 */ { "DIACRITIQUE VOYELLE BENGALI Î",NULL},
/* 09C1 */ { "DIACRITIQUE VOYELLE BENGALI OU",NULL},
/* 09C2 */ { "DIACRITIQUE VOYELLE BENGALI OÛ",NULL},
/* 09C3 */ { "DIACRITIQUE VOYELLE BENGALI R VOCALIQUE",NULL},
/* 09C4 */ { "DIACRITIQUE VOYELLE BENGALI RR VOCALIQUE",NULL},
/* 09C5 */ { NULL,NULL},
/* 09C6 */ { NULL,NULL},
/* 09C7 */ { "DIACRITIQUE VOYELLE BENGALI É","	* à gauche de la consonne"},
/* 09C8 */ { "DIACRITIQUE VOYELLE BENGALI AI","	* à gauche de la consonne"},
/* 09C9 */ { NULL,NULL},
/* 09CA */ { NULL,NULL},
/* 09CB */ { "DIACRITIQUE VOYELLE BENGALI O","	: 09C7 09BE"},
/* 09CC */ { "DIACRITIQUE VOYELLE BENGALI AOU","	: 09C7 09D7"},
/* 09CD */ { "DIACRITIQUE BENGALI VIRÂMA","	= hasant (terme bengali désignant le halant)"},
/* 09CE */ { "LETTRE BENGALI TA KHANDA","	* un ta qui a la forme d'une consonne morte, sans voyelle implicite, utilisé dans certaines séquences"},
/* 09CF */ { NULL,NULL},
/* 09D0 */ { NULL,NULL},
/* 09D1 */ { NULL,NULL},
/* 09D2 */ { NULL,NULL},
/* 09D3 */ { NULL,NULL},
/* 09D4 */ { NULL,NULL},
/* 09D5 */ { NULL,NULL},
/* 09D6 */ { NULL,NULL},
/* 09D7 */ { "SIGNE DE LONGUEUR BENGALI AOU",NULL},
/* 09D8 */ { NULL,NULL},
/* 09D9 */ { NULL,NULL},
/* 09DA */ { NULL,NULL},
/* 09DB */ { NULL,NULL},
/* 09DC */ { "LETTRE BENGALI RRA","	: 09A1 09BC"},
/* 09DD */ { "LETTRE BENGALI RHA","	: 09A2 09BC"},
/* 09DE */ { NULL,NULL},
/* 09DF */ { "LETTRE BENGALI YYA","	: 09AF 09BC"},
/* 09E0 */ { "LETTRE BENGALI RR VOCALIQUE",NULL},
/* 09E1 */ { "LETTRE BENGALI LL VOCALIQUE",NULL},
/* 09E2 */ { "DIACRITIQUE VOYELLE BENGALI L VOCALIQUE",NULL},
/* 09E3 */ { "DIACRITIQUE VOYELLE BENGALI LL VOCALIQUE",NULL},
/* 09E4 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 09E5 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 09E6 */ { "CHIFFRE BENGALI ZÉRO",NULL},
/* 09E7 */ { "CHIFFRE BENGALI UN",NULL},
/* 09E8 */ { "CHIFFRE BENGALI DEUX",NULL},
/* 09E9 */ { "CHIFFRE BENGALI TROIS",NULL},
/* 09EA */ { "CHIFFRE BENGALI QUATRE",NULL},
/* 09EB */ { "CHIFFRE BENGALI CINQ",NULL},
/* 09EC */ { "CHIFFRE BENGALI SIX",NULL},
/* 09ED */ { "CHIFFRE BENGALI SEPT",NULL},
/* 09EE */ { "CHIFFRE BENGALI HUIT",NULL},
/* 09EF */ { "CHIFFRE BENGALI NEUF",NULL},
/* 09F0 */ { "LETTRE BENGALI RA AVEC BARRE OBLIQUE MÉDIANE","	= lettre assamaise ra"},
/* 09F1 */ { "LETTRE BENGALI RA AVEC BARRE OBLIQUE SOUSCRITE","	= lettre assamaise wa\n"
	"	= lettre bengali va avec barre oblique souscrite (1.0)"},
/* 09F2 */ { "SIGNE BENGALI ROUPIE","	= taka\n"
	"	* symbole désuet"},
/* 09F3 */ { "SYMBOLE BENGALI ROUPIE","	= taka bangladais"},
/* 09F4 */ { "NUMÉRATEUR MONÉTAIRE BENGALI UN","	* tombé en désuétude"},
/* 09F5 */ { "NUMÉRATEUR MONÉTAIRE BENGALI DEUX","	* tombé en désuétude"},
/* 09F6 */ { "NUMÉRATEUR MONÉTAIRE BENGALI TROIS","	* tombé en désuétude"},
/* 09F7 */ { "NUMÉRATEUR MONÉTAIRE BENGALI QUATRE",NULL},
/* 09F8 */ { "NUMÉRATEUR MONÉTAIRE BENGALI DÉNOMINATEUR MOINS UN",NULL},
/* 09F9 */ { "DÉNOMINATEUR MONÉTAIRE BENGALI SEIZE",NULL},
/* 09FA */ { "ÎSCHAR BENGALI","	= îçvara\n"
	"	* représente le nom d'une divinité\n"
	"	= svargiya\n"
	"	* s'écrit devant le nom d'un défunt"},
/* 09FB */ { "SYMBOLE BENGALI GANDA",NULL},
/* 09FC */ { "LETTRE BENGALI ANOUSVÂRA VÉDIQUE",NULL},
/* 09FD */ { "SIGNE D'ABRÉVIATION BENGALI",NULL},
/* 09FE */ { "SIGNE BENGALI SANDHI","	* indique le sandhi externe dans les documents en sanskrit\n"
	"	x (signe bengali avagraha - 09BD)\n"
	"	x (signe charada sandhi - 111C9)\n"
	"	x (signe néwar sandhi - 1145E)"},
/* 09FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_0A[] = {
/* 0A00 */ { NULL,NULL},
/* 0A01 */ { "DIACRITIQUE GOURMOUKHÎ ADDAK BINDI",NULL},
/* 0A02 */ { "DIACRITIQUE GOURMOUKHÎ BINDI",NULL},
/* 0A03 */ { "DIACRITIQUE GOURMOUKHÎ VISARGA",NULL},
/* 0A04 */ { NULL,NULL},
/* 0A05 */ { "LETTRE GOURMOUKHÎ A","	= aïra"},
/* 0A06 */ { "LETTRE GOURMOUKHÎ Â",NULL},
/* 0A07 */ { "LETTRE GOURMOUKHÎ I",NULL},
/* 0A08 */ { "LETTRE GOURMOUKHÎ Î",NULL},
/* 0A09 */ { "LETTRE GOURMOUKHÎ OU",NULL},
/* 0A0A */ { "LETTRE GOURMOUKHÎ OÛ",NULL},
/* 0A0B */ { NULL,NULL},
/* 0A0C */ { NULL,NULL},
/* 0A0D */ { NULL,NULL},
/* 0A0E */ { NULL,NULL},
/* 0A0F */ { "LETTRE GOURMOUKHÎ ÉÉ",NULL},
/* 0A10 */ { "LETTRE GOURMOUKHÎ AI",NULL},
/* 0A11 */ { NULL,NULL},
/* 0A12 */ { NULL,NULL},
/* 0A13 */ { "LETTRE GOURMOUKHÎ Ô",NULL},
/* 0A14 */ { "LETTRE GOURMOUKHÎ AOU",NULL},
/* 0A15 */ { "LETTRE GOURMOUKHÎ KA",NULL},
/* 0A16 */ { "LETTRE GOURMOUKHÎ KHA",NULL},
/* 0A17 */ { "LETTRE GOURMOUKHÎ GA",NULL},
/* 0A18 */ { "LETTRE GOURMOUKHÎ GHA",NULL},
/* 0A19 */ { "LETTRE GOURMOUKHÎ NGA",NULL},
/* 0A1A */ { "LETTRE GOURMOUKHÎ TCHA",NULL},
/* 0A1B */ { "LETTRE GOURMOUKHÎ TCHHA",NULL},
/* 0A1C */ { "LETTRE GOURMOUKHÎ DJA",NULL},
/* 0A1D */ { "LETTRE GOURMOUKHÎ DJHA",NULL},
/* 0A1E */ { "LETTRE GOURMOUKHÎ ÑA",NULL},
/* 0A1F */ { "LETTRE GOURMOUKHÎ TTA",NULL},
/* 0A20 */ { "LETTRE GOURMOUKHÎ TTHA",NULL},
/* 0A21 */ { "LETTRE GOURMOUKHÎ DDA",NULL},
/* 0A22 */ { "LETTRE GOURMOUKHÎ DDHA",NULL},
/* 0A23 */ { "LETTRE GOURMOUKHÎ NNA",NULL},
/* 0A24 */ { "LETTRE GOURMOUKHÎ TA",NULL},
/* 0A25 */ { "LETTRE GOURMOUKHÎ THA",NULL},
/* 0A26 */ { "LETTRE GOURMOUKHÎ DA",NULL},
/* 0A27 */ { "LETTRE GOURMOUKHÎ DHA",NULL},
/* 0A28 */ { "LETTRE GOURMOUKHÎ NA",NULL},
/* 0A29 */ { NULL,NULL},
/* 0A2A */ { "LETTRE GOURMOUKHÎ PA",NULL},
/* 0A2B */ { "LETTRE GOURMOUKHÎ PHA","	= lettre gourmoukhî p'a"},
/* 0A2C */ { "LETTRE GOURMOUKHÎ BA",NULL},
/* 0A2D */ { "LETTRE GOURMOUKHÎ BHA",NULL},
/* 0A2E */ { "LETTRE GOURMOUKHÎ MA",NULL},
/* 0A2F */ { "LETTRE GOURMOUKHÎ YA",NULL},
/* 0A30 */ { "LETTRE GOURMOUKHÎ RA",NULL},
/* 0A31 */ { NULL,NULL},
/* 0A32 */ { "LETTRE GOURMOUKHÎ LA",NULL},
/* 0A33 */ { "LETTRE GOURMOUKHÎ LLA","	: 0A32 0A3C\n"
	"		Cette consonne munie d'un noukta figure dans le fichier CompositionExclusions.txt. Cela signifie qu'elle ne se recompose pas au moment de la normalisation. La forme NFC est identique à la séquence décomposée."},
/* 0A34 */ { NULL,NULL},
/* 0A35 */ { "LETTRE GOURMOUKHÎ VA",NULL},
/* 0A36 */ { "LETTRE GOURMOUKHÎ ÇA","	: 0A38 0A3C\n"
	"		Cette consonne munie d'un noukta figure dans le fichier CompositionExclusions.txt. Cela signifie qu'elle ne se recompose pas au moment de la normalisation. La forme NFC est identique à la séquence décomposée."},
/* 0A37 */ { NULL,NULL},
/* 0A38 */ { "LETTRE GOURMOUKHÎ SA",NULL},
/* 0A39 */ { "LETTRE GOURMOUKHÎ HA",NULL},
/* 0A3A */ { NULL,NULL},
/* 0A3B */ { NULL,NULL},
/* 0A3C */ { "DIACRITIQUE GOURMOUKHÎ NOUKTA","	= païrin bindi\n"
	"	* pour étendre l'alphabet et former de nouvelles lettres"},
/* 0A3D */ { NULL,NULL},
/* 0A3E */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ Â","	= kanna"},
/* 0A3F */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ I","	= siharî\n"
	"	* à gauche de la consonne"},
/* 0A40 */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ Î","	= biharî"},
/* 0A41 */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ OU","	= aounkar"},
/* 0A42 */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ OÛ","	= doulaïnkar"},
/* 0A43 */ { NULL,NULL},
/* 0A44 */ { NULL,NULL},
/* 0A45 */ { NULL,NULL},
/* 0A46 */ { NULL,NULL},
/* 0A47 */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ ÉÉ","	= lanvan"},
/* 0A48 */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ AI","	= doulanvan"},
/* 0A49 */ { NULL,NULL},
/* 0A4A */ { NULL,NULL},
/* 0A4B */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ Ô","	= hora"},
/* 0A4C */ { "DIACRITIQUE VOYELLE GOURMOUKHÎ AOU","	= kanaoura"},
/* 0A4D */ { "DIACRITIQUE GOURMOUKHÎ VIRÂMA",NULL},
/* 0A4E */ { NULL,NULL},
/* 0A4F */ { NULL,NULL},
/* 0A50 */ { NULL,NULL},
/* 0A51 */ { "DIACRITIQUE GOURMOUKHÎ OUDÂT",NULL},
/* 0A52 */ { NULL,NULL},
/* 0A53 */ { NULL,NULL},
/* 0A54 */ { NULL,NULL},
/* 0A55 */ { NULL,NULL},
/* 0A56 */ { NULL,NULL},
/* 0A57 */ { NULL,NULL},
/* 0A58 */ { NULL,NULL},
/* 0A59 */ { "LETTRE GOURMOUKHÎ KHHA","	: 0A16 0A3C"},
/* 0A5A */ { "LETTRE GOURMOUKHÎ GHHA","	: 0A17 0A3C"},
/* 0A5B */ { "LETTRE GOURMOUKHÎ ZA","	: 0A1C 0A3C"},
/* 0A5C */ { "LETTRE GOURMOUKHÎ RRA",NULL},
/* 0A5D */ { NULL,NULL},
/* 0A5E */ { "LETTRE GOURMOUKHÎ FA","	: 0A2B 0A3C"},
/* 0A5F */ { NULL,NULL},
/* 0A60 */ { NULL,NULL},
/* 0A61 */ { NULL,NULL},
/* 0A62 */ { NULL,NULL},
/* 0A63 */ { NULL,NULL},
/* 0A64 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0A65 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0A66 */ { "CHIFFRE GOURMOUKHÎ ZÉRO",NULL},
/* 0A67 */ { "CHIFFRE GOURMOUKHÎ UN",NULL},
/* 0A68 */ { "CHIFFRE GOURMOUKHÎ DEUX",NULL},
/* 0A69 */ { "CHIFFRE GOURMOUKHÎ TROIS",NULL},
/* 0A6A */ { "CHIFFRE GOURMOUKHÎ QUATRE",NULL},
/* 0A6B */ { "CHIFFRE GOURMOUKHÎ CINQ",NULL},
/* 0A6C */ { "CHIFFRE GOURMOUKHÎ SIX",NULL},
/* 0A6D */ { "CHIFFRE GOURMOUKHÎ SEPT",NULL},
/* 0A6E */ { "CHIFFRE GOURMOUKHÎ HUIT",NULL},
/* 0A6F */ { "CHIFFRE GOURMOUKHÎ NEUF",NULL},
/* 0A70 */ { "TIPPI GOURMOUKHÎ","	* nasalisation"},
/* 0A71 */ { "ADDAK GOURMOUKHÎ","	* doublé quand il suit une consonne"},
/* 0A72 */ { "IRI GOURMOUKHÎ",NULL},
/* 0A73 */ { "OURA GOURMOUKHÎ",NULL},
/* 0A74 */ { "EK ONKAR GOURMOUKHÎ","	* Dieu est Un"},
/* 0A75 */ { "DIACRITIQUE GOURMOUKHÎ YAKACH","	* certaines polices utilisent un autre glyphe, formé davantage comme la partie inférieure de 0A2F"},
/* 0A76 */ { "SIGNE D'ABRÉVIATION GOURMOUKHÎ","	x (signe d'abréviation charada - 111C7)"},
/* 0A77 */ { NULL,NULL},
/* 0A78 */ { NULL,NULL},
/* 0A79 */ { NULL,NULL},
/* 0A7A */ { NULL,NULL},
/* 0A7B */ { NULL,NULL},
/* 0A7C */ { NULL,NULL},
/* 0A7D */ { NULL,NULL},
/* 0A7E */ { NULL,NULL},
/* 0A7F */ { NULL,NULL},
/* 0A80 */ { NULL,NULL},
/* 0A81 */ { "DIACRITIQUE GOUDJARATI TCHANDRABINDOU",NULL},
/* 0A82 */ { "DIACRITIQUE GOUDJARATI ANOUSVÂRA",NULL},
/* 0A83 */ { "DIACRITIQUE GOUDJARATI VISARGA",NULL},
/* 0A84 */ { NULL,NULL},
/* 0A85 */ { "LETTRE GOUDJARATI A",NULL},
/* 0A86 */ { "LETTRE GOUDJARATI Â",NULL},
/* 0A87 */ { "LETTRE GOUDJARATI I",NULL},
/* 0A88 */ { "LETTRE GOUDJARATI Î",NULL},
/* 0A89 */ { "LETTRE GOUDJARATI OU",NULL},
/* 0A8A */ { "LETTRE GOUDJARATI OÛ",NULL},
/* 0A8B */ { "LETTRE GOUDJARATI R VOCALIQUE",NULL},
/* 0A8C */ { "LETTRE GOUDJARATI L VOCALIQUE","	* utilisée avec du texte en sanskrit"},
/* 0A8D */ { "VOYELLE GOUDJARATI É TCHANDRA",NULL},
/* 0A8E */ { NULL,NULL},
/* 0A8F */ { "LETTRE GOUDJARATI É",NULL},
/* 0A90 */ { "LETTRE GOUDJARATI AI",NULL},
/* 0A91 */ { "VOYELLE GOUDJARATI O TCHANDRA",NULL},
/* 0A92 */ { NULL,NULL},
/* 0A93 */ { "LETTRE GOUDJARATI O",NULL},
/* 0A94 */ { "LETTRE GOUDJARATI AOU",NULL},
/* 0A95 */ { "LETTRE GOUDJARATI KA",NULL},
/* 0A96 */ { "LETTRE GOUDJARATI KHA",NULL},
/* 0A97 */ { "LETTRE GOUDJARATI GA",NULL},
/* 0A98 */ { "LETTRE GOUDJARATI GHA",NULL},
/* 0A99 */ { "LETTRE GOUDJARATI NGA",NULL},
/* 0A9A */ { "LETTRE GOUDJARATI TCHA",NULL},
/* 0A9B */ { "LETTRE GOUDJARATI TCHHA",NULL},
/* 0A9C */ { "LETTRE GOUDJARATI DJA",NULL},
/* 0A9D */ { "LETTRE GOUDJARATI DJHA",NULL},
/* 0A9E */ { "LETTRE GOUDJARATI ÑA",NULL},
/* 0A9F */ { "LETTRE GOUDJARATI TTA",NULL},
/* 0AA0 */ { "LETTRE GOUDJARATI TTHA",NULL},
/* 0AA1 */ { "LETTRE GOUDJARATI DDA",NULL},
/* 0AA2 */ { "LETTRE GOUDJARATI DDHA",NULL},
/* 0AA3 */ { "LETTRE GOUDJARATI NNA",NULL},
/* 0AA4 */ { "LETTRE GOUDJARATI TA",NULL},
/* 0AA5 */ { "LETTRE GOUDJARATI THA",NULL},
/* 0AA6 */ { "LETTRE GOUDJARATI DA",NULL},
/* 0AA7 */ { "LETTRE GOUDJARATI DHA",NULL},
/* 0AA8 */ { "LETTRE GOUDJARATI NA",NULL},
/* 0AA9 */ { NULL,NULL},
/* 0AAA */ { "LETTRE GOUDJARATI PA",NULL},
/* 0AAB */ { "LETTRE GOUDJARATI PHA","	= lettre goudjarati p'a"},
/* 0AAC */ { "LETTRE GOUDJARATI BA",NULL},
/* 0AAD */ { "LETTRE GOUDJARATI BHA",NULL},
/* 0AAE */ { "LETTRE GOUDJARATI MA",NULL},
/* 0AAF */ { "LETTRE GOUDJARATI YA",NULL},
/* 0AB0 */ { "LETTRE GOUDJARATI RA",NULL},
/* 0AB1 */ { NULL,NULL},
/* 0AB2 */ { "LETTRE GOUDJARATI LA",NULL},
/* 0AB3 */ { "LETTRE GOUDJARATI LLA",NULL},
/* 0AB4 */ { NULL,NULL},
/* 0AB5 */ { "LETTRE GOUDJARATI VA",NULL},
/* 0AB6 */ { "LETTRE GOUDJARATI ÇA",NULL},
/* 0AB7 */ { "LETTRE GOUDJARATI CHA",NULL},
/* 0AB8 */ { "LETTRE GOUDJARATI SA",NULL},
/* 0AB9 */ { "LETTRE GOUDJARATI HA",NULL},
/* 0ABA */ { NULL,NULL},
/* 0ABB */ { NULL,NULL},
/* 0ABC */ { "DIACRITIQUE GOUDJARATI NOUKTA","	* pour étendre l'alphabet et former de nouvelles lettres"},
/* 0ABD */ { "SIGNE GOUDJARATI AVAGRAHA",NULL},
/* 0ABE */ { "DIACRITIQUE VOYELLE GOUDJARATI Â",NULL},
/* 0ABF */ { "DIACRITIQUE VOYELLE GOUDJARATI I","	* à gauche de la consonne"},
/* 0AC0 */ { "DIACRITIQUE VOYELLE GOUDJARATI Î",NULL},
/* 0AC1 */ { "DIACRITIQUE VOYELLE GOUDJARATI OU",NULL},
/* 0AC2 */ { "DIACRITIQUE VOYELLE GOUDJARATI OÛ",NULL},
/* 0AC3 */ { "DIACRITIQUE VOYELLE GOUDJARATI R VOCALIQUE",NULL},
/* 0AC4 */ { "DIACRITIQUE VOYELLE GOUDJARATI RR VOCALIQUE",NULL},
/* 0AC5 */ { "DIACRITIQUE VOYELLE GOUDJARATI É TCHANDRA",NULL},
/* 0AC6 */ { NULL,NULL},
/* 0AC7 */ { "DIACRITIQUE VOYELLE GOUDJARATI É",NULL},
/* 0AC8 */ { "DIACRITIQUE VOYELLE GOUDJARATI AI",NULL},
/* 0AC9 */ { "DIACRITIQUE VOYELLE GOUDJARATI O TCHANDRA",NULL},
/* 0ACA */ { NULL,NULL},
/* 0ACB */ { "DIACRITIQUE VOYELLE GOUDJARATI O",NULL},
/* 0ACC */ { "DIACRITIQUE VOYELLE GOUDJARATI AOU",NULL},
/* 0ACD */ { "DIACRITIQUE GOUDJARATI VIRÂMA",NULL},
/* 0ACE */ { NULL,NULL},
/* 0ACF */ { NULL,NULL},
/* 0AD0 */ { "OM GOUDJARATI",NULL},
/* 0AD1 */ { NULL,NULL},
/* 0AD2 */ { NULL,NULL},
/* 0AD3 */ { NULL,NULL},
/* 0AD4 */ { NULL,NULL},
/* 0AD5 */ { NULL,NULL},
/* 0AD6 */ { NULL,NULL},
/* 0AD7 */ { NULL,NULL},
/* 0AD8 */ { NULL,NULL},
/* 0AD9 */ { NULL,NULL},
/* 0ADA */ { NULL,NULL},
/* 0ADB */ { NULL,NULL},
/* 0ADC */ { NULL,NULL},
/* 0ADD */ { NULL,NULL},
/* 0ADE */ { NULL,NULL},
/* 0ADF */ { NULL,NULL},
/* 0AE0 */ { "LETTRE GOUDJARATI RR VOCALIQUE",NULL},
/* 0AE1 */ { "LETTRE GOUDJARATI LL VOCALIQUE",NULL},
/* 0AE2 */ { "DIACRITIQUE VOYELLE GOUDJARATI L VOCALIQUE",NULL},
/* 0AE3 */ { "DIACRITIQUE VOYELLE GOUDJARATI LL VOCALIQUE",NULL},
/* 0AE4 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0AE5 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0AE6 */ { "CHIFFRE GOUDJARATI ZÉRO",NULL},
/* 0AE7 */ { "CHIFFRE GOUDJARATI UN",NULL},
/* 0AE8 */ { "CHIFFRE GOUDJARATI DEUX",NULL},
/* 0AE9 */ { "CHIFFRE GOUDJARATI TROIS",NULL},
/* 0AEA */ { "CHIFFRE GOUDJARATI QUATRE",NULL},
/* 0AEB */ { "CHIFFRE GOUDJARATI CINQ",NULL},
/* 0AEC */ { "CHIFFRE GOUDJARATI SIX",NULL},
/* 0AED */ { "CHIFFRE GOUDJARATI SEPT",NULL},
/* 0AEE */ { "CHIFFRE GOUDJARATI HUIT",NULL},
/* 0AEF */ { "CHIFFRE GOUDJARATI NEUF",NULL},
/* 0AF0 */ { "SIGNE D'ABRÉVIATION GOUDJARATI",NULL},
/* 0AF1 */ { "SYMBOLE GOUDJARATI ROUPIE","	* l'écriture recommandée est 0AB0 0AC2 0AF0"},
/* 0AF2 */ { NULL,NULL},
/* 0AF3 */ { NULL,NULL},
/* 0AF4 */ { NULL,NULL},
/* 0AF5 */ { NULL,NULL},
/* 0AF6 */ { NULL,NULL},
/* 0AF7 */ { NULL,NULL},
/* 0AF8 */ { NULL,NULL},
/* 0AF9 */ { "LETTRE GOUDJARATI ZHA","	* s'emploie pour la translittération de l'avestique\n"
	"	x (lettre dévanâgarî zha - 0979)"},
/* 0AFA */ { "DIACRITIQUE GOUDJARATI SOUKOUN",NULL},
/* 0AFB */ { "DIACRITIQUE GOUDJARATI ÇADDA",NULL},
/* 0AFC */ { "DIACRITIQUE GOUDJARATI MADDAH",NULL},
/* 0AFD */ { "DIACRITIQUE GOUDJARATI NOUKTA SUSCRIT FORMÉ DE TROIS POINTS",NULL},
/* 0AFE */ { "DIACRITIQUE GOUDJARATI NOUKTA SUSCRIT FORMÉ D'UN CERCLE",NULL},
/* 0AFF */ { "DIACRITIQUE GOUDJARATI NOUKTA SUSCRIT FORMÉ DE DEUX CERCLES",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_0B[] = {
/* 0B00 */ { NULL,NULL},
/* 0B01 */ { "DIACRITIQUE ORIYA TCHANDRABINDOU",NULL},
/* 0B02 */ { "DIACRITIQUE ORIYA ANOUSVÂRA",NULL},
/* 0B03 */ { "DIACRITIQUE ORIYA VISARGA",NULL},
/* 0B04 */ { NULL,NULL},
/* 0B05 */ { "LETTRE ORIYA A",NULL},
/* 0B06 */ { "LETTRE ORIYA Â",NULL},
/* 0B07 */ { "LETTRE ORIYA I",NULL},
/* 0B08 */ { "LETTRE ORIYA Î",NULL},
/* 0B09 */ { "LETTRE ORIYA OU",NULL},
/* 0B0A */ { "LETTRE ORIYA OÛ",NULL},
/* 0B0B */ { "LETTRE ORIYA R VOCALIQUE",NULL},
/* 0B0C */ { "LETTRE ORIYA L VOCALIQUE",NULL},
/* 0B0D */ { NULL,NULL},
/* 0B0E */ { NULL,NULL},
/* 0B0F */ { "LETTRE ORIYA É",NULL},
/* 0B10 */ { "LETTRE ORIYA AI",NULL},
/* 0B11 */ { NULL,NULL},
/* 0B12 */ { NULL,NULL},
/* 0B13 */ { "LETTRE ORIYA O",NULL},
/* 0B14 */ { "LETTRE ORIYA AOU",NULL},
/* 0B15 */ { "LETTRE ORIYA KA",NULL},
/* 0B16 */ { "LETTRE ORIYA KHA",NULL},
/* 0B17 */ { "LETTRE ORIYA GA",NULL},
/* 0B18 */ { "LETTRE ORIYA GHA",NULL},
/* 0B19 */ { "LETTRE ORIYA NGA",NULL},
/* 0B1A */ { "LETTRE ORIYA TCHA",NULL},
/* 0B1B */ { "LETTRE ORIYA TCHHA",NULL},
/* 0B1C */ { "LETTRE ORIYA DJA",NULL},
/* 0B1D */ { "LETTRE ORIYA DJHA",NULL},
/* 0B1E */ { "LETTRE ORIYA ÑA",NULL},
/* 0B1F */ { "LETTRE ORIYA TTA",NULL},
/* 0B20 */ { "LETTRE ORIYA TTHA",NULL},
/* 0B21 */ { "LETTRE ORIYA DDA",NULL},
/* 0B22 */ { "LETTRE ORIYA DDHA",NULL},
/* 0B23 */ { "LETTRE ORIYA NNA",NULL},
/* 0B24 */ { "LETTRE ORIYA TA",NULL},
/* 0B25 */ { "LETTRE ORIYA THA",NULL},
/* 0B26 */ { "LETTRE ORIYA DA",NULL},
/* 0B27 */ { "LETTRE ORIYA DHA",NULL},
/* 0B28 */ { "LETTRE ORIYA NA",NULL},
/* 0B29 */ { NULL,NULL},
/* 0B2A */ { "LETTRE ORIYA PA",NULL},
/* 0B2B */ { "LETTRE ORIYA PHA","	= lettre oriya p'a"},
/* 0B2C */ { "LETTRE ORIYA BA","	= lettre oriya va, lettre oriya wa\n"
	"	x (lettre oriya va - 0B35)"},
/* 0B2D */ { "LETTRE ORIYA BHA",NULL},
/* 0B2E */ { "LETTRE ORIYA MA",NULL},
/* 0B2F */ { "LETTRE ORIYA YA","	= ja"},
/* 0B30 */ { "LETTRE ORIYA RA",NULL},
/* 0B31 */ { NULL,NULL},
/* 0B32 */ { "LETTRE ORIYA LA",NULL},
/* 0B33 */ { "LETTRE ORIYA LLA",NULL},
/* 0B34 */ { NULL,NULL},
/* 0B35 */ { "LETTRE ORIYA VA","	* le kui utilise une variante avec le point au-dessus du petit cercle\n"
	"	x (lettre oriya ba - 0B2C)"},
/* 0B36 */ { "LETTRE ORIYA ÇA",NULL},
/* 0B37 */ { "LETTRE ORIYA CHA",NULL},
/* 0B38 */ { "LETTRE ORIYA SA",NULL},
/* 0B39 */ { "LETTRE ORIYA HA",NULL},
/* 0B3A */ { NULL,NULL},
/* 0B3B */ { NULL,NULL},
/* 0B3C */ { "DIACRITIQUE ORIYA NOUKTA","	* pour étendre l'alphabet et former de nouvelles lettres"},
/* 0B3D */ { "SIGNE ORIYA AVAGRAHA",NULL},
/* 0B3E */ { "DIACRITIQUE VOYELLE ORIYA Â",NULL},
/* 0B3F */ { "DIACRITIQUE VOYELLE ORIYA I",NULL},
/* 0B40 */ { "DIACRITIQUE VOYELLE ORIYA Î",NULL},
/* 0B41 */ { "DIACRITIQUE VOYELLE ORIYA OU",NULL},
/* 0B42 */ { "DIACRITIQUE VOYELLE ORIYA OÛ",NULL},
/* 0B43 */ { "DIACRITIQUE VOYELLE ORIYA R VOCALIQUE",NULL},
/* 0B44 */ { "DIACRITIQUE VOYELLE ORIYA RR VOCALIQUE",NULL},
/* 0B45 */ { NULL,NULL},
/* 0B46 */ { NULL,NULL},
/* 0B47 */ { "DIACRITIQUE VOYELLE ORIYA É","	* à gauche de la consonne"},
/* 0B48 */ { "DIACRITIQUE VOYELLE ORIYA AI","	* à gauche et au-dessus de la consonne\n"
	"	: 0B47 0B56"},
/* 0B49 */ { NULL,NULL},
/* 0B4A */ { NULL,NULL},
/* 0B4B */ { "DIACRITIQUE VOYELLE ORIYA O","	: 0B47 0B3E"},
/* 0B4C */ { "DIACRITIQUE VOYELLE ORIYA AOU","	: 0B47 0B57"},
/* 0B4D */ { "DIACRITIQUE ORIYA VIRÂMA",NULL},
/* 0B4E */ { NULL,NULL},
/* 0B4F */ { NULL,NULL},
/* 0B50 */ { NULL,NULL},
/* 0B51 */ { NULL,NULL},
/* 0B52 */ { NULL,NULL},
/* 0B53 */ { NULL,NULL},
/* 0B54 */ { NULL,NULL},
/* 0B55 */ { "DIACRITIQUE ORIYA TIRET HAUT","	* kuvi, kui"},
/* 0B56 */ { "SIGNE DE LONGUEUR ORIYA AI",NULL},
/* 0B57 */ { "SIGNE DE LONGUEUR ORIYA AOU",NULL},
/* 0B58 */ { NULL,NULL},
/* 0B59 */ { NULL,NULL},
/* 0B5A */ { NULL,NULL},
/* 0B5B */ { NULL,NULL},
/* 0B5C */ { "LETTRE ORIYA RRA","	= dda\n"
	"	: 0B21 0B3C"},
/* 0B5D */ { "LETTRE ORIYA RHA","	= ddha\n"
	"	: 0B22 0B3C"},
/* 0B5E */ { NULL,NULL},
/* 0B5F */ { "LETTRE ORIYA YYA","	= ya"},
/* 0B60 */ { "LETTRE ORIYA RR VOCALIQUE",NULL},
/* 0B61 */ { "LETTRE ORIYA LL VOCALIQUE",NULL},
/* 0B62 */ { "DIACRITIQUE VOYELLE ORIYA L VOCALIQUE",NULL},
/* 0B63 */ { "DIACRITIQUE VOYELLE ORIYA LL VOCALIQUE",NULL},
/* 0B64 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0B65 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0B66 */ { "CHIFFRE ORIYA ZÉRO",NULL},
/* 0B67 */ { "CHIFFRE ORIYA UN",NULL},
/* 0B68 */ { "CHIFFRE ORIYA DEUX",NULL},
/* 0B69 */ { "CHIFFRE ORIYA TROIS",NULL},
/* 0B6A */ { "CHIFFRE ORIYA QUATRE",NULL},
/* 0B6B */ { "CHIFFRE ORIYA CINQ",NULL},
/* 0B6C */ { "CHIFFRE ORIYA SIX",NULL},
/* 0B6D */ { "CHIFFRE ORIYA SEPT",NULL},
/* 0B6E */ { "CHIFFRE ORIYA HUIT",NULL},
/* 0B6F */ { "CHIFFRE ORIYA NEUF",NULL},
/* 0B70 */ { "ÎSCHAR ORIYA",NULL},
/* 0B71 */ { "LETTRE ORIYA WA","	x (lettre oriya o - 0B13)\n"
	"	x (lettre oriya va - 0B35)"},
/* 0B72 */ { "FRACTION ORIYA UN QUART",NULL},
/* 0B73 */ { "FRACTION ORIYA UN DEMI",NULL},
/* 0B74 */ { "FRACTION ORIYA TROIS QUARTS",NULL},
/* 0B75 */ { "FRACTION ORIYA UN SIXIÈME",NULL},
/* 0B76 */ { "FRACTION ORIYA UN HUITIÈME",NULL},
/* 0B77 */ { "FRACTION ORIYA TROIS SEIZIÈMES",NULL},
/* 0B78 */ { NULL,NULL},
/* 0B79 */ { NULL,NULL},
/* 0B7A */ { NULL,NULL},
/* 0B7B */ { NULL,NULL},
/* 0B7C */ { NULL,NULL},
/* 0B7D */ { NULL,NULL},
/* 0B7E */ { NULL,NULL},
/* 0B7F */ { NULL,NULL},
/* 0B80 */ { NULL,NULL},
/* 0B81 */ { NULL,NULL},
/* 0B82 */ { "DIACRITIQUE TAMOUL ANOUSVÂRA","	* inusité en tamoul"},
/* 0B83 */ { "SYMBOLE TAMOUL VISARGA","	= aytham\n"
	"	* ce signe tire son origine d'une forme particulière de visarga, mais n'est pas utilisé comme un visarga en tamoul\n"
	"	* le glyphe de l'aytham, comme celui du poulli tamoul, peut présenter soit des points, soit des cercles"},
/* 0B84 */ { NULL,NULL},
/* 0B85 */ { "LETTRE TAMOULE A",NULL},
/* 0B86 */ { "LETTRE TAMOULE Â",NULL},
/* 0B87 */ { "LETTRE TAMOULE I",NULL},
/* 0B88 */ { "LETTRE TAMOULE Î",NULL},
/* 0B89 */ { "LETTRE TAMOULE OU",NULL},
/* 0B8A */ { "LETTRE TAMOULE OÛ",NULL},
/* 0B8B */ { NULL,NULL},
/* 0B8C */ { NULL,NULL},
/* 0B8D */ { NULL,NULL},
/* 0B8E */ { "LETTRE TAMOULE É",NULL},
/* 0B8F */ { "LETTRE TAMOULE ÉÉ",NULL},
/* 0B90 */ { "LETTRE TAMOULE AÏ",NULL},
/* 0B91 */ { NULL,NULL},
/* 0B92 */ { "LETTRE TAMOULE O",NULL},
/* 0B93 */ { "LETTRE TAMOULE Ô",NULL},
/* 0B94 */ { "LETTRE TAMOULE AOU","	: 0B92 0BD7"},
/* 0B95 */ { "LETTRE TAMOULE KA",NULL},
/* 0B96 */ { NULL,NULL},
/* 0B97 */ { NULL,NULL},
/* 0B98 */ { NULL,NULL},
/* 0B99 */ { "LETTRE TAMOULE NGA","	* désigne également la mesure kourouni/marakkâl\n"
	"	x (symbole tamoul kourouni - 11FDA)"},
/* 0B9A */ { "LETTRE TAMOULE TCHA",NULL},
/* 0B9B */ { NULL,NULL},
/* 0B9C */ { "LETTRE TAMOULE DJA",NULL},
/* 0B9D */ { NULL,NULL},
/* 0B9E */ { "LETTRE TAMOULE ÑA",NULL},
/* 0B9F */ { "LETTRE TAMOULE TTA",NULL},
/* 0BA0 */ { NULL,NULL},
/* 0BA1 */ { NULL,NULL},
/* 0BA2 */ { NULL,NULL},
/* 0BA3 */ { "LETTRE TAMOULE NNA",NULL},
/* 0BA4 */ { "LETTRE TAMOULE TA","	* désigne également la mesure thoûni\n"
	"	x (symbole tamoul moukkourouni - 11FDC)"},
/* 0BA5 */ { NULL,NULL},
/* 0BA6 */ { NULL,NULL},
/* 0BA7 */ { NULL,NULL},
/* 0BA8 */ { "LETTRE TAMOULE NA",NULL},
/* 0BA9 */ { "LETTRE TAMOULE NNNA",NULL},
/* 0BAA */ { "LETTRE TAMOULE PA","	x (fraction tamoule un vingtième - 11FC8)"},
/* 0BAB */ { NULL,NULL},
/* 0BAC */ { NULL,NULL},
/* 0BAD */ { NULL,NULL},
/* 0BAE */ { "LETTRE TAMOULE MA",NULL},
/* 0BAF */ { "LETTRE TAMOULE YA",NULL},
/* 0BB0 */ { "LETTRE TAMOULE RA",NULL},
/* 0BB1 */ { "LETTRE TAMOULE RRA",NULL},
/* 0BB2 */ { "LETTRE TAMOULE LA",NULL},
/* 0BB3 */ { "LETTRE TAMOULE LLA","	* désigne également la mesure kalam\n"
	"	x (symbole tamoul moukkourouni - 11FDC)"},
/* 0BB4 */ { "LETTRE TAMOULE LLLA",NULL},
/* 0BB5 */ { "LETTRE TAMOULE VA","	x (fraction tamoule un quart - 11FD0)"},
/* 0BB6 */ { "LETTRE TAMOULE ÇA",NULL},
/* 0BB7 */ { "LETTRE TAMOULE CHA",NULL},
/* 0BB8 */ { "LETTRE TAMOULE SA",NULL},
/* 0BB9 */ { "LETTRE TAMOULE HA",NULL},
/* 0BBA */ { NULL,NULL},
/* 0BBB */ { NULL,NULL},
/* 0BBC */ { NULL,NULL},
/* 0BBD */ { NULL,NULL},
/* 0BBE */ { "DIACRITIQUE VOYELLE TAMOULE Â",NULL},
/* 0BBF */ { "DIACRITIQUE VOYELLE TAMOULE I",NULL},
/* 0BC0 */ { "DIACRITIQUE VOYELLE TAMOULE Î",NULL},
/* 0BC1 */ { "DIACRITIQUE VOYELLE TAMOULE OU",NULL},
/* 0BC2 */ { "DIACRITIQUE VOYELLE TAMOULE OÛ",NULL},
/* 0BC3 */ { NULL,NULL},
/* 0BC4 */ { NULL,NULL},
/* 0BC5 */ { NULL,NULL},
/* 0BC6 */ { "DIACRITIQUE VOYELLE TAMOULE É","	* à gauche de la consonne"},
/* 0BC7 */ { "DIACRITIQUE VOYELLE TAMOULE ÉÉ","	* à gauche de la consonne"},
/* 0BC8 */ { "DIACRITIQUE VOYELLE TAMOULE AÏ","	* à gauche de la consonne"},
/* 0BC9 */ { NULL,NULL},
/* 0BCA */ { "DIACRITIQUE VOYELLE TAMOULE O","	: 0BC6 0BBE"},
/* 0BCB */ { "DIACRITIQUE VOYELLE TAMOULE Ô","	: 0BC7 0BBE"},
/* 0BCC */ { "DIACRITIQUE VOYELLE TAMOULE AOU","	: 0BC6 0BD7"},
/* 0BCD */ { "DIACRITIQUE TAMOUL VIRÂMA","	= poulli"},
/* 0BCE */ { NULL,NULL},
/* 0BCF */ { NULL,NULL},
/* 0BD0 */ { "OM TAMOUL",NULL},
/* 0BD1 */ { NULL,NULL},
/* 0BD2 */ { NULL,NULL},
/* 0BD3 */ { NULL,NULL},
/* 0BD4 */ { NULL,NULL},
/* 0BD5 */ { NULL,NULL},
/* 0BD6 */ { NULL,NULL},
/* 0BD7 */ { "SIGNE DE LONGUEUR TAMOUL AOU",NULL},
/* 0BD8 */ { NULL,NULL},
/* 0BD9 */ { NULL,NULL},
/* 0BDA */ { NULL,NULL},
/* 0BDB */ { NULL,NULL},
/* 0BDC */ { NULL,NULL},
/* 0BDD */ { NULL,NULL},
/* 0BDE */ { NULL,NULL},
/* 0BDF */ { NULL,NULL},
/* 0BE0 */ { NULL,NULL},
/* 0BE1 */ { NULL,NULL},
/* 0BE2 */ { NULL,NULL},
/* 0BE3 */ { NULL,NULL},
/* 0BE4 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0BE5 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0BE6 */ { "CHIFFRE TAMOUL ZÉRO",NULL},
/* 0BE7 */ { "CHIFFRE TAMOUL UN",NULL},
/* 0BE8 */ { "CHIFFRE TAMOUL DEUX",NULL},
/* 0BE9 */ { "CHIFFRE TAMOUL TROIS",NULL},
/* 0BEA */ { "CHIFFRE TAMOUL QUATRE",NULL},
/* 0BEB */ { "CHIFFRE TAMOUL CINQ",NULL},
/* 0BEC */ { "CHIFFRE TAMOUL SIX",NULL},
/* 0BED */ { "CHIFFRE TAMOUL SEPT",NULL},
/* 0BEE */ { "CHIFFRE TAMOUL HUIT",NULL},
/* 0BEF */ { "CHIFFRE TAMOUL NEUF",NULL},
/* 0BF0 */ { "NOMBRE TAMOUL DIX",NULL},
/* 0BF1 */ { "NOMBRE TAMOUL CENT",NULL},
/* 0BF2 */ { "NOMBRE TAMOUL MILLE",NULL},
/* 0BF3 */ { "SYMBOLE TAMOUL DU JOUR","	= nâl, nâli/padi\n"
	"	* désigne une mesure de capacité en grain qui équivant à 2 ouri ou 4 oulakkou\n"
	"	x (symbole tamoul mouvouzhakkou - 11FD9)\n"
	"	= pillaïyâr souli\n"
	"	* désigne une conjoncture favorable, un jour propice"},
/* 0BF4 */ { "SYMBOLE TAMOUL DU MOIS","	= mâtham"},
/* 0BF5 */ { "SYMBOLE TAMOUL DE L'ANNÉE","	= varoudam"},
/* 0BF6 */ { "SYMBOLE TAMOUL DE DÉBIT","	= patrou"},
/* 0BF7 */ { "SYMBOLE TAMOUL DE CRÉDIT","	= édouppou\n"
	"	* désigne l'encaissement d'argent liquide qui est mis de côté pour des dépenses inconnues\n"
	"	* parfois utilisé pour le symbole de crédit; le symbole traditionnel est différent\n"
	"	x (symbole tamoul traditionnel de crédit - 11FE8)"},
/* 0BF8 */ { "SYMBOLE TAMOUL COMME CI-DESSUS","	= merpadi"},
/* 0BF9 */ { "SYMBOLE TAMOUL ROUPIE","	= roupaï\n"
	"	x (symbole tamoul terrain - 11FE6)"},
/* 0BFA */ { "SYMBOLE TAMOUL NUMÉRO","	= enn, nilouvaï\n"
	"	* désigne le solde\n"
	"	* utilisé parfois comme symbole pour numéro, distinct du signe traditionnel\n"
	"	x (symbole tamoul traditionnel numéro - 11FE9)"},
/* 0BFB */ { NULL,NULL},
/* 0BFC */ { NULL,NULL},
/* 0BFD */ { NULL,NULL},
/* 0BFE */ { NULL,NULL},
/* 0BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_0C[] = {
/* 0C00 */ { "DIACRITIQUE TÉLOUGOU TCHANDRABINDOU SUSCRIT",NULL},
/* 0C01 */ { "DIACRITIQUE TÉLOUGOU TCHANDRABINDOU","	= arasounna\n"
	"	* indique une nasale élidée contextuellement"},
/* 0C02 */ { "DIACRITIQUE TÉLOUGOU ANOUSVÂRA","	= sounna\n"
	"	* utilisé dans les textes en langue prâkrit pour indiquer la gémination de la consonne suivante"},
/* 0C03 */ { "DIACRITIQUE TÉLOUGOU VISARGA",NULL},
/* 0C04 */ { "DIACRITIQUE TÉLOUGOU ANOUSVÂRA SUSCRIT","	* utilisé dans des textes en langue prâkrit pour l'anousvâra linguistique"},
/* 0C05 */ { "LETTRE TÉLOUGOU A",NULL},
/* 0C06 */ { "LETTRE TÉLOUGOU Â",NULL},
/* 0C07 */ { "LETTRE TÉLOUGOU I",NULL},
/* 0C08 */ { "LETTRE TÉLOUGOU Î",NULL},
/* 0C09 */ { "LETTRE TÉLOUGOU OU",NULL},
/* 0C0A */ { "LETTRE TÉLOUGOU OÛ",NULL},
/* 0C0B */ { "LETTRE TÉLOUGOU R VOCALIQUE",NULL},
/* 0C0C */ { "LETTRE TÉLOUGOU L VOCALIQUE",NULL},
/* 0C0D */ { NULL,NULL},
/* 0C0E */ { "LETTRE TÉLOUGOU É",NULL},
/* 0C0F */ { "LETTRE TÉLOUGOU ÉÉ",NULL},
/* 0C10 */ { "LETTRE TÉLOUGOU AÏ",NULL},
/* 0C11 */ { NULL,NULL},
/* 0C12 */ { "LETTRE TÉLOUGOU O",NULL},
/* 0C13 */ { "LETTRE TÉLOUGOU Ô",NULL},
/* 0C14 */ { "LETTRE TÉLOUGOU AOU",NULL},
/* 0C15 */ { "LETTRE TÉLOUGOU KA",NULL},
/* 0C16 */ { "LETTRE TÉLOUGOU KHA",NULL},
/* 0C17 */ { "LETTRE TÉLOUGOU GA",NULL},
/* 0C18 */ { "LETTRE TÉLOUGOU GHA",NULL},
/* 0C19 */ { "LETTRE TÉLOUGOU NGA",NULL},
/* 0C1A */ { "LETTRE TÉLOUGOU TCHA",NULL},
/* 0C1B */ { "LETTRE TÉLOUGOU TCHHA",NULL},
/* 0C1C */ { "LETTRE TÉLOUGOU DJA",NULL},
/* 0C1D */ { "LETTRE TÉLOUGOU DJHA",NULL},
/* 0C1E */ { "LETTRE TÉLOUGOU ÑA",NULL},
/* 0C1F */ { "LETTRE TÉLOUGOU TTA",NULL},
/* 0C20 */ { "LETTRE TÉLOUGOU TTHA",NULL},
/* 0C21 */ { "LETTRE TÉLOUGOU DDA",NULL},
/* 0C22 */ { "LETTRE TÉLOUGOU DDHA",NULL},
/* 0C23 */ { "LETTRE TÉLOUGOU NNA",NULL},
/* 0C24 */ { "LETTRE TÉLOUGOU TA",NULL},
/* 0C25 */ { "LETTRE TÉLOUGOU THA",NULL},
/* 0C26 */ { "LETTRE TÉLOUGOU DA",NULL},
/* 0C27 */ { "LETTRE TÉLOUGOU DHA",NULL},
/* 0C28 */ { "LETTRE TÉLOUGOU NA",NULL},
/* 0C29 */ { NULL,NULL},
/* 0C2A */ { "LETTRE TÉLOUGOU PA",NULL},
/* 0C2B */ { "LETTRE TÉLOUGOU PHA","	= lettre télougou p'a"},
/* 0C2C */ { "LETTRE TÉLOUGOU BA",NULL},
/* 0C2D */ { "LETTRE TÉLOUGOU BHA",NULL},
/* 0C2E */ { "LETTRE TÉLOUGOU MA",NULL},
/* 0C2F */ { "LETTRE TÉLOUGOU YA",NULL},
/* 0C30 */ { "LETTRE TÉLOUGOU RA",NULL},
/* 0C31 */ { "LETTRE TÉLOUGOU RRA",NULL},
/* 0C32 */ { "LETTRE TÉLOUGOU LA",NULL},
/* 0C33 */ { "LETTRE TÉLOUGOU LLA",NULL},
/* 0C34 */ { "LETTRE TÉLOUGOU LLLA",NULL},
/* 0C35 */ { "LETTRE TÉLOUGOU VA",NULL},
/* 0C36 */ { "LETTRE TÉLOUGOU ÇA",NULL},
/* 0C37 */ { "LETTRE TÉLOUGOU CHA",NULL},
/* 0C38 */ { "LETTRE TÉLOUGOU SA",NULL},
/* 0C39 */ { "LETTRE TÉLOUGOU HA",NULL},
/* 0C3A */ { NULL,NULL},
/* 0C3B */ { NULL,NULL},
/* 0C3C */ { "DIACRITIQUE TÉLOUGOU NOUKTA","	* utilisé pour la translittération du tamoul et pour des phonèmes perso-arabes\n"
	"	* peut également apparaître sous la forme d'un gros point ; il doit être placé suffisamment au-dessous de la ligne de pied d'une consonne pour éviter toute confusion/collision avec le marqueur d'aspiration"},
/* 0C3D */ { "SIGNE TÉLOUGOU AVAGRAHA",NULL},
/* 0C3E */ { "DIACRITIQUE VOYELLE TÉLOUGOU Â",NULL},
/* 0C3F */ { "DIACRITIQUE VOYELLE TÉLOUGOU I",NULL},
/* 0C40 */ { "DIACRITIQUE VOYELLE TÉLOUGOU Î",NULL},
/* 0C41 */ { "DIACRITIQUE VOYELLE TÉLOUGOU OU",NULL},
/* 0C42 */ { "DIACRITIQUE VOYELLE TÉLOUGOU OÛ",NULL},
/* 0C43 */ { "DIACRITIQUE VOYELLE TÉLOUGOU R VOCALIQUE",NULL},
/* 0C44 */ { "DIACRITIQUE VOYELLE TÉLOUGOU RR VOCALIQUE",NULL},
/* 0C45 */ { NULL,NULL},
/* 0C46 */ { "DIACRITIQUE VOYELLE TÉLOUGOU É",NULL},
/* 0C47 */ { "DIACRITIQUE VOYELLE TÉLOUGOU ÉÉ",NULL},
/* 0C48 */ { "DIACRITIQUE VOYELLE TÉLOUGOU AÏ","	: 0C46 0C56"},
/* 0C49 */ { NULL,NULL},
/* 0C4A */ { "DIACRITIQUE VOYELLE TÉLOUGOU O",NULL},
/* 0C4B */ { "DIACRITIQUE VOYELLE TÉLOUGOU Ô",NULL},
/* 0C4C */ { "DIACRITIQUE VOYELLE TÉLOUGOU AOU",NULL},
/* 0C4D */ { "DIACRITIQUE TÉLOUGOU VIRÂMA","	= halant (le nom recommandé)"},
/* 0C4E */ { NULL,NULL},
/* 0C4F */ { NULL,NULL},
/* 0C50 */ { NULL,NULL},
/* 0C51 */ { NULL,NULL},
/* 0C52 */ { NULL,NULL},
/* 0C53 */ { NULL,NULL},
/* 0C54 */ { NULL,NULL},
/* 0C55 */ { "SIGNE DE LONGUEUR TÉLOUGOU",NULL},
/* 0C56 */ { "SIGNE DE LONGUEUR TÉLOUGOU AÏ",NULL},
/* 0C57 */ { NULL,NULL},
/* 0C58 */ { "LETTRE TÉLOUGOU TSA",NULL},
/* 0C59 */ { "LETTRE TÉLOUGOU DZA",NULL},
/* 0C5A */ { "LETTRE TÉLOUGOU RRRA","	* lettre pour une consonne alvéolaire dont la valeur phonétique exacte n'est pas connue"},
/* 0C5B */ { NULL,NULL},
/* 0C5C */ { "ÇRÎ ARCHAÏQUE TÉLOUGOU","	* mot de bon augure çrî\n"
	"	* ne se combine pas avec d'autres lettres"},
/* 0C5D */ { "LETTRE TÉLOUGOU NAKÂRA POLLOU","	* forme de na dépourvue de voyelle\n"
	"	x (lettre kannara nakâra pollou - 0CDD)\n"
	"	x (lettre malayalam n tchillou - 0D7B)"},
/* 0C5E */ { NULL,NULL},
/* 0C5F */ { NULL,NULL},
/* 0C60 */ { "LETTRE TÉLOUGOU RR VOCALIQUE",NULL},
/* 0C61 */ { "LETTRE TÉLOUGOU LL VOCALIQUE",NULL},
/* 0C62 */ { "DIACRITIQUE VOYELLE TÉLOUGOU L VOCALIQUE",NULL},
/* 0C63 */ { "DIACRITIQUE VOYELLE TÉLOUGOU LL VOCALIQUE",NULL},
/* 0C64 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0C65 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0C66 */ { "CHIFFRE TÉLOUGOU ZÉRO",NULL},
/* 0C67 */ { "CHIFFRE TÉLOUGOU UN",NULL},
/* 0C68 */ { "CHIFFRE TÉLOUGOU DEUX",NULL},
/* 0C69 */ { "CHIFFRE TÉLOUGOU TROIS",NULL},
/* 0C6A */ { "CHIFFRE TÉLOUGOU QUATRE",NULL},
/* 0C6B */ { "CHIFFRE TÉLOUGOU CINQ",NULL},
/* 0C6C */ { "CHIFFRE TÉLOUGOU SIX",NULL},
/* 0C6D */ { "CHIFFRE TÉLOUGOU SEPT",NULL},
/* 0C6E */ { "CHIFFRE TÉLOUGOU HUIT",NULL},
/* 0C6F */ { "CHIFFRE TÉLOUGOU NEUF",NULL},
/* 0C70 */ { NULL,NULL},
/* 0C71 */ { NULL,NULL},
/* 0C72 */ { NULL,NULL},
/* 0C73 */ { NULL,NULL},
/* 0C74 */ { NULL,NULL},
/* 0C75 */ { NULL,NULL},
/* 0C76 */ { NULL,NULL},
/* 0C77 */ { "SIGNE TÉLOUGOU SIDDHAM","	= siddhirastou\n"
	"	* placé au début d'un texte comme une invocation\n"
	"	x (signe dévanâgarî siddham - A8FC)\n"
	"	x (signe charada siddham - 111DB)"},
/* 0C78 */ { "NUMÉRATEUR TÉLOUGOU ZÉRO POUR LES PUISSANCES IMPAIRES DE QUATRE",NULL},
/* 0C79 */ { "NUMÉRATEUR TÉLOUGOU UN POUR LES PUISSANCES IMPAIRES DE QUATRE",NULL},
/* 0C7A */ { "NUMÉRATEUR TÉLOUGOU DEUX POUR LES PUISSANCES IMPAIRES DE QUATRE",NULL},
/* 0C7B */ { "NUMÉRATEUR TÉLOUGOU TROIS POUR LES PUISSANCES IMPAIRES DE QUATRE",NULL},
/* 0C7C */ { "NUMÉRATEUR TÉLOUGOU UN POUR LES PUISSANCES PAIRES DE QUATRE",NULL},
/* 0C7D */ { "NUMÉRATEUR TÉLOUGOU DEUX POUR LES PUISSANCES PAIRES DE QUATRE",NULL},
/* 0C7E */ { "NUMÉRATEUR TÉLOUGOU TROIS POUR LES PUISSANCES PAIRES DE QUATRE",NULL},
/* 0C7F */ { "SYMBOLE TÉLOUGOU TOÛMOU",NULL},
/* 0C80 */ { "SIGNE KANNARA TCHANDRABINDOU À CHASSE",NULL},
/* 0C81 */ { "DIACRITIQUE KANNARA TCHANDRABINDOU",NULL},
/* 0C82 */ { "DIACRITIQUE KANNARA ANOUSVÂRA","	* utilisé pour représenter un anousvâra ordinaire dans les textes en konkani, en havyaka et en awadhi"},
/* 0C83 */ { "DIACRITIQUE KANNARA VISARGA",NULL},
/* 0C84 */ { "SIGNE KANNARA SIDDHAM","	= siddhirastou\n"
	"	* placé au début d'un texte comme une invocation\n"
	"	x (signe dévanâgarî siddham - A8FC)\n"
	"	x (signe charada siddham - 111DB)"},
/* 0C85 */ { "LETTRE KANNARA A",NULL},
/* 0C86 */ { "LETTRE KANNARA Â",NULL},
/* 0C87 */ { "LETTRE KANNARA I",NULL},
/* 0C88 */ { "LETTRE KANNARA Î",NULL},
/* 0C89 */ { "LETTRE KANNARA OU",NULL},
/* 0C8A */ { "LETTRE KANNARA OÛ",NULL},
/* 0C8B */ { "LETTRE KANNARA R VOCALIQUE",NULL},
/* 0C8C */ { "LETTRE KANNARA L VOCALIQUE",NULL},
/* 0C8D */ { NULL,NULL},
/* 0C8E */ { "LETTRE KANNARA É",NULL},
/* 0C8F */ { "LETTRE KANNARA ÉÉ",NULL},
/* 0C90 */ { "LETTRE KANNARA AI",NULL},
/* 0C91 */ { NULL,NULL},
/* 0C92 */ { "LETTRE KANNARA O",NULL},
/* 0C93 */ { "LETTRE KANNARA Ô",NULL},
/* 0C94 */ { "LETTRE KANNARA AOU",NULL},
/* 0C95 */ { "LETTRE KANNARA KA",NULL},
/* 0C96 */ { "LETTRE KANNARA KHA",NULL},
/* 0C97 */ { "LETTRE KANNARA GA",NULL},
/* 0C98 */ { "LETTRE KANNARA GHA",NULL},
/* 0C99 */ { "LETTRE KANNARA NGA",NULL},
/* 0C9A */ { "LETTRE KANNARA TCHA",NULL},
/* 0C9B */ { "LETTRE KANNARA TCHHA",NULL},
/* 0C9C */ { "LETTRE KANNARA DJA",NULL},
/* 0C9D */ { "LETTRE KANNARA DJHA",NULL},
/* 0C9E */ { "LETTRE KANNARA ÑA",NULL},
/* 0C9F */ { "LETTRE KANNARA TTA",NULL},
/* 0CA0 */ { "LETTRE KANNARA TTHA",NULL},
/* 0CA1 */ { "LETTRE KANNARA DDA",NULL},
/* 0CA2 */ { "LETTRE KANNARA DDHA",NULL},
/* 0CA3 */ { "LETTRE KANNARA NNA",NULL},
/* 0CA4 */ { "LETTRE KANNARA TA",NULL},
/* 0CA5 */ { "LETTRE KANNARA THA",NULL},
/* 0CA6 */ { "LETTRE KANNARA DA",NULL},
/* 0CA7 */ { "LETTRE KANNARA DHA",NULL},
/* 0CA8 */ { "LETTRE KANNARA NA",NULL},
/* 0CA9 */ { NULL,NULL},
/* 0CAA */ { "LETTRE KANNARA PA",NULL},
/* 0CAB */ { "LETTRE KANNARA PHA","	= lettre kannara p'a"},
/* 0CAC */ { "LETTRE KANNARA BA",NULL},
/* 0CAD */ { "LETTRE KANNARA BHA",NULL},
/* 0CAE */ { "LETTRE KANNARA MA",NULL},
/* 0CAF */ { "LETTRE KANNARA YA",NULL},
/* 0CB0 */ { "LETTRE KANNARA RA",NULL},
/* 0CB1 */ { "LETTRE KANNARA RRA",NULL},
/* 0CB2 */ { "LETTRE KANNARA LA",NULL},
/* 0CB3 */ { "LETTRE KANNARA LLA",NULL},
/* 0CB4 */ { NULL,NULL},
/* 0CB5 */ { "LETTRE KANNARA VA",NULL},
/* 0CB6 */ { "LETTRE KANNARA ÇA",NULL},
/* 0CB7 */ { "LETTRE KANNARA CHA",NULL},
/* 0CB8 */ { "LETTRE KANNARA SA",NULL},
/* 0CB9 */ { "LETTRE KANNARA HA",NULL},
/* 0CBA */ { NULL,NULL},
/* 0CBB */ { NULL,NULL},
/* 0CBC */ { "DIACRITIQUE KANNARA NOUKTA",NULL},
/* 0CBD */ { "SIGNE KANNARA AVAGRAHA",NULL},
/* 0CBE */ { "DIACRITIQUE VOYELLE KANNARA Â",NULL},
/* 0CBF */ { "DIACRITIQUE VOYELLE KANNARA I",NULL},
/* 0CC0 */ { "DIACRITIQUE VOYELLE KANNARA Î","	: 0CBF 0CD5"},
/* 0CC1 */ { "DIACRITIQUE VOYELLE KANNARA OU",NULL},
/* 0CC2 */ { "DIACRITIQUE VOYELLE KANNARA OÛ",NULL},
/* 0CC3 */ { "DIACRITIQUE VOYELLE KANNARA R VOCALIQUE",NULL},
/* 0CC4 */ { "DIACRITIQUE VOYELLE KANNARA RR VOCALIQUE",NULL},
/* 0CC5 */ { NULL,NULL},
/* 0CC6 */ { "DIACRITIQUE VOYELLE KANNARA É",NULL},
/* 0CC7 */ { "DIACRITIQUE VOYELLE KANNARA ÉÉ","	: 0CC6 0CD5"},
/* 0CC8 */ { "DIACRITIQUE VOYELLE KANNARA AI","	: 0CC6 0CD6"},
/* 0CC9 */ { NULL,NULL},
/* 0CCA */ { "DIACRITIQUE VOYELLE KANNARA O","	: 0CC6 0CC2"},
/* 0CCB */ { "DIACRITIQUE VOYELLE KANNARA Ô","	: 0CCA 0CD5"},
/* 0CCC */ { "DIACRITIQUE VOYELLE KANNARA AOU",NULL},
/* 0CCD */ { "DIACRITIQUE KANNARA VIRÂMA","	* le nom recommandé est halant"},
/* 0CCE */ { NULL,NULL},
/* 0CCF */ { NULL,NULL},
/* 0CD0 */ { NULL,NULL},
/* 0CD1 */ { NULL,NULL},
/* 0CD2 */ { NULL,NULL},
/* 0CD3 */ { NULL,NULL},
/* 0CD4 */ { NULL,NULL},
/* 0CD5 */ { "SIGNE DE LONGUEUR KANNARA",NULL},
/* 0CD6 */ { "SIGNE DE LONGUEUR KANNARA AI",NULL},
/* 0CD7 */ { NULL,NULL},
/* 0CD8 */ { NULL,NULL},
/* 0CD9 */ { NULL,NULL},
/* 0CDA */ { NULL,NULL},
/* 0CDB */ { NULL,NULL},
/* 0CDC */ { "ÇRÎ ARCHAÏQUE KANNARA","	* mot de bon augure çrî\n"
	"	* ne se combine pas avec d'autres lettres"},
/* 0CDD */ { "LETTRE KANNARA NAKÂRA POLLOU","	* forme de na dépourvue de voyelle\n"
	"	x (lettre télougou nakâra pollou - 0C5D)\n"
	"	x (lettre malayalam n tchillou - 0D7B)"},
/* 0CDE */ { "LETTRE KANNARA LLLA","	* le nom formel de ce caractère en anglais est erroné\n"
	"	* lettre désuète"},
/* 0CDF */ { NULL,NULL},
/* 0CE0 */ { "LETTRE KANNARA RR VOCALIQUE",NULL},
/* 0CE1 */ { "LETTRE KANNARA LL VOCALIQUE",NULL},
/* 0CE2 */ { "DIACRITIQUE VOYELLE KANNARA L VOCALIQUE",NULL},
/* 0CE3 */ { "DIACRITIQUE VOYELLE KANNARA LL VOCALIQUE",NULL},
/* 0CE4 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0CE5 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0CE6 */ { "CHIFFRE KANNARA ZÉRO",NULL},
/* 0CE7 */ { "CHIFFRE KANNARA UN",NULL},
/* 0CE8 */ { "CHIFFRE KANNARA DEUX",NULL},
/* 0CE9 */ { "CHIFFRE KANNARA TROIS",NULL},
/* 0CEA */ { "CHIFFRE KANNARA QUATRE",NULL},
/* 0CEB */ { "CHIFFRE KANNARA CINQ",NULL},
/* 0CEC */ { "CHIFFRE KANNARA SIX",NULL},
/* 0CED */ { "CHIFFRE KANNARA SEPT",NULL},
/* 0CEE */ { "CHIFFRE KANNARA HUIT",NULL},
/* 0CEF */ { "CHIFFRE KANNARA NEUF",NULL},
/* 0CF0 */ { NULL,NULL},
/* 0CF1 */ { "SIGNE KANNARA DJIHVAMOULIYA","	x (signe védique djihvamouliya - 1CF5)"},
/* 0CF2 */ { "SIGNE KANNARA OUPADHMANIYA","	x (signe védique oupadhmaniya - 1CF6)"},
/* 0CF3 */ { "DIACRITIQUE KANNARA ANOUSVÂRA SUSCRIT À DROITE","	* utilisé pour représenter un anounassika dans les textes en konkani, en havyaka et en awadhi"},
/* 0CF4 */ { NULL,NULL},
/* 0CF5 */ { NULL,NULL},
/* 0CF6 */ { NULL,NULL},
/* 0CF7 */ { NULL,NULL},
/* 0CF8 */ { NULL,NULL},
/* 0CF9 */ { NULL,NULL},
/* 0CFA */ { NULL,NULL},
/* 0CFB */ { NULL,NULL},
/* 0CFC */ { NULL,NULL},
/* 0CFD */ { NULL,NULL},
/* 0CFE */ { NULL,NULL},
/* 0CFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_0D[] = {
/* 0D00 */ { "DIACRITIQUE MALAYALAM ANOUSVÂRA SUSCRIT",NULL},
/* 0D01 */ { "DIACRITIQUE MALAYALAM TCHANDRABINDOU",NULL},
/* 0D02 */ { "DIACRITIQUE MALAYALAM ANOUSVÂRA","	* utilisé dans les textes en langue prâkrit pour indiquer la gémination de la consonne suivante"},
/* 0D03 */ { "DIACRITIQUE MALAYALAM VISARGA",NULL},
/* 0D04 */ { "LETTRE MALAYALAM ANOUSVÂRA VÉDIQUE",NULL},
/* 0D05 */ { "LETTRE MALAYALAM A",NULL},
/* 0D06 */ { "LETTRE MALAYALAM Â",NULL},
/* 0D07 */ { "LETTRE MALAYALAM I",NULL},
/* 0D08 */ { "LETTRE MALAYALAM Î",NULL},
/* 0D09 */ { "LETTRE MALAYALAM OU",NULL},
/* 0D0A */ { "LETTRE MALAYALAM OÛ",NULL},
/* 0D0B */ { "LETTRE MALAYALAM R VOCALIQUE",NULL},
/* 0D0C */ { "LETTRE MALAYALAM L VOCALIQUE",NULL},
/* 0D0D */ { NULL,NULL},
/* 0D0E */ { "LETTRE MALAYALAM É",NULL},
/* 0D0F */ { "LETTRE MALAYALAM ÉÉ",NULL},
/* 0D10 */ { "LETTRE MALAYALAM AI",NULL},
/* 0D11 */ { NULL,NULL},
/* 0D12 */ { "LETTRE MALAYALAM O",NULL},
/* 0D13 */ { "LETTRE MALAYALAM Ô",NULL},
/* 0D14 */ { "LETTRE MALAYALAM AOU",NULL},
/* 0D15 */ { "LETTRE MALAYALAM KA",NULL},
/* 0D16 */ { "LETTRE MALAYALAM KHA",NULL},
/* 0D17 */ { "LETTRE MALAYALAM GA",NULL},
/* 0D18 */ { "LETTRE MALAYALAM GHA",NULL},
/* 0D19 */ { "LETTRE MALAYALAM NGA",NULL},
/* 0D1A */ { "LETTRE MALAYALAM TCHA","	= cha"},
/* 0D1B */ { "LETTRE MALAYALAM TCHHA","	= chha"},
/* 0D1C */ { "LETTRE MALAYALAM DJA",NULL},
/* 0D1D */ { "LETTRE MALAYALAM DJHA",NULL},
/* 0D1E */ { "LETTRE MALAYALAM ÑA","	= nha"},
/* 0D1F */ { "LETTRE MALAYALAM TTA","	= ta"},
/* 0D20 */ { "LETTRE MALAYALAM TTHA","	= tta"},
/* 0D21 */ { "LETTRE MALAYALAM DDA","	= da dur"},
/* 0D22 */ { "LETTRE MALAYALAM DDHA","	= dda dur"},
/* 0D23 */ { "LETTRE MALAYALAM NNA","	= na dur"},
/* 0D24 */ { "LETTRE MALAYALAM TA","	= tha"},
/* 0D25 */ { "LETTRE MALAYALAM THA","	= ttha"},
/* 0D26 */ { "LETTRE MALAYALAM DA","	= da mou"},
/* 0D27 */ { "LETTRE MALAYALAM DHA","	= dda mou"},
/* 0D28 */ { "LETTRE MALAYALAM NA",NULL},
/* 0D29 */ { "LETTRE MALAYALAM NNNA","	* utilisation à des fins savantes uniquement"},
/* 0D2A */ { "LETTRE MALAYALAM PA",NULL},
/* 0D2B */ { "LETTRE MALAYALAM PHA","	= lettre malayalam p'a"},
/* 0D2C */ { "LETTRE MALAYALAM BA",NULL},
/* 0D2D */ { "LETTRE MALAYALAM BHA",NULL},
/* 0D2E */ { "LETTRE MALAYALAM MA","	* s'utilise aussi pour la fraction un quatre-vingtième (ou un huitantième)"},
/* 0D2F */ { "LETTRE MALAYALAM YA",NULL},
/* 0D30 */ { "LETTRE MALAYALAM RA",NULL},
/* 0D31 */ { "LETTRE MALAYALAM RRA",NULL},
/* 0D32 */ { "LETTRE MALAYALAM LA",NULL},
/* 0D33 */ { "LETTRE MALAYALAM LLA",NULL},
/* 0D34 */ { "LETTRE MALAYALAM LLLA","	= ja"},
/* 0D35 */ { "LETTRE MALAYALAM VA",NULL},
/* 0D36 */ { "LETTRE MALAYALAM ÇA","	= cha mou"},
/* 0D37 */ { "LETTRE MALAYALAM CHA","	= sha"},
/* 0D38 */ { "LETTRE MALAYALAM SA",NULL},
/* 0D39 */ { "LETTRE MALAYALAM HA",NULL},
/* 0D3A */ { "LETTRE MALAYALAM TTTA","	* utilisation à des fins savantes uniquement"},
/* 0D3B */ { "DIACRITIQUE MALAYALAM VIRÂMA EN FORME DE BARRE VERTICALE",NULL},
/* 0D3C */ { "DIACRITIQUE MALAYALAM VIRÂMA CIRCULAIRE",NULL},
/* 0D3D */ { "SIGNE MALAYALAM AVAGRAHA","	= praslecham"},
/* 0D3E */ { "DIACRITIQUE VOYELLE MALAYALAM Â",NULL},
/* 0D3F */ { "DIACRITIQUE VOYELLE MALAYALAM I",NULL},
/* 0D40 */ { "DIACRITIQUE VOYELLE MALAYALAM Î",NULL},
/* 0D41 */ { "DIACRITIQUE VOYELLE MALAYALAM OU",NULL},
/* 0D42 */ { "DIACRITIQUE VOYELLE MALAYALAM OÛ",NULL},
/* 0D43 */ { "DIACRITIQUE VOYELLE MALAYALAM R VOCALIQUE",NULL},
/* 0D44 */ { "DIACRITIQUE VOYELLE MALAYALAM RR VOCALIQUE",NULL},
/* 0D45 */ { NULL,NULL},
/* 0D46 */ { "DIACRITIQUE VOYELLE MALAYALAM É","	* à gauche de la consonne"},
/* 0D47 */ { "DIACRITIQUE VOYELLE MALAYALAM ÉÉ","	* à gauche de la consonne"},
/* 0D48 */ { "DIACRITIQUE VOYELLE MALAYALAM AI","	* à gauche de la consonne"},
/* 0D49 */ { NULL,NULL},
/* 0D4A */ { "DIACRITIQUE VOYELLE MALAYALAM O","	: 0D46 0D3E"},
/* 0D4B */ { "DIACRITIQUE VOYELLE MALAYALAM Ô","	: 0D47 0D3E"},
/* 0D4C */ { "DIACRITIQUE VOYELLE MALAYALAM AOU","	* forme archaïque de la voyelle diacritique /aou/\n"
	"	x (signe de longueur malayalam aou - 0D57)\n"
	"	: 0D46 0D57"},
/* 0D4D */ { "DIACRITIQUE MALAYALAM VIRÂMA","	= tchandrakkala (le nom recommandé)\n"
	"	= e muet malayalam, schwa malayalam"},
/* 0D4E */ { "LETTRE MALAYALAM REPHA POINT","	* inusité dans l'orthographe moderne malayalam"},
/* 0D4F */ { "SYMBOLE MALAYALAM PARA","	* utilisé autrefois pour la mesure du riz"},
/* 0D50 */ { NULL,NULL},
/* 0D51 */ { NULL,NULL},
/* 0D52 */ { NULL,NULL},
/* 0D53 */ { NULL,NULL},
/* 0D54 */ { "LETTRE MALAYALAM M TCHILLOU",NULL},
/* 0D55 */ { "LETTRE MALAYALAM Y TCHILLOU",NULL},
/* 0D56 */ { "LETTRE MALAYALAM LLL TCHILLOU",NULL},
/* 0D57 */ { "SIGNE DE LONGUEUR MALAYALAM AOU","	* s'utilise seul dans les textes modernes pour représenter la voyelle diacritique /aou/\n"
	"	x (diacritique voyelle malayalam aou - 0D4C)"},
/* 0D58 */ { "FRACTION MALAYALAM UN CENT-SOIXANTIÈME","	= arakâni"},
/* 0D59 */ { "FRACTION MALAYALAM UN QUARANTIÈME","	= aramâ"},
/* 0D5A */ { "FRACTION MALAYALAM TROIS QUATRE-VINGTIÈMES","	= fraction malayalam trois huitantièmes\n"
	"	= moûnnoukâni"},
/* 0D5B */ { "FRACTION MALAYALAM UN VINGTIÈME","	= oroumâ"},
/* 0D5C */ { "FRACTION MALAYALAM UN DIXIÈME","	= rantoumâ"},
/* 0D5D */ { "FRACTION MALAYALAM TROIS VINGTIÈMES","	= moûnnoumâ"},
/* 0D5E */ { "FRACTION MALAYALAM UN CINQUIÈME","	= nâloumâ"},
/* 0D5F */ { "LETTRE MALAYALAM Î ARCHAÏQUE",NULL},
/* 0D60 */ { "LETTRE MALAYALAM RR VOCALIQUE",NULL},
/* 0D61 */ { "LETTRE MALAYALAM LL VOCALIQUE",NULL},
/* 0D62 */ { "DIACRITIQUE VOYELLE MALAYALAM L VOCALIQUE",NULL},
/* 0D63 */ { "DIACRITIQUE VOYELLE MALAYALAM LL VOCALIQUE",NULL},
/* 0D64 */ { NULL,"	x (danda dévanâgarî - 0964)"},
/* 0D65 */ { NULL,"	x (double danda dévanâgarî - 0965)"},
/* 0D66 */ { "CHIFFRE MALAYALAM ZÉRO",NULL},
/* 0D67 */ { "CHIFFRE MALAYALAM UN",NULL},
/* 0D68 */ { "CHIFFRE MALAYALAM DEUX",NULL},
/* 0D69 */ { "CHIFFRE MALAYALAM TROIS",NULL},
/* 0D6A */ { "CHIFFRE MALAYALAM QUATRE",NULL},
/* 0D6B */ { "CHIFFRE MALAYALAM CINQ",NULL},
/* 0D6C */ { "CHIFFRE MALAYALAM SIX",NULL},
/* 0D6D */ { "CHIFFRE MALAYALAM SEPT",NULL},
/* 0D6E */ { "CHIFFRE MALAYALAM HUIT",NULL},
/* 0D6F */ { "CHIFFRE MALAYALAM NEUF",NULL},
/* 0D70 */ { "NOMBRE MALAYALAM DIX",NULL},
/* 0D71 */ { "NOMBRE MALAYALAM CENT",NULL},
/* 0D72 */ { "NOMBRE MALAYALAM MILLE",NULL},
/* 0D73 */ { "FRACTION MALAYALAM UN QUART","	= kâl\n"
	"	x (fraction indienne du nord un quart - A830)"},
/* 0D74 */ { "FRACTION MALAYALAM UN DEMI","	= ara\n"
	"	x (fraction indienne du nord un demi - A831)"},
/* 0D75 */ { "FRACTION MALAYALAM TROIS QUARTS","	= moukkâl\n"
	"	x (fraction indienne du nord trois quarts - A832)"},
/* 0D76 */ { "FRACTION MALAYALAM UN SEIZIÈME","	= mâkâni"},
/* 0D77 */ { "FRACTION MALAYALAM UN HUITIÈME","	= arakkâl"},
/* 0D78 */ { "FRACTION MALAYALAM TROIS SEIZIÈMES","	= mountâni"},
/* 0D79 */ { "SYMBOLE MALAYALAM QUANTIÈME",NULL},
/* 0D7A */ { "LETTRE MALAYALAM NN TCHILLOU",NULL},
/* 0D7B */ { "LETTRE MALAYALAM N TCHILLOU",NULL},
/* 0D7C */ { "LETTRE MALAYALAM RR TCHILLOU","	* historiquement dérivée de la lettre ra\n"
	"	* s'utilise aussi pour r tchillou"},
/* 0D7D */ { "LETTRE MALAYALAM L TCHILLOU","	* historiquement dérivée de la lettre ta\n"
	"	* s'utilise pour t tchillou et d tchillou"},
/* 0D7E */ { "LETTRE MALAYALAM LL TCHILLOU",NULL},
/* 0D7F */ { "LETTRE MALAYALAM K TCHILLOU",NULL},
/* 0D80 */ { NULL,NULL},
/* 0D81 */ { "DIACRITIQUE SINGHALAIS TCHANDRABINDOU","	* utilisé en sanskrit"},
/* 0D82 */ { "DIACRITIQUE SINGHALAIS ANOUSVÂRAYA","	= anusvara"},
/* 0D83 */ { "DIACRITIQUE SINGHALAIS VISARGAYA","	= visarga"},
/* 0D84 */ { NULL,NULL},
/* 0D85 */ { "LETTRE SINGHALAISE AYANNA","	= lettre singhalaise a"},
/* 0D86 */ { "LETTRE SINGHALAISE ÂYANNA","	= lettre singhalaise â"},
/* 0D87 */ { "LETTRE SINGHALAISE ÆYANNA","	= lettre singhalaise æ"},
/* 0D88 */ { "LETTRE SINGHALAISE ÆÆYANNA","	= lettre singhalaise ææ"},
/* 0D89 */ { "LETTRE SINGHALAISE IYANNA","	= lettre singhalaise i"},
/* 0D8A */ { "LETTRE SINGHALAISE ÎYANNA","	= lettre singhalaise î"},
/* 0D8B */ { "LETTRE SINGHALAISE OUYANNA","	= lettre singhalaise ou"},
/* 0D8C */ { "LETTRE SINGHALAISE OÛYANNA","	= lettre singhalaise oû"},
/* 0D8D */ { "LETTRE SINGHALAISE IROUYANNA","	= lettre singhalaise r vocalique"},
/* 0D8E */ { "LETTRE SINGHALAISE IROÛYANNA","	= lettre singhalaise rr vocalique"},
/* 0D8F */ { "LETTRE SINGHALAISE ILOUYANNA","	= lettre singhalaise l vocalique"},
/* 0D90 */ { "LETTRE SINGHALAISE ILOÛYANNA","	= lettre singhalaise ll vocalique"},
/* 0D91 */ { "LETTRE SINGHALAISE ÉYANNA","	= lettre singhalaise é"},
/* 0D92 */ { "LETTRE SINGHALAISE ÉÉYANNA","	= lettre singhalaise ê"},
/* 0D93 */ { "LETTRE SINGHALAISE AÏYANNA","	= lettre singhalaise aï"},
/* 0D94 */ { "LETTRE SINGHALAISE OYANNA","	= lettre singhalaise o"},
/* 0D95 */ { "LETTRE SINGHALAISE ÔYANNA","	= lettre singhalaise ô"},
/* 0D96 */ { "LETTRE SINGHALAISE AOUYANNA","	= lettre singhalaise aou"},
/* 0D97 */ { NULL,NULL},
/* 0D98 */ { NULL,NULL},
/* 0D99 */ { NULL,NULL},
/* 0D9A */ { "LETTRE SINGHALAISE ALPAPRÂNA KAYANNA","	= lettre singhalaise ka"},
/* 0D9B */ { "LETTRE SINGHALAISE MAHÂPRÂNA KAYANNA","	= lettre singhalaise kha"},
/* 0D9C */ { "LETTRE SINGHALAISE ALPAPRÂNA GAYANNA","	= lettre singhalaise ga"},
/* 0D9D */ { "LETTRE SINGHALAISE MAHÂPRÂNA GAYANNA","	= lettre singhalaise gha"},
/* 0D9E */ { "LETTRE SINGHALAISE KANTADJA NÂSIKYAYA","	= lettre singhalaise nna"},
/* 0D9F */ { "LETTRE SINGHALAISE SAÑAKA GAYANNA","	= lettre singhalaise nnga"},
/* 0DA0 */ { "LETTRE SINGHALAISE ALPAPRÂNA TCHAYANNA","	= lettre singhalaise tcha"},
/* 0DA1 */ { "LETTRE SINGHALAISE MAHÂPRÂNA TCHAYANNA","	= lettre singhalaise tchha"},
/* 0DA2 */ { "LETTRE SINGHALAISE ALPAPRÂNA DJAYANNA","	= lettre singhalaise dja"},
/* 0DA3 */ { "LETTRE SINGHALAISE MAHÂPRÂNA DJAYANNA","	= lettre singhalaise djha"},
/* 0DA4 */ { "LETTRE SINGHALAISE TÂLOUDJA NÂSIKYAYA","	= lettre singhalaise ña"},
/* 0DA5 */ { "LETTRE SINGHALAISE TÂLOUDJA SANYÔGA NÂKSIKYAYA","	= lettre singhalaise djña"},
/* 0DA6 */ { "LETTRE SINGHALAISE SAÑAKA DJAYANNA","	= lettre singhalaise ñdja"},
/* 0DA7 */ { "LETTRE SINGHALAISE ALPAPRÂNA TTAYANNA","	= lettre singhalaise tta"},
/* 0DA8 */ { "LETTRE SINGHALAISE MAHÂPRÂNA TTAYANNA","	= lettre singhalaise ttha"},
/* 0DA9 */ { "LETTRE SINGHALAISE ALPAPRÂNA DDAYANNA","	= lettre singhalaise dda"},
/* 0DAA */ { "LETTRE SINGHALAISE MAHÂPRÂNA DDAYANNA","	= lettre singhalaise ddha"},
/* 0DAB */ { "LETTRE SINGHALAISE MOÛRDHADJA NAYANNA","	= lettre singhalaise nna"},
/* 0DAC */ { "LETTRE SINGHALAISE SAÑAKA DDAYANNA","	= lettre singhalaise nndda"},
/* 0DAD */ { "LETTRE SINGHALAISE ALPAPRÂNA TAYANNA","	= lettre singhalaise ta"},
/* 0DAE */ { "LETTRE SINGHALAISE MAHÂPRÂNA TAYANNA","	= lettre singhalaise tha"},
/* 0DAF */ { "LETTRE SINGHALAISE ALPAPRÂNA DAYANNA","	= lettre singhalaise da"},
/* 0DB0 */ { "LETTRE SINGHALAISE MAHÂPRÂNA DAYANNA","	= lettre singhalaise dha"},
/* 0DB1 */ { "LETTRE SINGHALAISE DANTADJA NAYANNA","	= lettre singhalaise na"},
/* 0DB2 */ { NULL,NULL},
/* 0DB3 */ { "LETTRE SINGHALAISE SAÑAKA DAYANNA","	= lettre singhalaise nda"},
/* 0DB4 */ { "LETTRE SINGHALAISE ALPAPRÂNA PAYANNA","	= lettre singhalaise pa"},
/* 0DB5 */ { "LETTRE SINGHALAISE MAHÂPRÂNA PAYANNA","	= lettre singhalaise pha"},
/* 0DB6 */ { "LETTRE SINGHALAISE ALPAPRÂNA BAYANNA","	= lettre singhalaise ba"},
/* 0DB7 */ { "LETTRE SINGHALAISE MAHÂPRÂNA BAYANNA","	= lettre singhalaise bha"},
/* 0DB8 */ { "LETTRE SINGHALAISE MAYANNA","	= lettre singhalaise ma"},
/* 0DB9 */ { "LETTRE SINGHALAISE AMBA BAYANNA","	= lettre singhalaise mba"},
/* 0DBA */ { "LETTRE SINGHALAISE YAYANNA","	= lettre singhalaise ya"},
/* 0DBB */ { "LETTRE SINGHALAISE RAYANNA","	= lettre singhalaise ra"},
/* 0DBC */ { NULL,NULL},
/* 0DBD */ { "LETTRE SINGHALAISE DANTADJA LAYANNA","	= lettre singhalaise la\n"
	"	* dentale"},
/* 0DBE */ { NULL,NULL},
/* 0DBF */ { NULL,NULL},
/* 0DC0 */ { "LETTRE SINGHALAISE VAYANNA","	= lettre singhalaise va"},
/* 0DC1 */ { "LETTRE SINGHALAISE TÂLOUDJA ÇAYANNA","	= lettre singhalaise ça"},
/* 0DC2 */ { "LETTRE SINGHALAISE MOÛRDHADJA CHAYANNA","	= lettre singhalaise ssa\n"
	"	* rétroflexe"},
/* 0DC3 */ { "LETTRE SINGHALAISE DANTADJA SAYANNA","	= lettre singhalaise sa\n"
	"	* dentale"},
/* 0DC4 */ { "LETTRE SINGHALAISE HAYANNA","	= lettre singhalaise ha"},
/* 0DC5 */ { "LETTRE SINGHALAISE MOÛRDHADJA LAYANNA","	= lettre singhalaise lla\n"
	"	* rétroflexe"},
/* 0DC6 */ { "LETTRE SINGHALAISE FAYANNA","	= lettre singhalaise fa"},
/* 0DC7 */ { NULL,NULL},
/* 0DC8 */ { NULL,NULL},
/* 0DC9 */ { NULL,NULL},
/* 0DCA */ { "DIACRITIQUE SINGHALAIS AL-LAKOUNA","	= virâma"},
/* 0DCB */ { NULL,NULL},
/* 0DCC */ { NULL,NULL},
/* 0DCD */ { NULL,NULL},
/* 0DCE */ { NULL,NULL},
/* 0DCF */ { "DIACRITIQUE VOYELLE SINGHALAISE ÆLA-PILLA","	= diacritique voyelle singhalaise â"},
/* 0DD0 */ { "DIACRITIQUE VOYELLE SINGHALAISE KÉTTI ÆDA-PILLA","	= diacritique voyelle singhalaise æ"},
/* 0DD1 */ { "DIACRITIQUE VOYELLE SINGHALAISE DIGA ÆDA-PILLA","	= diacritique voyelle singhalaise æ"},
/* 0DD2 */ { "DIACRITIQUE VOYELLE SINGHALAISE KÉTTI IS-PILLA","	= diacritique voyelle singhalaise i"},
/* 0DD3 */ { "DIACRITIQUE VOYELLE SINGHALAISE DIGA IS-PILLA","	= diacritique voyelle singhalaise î"},
/* 0DD4 */ { "DIACRITIQUE VOYELLE SINGHALAISE KÉTTI PÂ-PILLA","	= diacritique voyelle singhalaise ou"},
/* 0DD5 */ { NULL,NULL},
/* 0DD6 */ { "DIACRITIQUE VOYELLE SINGHALAISE DIGA PÂ-PILLA","	= diacritique voyelle singhalaise oû"},
/* 0DD7 */ { NULL,NULL},
/* 0DD8 */ { "DIACRITIQUE VOYELLE SINGHALAISE GÆTTA-PILLA","	= diacritique voyelle singhalaise r vocalique"},
/* 0DD9 */ { "DIACRITIQUE VOYELLE SINGHALAISE KOMBOUVA","	= diacritique voyelle singhalaise é"},
/* 0DDA */ { "DIACRITIQUE VOYELLE SINGHALAISE DIGA KOMBOUVA","	= diacritique voyelle singhalaise ê\n"
	"	: 0DD9 0DCA"},
/* 0DDB */ { "DIACRITIQUE VOYELLE SINGHALAISE KOMBOU DEKA","	= diacritique voyelle singhalaise aï"},
/* 0DDC */ { "DIACRITIQUE VOYELLE SINGHALAISE KOMBOUVA HAA ÆLA-PILLA","	= diacritique voyelle singhalaise o\n"
	"	: 0DD9 0DCF"},
/* 0DDD */ { "DIACRITIQUE VOYELLE SINGHALAISE KOMBOUVA HAA DIGA ÆLA-PILLA","	= diacritique voyelle singhalaise ô\n"
	"	: 0DDC 0DCA"},
/* 0DDE */ { "DIACRITIQUE VOYELLE SINGHALAISE KOMBOUVA HAA GAYANOUKITTA","	= diacritique voyelle singhalaise aou\n"
	"	: 0DD9 0DDF"},
/* 0DDF */ { "DIACRITIQUE VOYELLE SINGHALAISE GAYANOUKITTA","	= diacritique voyelle singhalaise l vocalique"},
/* 0DE0 */ { NULL,NULL},
/* 0DE1 */ { NULL,NULL},
/* 0DE2 */ { NULL,NULL},
/* 0DE3 */ { NULL,NULL},
/* 0DE4 */ { NULL,NULL},
/* 0DE5 */ { NULL,NULL},
/* 0DE6 */ { "CHIFFRE LITH SINGHALAIS ZÉRO",NULL},
/* 0DE7 */ { "CHIFFRE LITH SINGHALAIS UN",NULL},
/* 0DE8 */ { "CHIFFRE LITH SINGHALAIS DEUX",NULL},
/* 0DE9 */ { "CHIFFRE LITH SINGHALAIS TROIS",NULL},
/* 0DEA */ { "CHIFFRE LITH SINGHALAIS QUATRE",NULL},
/* 0DEB */ { "CHIFFRE LITH SINGHALAIS CINQ",NULL},
/* 0DEC */ { "CHIFFRE LITH SINGHALAIS SIX",NULL},
/* 0DED */ { "CHIFFRE LITH SINGHALAIS SEPT",NULL},
/* 0DEE */ { "CHIFFRE LITH SINGHALAIS HUIT",NULL},
/* 0DEF */ { "CHIFFRE LITH SINGHALAIS NEUF",NULL},
/* 0DF0 */ { NULL,NULL},
/* 0DF1 */ { NULL,NULL},
/* 0DF2 */ { "DIACRITIQUE VOYELLE SINGHALAISE DIGA GÆTTA-PILLA","	= diacritique voyelle singhalaise rr vocalique"},
/* 0DF3 */ { "DIACRITIQUE VOYELLE SINGHALAISE DIGA GAYANOUKITTA","	= diacritique voyelle singhalaise ll vocalique"},
/* 0DF4 */ { "PONCTUATION SINGHALAISE KOUNDDALIYA","	x (ponctuation tamoule fin de texte - 11FFF)"},
/* 0DF5 */ { NULL,NULL},
/* 0DF6 */ { NULL,NULL},
/* 0DF7 */ { NULL,NULL},
/* 0DF8 */ { NULL,NULL},
/* 0DF9 */ { NULL,NULL},
/* 0DFA */ { NULL,NULL},
/* 0DFB */ { NULL,NULL},
/* 0DFC */ { NULL,NULL},
/* 0DFD */ { NULL,NULL},
/* 0DFE */ { NULL,NULL},
/* 0DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_0E[] = {
/* 0E00 */ { NULL,NULL},
/* 0E01 */ { "CARACTÈRE THAÏ KO KAÏ",NULL},
/* 0E02 */ { "CARACTÈRE THAÏ KHO KHAÏ",NULL},
/* 0E03 */ { "CARACTÈRE THAÏ KHO KHOUAT",NULL},
/* 0E04 */ { "CARACTÈRE THAÏ KHO KHWAÏ",NULL},
/* 0E05 */ { "CARACTÈRE THAÏ KHO KHON",NULL},
/* 0E06 */ { "CARACTÈRE THAÏ KHO RAKHANG",NULL},
/* 0E07 */ { "CARACTÈRE THAÏ NGO NGOU",NULL},
/* 0E08 */ { "CARACTÈRE THAÏ TCHO TCHAN",NULL},
/* 0E09 */ { "CARACTÈRE THAÏ TCHO TCHING",NULL},
/* 0E0A */ { "CARACTÈRE THAÏ TCHO TCHANG",NULL},
/* 0E0B */ { "CARACTÈRE THAÏ SO SO",NULL},
/* 0E0C */ { "CARACTÈRE THAÏ TCHO TCHEU",NULL},
/* 0E0D */ { "CARACTÈRE THAÏ YO YING",NULL},
/* 0E0E */ { "CARACTÈRE THAÏ DO TCHADA",NULL},
/* 0E0F */ { "CARACTÈRE THAÏ TO PATAK",NULL},
/* 0E10 */ { "CARACTÈRE THAÏ THO THAN",NULL},
/* 0E11 */ { "CARACTÈRE THAÏ THO NANGMONTHO",NULL},
/* 0E12 */ { "CARACTÈRE THAÏ THO PHOUTHAO",NULL},
/* 0E13 */ { "CARACTÈRE THAÏ NO NÉN",NULL},
/* 0E14 */ { "CARACTÈRE THAÏ DO DEK",NULL},
/* 0E15 */ { "CARACTÈRE THAÏ TO TAO",NULL},
/* 0E16 */ { "CARACTÈRE THAÏ THO THOUNG",NULL},
/* 0E17 */ { "CARACTÈRE THAÏ THO THAHAN",NULL},
/* 0E18 */ { "CARACTÈRE THAÏ THO THONG",NULL},
/* 0E19 */ { "CARACTÈRE THAÏ NO NOU",NULL},
/* 0E1A */ { "CARACTÈRE THAÏ BO BAÏMAÏ",NULL},
/* 0E1B */ { "CARACTÈRE THAÏ PO PLA",NULL},
/* 0E1C */ { "CARACTÈRE THAÏ PHO PHUNG",NULL},
/* 0E1D */ { "CARACTÈRE THAÏ FO FA",NULL},
/* 0E1E */ { "CARACTÈRE THAÏ PHO PHAN",NULL},
/* 0E1F */ { "CARACTÈRE THAÏ FO FAN",NULL},
/* 0E20 */ { "CARACTÈRE THAÏ PHO SAMPHAO",NULL},
/* 0E21 */ { "CARACTÈRE THAÏ MO MA",NULL},
/* 0E22 */ { "CARACTÈRE THAÏ YO YAK",NULL},
/* 0E23 */ { "CARACTÈRE THAÏ RO RUA",NULL},
/* 0E24 */ { "CARACTÈRE THAÏ RU","	* voyelle indépendante utilisée pour l'écriture en sanskrit"},
/* 0E25 */ { "CARACTÈRE THAÏ LO LING",NULL},
/* 0E26 */ { "CARACTÈRE THAÏ LU","	* voyelle indépendante utilisée pour l'écriture en sanskrit"},
/* 0E27 */ { "CARACTÈRE THAÏ WO WÈN",NULL},
/* 0E28 */ { "CARACTÈRE THAÏ SO SALA",NULL},
/* 0E29 */ { "CARACTÈRE THAÏ SO RUSI",NULL},
/* 0E2A */ { "CARACTÈRE THAÏ SO SUA",NULL},
/* 0E2B */ { "CARACTÈRE THAÏ HO HIP",NULL},
/* 0E2C */ { "CARACTÈRE THAÏ LO TCHOULA",NULL},
/* 0E2D */ { "CARACTÈRE THAÏ O ANG",NULL},
/* 0E2E */ { "CARACTÈRE THAÏ HO NOKHOUK","	= ho nok houk"},
/* 0E2F */ { "CARACTÈRE THAÏ PAÏYANNOÏ","	= païyan noï\n"
	"	* points de suspension, abréviation"},
/* 0E30 */ { "CARACTÈRE THAÏ SARA A",NULL},
/* 0E31 */ { "CARACTÈRE THAÏ MAÏ HAN-AKAT",NULL},
/* 0E32 */ { "CARACTÈRE THAÏ SARA Â","	x (caractère thaï lakkhangyao - 0E45)"},
/* 0E33 */ { "CARACTÈRE THAÏ SARA AM","	# 0E4D 0E32"},
/* 0E34 */ { "CARACTÈRE THAÏ SARA I",NULL},
/* 0E35 */ { "CARACTÈRE THAÏ SARA Î",NULL},
/* 0E36 */ { "CARACTÈRE THAÏ SARA U",NULL},
/* 0E37 */ { "CARACTÈRE THAÏ SARA Û","	= sara oûé"},
/* 0E38 */ { "CARACTÈRE THAÏ SARA OU",NULL},
/* 0E39 */ { "CARACTÈRE THAÏ SARA OÛ",NULL},
/* 0E3A */ { "CARACTÈRE THAÏ PHINTHOU","	* virâma pali"},
/* 0E3B */ { NULL,NULL},
/* 0E3C */ { NULL,NULL},
/* 0E3D */ { NULL,NULL},
/* 0E3E */ { NULL,NULL},
/* 0E3F */ { "SYMBOLE MONÉTAIRE THAÏ BAHT",NULL},
/* 0E40 */ { "CARACTÈRE THAÏ SARA É",NULL},
/* 0E41 */ { "CARACTÈRE THAÏ SARA Æ",NULL},
/* 0E42 */ { "CARACTÈRE THAÏ SARA O",NULL},
/* 0E43 */ { "CARACTÈRE THAÏ SARA AÏ MAÏMOUAN","	= sara aï maï mouan"},
/* 0E44 */ { "CARACTÈRE THAÏ SARA AÏ MAÏMALAÏ","	= sara aï maï malaï"},
/* 0E45 */ { "CARACTÈRE THAÏ LAKKHANGYAO","	= lakkhang yao\n"
	"	* indication de longueur de voyelle particulière utilisée avec 0E24 ou 0E26\n"
	"	x (caractère thaï sara â - 0E32)"},
/* 0E46 */ { "CARACTÈRE THAÏ MAÏYAMOK","	= maï yamok\n"
	"	* répétition"},
/* 0E47 */ { "CARACTÈRE THAÏ MAÏTAÏKHOU","	= maï taïkhou"},
/* 0E48 */ { "CARACTÈRE THAÏ MAÏ EK",NULL},
/* 0E49 */ { "CARACTÈRE THAÏ MAÏ THO",NULL},
/* 0E4A */ { "CARACTÈRE THAÏ MAÏ TRI",NULL},
/* 0E4B */ { "CARACTÈRE THAÏ MAÏ TCHATTAWA",NULL},
/* 0E4C */ { "CARACTÈRE THAÏ THANTHAKHAT","	* signe d'annulation\n"
	"	x (diacritique khmer toandakhiat - 17CD)"},
/* 0E4D */ { "CARACTÈRE THAÏ NIKHAHIT","	= nikkhahit\n"
	"	* nasale finale"},
/* 0E4E */ { "CARACTÈRE THAÏ YAMAKKAN","	x (yamakkan laotien - 0ECE)"},
/* 0E4F */ { "CARACTÈRE THAÏ FONGMAN","	* utilisé comme puce\n"
	"	x (signe khmer phnèk moen - 17D9)"},
/* 0E50 */ { "CHIFFRE THAÏ ZÉRO",NULL},
/* 0E51 */ { "CHIFFRE THAÏ UN",NULL},
/* 0E52 */ { "CHIFFRE THAÏ DEUX",NULL},
/* 0E53 */ { "CHIFFRE THAÏ TROIS",NULL},
/* 0E54 */ { "CHIFFRE THAÏ QUATRE",NULL},
/* 0E55 */ { "CHIFFRE THAÏ CINQ",NULL},
/* 0E56 */ { "CHIFFRE THAÏ SIX",NULL},
/* 0E57 */ { "CHIFFRE THAÏ SEPT",NULL},
/* 0E58 */ { "CHIFFRE THAÏ HUIT",NULL},
/* 0E59 */ { "CHIFFRE THAÏ NEUF",NULL},
/* 0E5A */ { "CARACTÈRE THAÏ ANGKHANKHOU","	* s'utilise pour indiquer la fin de longues sections\n"
	"	* s'utilise avec 0E30 pour indiquer la fin d'un vers"},
/* 0E5B */ { "CARACTÈRE THAÏ KHOMOUT","	* s'utilise pour indiquer la fin d'un chapitre ou d'un document\n"
	"	x (signe khmer koomoût - 17DA)"},
/* 0E5C */ { NULL,NULL},
/* 0E5D */ { NULL,NULL},
/* 0E5E */ { NULL,NULL},
/* 0E5F */ { NULL,NULL},
/* 0E60 */ { NULL,NULL},
/* 0E61 */ { NULL,NULL},
/* 0E62 */ { NULL,NULL},
/* 0E63 */ { NULL,NULL},
/* 0E64 */ { NULL,NULL},
/* 0E65 */ { NULL,NULL},
/* 0E66 */ { NULL,NULL},
/* 0E67 */ { NULL,NULL},
/* 0E68 */ { NULL,NULL},
/* 0E69 */ { NULL,NULL},
/* 0E6A */ { NULL,NULL},
/* 0E6B */ { NULL,NULL},
/* 0E6C */ { NULL,NULL},
/* 0E6D */ { NULL,NULL},
/* 0E6E */ { NULL,NULL},
/* 0E6F */ { NULL,NULL},
/* 0E70 */ { NULL,NULL},
/* 0E71 */ { NULL,NULL},
/* 0E72 */ { NULL,NULL},
/* 0E73 */ { NULL,NULL},
/* 0E74 */ { NULL,NULL},
/* 0E75 */ { NULL,NULL},
/* 0E76 */ { NULL,NULL},
/* 0E77 */ { NULL,NULL},
/* 0E78 */ { NULL,NULL},
/* 0E79 */ { NULL,NULL},
/* 0E7A */ { NULL,NULL},
/* 0E7B */ { NULL,NULL},
/* 0E7C */ { NULL,NULL},
/* 0E7D */ { NULL,NULL},
/* 0E7E */ { NULL,NULL},
/* 0E7F */ { NULL,NULL},
/* 0E80 */ { NULL,NULL},
/* 0E81 */ { "LETTRE LAOTIENNE KO","	= ko kay"},
/* 0E82 */ { "LETTRE LAOTIENNE KHO SOUNG","	= kho khay"},
/* 0E83 */ { NULL,NULL},
/* 0E84 */ { "LETTRE LAOTIENNE KHO TAM","	= kho khouay"},
/* 0E85 */ { NULL,NULL},
/* 0E86 */ { "LETTRE LAOTIENNE GHA PALI",NULL},
/* 0E87 */ { "LETTRE LAOTIENNE NGO","	= ngo ngou, ngo ngoua"},
/* 0E88 */ { "LETTRE LAOTIENNE TCHO","	= co cok, co tchoua"},
/* 0E89 */ { "LETTRE LAOTIENNE TCHHA PALI",NULL},
/* 0E8A */ { "LETTRE LAOTIENNE SO TAM","	= so sang"},
/* 0E8B */ { NULL,NULL},
/* 0E8C */ { "LETTRE LAOTIENNE DJHA PALI",NULL},
/* 0E8D */ { "LETTRE LAOTIENNE ÑO","	= nyo nyoung"},
/* 0E8E */ { "LETTRE LAOTIENNE ÑA PALI",NULL},
/* 0E8F */ { "LETTRE LAOTIENNE TTA PALI",NULL},
/* 0E90 */ { "LETTRE LAOTIENNE TTHA PALI",NULL},
/* 0E91 */ { "LETTRE LAOTIENNE DDA PALI",NULL},
/* 0E92 */ { "LETTRE LAOTIENNE DDHA PALI",NULL},
/* 0E93 */ { "LETTRE LAOTIENNE NNA PALI",NULL},
/* 0E94 */ { "LETTRE LAOTIENNE DO","	= do dek"},
/* 0E95 */ { "LETTRE LAOTIENNE TO","	= to ta"},
/* 0E96 */ { "LETTRE LAOTIENNE THO SOUNG","	= tho thong"},
/* 0E97 */ { "LETTRE LAOTIENNE THO TAM","	= tho thoung"},
/* 0E98 */ { "LETTRE LAOTIENNE DHA PALI",NULL},
/* 0E99 */ { "LETTRE LAOTIENNE NO","	= no nok"},
/* 0E9A */ { "LETTRE LAOTIENNE BO","	= bo be, bo bet"},
/* 0E9B */ { "LETTRE LAOTIENNE PO","	= po pa"},
/* 0E9C */ { "LETTRE LAOTIENNE PHO SOUNG","	= pho pheng"},
/* 0E9D */ { "LETTRE LAOTIENNE FO SOUNG","	= fo fa\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 0E9E */ { "LETTRE LAOTIENNE PHO TAM","	= pho phou"},
/* 0E9F */ { "LETTRE LAOTIENNE FO TAM","	= fo fay\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 0EA0 */ { "LETTRE LAOTIENNE BHA PALI",NULL},
/* 0EA1 */ { "LETTRE LAOTIENNE MO","	= mo mew, mo ma"},
/* 0EA2 */ { "LETTRE LAOTIENNE YO","	= yo ya"},
/* 0EA3 */ { "LETTRE LAOTIENNE LO LÔT","	= ro rot\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 0EA4 */ { NULL,NULL},
/* 0EA5 */ { "LETTRE LAOTIENNE LO LING","	= lo\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 0EA6 */ { NULL,NULL},
/* 0EA7 */ { "LETTRE LAOTIENNE WO","	= wo wi"},
/* 0EA8 */ { "LETTRE LAOTIENNE ÇA SANSKRIT",NULL},
/* 0EA9 */ { "LETTRE LAOTIENNE CHA SANSKRIT",NULL},
/* 0EAA */ { "LETTRE LAOTIENNE SO SOUNG","	= so sya"},
/* 0EAB */ { "LETTRE LAOTIENNE HO SOUNG","	= ho hay, ho han"},
/* 0EAC */ { "LETTRE LAOTIENNE LLA PALI",NULL},
/* 0EAD */ { "LETTRE LAOTIENNE O","	= o o"},
/* 0EAE */ { "LETTRE LAOTIENNE HO TAM","	= ho hya, ho hyan"},
/* 0EAF */ { "POINTS DE SUSPENSION LAOTIENS",NULL},
/* 0EB0 */ { "DIACRITIQUE VOYELLE LAOTIENNE A",NULL},
/* 0EB1 */ { "DIACRITIQUE VOYELLE LAOTIENNE MAÏ KAN","	* écourte la voyelle"},
/* 0EB2 */ { "DIACRITIQUE VOYELLE LAOTIENNE Â",NULL},
/* 0EB3 */ { "DIACRITIQUE VOYELLE LAOTIENNE AM","	# 0ECD 0EB2"},
/* 0EB4 */ { "DIACRITIQUE VOYELLE LAOTIENNE I",NULL},
/* 0EB5 */ { "DIACRITIQUE VOYELLE LAOTIENNE Î",NULL},
/* 0EB6 */ { "DIACRITIQUE VOYELLE LAOTIENNE U",NULL},
/* 0EB7 */ { "DIACRITIQUE VOYELLE LAOTIENNE Û",NULL},
/* 0EB8 */ { "DIACRITIQUE VOYELLE LAOTIENNE OU",NULL},
/* 0EB9 */ { "DIACRITIQUE VOYELLE LAOTIENNE OÛ",NULL},
/* 0EBA */ { "DIACRITIQUE LAOTIEN VIRÂMA PALI",NULL},
/* 0EBB */ { "DIACRITIQUE VOYELLE LAOTIENNE MAÏ KON","	= maï kong"},
/* 0EBC */ { "DIACRITIQUE SEMI-VOYELLE LAOTIENNE LO",NULL},
/* 0EBD */ { "DIACRITIQUE SEMI-VOYELLE LAOTIENNE ÑO","	= nyo fyang"},
/* 0EBE */ { NULL,NULL},
/* 0EBF */ { NULL,NULL},
/* 0EC0 */ { "DIACRITIQUE VOYELLE LAOTIENNE É",NULL},
/* 0EC1 */ { "DIACRITIQUE VOYELLE LAOTIENNE EI",NULL},
/* 0EC2 */ { "DIACRITIQUE VOYELLE LAOTIENNE O",NULL},
/* 0EC3 */ { "DIACRITIQUE VOYELLE LAOTIENNE AY","	= maï mouan"},
/* 0EC4 */ { "DIACRITIQUE VOYELLE LAOTIENNE AÏ","	= maï may"},
/* 0EC5 */ { NULL,NULL},
/* 0EC6 */ { "KO LA LAOTIEN","	* répétition"},
/* 0EC7 */ { NULL,NULL},
/* 0EC8 */ { "DIACRITIQUE TON LAOTIEN MAÏ ÉK",NULL},
/* 0EC9 */ { "DIACRITIQUE TON LAOTIEN MAÏ THO",NULL},
/* 0ECA */ { "DIACRITIQUE TON LAOTIEN MAÏ TI",NULL},
/* 0ECB */ { "DIACRITIQUE TON LAOTIEN MAÏ TCHATAWA",NULL},
/* 0ECC */ { "DIACRITIQUE LAOTIEN D'ANNULATION",NULL},
/* 0ECD */ { "DIACRITIQUE LAOTIEN NIGGAHITA","	* nasale finale ou longue voyelle o (ô)"},
/* 0ECE */ { "YAMAKKAN LAOTIEN","	* note une consonne qui fait simultanément partie de deux groupes de consonnes dans un texte en pali\n"
	"	x (caractère thaï yamakkan - 0E4E)"},
/* 0ECF */ { NULL,NULL},
/* 0ED0 */ { "CHIFFRE LAOTIEN ZÉRO",NULL},
/* 0ED1 */ { "CHIFFRE LAOTIEN UN",NULL},
/* 0ED2 */ { "CHIFFRE LAOTIEN DEUX",NULL},
/* 0ED3 */ { "CHIFFRE LAOTIEN TROIS",NULL},
/* 0ED4 */ { "CHIFFRE LAOTIEN QUATRE",NULL},
/* 0ED5 */ { "CHIFFRE LAOTIEN CINQ",NULL},
/* 0ED6 */ { "CHIFFRE LAOTIEN SIX",NULL},
/* 0ED7 */ { "CHIFFRE LAOTIEN SEPT",NULL},
/* 0ED8 */ { "CHIFFRE LAOTIEN HUIT",NULL},
/* 0ED9 */ { "CHIFFRE LAOTIEN NEUF",NULL},
/* 0EDA */ { NULL,NULL},
/* 0EDB */ { NULL,NULL},
/* 0EDC */ { "HO NO LAOTIEN","	# 0EAB 0E99"},
/* 0EDD */ { "HO MO LAOTIEN","	# 0EAB 0EA1"},
/* 0EDE */ { "LETTRE LAOTIENNE KHMOU GO",NULL},
/* 0EDF */ { "LETTRE LAOTIENNE KHMOU ÑO",NULL},
/* 0EE0 */ { NULL,NULL},
/* 0EE1 */ { NULL,NULL},
/* 0EE2 */ { NULL,NULL},
/* 0EE3 */ { NULL,NULL},
/* 0EE4 */ { NULL,NULL},
/* 0EE5 */ { NULL,NULL},
/* 0EE6 */ { NULL,NULL},
/* 0EE7 */ { NULL,NULL},
/* 0EE8 */ { NULL,NULL},
/* 0EE9 */ { NULL,NULL},
/* 0EEA */ { NULL,NULL},
/* 0EEB */ { NULL,NULL},
/* 0EEC */ { NULL,NULL},
/* 0EED */ { NULL,NULL},
/* 0EEE */ { NULL,NULL},
/* 0EEF */ { NULL,NULL},
/* 0EF0 */ { NULL,NULL},
/* 0EF1 */ { NULL,NULL},
/* 0EF2 */ { NULL,NULL},
/* 0EF3 */ { NULL,NULL},
/* 0EF4 */ { NULL,NULL},
/* 0EF5 */ { NULL,NULL},
/* 0EF6 */ { NULL,NULL},
/* 0EF7 */ { NULL,NULL},
/* 0EF8 */ { NULL,NULL},
/* 0EF9 */ { NULL,NULL},
/* 0EFA */ { NULL,NULL},
/* 0EFB */ { NULL,NULL},
/* 0EFC */ { NULL,NULL},
/* 0EFD */ { NULL,NULL},
/* 0EFE */ { NULL,NULL},
/* 0EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_0F[] = {
/* 0F00 */ { "SYLLABE TIBÉTAINE OM",NULL},
/* 0F01 */ { "SIGNE TIBÉTAIN GTER YIG MGO A TRONQUÉ","	= ter yik go a t'oung"},
/* 0F02 */ { "SIGNE TIBÉTAIN GTER YIG MGO 'OUM RNAM BTCHAD MA","	= ter yik go woum nam tché ma"},
/* 0F03 */ { "SIGNE TIBÉTAIN GTER YIG MGO 'OUM GTER TÇEG MA","	= ter yik go woum ter ts'ék ma"},
/* 0F04 */ { "SIGNE TIBÉTAIN YIG MGO MDOUN MA OUVRANT","	= yik go doun ma\n"
	"	* honorifique ; indique le début du texte ou d'un nouveau feuillet\n"
	"	x (birga mongol - 1800)"},
/* 0F05 */ { "SIGNE TIBÉTAIN YIG MGO SGAB MA FERMANT","	= yik go kab ma\n"
	"	* suit et se lie au yik-go initial (ouvrant)"},
/* 0F06 */ { "SIGNE TIBÉTAIN D'INSERTION YIG MGO PHOUR ÇAD MA","	= yik go p'our ché ma"},
/* 0F07 */ { "SIGNE TIBÉTAIN YIG MGO TÇEG ÇAD MA","	= yik go ts'ék ché ma"},
/* 0F08 */ { "SIGNE TIBÉTAIN SBROUL ÇAD","	= troul ché\n"
	"	* signale le début d'un sujet"},
/* 0F09 */ { "SIGNE TIBÉTAIN BSKOUR YIG MGO","	= kour yik go\n"
	"	* énumérateur de liste, s'utilise au Bhoutan"},
/* 0F0A */ { "SIGNE TIBÉTAIN ZHOU YIG GI MGO RGYAN","	= z'ou yik gui go guien\n"
	"	* pétition honorifique ; s'utilise dans la correspondance au Bhoutan quand un inférieur s'adresse à un supérieur\n"
	"	* le nom formel de ce caractère en anglais est erroné, car il se réfère à 0FD0, qui s'utilise dans la situation opposée"},
/* 0F0B */ { "SIGNE TIBÉTAIN TÇEG","	= ts'ék\n"
	"	* délimiteur de morphèmes, séparateur de syllabes (sens approximatif)\n"
	"	* le ts'ék habituel, qui indique une position sécable"},
/* 0F0C */ { "SIGNE TIBÉTAIN TÇEG INSÉCABLE","	* variante insécable du signe 0F0B, qui s'utilise exclusivement entre 0F44 et 0F0D\n"
	"	# <insécable> 0F0B"},
/* 0F0D */ { "SIGNE TIBÉTAIN ÇAD","	= ché\n"
	"	* marque la fin d'une section dans un texte\n"
	"	x (danda dévanâgarî - 0964)"},
/* 0F0E */ { "SIGNE TIBÉTAIN ÑIS ÇAD","	= double ché\n"
	"	* marque la fin d'un sujet complet\n"
	"	x (double danda dévanâgarî - 0965)"},
/* 0F0F */ { "SIGNE TIBÉTAIN TÇEG ÇAD","	= ts'ék ché"},
/* 0F10 */ { "SIGNE TIBÉTAIN ÑIS TÇEG ÇAD","	= ñi ts'ék ché"},
/* 0F11 */ { "SIGNE TIBÉTAIN RIN TCH'EN SPOUNGS ÇAD","	= rine tch'ène poung ché\n"
	"	* ché qui suit un ts'ék tar qui commence une nouvelle ligne"},
/* 0F12 */ { "SIGNE TIBÉTAIN RGYA GRAM ÇAD","	= gya tram ché"},
/* 0F13 */ { "SIGNE TIBÉTAIN D'INSERTION 'DZOUD RTAGS MÉ LONG TCHAN","	= dzou ta mé long tchène"},
/* 0F14 */ { "SIGNE TIBÉTAIN GTER TÇEG","	= ter ts'ék\n"
	"	* délimiteur proche de la virgule\n"
	"	x (signe khmer tchamnotch pii koûh - 17D6)"},
/* 0F15 */ { "LOGOTYPE TIBETAIN TCH'AD RTAGS","	= tch'é ta"},
/* 0F16 */ { "LOGOTYPE TIBÉTAIN LHAG RTAGS","	= hlak ta"},
/* 0F17 */ { "SIGNE TIBÉTAIN ASTROLOGIQUE SGRA GTCHAN TCH'AR RTAGS","	= tra tchène tch'ar ta"},
/* 0F18 */ { "DIACRITIQUE TIBÉTAIN ASTROLOGIQUE 'KHYOUD PA","	= kyou pa\n"
	"	* se combine avec les chiffres"},
/* 0F19 */ { "DIACRITIQUE TIBÉTAIN ASTROLOGIQUE SDONG TÇOUGS","	= dong tsou\n"
	"	* se combine avec les chiffres"},
/* 0F1A */ { "SIGNE TIBÉTAIN RDEL DKAR GTCHIG","	= dé ka tchig\n"
	"	= signe tibétain une pierre blanche"},
/* 0F1B */ { "SIGNE TIBÉTAIN RDEL DKAR GÑIS","	= dé ka ñi\n"
	"	= signe tibétain deux pierres blanches"},
/* 0F1C */ { "SIGNE TIBÉTAIN RDEL DKAR GSOUM","	= dé ka soum\n"
	"	= signe tibétain trois pierres blanches\n"
	"	x (symbole alchimique de l'huile - 1F746)"},
/* 0F1D */ { "SIGNE TIBÉTAIN RDEL NAG GTCHIG","	= dé na tchig\n"
	"	= signe tibétain une pierre noire"},
/* 0F1E */ { "SIGNE TIBÉTAIN RDEL NAG GÑIS","	= dé na ñi\n"
	"	= signe tibétain deux pierres noires"},
/* 0F1F */ { "SIGNE TIBÉTAIN RDEL DKAR RDEL NAG","	= dé ka dé na\n"
	"	= signe tibétain une pierre blanche et une pierre noire\n"
	"	* indique normalement une fortune neutre\n"
	"	* peut aussi signifier « bonne fortune d'abord, mauvaise fortune ensuite »\n"
	"	x (signe tibétain rdel nag rdel dkar - 0FCE)"},
/* 0F20 */ { "CHIFFRE TIBÉTAIN ZÉRO",NULL},
/* 0F21 */ { "CHIFFRE TIBÉTAIN UN",NULL},
/* 0F22 */ { "CHIFFRE TIBÉTAIN DEUX",NULL},
/* 0F23 */ { "CHIFFRE TIBÉTAIN TROIS",NULL},
/* 0F24 */ { "CHIFFRE TIBÉTAIN QUATRE",NULL},
/* 0F25 */ { "CHIFFRE TIBÉTAIN CINQ",NULL},
/* 0F26 */ { "CHIFFRE TIBÉTAIN SIX",NULL},
/* 0F27 */ { "CHIFFRE TIBÉTAIN SEPT",NULL},
/* 0F28 */ { "CHIFFRE TIBÉTAIN HUIT",NULL},
/* 0F29 */ { "CHIFFRE TIBÉTAIN NEUF",NULL},
/* 0F2A */ { "CHIFFRE TIBÉTAIN UN MOINS UN DEMI",NULL},
/* 0F2B */ { "CHIFFRE TIBÉTAIN DEUX MOINS UN DEMI",NULL},
/* 0F2C */ { "CHIFFRE TIBÉTAIN TROIS MOINS UN DEMI",NULL},
/* 0F2D */ { "CHIFFRE TIBÉTAIN QUATRE MOINS UN DEMI",NULL},
/* 0F2E */ { "CHIFFRE TIBÉTAIN CINQ MOINS UN DEMI",NULL},
/* 0F2F */ { "CHIFFRE TIBÉTAIN SIX MOINS UN DEMI",NULL},
/* 0F30 */ { "CHIFFRE TIBÉTAIN SEPT MOINS UN DEMI",NULL},
/* 0F31 */ { "CHIFFRE TIBÉTAIN HUIT MOINS UN DEMI",NULL},
/* 0F32 */ { "CHIFFRE TIBÉTAIN NEUF MOINS UN DEMI",NULL},
/* 0F33 */ { "CHIFFRE TIBÉTAIN ZÉRO MOINS UN DEMI",NULL},
/* 0F34 */ { "SIGNE TIBÉTAIN BSDOUS RTAGS","	= dou ta\n"
	"	* répétition"},
/* 0F35 */ { "DIACRITIQUE TIBÉTAIN NGAS BZOUNG ÑI ZLA","	= ngé zoung ñi da\n"
	"	* honorifique, mise en exergue ; correspond au soulignement"},
/* 0F36 */ { "SIGNE TIBÉTAIN D'INSERTION 'DZOUD RTAGS BZHI MIG TCHAN","	= dzou ta chi mig tchène\n"
	"	* indique le point d'insertion d'un texte ou d'une glose"},
/* 0F37 */ { "DIACRITIQUE TIBÉTAIN NGAS BZOUNG SGOR RTAGS","	= ngé zoung gor ta\n"
	"	* mise en exergue ; correspond au soulignement"},
/* 0F38 */ { "SIGNE TIBÉTAIN TCH'É MGO","	= tch'é go"},
/* 0F39 */ { "DIACRITIQUE TIBÉTAIN TSA 'PHROU","	= tsa trou\n"
	"	* signe de lénition ou d'adoucissement"},
/* 0F3A */ { "SIGNE TIBÉTAIN GOUG RTAGS GYON","	= goug ta yeun\n"
	"	* parenthèse ouvrante"},
/* 0F3B */ { "SIGNE TIBÉTAIN GOUG RTAGS GYAS","	= goug ta yé\n"
	"	* parenthèse fermante"},
/* 0F3C */ { "SIGNE TIBÉTAIN ANG KHANG GYON","	= ang kang yeun\n"
	"	* parenthèse à toit ouvrante"},
/* 0F3D */ { "SIGNE TIBÉTAIN ANG KHANG GYAS","	= ang kang yé\n"
	"	* parenthèse à toit fermante"},
/* 0F3E */ { "DIACRITIQUE TIBÉTAIN YAR TÇES","	= yar ts'é\n"
	"	* se combine avec les chiffres"},
/* 0F3F */ { "DIACRITIQUE TIBÉTAIN MAR TÇES","	= mar ts'é\n"
	"	* se combine avec les chiffres"},
/* 0F40 */ { "LETTRE TIBÉTAINE KA",NULL},
/* 0F41 */ { "LETTRE TIBÉTAINE KHA","	= lettre tibétaine k'a"},
/* 0F42 */ { "LETTRE TIBÉTAINE GA",NULL},
/* 0F43 */ { "LETTRE TIBÉTAINE GHA","	= lettre tibétaine gaha\n"
	"	: 0F42 0FB7"},
/* 0F44 */ { "LETTRE TIBÉTAINE NGA",NULL},
/* 0F45 */ { "LETTRE TIBÉTAINE TCHA",NULL},
/* 0F46 */ { "LETTRE TIBÉTAINE TCHHA","	= lettre tibétaine tch'a"},
/* 0F47 */ { "LETTRE TIBÉTAINE DJA",NULL},
/* 0F48 */ { NULL,NULL},
/* 0F49 */ { "LETTRE TIBÉTAINE ÑA",NULL},
/* 0F4A */ { "LETTRE TIBÉTAINE TTA",NULL},
/* 0F4B */ { "LETTRE TIBÉTAINE TTHA","	= lettre tibétaine tt'a"},
/* 0F4C */ { "LETTRE TIBÉTAINE DDA",NULL},
/* 0F4D */ { "LETTRE TIBÉTAINE DDHA","	= lettre tibétaine draha\n"
	"	: 0F4C 0FB7"},
/* 0F4E */ { "LETTRE TIBÉTAINE NNA",NULL},
/* 0F4F */ { "LETTRE TIBÉTAINE TA",NULL},
/* 0F50 */ { "LETTRE TIBÉTAINE THA","	= lettre tibétaine t'a"},
/* 0F51 */ { "LETTRE TIBÉTAINE DA",NULL},
/* 0F52 */ { "LETTRE TIBÉTAINE DHA","	= lettre tibétaine daha\n"
	"	: 0F51 0FB7"},
/* 0F53 */ { "LETTRE TIBÉTAINE NA",NULL},
/* 0F54 */ { "LETTRE TIBÉTAINE PA",NULL},
/* 0F55 */ { "LETTRE TIBÉTAINE PHA","	= lettre tibétaine p'a"},
/* 0F56 */ { "LETTRE TIBÉTAINE BA",NULL},
/* 0F57 */ { "LETTRE TIBÉTAINE BHA","	= lettre tibétaine baha\n"
	"	: 0F56 0FB7"},
/* 0F58 */ { "LETTRE TIBÉTAINE MA",NULL},
/* 0F59 */ { "LETTRE TIBÉTAINE TSA",NULL},
/* 0F5A */ { "LETTRE TIBÉTAINE TÇA","	= lettre tibétaine ts'a"},
/* 0F5B */ { "LETTRE TIBÉTAINE DZA",NULL},
/* 0F5C */ { "LETTRE TIBÉTAINE DZHA","	= lettre tibétaine dzaha\n"
	"	: 0F5B 0FB7"},
/* 0F5D */ { "LETTRE TIBÉTAINE WA","	= lettre tibétaine oua"},
/* 0F5E */ { "LETTRE TIBÉTAINE ZHA","	= lettre tibétaine z'a"},
/* 0F5F */ { "LETTRE TIBÉTAINE ZA","	= lettre tibétaine sa"},
/* 0F60 */ { "LETTRE TIBÉTAINE 'A",NULL},
/* 0F61 */ { "LETTRE TIBÉTAINE YA",NULL},
/* 0F62 */ { "LETTRE TIBÉTAINE RA","	* quand elle est suivie d'une lettre subjointe = ra go, ra suscrit"},
/* 0F63 */ { "LETTRE TIBÉTAINE LA",NULL},
/* 0F64 */ { "LETTRE TIBÉTAINE ÇA",NULL},
/* 0F65 */ { "LETTRE TIBÉTAINE CHA","	= ça réfléchi"},
/* 0F66 */ { "LETTRE TIBÉTAINE SA",NULL},
/* 0F67 */ { "LETTRE TIBÉTAINE HA",NULL},
/* 0F68 */ { "LETTRE TIBÉTAINE A","	* base pour des voyelles dépendantes"},
/* 0F69 */ { "LETTRE TIBÉTAINE KCHA","	= lettre tibétaine k'ya\n"
	"	: 0F40 0FB5"},
/* 0F6A */ { "LETTRE TIBÉTAINE RA À FORME FIXE","	* exempte des variations de forme de la lettre ra ordinaire\n"
	"	* ne s'utilise que dans les translittérations et transcriptions\n"
	"	x (lettre tibétaine ra - 0F62)"},
/* 0F6B */ { "LETTRE TIBÉTAINE KKA",NULL},
/* 0F6C */ { "LETTRE TIBÉTAINE RRA",NULL},
/* 0F6D */ { NULL,NULL},
/* 0F6E */ { NULL,NULL},
/* 0F6F */ { NULL,NULL},
/* 0F70 */ { NULL,NULL},
/* 0F71 */ { "DIACRITIQUE VOYELLE TIBÉTAINE Â","	= a-tchoung\n"
	"	* commun, marque d'allongement de voyelle"},
/* 0F72 */ { "DIACRITIQUE VOYELLE TIBÉTAINE I",NULL},
/* 0F73 */ { "DIACRITIQUE VOYELLE TIBÉTAINE Î","	* l'utilisation de ce caractère est déconseillée\n"
	"	: 0F71 0F72"},
/* 0F74 */ { "DIACRITIQUE VOYELLE TIBÉTAINE OU",NULL},
/* 0F75 */ { "DIACRITIQUE VOYELLE TIBÉTAINE OÛ","	* l'utilisation de ce caractère est déconseillée\n"
	"	: 0F71 0F74"},
/* 0F76 */ { "DIACRITIQUE VOYELLE TIBÉTAINE R VOCALIQUE","	: 0FB2 0F80"},
/* 0F77 */ { "DIACRITIQUE VOYELLE TIBÉTAINE RR VOCALIQUE","	* ce caractère est obsolète et son utilisation est fortement déconseillée\n"
	"	# 0FB2 0F81"},
/* 0F78 */ { "DIACRITIQUE VOYELLE TIBÉTAINE L VOCALIQUE","	: 0FB3 0F80"},
/* 0F79 */ { "DIACRITIQUE VOYELLE TIBÉTAINE LL VOCALIQUE","	* ce caractère est obsolète et son utilisation est fortement déconseillée\n"
	"	# 0FB3 0F81"},
/* 0F7A */ { "DIACRITIQUE VOYELLE TIBÉTAINE É",NULL},
/* 0F7B */ { "DIACRITIQUE VOYELLE TIBÉTAINE ÉÉ",NULL},
/* 0F7C */ { "DIACRITIQUE VOYELLE TIBÉTAINE O",NULL},
/* 0F7D */ { "DIACRITIQUE VOYELLE TIBÉTAINE Ô",NULL},
/* 0F7E */ { "DIACRITIQUE TIBÉTAIN RDJES SOU NGA RO","	= djé sou nga ro\n"
	"	= anousvâra"},
/* 0F7F */ { "DIACRITIQUE TIBÉTAIN RNAM BTCHAD","	= nam tché\n"
	"	= visarga"},
/* 0F80 */ { "DIACRITIQUE VOYELLE TIBÉTAINE I RÉFLÉCHI",NULL},
/* 0F81 */ { "DIACRITIQUE VOYELLE TIBÉTAINE Î RÉFLÉCHI","	* l'utilisation de ce caractère est déconseillée\n"
	"	: 0F71 0F80"},
/* 0F82 */ { "DIACRITIQUE TIBÉTAIN ÑI ZLA NÂ DA","	= ñi da na da"},
/* 0F83 */ { "DIACRITIQUE TIBÉTAIN SNA LDAN","	= nan dé\n"
	"	x (diacritique dévanâgarî tchandrabindou - 0901)"},
/* 0F84 */ { "DIACRITIQUE TIBÉTAIN HALANTA","	= rok mé\n"
	"	x (diacritique dévanâgarî virâma - 094D)"},
/* 0F85 */ { "SIGNE TIBÉTAIN PALOUTA","	* translittération de l'avagraha sanskrit\n"
	"	x (signe dévanâgarî avagraha - 093D)"},
/* 0F86 */ { "DIACRITIQUE TIBÉTAIN LTCHI RTAGS","	= dji ta"},
/* 0F87 */ { "DIACRITIQUE TIBÉTAIN YANG RTAGS","	= yang ta"},
/* 0F88 */ { "SIGNE TIBÉTAIN LTCHÉ TSA TCHAN","	= tché tsa tchène\n"
	"	x (signe védique djihvamouliya - 1CF5)\n"
	"	x (lettre mongole damarou ali gali - 1882)"},
/* 0F89 */ { "SIGNE TIBÉTAIN MTCH'OU TCHAN","	= tch'ou tchène\n"
	"	x (signe védique oupadhmaniya - 1CF6)\n"
	"	x (lettre mongole oubadama culbuté ali gali - 1884)"},
/* 0F8A */ { "SIGNE TIBÉTAIN GROU TCHAN RGYINGS","	= trou tchène guing\n"
	"	* toujours suivi de 0F82"},
/* 0F8B */ { "SIGNE TIBÉTAIN GROU MÉD RGYINGS","	= trou mé guing"},
/* 0F8C */ { "SIGNE TIBÉTAIN MTCH'OU TCHAN CULBUTÉ","	= tch'ou tchène culbuté\n"
	"	x (lettre mongole oubadama ali gali - 1883)"},
/* 0F8D */ { "SIGNE SUBJOINT TIBÉTAIN LTCHÉ TSA TCHAN","	= tché tsa tchène subjoint"},
/* 0F8E */ { "SIGNE SUBJOINT TIBÉTAIN MTCH'OU TCHAN","	= tch'ou tchène subjoint"},
/* 0F8F */ { "SIGNE SUBJOINT TIBÉTAIN MTCH'OU TCHAN CULBUTÉ","	= tch'ou tchène culbuté subjoint"},
/* 0F90 */ { "LETTRE SUBJOINTE TIBÉTAINE KA",NULL},
/* 0F91 */ { "LETTRE SUBJOINTE TIBÉTAINE KHA","	= k'a subjoint"},
/* 0F92 */ { "LETTRE SUBJOINTE TIBÉTAINE GA",NULL},
/* 0F93 */ { "LETTRE SUBJOINTE TIBÉTAINE GHA","	= gaha subjoint\n"
	"	: 0F92 0FB7"},
/* 0F94 */ { "LETTRE SUBJOINTE TIBÉTAINE NGA",NULL},
/* 0F95 */ { "LETTRE SUBJOINTE TIBÉTAINE TCHA",NULL},
/* 0F96 */ { "LETTRE SUBJOINTE TIBÉTAINE TCHHA","	= tch'a subjoint"},
/* 0F97 */ { "LETTRE SUBJOINTE TIBÉTAINE DJA",NULL},
/* 0F98 */ { NULL,NULL},
/* 0F99 */ { "LETTRE SUBJOINTE TIBÉTAINE ÑA",NULL},
/* 0F9A */ { "LETTRE SUBJOINTE TIBÉTAINE TTA",NULL},
/* 0F9B */ { "LETTRE SUBJOINTE TIBÉTAINE TTHA","	= tt'a subjoint"},
/* 0F9C */ { "LETTRE SUBJOINTE TIBÉTAINE DDA",NULL},
/* 0F9D */ { "LETTRE SUBJOINTE TIBÉTAINE DDHA","	= draha subjoint\n"
	"	: 0F9C 0FB7"},
/* 0F9E */ { "LETTRE SUBJOINTE TIBÉTAINE NNA",NULL},
/* 0F9F */ { "LETTRE SUBJOINTE TIBÉTAINE TA",NULL},
/* 0FA0 */ { "LETTRE SUBJOINTE TIBÉTAINE THA","	= t'a subjoint"},
/* 0FA1 */ { "LETTRE SUBJOINTE TIBÉTAINE DA",NULL},
/* 0FA2 */ { "LETTRE SUBJOINTE TIBÉTAINE DHA","	= daha subjoint\n"
	"	: 0FA1 0FB7"},
/* 0FA3 */ { "LETTRE SUBJOINTE TIBÉTAINE NA",NULL},
/* 0FA4 */ { "LETTRE SUBJOINTE TIBÉTAINE PA",NULL},
/* 0FA5 */ { "LETTRE SUBJOINTE TIBÉTAINE PHA","	= p'a subjoint"},
/* 0FA6 */ { "LETTRE SUBJOINTE TIBÉTAINE BA",NULL},
/* 0FA7 */ { "LETTRE SUBJOINTE TIBÉTAINE BHA","	= baha subjoint\n"
	"	: 0FA6 0FB7"},
/* 0FA8 */ { "LETTRE SUBJOINTE TIBÉTAINE MA",NULL},
/* 0FA9 */ { "LETTRE SUBJOINTE TIBÉTAINE TSA",NULL},
/* 0FAA */ { "LETTRE SUBJOINTE TIBÉTAINE TÇA","	= ts'a subjoint"},
/* 0FAB */ { "LETTRE SUBJOINTE TIBÉTAINE DZA",NULL},
/* 0FAC */ { "LETTRE SUBJOINTE TIBÉTAINE DZHA","	= dzaha subjoint\n"
	"	: 0FAB 0FB7"},
/* 0FAD */ { "LETTRE SUBJOINTE TIBÉTAINE WA","	= oua subjoint\n"
	"	= wa-zur (oua sour), wa-btags (oua ta)"},
/* 0FAE */ { "LETTRE SUBJOINTE TIBÉTAINE ZHA","	= z'a subjoint"},
/* 0FAF */ { "LETTRE SUBJOINTE TIBÉTAINE ZA",NULL},
/* 0FB0 */ { "LETTRE SUBJOINTE TIBÉTAINE 'A","	* rare, s'utilise uniquement avec une lettre subjointe de pleine taille\n"
	"	x (diacritique voyelle tibétaine â - 0F71)"},
/* 0FB1 */ { "LETTRE SUBJOINTE TIBÉTAINE YA","	= ya-btags (ya ta)"},
/* 0FB2 */ { "LETTRE SUBJOINTE TIBÉTAINE RA","	= ra-btags (ra ta)"},
/* 0FB3 */ { "LETTRE SUBJOINTE TIBÉTAINE LA",NULL},
/* 0FB4 */ { "LETTRE SUBJOINTE TIBÉTAINE ÇA",NULL},
/* 0FB5 */ { "LETTRE SUBJOINTE TIBÉTAINE CHA",NULL},
/* 0FB6 */ { "LETTRE SUBJOINTE TIBÉTAINE SA",NULL},
/* 0FB7 */ { "LETTRE SUBJOINTE TIBÉTAINE HA",NULL},
/* 0FB8 */ { "LETTRE SUBJOINTE TIBÉTAINE A",NULL},
/* 0FB9 */ { "LETTRE SUBJOINTE TIBÉTAINE KCHA","	= k'ya subjoint\n"
	"	: 0F90 0FB5"},
/* 0FBA */ { "LETTRE SUBJOINTE TIBÉTAINE WA À FORME FIXE","	= oua subjoint à forme fixe"},
/* 0FBB */ { "LETTRE SUBJOINTE TIBÉTAINE YA À FORME FIXE",NULL},
/* 0FBC */ { "LETTRE SUBJOINTE TIBÉTAINE RA À FORME FIXE",NULL},
/* 0FBD */ { NULL,NULL},
/* 0FBE */ { "SIGNE TIBÉTAIN KOU ROU KHA","	= kourouk'a\n"
	"	* souvent répété trois fois ; indique un refrain"},
/* 0FBF */ { "SIGNE TIBÉTAIN KOU ROU KHA BZHI MIG TCHAN","	= kourouk'a chi mik tchène\n"
	"	* indique le point d'insertion d'un texte ou d'une glose\n"
	"	x (marque de référence - 203B)"},
/* 0FC0 */ { "SIGNE TIBÉTAIN DE CANTILLATION TEMPS FORT","	* marque un fort coup de tambour"},
/* 0FC1 */ { "SIGNE TIBÉTAIN DE CANTILLATION TEMPS FAIBLE","	* marque un léger coup de tambour"},
/* 0FC2 */ { "SIGNE TIBÉTAIN DE CANTILLATION TCHANG TI-OU","	= tchang tyou\n"
	"	* symbole d'un petit tambour à main tibétain"},
/* 0FC3 */ { "SIGNE TIBÉTAIN DE CANTILLATION SBOUB TCH'AL","	= boub tché\n"
	"	* symbole d'une cymbale tibétaine"},
/* 0FC4 */ { "SYMBOLE TIBÉTAIN DRIL BOU","	= drilbou\n"
	"	* symbole d'une clochette tibétaine\n"
	"	x (cloche - 1F514)"},
/* 0FC5 */ { "SYMBOLE TIBÉTAIN RDO RDJÉ","	= dordjé"},
/* 0FC6 */ { "SYMBOLE TIBÉTAIN PADMA GDAN","	= pé ma dène"},
/* 0FC7 */ { "SYMBOLE TIBÉTAIN RDO RDJÉ RGYA GRAM","	= dordjé gya dram"},
/* 0FC8 */ { "SYMBOLE TIBÉTAIN PHOUR PA","	= p'ourba"},
/* 0FC9 */ { "SYMBOLE TIBÉTAIN NOR BOU","	= norbou"},
/* 0FCA */ { "SYMBOLE TIBÉTAIN NOR BOU ÑIS 'KHYIL","	= norbou ñi khyi\n"
	"	* le symbole du double corps\n"
	"	x (yin et yang - 262F)"},
/* 0FCB */ { "SYMBOLE TIBÉTAIN NOR BOU GSOUM 'KHYIL","	= norbou soum khyi\n"
	"	* le tri-kaya ou symbole du triple corps"},
/* 0FCC */ { "SYMBOLE TIBÉTAIN NOR BOU BZHI 'KHYIL","	= norbou chi khyi\n"
	"	* le symbole du corps quadruple, une forme de svastika\n"
	"	x (svastika lévogyre - 0FD6)"},
/* 0FCD */ { NULL,NULL},
/* 0FCE */ { "SIGNE TIBÉTAIN RDEL NAG RDEL DKAR","	= déna déka\n"
	"	* signifie « mauvaise fortune hier, bonne fortune demain »\n"
	"	x (signe tibétain rdel dkar rdel nag - 0F1F)"},
/* 0FCF */ { "SIGNE TIBÉTAIN RDEL NAG GSOUM","	= dé na soum"},
/* 0FD0 */ { "SIGNE TIBÉTAIN BKA' ÇOG GI MGO RGYAN","	= ka cho gui go guien\n"
	"	* en usage dans la correspondance au Bhoutan quand un supérieur s'adresse à un inférieur\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 0FD1 */ { "SIGNE TIBÉTAIN MÑAM YIG GI MGO RGYAN","	= nyam yik gi go guien\n"
	"	* en usage dans la correspondance au Bhoutan quand on s'adresse à un égal"},
/* 0FD2 */ { "SIGNE TIBÉTAIN ÑIS TÇEG","	= ñi ts'ék"},
/* 0FD3 */ { "SIGNE TIBÉTAIN BRDA RÑING YIG MGO MDOUN MA OUVRANT","	= da ñing yik go doun ma"},
/* 0FD4 */ { "SIGNE TIBÉTAIN BRDA RÑING YIG MGO SGAB MA FERMANT","	= da ñing yik go kab ma"},
/* 0FD5 */ { "SVASTIKA DEXTROGYRE","	= young-droung nang khor\n"
	"	* en Inde, symbole de la bonne fortune et du bien-être\n"
	"	x 5350"},
/* 0FD6 */ { "SVASTIKA LÉVOGYRE","	= young-droung tchi khor\n"
	"	x 534D"},
/* 0FD7 */ { "SVASTIKA DEXTROGYRE AVEC POINTS","	= young-droung nang khor chi mig tchène"},
/* 0FD8 */ { "SVASTIKA LÉVOGYRE AVEC POINTS","	= young-droung tchi khor chi mig tchène"},
/* 0FD9 */ { "SIGNE TIBÉTAIN MTCH'AN RTAGS INITIAL",NULL},
/* 0FDA */ { "SIGNE TIBÉTAIN MTCH'AN RTAGS FINAL",NULL},
/* 0FDB */ { NULL,NULL},
/* 0FDC */ { NULL,NULL},
/* 0FDD */ { NULL,NULL},
/* 0FDE */ { NULL,NULL},
/* 0FDF */ { NULL,NULL},
/* 0FE0 */ { NULL,NULL},
/* 0FE1 */ { NULL,NULL},
/* 0FE2 */ { NULL,NULL},
/* 0FE3 */ { NULL,NULL},
/* 0FE4 */ { NULL,NULL},
/* 0FE5 */ { NULL,NULL},
/* 0FE6 */ { NULL,NULL},
/* 0FE7 */ { NULL,NULL},
/* 0FE8 */ { NULL,NULL},
/* 0FE9 */ { NULL,NULL},
/* 0FEA */ { NULL,NULL},
/* 0FEB */ { NULL,NULL},
/* 0FEC */ { NULL,NULL},
/* 0FED */ { NULL,NULL},
/* 0FEE */ { NULL,NULL},
/* 0FEF */ { NULL,NULL},
/* 0FF0 */ { NULL,NULL},
/* 0FF1 */ { NULL,NULL},
/* 0FF2 */ { NULL,NULL},
/* 0FF3 */ { NULL,NULL},
/* 0FF4 */ { NULL,NULL},
/* 0FF5 */ { NULL,NULL},
/* 0FF6 */ { NULL,NULL},
/* 0FF7 */ { NULL,NULL},
/* 0FF8 */ { NULL,NULL},
/* 0FF9 */ { NULL,NULL},
/* 0FFA */ { NULL,NULL},
/* 0FFB */ { NULL,NULL},
/* 0FFC */ { NULL,NULL},
/* 0FFD */ { NULL,NULL},
/* 0FFE */ { NULL,NULL},
/* 0FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_10[] = {
/* 1000 */ { "LETTRE BIRMANE KA","	~ 1000 FE00 forme pointée"},
/* 1001 */ { "LETTRE BIRMANE KHA",NULL},
/* 1002 */ { "LETTRE BIRMANE GA","	~ 1002 FE00 forme pointée"},
/* 1003 */ { "LETTRE BIRMANE GHA",NULL},
/* 1004 */ { "LETTRE BIRMANE NGA","	~ 1004 FE00 forme pointée"},
/* 1005 */ { "LETTRE BIRMANE TCHA",NULL},
/* 1006 */ { "LETTRE BIRMANE TCHHA",NULL},
/* 1007 */ { "LETTRE BIRMANE DJA",NULL},
/* 1008 */ { "LETTRE BIRMANE DJHA",NULL},
/* 1009 */ { "LETTRE BIRMANE ÑA",NULL},
/* 100A */ { "LETTRE BIRMANE ÑÑA",NULL},
/* 100B */ { "LETTRE BIRMANE TTA",NULL},
/* 100C */ { "LETTRE BIRMANE TTHA",NULL},
/* 100D */ { "LETTRE BIRMANE DDA",NULL},
/* 100E */ { "LETTRE BIRMANE DDHA",NULL},
/* 100F */ { "LETTRE BIRMANE NNA",NULL},
/* 1010 */ { "LETTRE BIRMANE TA","	~ 1010 FE00 forme pointée"},
/* 1011 */ { "LETTRE BIRMANE THA","	~ 1011 FE00 forme pointée"},
/* 1012 */ { "LETTRE BIRMANE DA",NULL},
/* 1013 */ { "LETTRE BIRMANE DHA",NULL},
/* 1014 */ { "LETTRE BIRMANE NA",NULL},
/* 1015 */ { "LETTRE BIRMANE PA","	~ 1015 FE00 forme pointée"},
/* 1016 */ { "LETTRE BIRMANE PHA","	= lettre birmane p'a"},
/* 1017 */ { "LETTRE BIRMANE BA",NULL},
/* 1018 */ { "LETTRE BIRMANE BHA",NULL},
/* 1019 */ { "LETTRE BIRMANE MA","	~ 1019 FE00 forme pointée"},
/* 101A */ { "LETTRE BIRMANE YA","	~ 101A FE00 forme pointée"},
/* 101B */ { "LETTRE BIRMANE RA",NULL},
/* 101C */ { "LETTRE BIRMANE LA","	~ 101C FE00 forme pointée"},
/* 101D */ { "LETTRE BIRMANE WA","	~ 101D FE00 forme pointée"},
/* 101E */ { "LETTRE BIRMANE SA",NULL},
/* 101F */ { "LETTRE BIRMANE HA",NULL},
/* 1020 */ { "LETTRE BIRMANE LLA",NULL},
/* 1021 */ { "LETTRE BIRMANE A","	* représente également un coup de glotte en tant que consonne"},
/* 1022 */ { "LETTRE BIRMANE CHAN A","	~ 1022 FE00 forme pointée"},
/* 1023 */ { "LETTRE BIRMANE I",NULL},
/* 1024 */ { "LETTRE BIRMANE Î",NULL},
/* 1025 */ { "LETTRE BIRMANE OU",NULL},
/* 1026 */ { "LETTRE BIRMANE OÛ","	: 1025 102E"},
/* 1027 */ { "LETTRE BIRMANE É",NULL},
/* 1028 */ { "LETTRE BIRMANE MÔN É",NULL},
/* 1029 */ { "LETTRE BIRMANE O",NULL},
/* 102A */ { "LETTRE BIRMANE AOU",NULL},
/* 102B */ { "DIACRITIQUE VOYELLE BIRMANE Â ALLONGÉ",NULL},
/* 102C */ { "DIACRITIQUE VOYELLE BIRMANE Â",NULL},
/* 102D */ { "DIACRITIQUE VOYELLE BIRMANE I",NULL},
/* 102E */ { "DIACRITIQUE VOYELLE BIRMANE Î",NULL},
/* 102F */ { "DIACRITIQUE VOYELLE BIRMANE OU",NULL},
/* 1030 */ { "DIACRITIQUE VOYELLE BIRMANE OÛ",NULL},
/* 1031 */ { "DIACRITIQUE VOYELLE BIRMANE É","	* à gauche de la consonne\n"
	"	~ 1031 FE00 forme pointée"},
/* 1032 */ { "DIACRITIQUE VOYELLE BIRMANE AI",NULL},
/* 1033 */ { "DIACRITIQUE VOYELLE BIRMANE MÔN Î",NULL},
/* 1034 */ { "DIACRITIQUE VOYELLE BIRMANE MÔN O",NULL},
/* 1035 */ { "DIACRITIQUE VOYELLE BIRMANE É SUSCRIT",NULL},
/* 1036 */ { "DIACRITIQUE BIRMAN ANOUSVÂRA",NULL},
/* 1037 */ { "DIACRITIQUE BIRMAN POINT SOUSCRIT","	= aukmyit\n"
	"	* un signe de ton"},
/* 1038 */ { "DIACRITIQUE BIRMAN VISARGA",NULL},
/* 1039 */ { "DIACRITIQUE BIRMAN VIRÂMA",NULL},
/* 103A */ { "DIACRITIQUE BIRMAN ASAT","	= halant (toujours visible)"},
/* 103B */ { "DIACRITIQUE CONSONNE BIRMANE YA MÉDIAL",NULL},
/* 103C */ { "DIACRITIQUE CONSONNE BIRMANE RA MÉDIAL",NULL},
/* 103D */ { "DIACRITIQUE CONSONNE BIRMANE WA MÉDIAL",NULL},
/* 103E */ { "DIACRITIQUE CONSONNE BIRMANE HA MÉDIAL",NULL},
/* 103F */ { "LETTRE BIRMANE GRAND SA",NULL},
/* 1040 */ { "CHIFFRE BIRMAN ZÉRO",NULL},
/* 1041 */ { "CHIFFRE BIRMAN UN",NULL},
/* 1042 */ { "CHIFFRE BIRMAN DEUX",NULL},
/* 1043 */ { "CHIFFRE BIRMAN TROIS",NULL},
/* 1044 */ { "CHIFFRE BIRMAN QUATRE",NULL},
/* 1045 */ { "CHIFFRE BIRMAN CINQ",NULL},
/* 1046 */ { "CHIFFRE BIRMAN SIX",NULL},
/* 1047 */ { "CHIFFRE BIRMAN SEPT",NULL},
/* 1048 */ { "CHIFFRE BIRMAN HUIT",NULL},
/* 1049 */ { "CHIFFRE BIRMAN NEUF",NULL},
/* 104A */ { "SIGNE BIRMAN PETITE SECTION","	= temps d'arrêt\n"
	"	x (danda dévanâgarî - 0964)"},
/* 104B */ { "SIGNE BIRMAN SECTION","	= point\n"
	"	x (double danda dévanâgarî - 0965)"},
/* 104C */ { "SYMBOLE BIRMAN LOCATIF",NULL},
/* 104D */ { "SYMBOLE BIRMAN ACCOMPLI",NULL},
/* 104E */ { "SYMBOLE BIRMAN LEDIT",NULL},
/* 104F */ { "SYMBOLE BIRMAN GÉNITIF",NULL},
/* 1050 */ { "LETTRE BIRMANE ÇA",NULL},
/* 1051 */ { "LETTRE BIRMANE CHA",NULL},
/* 1052 */ { "LETTRE BIRMANE R VOCALIQUE",NULL},
/* 1053 */ { "LETTRE BIRMANE RR VOCALIQUE",NULL},
/* 1054 */ { "LETTRE BIRMANE L VOCALIQUE",NULL},
/* 1055 */ { "LETTRE BIRMANE LL VOCALIQUE",NULL},
/* 1056 */ { "DIACRITIQUE VOYELLE BIRMANE R VOCALIQUE",NULL},
/* 1057 */ { "DIACRITIQUE VOYELLE BIRMANE RR VOCALIQUE",NULL},
/* 1058 */ { "DIACRITIQUE VOYELLE BIRMANE L VOCALIQUE",NULL},
/* 1059 */ { "DIACRITIQUE VOYELLE BIRMANE LL VOCALIQUE",NULL},
/* 105A */ { "LETTRE BIRMANE MÔN NGA",NULL},
/* 105B */ { "LETTRE BIRMANE MÔN DJHA",NULL},
/* 105C */ { "LETTRE BIRMANE MÔN BBA",NULL},
/* 105D */ { "LETTRE BIRMANE MÔN BBÉ",NULL},
/* 105E */ { "DIACRITIQUE CONSONNE BIRMANE MÔN NA MÉDIAL",NULL},
/* 105F */ { "DIACRITIQUE CONSONNE BIRMANE MÔN MA MÉDIAL",NULL},
/* 1060 */ { "DIACRITIQUE CONSONNE BIRMANE MÔN LA MÉDIAL",NULL},
/* 1061 */ { "LETTRE BIRMANE KAREN SGAW ÇA",NULL},
/* 1062 */ { "DIACRITIQUE VOYELLE BIRMANE KAREN SGAW EU",NULL},
/* 1063 */ { "DIACRITIQUE TON BIRMAN KAREN SGAW HATHI",NULL},
/* 1064 */ { "DIACRITIQUE TON BIRMAN KAREN SGAW KÉ PHO",NULL},
/* 1065 */ { "LETTRE BIRMANE KAREN PWO OCCIDENTAL THA",NULL},
/* 1066 */ { "LETTRE BIRMANE KAREN PWO OCCIDENTAL PWA",NULL},
/* 1067 */ { "DIACRITIQUE VOYELLE BIRMANE KAREN PWO OCCIDENTAL EU",NULL},
/* 1068 */ { "DIACRITIQUE VOYELLE BIRMANE KAREN PWO OCCIDENTAL U",NULL},
/* 1069 */ { "DIACRITIQUE BIRMAN KAREN PWO OCCIDENTAL TON-1",NULL},
/* 106A */ { "DIACRITIQUE BIRMAN KAREN PWO OCCIDENTAL TON-2",NULL},
/* 106B */ { "DIACRITIQUE BIRMAN KAREN PWO OCCIDENTAL TON-3",NULL},
/* 106C */ { "DIACRITIQUE BIRMAN KAREN PWO OCCIDENTAL TON-4",NULL},
/* 106D */ { "DIACRITIQUE BIRMAN KAREN PWO OCCIDENTAL TON-5",NULL},
/* 106E */ { "LETTRE BIRMANE KAREN PWO ORIENTAL NNA",NULL},
/* 106F */ { "LETTRE BIRMANE KAREN PWO ORIENTAL YWA",NULL},
/* 1070 */ { "LETTRE BIRMANE KAREN PWO ORIENTAL GHWA",NULL},
/* 1071 */ { "DIACRITIQUE VOYELLE BIRMANE KAREN GÈBA I",NULL},
/* 1072 */ { "DIACRITIQUE VOYELLE BIRMANE KAYAH E",NULL},
/* 1073 */ { "DIACRITIQUE VOYELLE BIRMANE KAYAH OU",NULL},
/* 1074 */ { "DIACRITIQUE VOYELLE BIRMANE KAYAH ÉÉ",NULL},
/* 1075 */ { "LETTRE BIRMANE CHAN KA","	~ 1075 FE00 forme pointée"},
/* 1076 */ { "LETTRE BIRMANE CHAN KHA",NULL},
/* 1077 */ { "LETTRE BIRMANE CHAN GA",NULL},
/* 1078 */ { "LETTRE BIRMANE CHAN TCHA","	~ 1078 FE00 forme pointée"},
/* 1079 */ { "LETTRE BIRMANE CHAN ZA",NULL},
/* 107A */ { "LETTRE BIRMANE CHAN ÑA","	~ 107A FE00 forme pointée"},
/* 107B */ { "LETTRE BIRMANE CHAN DA",NULL},
/* 107C */ { "LETTRE BIRMANE CHAN NA",NULL},
/* 107D */ { "LETTRE BIRMANE CHAN PHA","	= lettre birmane chan p'a"},
/* 107E */ { "LETTRE BIRMANE CHAN FA",NULL},
/* 107F */ { "LETTRE BIRMANE CHAN BA",NULL},
/* 1080 */ { "LETTRE BIRMANE CHAN THA","	~ 1080 FE00 forme pointée"},
/* 1081 */ { "LETTRE BIRMANE CHAN HA",NULL},
/* 1082 */ { "DIACRITIQUE CONSONNE BIRMANE CHAN WA MÉDIAL",NULL},
/* 1083 */ { "DIACRITIQUE VOYELLE BIRMANE CHAN Â",NULL},
/* 1084 */ { "DIACRITIQUE VOYELLE BIRMANE CHAN É",NULL},
/* 1085 */ { "DIACRITIQUE VOYELLE BIRMANE CHAN É SUSCRIT",NULL},
/* 1086 */ { "DIACRITIQUE VOYELLE BIRMANE CHAN AY FINAL",NULL},
/* 1087 */ { "DIACRITIQUE BIRMAN CHAN TON-2",NULL},
/* 1088 */ { "DIACRITIQUE BIRMAN CHAN TON-3",NULL},
/* 1089 */ { "DIACRITIQUE BIRMAN CHAN TON-5",NULL},
/* 108A */ { "DIACRITIQUE BIRMAN CHAN TON-6",NULL},
/* 108B */ { "DIACRITIQUE BIRMAN CHAN TON-2 DU CONSEIL",NULL},
/* 108C */ { "DIACRITIQUE BIRMAN CHAN TON-3 DU CONSEIL",NULL},
/* 108D */ { "DIACRITIQUE BIRMAN CHAN TON EMPHATIQUE DU CONSEIL",NULL},
/* 108E */ { "LETTRE BIRMANE PALAUNG RUMAI FA",NULL},
/* 108F */ { "DIACRITIQUE BIRMAN PALAUNG RUMAI TON-5",NULL},
/* 1090 */ { "CHIFFRE BIRMAN CHAN ZÉRO",NULL},
/* 1091 */ { "CHIFFRE BIRMAN CHAN UN",NULL},
/* 1092 */ { "CHIFFRE BIRMAN CHAN DEUX",NULL},
/* 1093 */ { "CHIFFRE BIRMAN CHAN TROIS",NULL},
/* 1094 */ { "CHIFFRE BIRMAN CHAN QUATRE",NULL},
/* 1095 */ { "CHIFFRE BIRMAN CHAN CINQ",NULL},
/* 1096 */ { "CHIFFRE BIRMAN CHAN SIX",NULL},
/* 1097 */ { "CHIFFRE BIRMAN CHAN SEPT",NULL},
/* 1098 */ { "CHIFFRE BIRMAN CHAN HUIT",NULL},
/* 1099 */ { "CHIFFRE BIRMAN CHAN NEUF",NULL},
/* 109A */ { "DIACRITIQUE BIRMAN KHAMTI TON-1",NULL},
/* 109B */ { "DIACRITIQUE BIRMAN KHAMTI TON-3",NULL},
/* 109C */ { "DIACRITIQUE VOYELLE BIRMANE AITON A",NULL},
/* 109D */ { "DIACRITIQUE VOYELLE BIRMANE AITON AI",NULL},
/* 109E */ { "SYMBOLE BIRMAN CHAN UN",NULL},
/* 109F */ { "SYMBOLE BIRMAN CHAN EXCLAMATION",NULL},
/* 10A0 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI AN","	x (lettre géorgienne nouskhouri an - 2D00)"},
/* 10A1 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI BAN",NULL},
/* 10A2 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI GAN",NULL},
/* 10A3 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI DON",NULL},
/* 10A4 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI ÈN",NULL},
/* 10A5 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI VIN",NULL},
/* 10A6 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI ZÉN",NULL},
/* 10A7 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI THAN",NULL},
/* 10A8 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI IN",NULL},
/* 10A9 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI K'AN",NULL},
/* 10AA */ { "LETTRE GÉORGIENNE ASSOMTAVROULI LASS",NULL},
/* 10AB */ { "LETTRE GÉORGIENNE ASSOMTAVROULI MAN",NULL},
/* 10AC */ { "LETTRE GÉORGIENNE ASSOMTAVROULI NAR",NULL},
/* 10AD */ { "LETTRE GÉORGIENNE ASSOMTAVROULI ON",NULL},
/* 10AE */ { "LETTRE GÉORGIENNE ASSOMTAVROULI P'AR",NULL},
/* 10AF */ { "LETTRE GÉORGIENNE ASSOMTAVROULI JAN",NULL},
/* 10B0 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI RAÉ",NULL},
/* 10B1 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI SAN",NULL},
/* 10B2 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI T'AR",NULL},
/* 10B3 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI OUN",NULL},
/* 10B4 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI PHAR",NULL},
/* 10B5 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI KHAR",NULL},
/* 10B6 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI GHAN",NULL},
/* 10B7 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI Q'AR",NULL},
/* 10B8 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI CHIN",NULL},
/* 10B9 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI TCHIN",NULL},
/* 10BA */ { "LETTRE GÉORGIENNE ASSOMTAVROULI TSIN",NULL},
/* 10BB */ { "LETTRE GÉORGIENNE ASSOMTAVROULI DZIL",NULL},
/* 10BC */ { "LETTRE GÉORGIENNE ASSOMTAVROULI TS'IL",NULL},
/* 10BD */ { "LETTRE GÉORGIENNE ASSOMTAVROULI TCH'AR",NULL},
/* 10BE */ { "LETTRE GÉORGIENNE ASSOMTAVROULI KHAN",NULL},
/* 10BF */ { "LETTRE GÉORGIENNE ASSOMTAVROULI DJAN",NULL},
/* 10C0 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI HAÉ",NULL},
/* 10C1 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI HÉ",NULL},
/* 10C2 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI IÉ",NULL},
/* 10C3 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI WIÉ",NULL},
/* 10C4 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI QAR",NULL},
/* 10C5 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI HOÉ",NULL},
/* 10C6 */ { NULL,NULL},
/* 10C7 */ { "LETTRE GÉORGIENNE ASSOMTAVROULI YN",NULL},
/* 10C8 */ { NULL,NULL},
/* 10C9 */ { NULL,NULL},
/* 10CA */ { NULL,NULL},
/* 10CB */ { NULL,NULL},
/* 10CC */ { NULL,NULL},
/* 10CD */ { "LETTRE GÉORGIENNE ASSOMTAVROULI AÈN",NULL},
/* 10CE */ { NULL,NULL},
/* 10CF */ { NULL,NULL},
/* 10D0 */ { "LETTRE GÉORGIENNE AN","	x (lettre géorgienne mtavrouli majuscule an - 1C90)"},
/* 10D1 */ { "LETTRE GÉORGIENNE BAN",NULL},
/* 10D2 */ { "LETTRE GÉORGIENNE GAN",NULL},
/* 10D3 */ { "LETTRE GÉORGIENNE DON",NULL},
/* 10D4 */ { "LETTRE GÉORGIENNE ÈN",NULL},
/* 10D5 */ { "LETTRE GÉORGIENNE VIN",NULL},
/* 10D6 */ { "LETTRE GÉORGIENNE ZÉN",NULL},
/* 10D7 */ { "LETTRE GÉORGIENNE THAN",NULL},
/* 10D8 */ { "LETTRE GÉORGIENNE IN",NULL},
/* 10D9 */ { "LETTRE GÉORGIENNE K'AN",NULL},
/* 10DA */ { "LETTRE GÉORGIENNE LASS",NULL},
/* 10DB */ { "LETTRE GÉORGIENNE MAN",NULL},
/* 10DC */ { "LETTRE GÉORGIENNE NAR",NULL},
/* 10DD */ { "LETTRE GÉORGIENNE ON",NULL},
/* 10DE */ { "LETTRE GÉORGIENNE P'AR",NULL},
/* 10DF */ { "LETTRE GÉORGIENNE JAN",NULL},
/* 10E0 */ { "LETTRE GÉORGIENNE RAÉ",NULL},
/* 10E1 */ { "LETTRE GÉORGIENNE SAN",NULL},
/* 10E2 */ { "LETTRE GÉORGIENNE T'AR",NULL},
/* 10E3 */ { "LETTRE GÉORGIENNE OUN",NULL},
/* 10E4 */ { "LETTRE GÉORGIENNE PHAR",NULL},
/* 10E5 */ { "LETTRE GÉORGIENNE KHAR",NULL},
/* 10E6 */ { "LETTRE GÉORGIENNE GHAN",NULL},
/* 10E7 */ { "LETTRE GÉORGIENNE Q'AR",NULL},
/* 10E8 */ { "LETTRE GÉORGIENNE CHIN",NULL},
/* 10E9 */ { "LETTRE GÉORGIENNE TCHIN",NULL},
/* 10EA */ { "LETTRE GÉORGIENNE TSIN",NULL},
/* 10EB */ { "LETTRE GÉORGIENNE DZIL",NULL},
/* 10EC */ { "LETTRE GÉORGIENNE TS'IL",NULL},
/* 10ED */ { "LETTRE GÉORGIENNE TCH'AR",NULL},
/* 10EE */ { "LETTRE GÉORGIENNE KHAN",NULL},
/* 10EF */ { "LETTRE GÉORGIENNE DJAN",NULL},
/* 10F0 */ { "LETTRE GÉORGIENNE HAÉ",NULL},
/* 10F1 */ { "LETTRE GÉORGIENNE HÉ",NULL},
/* 10F2 */ { "LETTRE GÉORGIENNE IÉ",NULL},
/* 10F3 */ { "LETTRE GÉORGIENNE WIÉ",NULL},
/* 10F4 */ { "LETTRE GÉORGIENNE QAR",NULL},
/* 10F5 */ { "LETTRE GÉORGIENNE HOÉ",NULL},
/* 10F6 */ { "LETTRE GÉORGIENNE FI",NULL},
/* 10F7 */ { "LETTRE GÉORGIENNE YN",NULL},
/* 10F8 */ { "LETTRE GÉORGIENNE ELIFI",NULL},
/* 10F9 */ { "LETTRE GÉORGIENNE GAN CULBUTÉ",NULL},
/* 10FA */ { "LETTRE GÉORGIENNE 'AÏN",NULL},
/* 10FB */ { "SÉPARATEUR DE PARAGRAPHES GÉORGIEN","	x (trois-points - 2056)"},
/* 10FC */ { "LETTRE MODIFICATIVE GÉORGIENNE NAR","	# <exp> 10DC"},
/* 10FD */ { "LETTRE GÉORGIENNE AÈN",NULL},
/* 10FE */ { "LETTRE GÉORGIENNE SIGNE DUR",NULL},
/* 10FF */ { "LETTRE GÉORGIENNE SIGNE LABIAL",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_11[] = {
/* 1100 */ { "TCH'ÔSONG HANGÛL KIYOK","	= K"},
/* 1101 */ { "TCH'ÔSONG HANGÛL SSANGKIYOK","	= KK"},
/* 1102 */ { "TCH'ÔSONG HANGÛL NIÛN","	= N"},
/* 1103 */ { "TCH'ÔSONG HANGÛL TIKÛT","	= T"},
/* 1104 */ { "TCH'ÔSONG HANGÛL SSANGTIKÛT","	= TT"},
/* 1105 */ { "TCH'ÔSONG HANGÛL RIÛL","	= L"},
/* 1106 */ { "TCH'ÔSONG HANGÛL MIÛM","	= M"},
/* 1107 */ { "TCH'ÔSONG HANGÛL PIÛP","	= P"},
/* 1108 */ { "TCH'ÔSONG HANGÛL SSANGPIÛP","	= PP"},
/* 1109 */ { "TCH'ÔSONG HANGÛL SIÔS","	= S\n"
	"	* fricative alvéolaire sourde lenis"},
/* 110A */ { "TCH'ÔSONG HANGÛL SSANGSIÔS","	= SS\n"
	"	* fricative alvéolaire sourde fortis"},
/* 110B */ { "TCH'ÔSONG HANGÛL IÛNG","	* zéro phonique"},
/* 110C */ { "TCH'ÔSONG HANGÛL TCHIÛTCH","	= TCH\n"
	"	* affriquée alvéolaire sourde ou sonore lenis"},
/* 110D */ { "TCH'ÔSONG HANGÛL SSANGTCHIÛTCH","	= TTCH\n"
	"	* affriquée alvéolaire sourde non aspirée fortis"},
/* 110E */ { "TCH'ÔSONG HANGÛL TCH'IÛTCH'","	= TCH'\n"
	"	* affriquée alvéolaire sourde aspirée"},
/* 110F */ { "TCH'ÔSONG HANGÛL K'IÛK'","	= K'"},
/* 1110 */ { "TCH'ÔSONG HANGÛL T'IÛT'","	= T'"},
/* 1111 */ { "TCH'ÔSONG HANGÛL P'IÛP'","	= P'"},
/* 1112 */ { "TCH'ÔSONG HANGÛL HIÛH","	= H\n"
	"	* fricative glottale sourde"},
/* 1113 */ { "TCH'ÔSONG HANGÛL NIÛN-KIYOK",NULL},
/* 1114 */ { "TCH'ÔSONG HANGÛL SSANGNIÛN",NULL},
/* 1115 */ { "TCH'ÔSONG HANGÛL NIÛN-TIKÛT",NULL},
/* 1116 */ { "TCH'ÔSONG HANGÛL NIÛN-PIÛP",NULL},
/* 1117 */ { "TCH'ÔSONG HANGÛL TIKÛT-KIYOK",NULL},
/* 1118 */ { "TCH'ÔSONG HANGÛL RIÛL-NIÛN",NULL},
/* 1119 */ { "TCH'ÔSONG HANGÛL SSANGRIÛL",NULL},
/* 111A */ { "TCH'ÔSONG HANGÛL RIÛL-HIÛH",NULL},
/* 111B */ { "TCH'ÔSONG HANGÛL KAPYO-OUNRIÛL",NULL},
/* 111C */ { "TCH'ÔSONG HANGÛL MIÛM-PIÛP",NULL},
/* 111D */ { "TCH'ÔSONG HANGÛL KAPYO-OUNMIÛM",NULL},
/* 111E */ { "TCH'ÔSONG HANGÛL PIÛP-KIYOK",NULL},
/* 111F */ { "TCH'ÔSONG HANGÛL PIÛP-NIÛN",NULL},
/* 1120 */ { "TCH'ÔSONG HANGÛL PIÛP-TIKÛT",NULL},
/* 1121 */ { "TCH'ÔSONG HANGÛL PIÛP-SIÔS",NULL},
/* 1122 */ { "TCH'ÔSONG HANGÛL PIÛP-SIÔS-KIYOK",NULL},
/* 1123 */ { "TCH'ÔSONG HANGÛL PIÛP-SIÔS-TIKÛT",NULL},
/* 1124 */ { "TCH'ÔSONG HANGÛL PIÛP-SIÔS-PIÛP",NULL},
/* 1125 */ { "TCH'ÔSONG HANGÛL PIÛP-SSANGSIÔS",NULL},
/* 1126 */ { "TCH'ÔSONG HANGÛL PIÛP-SIÔS-TCHIÛTCH",NULL},
/* 1127 */ { "TCH'ÔSONG HANGÛL PIÛP-TCHIÛTCH",NULL},
/* 1128 */ { "TCH'ÔSONG HANGÛL PIÛP-TCH'IÛTCH'",NULL},
/* 1129 */ { "TCH'ÔSONG HANGÛL PIÛP-T'IÛT'",NULL},
/* 112A */ { "TCH'ÔSONG HANGÛL PIÛP-P'IÛP'",NULL},
/* 112B */ { "TCH'ÔSONG HANGÛL KAPYO-OUNPIÛP",NULL},
/* 112C */ { "TCH'ÔSONG HANGÛL KAPYO-OUNSSANGPIÛP",NULL},
/* 112D */ { "TCH'ÔSONG HANGÛL SIÔS-KIYOK",NULL},
/* 112E */ { "TCH'ÔSONG HANGÛL SIÔS-NIÛN",NULL},
/* 112F */ { "TCH'ÔSONG HANGÛL SIÔS-TIKÛT",NULL},
/* 1130 */ { "TCH'ÔSONG HANGÛL SIÔS-RIÛL",NULL},
/* 1131 */ { "TCH'ÔSONG HANGÛL SIÔS-MIÛM",NULL},
/* 1132 */ { "TCH'ÔSONG HANGÛL SIÔS-PIÛP",NULL},
/* 1133 */ { "TCH'ÔSONG HANGÛL SIÔS-PIÛP-KIYOK",NULL},
/* 1134 */ { "TCH'ÔSONG HANGÛL SIÔS-SSANGSIÔS",NULL},
/* 1135 */ { "TCH'ÔSONG HANGÛL SIÔS-IÛNG",NULL},
/* 1136 */ { "TCH'ÔSONG HANGÛL SIÔS-TCHIÛTCH",NULL},
/* 1137 */ { "TCH'ÔSONG HANGÛL SIÔS-TCH'IÛTCH'",NULL},
/* 1138 */ { "TCH'ÔSONG HANGÛL SIÔS-K'IÛK'",NULL},
/* 1139 */ { "TCH'ÔSONG HANGÛL SIÔS-T'IÛT'",NULL},
/* 113A */ { "TCH'ÔSONG HANGÛL SIÔS-P'IÛP'",NULL},
/* 113B */ { "TCH'ÔSONG HANGÛL SIÔS-HIÛH",NULL},
/* 113C */ { "TCH'ÔSONG HANGÛL TCH'ITOUÛMSIÔS","	* fricative dentale sourde lenis"},
/* 113D */ { "TCH'ÔSONG HANGÛL TCH'ITOUÛMSSANGSIÔS","	* fricative dentale sourde fortis"},
/* 113E */ { "TCH'ÔSONG HANGÛL TCHONGTCH'IÛMSIÔS","	* fricative rétroflexe sourde lenis"},
/* 113F */ { "TCH'ÔSONG HANGÛL TCHONGTCH'IÛMSSANGSIÔS","	* fricative rétroflexe sourde fortis"},
/* 1140 */ { "TCH'ÔSONG HANGÛL PANSIÔS","	* fricative alvéolaire sonore"},
/* 1141 */ { "TCH'ÔSONG HANGÛL IÛNG-KIYOK",NULL},
/* 1142 */ { "TCH'ÔSONG HANGÛL IÛNG-TIKÛT",NULL},
/* 1143 */ { "TCH'ÔSONG HANGÛL IÛNG-MIÛM",NULL},
/* 1144 */ { "TCH'ÔSONG HANGÛL IÛNG-PIÛP",NULL},
/* 1145 */ { "TCH'ÔSONG HANGÛL IÛNG-SIÔS",NULL},
/* 1146 */ { "TCH'ÔSONG HANGÛL IÛNG-PANSIÔS",NULL},
/* 1147 */ { "TCH'ÔSONG HANGÛL SSANGIÛNG",NULL},
/* 1148 */ { "TCH'ÔSONG HANGÛL IÛNG-TCHIÛTCH",NULL},
/* 1149 */ { "TCH'ÔSONG HANGÛL IÛNG-TCH'IÛTCH'",NULL},
/* 114A */ { "TCH'ÔSONG HANGÛL IÛNG-T'IÛT'",NULL},
/* 114B */ { "TCH'ÔSONG HANGÛL IÛNG-P'IÛP'",NULL},
/* 114C */ { "TCH'ÔSONG HANGÛL YESIÛNG","	* consonne nasale vélaire"},
/* 114D */ { "TCH'ÔSONG HANGÛL TCHIÛTCH-IÛNG",NULL},
/* 114E */ { "TCH'ÔSONG HANGÛL TCH'ITOUÛMTCHIÛTCH","	* affriquée dentale sourde ou sonore lenis"},
/* 114F */ { "TCH'ÔSONG HANGÛL TCH'ITOUÛMSSANGTCHIÛTCH","	* affriquée dentale sourde non aspirée fortis"},
/* 1150 */ { "TCH'ÔSONG HANGÛL TCHONGTCH'IÛMTCHIÛTCH","	* affriquée rétroflexe sourde ou sonore lenis"},
/* 1151 */ { "TCH'ÔSONG HANGÛL TCHONGTCH'IÛMSSANGTCHIÛTCH","	* affriquée rétroflexe sourde non aspirée fortis"},
/* 1152 */ { "TCH'ÔSONG HANGÛL TCH'IÛTCH'-K'IÛK'",NULL},
/* 1153 */ { "TCH'ÔSONG HANGÛL TCH'IÛTCH'-HIÛH",NULL},
/* 1154 */ { "TCH'ÔSONG HANGÛL TCH'ITOUÛMTCH'IÛTCH'","	* affriquée dentale sourde aspirée"},
/* 1155 */ { "TCH'ÔSONG HANGÛL TCHONGTCH'IÛMTCH'IÛTCH'","	* affriquée rétroflexe sourde aspirée"},
/* 1156 */ { "TCH'ÔSONG HANGÛL P'IÛP'-PIÛP",NULL},
/* 1157 */ { "TCH'ÔSONG HANGÛL KAPYO-OUNP'IÛP'",NULL},
/* 1158 */ { "TCH'ÔSONG HANGÛL SSANGHIÛH",NULL},
/* 1159 */ { "TCH'ÔSONG HANGÛL YORINHIÛH","	* coup de glotte"},
/* 115A */ { "TCH'ÔSONG HANGÛL KIYOK-TIKÛT",NULL},
/* 115B */ { "TCH'ÔSONG HANGÛL NIÛN-SIÔS",NULL},
/* 115C */ { "TCH'ÔSONG HANGÛL NIÛN-TCHIÛTCH",NULL},
/* 115D */ { "TCH'ÔSONG HANGÛL NIÛN-HIÛH",NULL},
/* 115E */ { "TCH'ÔSONG HANGÛL TIKÛT-RIÛL",NULL},
/* 115F */ { "BOURRE TCH'ÔSONG HANGÛL",NULL},
/* 1160 */ { "BOURRE DJOUNGSONG HANGÛL",NULL},
/* 1161 */ { "DJOUNGSONG HANGÛL A","	= A"},
/* 1162 */ { "DJOUNGSONG HANGÛL È","	= È"},
/* 1163 */ { "DJOUNGSONG HANGÛL YA","	= YA"},
/* 1164 */ { "DJOUNGSONG HANGÛL YÈ","	= YÈ"},
/* 1165 */ { "DJOUNGSONG HANGÛL O","	= O"},
/* 1166 */ { "DJOUNGSONG HANGÛL É","	= É"},
/* 1167 */ { "DJOUNGSONG HANGÛL YO","	= YO"},
/* 1168 */ { "DJOUNGSONG HANGÛL YÉ","	= YÉ"},
/* 1169 */ { "DJOUNGSONG HANGÛL Ô","	= Ô"},
/* 116A */ { "DJOUNGSONG HANGÛL WA","	= WA"},
/* 116B */ { "DJOUNGSONG HANGÛL WÈ","	= WÈ"},
/* 116C */ { "DJOUNGSONG HANGÛL EU","	= EU"},
/* 116D */ { "DJOUNGSONG HANGÛL YÔ","	= YÔ"},
/* 116E */ { "DJOUNGSONG HANGÛL OU","	= OU"},
/* 116F */ { "DJOUNGSONG HANGÛL WO","	= WO"},
/* 1170 */ { "DJOUNGSONG HANGÛL WÉ","	= WÉ"},
/* 1171 */ { "DJOUNGSONG HANGÛL WI","	= WI"},
/* 1172 */ { "DJOUNGSONG HANGÛL YOU","	= YOU"},
/* 1173 */ { "DJOUNGSONG HANGÛL Û","	= Û"},
/* 1174 */ { "DJOUNGSONG HANGÛL ÛI","	= ÛI"},
/* 1175 */ { "DJOUNGSONG HANGÛL I","	= I"},
/* 1176 */ { "DJOUNGSONG HANGÛL A-Ô",NULL},
/* 1177 */ { "DJOUNGSONG HANGÛL A-OU",NULL},
/* 1178 */ { "DJOUNGSONG HANGÛL YA-Ô",NULL},
/* 1179 */ { "DJOUNGSONG HANGÛL YA-YÔ",NULL},
/* 117A */ { "DJOUNGSONG HANGÛL O-Ô",NULL},
/* 117B */ { "DJOUNGSONG HANGÛL O-OU",NULL},
/* 117C */ { "DJOUNGSONG HANGÛL O-Û",NULL},
/* 117D */ { "DJOUNGSONG HANGÛL YO-Ô",NULL},
/* 117E */ { "DJOUNGSONG HANGÛL YO-OU",NULL},
/* 117F */ { "DJOUNGSONG HANGÛL Ô-O",NULL},
/* 1180 */ { "DJOUNGSONG HANGÛL Ô-É",NULL},
/* 1181 */ { "DJOUNGSONG HANGÛL Ô-YÉ",NULL},
/* 1182 */ { "DJOUNGSONG HANGÛL Ô-Ô",NULL},
/* 1183 */ { "DJOUNGSONG HANGÛL Ô-OU",NULL},
/* 1184 */ { "DJOUNGSONG HANGÛL YÔ-YA",NULL},
/* 1185 */ { "DJOUNGSONG HANGÛL YÔ-YÈ",NULL},
/* 1186 */ { "DJOUNGSONG HANGÛL YÔ-YO",NULL},
/* 1187 */ { "DJOUNGSONG HANGÛL YÔ-Ô",NULL},
/* 1188 */ { "DJOUNGSONG HANGÛL YÔ-I",NULL},
/* 1189 */ { "DJOUNGSONG HANGÛL OU-A",NULL},
/* 118A */ { "DJOUNGSONG HANGÛL OU-È",NULL},
/* 118B */ { "DJOUNGSONG HANGÛL OU-O-Û",NULL},
/* 118C */ { "DJOUNGSONG HANGÛL OU-YÉ",NULL},
/* 118D */ { "DJOUNGSONG HANGÛL OU-OU",NULL},
/* 118E */ { "DJOUNGSONG HANGÛL YOU-A",NULL},
/* 118F */ { "DJOUNGSONG HANGÛL YOU-O",NULL},
/* 1190 */ { "DJOUNGSONG HANGÛL YOU-É",NULL},
/* 1191 */ { "DJOUNGSONG HANGÛL YOU-YO",NULL},
/* 1192 */ { "DJOUNGSONG HANGÛL YOU-YÉ",NULL},
/* 1193 */ { "DJOUNGSONG HANGÛL YOU-OU",NULL},
/* 1194 */ { "DJOUNGSONG HANGÛL YOU-I",NULL},
/* 1195 */ { "DJOUNGSONG HANGÛL Û-OU",NULL},
/* 1196 */ { "DJOUNGSONG HANGÛL Û-Û",NULL},
/* 1197 */ { "DJOUNGSONG HANGÛL ÛI-OU",NULL},
/* 1198 */ { "DJOUNGSONG HANGÛL I-A",NULL},
/* 1199 */ { "DJOUNGSONG HANGÛL I-YA",NULL},
/* 119A */ { "DJOUNGSONG HANGÛL I-Ô",NULL},
/* 119B */ { "DJOUNGSONG HANGÛL I-OU",NULL},
/* 119C */ { "DJOUNGSONG HANGÛL I-Û",NULL},
/* 119D */ { "DJOUNGSONG HANGÛL I-ARÈA",NULL},
/* 119E */ { "DJOUNGSONG HANGÛL ARÈA","	* voyelle mi-ouverte postérieure arrondie"},
/* 119F */ { "DJOUNGSONG HANGÛL ARÈA-O",NULL},
/* 11A0 */ { "DJOUNGSONG HANGÛL ARÈA-OU",NULL},
/* 11A1 */ { "DJOUNGSONG HANGÛL ARÈA-I",NULL},
/* 11A2 */ { "DJOUNGSONG HANGÛL SSANGARÈA",NULL},
/* 11A3 */ { "DJOUNGSONG HANGÛL A-Û",NULL},
/* 11A4 */ { "DJOUNGSONG HANGÛL YA-OU",NULL},
/* 11A5 */ { "DJOUNGSONG HANGÛL YO-YA",NULL},
/* 11A6 */ { "DJOUNGSONG HANGÛL Ô-YA",NULL},
/* 11A7 */ { "DJOUNGSONG HANGÛL Ô-YÈ",NULL},
/* 11A8 */ { "DJÔNGSONG HANGÛL KIYOK","	= K"},
/* 11A9 */ { "DJÔNGSONG HANGÛL SSANGKIYOK","	= KK"},
/* 11AA */ { "DJÔNGSONG HANGÛL KIYOK-SIÔS","	= KS"},
/* 11AB */ { "DJÔNGSONG HANGÛL NIÛN","	= N"},
/* 11AC */ { "DJÔNGSONG HANGÛL NIÛN-TCHIÛTCH","	= NTCH"},
/* 11AD */ { "DJÔNGSONG HANGÛL NIÛN-HIÛH","	= NH"},
/* 11AE */ { "DJÔNGSONG HANGÛL TIKÛT","	= T"},
/* 11AF */ { "DJÔNGSONG HANGÛL RIÛL","	= L"},
/* 11B0 */ { "DJÔNGSONG HANGÛL RIÛL-KIYOK","	= LK"},
/* 11B1 */ { "DJÔNGSONG HANGÛL RIÛL-MIÛM","	= LM"},
/* 11B2 */ { "DJÔNGSONG HANGÛL RIÛL-PIÛP","	= LP"},
/* 11B3 */ { "DJÔNGSONG HANGÛL RIÛL-SIÔS","	= LS"},
/* 11B4 */ { "DJÔNGSONG HANGÛL RIÛL-T'IÛT'","	= LT'"},
/* 11B5 */ { "DJÔNGSONG HANGÛL RIÛL-P'IÛP'","	= LP'"},
/* 11B6 */ { "DJÔNGSONG HANGÛL RIÛL-HIÛH","	= LH"},
/* 11B7 */ { "DJÔNGSONG HANGÛL MIÛM","	= M"},
/* 11B8 */ { "DJÔNGSONG HANGÛL PIÛP","	= P"},
/* 11B9 */ { "DJÔNGSONG HANGÛL PIÛP-SIÔS","	= PS"},
/* 11BA */ { "DJÔNGSONG HANGÛL SIÔS","	= S"},
/* 11BB */ { "DJÔNGSONG HANGÛL SSANGSIÔS","	= SS"},
/* 11BC */ { "DJÔNGSONG HANGÛL IÛNG","	= NG\n"
	"	* consonne nasale vélaire"},
/* 11BD */ { "DJÔNGSONG HANGÛL TCHIÛTCH","	= TCH"},
/* 11BE */ { "DJÔNGSONG HANGÛL TCH'IÛTCH'","	= TCH'"},
/* 11BF */ { "DJÔNGSONG HANGÛL K'IÛK'","	= K'"},
/* 11C0 */ { "DJÔNGSONG HANGÛL T'IÛT'","	= T'"},
/* 11C1 */ { "DJÔNGSONG HANGÛL P'IÛP'","	= P'"},
/* 11C2 */ { "DJÔNGSONG HANGÛL HIÛH","	= H"},
/* 11C3 */ { "DJÔNGSONG HANGÛL KIYOK-RIÛL",NULL},
/* 11C4 */ { "DJÔNGSONG HANGÛL KIYOK-SIÔS-KIYOK",NULL},
/* 11C5 */ { "DJÔNGSONG HANGÛL NIÛN-KIYOK",NULL},
/* 11C6 */ { "DJÔNGSONG HANGÛL NIÛN-TIKÛT",NULL},
/* 11C7 */ { "DJÔNGSONG HANGÛL NIÛN-SIÔS",NULL},
/* 11C8 */ { "DJÔNGSONG HANGÛL NIÛN-PANSIÔS",NULL},
/* 11C9 */ { "DJÔNGSONG HANGÛL NIÛN-T'IÛT'",NULL},
/* 11CA */ { "DJÔNGSONG HANGÛL TIKÛT-KIYOK",NULL},
/* 11CB */ { "DJÔNGSONG HANGÛL TIKÛT-RIÛL",NULL},
/* 11CC */ { "DJÔNGSONG HANGÛL RIÛL-KIYOK-SIÔS",NULL},
/* 11CD */ { "DJÔNGSONG HANGÛL RIÛL-NIÛN",NULL},
/* 11CE */ { "DJÔNGSONG HANGÛL RIÛL-TIKÛT",NULL},
/* 11CF */ { "DJÔNGSONG HANGÛL RIÛL-TIKÛT-HIÛH",NULL},
/* 11D0 */ { "DJÔNGSONG HANGÛL SSANGRIÛL",NULL},
/* 11D1 */ { "DJÔNGSONG HANGÛL RIÛL-MIÛM-KIYOK",NULL},
/* 11D2 */ { "DJÔNGSONG HANGÛL RIÛL-MIÛM-SIÔS",NULL},
/* 11D3 */ { "DJÔNGSONG HANGÛL RIÛL-PIÛP-SIÔS",NULL},
/* 11D4 */ { "DJÔNGSONG HANGÛL RIÛL-PIÛP-HIÛH",NULL},
/* 11D5 */ { "DJÔNGSONG HANGÛL RIÛL-KAPYO-OUNPIÛP",NULL},
/* 11D6 */ { "DJÔNGSONG HANGÛL RIÛL-SSANGSIÔS",NULL},
/* 11D7 */ { "DJÔNGSONG HANGÛL RIÛL-PANSIÔS",NULL},
/* 11D8 */ { "DJÔNGSONG HANGÛL RIÛL-K'IÛK'",NULL},
/* 11D9 */ { "DJÔNGSONG HANGÛL RIÛL-YORINHIÛH",NULL},
/* 11DA */ { "DJÔNGSONG HANGÛL MIÛM-KIYOK",NULL},
/* 11DB */ { "DJÔNGSONG HANGÛL MIÛM-RIÛL",NULL},
/* 11DC */ { "DJÔNGSONG HANGÛL MIÛM-PIÛP",NULL},
/* 11DD */ { "DJÔNGSONG HANGÛL MIÛM-SIÔS",NULL},
/* 11DE */ { "DJÔNGSONG HANGÛL MIÛM-SSANGSIÔS",NULL},
/* 11DF */ { "DJÔNGSONG HANGÛL MIÛM-PANSIÔS",NULL},
/* 11E0 */ { "DJÔNGSONG HANGÛL MIÛM-TCH'IÛTCH'",NULL},
/* 11E1 */ { "DJÔNGSONG HANGÛL MIÛM-HIÛH",NULL},
/* 11E2 */ { "DJÔNGSONG HANGÛL KAPYO-OUNMIÛM",NULL},
/* 11E3 */ { "DJÔNGSONG HANGÛL PIÛP-RIÛL",NULL},
/* 11E4 */ { "DJÔNGSONG HANGÛL PIÛP-P'IÛP'",NULL},
/* 11E5 */ { "DJÔNGSONG HANGÛL PIÛP-HIÛH",NULL},
/* 11E6 */ { "DJÔNGSONG HANGÛL KAPYO-OUNPIÛP",NULL},
/* 11E7 */ { "DJÔNGSONG HANGÛL SIÔS-KIYOK",NULL},
/* 11E8 */ { "DJÔNGSONG HANGÛL SIÔS-TIKÛT",NULL},
/* 11E9 */ { "DJÔNGSONG HANGÛL SIÔS-RIÛL",NULL},
/* 11EA */ { "DJÔNGSONG HANGÛL SIÔS-PIÛP",NULL},
/* 11EB */ { "DJÔNGSONG HANGÛL PANSIÔS",NULL},
/* 11EC */ { "DJÔNGSONG HANGÛL YESIÛNG-KIYOK","	* le nom formel de ce caractère en anglais est erroné"},
/* 11ED */ { "DJÔNGSONG HANGÛL YESIÛNG-SSANGKIYOK","	* le nom formel de ce caractère en anglais est erroné"},
/* 11EE */ { "DJÔNGSONG HANGÛL SSANGYESIÛNG","	* le nom formel de ce caractère en anglais est erroné"},
/* 11EF */ { "DJÔNGSONG HANGÛL YESIÛNG-K'IÛK'","	* le nom formel de ce caractère en anglais est erroné"},
/* 11F0 */ { "DJÔNGSONG HANGÛL YESIÛNG",NULL},
/* 11F1 */ { "DJÔNGSONG HANGÛL YESIÛNG-SIÔS",NULL},
/* 11F2 */ { "DJÔNGSONG HANGÛL YESIÛNG-PANSIÔS",NULL},
/* 11F3 */ { "DJÔNGSONG HANGÛL P'IÛP'-PIÛP",NULL},
/* 11F4 */ { "DJÔNGSONG HANGÛL KAPYO-OUNP'IÛP'",NULL},
/* 11F5 */ { "DJÔNGSONG HANGÛL HIÛH-NIÛN",NULL},
/* 11F6 */ { "DJÔNGSONG HANGÛL HIÛH-RIÛL",NULL},
/* 11F7 */ { "DJÔNGSONG HANGÛL HIÛH-MIÛM",NULL},
/* 11F8 */ { "DJÔNGSONG HANGÛL HIÛH-PIÛP",NULL},
/* 11F9 */ { "DJÔNGSONG HANGÛL YORINHIÛH",NULL},
/* 11FA */ { "DJÔNGSONG HANGÛL KIYOK-NIÛN",NULL},
/* 11FB */ { "DJÔNGSONG HANGÛL KIYOK-PIÛP",NULL},
/* 11FC */ { "DJÔNGSONG HANGÛL KIYOK-TCH'IÛTCH'",NULL},
/* 11FD */ { "DJÔNGSONG HANGÛL KIYOK-K'IÛK'",NULL},
/* 11FE */ { "DJÔNGSONG HANGÛL KIYOK-HIÛH",NULL},
/* 11FF */ { "DJÔNGSONG HANGÛL SSANGNIÛN",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_12[] = {
/* 1200 */ { "SYLLABE ÉTHIOPIENNE HÄ",NULL},
/* 1201 */ { "SYLLABE ÉTHIOPIENNE HOU",NULL},
/* 1202 */ { "SYLLABE ÉTHIOPIENNE HI",NULL},
/* 1203 */ { "SYLLABE ÉTHIOPIENNE HA",NULL},
/* 1204 */ { "SYLLABE ÉTHIOPIENNE HÉ",NULL},
/* 1205 */ { "SYLLABE ÉTHIOPIENNE HE",NULL},
/* 1206 */ { "SYLLABE ÉTHIOPIENNE HO",NULL},
/* 1207 */ { "SYLLABE ÉTHIOPIENNE HOÄ","	* « oä » dénote un « o » ouvert"},
/* 1208 */ { "SYLLABE ÉTHIOPIENNE LÄ",NULL},
/* 1209 */ { "SYLLABE ÉTHIOPIENNE LOU",NULL},
/* 120A */ { "SYLLABE ÉTHIOPIENNE LI",NULL},
/* 120B */ { "SYLLABE ÉTHIOPIENNE LA",NULL},
/* 120C */ { "SYLLABE ÉTHIOPIENNE LÉ",NULL},
/* 120D */ { "SYLLABE ÉTHIOPIENNE LE",NULL},
/* 120E */ { "SYLLABE ÉTHIOPIENNE LO",NULL},
/* 120F */ { "SYLLABE ÉTHIOPIENNE LWA",NULL},
/* 1210 */ { "SYLLABE ÉTHIOPIENNE HHÄ",NULL},
/* 1211 */ { "SYLLABE ÉTHIOPIENNE HHOU",NULL},
/* 1212 */ { "SYLLABE ÉTHIOPIENNE HHI",NULL},
/* 1213 */ { "SYLLABE ÉTHIOPIENNE HHA",NULL},
/* 1214 */ { "SYLLABE ÉTHIOPIENNE HHÉ",NULL},
/* 1215 */ { "SYLLABE ÉTHIOPIENNE HHE",NULL},
/* 1216 */ { "SYLLABE ÉTHIOPIENNE HHO",NULL},
/* 1217 */ { "SYLLABE ÉTHIOPIENNE HHWA",NULL},
/* 1218 */ { "SYLLABE ÉTHIOPIENNE MÄ",NULL},
/* 1219 */ { "SYLLABE ÉTHIOPIENNE MOU",NULL},
/* 121A */ { "SYLLABE ÉTHIOPIENNE MI",NULL},
/* 121B */ { "SYLLABE ÉTHIOPIENNE MA",NULL},
/* 121C */ { "SYLLABE ÉTHIOPIENNE MÉ",NULL},
/* 121D */ { "SYLLABE ÉTHIOPIENNE ME",NULL},
/* 121E */ { "SYLLABE ÉTHIOPIENNE MO",NULL},
/* 121F */ { "SYLLABE ÉTHIOPIENNE MWA",NULL},
/* 1220 */ { "SYLLABE ÉTHIOPIENNE ÇÄ",NULL},
/* 1221 */ { "SYLLABE ÉTHIOPIENNE ÇOU",NULL},
/* 1222 */ { "SYLLABE ÉTHIOPIENNE ÇI",NULL},
/* 1223 */ { "SYLLABE ÉTHIOPIENNE ÇA",NULL},
/* 1224 */ { "SYLLABE ÉTHIOPIENNE ÇÉ",NULL},
/* 1225 */ { "SYLLABE ÉTHIOPIENNE ÇE",NULL},
/* 1226 */ { "SYLLABE ÉTHIOPIENNE ÇO",NULL},
/* 1227 */ { "SYLLABE ÉTHIOPIENNE ÇWA",NULL},
/* 1228 */ { "SYLLABE ÉTHIOPIENNE RÄ",NULL},
/* 1229 */ { "SYLLABE ÉTHIOPIENNE ROU",NULL},
/* 122A */ { "SYLLABE ÉTHIOPIENNE RI",NULL},
/* 122B */ { "SYLLABE ÉTHIOPIENNE RA",NULL},
/* 122C */ { "SYLLABE ÉTHIOPIENNE RÉ",NULL},
/* 122D */ { "SYLLABE ÉTHIOPIENNE RE",NULL},
/* 122E */ { "SYLLABE ÉTHIOPIENNE RO",NULL},
/* 122F */ { "SYLLABE ÉTHIOPIENNE RWA",NULL},
/* 1230 */ { "SYLLABE ÉTHIOPIENNE SÄ",NULL},
/* 1231 */ { "SYLLABE ÉTHIOPIENNE SOU",NULL},
/* 1232 */ { "SYLLABE ÉTHIOPIENNE SI",NULL},
/* 1233 */ { "SYLLABE ÉTHIOPIENNE SA",NULL},
/* 1234 */ { "SYLLABE ÉTHIOPIENNE SÉ",NULL},
/* 1235 */ { "SYLLABE ÉTHIOPIENNE SE",NULL},
/* 1236 */ { "SYLLABE ÉTHIOPIENNE SO",NULL},
/* 1237 */ { "SYLLABE ÉTHIOPIENNE SWA",NULL},
/* 1238 */ { "SYLLABE ÉTHIOPIENNE CHÄ",NULL},
/* 1239 */ { "SYLLABE ÉTHIOPIENNE CHOU",NULL},
/* 123A */ { "SYLLABE ÉTHIOPIENNE CHI",NULL},
/* 123B */ { "SYLLABE ÉTHIOPIENNE CHA",NULL},
/* 123C */ { "SYLLABE ÉTHIOPIENNE CHÉ",NULL},
/* 123D */ { "SYLLABE ÉTHIOPIENNE CHE",NULL},
/* 123E */ { "SYLLABE ÉTHIOPIENNE CHO",NULL},
/* 123F */ { "SYLLABE ÉTHIOPIENNE CHWA",NULL},
/* 1240 */ { "SYLLABE ÉTHIOPIENNE QÄ",NULL},
/* 1241 */ { "SYLLABE ÉTHIOPIENNE QOU",NULL},
/* 1242 */ { "SYLLABE ÉTHIOPIENNE QI",NULL},
/* 1243 */ { "SYLLABE ÉTHIOPIENNE QA",NULL},
/* 1244 */ { "SYLLABE ÉTHIOPIENNE QÉ",NULL},
/* 1245 */ { "SYLLABE ÉTHIOPIENNE QE",NULL},
/* 1246 */ { "SYLLABE ÉTHIOPIENNE QO",NULL},
/* 1247 */ { "SYLLABE ÉTHIOPIENNE QOÄ","	* « oä » dénote un « o » ouvert"},
/* 1248 */ { "SYLLABE ÉTHIOPIENNE QWÄ",NULL},
/* 1249 */ { NULL,NULL},
/* 124A */ { "SYLLABE ÉTHIOPIENNE QWI","	x (syllabe éthiopienne gouragé qwi - 1E7F0)"},
/* 124B */ { "SYLLABE ÉTHIOPIENNE QWA",NULL},
/* 124C */ { "SYLLABE ÉTHIOPIENNE QWÉ","	x (syllabe éthiopienne gouragé qwé - 1E7F1)"},
/* 124D */ { "SYLLABE ÉTHIOPIENNE QWE","	x (syllabe éthiopienne gouragé qwe - 1E7F2)"},
/* 124E */ { NULL,NULL},
/* 124F */ { NULL,NULL},
/* 1250 */ { "SYLLABE ÉTHIOPIENNE QHÄ","	* la partie supérieure de la lettre se nomme parfois « chapeau »"},
/* 1251 */ { "SYLLABE ÉTHIOPIENNE QHOU",NULL},
/* 1252 */ { "SYLLABE ÉTHIOPIENNE QHI",NULL},
/* 1253 */ { "SYLLABE ÉTHIOPIENNE QHA",NULL},
/* 1254 */ { "SYLLABE ÉTHIOPIENNE QHÉ",NULL},
/* 1255 */ { "SYLLABE ÉTHIOPIENNE QHE",NULL},
/* 1256 */ { "SYLLABE ÉTHIOPIENNE QHO",NULL},
/* 1257 */ { NULL,NULL},
/* 1258 */ { "SYLLABE ÉTHIOPIENNE QHWÄ",NULL},
/* 1259 */ { NULL,NULL},
/* 125A */ { "SYLLABE ÉTHIOPIENNE QHWI",NULL},
/* 125B */ { "SYLLABE ÉTHIOPIENNE QHWA",NULL},
/* 125C */ { "SYLLABE ÉTHIOPIENNE QHWÉ",NULL},
/* 125D */ { "SYLLABE ÉTHIOPIENNE QHWE",NULL},
/* 125E */ { NULL,NULL},
/* 125F */ { NULL,NULL},
/* 1260 */ { "SYLLABE ÉTHIOPIENNE BÄ",NULL},
/* 1261 */ { "SYLLABE ÉTHIOPIENNE BOU",NULL},
/* 1262 */ { "SYLLABE ÉTHIOPIENNE BI",NULL},
/* 1263 */ { "SYLLABE ÉTHIOPIENNE BA",NULL},
/* 1264 */ { "SYLLABE ÉTHIOPIENNE BÉ",NULL},
/* 1265 */ { "SYLLABE ÉTHIOPIENNE BE",NULL},
/* 1266 */ { "SYLLABE ÉTHIOPIENNE BO",NULL},
/* 1267 */ { "SYLLABE ÉTHIOPIENNE BWA",NULL},
/* 1268 */ { "SYLLABE ÉTHIOPIENNE VÄ",NULL},
/* 1269 */ { "SYLLABE ÉTHIOPIENNE VOU",NULL},
/* 126A */ { "SYLLABE ÉTHIOPIENNE VI",NULL},
/* 126B */ { "SYLLABE ÉTHIOPIENNE VA",NULL},
/* 126C */ { "SYLLABE ÉTHIOPIENNE VÉ",NULL},
/* 126D */ { "SYLLABE ÉTHIOPIENNE VE",NULL},
/* 126E */ { "SYLLABE ÉTHIOPIENNE VO",NULL},
/* 126F */ { "SYLLABE ÉTHIOPIENNE VWA",NULL},
/* 1270 */ { "SYLLABE ÉTHIOPIENNE TÄ",NULL},
/* 1271 */ { "SYLLABE ÉTHIOPIENNE TOU",NULL},
/* 1272 */ { "SYLLABE ÉTHIOPIENNE TI",NULL},
/* 1273 */ { "SYLLABE ÉTHIOPIENNE TA",NULL},
/* 1274 */ { "SYLLABE ÉTHIOPIENNE TÉ",NULL},
/* 1275 */ { "SYLLABE ÉTHIOPIENNE TE",NULL},
/* 1276 */ { "SYLLABE ÉTHIOPIENNE TO",NULL},
/* 1277 */ { "SYLLABE ÉTHIOPIENNE TWA",NULL},
/* 1278 */ { "SYLLABE ÉTHIOPIENNE TCHÄ",NULL},
/* 1279 */ { "SYLLABE ÉTHIOPIENNE TCHOU",NULL},
/* 127A */ { "SYLLABE ÉTHIOPIENNE TCHI",NULL},
/* 127B */ { "SYLLABE ÉTHIOPIENNE TCHA",NULL},
/* 127C */ { "SYLLABE ÉTHIOPIENNE TCHÉ",NULL},
/* 127D */ { "SYLLABE ÉTHIOPIENNE TCHE",NULL},
/* 127E */ { "SYLLABE ÉTHIOPIENNE TCHO",NULL},
/* 127F */ { "SYLLABE ÉTHIOPIENNE TCHWA",NULL},
/* 1280 */ { "SYLLABE ÉTHIOPIENNE XÄ",NULL},
/* 1281 */ { "SYLLABE ÉTHIOPIENNE XOU",NULL},
/* 1282 */ { "SYLLABE ÉTHIOPIENNE XI",NULL},
/* 1283 */ { "SYLLABE ÉTHIOPIENNE XA",NULL},
/* 1284 */ { "SYLLABE ÉTHIOPIENNE XÉ",NULL},
/* 1285 */ { "SYLLABE ÉTHIOPIENNE XE",NULL},
/* 1286 */ { "SYLLABE ÉTHIOPIENNE XO",NULL},
/* 1287 */ { "SYLLABE ÉTHIOPIENNE XOÄ",NULL},
/* 1288 */ { "SYLLABE ÉTHIOPIENNE XWÄ",NULL},
/* 1289 */ { NULL,NULL},
/* 128A */ { "SYLLABE ÉTHIOPIENNE XWI",NULL},
/* 128B */ { "SYLLABE ÉTHIOPIENNE XWA",NULL},
/* 128C */ { "SYLLABE ÉTHIOPIENNE XWÉ",NULL},
/* 128D */ { "SYLLABE ÉTHIOPIENNE XWE",NULL},
/* 128E */ { NULL,NULL},
/* 128F */ { NULL,NULL},
/* 1290 */ { "SYLLABE ÉTHIOPIENNE NÄ",NULL},
/* 1291 */ { "SYLLABE ÉTHIOPIENNE NOU",NULL},
/* 1292 */ { "SYLLABE ÉTHIOPIENNE NI",NULL},
/* 1293 */ { "SYLLABE ÉTHIOPIENNE NA",NULL},
/* 1294 */ { "SYLLABE ÉTHIOPIENNE NÉ",NULL},
/* 1295 */ { "SYLLABE ÉTHIOPIENNE NE",NULL},
/* 1296 */ { "SYLLABE ÉTHIOPIENNE NO",NULL},
/* 1297 */ { "SYLLABE ÉTHIOPIENNE NWA",NULL},
/* 1298 */ { "SYLLABE ÉTHIOPIENNE ÑÄ",NULL},
/* 1299 */ { "SYLLABE ÉTHIOPIENNE ÑOU",NULL},
/* 129A */ { "SYLLABE ÉTHIOPIENNE ÑI",NULL},
/* 129B */ { "SYLLABE ÉTHIOPIENNE ÑA",NULL},
/* 129C */ { "SYLLABE ÉTHIOPIENNE ÑÉ",NULL},
/* 129D */ { "SYLLABE ÉTHIOPIENNE ÑE",NULL},
/* 129E */ { "SYLLABE ÉTHIOPIENNE ÑO",NULL},
/* 129F */ { "SYLLABE ÉTHIOPIENNE ÑWA",NULL},
/* 12A0 */ { "SYLLABE ÉTHIOPIENNE Ä GLOTTAL",NULL},
/* 12A1 */ { "SYLLABE ÉTHIOPIENNE OU GLOTTAL",NULL},
/* 12A2 */ { "SYLLABE ÉTHIOPIENNE I GLOTTAL",NULL},
/* 12A3 */ { "SYLLABE ÉTHIOPIENNE A GLOTTAL",NULL},
/* 12A4 */ { "SYLLABE ÉTHIOPIENNE É GLOTTAL",NULL},
/* 12A5 */ { "SYLLABE ÉTHIOPIENNE E GLOTTAL",NULL},
/* 12A6 */ { "SYLLABE ÉTHIOPIENNE O GLOTTAL",NULL},
/* 12A7 */ { "SYLLABE ÉTHIOPIENNE WA GLOTTAL",NULL},
/* 12A8 */ { "SYLLABE ÉTHIOPIENNE KÄ",NULL},
/* 12A9 */ { "SYLLABE ÉTHIOPIENNE KOU",NULL},
/* 12AA */ { "SYLLABE ÉTHIOPIENNE KI",NULL},
/* 12AB */ { "SYLLABE ÉTHIOPIENNE KA",NULL},
/* 12AC */ { "SYLLABE ÉTHIOPIENNE KÉ",NULL},
/* 12AD */ { "SYLLABE ÉTHIOPIENNE KE",NULL},
/* 12AE */ { "SYLLABE ÉTHIOPIENNE KO",NULL},
/* 12AF */ { "SYLLABE ÉTHIOPIENNE KOÄ",NULL},
/* 12B0 */ { "SYLLABE ÉTHIOPIENNE KWÄ",NULL},
/* 12B1 */ { NULL,NULL},
/* 12B2 */ { "SYLLABE ÉTHIOPIENNE KWI","	x (syllabe éthiopienne gouragé kwi - 1E7F5)"},
/* 12B3 */ { "SYLLABE ÉTHIOPIENNE KWA",NULL},
/* 12B4 */ { "SYLLABE ÉTHIOPIENNE KWÉ","	x (syllabe éthiopienne gouragé kwé - 1E7F6)"},
/* 12B5 */ { "SYLLABE ÉTHIOPIENNE KWE","	x (syllabe éthiopienne gouragé kwe - 1E7F7)"},
/* 12B6 */ { NULL,NULL},
/* 12B7 */ { NULL,NULL},
/* 12B8 */ { "SYLLABE ÉTHIOPIENNE KXÄ",NULL},
/* 12B9 */ { "SYLLABE ÉTHIOPIENNE KXOU",NULL},
/* 12BA */ { "SYLLABE ÉTHIOPIENNE KXI",NULL},
/* 12BB */ { "SYLLABE ÉTHIOPIENNE KXA",NULL},
/* 12BC */ { "SYLLABE ÉTHIOPIENNE KXÉ",NULL},
/* 12BD */ { "SYLLABE ÉTHIOPIENNE KXE",NULL},
/* 12BE */ { "SYLLABE ÉTHIOPIENNE KXO",NULL},
/* 12BF */ { NULL,NULL},
/* 12C0 */ { "SYLLABE ÉTHIOPIENNE KXWÄ","	x (syllabe éthiopienne gouragé hhwä - 1E7E8)"},
/* 12C1 */ { NULL,NULL},
/* 12C2 */ { "SYLLABE ÉTHIOPIENNE KXWI","	x (syllabe éthiopienne hhwi - 1E7E9)"},
/* 12C3 */ { "SYLLABE ÉTHIOPIENNE KXWA",NULL},
/* 12C4 */ { "SYLLABE ÉTHIOPIENNE KXWÉ","	x (syllabe éthiopienne hhwé - 1E7EA)"},
/* 12C5 */ { "SYLLABE ÉTHIOPIENNE KXWE","	x (syllabe éthiopienne hhwe - 1E7EB)"},
/* 12C6 */ { NULL,NULL},
/* 12C7 */ { NULL,NULL},
/* 12C8 */ { "SYLLABE ÉTHIOPIENNE WÄ",NULL},
/* 12C9 */ { "SYLLABE ÉTHIOPIENNE WOU",NULL},
/* 12CA */ { "SYLLABE ÉTHIOPIENNE WI",NULL},
/* 12CB */ { "SYLLABE ÉTHIOPIENNE WA",NULL},
/* 12CC */ { "SYLLABE ÉTHIOPIENNE WÉ",NULL},
/* 12CD */ { "SYLLABE ÉTHIOPIENNE WE",NULL},
/* 12CE */ { "SYLLABE ÉTHIOPIENNE WO",NULL},
/* 12CF */ { "SYLLABE ÉTHIOPIENNE WOÄ",NULL},
/* 12D0 */ { "SYLLABE ÉTHIOPIENNE Ä PHARYNGAL",NULL},
/* 12D1 */ { "SYLLABE ÉTHIOPIENNE OU PHARYNGAL",NULL},
/* 12D2 */ { "SYLLABE ÉTHIOPIENNE I PHARYNGAL",NULL},
/* 12D3 */ { "SYLLABE ÉTHIOPIENNE A PHARYNGAL",NULL},
/* 12D4 */ { "SYLLABE ÉTHIOPIENNE É PHARYNGAL",NULL},
/* 12D5 */ { "SYLLABE ÉTHIOPIENNE E PHARYNGAL",NULL},
/* 12D6 */ { "SYLLABE ÉTHIOPIENNE O PHARYNGAL",NULL},
/* 12D7 */ { NULL,NULL},
/* 12D8 */ { "SYLLABE ÉTHIOPIENNE ZÄ",NULL},
/* 12D9 */ { "SYLLABE ÉTHIOPIENNE ZOU",NULL},
/* 12DA */ { "SYLLABE ÉTHIOPIENNE ZI",NULL},
/* 12DB */ { "SYLLABE ÉTHIOPIENNE ZA",NULL},
/* 12DC */ { "SYLLABE ÉTHIOPIENNE ZÉ",NULL},
/* 12DD */ { "SYLLABE ÉTHIOPIENNE ZE",NULL},
/* 12DE */ { "SYLLABE ÉTHIOPIENNE ZO",NULL},
/* 12DF */ { "SYLLABE ÉTHIOPIENNE ZWA",NULL},
/* 12E0 */ { "SYLLABE ÉTHIOPIENNE JÄ",NULL},
/* 12E1 */ { "SYLLABE ÉTHIOPIENNE JOU",NULL},
/* 12E2 */ { "SYLLABE ÉTHIOPIENNE JI",NULL},
/* 12E3 */ { "SYLLABE ÉTHIOPIENNE JA",NULL},
/* 12E4 */ { "SYLLABE ÉTHIOPIENNE JÉ",NULL},
/* 12E5 */ { "SYLLABE ÉTHIOPIENNE JE",NULL},
/* 12E6 */ { "SYLLABE ÉTHIOPIENNE JO",NULL},
/* 12E7 */ { "SYLLABE ÉTHIOPIENNE JWA",NULL},
/* 12E8 */ { "SYLLABE ÉTHIOPIENNE YÄ",NULL},
/* 12E9 */ { "SYLLABE ÉTHIOPIENNE YOU",NULL},
/* 12EA */ { "SYLLABE ÉTHIOPIENNE YI",NULL},
/* 12EB */ { "SYLLABE ÉTHIOPIENNE YA",NULL},
/* 12EC */ { "SYLLABE ÉTHIOPIENNE YÉ",NULL},
/* 12ED */ { "SYLLABE ÉTHIOPIENNE YE",NULL},
/* 12EE */ { "SYLLABE ÉTHIOPIENNE YO",NULL},
/* 12EF */ { "SYLLABE ÉTHIOPIENNE YOÄ",NULL},
/* 12F0 */ { "SYLLABE ÉTHIOPIENNE DÄ",NULL},
/* 12F1 */ { "SYLLABE ÉTHIOPIENNE DOU",NULL},
/* 12F2 */ { "SYLLABE ÉTHIOPIENNE DI",NULL},
/* 12F3 */ { "SYLLABE ÉTHIOPIENNE DA",NULL},
/* 12F4 */ { "SYLLABE ÉTHIOPIENNE DÉ",NULL},
/* 12F5 */ { "SYLLABE ÉTHIOPIENNE DE",NULL},
/* 12F6 */ { "SYLLABE ÉTHIOPIENNE DO",NULL},
/* 12F7 */ { "SYLLABE ÉTHIOPIENNE DWA",NULL},
/* 12F8 */ { "SYLLABE ÉTHIOPIENNE DDÄ",NULL},
/* 12F9 */ { "SYLLABE ÉTHIOPIENNE DDOU",NULL},
/* 12FA */ { "SYLLABE ÉTHIOPIENNE DDI",NULL},
/* 12FB */ { "SYLLABE ÉTHIOPIENNE DDA",NULL},
/* 12FC */ { "SYLLABE ÉTHIOPIENNE DDÉ",NULL},
/* 12FD */ { "SYLLABE ÉTHIOPIENNE DDE",NULL},
/* 12FE */ { "SYLLABE ÉTHIOPIENNE DDO",NULL},
/* 12FF */ { "SYLLABE ÉTHIOPIENNE DDWA",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_13[] = {
/* 1300 */ { "SYLLABE ÉTHIOPIENNE DJÄ",NULL},
/* 1301 */ { "SYLLABE ÉTHIOPIENNE DJOU",NULL},
/* 1302 */ { "SYLLABE ÉTHIOPIENNE DJI",NULL},
/* 1303 */ { "SYLLABE ÉTHIOPIENNE DJA",NULL},
/* 1304 */ { "SYLLABE ÉTHIOPIENNE DJÉ",NULL},
/* 1305 */ { "SYLLABE ÉTHIOPIENNE DJE",NULL},
/* 1306 */ { "SYLLABE ÉTHIOPIENNE DJO",NULL},
/* 1307 */ { "SYLLABE ÉTHIOPIENNE DJWA",NULL},
/* 1308 */ { "SYLLABE ÉTHIOPIENNE GÄ",NULL},
/* 1309 */ { "SYLLABE ÉTHIOPIENNE GOU",NULL},
/* 130A */ { "SYLLABE ÉTHIOPIENNE GI",NULL},
/* 130B */ { "SYLLABE ÉTHIOPIENNE GA",NULL},
/* 130C */ { "SYLLABE ÉTHIOPIENNE GÉ",NULL},
/* 130D */ { "SYLLABE ÉTHIOPIENNE GE",NULL},
/* 130E */ { "SYLLABE ÉTHIOPIENNE GO",NULL},
/* 130F */ { "SYLLABE ÉTHIOPIENNE GOÄ",NULL},
/* 1310 */ { "SYLLABE ÉTHIOPIENNE GWÄ",NULL},
/* 1311 */ { NULL,NULL},
/* 1312 */ { "SYLLABE ÉTHIOPIENNE GWI","	x (syllabe éthiopienne gouragé gwi - 1E7F8)"},
/* 1313 */ { "SYLLABE ÉTHIOPIENNE GWA",NULL},
/* 1314 */ { "SYLLABE ÉTHIOPIENNE GWÉ","	x (syllabe éthiopienne gouragé gwé - 1E7F9)"},
/* 1315 */ { "SYLLABE ÉTHIOPIENNE GWE","	x (syllabe éthiopienne gouragé gwe - 1E7FA)"},
/* 1316 */ { NULL,NULL},
/* 1317 */ { NULL,NULL},
/* 1318 */ { "SYLLABE ÉTHIOPIENNE GGÄ",NULL},
/* 1319 */ { "SYLLABE ÉTHIOPIENNE GGOU",NULL},
/* 131A */ { "SYLLABE ÉTHIOPIENNE GGI",NULL},
/* 131B */ { "SYLLABE ÉTHIOPIENNE GGA",NULL},
/* 131C */ { "SYLLABE ÉTHIOPIENNE GGÉ",NULL},
/* 131D */ { "SYLLABE ÉTHIOPIENNE GGE",NULL},
/* 131E */ { "SYLLABE ÉTHIOPIENNE GGO",NULL},
/* 131F */ { "SYLLABE ÉTHIOPIENNE GGWA",NULL},
/* 1320 */ { "SYLLABE ÉTHIOPIENNE THÄ",NULL},
/* 1321 */ { "SYLLABE ÉTHIOPIENNE THOU",NULL},
/* 1322 */ { "SYLLABE ÉTHIOPIENNE THI",NULL},
/* 1323 */ { "SYLLABE ÉTHIOPIENNE THA",NULL},
/* 1324 */ { "SYLLABE ÉTHIOPIENNE THÉ",NULL},
/* 1325 */ { "SYLLABE ÉTHIOPIENNE THE",NULL},
/* 1326 */ { "SYLLABE ÉTHIOPIENNE THO",NULL},
/* 1327 */ { "SYLLABE ÉTHIOPIENNE THWA",NULL},
/* 1328 */ { "SYLLABE ÉTHIOPIENNE TTCHÄ",NULL},
/* 1329 */ { "SYLLABE ÉTHIOPIENNE TTCHOU",NULL},
/* 132A */ { "SYLLABE ÉTHIOPIENNE TTCHI",NULL},
/* 132B */ { "SYLLABE ÉTHIOPIENNE TTCHA",NULL},
/* 132C */ { "SYLLABE ÉTHIOPIENNE TTCHÉ",NULL},
/* 132D */ { "SYLLABE ÉTHIOPIENNE TTCHE",NULL},
/* 132E */ { "SYLLABE ÉTHIOPIENNE TTCHO",NULL},
/* 132F */ { "SYLLABE ÉTHIOPIENNE TTCHWA",NULL},
/* 1330 */ { "SYLLABE ÉTHIOPIENNE PHÄ",NULL},
/* 1331 */ { "SYLLABE ÉTHIOPIENNE PHOU",NULL},
/* 1332 */ { "SYLLABE ÉTHIOPIENNE PHI",NULL},
/* 1333 */ { "SYLLABE ÉTHIOPIENNE PHA",NULL},
/* 1334 */ { "SYLLABE ÉTHIOPIENNE PHÉ",NULL},
/* 1335 */ { "SYLLABE ÉTHIOPIENNE PHE",NULL},
/* 1336 */ { "SYLLABE ÉTHIOPIENNE PHO",NULL},
/* 1337 */ { "SYLLABE ÉTHIOPIENNE PHWA",NULL},
/* 1338 */ { "SYLLABE ÉTHIOPIENNE TSÄ",NULL},
/* 1339 */ { "SYLLABE ÉTHIOPIENNE TSOU",NULL},
/* 133A */ { "SYLLABE ÉTHIOPIENNE TSI",NULL},
/* 133B */ { "SYLLABE ÉTHIOPIENNE TSA",NULL},
/* 133C */ { "SYLLABE ÉTHIOPIENNE TSÉ",NULL},
/* 133D */ { "SYLLABE ÉTHIOPIENNE TSE",NULL},
/* 133E */ { "SYLLABE ÉTHIOPIENNE TSO",NULL},
/* 133F */ { "SYLLABE ÉTHIOPIENNE TSWA",NULL},
/* 1340 */ { "SYLLABE ÉTHIOPIENNE TZÄ",NULL},
/* 1341 */ { "SYLLABE ÉTHIOPIENNE TZOU",NULL},
/* 1342 */ { "SYLLABE ÉTHIOPIENNE TZI",NULL},
/* 1343 */ { "SYLLABE ÉTHIOPIENNE TZA",NULL},
/* 1344 */ { "SYLLABE ÉTHIOPIENNE TZÉ",NULL},
/* 1345 */ { "SYLLABE ÉTHIOPIENNE TZE",NULL},
/* 1346 */ { "SYLLABE ÉTHIOPIENNE TZO",NULL},
/* 1347 */ { "SYLLABE ÉTHIOPIENNE TZOÄ",NULL},
/* 1348 */ { "SYLLABE ÉTHIOPIENNE FÄ",NULL},
/* 1349 */ { "SYLLABE ÉTHIOPIENNE FOU",NULL},
/* 134A */ { "SYLLABE ÉTHIOPIENNE FI",NULL},
/* 134B */ { "SYLLABE ÉTHIOPIENNE FA",NULL},
/* 134C */ { "SYLLABE ÉTHIOPIENNE FÉ",NULL},
/* 134D */ { "SYLLABE ÉTHIOPIENNE FE",NULL},
/* 134E */ { "SYLLABE ÉTHIOPIENNE FO",NULL},
/* 134F */ { "SYLLABE ÉTHIOPIENNE FWA",NULL},
/* 1350 */ { "SYLLABE ÉTHIOPIENNE PÄ",NULL},
/* 1351 */ { "SYLLABE ÉTHIOPIENNE POU",NULL},
/* 1352 */ { "SYLLABE ÉTHIOPIENNE PI",NULL},
/* 1353 */ { "SYLLABE ÉTHIOPIENNE PA",NULL},
/* 1354 */ { "SYLLABE ÉTHIOPIENNE PÉ",NULL},
/* 1355 */ { "SYLLABE ÉTHIOPIENNE PE",NULL},
/* 1356 */ { "SYLLABE ÉTHIOPIENNE PO",NULL},
/* 1357 */ { "SYLLABE ÉTHIOPIENNE PWA",NULL},
/* 1358 */ { "SYLLABE ÉTHIOPIENNE RYÄ",NULL},
/* 1359 */ { "SYLLABE ÉTHIOPIENNE MYÄ",NULL},
/* 135A */ { "SYLLABE ÉTHIOPIENNE FYÄ",NULL},
/* 135B */ { NULL,NULL},
/* 135C */ { NULL,NULL},
/* 135D */ { "DIACRITIQUE ÉTHIOPIEN DE GÉMINATION ET DE LONGUEUR DE VOYELLE","	* basketo"},
/* 135E */ { "DIACRITIQUE ÉTHIOPIEN DE LONGUEUR DE VOYELLE","	* basketo"},
/* 135F */ { "DIACRITIQUE ÉTHIOPIEN DE GÉMINATION",NULL},
/* 1360 */ { "REPÈRE DE SECTION ÉTHIOPIEN",NULL},
/* 1361 */ { "ESPACE ÉTHIOPIENNE",NULL},
/* 1362 */ { "POINT ÉTHIOPIEN",NULL},
/* 1363 */ { "VIRGULE ÉTHIOPIENNE",NULL},
/* 1364 */ { "POINT-VIRGULE ÉTHIOPIEN",NULL},
/* 1365 */ { "DEUX-POINTS ÉTHIOPIEN",NULL},
/* 1366 */ { "DEUX-POINTS DE PRÉFACE ÉTHIOPIEN",NULL},
/* 1367 */ { "POINT D'INTERROGATION ÉTHIOPIEN",NULL},
/* 1368 */ { "SÉPARATEUR DE PARAGRAPHES ÉTHIOPIEN",NULL},
/* 1369 */ { "CHIFFRE ÉTHIOPIEN UN",NULL},
/* 136A */ { "CHIFFRE ÉTHIOPIEN DEUX",NULL},
/* 136B */ { "CHIFFRE ÉTHIOPIEN TROIS",NULL},
/* 136C */ { "CHIFFRE ÉTHIOPIEN QUATRE",NULL},
/* 136D */ { "CHIFFRE ÉTHIOPIEN CINQ",NULL},
/* 136E */ { "CHIFFRE ÉTHIOPIEN SIX",NULL},
/* 136F */ { "CHIFFRE ÉTHIOPIEN SEPT",NULL},
/* 1370 */ { "CHIFFRE ÉTHIOPIEN HUIT",NULL},
/* 1371 */ { "CHIFFRE ÉTHIOPIEN NEUF",NULL},
/* 1372 */ { "NOMBRE ÉTHIOPIEN DIX",NULL},
/* 1373 */ { "NOMBRE ÉTHIOPIEN VINGT",NULL},
/* 1374 */ { "NOMBRE ÉTHIOPIEN TRENTE",NULL},
/* 1375 */ { "NOMBRE ÉTHIOPIEN QUARANTE",NULL},
/* 1376 */ { "NOMBRE ÉTHIOPIEN CINQUANTE",NULL},
/* 1377 */ { "NOMBRE ÉTHIOPIEN SOIXANTE",NULL},
/* 1378 */ { "NOMBRE ÉTHIOPIEN SOIXANTE-DIX","	= nombre éthiopien septante"},
/* 1379 */ { "NOMBRE ÉTHIOPIEN QUATRE-VINGTS","	= nombre éthiopien huitante"},
/* 137A */ { "NOMBRE ÉTHIOPIEN QUATRE-VINGT-DIX","	= nombre éthiopien nonante"},
/* 137B */ { "NOMBRE ÉTHIOPIEN CENT",NULL},
/* 137C */ { "NOMBRE ÉTHIOPIEN DIX MILLE",NULL},
/* 137D */ { NULL,NULL},
/* 137E */ { NULL,NULL},
/* 137F */ { NULL,NULL},
/* 1380 */ { "SYLLABE ÉTHIOPIENNE MWÄ",NULL},
/* 1381 */ { "SYLLABE ÉTHIOPIENNE MWI","	x (syllabe éthiopienne gouragé mwi - 1E7ED)"},
/* 1382 */ { "SYLLABE ÉTHIOPIENNE MWÉ","	x (syllabe éthiopienne gouragé mwé - 1E7EE)"},
/* 1383 */ { "SYLLABE ÉTHIOPIENNE MWE",NULL},
/* 1384 */ { "SYLLABE ÉTHIOPIENNE BWÄ",NULL},
/* 1385 */ { "SYLLABE ÉTHIOPIENNE BWI","	x (syllabe éthiopienne gouragé bwi - 1E7F3)"},
/* 1386 */ { "SYLLABE ÉTHIOPIENNE BWÉ","	x (syllabe éthiopienne gouragé bwé - 1E7F4)"},
/* 1387 */ { "SYLLABE ÉTHIOPIENNE BWE",NULL},
/* 1388 */ { "SYLLABE ÉTHIOPIENNE FWÄ",NULL},
/* 1389 */ { "SYLLABE ÉTHIOPIENNE FWI","	x (syllabe éthiopienne gouragé fwi - 1E7FB)"},
/* 138A */ { "SYLLABE ÉTHIOPIENNE FWÉ","	x (syllabe éthiopienne gouragé fwé - 1E7FC)"},
/* 138B */ { "SYLLABE ÉTHIOPIENNE FWE",NULL},
/* 138C */ { "SYLLABE ÉTHIOPIENNE PWÄ",NULL},
/* 138D */ { "SYLLABE ÉTHIOPIENNE PWI","	x (syllabe éthiopienne gouragé pwi - 1E7FD)"},
/* 138E */ { "SYLLABE ÉTHIOPIENNE PWÉ","	x (syllabe éthiopienne gouragé pwé - 1E7FE)"},
/* 138F */ { "SYLLABE ÉTHIOPIENNE PWE",NULL},
/* 1390 */ { "SIGNE DE TON ÉTHIOPIEN YEZÄT","	* pause ou accentuation"},
/* 1391 */ { "SIGNE DE TON ÉTHIOPIEN DÄRÄT","	* la mélodie s'arrête, le ton monte"},
/* 1392 */ { "SIGNE DE TON ÉTHIOPIEN REKREK","	* répétition du son"},
/* 1393 */ { "SIGNE DE TON ÉTHIOPIEN BREF REKREK",NULL},
/* 1394 */ { "SIGNE DE TON ÉTHIOPIEN DEFAT","	* le ton devrait baisser au début de la lettre"},
/* 1395 */ { "SIGNE DE TON ÉTHIOPIEN KENAT","	* soutenir la mélodie, hausser le ton"},
/* 1396 */ { "SIGNE DE TON ÉTHIOPIEN TTCHERÄT","	* la mélodie s'accélère"},
/* 1397 */ { "SIGNE DE TON ÉTHIOPIEN HIDÄT","	* la psalmodie enjambe plusieurs mots"},
/* 1398 */ { "SIGNE DE TON ÉTHIOPIEN DÄRÄT-HIDÄT","	* ton continu montant"},
/* 1399 */ { "SIGNE DE TON ÉTHIOPIEN KOURT","	* tenue du dernier mot et pause"},
/* 139A */ { NULL,NULL},
/* 139B */ { NULL,NULL},
/* 139C */ { NULL,NULL},
/* 139D */ { NULL,NULL},
/* 139E */ { NULL,NULL},
/* 139F */ { NULL,NULL},
/* 13A0 */ { "SYLLABE CHÉROKIE A",NULL},
/* 13A1 */ { "SYLLABE CHÉROKIE É",NULL},
/* 13A2 */ { "SYLLABE CHÉROKIE I",NULL},
/* 13A3 */ { "SYLLABE CHÉROKIE O",NULL},
/* 13A4 */ { "SYLLABE CHÉROKIE OU",NULL},
/* 13A5 */ { "SYLLABE CHÉROKIE ËN","	= syllabe chérokie v\n"
	"	= schwa nasal chérokie"},
/* 13A6 */ { "SYLLABE CHÉROKIE GA",NULL},
/* 13A7 */ { "SYLLABE CHÉROKIE KA",NULL},
/* 13A8 */ { "SYLLABE CHÉROKIE GUÉ",NULL},
/* 13A9 */ { "SYLLABE CHÉROKIE GUI",NULL},
/* 13AA */ { "SYLLABE CHÉROKIE GO",NULL},
/* 13AB */ { "SYLLABE CHÉROKIE GOU",NULL},
/* 13AC */ { "SYLLABE CHÉROKIE GUËN","	= syllabe chérokie gv"},
/* 13AD */ { "SYLLABE CHÉROKIE HA",NULL},
/* 13AE */ { "SYLLABE CHÉROKIE HÉ",NULL},
/* 13AF */ { "SYLLABE CHÉROKIE HI",NULL},
/* 13B0 */ { "SYLLABE CHÉROKIE HO",NULL},
/* 13B1 */ { "SYLLABE CHÉROKIE HOU",NULL},
/* 13B2 */ { "SYLLABE CHÉROKIE HËN","	= syllabe chérokie hv"},
/* 13B3 */ { "SYLLABE CHÉROKIE LA",NULL},
/* 13B4 */ { "SYLLABE CHÉROKIE LÉ",NULL},
/* 13B5 */ { "SYLLABE CHÉROKIE LI",NULL},
/* 13B6 */ { "SYLLABE CHÉROKIE LO",NULL},
/* 13B7 */ { "SYLLABE CHÉROKIE LOU",NULL},
/* 13B8 */ { "SYLLABE CHÉROKIE LËN","	= syllabe chérokie lv"},
/* 13B9 */ { "SYLLABE CHÉROKIE MA",NULL},
/* 13BA */ { "SYLLABE CHÉROKIE MÉ",NULL},
/* 13BB */ { "SYLLABE CHÉROKIE MI",NULL},
/* 13BC */ { "SYLLABE CHÉROKIE MO",NULL},
/* 13BD */ { "SYLLABE CHÉROKIE MOU",NULL},
/* 13BE */ { "SYLLABE CHÉROKIE NA",NULL},
/* 13BF */ { "SYLLABE CHÉROKIE HNA",NULL},
/* 13C0 */ { "SYLLABE CHÉROKIE NAH",NULL},
/* 13C1 */ { "SYLLABE CHÉROKIE NÉ",NULL},
/* 13C2 */ { "SYLLABE CHÉROKIE NI",NULL},
/* 13C3 */ { "SYLLABE CHÉROKIE NO",NULL},
/* 13C4 */ { "SYLLABE CHÉROKIE NOU",NULL},
/* 13C5 */ { "SYLLABE CHÉROKIE NËN","	= syllabe chérokie nv"},
/* 13C6 */ { "SYLLABE CHÉROKIE KWA",NULL},
/* 13C7 */ { "SYLLABE CHÉROKIE KWÉ",NULL},
/* 13C8 */ { "SYLLABE CHÉROKIE KWI",NULL},
/* 13C9 */ { "SYLLABE CHÉROKIE KWO",NULL},
/* 13CA */ { "SYLLABE CHÉROKIE KWOU",NULL},
/* 13CB */ { "SYLLABE CHÉROKIE KWËN","	= syllabe chérokie quv"},
/* 13CC */ { "SYLLABE CHÉROKIE SA",NULL},
/* 13CD */ { "SYLLABE CHÉROKIE S",NULL},
/* 13CE */ { "SYLLABE CHÉROKIE SÉ",NULL},
/* 13CF */ { "SYLLABE CHÉROKIE SI",NULL},
/* 13D0 */ { "SYLLABE CHÉROKIE SO",NULL},
/* 13D1 */ { "SYLLABE CHÉROKIE SOU",NULL},
/* 13D2 */ { "SYLLABE CHÉROKIE SËN","	= syllabe chérokie sv"},
/* 13D3 */ { "SYLLABE CHÉROKIE DA",NULL},
/* 13D4 */ { "SYLLABE CHÉROKIE TA",NULL},
/* 13D5 */ { "SYLLABE CHÉROKIE DÉ",NULL},
/* 13D6 */ { "SYLLABE CHÉROKIE TÉ",NULL},
/* 13D7 */ { "SYLLABE CHÉROKIE DI",NULL},
/* 13D8 */ { "SYLLABE CHÉROKIE TI",NULL},
/* 13D9 */ { "SYLLABE CHÉROKIE DO",NULL},
/* 13DA */ { "SYLLABE CHÉROKIE DOU",NULL},
/* 13DB */ { "SYLLABE CHÉROKIE DËN","	= syllabe chérokie dv"},
/* 13DC */ { "SYLLABE CHÉROKIE DLA",NULL},
/* 13DD */ { "SYLLABE CHÉROKIE TLA",NULL},
/* 13DE */ { "SYLLABE CHÉROKIE TLÉ",NULL},
/* 13DF */ { "SYLLABE CHÉROKIE TLI",NULL},
/* 13E0 */ { "SYLLABE CHÉROKIE TLO",NULL},
/* 13E1 */ { "SYLLABE CHÉROKIE TLOU",NULL},
/* 13E2 */ { "SYLLABE CHÉROKIE TLËN","	= syllabe chérokie tlv"},
/* 13E3 */ { "SYLLABE CHÉROKIE TSA",NULL},
/* 13E4 */ { "SYLLABE CHÉROKIE TSÉ",NULL},
/* 13E5 */ { "SYLLABE CHÉROKIE TSI",NULL},
/* 13E6 */ { "SYLLABE CHÉROKIE TSO",NULL},
/* 13E7 */ { "SYLLABE CHÉROKIE TSOU",NULL},
/* 13E8 */ { "SYLLABE CHÉROKIE TSËN","	= syllabe chérokie tsv"},
/* 13E9 */ { "SYLLABE CHÉROKIE WA",NULL},
/* 13EA */ { "SYLLABE CHÉROKIE WÉ",NULL},
/* 13EB */ { "SYLLABE CHÉROKIE WI",NULL},
/* 13EC */ { "SYLLABE CHÉROKIE WO",NULL},
/* 13ED */ { "SYLLABE CHÉROKIE WOU",NULL},
/* 13EE */ { "SYLLABE CHÉROKIE WËN","	= syllabe chérokie wv"},
/* 13EF */ { "SYLLABE CHÉROKIE YA",NULL},
/* 13F0 */ { "SYLLABE CHÉROKIE YÉ",NULL},
/* 13F1 */ { "SYLLABE CHÉROKIE YI",NULL},
/* 13F2 */ { "SYLLABE CHÉROKIE YO",NULL},
/* 13F3 */ { "SYLLABE CHÉROKIE YOU",NULL},
/* 13F4 */ { "SYLLABE CHÉROKIE YËN","	= syllabe chérokie yv"},
/* 13F5 */ { "SYLLABE CHÉROKIE MËN","	= syllabe chérokie mv"},
/* 13F6 */ { NULL,NULL},
/* 13F7 */ { NULL,NULL},
/* 13F8 */ { "SYLLABE CHÉROKIE MINUSCULE YÉ",NULL},
/* 13F9 */ { "SYLLABE CHÉROKIE MINUSCULE YI",NULL},
/* 13FA */ { "SYLLABE CHÉROKIE MINUSCULE YO",NULL},
/* 13FB */ { "SYLLABE CHÉROKIE MINUSCULE YOU",NULL},
/* 13FC */ { "SYLLABE CHÉROKIE MINUSCULE YËN","	= syllabe chérokie minuscule yv"},
/* 13FD */ { "SYLLABE CHÉROKIE MINUSCULE MËN","	= syllabe chérokie minuscule mv"},
/* 13FE */ { NULL,NULL},
/* 13FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_14[] = {
/* 1400 */ { "TRAIT D'UNION SYLLABE CANADIENNE",NULL},
/* 1401 */ { "SYLLABE CANADIENNE É","	* inuktitut (AÏ), porteur (OU)"},
/* 1402 */ { "SYLLABE CANADIENNE ÂÏ","	* inuktitut"},
/* 1403 */ { "SYLLABE CANADIENNE I","	* porteur (O)"},
/* 1404 */ { "SYLLABE CANADIENNE Î",NULL},
/* 1405 */ { "SYLLABE CANADIENNE O","	* inuktitut (OU), porteur (É)"},
/* 1406 */ { "SYLLABE CANADIENNE Ô","	* inuktitut (OÛ)"},
/* 1407 */ { "SYLLABE CANADIENNE Ô CRI-Y",NULL},
/* 1408 */ { "SYLLABE CANADIENNE É PORTEUR",NULL},
/* 1409 */ { "SYLLABE CANADIENNE I PORTEUR",NULL},
/* 140A */ { "SYLLABE CANADIENNE A",NULL},
/* 140B */ { "SYLLABE CANADIENNE Â",NULL},
/* 140C */ { "SYLLABE CANADIENNE OUÉ",NULL},
/* 140D */ { "SYLLABE CANADIENNE OUÉ CRI DES PLAINES",NULL},
/* 140E */ { "SYLLABE CANADIENNE OUI",NULL},
/* 140F */ { "SYLLABE CANADIENNE OUI CRI DES PLAINES",NULL},
/* 1410 */ { "SYLLABE CANADIENNE OUÎ",NULL},
/* 1411 */ { "SYLLABE CANADIENNE OUÎ CRI DES PLAINES",NULL},
/* 1412 */ { "SYLLABE CANADIENNE OUO",NULL},
/* 1413 */ { "SYLLABE CANADIENNE OUO CRI DES PLAINES",NULL},
/* 1414 */ { "SYLLABE CANADIENNE OUÔ",NULL},
/* 1415 */ { "SYLLABE CANADIENNE OUÔ CRI DES PLAINES",NULL},
/* 1416 */ { "SYLLABE CANADIENNE OUÔ NASKAPI",NULL},
/* 1417 */ { "SYLLABE CANADIENNE OUA",NULL},
/* 1418 */ { "SYLLABE CANADIENNE OUA CRI DES PLAINES",NULL},
/* 1419 */ { "SYLLABE CANADIENNE OUÂ",NULL},
/* 141A */ { "SYLLABE CANADIENNE OUÂ CRI DES PLAINES",NULL},
/* 141B */ { "SYLLABE CANADIENNE OUÂ NASKAPI",NULL},
/* 141C */ { "SYLLABE CANADIENNE AÏ","	* cri oriental"},
/* 141D */ { "SYLLABE CANADIENNE OU CRI-Y",NULL},
/* 141E */ { "SYLLABE CANADIENNE COUP DE GLOTTE","	* cri de Moose (Y), algonquien (COUP DE GLOTTE)"},
/* 141F */ { "SYLLABE CANADIENNE FINALE ACCENT AIGU","	* cri occidental (T), cri oriental (Y), inuktitut (COUP DE GLOTTE)\n"
	"	* athabascan (B/P), sayisi (I), porteur (G)"},
/* 1420 */ { "SYLLABE CANADIENNE FINALE ACCENT GRAVE","	* cri occidental (K), athabascan (K), porteur (KH)"},
/* 1421 */ { "SYLLABE CANADIENNE FINALE DEMI-ROND INFÉRIEUR","	* cri-n (CH), sayisi (R), porteur (NG)"},
/* 1422 */ { "SYLLABE CANADIENNE FINALE DEMI-ROND SUPÉRIEUR","	* algonquien (S), tchipéwayan (R), sayisi (S)"},
/* 1423 */ { "SYLLABE CANADIENNE FINALE DEMI-ROND DROIT","	* cri occidental (N), athabascan (D/T), sayisi (N), porteur (N)"},
/* 1424 */ { "SYLLABE CANADIENNE FINALE ROND","	* cri occidental (OU), sayisi (O)"},
/* 1425 */ { "SYLLABE CANADIENNE FINALE DOUBLE ACCENT AIGU","	* tchipéwayan (TT), esclave du Sud (GH)"},
/* 1426 */ { "SYLLABE CANADIENNE FINALE DEUX TRAITS VERTICAUX COURTS","	* algonquien (H), porteur (R)"},
/* 1427 */ { "SYLLABE CANADIENNE FINALE POINT MÉDIAN","	* cri de Moose (OU), athabascan (Y), sayisi (YOU), pied-noir (S)"},
/* 1428 */ { "SYLLABE CANADIENNE FINALE TRAIT HORIZONTAL COURT","	* cri occidental (C), sayisi (D)"},
/* 1429 */ { "SYLLABE CANADIENNE FINALE SIGNE PLUS","	* athabascan (N), sayisi (AÏ)"},
/* 142A */ { "SYLLABE CANADIENNE FINALE TAQUET VERS LE BAS","	* cri-n (L), porteur (D)\n"
	"	x (taquet vers le bas - 22A4)"},
/* 142B */ { "SYLLABE CANADIENNE ENNE",NULL},
/* 142C */ { "SYLLABE CANADIENNE INNE",NULL},
/* 142D */ { "SYLLABE CANADIENNE ONNE",NULL},
/* 142E */ { "SYLLABE CANADIENNE ANNE",NULL},
/* 142F */ { "SYLLABE CANADIENNE PÉ","	* inuktitut (PAÏ), athabascan (BÉ), porteur (HOU)"},
/* 1430 */ { "SYLLABE CANADIENNE PÂÏ","	* inuktitut"},
/* 1431 */ { "SYLLABE CANADIENNE PI",NULL},
/* 1432 */ { "SYLLABE CANADIENNE PÎ",NULL},
/* 1433 */ { "SYLLABE CANADIENNE PO","	* inuktitut (POU), athabascan (BO), porteur (HÉ)"},
/* 1434 */ { "SYLLABE CANADIENNE PÔ","	* inuktitut (POÛ)"},
/* 1435 */ { "SYLLABE CANADIENNE PÔ CRI-Y",NULL},
/* 1436 */ { "SYLLABE CANADIENNE HÉ PORTEUR",NULL},
/* 1437 */ { "SYLLABE CANADIENNE HI PORTEUR",NULL},
/* 1438 */ { "SYLLABE CANADIENNE PA","	* athabascan (BA), porteur (HA)"},
/* 1439 */ { "SYLLABE CANADIENNE PÂ",NULL},
/* 143A */ { "SYLLABE CANADIENNE POUÉ",NULL},
/* 143B */ { "SYLLABE CANADIENNE POUÉ CRI DES PLAINES",NULL},
/* 143C */ { "SYLLABE CANADIENNE POUI",NULL},
/* 143D */ { "SYLLABE CANADIENNE POUI CRI DES PLAINES",NULL},
/* 143E */ { "SYLLABE CANADIENNE POUÎ",NULL},
/* 143F */ { "SYLLABE CANADIENNE POUÎ CRI DES PLAINES",NULL},
/* 1440 */ { "SYLLABE CANADIENNE POUO",NULL},
/* 1441 */ { "SYLLABE CANADIENNE POUO CRI DES PLAINES",NULL},
/* 1442 */ { "SYLLABE CANADIENNE POUÔ",NULL},
/* 1443 */ { "SYLLABE CANADIENNE POUÔ CRI DES PLAINES",NULL},
/* 1444 */ { "SYLLABE CANADIENNE POUA",NULL},
/* 1445 */ { "SYLLABE CANADIENNE POUA CRI DES PLAINES",NULL},
/* 1446 */ { "SYLLABE CANADIENNE POUÂ",NULL},
/* 1447 */ { "SYLLABE CANADIENNE POUÂ CRI DES PLAINES",NULL},
/* 1448 */ { "SYLLABE CANADIENNE POUÂ CRI-Y",NULL},
/* 1449 */ { "SYLLABE CANADIENNE P","	* pied-noir (Y)"},
/* 144A */ { "SYLLABE CANADIENNE P CRI DES PLAINES","	* sayisi (G)"},
/* 144B */ { "SYLLABE CANADIENNE H PORTEUR",NULL},
/* 144C */ { "SYLLABE CANADIENNE TÉ","	* inuktitut (TAÏ), athabascan (DI), porteur (DOU)"},
/* 144D */ { "SYLLABE CANADIENNE TÂÏ","	* inuktitut"},
/* 144E */ { "SYLLABE CANADIENNE TI","	* athabascan (DÉ), porteur (DO)"},
/* 144F */ { "SYLLABE CANADIENNE TÎ",NULL},
/* 1450 */ { "SYLLABE CANADIENNE TO","	* inuktitut (TOU), athabascan (DO), porteur (DÉ), sayisi (DOU)"},
/* 1451 */ { "SYLLABE CANADIENNE TÔ","	* inuktitut (TOÛ)"},
/* 1452 */ { "SYLLABE CANADIENNE TÔ CRI-Y",NULL},
/* 1453 */ { "SYLLABE CANADIENNE DÉ PORTEUR",NULL},
/* 1454 */ { "SYLLABE CANADIENNE DI PORTEUR",NULL},
/* 1455 */ { "SYLLABE CANADIENNE TA","	* athabascan (DA)"},
/* 1456 */ { "SYLLABE CANADIENNE TÂ",NULL},
/* 1457 */ { "SYLLABE CANADIENNE TOUÉ",NULL},
/* 1458 */ { "SYLLABE CANADIENNE TOUÉ CRI DES PLAINES",NULL},
/* 1459 */ { "SYLLABE CANADIENNE TOUI",NULL},
/* 145A */ { "SYLLABE CANADIENNE TOUI CRI DES PLAINES",NULL},
/* 145B */ { "SYLLABE CANADIENNE TOUÎ",NULL},
/* 145C */ { "SYLLABE CANADIENNE TOUÎ CRI DES PLAINES",NULL},
/* 145D */ { "SYLLABE CANADIENNE TOUO",NULL},
/* 145E */ { "SYLLABE CANADIENNE TOUO CRI DES PLAINES",NULL},
/* 145F */ { "SYLLABE CANADIENNE TOUÔ",NULL},
/* 1460 */ { "SYLLABE CANADIENNE TOUÔ CRI DES PLAINES",NULL},
/* 1461 */ { "SYLLABE CANADIENNE TOUA",NULL},
/* 1462 */ { "SYLLABE CANADIENNE TOUA CRI DES PLAINES",NULL},
/* 1463 */ { "SYLLABE CANADIENNE TOUÂ",NULL},
/* 1464 */ { "SYLLABE CANADIENNE TOUÂ CRI DES PLAINES",NULL},
/* 1465 */ { "SYLLABE CANADIENNE TOUÂ NASKAPI",NULL},
/* 1466 */ { "SYLLABE CANADIENNE T",NULL},
/* 1467 */ { "SYLLABE CANADIENNE TTÉ","	* esclave du Sud (DEH)"},
/* 1468 */ { "SYLLABE CANADIENNE TTI","	* esclave du Sud (DIH)"},
/* 1469 */ { "SYLLABE CANADIENNE TTO","	* esclave du Sud (DOH)"},
/* 146A */ { "SYLLABE CANADIENNE TTA","	* esclave du Sud (DAH)"},
/* 146B */ { "SYLLABE CANADIENNE KÉ","	* inuktitut (KAÏ), pied-noir (PA)"},
/* 146C */ { "SYLLABE CANADIENNE KÂÏ","	* inuktitut"},
/* 146D */ { "SYLLABE CANADIENNE KI","	* pied-noir (PÉ)"},
/* 146E */ { "SYLLABE CANADIENNE KÎ",NULL},
/* 146F */ { "SYLLABE CANADIENNE KO","	* inuktitut (KOU), sayisi (KOU), pied-noir (PI)"},
/* 1470 */ { "SYLLABE CANADIENNE KÔ","	* inuktitut (KOÛ)"},
/* 1471 */ { "SYLLABE CANADIENNE KÔ CRI-Y",NULL},
/* 1472 */ { "SYLLABE CANADIENNE KA","	* pied-noir (PO)"},
/* 1473 */ { "SYLLABE CANADIENNE KÂ",NULL},
/* 1474 */ { "SYLLABE CANADIENNE KOUÉ",NULL},
/* 1475 */ { "SYLLABE CANADIENNE KOUÉ CRI DES PLAINES",NULL},
/* 1476 */ { "SYLLABE CANADIENNE KOUI",NULL},
/* 1477 */ { "SYLLABE CANADIENNE KOUI CRI DES PLAINES",NULL},
/* 1478 */ { "SYLLABE CANADIENNE KOUÎ",NULL},
/* 1479 */ { "SYLLABE CANADIENNE KOUÎ CRI DES PLAINES",NULL},
/* 147A */ { "SYLLABE CANADIENNE KOUO",NULL},
/* 147B */ { "SYLLABE CANADIENNE KOUO CRI DES PLAINES",NULL},
/* 147C */ { "SYLLABE CANADIENNE KOUÔ",NULL},
/* 147D */ { "SYLLABE CANADIENNE KOUÔ CRI DES PLAINES",NULL},
/* 147E */ { "SYLLABE CANADIENNE KOUA",NULL},
/* 147F */ { "SYLLABE CANADIENNE KOUA CRI DES PLAINES",NULL},
/* 1480 */ { "SYLLABE CANADIENNE KOUÂ",NULL},
/* 1481 */ { "SYLLABE CANADIENNE KOUÂ CRI DES PLAINES",NULL},
/* 1482 */ { "SYLLABE CANADIENNE KOUÂ NASKAPI",NULL},
/* 1483 */ { "SYLLABE CANADIENNE K",NULL},
/* 1484 */ { "SYLLABE CANADIENNE KOU","	* cri oriental"},
/* 1485 */ { "SYLLABE CANADIENNE KÉH ESCLAVE DU SUD",NULL},
/* 1486 */ { "SYLLABE CANADIENNE KIH ESCLAVE DU SUD",NULL},
/* 1487 */ { "SYLLABE CANADIENNE KOH ESCLAVE DU SUD",NULL},
/* 1488 */ { "SYLLABE CANADIENNE KAH ESCLAVE DU SUD",NULL},
/* 1489 */ { "SYLLABE CANADIENNE TCHÉ","	* inuktitut (GAÏ), athabascan (DHE), sayisi (THE), pied-noir (MA)"},
/* 148A */ { "SYLLABE CANADIENNE TCHÂÏ","	* inuktitut (GÂÏ)"},
/* 148B */ { "SYLLABE CANADIENNE TCHI","	* inuktitut (GI), athabascan (DHI), sayisi (THI), pied-noir (MÉ)"},
/* 148C */ { "SYLLABE CANADIENNE TCHÎ","	* inuktitut (GÎ)"},
/* 148D */ { "SYLLABE CANADIENNE TCHO","	* inuktitut (GOU), athabascan (DHO), sayisi (tho), pied-noir (mi)"},
/* 148E */ { "SYLLABE CANADIENNE TCHÔ","	* inuktitut (GOÛ)"},
/* 148F */ { "SYLLABE CANADIENNE TCHÔ CRI-Y",NULL},
/* 1490 */ { "SYLLABE CANADIENNE TCHA","	* inuktitut (GA), athabascan (DHA), sayisi (THA), pied-noir (MO)"},
/* 1491 */ { "SYLLABE CANADIENNE TCHÂ","	* inuktitut (GÂ)"},
/* 1492 */ { "SYLLABE CANADIENNE TCHOUÉ",NULL},
/* 1493 */ { "SYLLABE CANADIENNE TCHOUÉ CRI DES PLAINES",NULL},
/* 1494 */ { "SYLLABE CANADIENNE TCHOUI",NULL},
/* 1495 */ { "SYLLABE CANADIENNE TCHOUI CRI DES PLAINES",NULL},
/* 1496 */ { "SYLLABE CANADIENNE TCHOUÎ",NULL},
/* 1497 */ { "SYLLABE CANADIENNE TCHOUÎ CRI DES PLAINES",NULL},
/* 1498 */ { "SYLLABE CANADIENNE TCHOUO",NULL},
/* 1499 */ { "SYLLABE CANADIENNE TCHOUO CRI DES PLAINES",NULL},
/* 149A */ { "SYLLABE CANADIENNE TCHOUÔ",NULL},
/* 149B */ { "SYLLABE CANADIENNE TCHOUÔ CRI DES PLAINES",NULL},
/* 149C */ { "SYLLABE CANADIENNE TCHOUA",NULL},
/* 149D */ { "SYLLABE CANADIENNE TCHOUA CRI DES PLAINES",NULL},
/* 149E */ { "SYLLABE CANADIENNE TCHOUÂ",NULL},
/* 149F */ { "SYLLABE CANADIENNE TCHOUÂ CRI DES PLAINES",NULL},
/* 14A0 */ { "SYLLABE CANADIENNE TCHOUÂ NASKAPI",NULL},
/* 14A1 */ { "SYLLABE CANADIENNE TCH","	* inuktitut (G), sayisi (T)"},
/* 14A2 */ { "SYLLABE CANADIENNE TH SAYISI","	* athabascan (DH)"},
/* 14A3 */ { "SYLLABE CANADIENNE MÉ","	* inuktitut (MAÏ), pied-noir (TA)"},
/* 14A4 */ { "SYLLABE CANADIENNE MÂÏ","	* inuktitut"},
/* 14A5 */ { "SYLLABE CANADIENNE MI","	* pied-noir (TÉ)"},
/* 14A6 */ { "SYLLABE CANADIENNE MÎ",NULL},
/* 14A7 */ { "SYLLABE CANADIENNE MO","	* inuktitut (MOU), sayisi (MOU), pied-noir (TI)"},
/* 14A8 */ { "SYLLABE CANADIENNE MÔ","	* inuktitut (MOÛ)"},
/* 14A9 */ { "SYLLABE CANADIENNE MÔ CRI-Y",NULL},
/* 14AA */ { "SYLLABE CANADIENNE MA","	* pied-noir (TO)"},
/* 14AB */ { "SYLLABE CANADIENNE MÂ",NULL},
/* 14AC */ { "SYLLABE CANADIENNE MOUÉ",NULL},
/* 14AD */ { "SYLLABE CANADIENNE MOUÉ CRI DES PLAINES",NULL},
/* 14AE */ { "SYLLABE CANADIENNE MOUI",NULL},
/* 14AF */ { "SYLLABE CANADIENNE MOUI CRI DES PLAINES",NULL},
/* 14B0 */ { "SYLLABE CANADIENNE MOUÎ",NULL},
/* 14B1 */ { "SYLLABE CANADIENNE MOUÎ CRI DES PLAINES",NULL},
/* 14B2 */ { "SYLLABE CANADIENNE MOUO",NULL},
/* 14B3 */ { "SYLLABE CANADIENNE MOUO CRI DES PLAINES",NULL},
/* 14B4 */ { "SYLLABE CANADIENNE MOUÔ",NULL},
/* 14B5 */ { "SYLLABE CANADIENNE MOUÔ CRI DES PLAINES",NULL},
/* 14B6 */ { "SYLLABE CANADIENNE MOUA",NULL},
/* 14B7 */ { "SYLLABE CANADIENNE MOUA CRI DES PLAINES",NULL},
/* 14B8 */ { "SYLLABE CANADIENNE MOUÂ",NULL},
/* 14B9 */ { "SYLLABE CANADIENNE MOUÂ CRI DES PLAINES",NULL},
/* 14BA */ { "SYLLABE CANADIENNE MOUÂ NASKAPI",NULL},
/* 14BB */ { "SYLLABE CANADIENNE M",NULL},
/* 14BC */ { "SYLLABE CANADIENNE M CRI DES PLAINES","	* porteur (M)"},
/* 14BD */ { "SYLLABE CANADIENNE MH",NULL},
/* 14BE */ { "SYLLABE CANADIENNE M ATHABASCAN",NULL},
/* 14BF */ { "SYLLABE CANADIENNE M SAYISI",NULL},
/* 14C0 */ { "SYLLABE CANADIENNE NÉ","	* inuktitut (NAÏ)"},
/* 14C1 */ { "SYLLABE CANADIENNE NÂÏ","	* inuktitut"},
/* 14C2 */ { "SYLLABE CANADIENNE NI",NULL},
/* 14C3 */ { "SYLLABE CANADIENNE NÎ",NULL},
/* 14C4 */ { "SYLLABE CANADIENNE NO","	* inuktitut (NOU), sayisi (NOU)"},
/* 14C5 */ { "SYLLABE CANADIENNE NÔ","	* inuktitut (NOÛ)"},
/* 14C6 */ { "SYLLABE CANADIENNE NÔ CRI-Y",NULL},
/* 14C7 */ { "SYLLABE CANADIENNE NA",NULL},
/* 14C8 */ { "SYLLABE CANADIENNE NÂ",NULL},
/* 14C9 */ { "SYLLABE CANADIENNE NOUÉ",NULL},
/* 14CA */ { "SYLLABE CANADIENNE NOUÉ CRI DES PLAINES",NULL},
/* 14CB */ { "SYLLABE CANADIENNE NOUA",NULL},
/* 14CC */ { "SYLLABE CANADIENNE NOUA CRI DES PLAINES",NULL},
/* 14CD */ { "SYLLABE CANADIENNE NOUÂ",NULL},
/* 14CE */ { "SYLLABE CANADIENNE NOUÂ CRI DES PLAINES",NULL},
/* 14CF */ { "SYLLABE CANADIENNE NOUÂ NASKAPI",NULL},
/* 14D0 */ { "SYLLABE CANADIENNE N",NULL},
/* 14D1 */ { "SYLLABE CANADIENNE NG PORTEUR",NULL},
/* 14D2 */ { "SYLLABE CANADIENNE NH",NULL},
/* 14D3 */ { "SYLLABE CANADIENNE LÉ","	* inuktitut (LAÏ)"},
/* 14D4 */ { "SYLLABE CANADIENNE LÂÏ","	* inuktitut"},
/* 14D5 */ { "SYLLABE CANADIENNE LI",NULL},
/* 14D6 */ { "SYLLABE CANADIENNE LÎ",NULL},
/* 14D7 */ { "SYLLABE CANADIENNE LO","	* inuktitut (LOU)"},
/* 14D8 */ { "SYLLABE CANADIENNE LÔ","	* inuktitut (LOÛ)"},
/* 14D9 */ { "SYLLABE CANADIENNE LÔ CRI-Y",NULL},
/* 14DA */ { "SYLLABE CANADIENNE LA",NULL},
/* 14DB */ { "SYLLABE CANADIENNE LÂ",NULL},
/* 14DC */ { "SYLLABE CANADIENNE LOUÉ",NULL},
/* 14DD */ { "SYLLABE CANADIENNE LOUÉ CRI DES PLAINES",NULL},
/* 14DE */ { "SYLLABE CANADIENNE LOUI",NULL},
/* 14DF */ { "SYLLABE CANADIENNE LOUI CRI DES PLAINES",NULL},
/* 14E0 */ { "SYLLABE CANADIENNE LOUÎ",NULL},
/* 14E1 */ { "SYLLABE CANADIENNE LOUÎ CRI DES PLAINES",NULL},
/* 14E2 */ { "SYLLABE CANADIENNE LOUO",NULL},
/* 14E3 */ { "SYLLABE CANADIENNE LOUO CRI DES PLAINES",NULL},
/* 14E4 */ { "SYLLABE CANADIENNE LOUÔ",NULL},
/* 14E5 */ { "SYLLABE CANADIENNE LOUÔ CRI DES PLAINES",NULL},
/* 14E6 */ { "SYLLABE CANADIENNE LOUA",NULL},
/* 14E7 */ { "SYLLABE CANADIENNE LOUA CRI DES PLAINES",NULL},
/* 14E8 */ { "SYLLABE CANADIENNE LOUÂ",NULL},
/* 14E9 */ { "SYLLABE CANADIENNE LOUÂ CRI DES PLAINES",NULL},
/* 14EA */ { "SYLLABE CANADIENNE L",NULL},
/* 14EB */ { "SYLLABE CANADIENNE L CRI DES PLAINES",NULL},
/* 14EC */ { "SYLLABE CANADIENNE L MÉDIAL",NULL},
/* 14ED */ { "SYLLABE CANADIENNE SÉ","	* inuktitut (SAÏ), pied-noir (SA)"},
/* 14EE */ { "SYLLABE CANADIENNE SÂÏ","	* inuktitut"},
/* 14EF */ { "SYLLABE CANADIENNE SI","	* pied-noir (SÉ)"},
/* 14F0 */ { "SYLLABE CANADIENNE SÎ",NULL},
/* 14F1 */ { "SYLLABE CANADIENNE SO","	* inuktitut (SOU), sayisi (SOU), pied-noir (SI)"},
/* 14F2 */ { "SYLLABE CANADIENNE SÔ","	* inuktitut (SOÛ)"},
/* 14F3 */ { "SYLLABE CANADIENNE SÔ CRI-Y",NULL},
/* 14F4 */ { "SYLLABE CANADIENNE SA","	* pied-noir (SO)"},
/* 14F5 */ { "SYLLABE CANADIENNE SÂ",NULL},
/* 14F6 */ { "SYLLABE CANADIENNE SOUÉ",NULL},
/* 14F7 */ { "SYLLABE CANADIENNE SOUÉ CRI DES PLAINES",NULL},
/* 14F8 */ { "SYLLABE CANADIENNE SOUI",NULL},
/* 14F9 */ { "SYLLABE CANADIENNE SOUI CRI DES PLAINES",NULL},
/* 14FA */ { "SYLLABE CANADIENNE SOUÎ",NULL},
/* 14FB */ { "SYLLABE CANADIENNE SOUÎ CRI DES PLAINES",NULL},
/* 14FC */ { "SYLLABE CANADIENNE SOUO",NULL},
/* 14FD */ { "SYLLABE CANADIENNE SOUO CRI DES PLAINES",NULL},
/* 14FE */ { "SYLLABE CANADIENNE SOUÔ",NULL},
/* 14FF */ { "SYLLABE CANADIENNE SOUÔ CRI DES PLAINES",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_15[] = {
/* 1500 */ { "SYLLABE CANADIENNE SOUA",NULL},
/* 1501 */ { "SYLLABE CANADIENNE SOUA CRI DES PLAINES",NULL},
/* 1502 */ { "SYLLABE CANADIENNE SOUÂ",NULL},
/* 1503 */ { "SYLLABE CANADIENNE SOUÂ CRI DES PLAINES",NULL},
/* 1504 */ { "SYLLABE CANADIENNE SOUÂ NASKAPI",NULL},
/* 1505 */ { "SYLLABE CANADIENNE S",NULL},
/* 1506 */ { "SYLLABE CANADIENNE S ATHABASCAN",NULL},
/* 1507 */ { "SYLLABE CANADIENNE SOU",NULL},
/* 1508 */ { "SYLLABE CANADIENNE S PIED-NOIR",NULL},
/* 1509 */ { "SYLLABE CANADIENNE SK CRI DE MOOSE",NULL},
/* 150A */ { "SYLLABE CANADIENNE SKOU NASKAPI",NULL},
/* 150B */ { "SYLLABE CANADIENNE S-OU NASKAPI",NULL},
/* 150C */ { "SYLLABE CANADIENNE SPOUA NASKAPI",NULL},
/* 150D */ { "SYLLABE CANADIENNE STOUA NASKAPI",NULL},
/* 150E */ { "SYLLABE CANADIENNE SKOUA NASKAPI",NULL},
/* 150F */ { "SYLLABE CANADIENNE STCHOUA NASKAPI",NULL},
/* 1510 */ { "SYLLABE CANADIENNE CHÉ",NULL},
/* 1511 */ { "SYLLABE CANADIENNE CHI",NULL},
/* 1512 */ { "SYLLABE CANADIENNE CHÎ",NULL},
/* 1513 */ { "SYLLABE CANADIENNE CHO",NULL},
/* 1514 */ { "SYLLABE CANADIENNE CHÔ",NULL},
/* 1515 */ { "SYLLABE CANADIENNE CHA",NULL},
/* 1516 */ { "SYLLABE CANADIENNE CHÂ",NULL},
/* 1517 */ { "SYLLABE CANADIENNE CHOUÉ",NULL},
/* 1518 */ { "SYLLABE CANADIENNE CHOUÉ CRI DES PLAINES",NULL},
/* 1519 */ { "SYLLABE CANADIENNE CHOUI",NULL},
/* 151A */ { "SYLLABE CANADIENNE CHOUI CRI DES PLAINES",NULL},
/* 151B */ { "SYLLABE CANADIENNE CHOUÎ",NULL},
/* 151C */ { "SYLLABE CANADIENNE CHOUÎ CRI DES PLAINES",NULL},
/* 151D */ { "SYLLABE CANADIENNE CHOUO",NULL},
/* 151E */ { "SYLLABE CANADIENNE CHOUO CRI DES PLAINES",NULL},
/* 151F */ { "SYLLABE CANADIENNE CHOUÔ",NULL},
/* 1520 */ { "SYLLABE CANADIENNE CHOUÔ CRI DES PLAINES",NULL},
/* 1521 */ { "SYLLABE CANADIENNE CHOUA",NULL},
/* 1522 */ { "SYLLABE CANADIENNE CHOUA CRI DES PLAINES",NULL},
/* 1523 */ { "SYLLABE CANADIENNE CHOUÂ",NULL},
/* 1524 */ { "SYLLABE CANADIENNE CHOUÂ CRI DES PLAINES",NULL},
/* 1525 */ { "SYLLABE CANADIENNE CH",NULL},
/* 1526 */ { "SYLLABE CANADIENNE YÉ","	* inuktitut (yaï), pied-noir (YA)"},
/* 1527 */ { "SYLLABE CANADIENNE YÂÏ","	* inuktitut"},
/* 1528 */ { "SYLLABE CANADIENNE YI","	* pied-noir (YÉ)"},
/* 1529 */ { "SYLLABE CANADIENNE YÎ",NULL},
/* 152A */ { "SYLLABE CANADIENNE YO","	* inuktitut (you), pied-noir (YI)"},
/* 152B */ { "SYLLABE CANADIENNE YÔ","	* inuktitut (YOÛ)"},
/* 152C */ { "SYLLABE CANADIENNE YÔ CRI-Y",NULL},
/* 152D */ { "SYLLABE CANADIENNE YA","	* pied-noir (YO)"},
/* 152E */ { "SYLLABE CANADIENNE YÂ",NULL},
/* 152F */ { "SYLLABE CANADIENNE YOUÉ",NULL},
/* 1530 */ { "SYLLABE CANADIENNE YOUÉ CRI DES PLAINES",NULL},
/* 1531 */ { "SYLLABE CANADIENNE YOUI",NULL},
/* 1532 */ { "SYLLABE CANADIENNE YOUI CRI DES PLAINES",NULL},
/* 1533 */ { "SYLLABE CANADIENNE YOUÎ",NULL},
/* 1534 */ { "SYLLABE CANADIENNE YOUÎ CRI DES PLAINES",NULL},
/* 1535 */ { "SYLLABE CANADIENNE YOUO",NULL},
/* 1536 */ { "SYLLABE CANADIENNE YOUO CRI DES PLAINES",NULL},
/* 1537 */ { "SYLLABE CANADIENNE YOUÔ",NULL},
/* 1538 */ { "SYLLABE CANADIENNE YOUÔ CRI DES PLAINES",NULL},
/* 1539 */ { "SYLLABE CANADIENNE YOUA",NULL},
/* 153A */ { "SYLLABE CANADIENNE YOUA CRI DES PLAINES",NULL},
/* 153B */ { "SYLLABE CANADIENNE YOUÂ",NULL},
/* 153C */ { "SYLLABE CANADIENNE YOUÂ CRI DES PLAINES",NULL},
/* 153D */ { "SYLLABE CANADIENNE YOUÂ NASKAPI",NULL},
/* 153E */ { "SYLLABE CANADIENNE Y",NULL},
/* 153F */ { "SYLLABE CANADIENNE Y CRI BIBLIQUE",NULL},
/* 1540 */ { "SYLLABE CANADIENNE Y CRI DES PLAINES",NULL},
/* 1541 */ { "SYLLABE CANADIENNE YI SAYISI",NULL},
/* 1542 */ { "SYLLABE CANADIENNE RÉ","	* inuktitut (RAÏ)"},
/* 1543 */ { "SYLLABE CANADIENNE RÉ CRI-R","	* athabascan (LÉ)"},
/* 1544 */ { "SYLLABE CANADIENNE LÉ CRI DES PLAINES","	* athabascan (LI)"},
/* 1545 */ { "SYLLABE CANADIENNE RÂÏ","	* inuktitut"},
/* 1546 */ { "SYLLABE CANADIENNE RI",NULL},
/* 1547 */ { "SYLLABE CANADIENNE RÎ",NULL},
/* 1548 */ { "SYLLABE CANADIENNE RO","	* inuktitut (ROU)"},
/* 1549 */ { "SYLLABE CANADIENNE RÔ","	* inuktitut (ROÛ)"},
/* 154A */ { "SYLLABE CANADIENNE LO CRI DES PLAINES","	* sayisi (LOU)"},
/* 154B */ { "SYLLABE CANADIENNE RA",NULL},
/* 154C */ { "SYLLABE CANADIENNE RÂ",NULL},
/* 154D */ { "SYLLABE CANADIENNE LA CRI DES PLAINES",NULL},
/* 154E */ { "SYLLABE CANADIENNE ROUÂ",NULL},
/* 154F */ { "SYLLABE CANADIENNE ROUÂ CRI DES PLAINES",NULL},
/* 1550 */ { "SYLLABE CANADIENNE R",NULL},
/* 1551 */ { "SYLLABE CANADIENNE R CRI DES PLAINES",NULL},
/* 1552 */ { "SYLLABE CANADIENNE R MÉDIAL",NULL},
/* 1553 */ { "SYLLABE CANADIENNE FÉ","	* inuktitut (FAÏ)"},
/* 1554 */ { "SYLLABE CANADIENNE FÂÏ","	* inuktitut"},
/* 1555 */ { "SYLLABE CANADIENNE FI",NULL},
/* 1556 */ { "SYLLABE CANADIENNE FÎ",NULL},
/* 1557 */ { "SYLLABE CANADIENNE FO",NULL},
/* 1558 */ { "SYLLABE CANADIENNE FÔ",NULL},
/* 1559 */ { "SYLLABE CANADIENNE FA",NULL},
/* 155A */ { "SYLLABE CANADIENNE FÂ",NULL},
/* 155B */ { "SYLLABE CANADIENNE FOUÂ",NULL},
/* 155C */ { "SYLLABE CANADIENNE FOUÂ CRI DES PLAINES",NULL},
/* 155D */ { "SYLLABE CANADIENNE F",NULL},
/* 155E */ { "SYLLABE CANADIENNE THÉ","	* sayisi (TÉ)"},
/* 155F */ { "SYLLABE CANADIENNE THÉ CRI-N",NULL},
/* 1560 */ { "SYLLABE CANADIENNE THI","	* sayisi (TI)"},
/* 1561 */ { "SYLLABE CANADIENNE THI CRI-N",NULL},
/* 1562 */ { "SYLLABE CANADIENNE THÎ",NULL},
/* 1563 */ { "SYLLABE CANADIENNE THÎ CRI-N",NULL},
/* 1564 */ { "SYLLABE CANADIENNE THO","	* sayisi (TOU)"},
/* 1565 */ { "SYLLABE CANADIENNE THÔ",NULL},
/* 1566 */ { "SYLLABE CANADIENNE THA","	* sayisi (TA)"},
/* 1567 */ { "SYLLABE CANADIENNE THÂ",NULL},
/* 1568 */ { "SYLLABE CANADIENNE THOUÂ",NULL},
/* 1569 */ { "SYLLABE CANADIENNE THOUÂ CRI DES PLAINES",NULL},
/* 156A */ { "SYLLABE CANADIENNE TH",NULL},
/* 156B */ { "SYLLABE CANADIENNE TTHÉ",NULL},
/* 156C */ { "SYLLABE CANADIENNE TTHI",NULL},
/* 156D */ { "SYLLABE CANADIENNE TTHO","	* sayisi (TTHOU)"},
/* 156E */ { "SYLLABE CANADIENNE TTHA",NULL},
/* 156F */ { "SYLLABE CANADIENNE ASTÉRISQUE","	* le nom formel de ce caractère en anglais est erroné\n"
	"	x (astérisque - 002A)"},
/* 1570 */ { "SYLLABE CANADIENNE TYÉ",NULL},
/* 1571 */ { "SYLLABE CANADIENNE TYI",NULL},
/* 1572 */ { "SYLLABE CANADIENNE TYO",NULL},
/* 1573 */ { "SYLLABE CANADIENNE TYA",NULL},
/* 1574 */ { "SYLLABE CANADIENNE HÉ DU NUNAVIK",NULL},
/* 1575 */ { "SYLLABE CANADIENNE HI DU NUNAVIK",NULL},
/* 1576 */ { "SYLLABE CANADIENNE HÎ DU NUNAVIK",NULL},
/* 1577 */ { "SYLLABE CANADIENNE HO DU NUNAVIK",NULL},
/* 1578 */ { "SYLLABE CANADIENNE HÔ DU NUNAVIK",NULL},
/* 1579 */ { "SYLLABE CANADIENNE HA DU NUNAVIK",NULL},
/* 157A */ { "SYLLABE CANADIENNE HÂ DU NUNAVIK",NULL},
/* 157B */ { "SYLLABE CANADIENNE H DU NUNAVIK",NULL},
/* 157C */ { "SYLLABE CANADIENNE H DU NUNAVUT",NULL},
/* 157D */ { "SYLLABE CANADIENNE HK","	* algonquien"},
/* 157E */ { "SYLLABE CANADIENNE QÂÏ","	* inuktitut"},
/* 157F */ { "SYLLABE CANADIENNE QI",NULL},
/* 1580 */ { "SYLLABE CANADIENNE QÎ",NULL},
/* 1581 */ { "SYLLABE CANADIENNE QO","	* inuktitut (QOU)"},
/* 1582 */ { "SYLLABE CANADIENNE QÔ","	* inuktitut (QOÛ)"},
/* 1583 */ { "SYLLABE CANADIENNE QA",NULL},
/* 1584 */ { "SYLLABE CANADIENNE QÂ",NULL},
/* 1585 */ { "SYLLABE CANADIENNE Q",NULL},
/* 1586 */ { "SYLLABE CANADIENNE TLHÉ","	* sayisi (KLÉ)"},
/* 1587 */ { "SYLLABE CANADIENNE TLHI","	* sayisi (KLI)"},
/* 1588 */ { "SYLLABE CANADIENNE TLHO","	* sayisi (KLOU)"},
/* 1589 */ { "SYLLABE CANADIENNE TLHA","	* sayisi (KLA)"},
/* 158A */ { "SYLLABE CANADIENNE RÉ CRI DES PLAINES",NULL},
/* 158B */ { "SYLLABE CANADIENNE RI CRI DES PLAINES",NULL},
/* 158C */ { "SYLLABE CANADIENNE RO CRI DES PLAINES",NULL},
/* 158D */ { "SYLLABE CANADIENNE RA CRI DES PLAINES",NULL},
/* 158E */ { "SYLLABE CANADIENNE NGÂÏ","	* inuktitut"},
/* 158F */ { "SYLLABE CANADIENNE NGI",NULL},
/* 1590 */ { "SYLLABE CANADIENNE NGÎ",NULL},
/* 1591 */ { "SYLLABE CANADIENNE NGO","	* inuktitut (NGOU)"},
/* 1592 */ { "SYLLABE CANADIENNE NGÔ","	* inuktitut (NGOÛ)"},
/* 1593 */ { "SYLLABE CANADIENNE NGA",NULL},
/* 1594 */ { "SYLLABE CANADIENNE NGÂ",NULL},
/* 1595 */ { "SYLLABE CANADIENNE NG",NULL},
/* 1596 */ { "SYLLABE CANADIENNE NNG",NULL},
/* 1597 */ { "SYLLABE CANADIENNE CHÉ SAYISI",NULL},
/* 1598 */ { "SYLLABE CANADIENNE CHI SAYISI",NULL},
/* 1599 */ { "SYLLABE CANADIENNE CHO SAYISI","	* sayisi (CHOU)"},
/* 159A */ { "SYLLABE CANADIENNE CHA SAYISI",NULL},
/* 159B */ { "SYLLABE CANADIENNE THÉ CRI DES BOIS",NULL},
/* 159C */ { "SYLLABE CANADIENNE THI CRI DES BOIS",NULL},
/* 159D */ { "SYLLABE CANADIENNE THO CRI DES BOIS",NULL},
/* 159E */ { "SYLLABE CANADIENNE THA CRI DES BOIS",NULL},
/* 159F */ { "SYLLABE CANADIENNE TH CRI DES BOIS",NULL},
/* 15A0 */ { "SYLLABE CANADIENNE LHI",NULL},
/* 15A1 */ { "SYLLABE CANADIENNE LHÎ",NULL},
/* 15A2 */ { "SYLLABE CANADIENNE LHO","	* inuktitut (LHOU)"},
/* 15A3 */ { "SYLLABE CANADIENNE LHÔ","	* inuktitut (LHOÛ)"},
/* 15A4 */ { "SYLLABE CANADIENNE LHA",NULL},
/* 15A5 */ { "SYLLABE CANADIENNE LHÂ",NULL},
/* 15A6 */ { "SYLLABE CANADIENNE LH",NULL},
/* 15A7 */ { "SYLLABE CANADIENNE THÉ CRI-TH",NULL},
/* 15A8 */ { "SYLLABE CANADIENNE THI CRI-TH",NULL},
/* 15A9 */ { "SYLLABE CANADIENNE THÎ CRI-TH",NULL},
/* 15AA */ { "SYLLABE CANADIENNE THO CRI-TH",NULL},
/* 15AB */ { "SYLLABE CANADIENNE THÔ CRI-TH",NULL},
/* 15AC */ { "SYLLABE CANADIENNE THA CRI-TH",NULL},
/* 15AD */ { "SYLLABE CANADIENNE THÂ CRI-TH",NULL},
/* 15AE */ { "SYLLABE CANADIENNE TH CRI-TH",NULL},
/* 15AF */ { "SYLLABE CANADIENNE B AÏVILIK",NULL},
/* 15B0 */ { "SYLLABE CANADIENNE É PIED-NOIR",NULL},
/* 15B1 */ { "SYLLABE CANADIENNE I PIED-NOIR",NULL},
/* 15B2 */ { "SYLLABE CANADIENNE O PIED-NOIR",NULL},
/* 15B3 */ { "SYLLABE CANADIENNE A PIED-NOIR",NULL},
/* 15B4 */ { "SYLLABE CANADIENNE OUÉ PIED-NOIR",NULL},
/* 15B5 */ { "SYLLABE CANADIENNE OUI PIED-NOIR",NULL},
/* 15B6 */ { "SYLLABE CANADIENNE OUO PIED-NOIR",NULL},
/* 15B7 */ { "SYLLABE CANADIENNE OUA PIED-NOIR",NULL},
/* 15B8 */ { "SYLLABE CANADIENNE NÉ PIED-NOIR",NULL},
/* 15B9 */ { "SYLLABE CANADIENNE NI PIED-NOIR",NULL},
/* 15BA */ { "SYLLABE CANADIENNE NO PIED-NOIR",NULL},
/* 15BB */ { "SYLLABE CANADIENNE NA PIED-NOIR",NULL},
/* 15BC */ { "SYLLABE CANADIENNE KÉ PIED-NOIR",NULL},
/* 15BD */ { "SYLLABE CANADIENNE KI PIED-NOIR",NULL},
/* 15BE */ { "SYLLABE CANADIENNE KO PIED-NOIR",NULL},
/* 15BF */ { "SYLLABE CANADIENNE KA PIED-NOIR",NULL},
/* 15C0 */ { "SYLLABE CANADIENNE HÉ SAYISI",NULL},
/* 15C1 */ { "SYLLABE CANADIENNE HI SAYISI",NULL},
/* 15C2 */ { "SYLLABE CANADIENNE HO SAYISI","	* sayisi (HOU)"},
/* 15C3 */ { "SYLLABE CANADIENNE HA SAYISI",NULL},
/* 15C4 */ { "SYLLABE CANADIENNE GHOU PORTEUR",NULL},
/* 15C5 */ { "SYLLABE CANADIENNE GHO PORTEUR",NULL},
/* 15C6 */ { "SYLLABE CANADIENNE GHE PORTEUR",NULL},
/* 15C7 */ { "SYLLABE CANADIENNE GHÉ PORTEUR",NULL},
/* 15C8 */ { "SYLLABE CANADIENNE GHI PORTEUR",NULL},
/* 15C9 */ { "SYLLABE CANADIENNE GHA PORTEUR",NULL},
/* 15CA */ { "SYLLABE CANADIENNE ROU PORTEUR",NULL},
/* 15CB */ { "SYLLABE CANADIENNE RO PORTEUR",NULL},
/* 15CC */ { "SYLLABE CANADIENNE RE PORTEUR",NULL},
/* 15CD */ { "SYLLABE CANADIENNE RÉ PORTEUR",NULL},
/* 15CE */ { "SYLLABE CANADIENNE RI PORTEUR",NULL},
/* 15CF */ { "SYLLABE CANADIENNE RA PORTEUR",NULL},
/* 15D0 */ { "SYLLABE CANADIENNE OUOU PORTEUR",NULL},
/* 15D1 */ { "SYLLABE CANADIENNE OUO PORTEUR",NULL},
/* 15D2 */ { "SYLLABE CANADIENNE OUE PORTEUR",NULL},
/* 15D3 */ { "SYLLABE CANADIENNE OUÉ PORTEUR",NULL},
/* 15D4 */ { "SYLLABE CANADIENNE OUI PORTEUR",NULL},
/* 15D5 */ { "SYLLABE CANADIENNE OUA PORTEUR",NULL},
/* 15D6 */ { "SYLLABE CANADIENNE HOUOU PORTEUR",NULL},
/* 15D7 */ { "SYLLABE CANADIENNE HOUO PORTEUR",NULL},
/* 15D8 */ { "SYLLABE CANADIENNE HOUE PORTEUR",NULL},
/* 15D9 */ { "SYLLABE CANADIENNE HOUÉ PORTEUR",NULL},
/* 15DA */ { "SYLLABE CANADIENNE HOUI PORTEUR",NULL},
/* 15DB */ { "SYLLABE CANADIENNE HOUA PORTEUR",NULL},
/* 15DC */ { "SYLLABE CANADIENNE THOU PORTEUR",NULL},
/* 15DD */ { "SYLLABE CANADIENNE THO PORTEUR",NULL},
/* 15DE */ { "SYLLABE CANADIENNE THE PORTEUR",NULL},
/* 15DF */ { "SYLLABE CANADIENNE THÉ PORTEUR",NULL},
/* 15E0 */ { "SYLLABE CANADIENNE THI PORTEUR",NULL},
/* 15E1 */ { "SYLLABE CANADIENNE THA PORTEUR",NULL},
/* 15E2 */ { "SYLLABE CANADIENNE TTOU PORTEUR",NULL},
/* 15E3 */ { "SYLLABE CANADIENNE TTO PORTEUR",NULL},
/* 15E4 */ { "SYLLABE CANADIENNE TTE PORTEUR",NULL},
/* 15E5 */ { "SYLLABE CANADIENNE TTÉ PORTEUR",NULL},
/* 15E6 */ { "SYLLABE CANADIENNE TTI PORTEUR",NULL},
/* 15E7 */ { "SYLLABE CANADIENNE TTA PORTEUR",NULL},
/* 15E8 */ { "SYLLABE CANADIENNE POU PORTEUR",NULL},
/* 15E9 */ { "SYLLABE CANADIENNE PO PORTEUR",NULL},
/* 15EA */ { "SYLLABE CANADIENNE PE PORTEUR",NULL},
/* 15EB */ { "SYLLABE CANADIENNE PÉ PORTEUR",NULL},
/* 15EC */ { "SYLLABE CANADIENNE PI PORTEUR",NULL},
/* 15ED */ { "SYLLABE CANADIENNE PA PORTEUR",NULL},
/* 15EE */ { "SYLLABE CANADIENNE P PORTEUR",NULL},
/* 15EF */ { "SYLLABE CANADIENNE GOU PORTEUR",NULL},
/* 15F0 */ { "SYLLABE CANADIENNE GO PORTEUR",NULL},
/* 15F1 */ { "SYLLABE CANADIENNE GE PORTEUR",NULL},
/* 15F2 */ { "SYLLABE CANADIENNE GÉ PORTEUR",NULL},
/* 15F3 */ { "SYLLABE CANADIENNE GI PORTEUR",NULL},
/* 15F4 */ { "SYLLABE CANADIENNE GA PORTEUR",NULL},
/* 15F5 */ { "SYLLABE CANADIENNE KHOU PORTEUR",NULL},
/* 15F6 */ { "SYLLABE CANADIENNE KHO PORTEUR",NULL},
/* 15F7 */ { "SYLLABE CANADIENNE KHE PORTEUR",NULL},
/* 15F8 */ { "SYLLABE CANADIENNE KHÉ PORTEUR",NULL},
/* 15F9 */ { "SYLLABE CANADIENNE KHI PORTEUR",NULL},
/* 15FA */ { "SYLLABE CANADIENNE KHA PORTEUR",NULL},
/* 15FB */ { "SYLLABE CANADIENNE KKOU PORTEUR",NULL},
/* 15FC */ { "SYLLABE CANADIENNE KKO PORTEUR",NULL},
/* 15FD */ { "SYLLABE CANADIENNE KKE PORTEUR",NULL},
/* 15FE */ { "SYLLABE CANADIENNE KKÉ PORTEUR",NULL},
/* 15FF */ { "SYLLABE CANADIENNE KKI PORTEUR",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_16[] = {
/* 1600 */ { "SYLLABE CANADIENNE KKA PORTEUR",NULL},
/* 1601 */ { "SYLLABE CANADIENNE KK PORTEUR",NULL},
/* 1602 */ { "SYLLABE CANADIENNE NOU PORTEUR",NULL},
/* 1603 */ { "SYLLABE CANADIENNE NO PORTEUR",NULL},
/* 1604 */ { "SYLLABE CANADIENNE NE PORTEUR",NULL},
/* 1605 */ { "SYLLABE CANADIENNE NÉ PORTEUR",NULL},
/* 1606 */ { "SYLLABE CANADIENNE NI PORTEUR",NULL},
/* 1607 */ { "SYLLABE CANADIENNE NA PORTEUR",NULL},
/* 1608 */ { "SYLLABE CANADIENNE MOU PORTEUR",NULL},
/* 1609 */ { "SYLLABE CANADIENNE MO PORTEUR",NULL},
/* 160A */ { "SYLLABE CANADIENNE ME PORTEUR",NULL},
/* 160B */ { "SYLLABE CANADIENNE MÉ PORTEUR",NULL},
/* 160C */ { "SYLLABE CANADIENNE MI PORTEUR",NULL},
/* 160D */ { "SYLLABE CANADIENNE MA PORTEUR",NULL},
/* 160E */ { "SYLLABE CANADIENNE YOU PORTEUR",NULL},
/* 160F */ { "SYLLABE CANADIENNE YO PORTEUR",NULL},
/* 1610 */ { "SYLLABE CANADIENNE YE PORTEUR",NULL},
/* 1611 */ { "SYLLABE CANADIENNE YÉ PORTEUR",NULL},
/* 1612 */ { "SYLLABE CANADIENNE YI PORTEUR",NULL},
/* 1613 */ { "SYLLABE CANADIENNE YA PORTEUR",NULL},
/* 1614 */ { "SYLLABE CANADIENNE DJOU PORTEUR","	* athabascan (ZA), sayisi (TZO), esclave du Sud (DHA)"},
/* 1615 */ { "SYLLABE CANADIENNE DJOU SAYISI","	* athabascan (ZO), sayisi (TZOU), esclave du Sud (DHO)"},
/* 1616 */ { "SYLLABE CANADIENNE DJO PORTEUR",NULL},
/* 1617 */ { "SYLLABE CANADIENNE DJE PORTEUR",NULL},
/* 1618 */ { "SYLLABE CANADIENNE DJÉ PORTEUR",NULL},
/* 1619 */ { "SYLLABE CANADIENNE DJI PORTEUR",NULL},
/* 161A */ { "SYLLABE CANADIENNE DJI SAYISI","	* athabascan (ZÉ), sayisi (TZÉ), esclave du Sud (DHÉ)"},
/* 161B */ { "SYLLABE CANADIENNE DJA PORTEUR","	* athabascan (ZI), sayisi (TZI), esclave du Sud (DHI)"},
/* 161C */ { "SYLLABE CANADIENNE DJJOU PORTEUR",NULL},
/* 161D */ { "SYLLABE CANADIENNE DJJO PORTEUR",NULL},
/* 161E */ { "SYLLABE CANADIENNE DJJE PORTEUR",NULL},
/* 161F */ { "SYLLABE CANADIENNE DJJÉ PORTEUR",NULL},
/* 1620 */ { "SYLLABE CANADIENNE DJJI PORTEUR",NULL},
/* 1621 */ { "SYLLABE CANADIENNE DJJA PORTEUR",NULL},
/* 1622 */ { "SYLLABE CANADIENNE LOU PORTEUR",NULL},
/* 1623 */ { "SYLLABE CANADIENNE LO PORTEUR",NULL},
/* 1624 */ { "SYLLABE CANADIENNE LE PORTEUR",NULL},
/* 1625 */ { "SYLLABE CANADIENNE LÉ PORTEUR",NULL},
/* 1626 */ { "SYLLABE CANADIENNE LI PORTEUR",NULL},
/* 1627 */ { "SYLLABE CANADIENNE LA PORTEUR",NULL},
/* 1628 */ { "SYLLABE CANADIENNE DLOU PORTEUR",NULL},
/* 1629 */ { "SYLLABE CANADIENNE DLO PORTEUR",NULL},
/* 162A */ { "SYLLABE CANADIENNE DLE PORTEUR",NULL},
/* 162B */ { "SYLLABE CANADIENNE DLÉ PORTEUR",NULL},
/* 162C */ { "SYLLABE CANADIENNE DLI PORTEUR",NULL},
/* 162D */ { "SYLLABE CANADIENNE DLA PORTEUR",NULL},
/* 162E */ { "SYLLABE CANADIENNE LHOU PORTEUR",NULL},
/* 162F */ { "SYLLABE CANADIENNE LHO PORTEUR",NULL},
/* 1630 */ { "SYLLABE CANADIENNE LHE PORTEUR",NULL},
/* 1631 */ { "SYLLABE CANADIENNE LHÉ PORTEUR",NULL},
/* 1632 */ { "SYLLABE CANADIENNE LHI PORTEUR",NULL},
/* 1633 */ { "SYLLABE CANADIENNE LHA PORTEUR",NULL},
/* 1634 */ { "SYLLABE CANADIENNE TLHOU PORTEUR",NULL},
/* 1635 */ { "SYLLABE CANADIENNE TLHO PORTEUR",NULL},
/* 1636 */ { "SYLLABE CANADIENNE TLHE PORTEUR",NULL},
/* 1637 */ { "SYLLABE CANADIENNE TLHÉ PORTEUR",NULL},
/* 1638 */ { "SYLLABE CANADIENNE TLHI PORTEUR",NULL},
/* 1639 */ { "SYLLABE CANADIENNE TLHA PORTEUR",NULL},
/* 163A */ { "SYLLABE CANADIENNE TLOU PORTEUR",NULL},
/* 163B */ { "SYLLABE CANADIENNE TLO PORTEUR",NULL},
/* 163C */ { "SYLLABE CANADIENNE TLE PORTEUR",NULL},
/* 163D */ { "SYLLABE CANADIENNE TLÉ PORTEUR",NULL},
/* 163E */ { "SYLLABE CANADIENNE TLI PORTEUR",NULL},
/* 163F */ { "SYLLABE CANADIENNE TLA PORTEUR",NULL},
/* 1640 */ { "SYLLABE CANADIENNE ZOU PORTEUR",NULL},
/* 1641 */ { "SYLLABE CANADIENNE ZO PORTEUR",NULL},
/* 1642 */ { "SYLLABE CANADIENNE ZE PORTEUR",NULL},
/* 1643 */ { "SYLLABE CANADIENNE ZÉ PORTEUR",NULL},
/* 1644 */ { "SYLLABE CANADIENNE ZI PORTEUR",NULL},
/* 1645 */ { "SYLLABE CANADIENNE ZA PORTEUR",NULL},
/* 1646 */ { "SYLLABE CANADIENNE Z PORTEUR",NULL},
/* 1647 */ { "SYLLABE CANADIENNE Z INITIAL PORTEUR",NULL},
/* 1648 */ { "SYLLABE CANADIENNE DZOU PORTEUR",NULL},
/* 1649 */ { "SYLLABE CANADIENNE DZO PORTEUR",NULL},
/* 164A */ { "SYLLABE CANADIENNE DZE PORTEUR",NULL},
/* 164B */ { "SYLLABE CANADIENNE DZÉ PORTEUR",NULL},
/* 164C */ { "SYLLABE CANADIENNE DZI PORTEUR",NULL},
/* 164D */ { "SYLLABE CANADIENNE DZA PORTEUR",NULL},
/* 164E */ { "SYLLABE CANADIENNE SOU PORTEUR",NULL},
/* 164F */ { "SYLLABE CANADIENNE SO PORTEUR",NULL},
/* 1650 */ { "SYLLABE CANADIENNE SE PORTEUR",NULL},
/* 1651 */ { "SYLLABE CANADIENNE SÉ PORTEUR",NULL},
/* 1652 */ { "SYLLABE CANADIENNE SI PORTEUR",NULL},
/* 1653 */ { "SYLLABE CANADIENNE SA PORTEUR",NULL},
/* 1654 */ { "SYLLABE CANADIENNE CHOU PORTEUR",NULL},
/* 1655 */ { "SYLLABE CANADIENNE CHO PORTEUR",NULL},
/* 1656 */ { "SYLLABE CANADIENNE CHE PORTEUR",NULL},
/* 1657 */ { "SYLLABE CANADIENNE CHÉ PORTEUR",NULL},
/* 1658 */ { "SYLLABE CANADIENNE CHI PORTEUR",NULL},
/* 1659 */ { "SYLLABE CANADIENNE CHA PORTEUR",NULL},
/* 165A */ { "SYLLABE CANADIENNE CH PORTEUR",NULL},
/* 165B */ { "SYLLABE CANADIENNE TSOU PORTEUR",NULL},
/* 165C */ { "SYLLABE CANADIENNE TSO PORTEUR",NULL},
/* 165D */ { "SYLLABE CANADIENNE TSE PORTEUR",NULL},
/* 165E */ { "SYLLABE CANADIENNE TSÉ PORTEUR",NULL},
/* 165F */ { "SYLLABE CANADIENNE TSI PORTEUR",NULL},
/* 1660 */ { "SYLLABE CANADIENNE TSA PORTEUR",NULL},
/* 1661 */ { "SYLLABE CANADIENNE TCHOU PORTEUR",NULL},
/* 1662 */ { "SYLLABE CANADIENNE TCHO PORTEUR",NULL},
/* 1663 */ { "SYLLABE CANADIENNE TCHE PORTEUR",NULL},
/* 1664 */ { "SYLLABE CANADIENNE TCHÉ PORTEUR",NULL},
/* 1665 */ { "SYLLABE CANADIENNE TCHI PORTEUR",NULL},
/* 1666 */ { "SYLLABE CANADIENNE TCHA PORTEUR",NULL},
/* 1667 */ { "SYLLABE CANADIENNE TTSOU PORTEUR",NULL},
/* 1668 */ { "SYLLABE CANADIENNE TTSO PORTEUR",NULL},
/* 1669 */ { "SYLLABE CANADIENNE TTSE PORTEUR",NULL},
/* 166A */ { "SYLLABE CANADIENNE TTSÉ PORTEUR",NULL},
/* 166B */ { "SYLLABE CANADIENNE TTSI PORTEUR",NULL},
/* 166C */ { "SYLLABE CANADIENNE TTSA PORTEUR",NULL},
/* 166D */ { "SIGNE SYLLABE CANADIENNE KHI","	* algonquien\n"
	"	* utilisé comme symbole du Christ\n"
	"	x (chrisme - 2627)"},
/* 166E */ { "POINT SYLLABE CANADIENNE","	x (point sténographique - 2E3C)"},
/* 166F */ { "SYLLABE CANADIENNE QAÏ",NULL},
/* 1670 */ { "SYLLABE CANADIENNE NGAÏ",NULL},
/* 1671 */ { "SYLLABE CANADIENNE NNGI",NULL},
/* 1672 */ { "SYLLABE CANADIENNE NNGÎ",NULL},
/* 1673 */ { "SYLLABE CANADIENNE NNGO","	* inuktitut (NNGOU)"},
/* 1674 */ { "SYLLABE CANADIENNE NNGÔ","	* inuktitut (NNGOÛ)"},
/* 1675 */ { "SYLLABE CANADIENNE NNGA",NULL},
/* 1676 */ { "SYLLABE CANADIENNE NNGÂ",NULL},
/* 1677 */ { "SYLLABE CANADIENNE THOUÉ CRI DES BOIS",NULL},
/* 1678 */ { "SYLLABE CANADIENNE THOUI CRI DES BOIS",NULL},
/* 1679 */ { "SYLLABE CANADIENNE THOUÎ CRI DES BOIS",NULL},
/* 167A */ { "SYLLABE CANADIENNE THOUO CRI DES BOIS",NULL},
/* 167B */ { "SYLLABE CANADIENNE THOUÔ CRI DES BOIS",NULL},
/* 167C */ { "SYLLABE CANADIENNE THOUA CRI DES BOIS",NULL},
/* 167D */ { "SYLLABE CANADIENNE THOUÂ CRI DES BOIS",NULL},
/* 167E */ { "SYLLABE CANADIENNE T FINAL CRI DES BOIS",NULL},
/* 167F */ { "SYLLABE CANADIENNE OU PIED-NOIR",NULL},
/* 1680 */ { "ESPACE D'OGAM","	* le glyphe est vierge dans les polices sans « jambage »\n"
	"	x (espace - 0020)"},
/* 1681 */ { "LETTRE D'OGAM BEITH",NULL},
/* 1682 */ { "LETTRE D'OGAM LUIS",NULL},
/* 1683 */ { "LETTRE D'OGAM FEARN",NULL},
/* 1684 */ { "LETTRE D'OGAM SAIL",NULL},
/* 1685 */ { "LETTRE D'OGAM NION",NULL},
/* 1686 */ { "LETTRE D'OGAM UATH",NULL},
/* 1687 */ { "LETTRE D'OGAM DAIR",NULL},
/* 1688 */ { "LETTRE D'OGAM TINNE",NULL},
/* 1689 */ { "LETTRE D'OGAM COLL",NULL},
/* 168A */ { "LETTRE D'OGAM CEIRT",NULL},
/* 168B */ { "LETTRE D'OGAM MUIN",NULL},
/* 168C */ { "LETTRE D'OGAM GORT",NULL},
/* 168D */ { "LETTRE D'OGAM NGÉADAL",NULL},
/* 168E */ { "LETTRE D'OGAM STRAIF",NULL},
/* 168F */ { "LETTRE D'OGAM RUIS",NULL},
/* 1690 */ { "LETTRE D'OGAM AILM",NULL},
/* 1691 */ { "LETTRE D'OGAM ONN",NULL},
/* 1692 */ { "LETTRE D'OGAM ÚR",NULL},
/* 1693 */ { "LETTRE D'OGAM EADHADH",NULL},
/* 1694 */ { "LETTRE D'OGAM IODHADH",NULL},
/* 1695 */ { "LETTRE D'OGAM ÉABHADH",NULL},
/* 1696 */ { "LETTRE D'OGAM ÓR",NULL},
/* 1697 */ { "LETTRE D'OGAM UILLEANN",NULL},
/* 1698 */ { "LETTRE D'OGAM IFÍN",NULL},
/* 1699 */ { "LETTRE D'OGAM EAMHANCHOLL",NULL},
/* 169A */ { "LETTRE D'OGAM PEITH",NULL},
/* 169B */ { "PLUME D'OGAM","	* indique le début d'un texte en alphabet ogamique"},
/* 169C */ { "PLUME RÉFLÉCHIE D'OGAM","	* indique la fin d'un texte en alphabet ogamique"},
/* 169D */ { NULL,NULL},
/* 169E */ { NULL,NULL},
/* 169F */ { NULL,NULL},
/* 16A0 */ { "LETTRE RUNIQUE FÉHU FÉOH FÉ F",NULL},
/* 16A1 */ { "LETTRE RUNIQUE V",NULL},
/* 16A2 */ { "LETTRE RUNIQUE URUZ UR OU",NULL},
/* 16A3 */ { "LETTRE RUNIQUE YR",NULL},
/* 16A4 */ { "LETTRE RUNIQUE Y",NULL},
/* 16A5 */ { "LETTRE RUNIQUE W",NULL},
/* 16A6 */ { "LETTRE RUNIQUE THURISAZ THORN THURS TH","	x (lettre minuscule latine thorn - 00FE)"},
/* 16A7 */ { "LETTRE RUNIQUE ETH",NULL},
/* 16A8 */ { "LETTRE RUNIQUE ANSUZ A",NULL},
/* 16A9 */ { "LETTRE RUNIQUE OS O",NULL},
/* 16AA */ { "LETTRE RUNIQUE AC A",NULL},
/* 16AB */ { "LETTRE RUNIQUE ÆSC",NULL},
/* 16AC */ { "LETTRE RUNIQUE OSS-À-BRANCHE-LONGUE O",NULL},
/* 16AD */ { "LETTRE RUNIQUE OSS-À-RAMILLE O",NULL},
/* 16AE */ { "LETTRE RUNIQUE O",NULL},
/* 16AF */ { "LETTRE RUNIQUE OE",NULL},
/* 16B0 */ { "LETTRE RUNIQUE ON",NULL},
/* 16B1 */ { "LETTRE RUNIQUE RAIDO RAD REID R",NULL},
/* 16B2 */ { "LETTRE RUNIQUE KAUNA",NULL},
/* 16B3 */ { "LETTRE RUNIQUE CEN",NULL},
/* 16B4 */ { "LETTRE RUNIQUE KAUN K",NULL},
/* 16B5 */ { "LETTRE RUNIQUE G",NULL},
/* 16B6 */ { "LETTRE RUNIQUE ENG",NULL},
/* 16B7 */ { "LETTRE RUNIQUE GEBO GEOFU G",NULL},
/* 16B8 */ { "LETTRE RUNIQUE GAR",NULL},
/* 16B9 */ { "LETTRE RUNIQUE WUNJO WYNN W","	x (lettre latine wynn - 01BF)"},
/* 16BA */ { "LETTRE RUNIQUE HAGLAZ H",NULL},
/* 16BB */ { "LETTRE RUNIQUE HÆGL H",NULL},
/* 16BC */ { "LETTRE RUNIQUE HAGALL-À-LONGUE-BRANCHE H",NULL},
/* 16BD */ { "LETTRE RUNIQUE HAGALL-À-RAMILLE H",NULL},
/* 16BE */ { "LETTRE RUNIQUE NAUDIZ NYD NAUD N",NULL},
/* 16BF */ { "LETTRE RUNIQUE NAUD-À-RAMILLE N",NULL},
/* 16C0 */ { "LETTRE RUNIQUE N-POINTÉ",NULL},
/* 16C1 */ { "LETTRE RUNIQUE ISA IS ISS I",NULL},
/* 16C2 */ { "LETTRE RUNIQUE E",NULL},
/* 16C3 */ { "LETTRE RUNIQUE JERAN J",NULL},
/* 16C4 */ { "LETTRE RUNIQUE GER",NULL},
/* 16C5 */ { "LETTRE RUNIQUE AR-À-LONGUE-BRANCHE Æ",NULL},
/* 16C6 */ { "LETTRE RUNIQUE AR A",NULL},
/* 16C7 */ { "LETTRE RUNIQUE IWAZ EOH",NULL},
/* 16C8 */ { "LETTRE RUNIQUE PERTHRO PEORTH P",NULL},
/* 16C9 */ { "LETTRE RUNIQUE ALGIZ EOLHX",NULL},
/* 16CA */ { "LETTRE RUNIQUE SOWILO S",NULL},
/* 16CB */ { "LETTRE RUNIQUE SIGEL SOL-À-LONGUE-BRANCHE S",NULL},
/* 16CC */ { "LETTRE RUNIQUE SOL-À-RAMILLE S",NULL},
/* 16CD */ { "LETTRE RUNIQUE C",NULL},
/* 16CE */ { "LETTRE RUNIQUE Z",NULL},
/* 16CF */ { "LETTRE RUNIQUE TIWAZ TIR TYR T",NULL},
/* 16D0 */ { "LETTRE RUNIQUE TYR-À-RAMILLE T",NULL},
/* 16D1 */ { "LETTRE RUNIQUE D",NULL},
/* 16D2 */ { "LETTRE RUNIQUE BERKANAN BEORC BIARKAN B",NULL},
/* 16D3 */ { "LETTRE RUNIQUE BIARKAN-À-RAMILLE B",NULL},
/* 16D4 */ { "LETTRE RUNIQUE P-POINTÉ",NULL},
/* 16D5 */ { "LETTRE RUNIQUE P-OUVERT",NULL},
/* 16D6 */ { "LETTRE RUNIQUE EHWAZ EH E",NULL},
/* 16D7 */ { "LETTRE RUNIQUE MANNAZ MAN M",NULL},
/* 16D8 */ { "LETTRE RUNIQUE MADR-À-LONGUE-BRANCHE M",NULL},
/* 16D9 */ { "LETTRE RUNIQUE MADR-À-RAMILLE M",NULL},
/* 16DA */ { "LETTRE RUNIQUE LAUKAZ LAGU LOGR L",NULL},
/* 16DB */ { "LETTRE RUNIQUE L-POINTÉ",NULL},
/* 16DC */ { "LETTRE RUNIQUE INGWAZ",NULL},
/* 16DD */ { "LETTRE RUNIQUE ING",NULL},
/* 16DE */ { "LETTRE RUNIQUE DAGAZ DÆG D",NULL},
/* 16DF */ { "LETTRE RUNIQUE OTHALAN ETHEL O",NULL},
/* 16E0 */ { "LETTRE RUNIQUE EAR",NULL},
/* 16E1 */ { "LETTRE RUNIQUE IOR",NULL},
/* 16E2 */ { "LETTRE RUNIQUE CWEORTH",NULL},
/* 16E3 */ { "LETTRE RUNIQUE CALC",NULL},
/* 16E4 */ { "LETTRE RUNIQUE CEALC",NULL},
/* 16E5 */ { "LETTRE RUNIQUE STAN",NULL},
/* 16E6 */ { "LETTRE RUNIQUE YR-À-LONGUE-BRANCHE",NULL},
/* 16E7 */ { "LETTRE RUNIQUE YR-À-RAMILLE",NULL},
/* 16E8 */ { "LETTRE RUNIQUE YR-ISLANDAIS",NULL},
/* 16E9 */ { "LETTRE RUNIQUE Q",NULL},
/* 16EA */ { "LETTRE RUNIQUE X",NULL},
/* 16EB */ { "PONCTUATION RUNIQUE SIMPLE",NULL},
/* 16EC */ { "PONCTUATION RUNIQUE MULTIPLE",NULL},
/* 16ED */ { "PONCTUATION RUNIQUE EN CROIX",NULL},
/* 16EE */ { "SYMBOLE RUNIQUE ARLAUG","	* nombre d'or 17"},
/* 16EF */ { "SYMBOLE RUNIQUE TVIMADUR","	* nombre d'or 18"},
/* 16F0 */ { "SYMBOLE RUNIQUE BELGTHOR","	* nombre d'or 19"},
/* 16F1 */ { "LETTRE RUNIQUE K",NULL},
/* 16F2 */ { "LETTRE RUNIQUE SH",NULL},
/* 16F3 */ { "LETTRE RUNIQUE OO",NULL},
/* 16F4 */ { "LETTRE RUNIQUE DU COFFRET D'AUZON OS",NULL},
/* 16F5 */ { "LETTRE RUNIQUE DU COFFRET D'AUZON IS",NULL},
/* 16F6 */ { "LETTRE RUNIQUE DU COFFRET D'AUZON EH",NULL},
/* 16F7 */ { "LETTRE RUNIQUE DU COFFRET D'AUZON AC",NULL},
/* 16F8 */ { "LETTRE RUNIQUE DU COFFRET D'AUZON ÆSC",NULL},
/* 16F9 */ { NULL,NULL},
/* 16FA */ { NULL,NULL},
/* 16FB */ { NULL,NULL},
/* 16FC */ { NULL,NULL},
/* 16FD */ { NULL,NULL},
/* 16FE */ { NULL,NULL},
/* 16FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_17[] = {
/* 1700 */ { "LETTRE TAGALOG A",NULL},
/* 1701 */ { "LETTRE TAGALOG I",NULL},
/* 1702 */ { "LETTRE TAGALOG OU",NULL},
/* 1703 */ { "LETTRE TAGALOG KA",NULL},
/* 1704 */ { "LETTRE TAGALOG GA",NULL},
/* 1705 */ { "LETTRE TAGALOG NGA",NULL},
/* 1706 */ { "LETTRE TAGALOG TA",NULL},
/* 1707 */ { "LETTRE TAGALOG DA",NULL},
/* 1708 */ { "LETTRE TAGALOG NA",NULL},
/* 1709 */ { "LETTRE TAGALOG PA",NULL},
/* 170A */ { "LETTRE TAGALOG BA",NULL},
/* 170B */ { "LETTRE TAGALOG MA",NULL},
/* 170C */ { "LETTRE TAGALOG YA",NULL},
/* 170D */ { "LETTRE TAGALOG RA","	* adaptation moderne, absente en vieux tagalog"},
/* 170E */ { "LETTRE TAGALOG LA",NULL},
/* 170F */ { "LETTRE TAGALOG WA",NULL},
/* 1710 */ { "LETTRE TAGALOG SA",NULL},
/* 1711 */ { "LETTRE TAGALOG HA",NULL},
/* 1712 */ { "DIACRITIQUE VOYELLE TAGALOG I",NULL},
/* 1713 */ { "DIACRITIQUE VOYELLE TAGALOG OU",NULL},
/* 1714 */ { "DIACRITIQUE TAGALOG VIRÂMA",NULL},
/* 1715 */ { "DIACRITIQUE TAGALOG PAMOUDPOD","	x (diacritique hanounóo pamoudpod - 1734)"},
/* 1716 */ { NULL,NULL},
/* 1717 */ { NULL,NULL},
/* 1718 */ { NULL,NULL},
/* 1719 */ { NULL,NULL},
/* 171A */ { NULL,NULL},
/* 171B */ { NULL,NULL},
/* 171C */ { NULL,NULL},
/* 171D */ { NULL,NULL},
/* 171E */ { NULL,NULL},
/* 171F */ { "LETTRE TAGALOG RA ARCHAÏQUE","	= ra de Zambales\n"
	"	* adaptation moderne, absente en vieux tagalog"},
/* 1720 */ { "LETTRE HANOUNÓO A",NULL},
/* 1721 */ { "LETTRE HANOUNÓO I",NULL},
/* 1722 */ { "LETTRE HANOUNÓO OU",NULL},
/* 1723 */ { "LETTRE HANOUNÓO KA",NULL},
/* 1724 */ { "LETTRE HANOUNÓO GA",NULL},
/* 1725 */ { "LETTRE HANOUNÓO NGA",NULL},
/* 1726 */ { "LETTRE HANOUNÓO TA",NULL},
/* 1727 */ { "LETTRE HANOUNÓO DA",NULL},
/* 1728 */ { "LETTRE HANOUNÓO NA",NULL},
/* 1729 */ { "LETTRE HANOUNÓO PA",NULL},
/* 172A */ { "LETTRE HANOUNÓO BA",NULL},
/* 172B */ { "LETTRE HANOUNÓO MA",NULL},
/* 172C */ { "LETTRE HANOUNÓO YA",NULL},
/* 172D */ { "LETTRE HANOUNÓO RA",NULL},
/* 172E */ { "LETTRE HANOUNÓO LA",NULL},
/* 172F */ { "LETTRE HANOUNÓO WA",NULL},
/* 1730 */ { "LETTRE HANOUNÓO SA",NULL},
/* 1731 */ { "LETTRE HANOUNÓO HA",NULL},
/* 1732 */ { "DIACRITIQUE VOYELLE HANOUNÓO I",NULL},
/* 1733 */ { "DIACRITIQUE VOYELLE HANOUNÓO OU",NULL},
/* 1734 */ { "DIACRITIQUE HANOUNÓO PAMOUDPOD","	x (diacritique tagalog pamoudpod - 1715)"},
/* 1735 */ { "PONCTUATION PHILIPPINE SIMPLE","	x (danda dévanâgarî - 0964)"},
/* 1736 */ { "PONCTUATION PHILIPPINE DOUBLE","	x (double danda dévanâgarî - 0965)"},
/* 1737 */ { NULL,NULL},
/* 1738 */ { NULL,NULL},
/* 1739 */ { NULL,NULL},
/* 173A */ { NULL,NULL},
/* 173B */ { NULL,NULL},
/* 173C */ { NULL,NULL},
/* 173D */ { NULL,NULL},
/* 173E */ { NULL,NULL},
/* 173F */ { NULL,NULL},
/* 1740 */ { "LETTRE BOUHID A",NULL},
/* 1741 */ { "LETTRE BOUHID I",NULL},
/* 1742 */ { "LETTRE BOUHID OU",NULL},
/* 1743 */ { "LETTRE BOUHID KA",NULL},
/* 1744 */ { "LETTRE BOUHID GA",NULL},
/* 1745 */ { "LETTRE BOUHID NGA",NULL},
/* 1746 */ { "LETTRE BOUHID TA",NULL},
/* 1747 */ { "LETTRE BOUHID DA",NULL},
/* 1748 */ { "LETTRE BOUHID NA",NULL},
/* 1749 */ { "LETTRE BOUHID PA",NULL},
/* 174A */ { "LETTRE BOUHID BA",NULL},
/* 174B */ { "LETTRE BOUHID MA",NULL},
/* 174C */ { "LETTRE BOUHID YA",NULL},
/* 174D */ { "LETTRE BOUHID RA",NULL},
/* 174E */ { "LETTRE BOUHID LA",NULL},
/* 174F */ { "LETTRE BOUHID WA",NULL},
/* 1750 */ { "LETTRE BOUHID SA",NULL},
/* 1751 */ { "LETTRE BOUHID HA",NULL},
/* 1752 */ { "DIACRITIQUE VOYELLE BOUHID I",NULL},
/* 1753 */ { "DIACRITIQUE VOYELLE BOUHID OU",NULL},
/* 1754 */ { NULL,NULL},
/* 1755 */ { NULL,NULL},
/* 1756 */ { NULL,NULL},
/* 1757 */ { NULL,NULL},
/* 1758 */ { NULL,NULL},
/* 1759 */ { NULL,NULL},
/* 175A */ { NULL,NULL},
/* 175B */ { NULL,NULL},
/* 175C */ { NULL,NULL},
/* 175D */ { NULL,NULL},
/* 175E */ { NULL,NULL},
/* 175F */ { NULL,NULL},
/* 1760 */ { "LETTRE TAGBANOUA A",NULL},
/* 1761 */ { "LETTRE TAGBANOUA I",NULL},
/* 1762 */ { "LETTRE TAGBANOUA OU",NULL},
/* 1763 */ { "LETTRE TAGBANOUA KA",NULL},
/* 1764 */ { "LETTRE TAGBANOUA GA",NULL},
/* 1765 */ { "LETTRE TAGBANOUA NGA",NULL},
/* 1766 */ { "LETTRE TAGBANOUA TA",NULL},
/* 1767 */ { "LETTRE TAGBANOUA DA",NULL},
/* 1768 */ { "LETTRE TAGBANOUA NA",NULL},
/* 1769 */ { "LETTRE TAGBANOUA PA",NULL},
/* 176A */ { "LETTRE TAGBANOUA BA",NULL},
/* 176B */ { "LETTRE TAGBANOUA MA",NULL},
/* 176C */ { "LETTRE TAGBANOUA YA",NULL},
/* 176D */ { NULL,NULL},
/* 176E */ { "LETTRE TAGBANOUA LA",NULL},
/* 176F */ { "LETTRE TAGBANOUA WA",NULL},
/* 1770 */ { "LETTRE TAGBANOUA SA",NULL},
/* 1771 */ { NULL,NULL},
/* 1772 */ { "DIACRITIQUE VOYELLE TAGBANOUA I",NULL},
/* 1773 */ { "DIACRITIQUE VOYELLE TAGBANOUA OU",NULL},
/* 1774 */ { NULL,NULL},
/* 1775 */ { NULL,NULL},
/* 1776 */ { NULL,NULL},
/* 1777 */ { NULL,NULL},
/* 1778 */ { NULL,NULL},
/* 1779 */ { NULL,NULL},
/* 177A */ { NULL,NULL},
/* 177B */ { NULL,NULL},
/* 177C */ { NULL,NULL},
/* 177D */ { NULL,NULL},
/* 177E */ { NULL,NULL},
/* 177F */ { NULL,NULL},
/* 1780 */ { "LETTRE KHMÈRE KA",NULL},
/* 1781 */ { "LETTRE KHMÈRE KHA",NULL},
/* 1782 */ { "LETTRE KHMÈRE KO",NULL},
/* 1783 */ { "LETTRE KHMÈRE KHO",NULL},
/* 1784 */ { "LETTRE KHMÈRE NGO",NULL},
/* 1785 */ { "LETTRE KHMÈRE TCHA",NULL},
/* 1786 */ { "LETTRE KHMÈRE TCHHA",NULL},
/* 1787 */ { "LETTRE KHMÈRE TCHO",NULL},
/* 1788 */ { "LETTRE KHMÈRE TCHHO",NULL},
/* 1789 */ { "LETTRE KHMÈRE ÑO",NULL},
/* 178A */ { "LETTRE KHMÈRE DA",NULL},
/* 178B */ { "LETTRE KHMÈRE TTHA",NULL},
/* 178C */ { "LETTRE KHMÈRE DO",NULL},
/* 178D */ { "LETTRE KHMÈRE TTHO",NULL},
/* 178E */ { "LETTRE KHMÈRE NNA","	* le nom formel de ce caractère en anglais est erroné"},
/* 178F */ { "LETTRE KHMÈRE TA",NULL},
/* 1790 */ { "LETTRE KHMÈRE THA",NULL},
/* 1791 */ { "LETTRE KHMÈRE TO",NULL},
/* 1792 */ { "LETTRE KHMÈRE THO",NULL},
/* 1793 */ { "LETTRE KHMÈRE NO",NULL},
/* 1794 */ { "LETTRE KHMÈRE BA",NULL},
/* 1795 */ { "LETTRE KHMÈRE PHA","	= lettre khmère p'a"},
/* 1796 */ { "LETTRE KHMÈRE PO",NULL},
/* 1797 */ { "LETTRE KHMÈRE PHO","	= lettre khmère p'o"},
/* 1798 */ { "LETTRE KHMÈRE MO",NULL},
/* 1799 */ { "LETTRE KHMÈRE YO",NULL},
/* 179A */ { "LETTRE KHMÈRE RO",NULL},
/* 179B */ { "LETTRE KHMÈRE LO",NULL},
/* 179C */ { "LETTRE KHMÈRE VO",NULL},
/* 179D */ { "LETTRE KHMÈRE ÇA","	* uniquement pour les translittérations du pali et du sanskrit"},
/* 179E */ { "LETTRE KHMÈRE CHA","	* uniquement pour les translittérations du pali et du sanskrit\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 179F */ { "LETTRE KHMÈRE SA",NULL},
/* 17A0 */ { "LETTRE KHMÈRE HA",NULL},
/* 17A1 */ { "LETTRE KHMÈRE LA",NULL},
/* 17A2 */ { "LETTRE KHMÈRE 'A","	* coup de glotte"},
/* 17A3 */ { "VOYELLE PLEINE KHMÈRE 'A'","	* l'utilisation de ce caractère est fortement déconseillée ; il faut plutôt utiliser 17A2"},
/* 17A4 */ { "VOYELLE PLEINE KHMÈRE 'AA","	* l'utilisation de ce caractère n'est pas recommandée ; il faut plutôt utiliser la séquence 17A2 17B6"},
/* 17A5 */ { "VOYELLE PLEINE KHMÈRE 'I",NULL},
/* 17A6 */ { "VOYELLE PLEINE KHMÈRE 'II",NULL},
/* 17A7 */ { "VOYELLE PLEINE KHMÈRE 'OU",NULL},
/* 17A8 */ { "VOYELLE PLEINE KHMÈRE 'OUK","	* ligature désuète de la séquence 17A7 1780\n"
	"	* l'emploi de cette séquence est aujourd'hui recommandée"},
/* 17A9 */ { "VOYELLE PLEINE KHMÈRE 'OÛ","	* redoublement du son ou /u/"},
/* 17AA */ { "VOYELLE PLEINE KHMÈRE 'EOU",NULL},
/* 17AB */ { "VOYELLE PLEINE KHMÈRE RY","	* parfois romanisé en « rü » ou « reu »"},
/* 17AC */ { "VOYELLE PLEINE KHMÈRE RYY",NULL},
/* 17AD */ { "VOYELLE PLEINE KHMÈRE LY","	* parfois romanisé en « lü » ou « leu »"},
/* 17AE */ { "VOYELLE PLEINE KHMÈRE LYY",NULL},
/* 17AF */ { "VOYELLE PLEINE KHMÈRE 'ÈÈ",NULL},
/* 17B0 */ { "VOYELLE PLEINE KHMÈRE 'AÏ",NULL},
/* 17B1 */ { "VOYELLE PLEINE KHMÈRE 'OO TYPE UN",NULL},
/* 17B2 */ { "VOYELLE PLEINE KHMÈRE 'OO TYPE DEUX","	* il s'agit d'une variante de 17B1, utilisée seulement dans deux mots\n"
	"	* 17B1 est la variante habituelle de cette voyelle"},
/* 17B3 */ { "VOYELLE PLEINE KHMÈRE 'AOU",NULL},
/* 17B4 */ { "VOYELLE IMPLICITE KHMÈRE A'",NULL},
/* 17B5 */ { "VOYELLE IMPLICITE KHMÈRE AA",NULL},
/* 17B6 */ { "DIACRITIQUE VOYELLE KHMÈRE AA",NULL},
/* 17B7 */ { "DIACRITIQUE VOYELLE KHMÈRE I",NULL},
/* 17B8 */ { "DIACRITIQUE VOYELLE KHMÈRE II",NULL},
/* 17B9 */ { "DIACRITIQUE VOYELLE KHMÈRE Y","	= ü, eu"},
/* 17BA */ { "DIACRITIQUE VOYELLE KHMÈRE YY","	= üü, eû"},
/* 17BB */ { "DIACRITIQUE VOYELLE KHMÈRE OU",NULL},
/* 17BC */ { "DIACRITIQUE VOYELLE KHMÈRE OÛ","	* redoublement du son ou /u/"},
/* 17BD */ { "DIACRITIQUE VOYELLE KHMÈRE OUE",NULL},
/* 17BE */ { "DIACRITIQUE VOYELLE KHMÈRE EE","	= oe, œ"},
/* 17BF */ { "DIACRITIQUE VOYELLE KHMÈRE YE","	= üeu, eue"},
/* 17C0 */ { "DIACRITIQUE VOYELLE KHMÈRE IE",NULL},
/* 17C1 */ { "DIACRITIQUE VOYELLE KHMÈRE ÉÉ",NULL},
/* 17C2 */ { "DIACRITIQUE VOYELLE KHMÈRE ÈÈ","	= ae"},
/* 17C3 */ { "DIACRITIQUE VOYELLE KHMÈRE AÏ",NULL},
/* 17C4 */ { "DIACRITIQUE VOYELLE KHMÈRE OO",NULL},
/* 17C5 */ { "DIACRITIQUE VOYELLE KHMÈRE AOU",NULL},
/* 17C6 */ { "DIACRITIQUE KHMER NIKAHIT","	= srak âm\n"
	"	= anousvâra\n"
	"	* nasalisation finale\n"
	"	* on considère habituellement ce caractère comme la voyelle âm ; il permet d'écrire les voyelles om et aam\n"
	"	x (caractère thaï nikhahit - 0E4D)\n"
	"	x (diacritique birman anousvâra - 1036)"},
/* 17C7 */ { "DIACRITIQUE KHMER RÉAHMOUK","	= srak ah\n"
	"	= visarga\n"
	"	x (diacritique birman visarga - 1038)"},
/* 17C8 */ { "DIACRITIQUE KHMER YOUKALÉAKPINTOU","	* insère une voyelle inhérente brève accompagnée d'un coup de glotte abrupt"},
/* 17C9 */ { "DIACRITIQUE KHMER MOÛSÉKETOEN","	* passe du second registre au premier"},
/* 17CA */ { "DIACRITIQUE KHMER TREISAP","	* passe du premier registre au second"},
/* 17CB */ { "DIACRITIQUE KHMER BANTAK","	* abrège la voyelle de la syllabe orthographique précédente"},
/* 17CC */ { "DIACRITIQUE KHMER ROBAT","	* diacritique correspondant autrefois à la forme repha du ra dévanâgarî"},
/* 17CD */ { "DIACRITIQUE KHMER TOANDAKHIAT","	* signale que le caractère de base est muet\n"
	"	x (caractère thaï thanthakhat - 0E4C)"},
/* 17CE */ { "DIACRITIQUE KHMER KAKABAT","	= patte de corbeau\n"
	"	* s'utilise dans certaines exclamations"},
/* 17CF */ { "DIACRITIQUE KHMER AHSDAA","	* marque une intonation forte dans certains mots à une consonne"},
/* 17D0 */ { "DIACRITIQUE KHMER SAÑÑOK SAÑÑAA","	* indique une prononciation irrégulière, habituellement dans les mots empruntés au pali/sanskrit, au français, etc."},
/* 17D1 */ { "DIACRITIQUE KHMER VIRIAM","	* signe « tueur » moribond\n"
	"	* indique que le caractère de base correspond à la consonne finale d'un mot sans sa voyelle inhérente (on dit que la consonne est dévoyellée)"},
/* 17D2 */ { "DIACRITIQUE KHMER TCHOENG","	* indique que la lettre khmère suivante doit être souscrite à l'affichage\n"
	"	* la forme choisie est arbitraire, invisible"},
/* 17D3 */ { "DIACRITIQUE KHMER PATHAMASAT","	* destiné initialement à représenter un symbole du calendrier lunaire\n"
	"	* l'utilisation de ce caractère est déconseillée, au profit de l'ensemble complet des symboles du calendrier lunaire\n"
	"	x (symbole khmer pathamasat - 19E0)"},
/* 17D4 */ { "SIGNE KHMER KHAN","	* équivalent à un point final, un point\n"
	"	x (caractère thaï païyannoï - 0E2F)\n"
	"	x (signe birman petite section - 104A)"},
/* 17D5 */ { "SIGNE KHMER PAREIAOSAAN","	* indique la fin d'une section ou d'un texte\n"
	"	x (caractère thaï angkhankhou - 0E5A)\n"
	"	x (signe birman section - 104B)"},
/* 17D6 */ { "SIGNE KHMER TCHAMNOTCH PII KOÛH","	* s'utilise comme un deux-points\n"
	"	x (signe de division - 00F7)\n"
	"	x (signe tibétain gter tçeg - 0F14)"},
/* 17D7 */ { "SIGNE KHMER LÉÉK TOO","	* signe de répétition\n"
	"	x (caractère thaï maïyamok - 0E46)"},
/* 17D8 */ { "SIGNE KHMER PÉÉIAAL","	= lak\n"
	"	* et cetera\n"
	"	* l'utilisation de ce caractère n'est pas conseillée ; il existe d'autres abréviations d'et cetera\n"
	"	* écriture recommandée : 17D4 179B 17D4"},
/* 17D9 */ { "SIGNE KHMER PHNÈK MOEN","	= œil de coq\n"
	"	* indique le début d'un livre ou d'un traité\n"
	"	x (caractère thaï fongman - 0E4F)"},
/* 17DA */ { "SIGNE KHMER KOOMOÛT","	= urine de vache, komot, koumout\n"
	"	* indique la fin d'un livre ou d'un traité\n"
	"	* pendant de 17D9\n"
	"	x (caractère thaï khomout - 0E5B)"},
/* 17DB */ { "SYMBOLE MONÉTAIRE KHMER RIEL",NULL},
/* 17DC */ { "SIGNE KHMER AVAKRAHASAÑÑAA","	= avakraha sannya\n"
	"	* rare, indique la suppression d'une voyelle sanskrite, de la même façon qu'une apostrophe\n"
	"	x (signe dévanâgarî avagraha - 093D)"},
/* 17DD */ { "DIACRITIQUE KHMER ATTHATCHAN","	* signe moribond\n"
	"	* indique que le caractère de base correspond à la consonne finale d'un mot avec sa voyelle inhérente associée dans la prononciation\n"
	"	x (diacritique khmer viriam - 17D1)"},
/* 17DE */ { NULL,NULL},
/* 17DF */ { NULL,NULL},
/* 17E0 */ { "CHIFFRE KHMER ZÉRO",NULL},
/* 17E1 */ { "CHIFFRE KHMER UN",NULL},
/* 17E2 */ { "CHIFFRE KHMER DEUX",NULL},
/* 17E3 */ { "CHIFFRE KHMER TROIS",NULL},
/* 17E4 */ { "CHIFFRE KHMER QUATRE",NULL},
/* 17E5 */ { "CHIFFRE KHMER CINQ",NULL},
/* 17E6 */ { "CHIFFRE KHMER SIX",NULL},
/* 17E7 */ { "CHIFFRE KHMER SEPT",NULL},
/* 17E8 */ { "CHIFFRE KHMER HUIT",NULL},
/* 17E9 */ { "CHIFFRE KHMER NEUF",NULL},
/* 17EA */ { NULL,NULL},
/* 17EB */ { NULL,NULL},
/* 17EC */ { NULL,NULL},
/* 17ED */ { NULL,NULL},
/* 17EE */ { NULL,NULL},
/* 17EF */ { NULL,NULL},
/* 17F0 */ { "CHIFFRE DIVINATOIRE KHMER ZÉRO","	= léékh attak soon"},
/* 17F1 */ { "CHIFFRE DIVINATOIRE KHMER UN","	= léékh attak mouei"},
/* 17F2 */ { "CHIFFRE DIVINATOIRE KHMER DEUX","	= léékh attak pii"},
/* 17F3 */ { "CHIFFRE DIVINATOIRE KHMER TROIS","	= léékh attak bèi"},
/* 17F4 */ { "CHIFFRE DIVINATOIRE KHMER QUATRE","	= léékh attak buen"},
/* 17F5 */ { "CHIFFRE DIVINATOIRE KHMER CINQ","	= léékh attak pram"},
/* 17F6 */ { "CHIFFRE DIVINATOIRE KHMER SIX","	= léékh attak pram-mouei"},
/* 17F7 */ { "CHIFFRE DIVINATOIRE KHMER SEPT","	= léékh attak pram-pii"},
/* 17F8 */ { "CHIFFRE DIVINATOIRE KHMER HUIT","	= léékh attak pram-bèi"},
/* 17F9 */ { "CHIFFRE DIVINATOIRE KHMER NEUF","	= léékh attak pram-buen"},
/* 17FA */ { NULL,NULL},
/* 17FB */ { NULL,NULL},
/* 17FC */ { NULL,NULL},
/* 17FD */ { NULL,NULL},
/* 17FE */ { NULL,NULL},
/* 17FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_18[] = {
/* 1800 */ { "BIRGA MONGOL","	x (signe tibétain yig mgo mdoun ma ouvrant - 0F04)"},
/* 1801 */ { "POINTS DE SUSPENSION MONGOLS",NULL},
/* 1802 */ { "VIRGULE MONGOLE",NULL},
/* 1803 */ { "POINT MONGOL",NULL},
/* 1804 */ { "DEUX-POINTS MONGOL",NULL},
/* 1805 */ { "QUATRE-POINTS MONGOL","	* indique la fin d'un chapitre"},
/* 1806 */ { "TRAIT D'UNION CONDITIONNEL MONGOL TODO","	* pas un caractère de formatage, mais simplement un trait d'union pour le todo\n"
	"	* également utilisé dans le système d'écriture hudum (mongol moderne)\n"
	"	x (trait d'union conditionnel - 00AD)"},
/* 1807 */ { "SÉPARATEUR DE SYLLABES MONGOL SÎBÉ",NULL},
/* 1808 */ { "VIRGULE MONGOLE MANDCHOUE",NULL},
/* 1809 */ { "POINT MONGOL MANDCHOU",NULL},
/* 180A */ { "NIROUGOU MONGOL",NULL},
/* 180B */ { "SÉLECTEUR DE VARIANTE LIBRE MONGOL UN","	* abrégé en FVS1 (free variation selector one)"},
/* 180C */ { "SÉLECTEUR DE VARIANTE LIBRE MONGOL DEUX","	* abrégé en FVS2 (free variation selector two)"},
/* 180D */ { "SÉLECTEUR DE VARIANTE LIBRE MONGOL TROIS","	* abrégé en FVS3 (free variation selector three)"},
/* 180E */ { "SÉPARATEUR DE VOYELLES MONGOL","	* abrégé en MVS (Mongolian vowel separator)"},
/* 180F */ { "SÉLECTEUR DE VARIANTE LIBRE MONGOL QUATRE","	* abrégé en FVS4 (free variation selector four)"},
/* 1810 */ { "CHIFFRE MONGOL ZÉRO",NULL},
/* 1811 */ { "CHIFFRE MONGOL UN",NULL},
/* 1812 */ { "CHIFFRE MONGOL DEUX",NULL},
/* 1813 */ { "CHIFFRE MONGOL TROIS",NULL},
/* 1814 */ { "CHIFFRE MONGOL QUATRE",NULL},
/* 1815 */ { "CHIFFRE MONGOL CINQ",NULL},
/* 1816 */ { "CHIFFRE MONGOL SIX",NULL},
/* 1817 */ { "CHIFFRE MONGOL SEPT",NULL},
/* 1818 */ { "CHIFFRE MONGOL HUIT",NULL},
/* 1819 */ { "CHIFFRE MONGOL NEUF",NULL},
/* 181A */ { NULL,NULL},
/* 181B */ { NULL,NULL},
/* 181C */ { NULL,NULL},
/* 181D */ { NULL,NULL},
/* 181E */ { NULL,NULL},
/* 181F */ { NULL,NULL},
/* 1820 */ { "LETTRE MONGOLE A","	x (lettre minuscule cyrillique a - 0430)"},
/* 1821 */ { "LETTRE MONGOLE É","	= lettre mongole ä\n"
	"	x (lettre minuscule cyrillique é - 044D)"},
/* 1822 */ { "LETTRE MONGOLE I","	x (lettre minuscule cyrillique i - 0438)"},
/* 1823 */ { "LETTRE MONGOLE O","	x (lettre minuscule cyrillique o - 043E)"},
/* 1824 */ { "LETTRE MONGOLE OU","	x (lettre minuscule cyrillique ou - 0443)"},
/* 1825 */ { "LETTRE MONGOLE E","	= lettre mongole ö\n"
	"	x (lettre minuscule cyrillique o barré - 04E9)"},
/* 1826 */ { "LETTRE MONGOLE U","	= lettre mongole ü\n"
	"	x (lettre minuscule cyrillique ou droit - 04AF)"},
/* 1827 */ { "LETTRE MONGOLE ÉÉ",NULL},
/* 1828 */ { "LETTRE MONGOLE NA","	x (lettre minuscule cyrillique enne - 043D)"},
/* 1829 */ { "LETTRE MONGOLE ANG",NULL},
/* 182A */ { "LETTRE MONGOLE BA","	x (lettre minuscule cyrillique bé - 0431)"},
/* 182B */ { "LETTRE MONGOLE PA","	x (lettre minuscule cyrillique pé - 043F)"},
/* 182C */ { "LETTRE MONGOLE QA","	= lettre mongole xa\n"
	"	x (lettre minuscule cyrillique kha - 0445)"},
/* 182D */ { "LETTRE MONGOLE GA","	x (lettre minuscule cyrillique gué - 0433)"},
/* 182E */ { "LETTRE MONGOLE MA","	x (lettre minuscule cyrillique emme - 043C)"},
/* 182F */ { "LETTRE MONGOLE LA","	x (lettre minuscule cyrillique elle - 043B)"},
/* 1830 */ { "LETTRE MONGOLE SA","	x (lettre minuscule cyrillique esse - 0441)"},
/* 1831 */ { "LETTRE MONGOLE ÇA","	x (lettre minuscule cyrillique cha - 0448)"},
/* 1832 */ { "LETTRE MONGOLE TA","	x (lettre minuscule cyrillique té - 0442)"},
/* 1833 */ { "LETTRE MONGOLE DA","	x (lettre minuscule cyrillique dé - 0434)"},
/* 1834 */ { "LETTRE MONGOLE TCHHA","	x (lettre minuscule cyrillique tché - 0447)"},
/* 1835 */ { "LETTRE MONGOLE DJA","	x (lettre minuscule cyrillique jé - 0436)"},
/* 1836 */ { "LETTRE MONGOLE YA","	x (lettre minuscule cyrillique i bref - 0439)"},
/* 1837 */ { "LETTRE MONGOLE RA","	x (lettre minuscule cyrillique erre - 0440)"},
/* 1838 */ { "LETTRE MONGOLE WA","	x (lettre minuscule cyrillique vé - 0432)"},
/* 1839 */ { "LETTRE MONGOLE FA","	x (lettre minuscule cyrillique effe - 0444)"},
/* 183A */ { "LETTRE MONGOLE KA","	x (lettre minuscule cyrillique kha - 0445)"},
/* 183B */ { "LETTRE MONGOLE KHA","	x (lettre minuscule cyrillique ka - 043A)"},
/* 183C */ { "LETTRE MONGOLE TSA","	x (lettre minuscule cyrillique tsé - 0446)"},
/* 183D */ { "LETTRE MONGOLE ZA","	x (lettre minuscule cyrillique zé - 0437)"},
/* 183E */ { "LETTRE MONGOLE HÂ","	x (lettre minuscule cyrillique kha - 0445)"},
/* 183F */ { "LETTRE MONGOLE ZRA","	x (lettre minuscule cyrillique jé - 0436)"},
/* 1840 */ { "LETTRE MONGOLE LHA",NULL},
/* 1841 */ { "LETTRE MONGOLE ZHI",NULL},
/* 1842 */ { "LETTRE MONGOLE TCHHI",NULL},
/* 1843 */ { "LETTRE MONGOLE SIGNE DE VOYELLE LONGUE TODO",NULL},
/* 1844 */ { "LETTRE MONGOLE É TODO",NULL},
/* 1845 */ { "LETTRE MONGOLE I TODO",NULL},
/* 1846 */ { "LETTRE MONGOLE O TODO",NULL},
/* 1847 */ { "LETTRE MONGOLE OU TODO",NULL},
/* 1848 */ { "LETTRE MONGOLE E TODO","	= lettre mongole ö todo"},
/* 1849 */ { "LETTRE MONGOLE U TODO","	= lettre mongole ü todo"},
/* 184A */ { "LETTRE MONGOLE ANG TODO",NULL},
/* 184B */ { "LETTRE MONGOLE BA TODO",NULL},
/* 184C */ { "LETTRE MONGOLE PA TODO",NULL},
/* 184D */ { "LETTRE MONGOLE QA TODO","	= lettre mongole xa todo"},
/* 184E */ { "LETTRE MONGOLE GA TODO",NULL},
/* 184F */ { "LETTRE MONGOLE MA TODO",NULL},
/* 1850 */ { "LETTRE MONGOLE TA TODO",NULL},
/* 1851 */ { "LETTRE MONGOLE DA TODO",NULL},
/* 1852 */ { "LETTRE MONGOLE TCHHA TODO",NULL},
/* 1853 */ { "LETTRE MONGOLE DJA TODO",NULL},
/* 1854 */ { "LETTRE MONGOLE TSA TODO",NULL},
/* 1855 */ { "LETTRE MONGOLE YA TODO",NULL},
/* 1856 */ { "LETTRE MONGOLE WA TODO",NULL},
/* 1857 */ { "LETTRE MONGOLE KA TODO",NULL},
/* 1858 */ { "LETTRE MONGOLE GÂ TODO",NULL},
/* 1859 */ { "LETTRE MONGOLE HÂ TODO",NULL},
/* 185A */ { "LETTRE MONGOLE DJIA TODO",NULL},
/* 185B */ { "LETTRE MONGOLE NIA TODO",NULL},
/* 185C */ { "LETTRE MONGOLE DZA TODO",NULL},
/* 185D */ { "LETTRE MONGOLE É SÎBÉ",NULL},
/* 185E */ { "LETTRE MONGOLE I SÎBÉ",NULL},
/* 185F */ { "LETTRE MONGOLE IY SÎBÉ",NULL},
/* 1860 */ { "LETTRE MONGOLE U SÎBÉ","	= lettre mongole ü sîbé"},
/* 1861 */ { "LETTRE MONGOLE OU SÎBÉ",NULL},
/* 1862 */ { "LETTRE MONGOLE ANG SÎBÉ",NULL},
/* 1863 */ { "LETTRE MONGOLE KA SÎBÉ",NULL},
/* 1864 */ { "LETTRE MONGOLE GA SÎBÉ",NULL},
/* 1865 */ { "LETTRE MONGOLE HA SÎBÉ",NULL},
/* 1866 */ { "LETTRE MONGOLE PA SÎBÉ",NULL},
/* 1867 */ { "LETTRE MONGOLE ÇA SÎBÉ",NULL},
/* 1868 */ { "LETTRE MONGOLE TA SÎBÉ",NULL},
/* 1869 */ { "LETTRE MONGOLE DA SÎBÉ",NULL},
/* 186A */ { "LETTRE MONGOLE DJA SÎBÉ",NULL},
/* 186B */ { "LETTRE MONGOLE FA SÎBÉ",NULL},
/* 186C */ { "LETTRE MONGOLE GÂ SÎBÉ",NULL},
/* 186D */ { "LETTRE MONGOLE HÂ SÎBÉ",NULL},
/* 186E */ { "LETTRE MONGOLE TSA SÎBÉ",NULL},
/* 186F */ { "LETTRE MONGOLE ZA SÎBÉ",NULL},
/* 1870 */ { "LETTRE MONGOLE RÂ SÎBÉ",NULL},
/* 1871 */ { "LETTRE MONGOLE TCHHA SÎBÉ",NULL},
/* 1872 */ { "LETTRE MONGOLE ZHA SÎBÉ",NULL},
/* 1873 */ { "LETTRE MONGOLE I MANDCHOU",NULL},
/* 1874 */ { "LETTRE MONGOLE KA MANDCHOU",NULL},
/* 1875 */ { "LETTRE MONGOLE RA MANDCHOU",NULL},
/* 1876 */ { "LETTRE MONGOLE FA MANDCHOU",NULL},
/* 1877 */ { "LETTRE MONGOLE ZHA MANDCHOU",NULL},
/* 1878 */ { "LETTRE MONGOLE TCHHA AVEC DEUX POINTS",NULL},
/* 1879 */ { NULL,NULL},
/* 187A */ { NULL,NULL},
/* 187B */ { NULL,NULL},
/* 187C */ { NULL,NULL},
/* 187D */ { NULL,NULL},
/* 187E */ { NULL,NULL},
/* 187F */ { NULL,NULL},
/* 1880 */ { "LETTRE MONGOLE ANOUSVÂRA UN ALI GALI","	x (diacritique tibétain sna ldan - 0F83)"},
/* 1881 */ { "LETTRE MONGOLE VISARGA UN ALI GALI","	x (diacritique tibétain rnam btchad - 0F7F)"},
/* 1882 */ { "LETTRE MONGOLE DAMAROU ALI GALI","	x (signe tibétain ltché tsa tchan - 0F88)"},
/* 1883 */ { "LETTRE MONGOLE OUBADAMA ALI GALI",NULL},
/* 1884 */ { "LETTRE MONGOLE OUBADAMA CULBUTÉ ALI GALI","	x (signe tibétain mtch'ou tchan - 0F89)"},
/* 1885 */ { "LETTRE MONGOLE BALOUDA ALI GALI","	x (signe tibétain palouta - 0F85)"},
/* 1886 */ { "LETTRE MONGOLE TROIS BALOUDAS ALI GALI",NULL},
/* 1887 */ { "LETTRE MONGOLE A ALI GALI",NULL},
/* 1888 */ { "LETTRE MONGOLE I ALI GALI",NULL},
/* 1889 */ { "LETTRE MONGOLE KA ALI GALI",NULL},
/* 188A */ { "LETTRE MONGOLE NGA ALI GALI",NULL},
/* 188B */ { "LETTRE MONGOLE TCHA ALI GALI",NULL},
/* 188C */ { "LETTRE MONGOLE TTA ALI GALI",NULL},
/* 188D */ { "LETTRE MONGOLE TTHA ALI GALI",NULL},
/* 188E */ { "LETTRE MONGOLE DDA ALI GALI",NULL},
/* 188F */ { "LETTRE MONGOLE NNA ALI GALI",NULL},
/* 1890 */ { "LETTRE MONGOLE TA ALI GALI",NULL},
/* 1891 */ { "LETTRE MONGOLE DA ALI GALI",NULL},
/* 1892 */ { "LETTRE MONGOLE PA ALI GALI",NULL},
/* 1893 */ { "LETTRE MONGOLE PHA ALI GALI","	= lettre mongole p'a ali gali"},
/* 1894 */ { "LETTRE MONGOLE CHA ALI GALI",NULL},
/* 1895 */ { "LETTRE MONGOLE ZHA ALI GALI",NULL},
/* 1896 */ { "LETTRE MONGOLE ZA ALI GALI",NULL},
/* 1897 */ { "LETTRE MONGOLE AH ALI GALI",NULL},
/* 1898 */ { "LETTRE MONGOLE TA TODO ALI GALI",NULL},
/* 1899 */ { "LETTRE MONGOLE ZHA TODO ALI GALI",NULL},
/* 189A */ { "LETTRE MONGOLE GHA ALI GALI",NULL},
/* 189B */ { "LETTRE MONGOLE NGA MANDCHOU ALI GALI",NULL},
/* 189C */ { "LETTRE MONGOLE TCHA MANDCHOU ALI GALI",NULL},
/* 189D */ { "LETTRE MONGOLE DJHA MANDCHOU ALI GALI",NULL},
/* 189E */ { "LETTRE MONGOLE TTA MANDCHOU ALI GALI",NULL},
/* 189F */ { "LETTRE MONGOLE DDHA MANDCHOU ALI GALI",NULL},
/* 18A0 */ { "LETTRE MONGOLE TA MANDCHOU ALI GALI",NULL},
/* 18A1 */ { "LETTRE MONGOLE DHA MANDCHOU ALI GALI",NULL},
/* 18A2 */ { "LETTRE MONGOLE CHA MANDCHOU ALI GALI",NULL},
/* 18A3 */ { "LETTRE MONGOLE TCHYA MANDCHOU ALI GALI",NULL},
/* 18A4 */ { "LETTRE MONGOLE ZHA MANDCHOU ALI GALI",NULL},
/* 18A5 */ { "LETTRE MONGOLE ZA MANDCHOU ALI GALI",NULL},
/* 18A6 */ { "LETTRE MONGOLE DEMI-OU ALI GALI",NULL},
/* 18A7 */ { "LETTRE MONGOLE DEMI-YA ALI GALI",NULL},
/* 18A8 */ { "LETTRE MONGOLE BHA ALI GALI",NULL},
/* 18A9 */ { "LETTRE MONGOLE DAGALGA ALI GALI",NULL},
/* 18AA */ { "LETTRE MONGOLE MANDCHOUE LHA ALI GALI",NULL},
/* 18AB */ { NULL,NULL},
/* 18AC */ { NULL,NULL},
/* 18AD */ { NULL,NULL},
/* 18AE */ { NULL,NULL},
/* 18AF */ { NULL,NULL},
/* 18B0 */ { "SYLLABE CANADIENNE OY",NULL},
/* 18B1 */ { "SYLLABE CANADIENNE AY",NULL},
/* 18B2 */ { "SYLLABE CANADIENNE ÂY",NULL},
/* 18B3 */ { "SYLLABE CANADIENNE WAY",NULL},
/* 18B4 */ { "SYLLABE CANADIENNE POY",NULL},
/* 18B5 */ { "SYLLABE CANADIENNE PAY",NULL},
/* 18B6 */ { "SYLLABE CANADIENNE POUOY",NULL},
/* 18B7 */ { "SYLLABE CANADIENNE TAY",NULL},
/* 18B8 */ { "SYLLABE CANADIENNE KAY",NULL},
/* 18B9 */ { "SYLLABE CANADIENNE KOUAY",NULL},
/* 18BA */ { "SYLLABE CANADIENNE MAY",NULL},
/* 18BB */ { "SYLLABE CANADIENNE NOY",NULL},
/* 18BC */ { "SYLLABE CANADIENNE NAY",NULL},
/* 18BD */ { "SYLLABE CANADIENNE LAY",NULL},
/* 18BE */ { "SYLLABE CANADIENNE SOY",NULL},
/* 18BF */ { "SYLLABE CANADIENNE SAY",NULL},
/* 18C0 */ { "SYLLABE CANADIENNE SHOY",NULL},
/* 18C1 */ { "SYLLABE CANADIENNE CHAY",NULL},
/* 18C2 */ { "SYLLABE CANADIENNE CHOUOY",NULL},
/* 18C3 */ { "SYLLABE CANADIENNE YOY",NULL},
/* 18C4 */ { "SYLLABE CANADIENNE YAY",NULL},
/* 18C5 */ { "SYLLABE CANADIENNE RAY",NULL},
/* 18C6 */ { "SYLLABE CANADIENNE NOUI",NULL},
/* 18C7 */ { "SYLLABE CANADIENNE NOUI OJIBWÉ",NULL},
/* 18C8 */ { "SYLLABE CANADIENNE NOUÎ",NULL},
/* 18C9 */ { "SYLLABE CANADIENNE NOUÎ OJIBWÉ",NULL},
/* 18CA */ { "SYLLABE CANADIENNE NOUO",NULL},
/* 18CB */ { "SYLLABE CANADIENNE NOUO OJIBWÉ",NULL},
/* 18CC */ { "SYLLABE CANADIENNE NOUÔ",NULL},
/* 18CD */ { "SYLLABE CANADIENNE NOUÔ OJIBWÉ",NULL},
/* 18CE */ { "SYLLABE CANADIENNE ROUÉ",NULL},
/* 18CF */ { "SYLLABE CANADIENNE ROUI",NULL},
/* 18D0 */ { "SYLLABE CANADIENNE ROUÎ",NULL},
/* 18D1 */ { "SYLLABE CANADIENNE ROUO",NULL},
/* 18D2 */ { "SYLLABE CANADIENNE ROUÔ",NULL},
/* 18D3 */ { "SYLLABE CANADIENNE ROUA",NULL},
/* 18D4 */ { "SYLLABE CANADIENNE P OJIBWÉ",NULL},
/* 18D5 */ { "SYLLABE CANADIENNE T OJIBWÉ",NULL},
/* 18D6 */ { "SYLLABE CANADIENNE K OJIBWÉ",NULL},
/* 18D7 */ { "SYLLABE CANADIENNE TCH OJIBWÉ",NULL},
/* 18D8 */ { "SYLLABE CANADIENNE M OJIBWÉ",NULL},
/* 18D9 */ { "SYLLABE CANADIENNE N OJIBWÉ",NULL},
/* 18DA */ { "SYLLABE CANADIENNE S OJIBWÉ",NULL},
/* 18DB */ { "SYLLABE CANADIENNE CH OJIBWÉ",NULL},
/* 18DC */ { "SYLLABE CANADIENNE OU DE L'EST",NULL},
/* 18DD */ { "SYLLABE CANADIENNE OU DE L'OUEST",NULL},
/* 18DE */ { "SYLLABE CANADIENNE FINALE PETIT ROND",NULL},
/* 18DF */ { "SYLLABE CANADIENNE FINALE POINT ÉLEVÉ","	* porteur (COUP DE GLOTTE)"},
/* 18E0 */ { "SYLLABE CANADIENNE ROUE CRI-R","	* déné castor (LYE)"},
/* 18E1 */ { "SYLLABE CANADIENNE LÔ CRI DES PLAINES","	* déné tchipéwayan (LOU)"},
/* 18E2 */ { "SYLLABE CANADIENNE LÂ CRI DES PLAINES","	* déné castor (LAÏ)"},
/* 18E3 */ { "SYLLABE CANADIENNE THOUE","	* déné castor (TYE)"},
/* 18E4 */ { "SYLLABE CANADIENNE THOUA","	* déné castor (TYA)"},
/* 18E5 */ { "SYLLABE CANADIENNE TTHOUE","	* déné castor (HYE)"},
/* 18E6 */ { "SYLLABE CANADIENNE TTHÔ","	* déné tchipéwayan (TTHOU)"},
/* 18E7 */ { "SYLLABE CANADIENNE TTHÂ","	* déné castor (HAÏ)"},
/* 18E8 */ { "SYLLABE CANADIENNE TLHOUE","	* déné castor (TLYE)"},
/* 18E9 */ { "SYLLABE CANADIENNE TLHÔ","	* déné tchipéwayan (TLOU)"},
/* 18EA */ { "SYLLABE CANADIENNE CHOUE SAYISI","	* déné castor (ZYE)"},
/* 18EB */ { "SYLLABE CANADIENNE CHÔ SAYISI","	* déné tchipéwayan (CHOU)"},
/* 18EC */ { "SYLLABE CANADIENNE HÔ SAYISI","	* déné tchipéwayan (GOU)"},
/* 18ED */ { "SYLLABE CANADIENNE GOUOU PORTEUR","	* déné castor (TCHYE)"},
/* 18EE */ { "SYLLABE CANADIENNE GÉ DÉNÉ PORTEUR","	* déné tchipéwayan (TCHOU)"},
/* 18EF */ { "SYLLABE CANADIENNE GÂ PORTEUR","	* déné castor (TCHAÏ)"},
/* 18F0 */ { "SYLLABE CANADIENNE GOUA PORTEUR","	* déné lièvre (CHYA)"},
/* 18F1 */ { "SYLLABE CANADIENNE DJOÛ SAYISI","	* déné tchipéwayan (TSOU)"},
/* 18F2 */ { "SYLLABE CANADIENNE DJOUA PORTEUR","	* déné castor (TSYE)"},
/* 18F3 */ { "SYLLABE CANADIENNE L DÉNÉ CASTOR",NULL},
/* 18F4 */ { "SYLLABE CANADIENNE R DÉNÉ CASTOR",NULL},
/* 18F5 */ { "SYLLABE CANADIENNE S DENTAL PORTEUR",NULL},
/* 18F6 */ { NULL,NULL},
/* 18F7 */ { NULL,NULL},
/* 18F8 */ { NULL,NULL},
/* 18F9 */ { NULL,NULL},
/* 18FA */ { NULL,NULL},
/* 18FB */ { NULL,NULL},
/* 18FC */ { NULL,NULL},
/* 18FD */ { NULL,NULL},
/* 18FE */ { NULL,NULL},
/* 18FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_19[] = {
/* 1900 */ { "LETTRE LIMBU PORTE-VOYELLE",NULL},
/* 1901 */ { "LETTRE LIMBU KA",NULL},
/* 1902 */ { "LETTRE LIMBU KHA",NULL},
/* 1903 */ { "LETTRE LIMBU GA",NULL},
/* 1904 */ { "LETTRE LIMBU GHA",NULL},
/* 1905 */ { "LETTRE LIMBU NGA",NULL},
/* 1906 */ { "LETTRE LIMBU TCHA",NULL},
/* 1907 */ { "LETTRE LIMBU TCHHA",NULL},
/* 1908 */ { "LETTRE LIMBU DJA",NULL},
/* 1909 */ { "LETTRE LIMBU DJHA",NULL},
/* 190A */ { "LETTRE LIMBU YAN",NULL},
/* 190B */ { "LETTRE LIMBU TA",NULL},
/* 190C */ { "LETTRE LIMBU THA",NULL},
/* 190D */ { "LETTRE LIMBU DA",NULL},
/* 190E */ { "LETTRE LIMBU DHA",NULL},
/* 190F */ { "LETTRE LIMBU NA",NULL},
/* 1910 */ { "LETTRE LIMBU PA",NULL},
/* 1911 */ { "LETTRE LIMBU PHA","	= lettre limbu p'a"},
/* 1912 */ { "LETTRE LIMBU BA",NULL},
/* 1913 */ { "LETTRE LIMBU BHA",NULL},
/* 1914 */ { "LETTRE LIMBU MA",NULL},
/* 1915 */ { "LETTRE LIMBU YA",NULL},
/* 1916 */ { "LETTRE LIMBU RA",NULL},
/* 1917 */ { "LETTRE LIMBU LA",NULL},
/* 1918 */ { "LETTRE LIMBU WA",NULL},
/* 1919 */ { "LETTRE LIMBU ÇA",NULL},
/* 191A */ { "LETTRE LIMBU CHA",NULL},
/* 191B */ { "LETTRE LIMBU SA",NULL},
/* 191C */ { "LETTRE LIMBU HA",NULL},
/* 191D */ { "LETTRE LIMBU GYAN",NULL},
/* 191E */ { "LETTRE LIMBU TRA",NULL},
/* 191F */ { NULL,NULL},
/* 1920 */ { "DIACRITIQUE VOYELLE LIMBU A",NULL},
/* 1921 */ { "DIACRITIQUE VOYELLE LIMBU I",NULL},
/* 1922 */ { "DIACRITIQUE VOYELLE LIMBU OU",NULL},
/* 1923 */ { "DIACRITIQUE VOYELLE LIMBU ÉÉ",NULL},
/* 1924 */ { "DIACRITIQUE VOYELLE LIMBU AI",NULL},
/* 1925 */ { "DIACRITIQUE VOYELLE LIMBU Ô",NULL},
/* 1926 */ { "DIACRITIQUE VOYELLE LIMBU AOU",NULL},
/* 1927 */ { "DIACRITIQUE VOYELLE LIMBU È",NULL},
/* 1928 */ { "DIACRITIQUE VOYELLE LIMBU O",NULL},
/* 1929 */ { "LETTRE SUBJOINTE LIMBU YA",NULL},
/* 192A */ { "LETTRE SUBJOINTE LIMBU RA",NULL},
/* 192B */ { "LETTRE SUBJOINTE LIMBU WA",NULL},
/* 192C */ { NULL,NULL},
/* 192D */ { NULL,NULL},
/* 192E */ { NULL,NULL},
/* 192F */ { NULL,NULL},
/* 1930 */ { "PETITE LETTRE LIMBU KA",NULL},
/* 1931 */ { "PETITE LETTRE LIMBU NGA",NULL},
/* 1932 */ { "PETITE LETTRE LIMBU ANOUSVÂRA",NULL},
/* 1933 */ { "PETITE LETTRE LIMBU TA",NULL},
/* 1934 */ { "PETITE LETTRE LIMBU NA",NULL},
/* 1935 */ { "PETITE LETTRE LIMBU PA",NULL},
/* 1936 */ { "PETITE LETTRE LIMBU MA",NULL},
/* 1937 */ { "PETITE LETTRE LIMBU RA",NULL},
/* 1938 */ { "PETITE LETTRE LIMBU LA",NULL},
/* 1939 */ { "DIACRITIQUE LIMBU MOUKPHRENG",NULL},
/* 193A */ { "DIACRITIQUE LIMBU KEMPHRENG",NULL},
/* 193B */ { "DIACRITIQUE LIMBU SA-I",NULL},
/* 193C */ { NULL,NULL},
/* 193D */ { NULL,NULL},
/* 193E */ { NULL,NULL},
/* 193F */ { NULL,NULL},
/* 1940 */ { "SIGNE LIMBU LÔ",NULL},
/* 1941 */ { NULL,NULL},
/* 1942 */ { NULL,NULL},
/* 1943 */ { NULL,NULL},
/* 1944 */ { "POINT D'EXCLAMATION LIMBU",NULL},
/* 1945 */ { "POINT D'INTERROGATION LIMBU",NULL},
/* 1946 */ { "CHIFFRE LIMBU ZÉRO",NULL},
/* 1947 */ { "CHIFFRE LIMBU UN",NULL},
/* 1948 */ { "CHIFFRE LIMBU DEUX",NULL},
/* 1949 */ { "CHIFFRE LIMBU TROIS",NULL},
/* 194A */ { "CHIFFRE LIMBU QUATRE",NULL},
/* 194B */ { "CHIFFRE LIMBU CINQ",NULL},
/* 194C */ { "CHIFFRE LIMBU SIX",NULL},
/* 194D */ { "CHIFFRE LIMBU SEPT",NULL},
/* 194E */ { "CHIFFRE LIMBU HUIT",NULL},
/* 194F */ { "CHIFFRE LIMBU NEUF",NULL},
/* 1950 */ { "LETTRE TAÏ-LE KA",NULL},
/* 1951 */ { "LETTRE TAÏ-LE XA",NULL},
/* 1952 */ { "LETTRE TAÏ-LE NGA",NULL},
/* 1953 */ { "LETTRE TAÏ-LE TSA",NULL},
/* 1954 */ { "LETTRE TAÏ-LE SA",NULL},
/* 1955 */ { "LETTRE TAÏ-LE YA",NULL},
/* 1956 */ { "LETTRE TAÏ-LE TA",NULL},
/* 1957 */ { "LETTRE TAÏ-LE THA",NULL},
/* 1958 */ { "LETTRE TAÏ-LE LA",NULL},
/* 1959 */ { "LETTRE TAÏ-LE PA",NULL},
/* 195A */ { "LETTRE TAÏ-LE PHA","	= lettre taï-le p'a"},
/* 195B */ { "LETTRE TAÏ-LE MA",NULL},
/* 195C */ { "LETTRE TAÏ-LE FA",NULL},
/* 195D */ { "LETTRE TAÏ-LE VA",NULL},
/* 195E */ { "LETTRE TAÏ-LE HA",NULL},
/* 195F */ { "LETTRE TAÏ-LE 'A",NULL},
/* 1960 */ { "LETTRE TAÏ-LE KHA",NULL},
/* 1961 */ { "LETTRE TAÏ-LE TÇA",NULL},
/* 1962 */ { "LETTRE TAÏ-LE NA",NULL},
/* 1963 */ { "LETTRE TAÏ-LE A",NULL},
/* 1964 */ { "LETTRE TAÏ-LE I",NULL},
/* 1965 */ { "LETTRE TAÏ-LE É",NULL},
/* 1966 */ { "LETTRE TAÏ-LE È",NULL},
/* 1967 */ { "LETTRE TAÏ-LE OU",NULL},
/* 1968 */ { "LETTRE TAÏ-LE Ô",NULL},
/* 1969 */ { "LETTRE TAÏ-LE O",NULL},
/* 196A */ { "LETTRE TAÏ-LE U",NULL},
/* 196B */ { "LETTRE TAÏ-LE E",NULL},
/* 196C */ { "LETTRE TAÏ-LE AU",NULL},
/* 196D */ { "LETTRE TAÏ-LE AÏ",NULL},
/* 196E */ { NULL,NULL},
/* 196F */ { NULL,NULL},
/* 1970 */ { "LETTRE TAÏ-LE TON-2",NULL},
/* 1971 */ { "LETTRE TAÏ-LE TON-3",NULL},
/* 1972 */ { "LETTRE TAÏ-LE TON-4",NULL},
/* 1973 */ { "LETTRE TAÏ-LE TON-5",NULL},
/* 1974 */ { "LETTRE TAÏ-LE TON-6",NULL},
/* 1975 */ { NULL,NULL},
/* 1976 */ { NULL,NULL},
/* 1977 */ { NULL,NULL},
/* 1978 */ { NULL,NULL},
/* 1979 */ { NULL,NULL},
/* 197A */ { NULL,NULL},
/* 197B */ { NULL,NULL},
/* 197C */ { NULL,NULL},
/* 197D */ { NULL,NULL},
/* 197E */ { NULL,NULL},
/* 197F */ { NULL,NULL},
/* 1980 */ { "LETTRE NOUVEAU TAÏ LÜ QA HAUT",NULL},
/* 1981 */ { "LETTRE NOUVEAU TAÏ LÜ QA BAS",NULL},
/* 1982 */ { "LETTRE NOUVEAU TAÏ LÜ KA HAUT",NULL},
/* 1983 */ { "LETTRE NOUVEAU TAÏ LÜ XA HAUT",NULL},
/* 1984 */ { "LETTRE NOUVEAU TAÏ LÜ NGA HAUT",NULL},
/* 1985 */ { "LETTRE NOUVEAU TAÏ LÜ KA BAS",NULL},
/* 1986 */ { "LETTRE NOUVEAU TAÏ LÜ XA BAS",NULL},
/* 1987 */ { "LETTRE NOUVEAU TAÏ LÜ NGA BAS",NULL},
/* 1988 */ { "LETTRE NOUVEAU TAÏ LÜ TSA HAUT",NULL},
/* 1989 */ { "LETTRE NOUVEAU TAÏ LÜ SA HAUT",NULL},
/* 198A */ { "LETTRE NOUVEAU TAÏ LÜ YA HAUT",NULL},
/* 198B */ { "LETTRE NOUVEAU TAÏ LÜ TSA BAS",NULL},
/* 198C */ { "LETTRE NOUVEAU TAÏ LÜ SA BAS",NULL},
/* 198D */ { "LETTRE NOUVEAU TAÏ LÜ YA BAS",NULL},
/* 198E */ { "LETTRE NOUVEAU TAÏ LÜ TA HAUT",NULL},
/* 198F */ { "LETTRE NOUVEAU TAÏ LÜ THA HAUT",NULL},
/* 1990 */ { "LETTRE NOUVEAU TAÏ LÜ NA HAUT",NULL},
/* 1991 */ { "LETTRE NOUVEAU TAÏ LÜ TA BAS",NULL},
/* 1992 */ { "LETTRE NOUVEAU TAÏ LÜ THA BAS",NULL},
/* 1993 */ { "LETTRE NOUVEAU TAÏ LÜ NA BAS",NULL},
/* 1994 */ { "LETTRE NOUVEAU TAÏ LÜ PA HAUT",NULL},
/* 1995 */ { "LETTRE NOUVEAU TAÏ LÜ PHA HAUT","	= lettre nouveau taï lü p'a haut"},
/* 1996 */ { "LETTRE NOUVEAU TAÏ LÜ MA HAUT",NULL},
/* 1997 */ { "LETTRE NOUVEAU TAÏ LÜ PA BAS",NULL},
/* 1998 */ { "LETTRE NOUVEAU TAÏ LÜ PHA BAS","	= lettre nouveau taï lü p'a bas"},
/* 1999 */ { "LETTRE NOUVEAU TAÏ LÜ MA BAS",NULL},
/* 199A */ { "LETTRE NOUVEAU TAÏ LÜ FA HAUT",NULL},
/* 199B */ { "LETTRE NOUVEAU TAÏ LÜ VA HAUT",NULL},
/* 199C */ { "LETTRE NOUVEAU TAÏ LÜ LA HAUT",NULL},
/* 199D */ { "LETTRE NOUVEAU TAÏ LÜ FA BAS",NULL},
/* 199E */ { "LETTRE NOUVEAU TAÏ LÜ VA BAS",NULL},
/* 199F */ { "LETTRE NOUVEAU TAÏ LÜ LA BAS",NULL},
/* 19A0 */ { "LETTRE NOUVEAU TAÏ LÜ HA HAUT",NULL},
/* 19A1 */ { "LETTRE NOUVEAU TAÏ LÜ DA HAUT",NULL},
/* 19A2 */ { "LETTRE NOUVEAU TAÏ LÜ BA HAUT",NULL},
/* 19A3 */ { "LETTRE NOUVEAU TAÏ LÜ HA BAS",NULL},
/* 19A4 */ { "LETTRE NOUVEAU TAÏ LÜ DA BAS",NULL},
/* 19A5 */ { "LETTRE NOUVEAU TAÏ LÜ BA BAS",NULL},
/* 19A6 */ { "LETTRE NOUVEAU TAÏ LÜ KVA HAUT",NULL},
/* 19A7 */ { "LETTRE NOUVEAU TAÏ LÜ XVA HAUT",NULL},
/* 19A8 */ { "LETTRE NOUVEAU TAÏ LÜ KVA BAS",NULL},
/* 19A9 */ { "LETTRE NOUVEAU TAÏ LÜ XVA BAS",NULL},
/* 19AA */ { "LETTRE NOUVEAU TAÏ LÜ SUA HAUT",NULL},
/* 19AB */ { "LETTRE NOUVEAU TAÏ LÜ SUA BAS","	* un groupe consonantique labialisé"},
/* 19AC */ { NULL,NULL},
/* 19AD */ { NULL,NULL},
/* 19AE */ { NULL,NULL},
/* 19AF */ { NULL,NULL},
/* 19B0 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ RÉDUCTEUR DE VOYELLE",NULL},
/* 19B1 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ Â",NULL},
/* 19B2 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ Î",NULL},
/* 19B3 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ OU",NULL},
/* 19B4 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ OÛ",NULL},
/* 19B5 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ É","	* précède la consonne en ordre visuel"},
/* 19B6 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ Æ","	* précède la consonne en ordre visuel"},
/* 19B7 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ Ô","	* précède la consonne en ordre visuel"},
/* 19B8 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ O",NULL},
/* 19B9 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ U",NULL},
/* 19BA */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ AÏ","	* précède la consonne en ordre visuel"},
/* 19BB */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ ÂÏ",NULL},
/* 19BC */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ OUÏ",NULL},
/* 19BD */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ ÔÏ",NULL},
/* 19BE */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ OÏ",NULL},
/* 19BF */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ UÏ",NULL},
/* 19C0 */ { "DIACRITIQUE VOYELLE NOUVEAU TAÏ LÜ EÏ",NULL},
/* 19C1 */ { "LETTRE NOUVEAU TAÏ LÜ V FINAL",NULL},
/* 19C2 */ { "LETTRE NOUVEAU TAÏ LÜ NG FINAL",NULL},
/* 19C3 */ { "LETTRE NOUVEAU TAÏ LÜ N FINAL",NULL},
/* 19C4 */ { "LETTRE NOUVEAU TAÏ LÜ M FINAL",NULL},
/* 19C5 */ { "LETTRE NOUVEAU TAÏ LÜ K FINAL",NULL},
/* 19C6 */ { "LETTRE NOUVEAU TAÏ LÜ D FINAL",NULL},
/* 19C7 */ { "LETTRE NOUVEAU TAÏ LÜ B FINAL",NULL},
/* 19C8 */ { "DIACRITIQUE NOUVEAU TAÏ LÜ TON-1",NULL},
/* 19C9 */ { "DIACRITIQUE NOUVEAU TAÏ LÜ TON-2",NULL},
/* 19CA */ { NULL,NULL},
/* 19CB */ { NULL,NULL},
/* 19CC */ { NULL,NULL},
/* 19CD */ { NULL,NULL},
/* 19CE */ { NULL,NULL},
/* 19CF */ { NULL,NULL},
/* 19D0 */ { "CHIFFRE NOUVEAU TAÏ LÜ ZÉRO",NULL},
/* 19D1 */ { "CHIFFRE NOUVEAU TAÏ LÜ UN",NULL},
/* 19D2 */ { "CHIFFRE NOUVEAU TAÏ LÜ DEUX",NULL},
/* 19D3 */ { "CHIFFRE NOUVEAU TAÏ LÜ TROIS",NULL},
/* 19D4 */ { "CHIFFRE NOUVEAU TAÏ LÜ QUATRE",NULL},
/* 19D5 */ { "CHIFFRE NOUVEAU TAÏ LÜ CINQ",NULL},
/* 19D6 */ { "CHIFFRE NOUVEAU TAÏ LÜ SIX",NULL},
/* 19D7 */ { "CHIFFRE NOUVEAU TAÏ LÜ SEPT",NULL},
/* 19D8 */ { "CHIFFRE NOUVEAU TAÏ LÜ HUIT",NULL},
/* 19D9 */ { "CHIFFRE NOUVEAU TAÏ LÜ NEUF",NULL},
/* 19DA */ { "CHIFFRE NOUVEAU TAÏ LÜ THAM UN",NULL},
/* 19DB */ { NULL,NULL},
/* 19DC */ { NULL,NULL},
/* 19DD */ { NULL,NULL},
/* 19DE */ { "SIGNE NOUVEAU TAÏ LÜ LÊ","	* conjonction : et"},
/* 19DF */ { "SIGNE NOUVEAU TAÏ LÜ LÊV","	* perfectif"},
/* 19E0 */ { "SYMBOLE KHMER PATHAMASAT","	* représente le premier août des années bissextiles\n"
	"		Les quinze caractères suivants représentent les quinze jours de lune croissante."},
/* 19E1 */ { "SYMBOLE KHMER PREMIÈRE LUNE CROISSANTE","	= mouei khneut"},
/* 19E2 */ { "SYMBOLE KHMER DEUXIÈME LUNE CROISSANTE","	= pii khneut"},
/* 19E3 */ { "SYMBOLE KHMER TROISIÈME LUNE CROISSANTE","	= bèi khneut"},
/* 19E4 */ { "SYMBOLE KHMER QUATRIÈME LUNE CROISSANTE","	= buen khneut"},
/* 19E5 */ { "SYMBOLE KHMER CINQUIÈME LUNE CROISSANTE","	= pram khneut"},
/* 19E6 */ { "SYMBOLE KHMER SIXIÈME LUNE CROISSANTE","	= pram-mouei khneut"},
/* 19E7 */ { "SYMBOLE KHMER SEPTIÈME LUNE CROISSANTE","	= pram-pii khneut"},
/* 19E8 */ { "SYMBOLE KHMER HUITIÈME LUNE CROISSANTE","	= pram-bèi khneut"},
/* 19E9 */ { "SYMBOLE KHMER NEUVIÈME LUNE CROISSANTE","	= pram-buen khneut"},
/* 19EA */ { "SYMBOLE KHMER DIXIÈME LUNE CROISSANTE","	= dâp khneut"},
/* 19EB */ { "SYMBOLE KHMER ONZIÈME LUNE CROISSANTE","	= dâp-mouei khneut"},
/* 19EC */ { "SYMBOLE KHMER DOUZIÈME LUNE CROISSANTE","	= dâp-pii khneut"},
/* 19ED */ { "SYMBOLE KHMER TREIZIÈME LUNE CROISSANTE","	= dâp-bèi khneut"},
/* 19EE */ { "SYMBOLE KHMER QUATORZIÈME LUNE CROISSANTE","	= dâp-buen khneut"},
/* 19EF */ { "SYMBOLE KHMER QUINZIÈME LUNE CROISSANTE","	= dâp-pram khneut"},
/* 19F0 */ { "SYMBOLE KHMER TUTEYASAT","	* représente le deux août des années bissextiles\n"
	"		Les quinze caractères suivants représentent les quinze jours de lune décroissante."},
/* 19F1 */ { "SYMBOLE KHMER PREMIÈRE LUNE DÉCROISSANTE","	= mouei rootch"},
/* 19F2 */ { "SYMBOLE KHMER DEUXIÈME LUNE DÉCROISSANTE","	= pii rootch"},
/* 19F3 */ { "SYMBOLE KHMER TROISIÈME LUNE DÉCROISSANTE","	= bèi rootch"},
/* 19F4 */ { "SYMBOLE KHMER QUATRIÈME LUNE DÉCROISSANTE","	= buen rootch"},
/* 19F5 */ { "SYMBOLE KHMER CINQUIÈME LUNE DÉCROISSANTE","	= pram rootch"},
/* 19F6 */ { "SYMBOLE KHMER SIXIÈME LUNE DÉCROISSANTE","	= pram-moeui rootch"},
/* 19F7 */ { "SYMBOLE KHMER SEPTIÈME LUNE DÉCROISSANTE","	= pram-pii rootch"},
/* 19F8 */ { "SYMBOLE KHMER HUITIÈME LUNE DÉCROISSANTE","	= pram-bèi rootch"},
/* 19F9 */ { "SYMBOLE KHMER NEUVIÈME LUNE DÉCROISSANTE","	= pram-buen rootch"},
/* 19FA */ { "SYMBOLE KHMER DIXIÈME LUNE DÉCROISSANTE","	= dâp rootch"},
/* 19FB */ { "SYMBOLE KHMER ONZIÈME LUNE DÉCROISSANTE","	= dâp-moei rootch"},
/* 19FC */ { "SYMBOLE KHMER DOUZIÈME LUNE DÉCROISSANTE","	= dâp-pii rootch"},
/* 19FD */ { "SYMBOLE KHMER TREIZIÈME LUNE DÉCROISSANTE","	= dâp-bèi rootch"},
/* 19FE */ { "SYMBOLE KHMER QUATORZIÈME LUNE DÉCROISSANTE","	= dâp-buen rootch"},
/* 19FF */ { "SYMBOLE KHMER QUINZIÈME LUNE DÉCROISSANTE","	= dâp-pram rootch"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_1A[] = {
/* 1A00 */ { "LETTRE BOUGUIE KA",NULL},
/* 1A01 */ { "LETTRE BOUGUIE GA",NULL},
/* 1A02 */ { "LETTRE BOUGUIE NGA",NULL},
/* 1A03 */ { "LETTRE BOUGUIE NGKA",NULL},
/* 1A04 */ { "LETTRE BOUGUIE PA",NULL},
/* 1A05 */ { "LETTRE BOUGUIE BA",NULL},
/* 1A06 */ { "LETTRE BOUGUIE MA",NULL},
/* 1A07 */ { "LETTRE BOUGUIE MPA",NULL},
/* 1A08 */ { "LETTRE BOUGUIE TA",NULL},
/* 1A09 */ { "LETTRE BOUGUIE DA",NULL},
/* 1A0A */ { "LETTRE BOUGUIE NA",NULL},
/* 1A0B */ { "LETTRE BOUGUIE NRA",NULL},
/* 1A0C */ { "LETTRE BOUGUIE TCHA",NULL},
/* 1A0D */ { "LETTRE BOUGUIE DJA",NULL},
/* 1A0E */ { "LETTRE BOUGUIE ÑA",NULL},
/* 1A0F */ { "LETTRE BOUGUIE ÑTCHA",NULL},
/* 1A10 */ { "LETTRE BOUGUIE YA",NULL},
/* 1A11 */ { "LETTRE BOUGUIE RA",NULL},
/* 1A12 */ { "LETTRE BOUGUIE LA",NULL},
/* 1A13 */ { "LETTRE BOUGUIE VA",NULL},
/* 1A14 */ { "LETTRE BOUGUIE SA",NULL},
/* 1A15 */ { "LETTRE BOUGUIE A",NULL},
/* 1A16 */ { "LETTRE BOUGUIE HA",NULL},
/* 1A17 */ { "DIACRITIQUE VOYELLE BOUGUIE I",NULL},
/* 1A18 */ { "DIACRITIQUE VOYELLE BOUGUIE OU",NULL},
/* 1A19 */ { "DIACRITIQUE VOYELLE BOUGUIE É",NULL},
/* 1A1A */ { "DIACRITIQUE VOYELLE BOUGUIE O",NULL},
/* 1A1B */ { "DIACRITIQUE VOYELLE BOUGUIE E",NULL},
/* 1A1C */ { NULL,NULL},
/* 1A1D */ { NULL,NULL},
/* 1A1E */ { "PALLAWA BOUGUI",NULL},
/* 1A1F */ { "FIN DE SECTION BOUGUIE",NULL},
/* 1A20 */ { "LETTRE TAÏ-THAM KA HAUT",NULL},
/* 1A21 */ { "LETTRE TAÏ-THAM KHA HAUT",NULL},
/* 1A22 */ { "LETTRE TAÏ-THAM KXA HAUT",NULL},
/* 1A23 */ { "LETTRE TAÏ-THAM KA BAS",NULL},
/* 1A24 */ { "LETTRE TAÏ-THAM KXA BAS",NULL},
/* 1A25 */ { "LETTRE TAÏ-THAM KHA BAS",NULL},
/* 1A26 */ { "LETTRE TAÏ-THAM NGA",NULL},
/* 1A27 */ { "LETTRE TAÏ-THAM TCHA HAUT",NULL},
/* 1A28 */ { "LETTRE TAÏ-THAM TCHHA HAUT",NULL},
/* 1A29 */ { "LETTRE TAÏ-THAM TCHA BAS",NULL},
/* 1A2A */ { "LETTRE TAÏ-THAM SA BAS",NULL},
/* 1A2B */ { "LETTRE TAÏ-THAM TCHHA BAS",NULL},
/* 1A2C */ { "LETTRE TAÏ-THAM ÑA",NULL},
/* 1A2D */ { "LETTRE TAÏ-THAM RATA",NULL},
/* 1A2E */ { "LETTRE TAÏ-THAM RATHA HAUT","	* une variante avec la partie supérieure qui a la forme de 1A33 est utilisée en Thaïlande et au Laos\n"
	"	* contraste avec la séquence 1A2D 1A5B"},
/* 1A2F */ { "LETTRE TAÏ-THAM DA",NULL},
/* 1A30 */ { "LETTRE TAÏ-THAM RATHA BAS",NULL},
/* 1A31 */ { "LETTRE TAÏ-THAM RANA",NULL},
/* 1A32 */ { "LETTRE TAÏ-THAM TA HAUT",NULL},
/* 1A33 */ { "LETTRE TAÏ-THAM THA HAUT",NULL},
/* 1A34 */ { "LETTRE TAÏ-THAM TA BAS",NULL},
/* 1A35 */ { "LETTRE TAÏ-THAM THA BAS",NULL},
/* 1A36 */ { "LETTRE TAÏ-THAM NA",NULL},
/* 1A37 */ { "LETTRE TAÏ-THAM BA",NULL},
/* 1A38 */ { "LETTRE TAÏ-THAM PA HAUT",NULL},
/* 1A39 */ { "LETTRE TAÏ-THAM PHA HAUT","	= lettre taï-tham p'a haut"},
/* 1A3A */ { "LETTRE TAÏ-THAM FA HAUT",NULL},
/* 1A3B */ { "LETTRE TAÏ-THAM PA BAS",NULL},
/* 1A3C */ { "LETTRE TAÏ-THAM FA BAS",NULL},
/* 1A3D */ { "LETTRE TAÏ-THAM PHA BAS","	= lettre taï-tham p'a bas"},
/* 1A3E */ { "LETTRE TAÏ-THAM MA",NULL},
/* 1A3F */ { "LETTRE TAÏ-THAM YA BAS",NULL},
/* 1A40 */ { "LETTRE TAÏ-THAM YA HAUT",NULL},
/* 1A41 */ { "LETTRE TAÏ-THAM RA",NULL},
/* 1A42 */ { "LETTRE TAÏ-THAM RU",NULL},
/* 1A43 */ { "LETTRE TAÏ-THAM LA",NULL},
/* 1A44 */ { "LETTRE TAÏ-THAM LU",NULL},
/* 1A45 */ { "LETTRE TAÏ-THAM WA",NULL},
/* 1A46 */ { "LETTRE TAÏ-THAM ÇA HAUT",NULL},
/* 1A47 */ { "LETTRE TAÏ-THAM CHA HAUT",NULL},
/* 1A48 */ { "LETTRE TAÏ-THAM SA HAUT",NULL},
/* 1A49 */ { "LETTRE TAÏ-THAM HA HAUT",NULL},
/* 1A4A */ { "LETTRE TAÏ-THAM LLA",NULL},
/* 1A4B */ { "LETTRE TAÏ-THAM A","	* indique une consonne glottale"},
/* 1A4C */ { "LETTRE TAÏ-THAM HA BAS",NULL},
/* 1A4D */ { "LETTRE TAÏ-THAM I",NULL},
/* 1A4E */ { "LETTRE TAÏ-THAM Î",NULL},
/* 1A4F */ { "LETTRE TAÏ-THAM OU",NULL},
/* 1A50 */ { "LETTRE TAÏ-THAM OÛ",NULL},
/* 1A51 */ { "LETTRE TAÏ-THAM ÉÉ",NULL},
/* 1A52 */ { "LETTRE TAÏ-THAM Ô",NULL},
/* 1A53 */ { "LETTRE TAÏ-THAM LÆ",NULL},
/* 1A54 */ { "LETTRE TAÏ-THAM GRAND SA",NULL},
/* 1A55 */ { "DIACRITIQUE CONSONNE TAÏ-THAM RA MÉDIAL",NULL},
/* 1A56 */ { "DIACRITIQUE CONSONNE TAÏ-THAM LA MÉDIAL",NULL},
/* 1A57 */ { "DIACRITIQUE CONSONNE TAÏ-THAM LA TANG LAÏ",NULL},
/* 1A58 */ { "DIACRITIQUE TAÏ-THAM MAÏ KANG LAÏ",NULL},
/* 1A59 */ { "DIACRITIQUE CONSONNE TAÏ-THAM NGA FINAL",NULL},
/* 1A5A */ { "DIACRITIQUE CONSONNE TAÏ-THAM PA BAS",NULL},
/* 1A5B */ { "DIACRITIQUE CONSONNE TAÏ-THAM RATHA HAUT OU PA BAS",NULL},
/* 1A5C */ { "DIACRITIQUE CONSONNE TAÏ-THAM MA",NULL},
/* 1A5D */ { "DIACRITIQUE CONSONNE TAÏ-THAM BA",NULL},
/* 1A5E */ { "DIACRITIQUE CONSONNE TAÏ-THAM SA",NULL},
/* 1A5F */ { NULL,NULL},
/* 1A60 */ { "DIACRITIQUE TAÏ-THAM SAKOT",NULL},
/* 1A61 */ { "DIACRITIQUE VOYELLE TAÏ-THAM A",NULL},
/* 1A62 */ { "DIACRITIQUE VOYELLE TAÏ-THAM MAÏ SAT",NULL},
/* 1A63 */ { "DIACRITIQUE VOYELLE TAÏ-THAM Â",NULL},
/* 1A64 */ { "DIACRITIQUE VOYELLE TAÏ-THAM GRAND Â",NULL},
/* 1A65 */ { "DIACRITIQUE VOYELLE TAÏ-THAM I",NULL},
/* 1A66 */ { "DIACRITIQUE VOYELLE TAÏ-THAM Î",NULL},
/* 1A67 */ { "DIACRITIQUE VOYELLE TAÏ-THAM U",NULL},
/* 1A68 */ { "DIACRITIQUE VOYELLE TAÏ-THAM Û",NULL},
/* 1A69 */ { "DIACRITIQUE VOYELLE TAÏ-THAM OU",NULL},
/* 1A6A */ { "DIACRITIQUE VOYELLE TAÏ-THAM OÛ",NULL},
/* 1A6B */ { "DIACRITIQUE VOYELLE TAÏ-THAM O",NULL},
/* 1A6C */ { "DIACRITIQUE VOYELLE TAÏ-THAM OA SOUSCRIT",NULL},
/* 1A6D */ { "DIACRITIQUE VOYELLE TAÏ-THAM ÔÏ",NULL},
/* 1A6E */ { "DIACRITIQUE VOYELLE TAÏ-THAM É",NULL},
/* 1A6F */ { "DIACRITIQUE VOYELLE TAÏ-THAM Æ",NULL},
/* 1A70 */ { "DIACRITIQUE VOYELLE TAÏ-THAM Ô",NULL},
/* 1A71 */ { "DIACRITIQUE VOYELLE TAÏ-THAM AÏ",NULL},
/* 1A72 */ { "DIACRITIQUE VOYELLE TAÏ-THAM THAM AÏ",NULL},
/* 1A73 */ { "DIACRITIQUE VOYELLE TAÏ-THAM OA SUSCRIT",NULL},
/* 1A74 */ { "DIACRITIQUE TAÏ-THAM MAÏ KANG",NULL},
/* 1A75 */ { "DIACRITIQUE TAÏ-THAM TON-1",NULL},
/* 1A76 */ { "DIACRITIQUE TAÏ-THAM TON-2",NULL},
/* 1A77 */ { "DIACRITIQUE TAÏ-THAM KHÜN TON-3",NULL},
/* 1A78 */ { "DIACRITIQUE TAÏ-THAM KHÜN TON-4",NULL},
/* 1A79 */ { "DIACRITIQUE TAÏ-THAM KHÜN TON-5",NULL},
/* 1A7A */ { "DIACRITIQUE TAÏ-THAM RA HÂM","	* indique que le ou les caractères suivants sont muets"},
/* 1A7B */ { "DIACRITIQUE TAÏ-THAM MAÏ SAM",NULL},
/* 1A7C */ { "DIACRITIQUE TAÏ-THAM KHÜN-LÜ KARAN",NULL},
/* 1A7D */ { NULL,NULL},
/* 1A7E */ { NULL,NULL},
/* 1A7F */ { "DIACRITIQUE TAÏ-THAM POINT CRYPTOGRAPHIQUE",NULL},
/* 1A80 */ { "CHIFFRE TAÏ-THAM HORA ZÉRO",NULL},
/* 1A81 */ { "CHIFFRE TAÏ-THAM HORA UN",NULL},
/* 1A82 */ { "CHIFFRE TAÏ-THAM HORA DEUX",NULL},
/* 1A83 */ { "CHIFFRE TAÏ-THAM HORA TROIS",NULL},
/* 1A84 */ { "CHIFFRE TAÏ-THAM HORA QUATRE",NULL},
/* 1A85 */ { "CHIFFRE TAÏ-THAM HORA CINQ",NULL},
/* 1A86 */ { "CHIFFRE TAÏ-THAM HORA SIX",NULL},
/* 1A87 */ { "CHIFFRE TAÏ-THAM HORA SEPT",NULL},
/* 1A88 */ { "CHIFFRE TAÏ-THAM HORA HUIT",NULL},
/* 1A89 */ { "CHIFFRE TAÏ-THAM HORA NEUF",NULL},
/* 1A8A */ { NULL,NULL},
/* 1A8B */ { NULL,NULL},
/* 1A8C */ { NULL,NULL},
/* 1A8D */ { NULL,NULL},
/* 1A8E */ { NULL,NULL},
/* 1A8F */ { NULL,NULL},
/* 1A90 */ { "CHIFFRE TAÏ-THAM THAM ZÉRO",NULL},
/* 1A91 */ { "CHIFFRE TAÏ-THAM THAM UN",NULL},
/* 1A92 */ { "CHIFFRE TAÏ-THAM THAM DEUX",NULL},
/* 1A93 */ { "CHIFFRE TAÏ-THAM THAM TROIS",NULL},
/* 1A94 */ { "CHIFFRE TAÏ-THAM THAM QUATRE",NULL},
/* 1A95 */ { "CHIFFRE TAÏ-THAM THAM CINQ",NULL},
/* 1A96 */ { "CHIFFRE TAÏ-THAM THAM SIX",NULL},
/* 1A97 */ { "CHIFFRE TAÏ-THAM THAM SEPT",NULL},
/* 1A98 */ { "CHIFFRE TAÏ-THAM THAM HUIT",NULL},
/* 1A99 */ { "CHIFFRE TAÏ-THAM THAM NEUF",NULL},
/* 1A9A */ { NULL,NULL},
/* 1A9B */ { NULL,NULL},
/* 1A9C */ { NULL,NULL},
/* 1A9D */ { NULL,NULL},
/* 1A9E */ { NULL,NULL},
/* 1A9F */ { NULL,NULL},
/* 1AA0 */ { "SIGNE TAÏ-THAM WIANG","	* logogramme pour ville"},
/* 1AA1 */ { "SIGNE TAÏ-THAM WIANGWÂK","	* logogramme pour village"},
/* 1AA2 */ { "SIGNE TAÏ-THAM SAWAN","	* logogramme pour le ciel"},
/* 1AA3 */ { "SIGNE TAÏ-THAM KÉOW","	= cour"},
/* 1AA4 */ { "SIGNE TAÏ-THAM HÔÏ","	= huître"},
/* 1AA5 */ { "SIGNE TAÏ-THAM DOKMAÏ","	= fleur\n"
	"	x (point-fleur - 2055)"},
/* 1AA6 */ { "SIGNE TAÏ-THAM RANA COUCHÉ RÉFLÉCHI",NULL},
/* 1AA7 */ { "SIGNE TAÏ-THAM MAÏ YAMOK","	x (caractère thaï maïyamok - 0E46)"},
/* 1AA8 */ { "SIGNE TAÏ-THAM KÂN","	* danda"},
/* 1AA9 */ { "SIGNE TAÏ-THAM KÂNKOÛ","	* double danda"},
/* 1AAA */ { "SIGNE TAÏ-THAM SATKÂN",NULL},
/* 1AAB */ { "SIGNE TAÏ-THAM SATKÂNKOÛ","	x (caractère thaï angkhankhou - 0E5A)"},
/* 1AAC */ { "SIGNE TAÏ-THAM HANG","	* s'utilise en combinaison avec d'autres signes de ponctuation à la fin des sections"},
/* 1AAD */ { "SIGNE TAÏ-THAM TCHÂNG",NULL},
/* 1AAE */ { NULL,NULL},
/* 1AAF */ { NULL,NULL},
/* 1AB0 */ { "DIACRITIQUE DOUBLE ACCENT CIRCONFLEXE",NULL},
/* 1AB1 */ { "DIACRITIQUE TRÉMA-ROND",NULL},
/* 1AB2 */ { "DIACRITIQUE INFINI",NULL},
/* 1AB3 */ { "DIACRITIQUE FLÈCHE VERS LE BAS","	* à l'origine, une mauvaise interprétation d'une séquence caron-accent aigu en dialectologie croate\n"
	"	* pour la dialectologie croate, utiliser plutôt la séquence 030C 0301"},
/* 1AB4 */ { "DIACRITIQUE TRIPLE POINT",NULL},
/* 1AB5 */ { "DIACRITIQUE DEUX X SOUSCRITS",NULL},
/* 1AB6 */ { "DIACRITIQUE LIGNE ONDULÉE SOUSCRITE",NULL},
/* 1AB7 */ { "DIACRITIQUE OUVERTURE SOUSCRITE","	x (diacritique ogonek - 0328)\n"
	"	x (diacritique grec iota souscrit - 0345)"},
/* 1AB8 */ { "DIACRITIQUE DOUBLE OUVERTURE SOUSCRITE",NULL},
/* 1AB9 */ { "DIACRITIQUE TRAIT DE CENTRALISATION LÉGER SOUSCRIT",NULL},
/* 1ABA */ { "DIACRITIQUE TRAIT DE CENTRALISATION FORT SOUSCRIT",NULL},
/* 1ABB */ { "DIACRITIQUE PARENTHÈSES SUSCRITES","	* destiné à encadrer un diacritique suscrit"},
/* 1ABC */ { "DIACRITIQUE DOUBLES PARENTHÈSES SUSCRITES",NULL},
/* 1ABD */ { "DIACRITIQUE PARENTHÈSES SOUSCRITES","	* destiné à encadrer un diacritique souscrit"},
/* 1ABE */ { "DIACRITIQUE PARENTHÈSES COUVRANTES","	* destiné à encadrer une lettre de base\n"
	"	* le placement exact dépend de la police"},
/* 1ABF */ { "DIACRITIQUE LETTRE MINUSCULE LATINE W SOUSCRIT","	* indique une labialisation sonore\n"
	"	x (lettre modificative minuscule w - 02B7)"},
/* 1AC0 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE W CULBUTÉ SOUSCRIT","	* indique une labialisation sourde"},
/* 1AC1 */ { "DIACRITIQUE PARENTHÈSE GAUCHE EN CHEF À GAUCHE",NULL},
/* 1AC2 */ { "DIACRITIQUE PARENTHÈSE DROITE EN CHEF À DROITE",NULL},
/* 1AC3 */ { "DIACRITIQUE PARENTHÈSE GAUCHE SOUSCRITE À GAUCHE",NULL},
/* 1AC4 */ { "DIACRITIQUE PARENTHÈSE DROITE SOUSCRITE À DROITE",NULL},
/* 1AC5 */ { "DIACRITIQUE CROCHETS EN CHEF","	* destiné à encadrer un diacritique suscrit\n"
	"	* utilisé pour indiquer la suppression d'un accent dans la translittération du japonais"},
/* 1AC6 */ { "DIACRITIQUE CROISILLON EN CHEF","	= croisillon suscrit"},
/* 1AC7 */ { "DIACRITIQUE OMÉGA EN CHEF","	= diacritique double voûte inversée en chef\n"
	"	= diacritique w en chef\n"
	"	x (diacritique oméga souscrit - 032B)\n"
	"	x (diacritique lettre minuscule latine w - 1DF1)"},
/* 1AC8 */ { "DIACRITIQUE SIGNE PLUS EN CHEF","	x (diacritique signe plus souscrit - 031F)"},
/* 1AC9 */ { "DIACRITIQUE DOUBLE SIGNE PLUS EN CHEF",NULL},
/* 1ACA */ { "DIACRITIQUE DOUBLE SIGNE PLUS SOUSCRIT",NULL},
/* 1ACB */ { "DIACRITIQUE TRIPLE ACCENT AIGU","	x (diacritique double accent aigu - 030B)"},
/* 1ACC */ { "DIACRITIQUE LETTRE MINUSCULE LATINE G INSULAIRE",NULL},
/* 1ACD */ { "DIACRITIQUE LETTRE MINUSCULE LATINE R INSULAIRE",NULL},
/* 1ACE */ { "DIACRITIQUE LETTRE MINUSCULE LATINE T INSULAIRE",NULL},
/* 1ACF */ { "DIACRITIQUE DOUBLE CARON",NULL},
/* 1AD0 */ { "DIACRITIQUE LIGNE-VERTICALE-AIGU",NULL},
/* 1AD1 */ { "DIACRITIQUE GRAVE-LIGNE-VERTICALE",NULL},
/* 1AD2 */ { "DIACRITIQUE LIGNE-VERTICALE-GRAVE",NULL},
/* 1AD3 */ { "DIACRITIQUE AIGU-LIGNE-VERTICALE",NULL},
/* 1AD4 */ { "DIACRITIQUE LIGNE-VERTICALE-MACRON",NULL},
/* 1AD5 */ { "DIACRITIQUE MACRON-LIGNE-VERTICALE",NULL},
/* 1AD6 */ { "DIACRITIQUE LIGNE-VERTICALE-AIGU-GRAVE",NULL},
/* 1AD7 */ { "DIACRITIQUE LIGNE-VERTICALE-GRAVE-AIGU",NULL},
/* 1AD8 */ { "DIACRITIQUE MACRON-AIGU-GRAVE",NULL},
/* 1AD9 */ { "DIACRITIQUE DIÈSE",NULL},
/* 1ADA */ { "DIACRITIQUE BÉMOL",NULL},
/* 1ADB */ { "DIACRITIQUE TAQUET VERS LE BAS EN CHEF","	x (diacritique taquet vers le bas souscrit - 031E)"},
/* 1ADC */ { "DIACRITIQUE TRÉMA AVEC POINT ÉLEVÉ À GAUCHE",NULL},
/* 1ADD */ { "DIACRITIQUE POINT-ET-ROND SOUSCRIT",NULL},
/* 1ADE */ { NULL,NULL},
/* 1ADF */ { NULL,NULL},
/* 1AE0 */ { "DIACRITIQUE TAQUET À GAUCHE EN CHEF","	x (diacritique taquet à gauche souscrit - 0318)\n"
	"	x (diacritique cyrillique psili pneumata - 0486)\n"
	"	x (diacritique copte esprit doux - 2CF1)"},
/* 1AE1 */ { "DIACRITIQUE TAQUET Á DROITE EN CHEF","	x (diacritique taquet à droite souscrit - 0319)\n"
	"	x (diacritique cyrillique dasia pneumata - 0485)\n"
	"	x (diacritique copte esprit rude - 2CF0)"},
/* 1AE2 */ { "DIACRITIQUE SIGNE MOINS EN CHEF","	x (diacritique macron - 0304)\n"
	"	x (diacritique signe moins souscrit - 0320)"},
/* 1AE3 */ { "DIACRITIQUE PONTET RENVERSÉ EN CHEF","	x (diacritique pontet renversé souscrit - 033A)"},
/* 1AE4 */ { "DIACRITIQUE CARRÉ EN CHEF","	x (diacritique carré souscrit - 033B)"},
/* 1AE5 */ { "DIACRITIQUE MOUETTE EN CHEF","	x (diacritique mouette souscrite - 033C)"},
/* 1AE6 */ { "DIACRITIQUE DOUBLE VOÛTE SOUSCRITE","	= oméga culbuté souscrit\n"
	"	x (diacritique oméga souscrit - 032B)\n"
	"	x (diacritique mouette souscrite - 033C)"},
/* 1AE7 */ { "DIACRITIQUE DOUBLE VOÛTE EN CHEF","	= oméga culbuté en chef"},
/* 1AE8 */ { "DIACRITIQUE SIGNE ÉGAL EN CHEF","	x (diacritique signe égal souscrit - 0347)"},
/* 1AE9 */ { "DIACRITIQUE ANGLE GAUCHE CENTRÉ EN CHEF","	x (diacritique angle gauche en chef - 031A)\n"
	"	x (diacritique angle gauche souscrit - 0349)"},
/* 1AEA */ { "DIACRITIQUE FLÈCHE VERS LE HAUT EN CHEF","	x (diacritique flèche vers le haut souscrite - 034E)"},
/* 1AEB */ { "DIACRITIQUE DOUBLE FLÈCHE VERS LA DROITE EN CHEF","	x (diacritique double flèche vers la droite souscrite - 0362)"},
/* 1AEC */ { NULL,NULL},
/* 1AED */ { NULL,NULL},
/* 1AEE */ { NULL,NULL},
/* 1AEF */ { NULL,NULL},
/* 1AF0 */ { NULL,NULL},
/* 1AF1 */ { NULL,NULL},
/* 1AF2 */ { NULL,NULL},
/* 1AF3 */ { NULL,NULL},
/* 1AF4 */ { NULL,NULL},
/* 1AF5 */ { NULL,NULL},
/* 1AF6 */ { NULL,NULL},
/* 1AF7 */ { NULL,NULL},
/* 1AF8 */ { NULL,NULL},
/* 1AF9 */ { NULL,NULL},
/* 1AFA */ { NULL,NULL},
/* 1AFB */ { NULL,NULL},
/* 1AFC */ { NULL,NULL},
/* 1AFD */ { NULL,NULL},
/* 1AFE */ { NULL,NULL},
/* 1AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_1B[] = {
/* 1B00 */ { "DIACRITIQUE BALINAIS ULU RICEM","	= ardhatchandra"},
/* 1B01 */ { "DIACRITIQUE BALINAIS ULU CANDRA","	= tchandrabindou"},
/* 1B02 */ { "DIACRITIQUE BALINAIS CECEK","	= anousvâra"},
/* 1B03 */ { "DIACRITIQUE BALINAIS SURANG","	= r final\n"
	"	* également utilisé pour le repha dans la translittération du kawi\n"
	"	x (diacritique javanais layar - A982)"},
/* 1B04 */ { "DIACRITIQUE BALINAIS BISAH","	= visarga"},
/* 1B05 */ { "LETTRE BALINAISE AKARA","	= a"},
/* 1B06 */ { "LETTRE BALINAISE AKARA TEDUNG","	= â\n"
	"	: 1B05 1B35"},
/* 1B07 */ { "LETTRE BALINAISE IKARA","	= i"},
/* 1B08 */ { "LETTRE BALINAISE IKARA TEDUNG","	= î\n"
	"	: 1B07 1B35"},
/* 1B09 */ { "LETTRE BALINAISE UKARA","	= ou"},
/* 1B0A */ { "LETTRE BALINAISE UKARA TEDUNG","	= oû\n"
	"	: 1B09 1B35"},
/* 1B0B */ { "LETTRE BALINAISE RA REPA","	= r vocalique"},
/* 1B0C */ { "LETTRE BALINAISE RA REPA TEDUNG","	= rr vocalique\n"
	"	: 1B0B 1B35"},
/* 1B0D */ { "LETTRE BALINAISE LA LENGA","	= l vocalique"},
/* 1B0E */ { "LETTRE BALINAISE LA LENGA TEDUNG","	= ll vocalique\n"
	"	: 1B0D 1B35"},
/* 1B0F */ { "LETTRE BALINAISE EKARA","	= é"},
/* 1B10 */ { "LETTRE BALINAISE AIKARA","	= aï"},
/* 1B11 */ { "LETTRE BALINAISE OKARA","	= o"},
/* 1B12 */ { "LETTRE BALINAISE OKARA TEDUNG","	= aou\n"
	"	: 1B11 1B35"},
/* 1B13 */ { "LETTRE BALINAISE KA",NULL},
/* 1B14 */ { "LETTRE BALINAISE KA MAHAPRANA","	= kha"},
/* 1B15 */ { "LETTRE BALINAISE GA",NULL},
/* 1B16 */ { "LETTRE BALINAISE GA GORA","	= gha"},
/* 1B17 */ { "LETTRE BALINAISE NGA",NULL},
/* 1B18 */ { "LETTRE BALINAISE CA",NULL},
/* 1B19 */ { "LETTRE BALINAISE CA LACA","	= tcha"},
/* 1B1A */ { "LETTRE BALINAISE JA",NULL},
/* 1B1B */ { "LETTRE BALINAISE JA JERA","	= dja"},
/* 1B1C */ { "LETTRE BALINAISE ÑA",NULL},
/* 1B1D */ { "LETTRE BALINAISE TA LATIK","	= tta"},
/* 1B1E */ { "LETTRE BALINAISE TA MURDA MAHAPRANA","	= ttha"},
/* 1B1F */ { "LETTRE BALINAISE DA MURDA ALPAPRANA","	= dda"},
/* 1B20 */ { "LETTRE BALINAISE DA MURDA MAHAPRANA","	= ddha"},
/* 1B21 */ { "LETTRE BALINAISE NA RAMBAT","	= nna"},
/* 1B22 */ { "LETTRE BALINAISE TA",NULL},
/* 1B23 */ { "LETTRE BALINAISE TA TAWA","	= tha"},
/* 1B24 */ { "LETTRE BALINAISE DA",NULL},
/* 1B25 */ { "LETTRE BALINAISE DA MADU","	= dha"},
/* 1B26 */ { "LETTRE BALINAISE NA",NULL},
/* 1B27 */ { "LETTRE BALINAISE PA",NULL},
/* 1B28 */ { "LETTRE BALINAISE PA KAPAL","	= pha"},
/* 1B29 */ { "LETTRE BALINAISE BA",NULL},
/* 1B2A */ { "LETTRE BALINAISE BA KEMBANG","	= bha"},
/* 1B2B */ { "LETTRE BALINAISE MA",NULL},
/* 1B2C */ { "LETTRE BALINAISE YA",NULL},
/* 1B2D */ { "LETTRE BALINAISE RA",NULL},
/* 1B2E */ { "LETTRE BALINAISE LA",NULL},
/* 1B2F */ { "LETTRE BALINAISE WA",NULL},
/* 1B30 */ { "LETTRE BALINAISE SA SAGA","	= cha"},
/* 1B31 */ { "LETTRE BALINAISE SA SAPA","	= ssa"},
/* 1B32 */ { "LETTRE BALINAISE SA",NULL},
/* 1B33 */ { "LETTRE BALINAISE HA",NULL},
/* 1B34 */ { "DIACRITIQUE BALINAIS REREKAN","	= noukta"},
/* 1B35 */ { "DIACRITIQUE VOYELLE BALINAISE TEDUNG","	= â"},
/* 1B36 */ { "DIACRITIQUE VOYELLE BALINAISE ULU","	= i"},
/* 1B37 */ { "DIACRITIQUE VOYELLE BALINAISE ULU SARI","	= î"},
/* 1B38 */ { "DIACRITIQUE VOYELLE BALINAISE SUKU","	= ou"},
/* 1B39 */ { "DIACRITIQUE VOYELLE BALINAISE SUKU ILUT","	= oû"},
/* 1B3A */ { "DIACRITIQUE VOYELLE BALINAISE RA REPA","	= r vocalique"},
/* 1B3B */ { "DIACRITIQUE VOYELLE BALINAISE RA REPA TEDUNG","	= rr vocalique\n"
	"	: 1B3A 1B35"},
/* 1B3C */ { "DIACRITIQUE VOYELLE BALINAISE LA LENGA","	= l vocalique"},
/* 1B3D */ { "DIACRITIQUE VOYELLE BALINAISE LA LENGA TEDUNG","	= ll vocalique\n"
	"	: 1B3C 1B35"},
/* 1B3E */ { "DIACRITIQUE VOYELLE BALINAISE TALING","	= é"},
/* 1B3F */ { "DIACRITIQUE VOYELLE BALINAISE TALING REPA","	= aï"},
/* 1B40 */ { "DIACRITIQUE VOYELLE BALINAISE TALING TEDUNG","	= o\n"
	"	: 1B3E 1B35"},
/* 1B41 */ { "DIACRITIQUE VOYELLE BALINAISE TALING REPA TEDUNG","	= aou\n"
	"	: 1B3F 1B35"},
/* 1B42 */ { "DIACRITIQUE VOYELLE BALINAISE PEPET","	= aé"},
/* 1B43 */ { "DIACRITIQUE VOYELLE BALINAISE PEPET TEDUNG","	= oé\n"
	"	: 1B42 1B35"},
/* 1B44 */ { "ADEG ADEG BALINAIS","	= virâma"},
/* 1B45 */ { "LETTRE BALINAISE KAF SASAK",NULL},
/* 1B46 */ { "LETTRE BALINAISE KHOT SASAK",NULL},
/* 1B47 */ { "LETTRE BALINAISE TZIR SASAK",NULL},
/* 1B48 */ { "LETTRE BALINAISE EF SASAK",NULL},
/* 1B49 */ { "LETTRE BALINAISE VE SASAK",NULL},
/* 1B4A */ { "LETTRE BALINAISE ZAL SASAK",NULL},
/* 1B4B */ { "LETTRE BALINAISE ASYURA SASAK",NULL},
/* 1B4C */ { "LETTRE BALINAISE DJÑA ARCHAÏQUE","	* utilisée dans des textes anciens à la place de la ligature dja + ña\n"
	"	x (lettre javanaise ña murda - A998)"},
/* 1B4D */ { NULL,NULL},
/* 1B4E */ { "CARIK SIKI RENVERSÉ BALINAIS",NULL},
/* 1B4F */ { "CARIK PAREREN RENVERSÉ BALINAIS",NULL},
/* 1B50 */ { "CHIFFRE BALINAIS ZÉRO",NULL},
/* 1B51 */ { "CHIFFRE BALINAIS UN",NULL},
/* 1B52 */ { "CHIFFRE BALINAIS DEUX",NULL},
/* 1B53 */ { "CHIFFRE BALINAIS TROIS",NULL},
/* 1B54 */ { "CHIFFRE BALINAIS QUATRE",NULL},
/* 1B55 */ { "CHIFFRE BALINAIS CINQ",NULL},
/* 1B56 */ { "CHIFFRE BALINAIS SIX",NULL},
/* 1B57 */ { "CHIFFRE BALINAIS SEPT",NULL},
/* 1B58 */ { "CHIFFRE BALINAIS HUIT",NULL},
/* 1B59 */ { "CHIFFRE BALINAIS NEUF",NULL},
/* 1B5A */ { "PANTI BALINAIS","	= section"},
/* 1B5B */ { "PAMADA BALINAIS","	= section honorifique"},
/* 1B5C */ { "WINDU BALINAIS","	= cercle de ponctuation"},
/* 1B5D */ { "CARIK PAMUNGKAH BALINAIS","	= deux-points"},
/* 1B5E */ { "CARIK SIKI BALINAIS","	= danda\n"
	"	x (danda dévanâgarî - 0964)"},
/* 1B5F */ { "CARIK PAREREN BALINAIS","	= double danda\n"
	"	x (double danda dévanâgarî - 0965)"},
/* 1B60 */ { "PAMENENG BALINAIS","	= trait de coupure de ligne, division"},
/* 1B61 */ { "SYMBOLE MUSICAL BALINAIS DONG",NULL},
/* 1B62 */ { "SYMBOLE MUSICAL BALINAIS DENG",NULL},
/* 1B63 */ { "SYMBOLE MUSICAL BALINAIS DUNG",NULL},
/* 1B64 */ { "SYMBOLE MUSICAL BALINAIS DANG",NULL},
/* 1B65 */ { "SYMBOLE MUSICAL BALINAIS DANG SURANG",NULL},
/* 1B66 */ { "SYMBOLE MUSICAL BALINAIS DING",NULL},
/* 1B67 */ { "SYMBOLE MUSICAL BALINAIS DAENG",NULL},
/* 1B68 */ { "SYMBOLE MUSICAL BALINAIS DEUNG",NULL},
/* 1B69 */ { "SYMBOLE MUSICAL BALINAIS DAING",NULL},
/* 1B6A */ { "SYMBOLE MUSICAL BALINAIS DANG GEDE",NULL},
/* 1B6B */ { "DIACRITIQUE MUSICAL BALINAIS TEGEH",NULL},
/* 1B6C */ { "DIACRITIQUE MUSICAL BALINAIS ENDEP",NULL},
/* 1B6D */ { "DIACRITIQUE MUSICAL BALINAIS KEMPUL",NULL},
/* 1B6E */ { "DIACRITIQUE MUSICAL BALINAIS KEMPLI",NULL},
/* 1B6F */ { "DIACRITIQUE MUSICAL BALINAIS JEGOGAN",NULL},
/* 1B70 */ { "DIACRITIQUE MUSICAL BALINAIS KEMPUL AVEC JEGOGAN",NULL},
/* 1B71 */ { "DIACRITIQUE MUSICAL BALINAIS KEMPLI AVEC JEGOGAN",NULL},
/* 1B72 */ { "DIACRITIQUE MUSICAL BALINAIS BENDE",NULL},
/* 1B73 */ { "DIACRITIQUE MUSICAL BALINAIS GONG",NULL},
/* 1B74 */ { "SYMBOLE MUSICAL BALINAIS DUG MAIN DROITE OUVERTE",NULL},
/* 1B75 */ { "SYMBOLE MUSICAL BALINAIS DAG MAIN DROITE OUVERTE",NULL},
/* 1B76 */ { "SYMBOLE MUSICAL BALINAIS TUK MAIN DROITE FERMÉE",NULL},
/* 1B77 */ { "SYMBOLE MUSICAL BALINAIS TAK MAIN DROITE FERMÉE",NULL},
/* 1B78 */ { "SYMBOLE MUSICAL BALINAIS PANG MAIN GAUCHE OUVERTE",NULL},
/* 1B79 */ { "SYMBOLE MUSICAL BALINAIS PUNG MAIN GAUCHE OUVERTE",NULL},
/* 1B7A */ { "SYMBOLE MUSICAL BALINAIS PLAK MAIN GAUCHE FERMÉE",NULL},
/* 1B7B */ { "SYMBOLE MUSICAL BALINAIS PLUK MAIN GAUCHE FERMÉE",NULL},
/* 1B7C */ { "SYMBOLE MUSICAL BALINAIS PING MAIN GAUCHE OUVERTE",NULL},
/* 1B7D */ { "PANTI LANTANG BALINAIS","	= fin du texte"},
/* 1B7E */ { "PAMADA LANTANG BALINAIS","	= fin du texte"},
/* 1B7F */ { "PANTI BAWAK BALINAIS","	* forme tronquée de panti\n"
	"	x (panti balinais - 1B5A)"},
/* 1B80 */ { "DIACRITIQUE SOUNDANAIS PAÑETCHEK","	= anousvâra"},
/* 1B81 */ { "DIACRITIQUE SOUNDANAIS PANGLAYAR","	= r final"},
/* 1B82 */ { "DIACRITIQUE SOUNDANAIS PANGWISAD","	= visarga"},
/* 1B83 */ { "LETTRE SOUNDANAISE A",NULL},
/* 1B84 */ { "LETTRE SOUNDANAISE I",NULL},
/* 1B85 */ { "LETTRE SOUNDANAISE OU",NULL},
/* 1B86 */ { "LETTRE SOUNDANAISE Æ",NULL},
/* 1B87 */ { "LETTRE SOUNDANAISE O",NULL},
/* 1B88 */ { "LETTRE SOUNDANAISE E",NULL},
/* 1B89 */ { "LETTRE SOUNDANAISE EU",NULL},
/* 1B8A */ { "LETTRE SOUNDANAISE KA",NULL},
/* 1B8B */ { "LETTRE SOUNDANAISE QA",NULL},
/* 1B8C */ { "LETTRE SOUNDANAISE GA",NULL},
/* 1B8D */ { "LETTRE SOUNDANAISE NGA",NULL},
/* 1B8E */ { "LETTRE SOUNDANAISE TCHA",NULL},
/* 1B8F */ { "LETTRE SOUNDANAISE DJA",NULL},
/* 1B90 */ { "LETTRE SOUNDANAISE ZA",NULL},
/* 1B91 */ { "LETTRE SOUNDANAISE ÑA",NULL},
/* 1B92 */ { "LETTRE SOUNDANAISE TA",NULL},
/* 1B93 */ { "LETTRE SOUNDANAISE DA",NULL},
/* 1B94 */ { "LETTRE SOUNDANAISE NA",NULL},
/* 1B95 */ { "LETTRE SOUNDANAISE PA",NULL},
/* 1B96 */ { "LETTRE SOUNDANAISE FA",NULL},
/* 1B97 */ { "LETTRE SOUNDANAISE VA",NULL},
/* 1B98 */ { "LETTRE SOUNDANAISE BA",NULL},
/* 1B99 */ { "LETTRE SOUNDANAISE MA",NULL},
/* 1B9A */ { "LETTRE SOUNDANAISE YA",NULL},
/* 1B9B */ { "LETTRE SOUNDANAISE RA",NULL},
/* 1B9C */ { "LETTRE SOUNDANAISE LA",NULL},
/* 1B9D */ { "LETTRE SOUNDANAISE WA",NULL},
/* 1B9E */ { "LETTRE SOUNDANAISE SA",NULL},
/* 1B9F */ { "LETTRE SOUNDANAISE XA",NULL},
/* 1BA0 */ { "LETTRE SOUNDANAISE HA",NULL},
/* 1BA1 */ { "DIACRITIQUE CONSONNE SOUNDANAISE PAMINGKAL","	= ya subjoint"},
/* 1BA2 */ { "DIACRITIQUE CONSONNE SOUNDANAISE PANYAKRA","	= ra subjoint"},
/* 1BA3 */ { "DIACRITIQUE CONSONNE SOUNDANAISE PAÑIKOU","	= la subjoint"},
/* 1BA4 */ { "DIACRITIQUE VOYELLE SOUNDANAISE PANGHOULOU","	= i"},
/* 1BA5 */ { "DIACRITIQUE VOYELLE SOUNDANAISE PAÑOUKOU","	= u"},
/* 1BA6 */ { "DIACRITIQUE VOYELLE SOUNDANAISE PANÆLÆNG","	= ae"},
/* 1BA7 */ { "DIACRITIQUE VOYELLE SOUNDANAISE PANOLONG","	= o"},
/* 1BA8 */ { "DIACRITIQUE VOYELLE SOUNDANAISE PAMEPET","	= e"},
/* 1BA9 */ { "DIACRITIQUE VOYELLE SOUNDANAISE PANEULEUNG","	= eu"},
/* 1BAA */ { "DIACRITIQUE SOUNDANAIS PAMAÆH","	* ne forme pas de ligatures"},
/* 1BAB */ { "DIACRITIQUE SOUNDANAIS VIRÂMA","	* forme des ligatures dans une orthographe ancienne"},
/* 1BAC */ { "DIACRITIQUE CONSONNE SOUNDANAISE PASANGAN MA","	= ma subjoint"},
/* 1BAD */ { "DIACRITIQUE CONSONNE SOUNDANAISE PASANGAN WA","	= wa subjoint"},
/* 1BAE */ { "LETTRE SOUNDANAISE KHA",NULL},
/* 1BAF */ { "LETTRE SOUNDANAISE SYA",NULL},
/* 1BB0 */ { "CHIFFRE SOUNDANAIS ZÉRO",NULL},
/* 1BB1 */ { "CHIFFRE SOUNDANAIS UN",NULL},
/* 1BB2 */ { "CHIFFRE SOUNDANAIS DEUX",NULL},
/* 1BB3 */ { "CHIFFRE SOUNDANAIS TROIS",NULL},
/* 1BB4 */ { "CHIFFRE SOUNDANAIS QUATRE",NULL},
/* 1BB5 */ { "CHIFFRE SOUNDANAIS CINQ",NULL},
/* 1BB6 */ { "CHIFFRE SOUNDANAIS SIX",NULL},
/* 1BB7 */ { "CHIFFRE SOUNDANAIS SEPT",NULL},
/* 1BB8 */ { "CHIFFRE SOUNDANAIS HUIT",NULL},
/* 1BB9 */ { "CHIFFRE SOUNDANAIS NEUF",NULL},
/* 1BBA */ { "AVAGRAHA SOUNDANAIS","	= marque de gémination"},
/* 1BBB */ { "LETTRE SOUNDANAISE REU","	* r vocalique"},
/* 1BBC */ { "LETTRE SOUNDANAISE LEU","	* l vocalique"},
/* 1BBD */ { "LETTRE SOUNDANAISE I ARCHAÏQUE","	* le nom formel de ce caractère en anglais est erroné"},
/* 1BBE */ { "LETTRE SOUNDANAISE K FINAL",NULL},
/* 1BBF */ { "LETTRE SOUNDANAISE M FINAL","	* utilisée dans un document du XXIe siècle\n"
	"	* pour le m final réel, il faut utiliser la séquence 1B99 1BAA"},
/* 1BC0 */ { "LETTRE BATAK A","	* lettre a ou ha pour le karo et le pakpak"},
/* 1BC1 */ { "LETTRE BATAK SIMALOUNGOUN A",NULL},
/* 1BC2 */ { "LETTRE BATAK HA","	* lettre toba ha ou ka\n"
	"	* désigne aussi la lettre ka pour le karo et le pakpak"},
/* 1BC3 */ { "LETTRE BATAK SIMALOUNGOUN HA","	* désigne aussi la lettre simalungun ka"},
/* 1BC4 */ { "LETTRE BATAK MANDAÏLING HA",NULL},
/* 1BC5 */ { "LETTRE BATAK BA",NULL},
/* 1BC6 */ { "LETTRE BATAK KARO BA","	* utilisée aussi en toba"},
/* 1BC7 */ { "LETTRE BATAK PA",NULL},
/* 1BC8 */ { "LETTRE BATAK SIMALOUNGOUN PA",NULL},
/* 1BC9 */ { "LETTRE BATAK NA",NULL},
/* 1BCA */ { "LETTRE BATAK MANDAÏLING NA",NULL},
/* 1BCB */ { "LETTRE BATAK WA","	* la lettre toba wa peut être représentée soit par 1BCB, soit par 1BCD"},
/* 1BCC */ { "LETTRE BATAK SIMALOUNGOUN WA",NULL},
/* 1BCD */ { "LETTRE BATAK PAKPAK WA",NULL},
/* 1BCE */ { "LETTRE BATAK GA",NULL},
/* 1BCF */ { "LETTRE BATAK SIMALOUNGOUN GA",NULL},
/* 1BD0 */ { "LETTRE BATAK DJA",NULL},
/* 1BD1 */ { "LETTRE BATAK DA",NULL},
/* 1BD2 */ { "LETTRE BATAK RA",NULL},
/* 1BD3 */ { "LETTRE BATAK SIMALOUNGOUN RA",NULL},
/* 1BD4 */ { "LETTRE BATAK MA",NULL},
/* 1BD5 */ { "LETTRE BATAK SIMALOUNGOUN MA",NULL},
/* 1BD6 */ { "LETTRE BATAK TA DU SUD","	* la lettre toba ta peut être représentée soit par 1BD6, soit par 1BD7"},
/* 1BD7 */ { "LETTRE BATAK TA DU NORD",NULL},
/* 1BD8 */ { "LETTRE BATAK SA","	* lettre pakpak sa ou ca"},
/* 1BD9 */ { "LETTRE BATAK SIMALOUNGOUN SA",NULL},
/* 1BDA */ { "LETTRE BATAK MANDAÏLING SA",NULL},
/* 1BDB */ { "LETTRE BATAK YA",NULL},
/* 1BDC */ { "LETTRE BATAK SIMALOUNGOUN YA",NULL},
/* 1BDD */ { "LETTRE BATAK NGA",NULL},
/* 1BDE */ { "LETTRE BATAK LA",NULL},
/* 1BDF */ { "LETTRE BATAK SIMALOUNGOUN LA",NULL},
/* 1BE0 */ { "LETTRE BATAK ÑA","	* la lettre karo ca peut être représentée soit par 1BE0, soit par 1BE1"},
/* 1BE1 */ { "LETTRE BATAK TCHA",NULL},
/* 1BE2 */ { "LETTRE BATAK NDA",NULL},
/* 1BE3 */ { "LETTRE BATAK MBA",NULL},
/* 1BE4 */ { "LETTRE BATAK I",NULL},
/* 1BE5 */ { "LETTRE BATAK OU",NULL},
/* 1BE6 */ { "DIACRITIQUE BATAK TOMPI",NULL},
/* 1BE7 */ { "DIACRITIQUE VOYELLE BATAK É","	= kebereten"},
/* 1BE8 */ { "DIACRITIQUE VOYELLE BATAK PAKPAK É","	= ketolongen"},
/* 1BE9 */ { "DIACRITIQUE VOYELLE BATAK ÉÉ","	= talinga"},
/* 1BEA */ { "DIACRITIQUE VOYELLE BATAK I","	= ulua"},
/* 1BEB */ { "DIACRITIQUE VOYELLE BATAK KARO I","	= haluan"},
/* 1BEC */ { "DIACRITIQUE VOYELLE BATAK O","	= siala ulu"},
/* 1BED */ { "DIACRITIQUE VOYELLE BATAK KARO O","	= hatulungan"},
/* 1BEE */ { "DIACRITIQUE VOYELLE BATAK OU","	= boruta"},
/* 1BEF */ { "DIACRITIQUE VOYELLE BATAK OU POUR SA SIMALOUNGOUN","	= haboritan pour sa simalungun"},
/* 1BF0 */ { "DIACRITIQUE CONSONNE BATAK NG","	= amisara"},
/* 1BF1 */ { "DIACRITIQUE CONSONNE BATAK H","	= hajoringan"},
/* 1BF2 */ { "PANGOLAT BATAK","	= virâma\n"
	"	* ne peut pas suivre un signe voyelle"},
/* 1BF3 */ { "PANONGONAN BATAK","	= virâma"},
/* 1BF4 */ { NULL,NULL},
/* 1BF5 */ { NULL,NULL},
/* 1BF6 */ { NULL,NULL},
/* 1BF7 */ { NULL,NULL},
/* 1BF8 */ { NULL,NULL},
/* 1BF9 */ { NULL,NULL},
/* 1BFA */ { NULL,NULL},
/* 1BFB */ { NULL,NULL},
/* 1BFC */ { "SYMBOLE BATAK BINDOU NA MÉTEK",NULL},
/* 1BFD */ { "SYMBOLE BATAK BINDOU PINARBORAS",NULL},
/* 1BFE */ { "SYMBOLE BATAK BINDOU DJOUDOUL",NULL},
/* 1BFF */ { "SYMBOLE BATAK BINDOU PANGOLAT",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_1C[] = {
/* 1C00 */ { "LETTRE LEPTCHA KA",NULL},
/* 1C01 */ { "LETTRE LEPTCHA KLA",NULL},
/* 1C02 */ { "LETTRE LEPTCHA KHA",NULL},
/* 1C03 */ { "LETTRE LEPTCHA GA",NULL},
/* 1C04 */ { "LETTRE LEPTCHA GLA",NULL},
/* 1C05 */ { "LETTRE LEPTCHA NGA",NULL},
/* 1C06 */ { "LETTRE LEPTCHA TCHA",NULL},
/* 1C07 */ { "LETTRE LEPTCHA TCHHA",NULL},
/* 1C08 */ { "LETTRE LEPTCHA DJA",NULL},
/* 1C09 */ { "LETTRE LEPTCHA ÑA",NULL},
/* 1C0A */ { "LETTRE LEPTCHA TA",NULL},
/* 1C0B */ { "LETTRE LEPTCHA THA",NULL},
/* 1C0C */ { "LETTRE LEPTCHA DA",NULL},
/* 1C0D */ { "LETTRE LEPTCHA NA",NULL},
/* 1C0E */ { "LETTRE LEPTCHA PA",NULL},
/* 1C0F */ { "LETTRE LEPTCHA PLA",NULL},
/* 1C10 */ { "LETTRE LEPTCHA PHA","	= lettre leptcha p'a"},
/* 1C11 */ { "LETTRE LEPTCHA FA",NULL},
/* 1C12 */ { "LETTRE LEPTCHA FLA",NULL},
/* 1C13 */ { "LETTRE LEPTCHA BA",NULL},
/* 1C14 */ { "LETTRE LEPTCHA BLA",NULL},
/* 1C15 */ { "LETTRE LEPTCHA MA",NULL},
/* 1C16 */ { "LETTRE LEPTCHA MLA",NULL},
/* 1C17 */ { "LETTRE LEPTCHA TSA",NULL},
/* 1C18 */ { "LETTRE LEPTCHA TÇA",NULL},
/* 1C19 */ { "LETTRE LEPTCHA DZA",NULL},
/* 1C1A */ { "LETTRE LEPTCHA YA",NULL},
/* 1C1B */ { "LETTRE LEPTCHA RA",NULL},
/* 1C1C */ { "LETTRE LEPTCHA LA",NULL},
/* 1C1D */ { "LETTRE LEPTCHA HA",NULL},
/* 1C1E */ { "LETTRE LEPTCHA HLA",NULL},
/* 1C1F */ { "LETTRE LEPTCHA VA",NULL},
/* 1C20 */ { "LETTRE LEPTCHA SA",NULL},
/* 1C21 */ { "LETTRE LEPTCHA ÇA",NULL},
/* 1C22 */ { "LETTRE LEPTCHA WA",NULL},
/* 1C23 */ { "LETTRE LEPTCHA A",NULL},
/* 1C24 */ { "LETTRE SUBJOINTE LEPTCHA YA",NULL},
/* 1C25 */ { "LETTRE SUBJOINTE LEPTCHA RA",NULL},
/* 1C26 */ { "DIACRITIQUE VOYELLE LEPTCHA Â",NULL},
/* 1C27 */ { "DIACRITIQUE VOYELLE LEPTCHA I",NULL},
/* 1C28 */ { "DIACRITIQUE VOYELLE LEPTCHA O",NULL},
/* 1C29 */ { "DIACRITIQUE VOYELLE LEPTCHA Ô",NULL},
/* 1C2A */ { "DIACRITIQUE VOYELLE LEPTCHA OU",NULL},
/* 1C2B */ { "DIACRITIQUE VOYELLE LEPTCHA OÛ",NULL},
/* 1C2C */ { "DIACRITIQUE VOYELLE LEPTCHA É",NULL},
/* 1C2D */ { "DIACRITIQUE CONSONNE LEPTCHA K",NULL},
/* 1C2E */ { "DIACRITIQUE CONSONNE LEPTCHA M",NULL},
/* 1C2F */ { "DIACRITIQUE CONSONNE LEPTCHA L",NULL},
/* 1C30 */ { "DIACRITIQUE CONSONNE LEPTCHA N",NULL},
/* 1C31 */ { "DIACRITIQUE CONSONNE LEPTCHA P",NULL},
/* 1C32 */ { "DIACRITIQUE CONSONNE LEPTCHA R",NULL},
/* 1C33 */ { "DIACRITIQUE CONSONNE LEPTCHA T",NULL},
/* 1C34 */ { "DIACRITIQUE CONSONNE LEPTCHA ÑIN-DO",NULL},
/* 1C35 */ { "DIACRITIQUE CONSONNE LEPTCHA KANG",NULL},
/* 1C36 */ { "DIACRITIQUE LEPTCHA RAN",NULL},
/* 1C37 */ { "DIACRITIQUE LEPTCHA NOUKTA",NULL},
/* 1C38 */ { NULL,NULL},
/* 1C39 */ { NULL,NULL},
/* 1C3A */ { NULL,NULL},
/* 1C3B */ { "PONCTUATION LEPTCHA TA-ROL",NULL},
/* 1C3C */ { "PONCTUATION LEPTCHA ÑET THYÔM TA-ROL",NULL},
/* 1C3D */ { "PONCTUATION LEPTCHA TCHER-WA",NULL},
/* 1C3E */ { "PONCTUATION LEPTCHA TCHÔK TCHER-WA",NULL},
/* 1C3F */ { "PONCTUATION LEPTCHA TCHÔK",NULL},
/* 1C40 */ { "CHIFFRE LEPTCHA ZÉRO",NULL},
/* 1C41 */ { "CHIFFRE LEPTCHA UN",NULL},
/* 1C42 */ { "CHIFFRE LEPTCHA DEUX",NULL},
/* 1C43 */ { "CHIFFRE LEPTCHA TROIS",NULL},
/* 1C44 */ { "CHIFFRE LEPTCHA QUATRE",NULL},
/* 1C45 */ { "CHIFFRE LEPTCHA CINQ",NULL},
/* 1C46 */ { "CHIFFRE LEPTCHA SIX",NULL},
/* 1C47 */ { "CHIFFRE LEPTCHA SEPT",NULL},
/* 1C48 */ { "CHIFFRE LEPTCHA HUIT",NULL},
/* 1C49 */ { "CHIFFRE LEPTCHA NEUF",NULL},
/* 1C4A */ { NULL,NULL},
/* 1C4B */ { NULL,NULL},
/* 1C4C */ { NULL,NULL},
/* 1C4D */ { "LETTRE LEPTCHA TTA",NULL},
/* 1C4E */ { "LETTRE LEPTCHA TTHA",NULL},
/* 1C4F */ { "LETTRE LEPTCHA DDA",NULL},
/* 1C50 */ { "CHIFFRE OL TCHIKI ZÉRO",NULL},
/* 1C51 */ { "CHIFFRE OL TCHIKI UN",NULL},
/* 1C52 */ { "CHIFFRE OL TCHIKI DEUX",NULL},
/* 1C53 */ { "CHIFFRE OL TCHIKI TROIS",NULL},
/* 1C54 */ { "CHIFFRE OL TCHIKI QUATRE",NULL},
/* 1C55 */ { "CHIFFRE OL TCHIKI CINQ",NULL},
/* 1C56 */ { "CHIFFRE OL TCHIKI SIX",NULL},
/* 1C57 */ { "CHIFFRE OL TCHIKI SEPT",NULL},
/* 1C58 */ { "CHIFFRE OL TCHIKI HUIT",NULL},
/* 1C59 */ { "CHIFFRE OL TCHIKI NEUF",NULL},
/* 1C5A */ { "LETTRE OL TCHIKI LA",NULL},
/* 1C5B */ { "LETTRE OL TCHIKI AT",NULL},
/* 1C5C */ { "LETTRE OL TCHIKI AG",NULL},
/* 1C5D */ { "LETTRE OL TCHIKI ANG",NULL},
/* 1C5E */ { "LETTRE OL TCHIKI AL",NULL},
/* 1C5F */ { "LETTRE OL TCHIKI LÂ",NULL},
/* 1C60 */ { "LETTRE OL TCHIKI ÂK",NULL},
/* 1C61 */ { "LETTRE OL TCHIKI ÂJ",NULL},
/* 1C62 */ { "LETTRE OL TCHIKI ÂM",NULL},
/* 1C63 */ { "LETTRE OL TCHIKI ÂW",NULL},
/* 1C64 */ { "LETTRE OL TCHIKI LI",NULL},
/* 1C65 */ { "LETTRE OL TCHIKI IS",NULL},
/* 1C66 */ { "LETTRE OL TCHIKI IH",NULL},
/* 1C67 */ { "LETTRE OL TCHIKI IÑ",NULL},
/* 1C68 */ { "LETTRE OL TCHIKI IR",NULL},
/* 1C69 */ { "LETTRE OL TCHIKI LOU",NULL},
/* 1C6A */ { "LETTRE OL TCHIKI OUTCH",NULL},
/* 1C6B */ { "LETTRE OL TCHIKI OUD",NULL},
/* 1C6C */ { "LETTRE OL TCHIKI OUNN",NULL},
/* 1C6D */ { "LETTRE OL TCHIKI OUY",NULL},
/* 1C6E */ { "LETTRE OL TCHIKI LÉ",NULL},
/* 1C6F */ { "LETTRE OL TCHIKI ÉP",NULL},
/* 1C70 */ { "LETTRE OL TCHIKI ÉDD",NULL},
/* 1C71 */ { "LETTRE OL TCHIKI ÉN",NULL},
/* 1C72 */ { "LETTRE OL TCHIKI ÉRR",NULL},
/* 1C73 */ { "LETTRE OL TCHIKI LO",NULL},
/* 1C74 */ { "LETTRE OL TCHIKI OTT",NULL},
/* 1C75 */ { "LETTRE OL TCHIKI OB",NULL},
/* 1C76 */ { "LETTRE OL TCHIKI OV",NULL},
/* 1C77 */ { "LETTRE OL TCHIKI OH",NULL},
/* 1C78 */ { "MOU TTOUDDAG OL TCHIKI","	* marque de nasalisation"},
/* 1C79 */ { "GÂHLÂ TTOUDDÂG OL TCHIKI","	* modificateur de voyelle"},
/* 1C7A */ { "MOU-GÂHLÂ TTOUDDÂG OL TCHIKI",NULL},
/* 1C7B */ { "RÉLÂ OL TCHIKI","	* marque de longueur"},
/* 1C7C */ { "PHÂRKÂ OL TCHIKI","	* protecteur glottal"},
/* 1C7D */ { "AHAD OL TCHIKI","	* déglottalise les consonnes"},
/* 1C7E */ { "PONCTUATION OL TCHIKI MOUTCHÂD",NULL},
/* 1C7F */ { "PONCTUATION OL TCHIKI DOUBLE MOUTCHÂD",NULL},
/* 1C80 */ { "LETTRE MINUSCULE CYRILLIQUE VÉ ARRONDI","	x (lettre minuscule cyrillique vé - 0432)"},
/* 1C81 */ { "LETTRE MINUSCULE CYRILLIQUE DÉ À HAMPE LONGUE","	x (lettre minuscule cyrillique dé - 0434)"},
/* 1C82 */ { "LETTRE MINUSCULE CYRILLIQUE O ÉTROIT","	x (lettre minuscule cyrillique o - 043E)"},
/* 1C83 */ { "LETTRE MINUSCULE CYRILLIQUE GRAND ESSE","	x (lettre minuscule cyrillique esse - 0441)"},
/* 1C84 */ { "LETTRE MINUSCULE CYRILLIQUE TÉ HAUT",NULL},
/* 1C85 */ { "LETTRE MINUSCULE CYRILLIQUE TÉ À TROIS HAMPES","	x (lettre minuscule cyrillique té - 0442)"},
/* 1C86 */ { "LETTRE MINUSCULE CYRILLIQUE SIGNE DUR HAUT","	x (lettre minuscule cyrillique signe dur - 044A)"},
/* 1C87 */ { "LETTRE MINUSCULE CYRILLIQUE IAT HAUT","	x (lettre minuscule cyrillique iat - 0463)"},
/* 1C88 */ { "LETTRE MINUSCULE CYRILLIQUE OUK NON MÉLANGÉ","	x (lettre minuscule cyrillique ouk - 0479)\n"
	"	x (lettre minuscule cyrillique monogramme ouk - A64B)"},
/* 1C89 */ { "LETTRE MAJUSCULE CYRILLIQUE TÉ SIGNE MOU",NULL},
/* 1C8A */ { "LETTRE MINUSCULE CYRILLIQUE TÉ SIGNE MOU","	x (lettre minuscule cyrillique tié komi - 050F)"},
/* 1C8B */ { NULL,NULL},
/* 1C8C */ { NULL,NULL},
/* 1C8D */ { NULL,NULL},
/* 1C8E */ { NULL,NULL},
/* 1C8F */ { NULL,NULL},
/* 1C90 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE AN","	x (lettre géorgienne an - 10D0)"},
/* 1C91 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE BAN",NULL},
/* 1C92 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE GAN",NULL},
/* 1C93 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE DON",NULL},
/* 1C94 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE ÈN",NULL},
/* 1C95 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE VIN",NULL},
/* 1C96 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE ZÉN",NULL},
/* 1C97 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE THAN",NULL},
/* 1C98 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE IN",NULL},
/* 1C99 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE K'AN",NULL},
/* 1C9A */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE LASS",NULL},
/* 1C9B */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE MAN",NULL},
/* 1C9C */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE NAR",NULL},
/* 1C9D */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE ON",NULL},
/* 1C9E */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE P'AR",NULL},
/* 1C9F */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE JAN",NULL},
/* 1CA0 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE RAÉ",NULL},
/* 1CA1 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE SAN",NULL},
/* 1CA2 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE T'AR",NULL},
/* 1CA3 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE OUN",NULL},
/* 1CA4 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE PHAR",NULL},
/* 1CA5 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE KHAR",NULL},
/* 1CA6 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE GHAN",NULL},
/* 1CA7 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE Q'AR",NULL},
/* 1CA8 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE CHIN",NULL},
/* 1CA9 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE TCHIN",NULL},
/* 1CAA */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE TSIN",NULL},
/* 1CAB */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE DZIL",NULL},
/* 1CAC */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE TS'IL",NULL},
/* 1CAD */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE TCH'AR",NULL},
/* 1CAE */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE KHAN",NULL},
/* 1CAF */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE DJAN",NULL},
/* 1CB0 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE HAÉ",NULL},
/* 1CB1 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE HÉ",NULL},
/* 1CB2 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE IÉ",NULL},
/* 1CB3 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE WIÉ",NULL},
/* 1CB4 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE QAR",NULL},
/* 1CB5 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE HOÉ",NULL},
/* 1CB6 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE FI",NULL},
/* 1CB7 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE YN",NULL},
/* 1CB8 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE ELIFI",NULL},
/* 1CB9 */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE GAN CULBUTÉ",NULL},
/* 1CBA */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE 'AÏN",NULL},
/* 1CBB */ { NULL,NULL},
/* 1CBC */ { NULL,NULL},
/* 1CBD */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE AÈN",NULL},
/* 1CBE */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE SIGNE DUR",NULL},
/* 1CBF */ { "LETTRE GÉORGIENNE MTAVROULI MAJUSCULE SIGNE LABIAL",NULL},
/* 1CC0 */ { "PONCTUATION SOUNDANAISE BINDU SURYA","	* soleil"},
/* 1CC1 */ { "PONCTUATION SOUNDANAISE BINDU PANGLONG","	* demi-lune"},
/* 1CC2 */ { "PONCTUATION SOUNDANAISE BINDU PURNAMA","	* pleine lune"},
/* 1CC3 */ { "PONCTUATION SOUNDANAISE BINDU CAKRA","	* roue"},
/* 1CC4 */ { "PONCTUATION SOUNDANAISE BINDU LEU SATANGA",NULL},
/* 1CC5 */ { "PONCTUATION SOUNDANAISE BINDU KA SATANGA",NULL},
/* 1CC6 */ { "PONCTUATION SOUNDANAISE BINDU DA SATANGA",NULL},
/* 1CC7 */ { "PONCTUATION SOUNDANAISE BINDU BA SATANGA",NULL},
/* 1CC8 */ { NULL,NULL},
/* 1CC9 */ { NULL,NULL},
/* 1CCA */ { NULL,NULL},
/* 1CCB */ { NULL,NULL},
/* 1CCC */ { NULL,NULL},
/* 1CCD */ { NULL,NULL},
/* 1CCE */ { NULL,NULL},
/* 1CCF */ { NULL,NULL},
/* 1CD0 */ { "DIACRITIQUE TON VÉDIQUE KARSHANA","	= vaïdika sâmasvara karshanna"},
/* 1CD1 */ { "DIACRITIQUE TON VÉDIQUE SHARA","	= vaïdika svarita oûrdhva shara"},
/* 1CD2 */ { "DIACRITIQUE TON VÉDIQUE PRENKHA","	= vaïdika sâmasvara prenkha\n"
	"	* indique un vibrato"},
/* 1CD3 */ { "SIGNE VÉDIQUE NIHSHVASA","	= vaïdika sâmagâna yogakâla\n"
	"	* sépare des passages entre lesquels une pause est interdite"},
/* 1CD4 */ { "DIACRITIQUE VÉDIQUE YAJURVÉDIQUE SVARITA MÉDIAN","	* utilisé principalement dans la Maitrayani Samhita et dans certains manuscrits de la Vajasaneyi Madhyandina Samhita"},
/* 1CD5 */ { "DIACRITIQUE TON VÉDIQUE YAJURVÉDIQUE SVARITA INDÉPENDANT AGGRAVÉ","	= vaïdika svarita adho nyoubdja"},
/* 1CD6 */ { "DIACRITIQUE TON VÉDIQUE YAJURVÉDIQUE SVARITA INDÉPENDANT","	= vaïdika svarita adhah konna"},
/* 1CD7 */ { "DIACRITIQUE TON VÉDIQUE YAJURVÉDIQUE KATHAKA SVARITA INDÉPENDANT","	= vaïdika svarita adho vakra rékhâ"},
/* 1CD8 */ { "DIACRITIQUE TON VÉDIQUE TCHANDRA SOUSCRIT","	= vaïdika svarita adho'rdha vakra"},
/* 1CD9 */ { "DIACRITIQUE TON VÉDIQUE YAJURVÉDIQUE KATHAKA SVARITA INDÉPENDANT SCHROEDER","	= vaïdika svarita adhah samyoukta rékhâ"},
/* 1CDA */ { "DIACRITIQUE TON VÉDIQUE DOUBLE SVARITA","	= vaïdika svarita oûrdhva dvi rékhâ\n"
	"	x (diacritique d'accentuation dévanâgarî oudatta - 0951)"},
/* 1CDB */ { "DIACRITIQUE TON VÉDIQUE TRIPLE SVARITA","	= vaïdika svarita oûrdhva tri rékhâ"},
/* 1CDC */ { "DIACRITIQUE TON VÉDIQUE KATHAKA ANOUDATTA","	= vaïdika svarita adho rékhâ\n"
	"	x (diacritique d'accentuation dévanâgarî anoudatta - 0952)"},
/* 1CDD */ { "DIACRITIQUE TON VÉDIQUE POINT SOUSCRIT","	= vaïdika svarita adho bindou"},
/* 1CDE */ { "DIACRITIQUE TON VÉDIQUE DEUX POINTS SOUSCRITS","	= vaïdika svarita adho dvi bindou"},
/* 1CDF */ { "DIACRITIQUE TON VÉDIQUE TROIS POINTS SOUSCRITS","	= vaïdika svarita adhas tri bindou"},
/* 1CE0 */ { "DIACRITIQUE TON VÉDIQUE RIGVÉDIQUE CACHEMIRI SVARITA INDÉPENDANT","	= vaïdika uurdhva vakra rékhâ"},
/* 1CE1 */ { "DIACRITIQUE TON VÉDIQUE ATHARVAVÉDIQUE SVARITA INDÉPENDANT","	= vaïdika svarita dvi vakra khannda"},
/* 1CE2 */ { "DIACRITIQUE VÉDIQUE VISARGA SVARITA","	= vaïdika madhyarekhâ"},
/* 1CE3 */ { "DIACRITIQUE VÉDIQUE VISARGA OUDATTA","	= vaïdika visarga dakshinnatah oûrdhvaga"},
/* 1CE4 */ { "DIACRITIQUE VÉDIQUE VISARGA OUDATTA RÉFLÉCHI","	= vaïdika visarga vâmatah oûrdhvaga"},
/* 1CE5 */ { "DIACRITIQUE VÉDIQUE VISARGA ANOUDATTA","	= vaïdika visarga vâmatah adhoga"},
/* 1CE6 */ { "DIACRITIQUE VÉDIQUE VISARGA ANOUDATTA RÉFLÉCHI","	= vaïdika visarga dakshinnatah adhoga"},
/* 1CE7 */ { "DIACRITIQUE VÉDIQUE VISARGA OUDATTA HAMEÇON","	= vaïdika visarga dakshinnatah oûrdhva vakra"},
/* 1CE8 */ { "DIACRITIQUE VÉDIQUE VISARGA ANOUDATTA HAMEÇON","	= vaïdika visarga vâmatah adho vakra"},
/* 1CE9 */ { "SIGNE VÉDIQUE ANOUSVÂRA ANTARGOMOUKHA","	= vaïdika anousvâra antarmoukha"},
/* 1CEA */ { "SIGNE VÉDIQUE ANOUSVÂRA BAHIRGOMOUKHA","	= vaïdika anousvâra nâgaphanna"},
/* 1CEB */ { "SIGNE VÉDIQUE ANOUSVÂRA VAMAGOMOUKHA","	= vaïdika anousvâra vâmagomoukha"},
/* 1CEC */ { "SIGNE VÉDIQUE ANOUSVÂRA VAMAGOMOUKHA HAMEÇON","	= vaïdika anousvâra vâmagomoukha sa-vakra"},
/* 1CED */ { "DIACRITIQUE VÉDIQUE TIRYAK","	= vaïdika tiryak"},
/* 1CEE */ { "SIGNE VÉDIQUE ANOUSVÂRA LONG HEXAFORME","	= vaïdika anousvâra anougâmî"},
/* 1CEF */ { "SIGNE VÉDIQUE ANOUSVÂRA LONG","	= vaïdika anousvâra dakshinnamoukha"},
/* 1CF0 */ { "SIGNE VÉDIQUE RTHANG ANOUSVÂRA LONG","	= vaïdika anousvâra ttha-sadrisha"},
/* 1CF1 */ { "SIGNE VÉDIQUE ANOUSVÂRA OUBHAYATO MOUKHA","	= vaïdika anousvâra oubhayato moukha"},
/* 1CF2 */ { "DIACRITIQUE VÉDIQUE ARDHAVISARGA","	= vaïdika anousvâra ttha-sadrisha"},
/* 1CF3 */ { "DIACRITIQUE VÉDIQUE ARDHAVISARGA COUCHÉ",NULL},
/* 1CF4 */ { "DIACRITIQUE TON VÉDIQUE TCHANDRA EN CHEF",NULL},
/* 1CF5 */ { "SIGNE VÉDIQUE DJIHVAMOULIYA","	* marque une fricative vélaire n'apparaissant que devant les occlusives vélaires sourdes\n"
	"	x (signe kannara djihvamouliya - 0CF1)\n"
	"	x (signe tibétain ltché tsa tchan - 0F88)\n"
	"	x (signe brahmi djihvamouliya - 11003)\n"
	"	x (signe charada djihvamouliya - 111C2)\n"
	"	x (signe néwar djihvamouliya - 11460)\n"
	"	x (signe soyombo djihvamouliya - 11A84)"},
/* 1CF6 */ { "SIGNE VÉDIQUE OUPADHMANIYA","	* marque une fricative bilabiale n'apparaissant que devant les occlusives labiales sourdes\n"
	"	x (signe kannara oupadhmaniya - 0CF2)\n"
	"	x (signe tibétain mtch'ou tchan - 0F89)\n"
	"	x (signe brahmi oupadhmaniya - 11004)\n"
	"	x (signe charada oupadhmaniya - 111C3)\n"
	"	x (signe néwar oupadhmaniya - 11461)\n"
	"	x (signe soyombo oupadhmaniya - 11A85)"},
/* 1CF7 */ { "DIACRITIQUE VÉDIQUE ATIKRAMA","	= vaïdika sâmagâna atikrama\n"
	"	* indique la suppression d'un svara"},
/* 1CF8 */ { "DIACRITIQUE TON VÉDIQUE ROND SUSCRIT",NULL},
/* 1CF9 */ { "DIACRITIQUE TON VÉDIQUE DOUBLE ROND SUSCRIT",NULL},
/* 1CFA */ { "SIGNE VÉDIQUE DOUBLE ANOUSVÂRA ANTARGOMOUKHA","	* tient lieu de base pour un signe combinatoire nasal"},
/* 1CFB */ { NULL,NULL},
/* 1CFC */ { NULL,NULL},
/* 1CFD */ { NULL,NULL},
/* 1CFE */ { NULL,NULL},
/* 1CFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_1D[] = {
/* 1D00 */ { "LETTRE LATINE PETITE CAPITALE A",NULL},
/* 1D01 */ { "LETTRE LATINE PETITE CAPITALE AE",NULL},
/* 1D02 */ { "LETTRE MINUSCULE LATINE AE CULBUTÉ","	* le glyphe peut également apparaître de biais"},
/* 1D03 */ { "LETTRE LATINE PETITE CAPITALE B BARRÉ","	x (lettre majuscule latine b barré - 0243)"},
/* 1D04 */ { "LETTRE LATINE PETITE CAPITALE C",NULL},
/* 1D05 */ { "LETTRE LATINE PETITE CAPITALE D",NULL},
/* 1D06 */ { "LETTRE LATINE PETITE CAPITALE ETH",NULL},
/* 1D07 */ { "LETTRE LATINE PETITE CAPITALE E",NULL},
/* 1D08 */ { "LETTRE MINUSCULE LATINE E OUVERT CULBUTÉ","	x (lettre minuscule latine e ouvert réfléchi - 025C)\n"
	"	x (lettre modificative minuscule e ouvert culbuté - 1D4C)"},
/* 1D09 */ { "LETTRE MINUSCULE LATINE I CULBUTÉ",NULL},
/* 1D0A */ { "LETTRE LATINE PETITE CAPITALE J",NULL},
/* 1D0B */ { "LETTRE LATINE PETITE CAPITALE K","	x (lettre minuscule latine kra - 0138)\n"
	"	x (lettre minuscule cyrillique ka - 043A)"},
/* 1D0C */ { "LETTRE LATINE PETITE CAPITALE L BARRÉ OBLIQUEMENT",NULL},
/* 1D0D */ { "LETTRE LATINE PETITE CAPITALE M",NULL},
/* 1D0E */ { "LETTRE LATINE PETITE CAPITALE N RÉFLÉCHI","	x (lettre minuscule cyrillique i - 0438)\n"
	"	x (lettre modificative majuscule n réfléchi - 1D3B)"},
/* 1D0F */ { "LETTRE LATINE PETITE CAPITALE O",NULL},
/* 1D10 */ { "LETTRE LATINE PETITE CAPITALE O OUVERT","	x (lettre minuscule latine o ouvert - 0254)\n"
	"	x (lettre minuscule latine c réfléchi - 2184)"},
/* 1D11 */ { "LETTRE MINUSCULE LATINE O COUCHÉ",NULL},
/* 1D12 */ { "LETTRE MINUSCULE LATINE O OUVERT COUCHÉ",NULL},
/* 1D13 */ { "LETTRE MINUSCULE LATINE O COUCHÉ BARRÉ OBLIQUEMENT",NULL},
/* 1D14 */ { "LETTRE MINUSCULE LATINE OE CULBUTÉ","	* le glyphe peut également apparaître de biais"},
/* 1D15 */ { "LETTRE LATINE PETITE CAPITALE OU",NULL},
/* 1D16 */ { "LETTRE MINUSCULE LATINE MOITIÉ SUPÉRIEURE DE O",NULL},
/* 1D17 */ { "LETTRE MINUSCULE LATINE MOITIÉ INFÉRIEURE DE O",NULL},
/* 1D18 */ { "LETTRE LATINE PETITE CAPITALE P","	* représente un [p] semi-sonore\n"
	"	x (lettre grecque petite capitale rhô - 1D29)"},
/* 1D19 */ { "LETTRE LATINE PETITE CAPITALE R RÉFLÉCHI",NULL},
/* 1D1A */ { "LETTRE LATINE PETITE CAPITALE R CULBUTÉ",NULL},
/* 1D1B */ { "LETTRE LATINE PETITE CAPITALE T","	x (lettre minuscule cyrillique té - 0442)"},
/* 1D1C */ { "LETTRE LATINE PETITE CAPITALE U",NULL},
/* 1D1D */ { "LETTRE MINUSCULE LATINE U COUCHÉ",NULL},
/* 1D1E */ { "LETTRE MINUSCULE LATINE U TRÉMA COUCHÉ","	* le glyphe peut également apparaître de biais"},
/* 1D1F */ { "LETTRE MINUSCULE LATINE M COUCHÉ",NULL},
/* 1D20 */ { "LETTRE LATINE PETITE CAPITALE V",NULL},
/* 1D21 */ { "LETTRE LATINE PETITE CAPITALE W",NULL},
/* 1D22 */ { "LETTRE LATINE PETITE CAPITALE Z",NULL},
/* 1D23 */ { "LETTRE LATINE PETITE CAPITALE EJ","	x (lettre minuscule cyrillique dzé abkhaze - 04E1)"},
/* 1D24 */ { "LETTRE LATINE SPIRANTE LARYNGALE SONORE",NULL},
/* 1D25 */ { "LETTRE LATINE 'AÏN","	x (lettre arabe 'aïn - 0639)\n"
	"	x (lettre minuscule latine 'aïn égyptologique - A725)"},
/* 1D26 */ { "LETTRE GRECQUE PETITE CAPITALE GAMMA",NULL},
/* 1D27 */ { "LETTRE GRECQUE PETITE CAPITALE LAMBDA",NULL},
/* 1D28 */ { "LETTRE GRECQUE PETITE CAPITALE PI",NULL},
/* 1D29 */ { "LETTRE GRECQUE PETITE CAPITALE RHÔ","	* représente une vibrante uvulaire sourde\n"
	"	x (lettre latine petite capitale p - 1D18)"},
/* 1D2A */ { "LETTRE GRECQUE PETITE CAPITALE PSI",NULL},
/* 1D2B */ { "LETTRE CYRILLIQUE PETITE CAPITALE ELLE","	* dans un contexte italique, cette lettre est penchée au lieu d'avoir un tracé italique\n"
	"	x (lettre minuscule cyrillique elle - 043B)"},
/* 1D2C */ { "LETTRE MODIFICATIVE MAJUSCULE A","	# <exp> 0041"},
/* 1D2D */ { "LETTRE MODIFICATIVE MAJUSCULE AE","	# <exp> 00C6"},
/* 1D2E */ { "LETTRE MODIFICATIVE MAJUSCULE B","	# <exp> 0042"},
/* 1D2F */ { "LETTRE MODIFICATIVE MAJUSCULE B BARRÉ",NULL},
/* 1D30 */ { "LETTRE MODIFICATIVE MAJUSCULE D","	# <exp> 0044"},
/* 1D31 */ { "LETTRE MODIFICATIVE MAJUSCULE E","	# <exp> 0045"},
/* 1D32 */ { "LETTRE MODIFICATIVE MAJUSCULE E RÉFLÉCHI","	# <exp> 018E"},
/* 1D33 */ { "LETTRE MODIFICATIVE MAJUSCULE G","	# <exp> 0047"},
/* 1D34 */ { "LETTRE MODIFICATIVE MAJUSCULE H","	# <exp> 0048\n"
	"		Une différence typographique entre une majuscule et une petite capitale ne constitue pas un signe distinctif pour ce caractère dans le contexte de l'alphabet phonétique international.\n"
	"	* réalisation sourde épiglottalisée (API étendu)\n"
	"	x (lettre latine petite capitale h - 029C)\n"
	"	x (lettre modificative cyrillique enne - 1D78)"},
/* 1D35 */ { "LETTRE MODIFICATIVE MAJUSCULE I","	# <exp> 0049"},
/* 1D36 */ { "LETTRE MODIFICATIVE MAJUSCULE J","	# <exp> 004A"},
/* 1D37 */ { "LETTRE MODIFICATIVE MAJUSCULE K","	# <exp> 004B"},
/* 1D38 */ { "LETTRE MODIFICATIVE MAJUSCULE L","	# <exp> 004C"},
/* 1D39 */ { "LETTRE MODIFICATIVE MAJUSCULE M","	# <exp> 004D"},
/* 1D3A */ { "LETTRE MODIFICATIVE MAJUSCULE N","	# <exp> 004E"},
/* 1D3B */ { "LETTRE MODIFICATIVE MAJUSCULE N RÉFLÉCHI",NULL},
/* 1D3C */ { "LETTRE MODIFICATIVE MAJUSCULE O","	# <exp> 004F"},
/* 1D3D */ { "LETTRE MODIFICATIVE MAJUSCULE OU","	# <exp> 0222"},
/* 1D3E */ { "LETTRE MODIFICATIVE MAJUSCULE P","	# <exp> 0050"},
/* 1D3F */ { "LETTRE MODIFICATIVE MAJUSCULE R","	# <exp> 0052"},
/* 1D40 */ { "LETTRE MODIFICATIVE MAJUSCULE T","	# <exp> 0054"},
/* 1D41 */ { "LETTRE MODIFICATIVE MAJUSCULE U","	# <exp> 0055"},
/* 1D42 */ { "LETTRE MODIFICATIVE MAJUSCULE W","	# <exp> 0057"},
/* 1D43 */ { "LETTRE MODIFICATIVE MINUSCULE A","	# <exp> 0061"},
/* 1D44 */ { "LETTRE MODIFICATIVE MINUSCULE A CULBUTÉ","	# <exp> 0250"},
/* 1D45 */ { "LETTRE MODIFICATIVE MINUSCULE ALPHA","	# <exp> 0251"},
/* 1D46 */ { "LETTRE MODIFICATIVE MINUSCULE AE CULBUTÉ","	# <exp> 1D02"},
/* 1D47 */ { "LETTRE MODIFICATIVE MINUSCULE B","	# <exp> 0062"},
/* 1D48 */ { "LETTRE MODIFICATIVE MINUSCULE D","	# <exp> 0064"},
/* 1D49 */ { "LETTRE MODIFICATIVE MINUSCULE E","	# <exp> 0065"},
/* 1D4A */ { "LETTRE MODIFICATIVE MINUSCULE SCHWA","	# <exp> 0259"},
/* 1D4B */ { "LETTRE MODIFICATIVE MINUSCULE E OUVERT","	# <exp> 025B"},
/* 1D4C */ { "LETTRE MODIFICATIVE MINUSCULE E OUVERT CULBUTÉ","	* 1D08 serait probablement une meilleure équivalence\n"
	"	# <exp> 025C"},
/* 1D4D */ { "LETTRE MODIFICATIVE MINUSCULE G","	# <exp> 0067"},
/* 1D4E */ { "LETTRE MODIFICATIVE MINUSCULE I CULBUTÉ",NULL},
/* 1D4F */ { "LETTRE MODIFICATIVE MINUSCULE K","	# <exp> 006B"},
/* 1D50 */ { "LETTRE MODIFICATIVE MINUSCULE M","	# <exp> 006D"},
/* 1D51 */ { "LETTRE MODIFICATIVE MINUSCULE ENG","	# <exp> 014B"},
/* 1D52 */ { "LETTRE MODIFICATIVE MINUSCULE O","	# <exp> 006F"},
/* 1D53 */ { "LETTRE MODIFICATIVE MINUSCULE O OUVERT","	# <exp> 0254"},
/* 1D54 */ { "LETTRE MODIFICATIVE MINUSCULE MOITIÉ SUPÉRIEURE DE O","	# <exp> 1D16"},
/* 1D55 */ { "LETTRE MODIFICATIVE MINUSCULE MOITIÉ INFÉRIEURE DE O","	# <exp> 1D17"},
/* 1D56 */ { "LETTRE MODIFICATIVE MINUSCULE P","	# <exp> 0070"},
/* 1D57 */ { "LETTRE MODIFICATIVE MINUSCULE T","	# <exp> 0074"},
/* 1D58 */ { "LETTRE MODIFICATIVE MINUSCULE U","	# <exp> 0075"},
/* 1D59 */ { "LETTRE MODIFICATIVE MINUSCULE U COUCHÉ","	# <exp> 1D1D"},
/* 1D5A */ { "LETTRE MODIFICATIVE MINUSCULE M CULBUTÉ","	# <exp> 026F"},
/* 1D5B */ { "LETTRE MODIFICATIVE MINUSCULE V","	# <exp> 0076"},
/* 1D5C */ { "LETTRE MODIFICATIVE MINUSCULE 'AÏN","	x (lettre minuscule latine 'aïn égyptologique - A725)\n"
	"	# <exp> 1D25"},
/* 1D5D */ { "LETTRE MODIFICATIVE MINUSCULE BÊTA","	# <exp> 03B2"},
/* 1D5E */ { "LETTRE MODIFICATIVE MINUSCULE GRECQUE GAMMA","	# <exp> 03B3"},
/* 1D5F */ { "LETTRE MODIFICATIVE MINUSCULE DELTA","	# <exp> 03B4"},
/* 1D60 */ { "LETTRE MODIFICATIVE MINUSCULE GRECQUE PHI","	# <exp> 03C6"},
/* 1D61 */ { "LETTRE MODIFICATIVE MINUSCULE KHI","	# <exp> 03C7"},
/* 1D62 */ { "INDICE LETTRE MINUSCULE LATINE I","	# <souscrite> 0069"},
/* 1D63 */ { "INDICE LETTRE MINUSCULE LATINE R","	# <souscrite> 0072"},
/* 1D64 */ { "INDICE LETTRE MINUSCULE LATINE U","	# <souscrite> 0075"},
/* 1D65 */ { "INDICE LETTRE MINUSCULE LATINE V","	# <souscrite> 0076"},
/* 1D66 */ { "INDICE LETTRE MINUSCULE GRECQUE BÊTA","	# <souscrite> 03B2"},
/* 1D67 */ { "INDICE LETTRE MINUSCULE GRECQUE GAMMA","	# <souscrite> 03B3"},
/* 1D68 */ { "INDICE LETTRE MINUSCULE GRECQUE RHÔ","	# <souscrite> 03C1"},
/* 1D69 */ { "INDICE LETTRE MINUSCULE GRECQUE PHI","	# <souscrite> 03C6"},
/* 1D6A */ { "INDICE LETTRE MINUSCULE GRECQUE KHI","	# <souscrite> 03C7"},
/* 1D6B */ { "LETTRE MINUSCULE LATINE UE",NULL},
/* 1D6C */ { "LETTRE MINUSCULE LATINE B TILDE MÉDIAN",NULL},
/* 1D6D */ { "LETTRE MINUSCULE LATINE D TILDE MÉDIAN",NULL},
/* 1D6E */ { "LETTRE MINUSCULE LATINE F TILDE MÉDIAN",NULL},
/* 1D6F */ { "LETTRE MINUSCULE LATINE M TILDE MÉDIAN",NULL},
/* 1D70 */ { "LETTRE MINUSCULE LATINE N TILDE MÉDIAN",NULL},
/* 1D71 */ { "LETTRE MINUSCULE LATINE P TILDE MÉDIAN",NULL},
/* 1D72 */ { "LETTRE MINUSCULE LATINE R TILDE MÉDIAN",NULL},
/* 1D73 */ { "LETTRE MINUSCULE LATINE R SANS OBIT TILDE MÉDIAN",NULL},
/* 1D74 */ { "LETTRE MINUSCULE LATINE S TILDE MÉDIAN",NULL},
/* 1D75 */ { "LETTRE MINUSCULE LATINE T TILDE MÉDIAN",NULL},
/* 1D76 */ { "LETTRE MINUSCULE LATINE Z TILDE MÉDIAN",NULL},
/* 1D77 */ { "LETTRE MINUSCULE LATINE G CULBUTÉ","	* transcription du géorgien\n"
	"	x (lettre géorgienne gan culbuté - 10F9)"},
/* 1D78 */ { "LETTRE MODIFICATIVE CYRILLIQUE ENNE","	* remplace parfois 1D34 dans l'API étendu\n"
	"	x (lettre modificative majuscule h - 1D34)\n"
	"	# <exp> 043D"},
/* 1D79 */ { "LETTRE MINUSCULE LATINE G INSULAIRE","	* ancienne notation phonétique irlandaise\n"
	"	* la majuscule est A77D\n"
	"	x (lettre minuscule latine g - 0067)\n"
	"	x (lettre minuscule latine yogh - 021D)\n"
	"	x (lettre minuscule latine g cursif - 0261)\n"
	"	x (lettre minuscule latine gamma - 0263)\n"
	"	x (lettre minuscule latine g insulaire fermé - A7D1)"},
/* 1D7A */ { "LETTRE MINUSCULE LATINE TH BARRÉ OBLIQUEMENT","	* usage lexicographique américain\n"
	"	x (lettre minuscule grecque thêta - 03B8)"},
/* 1D7B */ { "LETTRE LATINE PETITE CAPITALE I BARRÉ","	* a des sens différents pour les américanistes et les dictionnaires Oxford\n"
	"	x (lettre majuscule latine i barré - 0197)"},
/* 1D7C */ { "LETTRE MINUSCULE LATINE IOTA BARRÉ","	* utilisée par les russistes"},
/* 1D7D */ { "LETTRE MINUSCULE LATINE P BARRÉ","	* utilisée par les américanistes\n"
	"	* la majuscule est 2C63"},
/* 1D7E */ { "LETTRE LATINE PETITE CAPITALE U BARRÉ","	* utilisée par les américanistes\n"
	"	x (lettre minuscule latine u barré - 0289)"},
/* 1D7F */ { "LETTRE MINUSCULE LATINE UPSILON BARRÉ","	* utilisée par les américanistes et les dictionnaires Oxford"},
/* 1D80 */ { "LETTRE MINUSCULE LATINE B HAMEÇON PALATAL",NULL},
/* 1D81 */ { "LETTRE MINUSCULE LATINE D HAMEÇON PALATAL",NULL},
/* 1D82 */ { "LETTRE MINUSCULE LATINE F HAMEÇON PALATAL",NULL},
/* 1D83 */ { "LETTRE MINUSCULE LATINE G HAMEÇON PALATAL",NULL},
/* 1D84 */ { "LETTRE MINUSCULE LATINE K HAMEÇON PALATAL",NULL},
/* 1D85 */ { "LETTRE MINUSCULE LATINE L HAMEÇON PALATAL",NULL},
/* 1D86 */ { "LETTRE MINUSCULE LATINE M HAMEÇON PALATAL","	x (lettre minuscule latine m hameçon - 0271)"},
/* 1D87 */ { "LETTRE MINUSCULE LATINE N HAMEÇON PALATAL","	x (lettre minuscule latine eng - 014B)"},
/* 1D88 */ { "LETTRE MINUSCULE LATINE P HAMEÇON PALATAL",NULL},
/* 1D89 */ { "LETTRE MINUSCULE LATINE R HAMEÇON PALATAL",NULL},
/* 1D8A */ { "LETTRE MINUSCULE LATINE S HAMEÇON PALATAL",NULL},
/* 1D8B */ { "LETTRE MINUSCULE LATINE ECH HAMEÇON PALATAL",NULL},
/* 1D8C */ { "LETTRE MINUSCULE LATINE V HAMEÇON PALATAL",NULL},
/* 1D8D */ { "LETTRE MINUSCULE LATINE X HAMEÇON PALATAL",NULL},
/* 1D8E */ { "LETTRE MINUSCULE LATINE Z HAMEÇON PALATAL","	* la majuscule est A7C6\n"
	"	x (lettre minuscule latine z hameçon - 0225)"},
/* 1D8F */ { "LETTRE MINUSCULE LATINE A HAMEÇON RÉTROFLEXE",NULL},
/* 1D90 */ { "LETTRE MINUSCULE LATINE ALPHA HAMEÇON RÉTROFLEXE",NULL},
/* 1D91 */ { "LETTRE MINUSCULE LATINE D CROSSE ET HAMEÇON RÉTROFLEXE",NULL},
/* 1D92 */ { "LETTRE MINUSCULE LATINE E HAMEÇON RÉTROFLEXE",NULL},
/* 1D93 */ { "LETTRE MINUSCULE LATINE E OUVERT HAMEÇON RÉTROFLEXE",NULL},
/* 1D94 */ { "LETTRE MINUSCULE LATINE E OUVERT RÉFLÉCHI HAMEÇON RÉTROFLEXE","	x (lettre minuscule latine e ouvert réfléchi crochet - 025D)"},
/* 1D95 */ { "LETTRE MINUSCULE LATINE SCHWA HAMEÇON RÉTROFLEXE","	x (lettre minuscule latine schwa crochet - 025A)"},
/* 1D96 */ { "LETTRE MINUSCULE LATINE I HAMEÇON RÉTROFLEXE",NULL},
/* 1D97 */ { "LETTRE MINUSCULE LATINE O OUVERT HAMEÇON RÉTROFLEXE",NULL},
/* 1D98 */ { "LETTRE MINUSCULE LATINE ECH HAMEÇON RÉTROFLEXE",NULL},
/* 1D99 */ { "LETTRE MINUSCULE LATINE U HAMEÇON RÉTROFLEXE",NULL},
/* 1D9A */ { "LETTRE MINUSCULE LATINE EJ HAMEÇON RÉTROFLEXE",NULL},
/* 1D9B */ { "LETTRE MODIFICATIVE MINUSCULE ALPHA CULBUTÉ","	# <exp> 0252"},
/* 1D9C */ { "LETTRE MODIFICATIVE MINUSCULE C","	# <exp> 0063"},
/* 1D9D */ { "LETTRE MODIFICATIVE MINUSCULE C BOUCLÉ","	# <exp> 0255"},
/* 1D9E */ { "LETTRE MODIFICATIVE MINUSCULE ED","	# <exp> 00F0"},
/* 1D9F */ { "LETTRE MODIFICATIVE MINUSCULE E OUVERT RÉFLÉCHI","	# <exp> 025C"},
/* 1DA0 */ { "LETTRE MODIFICATIVE MINUSCULE F","	# <exp> 0066"},
/* 1DA1 */ { "LETTRE MODIFICATIVE MINUSCULE J SANS POINT BARRÉ","	# <exp> 025F"},
/* 1DA2 */ { "LETTRE MODIFICATIVE MINUSCULE G CURSIF","	# <exp> 0261"},
/* 1DA3 */ { "LETTRE MODIFICATIVE MINUSCULE H CULBUTÉ","	# <exp> 0265"},
/* 1DA4 */ { "LETTRE MODIFICATIVE MINUSCULE I BARRÉ","	# <exp> 0268"},
/* 1DA5 */ { "LETTRE MODIFICATIVE MINUSCULE IOTA","	# <exp> 0269"},
/* 1DA6 */ { "LETTRE MODIFICATIVE PETITE CAPITALE I","	* pas destiné à l'APO\n"
	"	x (lettre modificative majuscule i - 1D35)\n"
	"	# <exp> 026A"},
/* 1DA7 */ { "LETTRE MODIFICATIVE PETITE CAPITALE I BARRÉ","	# <exp> 1D7B"},
/* 1DA8 */ { "LETTRE MODIFICATIVE MINUSCULE J À QUEUE CROISÉE","	# <exp> 029D"},
/* 1DA9 */ { "LETTRE MODIFICATIVE MINUSCULE L HAMEÇON RÉTROFLEXE","	# <exp> 026D"},
/* 1DAA */ { "LETTRE MODIFICATIVE MINUSCULE L HAMEÇON PALATAL","	# <exp> 1D85"},
/* 1DAB */ { "LETTRE MODIFICATIVE PETITE CAPITALE L","	* pas destiné à l'APO\n"
	"	x (lettre modificative majuscule l - 1D38)\n"
	"	# <exp> 029F"},
/* 1DAC */ { "LETTRE MODIFICATIVE MINUSCULE M HAMEÇON","	# <exp> 0271"},
/* 1DAD */ { "LETTRE MODIFICATIVE MINUSCULE M CULBUTÉ À LONG FÛT","	# <exp> 0270"},
/* 1DAE */ { "LETTRE MODIFICATIVE MINUSCULE N HAMEÇON À GAUCHE","	# <exp> 0272"},
/* 1DAF */ { "LETTRE MODIFICATIVE MINUSCULE N HAMEÇON RÉTROFLEXE","	# <exp> 0273"},
/* 1DB0 */ { "LETTRE MODIFICATIVE PETITE CAPITALE N","	* pas destiné à l'APO\n"
	"	x (lettre modificative majuscule n - 1D3A)\n"
	"	# <exp> 0274"},
/* 1DB1 */ { "LETTRE MODIFICATIVE MINUSCULE O BARRÉ","	# <exp> 0275"},
/* 1DB2 */ { "LETTRE MODIFICATIVE MINUSCULE PHI","	# <exp> 0278"},
/* 1DB3 */ { "LETTRE MODIFICATIVE MINUSCULE S HAMEÇON RÉTROFLEXE","	# <exp> 0282"},
/* 1DB4 */ { "LETTRE MODIFICATIVE MINUSCULE ECH","	# <exp> 0283"},
/* 1DB5 */ { "LETTRE MODIFICATIVE MINUSCULE T HAMEÇON PALATAL","	# <exp> 01AB"},
/* 1DB6 */ { "LETTRE MODIFICATIVE MINUSCULE U BARRÉ","	# <exp> 0289"},
/* 1DB7 */ { "LETTRE MODIFICATIVE MINUSCULE UPSILON","	# <exp> 028A"},
/* 1DB8 */ { "LETTRE MODIFICATIVE PETITE CAPITALE U","	* pas destiné à l'APO\n"
	"	x (lettre modificative majuscule u - 1D41)\n"
	"	# <exp> 1D1C"},
/* 1DB9 */ { "LETTRE MODIFICATIVE MINUSCULE V CROSSE","	# <exp> 028B"},
/* 1DBA */ { "LETTRE MODIFICATIVE MINUSCULE V CULBUTÉ","	# <exp> 028C"},
/* 1DBB */ { "LETTRE MODIFICATIVE MINUSCULE Z","	# <exp> 007A"},
/* 1DBC */ { "LETTRE MODIFICATIVE MINUSCULE Z HAMEÇON RÉTROFLEXE","	# <exp> 0290"},
/* 1DBD */ { "LETTRE MODIFICATIVE MINUSCULE Z BOUCLÉ","	# <exp> 0291"},
/* 1DBE */ { "LETTRE MODIFICATIVE MINUSCULE EJ","	# <exp> 0292"},
/* 1DBF */ { "LETTRE MODIFICATIVE MINUSCULE THÊTA","	# <exp> 03B8"},
/* 1DC0 */ { "DIACRITIQUE ACCENT GRAVE POINTÉ","	x (diacritique accent grave - 0300)\n"
	"	x (tréma et accent grave grecs - 1FED)"},
/* 1DC1 */ { "DIACRITIQUE ACCENT AIGU POINTÉ","	x (diacritique accent aigu - 0301)\n"
	"	x (diacritique grec tréma accent - 0344)\n"
	"	x (tréma et accent aigu grecs - 1FEE)"},
/* 1DC2 */ { "DIACRITIQUE SERPENT SOUSCRIT",NULL},
/* 1DC3 */ { "DIACRITIQUE POINT DE SUSPENSION","	* signe d'abréviation en glagolitique\n"
	"	x (diacritique brève - 0306)"},
/* 1DC4 */ { "DIACRITIQUE MACRON-AIGU","	* également utilisé pour représenter le diacritique « apex » du moyen vietnamien (dấu sóng)\n"
	"	x (diacritique tilde - 0303)"},
/* 1DC5 */ { "DIACRITIQUE GRAVE-MACRON",NULL},
/* 1DC6 */ { "DIACRITIQUE MACRON-GRAVE",NULL},
/* 1DC7 */ { "DIACRITIQUE AIGU-MACRON",NULL},
/* 1DC8 */ { "DIACRITIQUE GRAVE-AIGU-GRAVE",NULL},
/* 1DC9 */ { "DIACRITIQUE AIGU-GRAVE-AIGU",NULL},
/* 1DCA */ { "DIACRITIQUE LETTRE MINUSCULE LATINE R SOUSCRIT",NULL},
/* 1DCB */ { "DIACRITIQUE BRÈVE-MACRON","	* dialectologie lituanienne"},
/* 1DCC */ { "DIACRITIQUE MACRON-BRÈVE","	* dialectologie lituanienne"},
/* 1DCD */ { "DIACRITIQUE DOUBLE CIRCONFLEXE",NULL},
/* 1DCE */ { "DIACRITIQUE OGONEK EN CHEF",NULL},
/* 1DCF */ { "DIACRITIQUE EN ZIGZAG SOUSCRIT",NULL},
/* 1DD0 */ { "DIACRITIQUE IS SOUSCRIT",NULL},
/* 1DD1 */ { "DIACRITIQUE UR SUSCRIT",NULL},
/* 1DD2 */ { "DIACRITIQUE US SUSCRIT",NULL},
/* 1DD3 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE A OUVERT APLATI SUSCRIT",NULL},
/* 1DD4 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE AE",NULL},
/* 1DD5 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE AO",NULL},
/* 1DD6 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE AV",NULL},
/* 1DD7 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE C CÉDILLE",NULL},
/* 1DD8 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE D INSULAIRE",NULL},
/* 1DD9 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE ETH",NULL},
/* 1DDA */ { "DIACRITIQUE LETTRE MINUSCULE LATINE G",NULL},
/* 1DDB */ { "DIACRITIQUE LETTRE LATINE PETITE CAPITALE G",NULL},
/* 1DDC */ { "DIACRITIQUE LETTRE MINUSCULE LATINE K",NULL},
/* 1DDD */ { "DIACRITIQUE LETTRE MINUSCULE LATINE L",NULL},
/* 1DDE */ { "DIACRITIQUE LETTRE LATINE PETITE CAPITALE L",NULL},
/* 1DDF */ { "DIACRITIQUE LETTRE LATINE PETITE CAPITALE M",NULL},
/* 1DE0 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE N",NULL},
/* 1DE1 */ { "DIACRITIQUE LETTRE LATINE PETITE CAPITALE N",NULL},
/* 1DE2 */ { "DIACRITIQUE LETTRE LATINE PETITE CAPITALE R",NULL},
/* 1DE3 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE R ROTUNDA",NULL},
/* 1DE4 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE S",NULL},
/* 1DE5 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE S LONG",NULL},
/* 1DE6 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE Z",NULL},
/* 1DE7 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE ALPHA",NULL},
/* 1DE8 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE B",NULL},
/* 1DE9 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE BÊTA",NULL},
/* 1DEA */ { "DIACRITIQUE LETTRE MINUSCULE LATINE SCHWA",NULL},
/* 1DEB */ { "DIACRITIQUE LETTRE MINUSCULE LATINE F",NULL},
/* 1DEC */ { "DIACRITIQUE LETTRE MINUSCULE LATINE L DOUBLE TILDE MÉDIAN",NULL},
/* 1DED */ { "DIACRITIQUE LETTRE MINUSCULE LATINE O À TRAIT DE CENTRALISATION LÉGER",NULL},
/* 1DEE */ { "DIACRITIQUE LETTRE MINUSCULE LATINE P",NULL},
/* 1DEF */ { "DIACRITIQUE LETTRE MINUSCULE LATINE ECH",NULL},
/* 1DF0 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE U À TRAIT DE CENTRALISATION LÉGER",NULL},
/* 1DF1 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE W","	x (diacritique lettre minuscule latine w souscrit - 1ABF)\n"
	"	x (diacritique oméga en chef - 1AC7)"},
/* 1DF2 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE A TRÉMA",NULL},
/* 1DF3 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE O TRÉMA",NULL},
/* 1DF4 */ { "DIACRITIQUE LETTRE MINUSCULE LATINE U TRÉMA",NULL},
/* 1DF5 */ { "DIACRITIQUE TAQUET VERS LE HAUT EN CHEF","	x (diacritique taquet vers le haut souscrit - 031D)"},
/* 1DF6 */ { "DIACRITIQUE KAVYKA EN CHEF À DROITE",NULL},
/* 1DF7 */ { "DIACRITIQUE KAVYKA EN CHEF À GAUCHE","	x (diacritique cyrillique kavyka - A67C)"},
/* 1DF8 */ { "DIACRITIQUE POINT EN CHEF À GAUCHE","	* utilisé en syriaque comme un point de désambiguïsation\n"
	"	* utilisé dans le cyrillique du typikon, où le point peut avoir un dessin carré\n"
	"	* utilisé dans la notation phonétique américaniste en alphabet latin de Franz Boas\n"
	"	x (diacritique point en chef à droite - 0358)\n"
	"	x (point féminin syriaque - 0740)"},
/* 1DF9 */ { "DIACRITIQUE PONT RENVERSÉ SOUSCRIT","	* est utilisé pour un signe du typikon\n"
	"	x (diacritique pontet renversé souscrit - 033A)"},
/* 1DFA */ { "DIACRITIQUE POINT SOUSCRIT À GAUCHE","	* utilisé en syriaque comme un point de désambiguïsation"},
/* 1DFB */ { "DIACRITIQUE DE SUPPRESSION","	* utilisé pour « mhusaa » dans la tradition scribale néwar"},
/* 1DFC */ { "DIACRITIQUE DOUBLE BRÈVE RENVERSÉE SOUSCRITE",NULL},
/* 1DFD */ { "DIACRITIQUE SOUSCRIT PRESQUE ÉGAL À","	* indique une voyelle stridente dans les langues de la famille khoïsane"},
/* 1DFE */ { "DIACRITIQUE POINTE DE FLÈCHE VERS LA GAUCHE EN CHEF","	x (diacritique pointe de flèche vers la gauche souscrite - 0354)"},
/* 1DFF */ { "DIACRITIQUE POINTES DE FLÈCHE VERS LA DROITE ET VERS LE BAS SOUSCRITES",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_1E[] = {
/* 1E00 */ { "LETTRE MAJUSCULE LATINE A ROND SOUSCRIT","	: 0041 0325"},
/* 1E01 */ { "LETTRE MINUSCULE LATINE A ROND SOUSCRIT","	: 0061 0325"},
/* 1E02 */ { "LETTRE MAJUSCULE LATINE B POINT EN CHEF","	: 0042 0307"},
/* 1E03 */ { "LETTRE MINUSCULE LATINE B POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 0062 0307"},
/* 1E04 */ { "LETTRE MAJUSCULE LATINE B POINT SOUSCRIT","	: 0042 0323"},
/* 1E05 */ { "LETTRE MINUSCULE LATINE B POINT SOUSCRIT","	: 0062 0323"},
/* 1E06 */ { "LETTRE MAJUSCULE LATINE B LIGNE SOUSCRITE","	: 0042 0331"},
/* 1E07 */ { "LETTRE MINUSCULE LATINE B LIGNE SOUSCRITE","	: 0062 0331"},
/* 1E08 */ { "LETTRE MAJUSCULE LATINE C CÉDILLE ET ACCENT AIGU","	: 00C7 0301"},
/* 1E09 */ { "LETTRE MINUSCULE LATINE C CÉDILLE ET ACCENT AIGU","	: 00E7 0301"},
/* 1E0A */ { "LETTRE MAJUSCULE LATINE D POINT EN CHEF","	: 0044 0307"},
/* 1E0B */ { "LETTRE MINUSCULE LATINE D POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 0064 0307"},
/* 1E0C */ { "LETTRE MAJUSCULE LATINE D POINT SOUSCRIT","	: 0044 0323"},
/* 1E0D */ { "LETTRE MINUSCULE LATINE D POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	: 0064 0323"},
/* 1E0E */ { "LETTRE MAJUSCULE LATINE D LIGNE SOUSCRITE","	: 0044 0331"},
/* 1E0F */ { "LETTRE MINUSCULE LATINE D LIGNE SOUSCRITE","	: 0064 0331"},
/* 1E10 */ { "LETTRE MAJUSCULE LATINE D CÉDILLE","	: 0044 0327"},
/* 1E11 */ { "LETTRE MINUSCULE LATINE D CÉDILLE","	* live\n"
	"	* en dépit de leurs noms, ces deux caractères devraient normalement être affichés avec une virgule souscrite\n"
	"	: 0064 0327"},
/* 1E12 */ { "LETTRE MAJUSCULE LATINE D ACCENT CIRCONFLEXE SOUSCRIT","	: 0044 032D"},
/* 1E13 */ { "LETTRE MINUSCULE LATINE D ACCENT CIRCONFLEXE SOUSCRIT","	: 0064 032D"},
/* 1E14 */ { "LETTRE MAJUSCULE LATINE E MACRON ET ACCENT GRAVE","	: 0112 0300"},
/* 1E15 */ { "LETTRE MINUSCULE LATINE E MACRON ET ACCENT GRAVE","	: 0113 0300"},
/* 1E16 */ { "LETTRE MAJUSCULE LATINE E MACRON ET ACCENT AIGU","	: 0112 0301"},
/* 1E17 */ { "LETTRE MINUSCULE LATINE E MACRON ET ACCENT AIGU","	: 0113 0301"},
/* 1E18 */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE SOUSCRIT","	: 0045 032D"},
/* 1E19 */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE SOUSCRIT","	: 0065 032D"},
/* 1E1A */ { "LETTRE MAJUSCULE LATINE E TILDE SOUSCRIT","	: 0045 0330"},
/* 1E1B */ { "LETTRE MINUSCULE LATINE E TILDE SOUSCRIT","	: 0065 0330"},
/* 1E1C */ { "LETTRE MAJUSCULE LATINE E CÉDILLE ET BRÈVE","	: 0228 0306"},
/* 1E1D */ { "LETTRE MINUSCULE LATINE E CÉDILLE ET BRÈVE","	* translittération de l'hébreu\n"
	"	: 0229 0306"},
/* 1E1E */ { "LETTRE MAJUSCULE LATINE F POINT EN CHEF","	: 0046 0307"},
/* 1E1F */ { "LETTRE MINUSCULE LATINE F POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 0066 0307"},
/* 1E20 */ { "LETTRE MAJUSCULE LATINE G MACRON","	: 0047 0304"},
/* 1E21 */ { "LETTRE MINUSCULE LATINE G MACRON","	: 0067 0304"},
/* 1E22 */ { "LETTRE MAJUSCULE LATINE H POINT EN CHEF","	: 0048 0307"},
/* 1E23 */ { "LETTRE MINUSCULE LATINE H POINT EN CHEF","	: 0068 0307"},
/* 1E24 */ { "LETTRE MAJUSCULE LATINE H POINT SOUSCRIT","	: 0048 0323"},
/* 1E25 */ { "LETTRE MINUSCULE LATINE H POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	: 0068 0323"},
/* 1E26 */ { "LETTRE MAJUSCULE LATINE H TRÉMA","	: 0048 0308"},
/* 1E27 */ { "LETTRE MINUSCULE LATINE H TRÉMA","	: 0068 0308"},
/* 1E28 */ { "LETTRE MAJUSCULE LATINE H CÉDILLE","	: 0048 0327"},
/* 1E29 */ { "LETTRE MINUSCULE LATINE H CÉDILLE","	: 0068 0327"},
/* 1E2A */ { "LETTRE MAJUSCULE LATINE H BRÈVE SOUSCRITE","	: 0048 032E"},
/* 1E2B */ { "LETTRE MINUSCULE LATINE H BRÈVE SOUSCRITE","	* translittération des écritures sémitiques\n"
	"	: 0068 032E"},
/* 1E2C */ { "LETTRE MAJUSCULE LATINE I TILDE SOUSCRIT","	: 0049 0330"},
/* 1E2D */ { "LETTRE MINUSCULE LATINE I TILDE SOUSCRIT","	: 0069 0330"},
/* 1E2E */ { "LETTRE MAJUSCULE LATINE I TRÉMA ET ACCENT AIGU","	: 00CF 0301"},
/* 1E2F */ { "LETTRE MINUSCULE LATINE I TRÉMA ET ACCENT AIGU","	: 00EF 0301"},
/* 1E30 */ { "LETTRE MAJUSCULE LATINE K ACCENT AIGU","	: 004B 0301"},
/* 1E31 */ { "LETTRE MINUSCULE LATINE K ACCENT AIGU","	* translittération du macédonien\n"
	"	: 006B 0301"},
/* 1E32 */ { "LETTRE MAJUSCULE LATINE K POINT SOUSCRIT","	: 004B 0323"},
/* 1E33 */ { "LETTRE MINUSCULE LATINE K POINT SOUSCRIT","	: 006B 0323"},
/* 1E34 */ { "LETTRE MAJUSCULE LATINE K LIGNE SOUSCRITE","	: 004B 0331"},
/* 1E35 */ { "LETTRE MINUSCULE LATINE K LIGNE SOUSCRITE","	: 006B 0331"},
/* 1E36 */ { "LETTRE MAJUSCULE LATINE L POINT SOUSCRIT","	: 004C 0323"},
/* 1E37 */ { "LETTRE MINUSCULE LATINE L POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	* voir la norme ISO 15919 sur l'utilisation du point souscrit par opposition au rond souscrit dans la translittération des écritures indiennes\n"
	"	x (diacritique rond souscrit - 0325)\n"
	"	: 006C 0323"},
/* 1E38 */ { "LETTRE MAJUSCULE LATINE L POINT SOUSCRIT ET MACRON","	: 1E36 0304"},
/* 1E39 */ { "LETTRE MINUSCULE LATINE L POINT SOUSCRIT ET MACRON","	* translittération des écritures indiennes\n"
	"	: 1E37 0304"},
/* 1E3A */ { "LETTRE MAJUSCULE LATINE L LIGNE SOUSCRITE","	: 004C 0331"},
/* 1E3B */ { "LETTRE MINUSCULE LATINE L LIGNE SOUSCRITE","	* translittération des écritures indiennes\n"
	"	: 006C 0331"},
/* 1E3C */ { "LETTRE MAJUSCULE LATINE L ACCENT CIRCONFLEXE SOUSCRIT","	: 004C 032D"},
/* 1E3D */ { "LETTRE MINUSCULE LATINE L ACCENT CIRCONFLEXE SOUSCRIT","	: 006C 032D"},
/* 1E3E */ { "LETTRE MAJUSCULE LATINE M ACCENT AIGU","	: 004D 0301"},
/* 1E3F */ { "LETTRE MINUSCULE LATINE M ACCENT AIGU","	: 006D 0301"},
/* 1E40 */ { "LETTRE MAJUSCULE LATINE M POINT EN CHEF","	: 004D 0307"},
/* 1E41 */ { "LETTRE MINUSCULE LATINE M POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 006D 0307"},
/* 1E42 */ { "LETTRE MAJUSCULE LATINE M POINT SOUSCRIT","	: 004D 0323"},
/* 1E43 */ { "LETTRE MINUSCULE LATINE M POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	: 006D 0323"},
/* 1E44 */ { "LETTRE MAJUSCULE LATINE N POINT EN CHEF","	: 004E 0307"},
/* 1E45 */ { "LETTRE MINUSCULE LATINE N POINT EN CHEF","	* translittération des écritures indiennes\n"
	"	: 006E 0307"},
/* 1E46 */ { "LETTRE MAJUSCULE LATINE N POINT SOUSCRIT","	: 004E 0323"},
/* 1E47 */ { "LETTRE MINUSCULE LATINE N POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	: 006E 0323"},
/* 1E48 */ { "LETTRE MAJUSCULE LATINE N LIGNE SOUSCRITE","	: 004E 0331"},
/* 1E49 */ { "LETTRE MINUSCULE LATINE N LIGNE SOUSCRITE","	* translittération des écritures indiennes\n"
	"	: 006E 0331"},
/* 1E4A */ { "LETTRE MAJUSCULE LATINE N ACCENT CIRCONFLEXE SOUSCRIT","	: 004E 032D"},
/* 1E4B */ { "LETTRE MINUSCULE LATINE N ACCENT CIRCONFLEXE SOUSCRIT","	: 006E 032D"},
/* 1E4C */ { "LETTRE MAJUSCULE LATINE O TILDE ET ACCENT AIGU","	: 00D5 0301"},
/* 1E4D */ { "LETTRE MINUSCULE LATINE O TILDE ET ACCENT AIGU","	: 00F5 0301"},
/* 1E4E */ { "LETTRE MAJUSCULE LATINE O TILDE ET TRÉMA","	: 00D5 0308"},
/* 1E4F */ { "LETTRE MINUSCULE LATINE O TILDE ET TRÉMA","	: 00F5 0308"},
/* 1E50 */ { "LETTRE MAJUSCULE LATINE O MACRON ET ACCENT GRAVE","	: 014C 0300"},
/* 1E51 */ { "LETTRE MINUSCULE LATINE O MACRON ET ACCENT GRAVE","	: 014D 0300"},
/* 1E52 */ { "LETTRE MAJUSCULE LATINE O MACRON ET ACCENT AIGU","	: 014C 0301"},
/* 1E53 */ { "LETTRE MINUSCULE LATINE O MACRON ET ACCENT AIGU","	: 014D 0301"},
/* 1E54 */ { "LETTRE MAJUSCULE LATINE P ACCENT AIGU","	: 0050 0301"},
/* 1E55 */ { "LETTRE MINUSCULE LATINE P ACCENT AIGU","	: 0070 0301"},
/* 1E56 */ { "LETTRE MAJUSCULE LATINE P POINT EN CHEF","	: 0050 0307"},
/* 1E57 */ { "LETTRE MINUSCULE LATINE P POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 0070 0307"},
/* 1E58 */ { "LETTRE MAJUSCULE LATINE R POINT EN CHEF","	: 0052 0307"},
/* 1E59 */ { "LETTRE MINUSCULE LATINE R POINT EN CHEF","	: 0072 0307"},
/* 1E5A */ { "LETTRE MAJUSCULE LATINE R POINT SOUSCRIT","	: 0052 0323"},
/* 1E5B */ { "LETTRE MINUSCULE LATINE R POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	* voir la norme ISO 15919 sur l'utilisation du point souscrit par opposition au rond souscrit dans la translittération des écritures indiennes\n"
	"	x (diacritique rond souscrit - 0325)\n"
	"	: 0072 0323"},
/* 1E5C */ { "LETTRE MAJUSCULE LATINE R POINT SOUSCRIT ET MACRON","	: 1E5A 0304"},
/* 1E5D */ { "LETTRE MINUSCULE LATINE R POINT SOUSCRIT ET MACRON","	* translittération des écritures indiennes\n"
	"	: 1E5B 0304"},
/* 1E5E */ { "LETTRE MAJUSCULE LATINE R LIGNE SOUSCRITE","	: 0052 0331"},
/* 1E5F */ { "LETTRE MINUSCULE LATINE R LIGNE SOUSCRITE","	* translittération des écritures indiennes\n"
	"	: 0072 0331"},
/* 1E60 */ { "LETTRE MAJUSCULE LATINE S POINT EN CHEF","	: 0053 0307"},
/* 1E61 */ { "LETTRE MINUSCULE LATINE S POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 0073 0307"},
/* 1E62 */ { "LETTRE MAJUSCULE LATINE S POINT SOUSCRIT","	: 0053 0323"},
/* 1E63 */ { "LETTRE MINUSCULE LATINE S POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	: 0073 0323"},
/* 1E64 */ { "LETTRE MAJUSCULE LATINE S ACCENT AIGU ET POINT EN CHEF","	: 015A 0307"},
/* 1E65 */ { "LETTRE MINUSCULE LATINE S ACCENT AIGU ET POINT EN CHEF","	: 015B 0307"},
/* 1E66 */ { "LETTRE MAJUSCULE LATINE S CARON ET POINT EN CHEF","	: 0160 0307"},
/* 1E67 */ { "LETTRE MINUSCULE LATINE S CARON ET POINT EN CHEF","	: 0161 0307"},
/* 1E68 */ { "LETTRE MAJUSCULE LATINE S POINT SOUSCRIT ET POINT EN CHEF","	: 1E62 0307"},
/* 1E69 */ { "LETTRE MINUSCULE LATINE S POINT SOUSCRIT ET POINT EN CHEF","	: 1E63 0307"},
/* 1E6A */ { "LETTRE MAJUSCULE LATINE T POINT EN CHEF","	: 0054 0307"},
/* 1E6B */ { "LETTRE MINUSCULE LATINE T POINT EN CHEF","	* gaélique irlandais (ancienne orthographe)\n"
	"	: 0074 0307"},
/* 1E6C */ { "LETTRE MAJUSCULE LATINE T POINT SOUSCRIT","	: 0054 0323"},
/* 1E6D */ { "LETTRE MINUSCULE LATINE T POINT SOUSCRIT","	* translittération des écritures indiennes\n"
	"	: 0074 0323"},
/* 1E6E */ { "LETTRE MAJUSCULE LATINE T LIGNE SOUSCRITE","	: 0054 0331"},
/* 1E6F */ { "LETTRE MINUSCULE LATINE T LIGNE SOUSCRITE","	* translittération des écritures sémitiques\n"
	"	: 0074 0331"},
/* 1E70 */ { "LETTRE MAJUSCULE LATINE T ACCENT CIRCONFLEXE SOUSCRIT","	: 0054 032D"},
/* 1E71 */ { "LETTRE MINUSCULE LATINE T ACCENT CIRCONFLEXE SOUSCRIT","	: 0074 032D"},
/* 1E72 */ { "LETTRE MAJUSCULE LATINE U TRÉMA SOUSCRIT","	: 0055 0324"},
/* 1E73 */ { "LETTRE MINUSCULE LATINE U TRÉMA SOUSCRIT","	: 0075 0324"},
/* 1E74 */ { "LETTRE MAJUSCULE LATINE U TILDE SOUSCRIT","	: 0055 0330"},
/* 1E75 */ { "LETTRE MINUSCULE LATINE U TILDE SOUSCRIT","	: 0075 0330"},
/* 1E76 */ { "LETTRE MAJUSCULE LATINE U ACCENT CIRCONFLEXE SOUSCRIT","	: 0055 032D"},
/* 1E77 */ { "LETTRE MINUSCULE LATINE U ACCENT CIRCONFLEXE SOUSCRIT","	: 0075 032D"},
/* 1E78 */ { "LETTRE MAJUSCULE LATINE U TILDE ET ACCENT AIGU","	: 0168 0301"},
/* 1E79 */ { "LETTRE MINUSCULE LATINE U TILDE ET ACCENT AIGU","	: 0169 0301"},
/* 1E7A */ { "LETTRE MAJUSCULE LATINE U MACRON ET TRÉMA","	: 016A 0308"},
/* 1E7B */ { "LETTRE MINUSCULE LATINE U MACRON ET TRÉMA","	: 016B 0308"},
/* 1E7C */ { "LETTRE MAJUSCULE LATINE V TILDE","	: 0056 0303"},
/* 1E7D */ { "LETTRE MINUSCULE LATINE V TILDE","	: 0076 0303"},
/* 1E7E */ { "LETTRE MAJUSCULE LATINE V POINT SOUSCRIT","	: 0056 0323"},
/* 1E7F */ { "LETTRE MINUSCULE LATINE V POINT SOUSCRIT","	: 0076 0323"},
/* 1E80 */ { "LETTRE MAJUSCULE LATINE W ACCENT GRAVE","	: 0057 0300"},
/* 1E81 */ { "LETTRE MINUSCULE LATINE W ACCENT GRAVE","	* gallois\n"
	"	: 0077 0300"},
/* 1E82 */ { "LETTRE MAJUSCULE LATINE W ACCENT AIGU","	: 0057 0301"},
/* 1E83 */ { "LETTRE MINUSCULE LATINE W ACCENT AIGU","	* gallois\n"
	"	: 0077 0301"},
/* 1E84 */ { "LETTRE MAJUSCULE LATINE W TRÉMA","	: 0057 0308"},
/* 1E85 */ { "LETTRE MINUSCULE LATINE W TRÉMA","	* gallois\n"
	"	: 0077 0308"},
/* 1E86 */ { "LETTRE MAJUSCULE LATINE W POINT EN CHEF","	: 0057 0307"},
/* 1E87 */ { "LETTRE MINUSCULE LATINE W POINT EN CHEF","	: 0077 0307"},
/* 1E88 */ { "LETTRE MAJUSCULE LATINE W POINT SOUSCRIT","	: 0057 0323"},
/* 1E89 */ { "LETTRE MINUSCULE LATINE W POINT SOUSCRIT","	: 0077 0323"},
/* 1E8A */ { "LETTRE MAJUSCULE LATINE X POINT EN CHEF","	: 0058 0307"},
/* 1E8B */ { "LETTRE MINUSCULE LATINE X POINT EN CHEF","	: 0078 0307"},
/* 1E8C */ { "LETTRE MAJUSCULE LATINE X TRÉMA","	: 0058 0308"},
/* 1E8D */ { "LETTRE MINUSCULE LATINE X TRÉMA","	: 0078 0308"},
/* 1E8E */ { "LETTRE MAJUSCULE LATINE Y POINT EN CHEF","	: 0059 0307"},
/* 1E8F */ { "LETTRE MINUSCULE LATINE Y POINT EN CHEF","	: 0079 0307"},
/* 1E90 */ { "LETTRE MAJUSCULE LATINE Z ACCENT CIRCONFLEXE","	: 005A 0302"},
/* 1E91 */ { "LETTRE MINUSCULE LATINE Z ACCENT CIRCONFLEXE","	: 007A 0302"},
/* 1E92 */ { "LETTRE MAJUSCULE LATINE Z POINT SOUSCRIT","	: 005A 0323"},
/* 1E93 */ { "LETTRE MINUSCULE LATINE Z POINT SOUSCRIT","	* translittération des écritures sémitiques\n"
	"	x (lettre arabe zza' - 0638)\n"
	"	: 007A 0323"},
/* 1E94 */ { "LETTRE MAJUSCULE LATINE Z LIGNE SOUSCRITE","	: 005A 0331"},
/* 1E95 */ { "LETTRE MINUSCULE LATINE Z LIGNE SOUSCRITE","	* translittération des écritures sémitiques\n"
	"	: 007A 0331"},
/* 1E96 */ { "LETTRE MINUSCULE LATINE H LIGNE SOUSCRITE","	* translittération des écritures sémitiques\n"
	"	: 0068 0331"},
/* 1E97 */ { "LETTRE MINUSCULE LATINE T TRÉMA","	: 0074 0308"},
/* 1E98 */ { "LETTRE MINUSCULE LATINE W ROND EN CHEF","	: 0077 030A"},
/* 1E99 */ { "LETTRE MINUSCULE LATINE Y ROND EN CHEF","	: 0079 030A"},
/* 1E9A */ { "LETTRE MINUSCULE LATINE A DEMI-ROND DROIT","	# 0061 02BE"},
/* 1E9B */ { "LETTRE MINUSCULE LATINE S LONG POINT EN CHEF","	* s'utilise actuellement en gaélique (variante de glyphe de 1E61)\n"
	"	: 017F 0307"},
/* 1E9C */ { "LETTRE MINUSCULE LATINE S LONG À BARRE DIAGONALE","	* usage médiéviste pour plusieurs abréviations\n"
	"	* utilisée dans l'orthographe lettone d'avant 1921\n"
	"	* utilisée dans les polices gothiques de l'orthographe du bas-sorabe d'avant 1950\n"
	"	x (lettre minuscule latine s barre oblique - A7A9)"},
/* 1E9D */ { "LETTRE MINUSCULE LATINE S LONG À BARRE HAUTE",NULL},
/* 1E9E */ { "LETTRE MAJUSCULE LATINE S DUR","	* inutilisée en allemand standard suisse (« haut-allemand » suisse)\n"
	"	* la minuscule est 00DF\n"
	"	x (lettre minuscule latine s dur - 00DF)\n"
	"	x (lettre majuscule latine s moyen scots - A7D6)"},
/* 1E9F */ { "LETTRE MINUSCULE LATINE DELTA","	* lettre à casse unique\n"
	"	x (lettre minuscule grecque delta - 03B4)"},
/* 1EA0 */ { "LETTRE MAJUSCULE LATINE A POINT SOUSCRIT","	: 0041 0323"},
/* 1EA1 */ { "LETTRE MINUSCULE LATINE A POINT SOUSCRIT","	: 0061 0323"},
/* 1EA2 */ { "LETTRE MAJUSCULE LATINE A CROCHET EN CHEF","	: 0041 0309"},
/* 1EA3 */ { "LETTRE MINUSCULE LATINE A CROCHET EN CHEF","	: 0061 0309"},
/* 1EA4 */ { "LETTRE MAJUSCULE LATINE A ACCENT CIRCONFLEXE ET ACCENT AIGU","	: 00C2 0301"},
/* 1EA5 */ { "LETTRE MINUSCULE LATINE A ACCENT CIRCONFLEXE ET ACCENT AIGU","	: 00E2 0301"},
/* 1EA6 */ { "LETTRE MAJUSCULE LATINE A ACCENT CIRCONFLEXE ET ACCENT GRAVE","	: 00C2 0300"},
/* 1EA7 */ { "LETTRE MINUSCULE LATINE A ACCENT CIRCONFLEXE ET ACCENT GRAVE","	: 00E2 0300"},
/* 1EA8 */ { "LETTRE MAJUSCULE LATINE A ACCENT CIRCONFLEXE ET CROCHET EN CHEF","	: 00C2 0309"},
/* 1EA9 */ { "LETTRE MINUSCULE LATINE A ACCENT CIRCONFLEXE ET CROCHET EN CHEF","	: 00E2 0309"},
/* 1EAA */ { "LETTRE MAJUSCULE LATINE A ACCENT CIRCONFLEXE ET TILDE","	: 00C2 0303"},
/* 1EAB */ { "LETTRE MINUSCULE LATINE A ACCENT CIRCONFLEXE ET TILDE","	: 00E2 0303"},
/* 1EAC */ { "LETTRE MAJUSCULE LATINE A ACCENT CIRCONFLEXE ET POINT SOUSCRIT","	: 1EA0 0302"},
/* 1EAD */ { "LETTRE MINUSCULE LATINE A ACCENT CIRCONFLEXE ET POINT SOUSCRIT","	: 1EA1 0302"},
/* 1EAE */ { "LETTRE MAJUSCULE LATINE A BRÈVE ET ACCENT AIGU","	: 0102 0301"},
/* 1EAF */ { "LETTRE MINUSCULE LATINE A BRÈVE ET ACCENT AIGU","	: 0103 0301"},
/* 1EB0 */ { "LETTRE MAJUSCULE LATINE A BRÈVE ET ACCENT GRAVE","	: 0102 0300"},
/* 1EB1 */ { "LETTRE MINUSCULE LATINE A BRÈVE ET ACCENT GRAVE","	: 0103 0300"},
/* 1EB2 */ { "LETTRE MAJUSCULE LATINE A BRÈVE ET CROCHET EN CHEF","	: 0102 0309"},
/* 1EB3 */ { "LETTRE MINUSCULE LATINE A BRÈVE ET CROCHET EN CHEF","	: 0103 0309"},
/* 1EB4 */ { "LETTRE MAJUSCULE LATINE A BRÈVE ET TILDE","	: 0102 0303"},
/* 1EB5 */ { "LETTRE MINUSCULE LATINE A BRÈVE ET TILDE","	: 0103 0303"},
/* 1EB6 */ { "LETTRE MAJUSCULE LATINE A BRÈVE ET POINT SOUSCRIT","	: 1EA0 0306"},
/* 1EB7 */ { "LETTRE MINUSCULE LATINE A BRÈVE ET POINT SOUSCRIT","	: 1EA1 0306"},
/* 1EB8 */ { "LETTRE MAJUSCULE LATINE E POINT SOUSCRIT","	: 0045 0323"},
/* 1EB9 */ { "LETTRE MINUSCULE LATINE E POINT SOUSCRIT","	: 0065 0323"},
/* 1EBA */ { "LETTRE MAJUSCULE LATINE E CROCHET EN CHEF","	: 0045 0309"},
/* 1EBB */ { "LETTRE MINUSCULE LATINE E CROCHET EN CHEF","	: 0065 0309"},
/* 1EBC */ { "LETTRE MAJUSCULE LATINE E TILDE","	: 0045 0303"},
/* 1EBD */ { "LETTRE MINUSCULE LATINE E TILDE","	: 0065 0303"},
/* 1EBE */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE ET ACCENT AIGU","	: 00CA 0301"},
/* 1EBF */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE ET ACCENT AIGU","	: 00EA 0301"},
/* 1EC0 */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE ET ACCENT GRAVE","	: 00CA 0300"},
/* 1EC1 */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE ET ACCENT GRAVE","	: 00EA 0300"},
/* 1EC2 */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE ET CROCHET EN CHEF","	: 00CA 0309"},
/* 1EC3 */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE ET CROCHET EN CHEF","	: 00EA 0309"},
/* 1EC4 */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE ET TILDE","	: 00CA 0303"},
/* 1EC5 */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE ET TILDE","	: 00EA 0303"},
/* 1EC6 */ { "LETTRE MAJUSCULE LATINE E ACCENT CIRCONFLEXE ET POINT SOUSCRIT","	: 1EB8 0302"},
/* 1EC7 */ { "LETTRE MINUSCULE LATINE E ACCENT CIRCONFLEXE ET POINT SOUSCRIT","	: 1EB9 0302"},
/* 1EC8 */ { "LETTRE MAJUSCULE LATINE I CROCHET EN CHEF","	: 0049 0309"},
/* 1EC9 */ { "LETTRE MINUSCULE LATINE I CROCHET EN CHEF","	: 0069 0309"},
/* 1ECA */ { "LETTRE MAJUSCULE LATINE I POINT SOUSCRIT","	: 0049 0323"},
/* 1ECB */ { "LETTRE MINUSCULE LATINE I POINT SOUSCRIT","	: 0069 0323"},
/* 1ECC */ { "LETTRE MAJUSCULE LATINE O POINT SOUSCRIT","	: 004F 0323"},
/* 1ECD */ { "LETTRE MINUSCULE LATINE O POINT SOUSCRIT","	: 006F 0323"},
/* 1ECE */ { "LETTRE MAJUSCULE LATINE O CROCHET EN CHEF","	: 004F 0309"},
/* 1ECF */ { "LETTRE MINUSCULE LATINE O CROCHET EN CHEF","	: 006F 0309"},
/* 1ED0 */ { "LETTRE MAJUSCULE LATINE O ACCENT CIRCONFLEXE ET ACCENT AIGU","	: 00D4 0301"},
/* 1ED1 */ { "LETTRE MINUSCULE LATINE O ACCENT CIRCONFLEXE ET ACCENT AIGU","	: 00F4 0301"},
/* 1ED2 */ { "LETTRE MAJUSCULE LATINE O ACCENT CIRCONFLEXE ET ACCENT GRAVE","	: 00D4 0300"},
/* 1ED3 */ { "LETTRE MINUSCULE LATINE O ACCENT CIRCONFLEXE ET ACCENT GRAVE","	: 00F4 0300"},
/* 1ED4 */ { "LETTRE MAJUSCULE LATINE O ACCENT CIRCONFLEXE ET CROCHET EN CHEF","	: 00D4 0309"},
/* 1ED5 */ { "LETTRE MINUSCULE LATINE O ACCENT CIRCONFLEXE ET CROCHET EN CHEF","	: 00F4 0309"},
/* 1ED6 */ { "LETTRE MAJUSCULE LATINE O ACCENT CIRCONFLEXE ET TILDE","	: 00D4 0303"},
/* 1ED7 */ { "LETTRE MINUSCULE LATINE O ACCENT CIRCONFLEXE ET TILDE","	: 00F4 0303"},
/* 1ED8 */ { "LETTRE MAJUSCULE LATINE O ACCENT CIRCONFLEXE ET POINT SOUSCRIT","	: 1ECC 0302"},
/* 1ED9 */ { "LETTRE MINUSCULE LATINE O ACCENT CIRCONFLEXE ET POINT SOUSCRIT","	: 1ECD 0302"},
/* 1EDA */ { "LETTRE MAJUSCULE LATINE O CORNU ACCENT AIGU","	: 01A0 0301"},
/* 1EDB */ { "LETTRE MINUSCULE LATINE O CORNU ACCENT AIGU","	: 01A1 0301"},
/* 1EDC */ { "LETTRE MAJUSCULE LATINE O CORNU ACCENT GRAVE","	: 01A0 0300"},
/* 1EDD */ { "LETTRE MINUSCULE LATINE O CORNU ACCENT GRAVE","	: 01A1 0300"},
/* 1EDE */ { "LETTRE MAJUSCULE LATINE O CORNU CROCHET EN CHEF","	: 01A0 0309"},
/* 1EDF */ { "LETTRE MINUSCULE LATINE O CORNU CROCHET EN CHEF","	: 01A1 0309"},
/* 1EE0 */ { "LETTRE MAJUSCULE LATINE O CORNU TILDE","	: 01A0 0303"},
/* 1EE1 */ { "LETTRE MINUSCULE LATINE O CORNU TILDE","	: 01A1 0303"},
/* 1EE2 */ { "LETTRE MAJUSCULE LATINE O CORNU POINT SOUSCRIT","	: 01A0 0323"},
/* 1EE3 */ { "LETTRE MINUSCULE LATINE O CORNU POINT SOUSCRIT","	: 01A1 0323"},
/* 1EE4 */ { "LETTRE MAJUSCULE LATINE U POINT SOUSCRIT","	: 0055 0323"},
/* 1EE5 */ { "LETTRE MINUSCULE LATINE U POINT SOUSCRIT","	: 0075 0323"},
/* 1EE6 */ { "LETTRE MAJUSCULE LATINE U CROCHET EN CHEF","	: 0055 0309"},
/* 1EE7 */ { "LETTRE MINUSCULE LATINE U CROCHET EN CHEF","	: 0075 0309"},
/* 1EE8 */ { "LETTRE MAJUSCULE LATINE U CORNU ACCENT AIGU","	: 01AF 0301"},
/* 1EE9 */ { "LETTRE MINUSCULE LATINE U CORNU ACCENT AIGU","	: 01B0 0301"},
/* 1EEA */ { "LETTRE MAJUSCULE LATINE U CORNU ACCENT GRAVE","	: 01AF 0300"},
/* 1EEB */ { "LETTRE MINUSCULE LATINE U CORNU ACCENT GRAVE","	: 01B0 0300"},
/* 1EEC */ { "LETTRE MAJUSCULE LATINE U CORNU CROCHET EN CHEF","	: 01AF 0309"},
/* 1EED */ { "LETTRE MINUSCULE LATINE U CORNU CROCHET EN CHEF","	: 01B0 0309"},
/* 1EEE */ { "LETTRE MAJUSCULE LATINE U CORNU TILDE","	: 01AF 0303"},
/* 1EEF */ { "LETTRE MINUSCULE LATINE U CORNU TILDE","	: 01B0 0303"},
/* 1EF0 */ { "LETTRE MAJUSCULE LATINE U CORNU POINT SOUSCRIT","	: 01AF 0323"},
/* 1EF1 */ { "LETTRE MINUSCULE LATINE U CORNU POINT SOUSCRIT","	: 01B0 0323"},
/* 1EF2 */ { "LETTRE MAJUSCULE LATINE Y ACCENT GRAVE","	: 0059 0300"},
/* 1EF3 */ { "LETTRE MINUSCULE LATINE Y ACCENT GRAVE","	* gallois\n"
	"	: 0079 0300"},
/* 1EF4 */ { "LETTRE MAJUSCULE LATINE Y POINT SOUSCRIT","	: 0059 0323"},
/* 1EF5 */ { "LETTRE MINUSCULE LATINE Y POINT SOUSCRIT","	: 0079 0323"},
/* 1EF6 */ { "LETTRE MAJUSCULE LATINE Y CROCHET EN CHEF","	: 0059 0309"},
/* 1EF7 */ { "LETTRE MINUSCULE LATINE Y CROCHET EN CHEF","	: 0079 0309"},
/* 1EF8 */ { "LETTRE MAJUSCULE LATINE Y TILDE","	: 0059 0303"},
/* 1EF9 */ { "LETTRE MINUSCULE LATINE Y TILDE","	: 0079 0303"},
/* 1EFA */ { "LETTRE MAJUSCULE LATINE LL MOYEN GALLOIS",NULL},
/* 1EFB */ { "LETTRE MINUSCULE LATINE LL MOYEN GALLOIS",NULL},
/* 1EFC */ { "LETTRE MAJUSCULE LATINE V MOYEN GALLOIS",NULL},
/* 1EFD */ { "LETTRE MINUSCULE LATINE V MOYEN GALLOIS",NULL},
/* 1EFE */ { "LETTRE MAJUSCULE LATINE Y BOUCLÉ",NULL},
/* 1EFF */ { "LETTRE MINUSCULE LATINE Y BOUCLÉ",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_1F[] = {
/* 1F00 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX","	: 03B1 0313"},
/* 1F01 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE","	: 03B1 0314"},
/* 1F02 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX ET ACCENT GRAVE","	: 1F00 0300"},
/* 1F03 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE ET ACCENT GRAVE","	: 1F01 0300"},
/* 1F04 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX ET ACCENT AIGU","	: 1F00 0301"},
/* 1F05 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE ET ACCENT AIGU","	: 1F01 0301"},
/* 1F06 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX ET CIRCONFLEXE","	: 1F00 0342"},
/* 1F07 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE ET CIRCONFLEXE","	: 1F01 0342"},
/* 1F08 */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX","	: 0391 0313"},
/* 1F09 */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE","	: 0391 0314"},
/* 1F0A */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX ET ACCENT GRAVE","	: 1F08 0300"},
/* 1F0B */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE ET ACCENT GRAVE","	: 1F09 0300"},
/* 1F0C */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX ET ACCENT AIGU","	: 1F08 0301"},
/* 1F0D */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE ET ACCENT AIGU","	: 1F09 0301"},
/* 1F0E */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX ET CIRCONFLEXE","	: 1F08 0342"},
/* 1F0F */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE ET CIRCONFLEXE","	: 1F09 0342"},
/* 1F10 */ { "LETTRE MINUSCULE GRECQUE EPSILON ESPRIT DOUX","	: 03B5 0313"},
/* 1F11 */ { "LETTRE MINUSCULE GRECQUE EPSILON ESPRIT RUDE","	: 03B5 0314"},
/* 1F12 */ { "LETTRE MINUSCULE GRECQUE EPSILON ESPRIT DOUX ET ACCENT GRAVE","	: 1F10 0300"},
/* 1F13 */ { "LETTRE MINUSCULE GRECQUE EPSILON ESPRIT RUDE ET ACCENT GRAVE","	: 1F11 0300"},
/* 1F14 */ { "LETTRE MINUSCULE GRECQUE EPSILON ESPRIT DOUX ET ACCENT AIGU","	: 1F10 0301"},
/* 1F15 */ { "LETTRE MINUSCULE GRECQUE EPSILON ESPRIT RUDE ET ACCENT AIGU","	: 1F11 0301"},
/* 1F16 */ { NULL,NULL},
/* 1F17 */ { NULL,NULL},
/* 1F18 */ { "LETTRE MAJUSCULE GRECQUE EPSILON ESPRIT DOUX","	: 0395 0313"},
/* 1F19 */ { "LETTRE MAJUSCULE GRECQUE EPSILON ESPRIT RUDE","	: 0395 0314"},
/* 1F1A */ { "LETTRE MAJUSCULE GRECQUE EPSILON ESPRIT DOUX ET ACCENT GRAVE","	: 1F18 0300"},
/* 1F1B */ { "LETTRE MAJUSCULE GRECQUE EPSILON ESPRIT RUDE ET ACCENT GRAVE","	: 1F19 0300"},
/* 1F1C */ { "LETTRE MAJUSCULE GRECQUE EPSILON ESPRIT DOUX ET ACCENT AIGU","	: 1F18 0301"},
/* 1F1D */ { "LETTRE MAJUSCULE GRECQUE EPSILON ESPRIT RUDE ET ACCENT AIGU","	: 1F19 0301"},
/* 1F1E */ { NULL,NULL},
/* 1F1F */ { NULL,NULL},
/* 1F20 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX","	: 03B7 0313"},
/* 1F21 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE","	: 03B7 0314"},
/* 1F22 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX ET ACCENT GRAVE","	: 1F20 0300"},
/* 1F23 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE ET ACCENT GRAVE","	: 1F21 0300"},
/* 1F24 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX ET ACCENT AIGU","	: 1F20 0301"},
/* 1F25 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE ET ACCENT AIGU","	: 1F21 0301"},
/* 1F26 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX ET CIRCONFLEXE","	: 1F20 0342"},
/* 1F27 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE ET CIRCONFLEXE","	: 1F21 0342"},
/* 1F28 */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX","	: 0397 0313"},
/* 1F29 */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE","	: 0397 0314"},
/* 1F2A */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX ET ACCENT GRAVE","	: 1F28 0300"},
/* 1F2B */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE ET ACCENT GRAVE","	: 1F29 0300"},
/* 1F2C */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX ET ACCENT AIGU","	: 1F28 0301"},
/* 1F2D */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE ET ACCENT AIGU","	: 1F29 0301"},
/* 1F2E */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX ET CIRCONFLEXE","	: 1F28 0342"},
/* 1F2F */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE ET CIRCONFLEXE","	: 1F29 0342"},
/* 1F30 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT DOUX","	: 03B9 0313"},
/* 1F31 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT RUDE","	: 03B9 0314"},
/* 1F32 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT DOUX ET ACCENT GRAVE","	: 1F30 0300"},
/* 1F33 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT RUDE ET ACCENT GRAVE","	: 1F31 0300"},
/* 1F34 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT DOUX ET ACCENT AIGU","	: 1F30 0301"},
/* 1F35 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT RUDE ET ACCENT AIGU","	: 1F31 0301"},
/* 1F36 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT DOUX ET CIRCONFLEXE","	: 1F30 0342"},
/* 1F37 */ { "LETTRE MINUSCULE GRECQUE IOTA ESPRIT RUDE ET CIRCONFLEXE","	: 1F31 0342"},
/* 1F38 */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT DOUX","	: 0399 0313"},
/* 1F39 */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT RUDE","	: 0399 0314"},
/* 1F3A */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT DOUX ET ACCENT GRAVE","	: 1F38 0300"},
/* 1F3B */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT RUDE ET ACCENT GRAVE","	: 1F39 0300"},
/* 1F3C */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT DOUX ET ACCENT AIGU","	: 1F38 0301"},
/* 1F3D */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT RUDE ET ACCENT AIGU","	: 1F39 0301"},
/* 1F3E */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT DOUX ET CIRCONFLEXE","	: 1F38 0342"},
/* 1F3F */ { "LETTRE MAJUSCULE GRECQUE IOTA ESPRIT RUDE ET CIRCONFLEXE","	: 1F39 0342"},
/* 1F40 */ { "LETTRE MINUSCULE GRECQUE OMICRON ESPRIT DOUX","	: 03BF 0313"},
/* 1F41 */ { "LETTRE MINUSCULE GRECQUE OMICRON ESPRIT RUDE","	: 03BF 0314"},
/* 1F42 */ { "LETTRE MINUSCULE GRECQUE OMICRON ESPRIT DOUX ET ACCENT GRAVE","	: 1F40 0300"},
/* 1F43 */ { "LETTRE MINUSCULE GRECQUE OMICRON ESPRIT RUDE ET ACCENT GRAVE","	: 1F41 0300"},
/* 1F44 */ { "LETTRE MINUSCULE GRECQUE OMICRON ESPRIT DOUX ET ACCENT AIGU","	: 1F40 0301"},
/* 1F45 */ { "LETTRE MINUSCULE GRECQUE OMICRON ESPRIT RUDE ET ACCENT AIGU","	: 1F41 0301"},
/* 1F46 */ { NULL,NULL},
/* 1F47 */ { NULL,NULL},
/* 1F48 */ { "LETTRE MAJUSCULE GRECQUE OMICRON ESPRIT DOUX","	: 039F 0313"},
/* 1F49 */ { "LETTRE MAJUSCULE GRECQUE OMICRON ESPRIT RUDE","	: 039F 0314"},
/* 1F4A */ { "LETTRE MAJUSCULE GRECQUE OMICRON ESPRIT DOUX ET ACCENT GRAVE","	: 1F48 0300"},
/* 1F4B */ { "LETTRE MAJUSCULE GRECQUE OMICRON ESPRIT RUDE ET ACCENT GRAVE","	: 1F49 0300"},
/* 1F4C */ { "LETTRE MAJUSCULE GRECQUE OMICRON ESPRIT DOUX ET ACCENT AIGU","	: 1F48 0301"},
/* 1F4D */ { "LETTRE MAJUSCULE GRECQUE OMICRON ESPRIT RUDE ET ACCENT AIGU","	: 1F49 0301"},
/* 1F4E */ { NULL,NULL},
/* 1F4F */ { NULL,NULL},
/* 1F50 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT DOUX","	: 03C5 0313"},
/* 1F51 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT RUDE","	: 03C5 0314"},
/* 1F52 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT DOUX ET ACCENT GRAVE","	: 1F50 0300"},
/* 1F53 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT RUDE ET ACCENT GRAVE","	: 1F51 0300"},
/* 1F54 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT DOUX ET ACCENT AIGU","	: 1F50 0301"},
/* 1F55 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT RUDE ET ACCENT AIGU","	: 1F51 0301"},
/* 1F56 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT DOUX ET CIRCONFLEXE","	: 1F50 0342"},
/* 1F57 */ { "LETTRE MINUSCULE GRECQUE UPSILON ESPRIT RUDE ET CIRCONFLEXE","	: 1F51 0342"},
/* 1F58 */ { NULL,NULL},
/* 1F59 */ { "LETTRE MAJUSCULE GRECQUE UPSILON ESPRIT RUDE","	: 03A5 0314"},
/* 1F5A */ { NULL,NULL},
/* 1F5B */ { "LETTRE MAJUSCULE GRECQUE UPSILON ESPRIT RUDE ET ACCENT GRAVE","	: 1F59 0300"},
/* 1F5C */ { NULL,NULL},
/* 1F5D */ { "LETTRE MAJUSCULE GRECQUE UPSILON ESPRIT RUDE ET ACCENT AIGU","	: 1F59 0301"},
/* 1F5E */ { NULL,NULL},
/* 1F5F */ { "LETTRE MAJUSCULE GRECQUE UPSILON ESPRIT RUDE ET CIRCONFLEXE","	: 1F59 0342"},
/* 1F60 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX","	: 03C9 0313"},
/* 1F61 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE","	: 03C9 0314"},
/* 1F62 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX ET ACCENT GRAVE","	: 1F60 0300"},
/* 1F63 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE ET ACCENT GRAVE","	: 1F61 0300"},
/* 1F64 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX ET ACCENT AIGU","	: 1F60 0301"},
/* 1F65 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE ET ACCENT AIGU","	: 1F61 0301"},
/* 1F66 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX ET CIRCONFLEXE","	: 1F60 0342"},
/* 1F67 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE ET CIRCONFLEXE","	: 1F61 0342"},
/* 1F68 */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX","	: 03A9 0313"},
/* 1F69 */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE","	: 03A9 0314"},
/* 1F6A */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX ET ACCENT GRAVE","	: 1F68 0300"},
/* 1F6B */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE ET ACCENT GRAVE","	: 1F69 0300"},
/* 1F6C */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX ET ACCENT AIGU","	: 1F68 0301"},
/* 1F6D */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE ET ACCENT AIGU","	: 1F69 0301"},
/* 1F6E */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX ET CIRCONFLEXE","	: 1F68 0342"},
/* 1F6F */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE ET CIRCONFLEXE","	: 1F69 0342"},
/* 1F70 */ { "LETTRE MINUSCULE GRECQUE ALPHA ACCENT GRAVE","	: 03B1 0300"},
/* 1F71 */ { "LETTRE MINUSCULE GRECQUE ALPHA ACCENT AIGU","	: 03AC lettre minuscule grecque alpha accent"},
/* 1F72 */ { "LETTRE MINUSCULE GRECQUE EPSILON ACCENT GRAVE","	: 03B5 0300"},
/* 1F73 */ { "LETTRE MINUSCULE GRECQUE EPSILON ACCENT AIGU","	: 03AD lettre minuscule grecque epsilon accent"},
/* 1F74 */ { "LETTRE MINUSCULE GRECQUE ÊTA ACCENT GRAVE","	: 03B7 0300"},
/* 1F75 */ { "LETTRE MINUSCULE GRECQUE ÊTA ACCENT AIGU","	: 03AE lettre minuscule grecque êta accent"},
/* 1F76 */ { "LETTRE MINUSCULE GRECQUE IOTA ACCENT GRAVE","	: 03B9 0300"},
/* 1F77 */ { "LETTRE MINUSCULE GRECQUE IOTA ACCENT AIGU","	: 03AF lettre minuscule grecque iota accent"},
/* 1F78 */ { "LETTRE MINUSCULE GRECQUE OMICRON ACCENT GRAVE","	: 03BF 0300"},
/* 1F79 */ { "LETTRE MINUSCULE GRECQUE OMICRON ACCENT AIGU","	: 03CC lettre minuscule grecque omicron accent"},
/* 1F7A */ { "LETTRE MINUSCULE GRECQUE UPSILON ACCENT GRAVE","	: 03C5 0300"},
/* 1F7B */ { "LETTRE MINUSCULE GRECQUE UPSILON ACCENT AIGU","	: 03CD lettre minuscule grecque upsilon accent"},
/* 1F7C */ { "LETTRE MINUSCULE GRECQUE OMÉGA ACCENT GRAVE","	: 03C9 0300"},
/* 1F7D */ { "LETTRE MINUSCULE GRECQUE OMÉGA ACCENT AIGU","	: 03CE lettre minuscule grecque oméga accent"},
/* 1F7E */ { NULL,NULL},
/* 1F7F */ { NULL,NULL},
/* 1F80 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX IOTA SOUSCRIT","	: 1F00 0345"},
/* 1F81 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE IOTA SOUSCRIT","	: 1F01 0345"},
/* 1F82 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F02 0345"},
/* 1F83 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F03 0345"},
/* 1F84 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX ACCENT AIGU ET IOTA SOUSCRIT","	: 1F04 0345"},
/* 1F85 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE ACCENT AIGU ET IOTA SOUSCRIT","	: 1F05 0345"},
/* 1F86 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT DOUX CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F06 0345"},
/* 1F87 */ { "LETTRE MINUSCULE GRECQUE ALPHA ESPRIT RUDE CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F07 0345"},
/* 1F88 */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX IOTA SOUSCRIT","	: 1F08 0345"},
/* 1F89 */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE IOTA SOUSCRIT","	: 1F09 0345"},
/* 1F8A */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F0A 0345"},
/* 1F8B */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F0B 0345"},
/* 1F8C */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX ACCENT AIGU ET IOTA SOUSCRIT","	: 1F0C 0345"},
/* 1F8D */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE ACCENT AIGU ET IOTA SOUSCRIT","	: 1F0D 0345"},
/* 1F8E */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT DOUX CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F0E 0345"},
/* 1F8F */ { "LETTRE MAJUSCULE GRECQUE ALPHA ESPRIT RUDE CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F0F 0345"},
/* 1F90 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX IOTA SOUSCRIT","	: 1F20 0345"},
/* 1F91 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE IOTA SOUSCRIT","	: 1F21 0345"},
/* 1F92 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F22 0345"},
/* 1F93 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F23 0345"},
/* 1F94 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX ACCENT AIGU ET IOTA SOUSCRIT","	: 1F24 0345"},
/* 1F95 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE ACCENT AIGU ET IOTA SOUSCRIT","	: 1F25 0345"},
/* 1F96 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT DOUX CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F26 0345"},
/* 1F97 */ { "LETTRE MINUSCULE GRECQUE ÊTA ESPRIT RUDE CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F27 0345"},
/* 1F98 */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX IOTA SOUSCRIT","	: 1F28 0345"},
/* 1F99 */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE IOTA SOUSCRIT","	: 1F29 0345"},
/* 1F9A */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F2A 0345"},
/* 1F9B */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F2B 0345"},
/* 1F9C */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX ACCENT AIGU ET IOTA SOUSCRIT","	: 1F2C 0345"},
/* 1F9D */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE ACCENT AIGU ET IOTA SOUSCRIT","	: 1F2D 0345"},
/* 1F9E */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT DOUX CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F2E 0345"},
/* 1F9F */ { "LETTRE MAJUSCULE GRECQUE ÊTA ESPRIT RUDE CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F2F 0345"},
/* 1FA0 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX IOTA SOUSCRIT","	: 1F60 0345"},
/* 1FA1 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE IOTA SOUSCRIT","	: 1F61 0345"},
/* 1FA2 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F62 0345"},
/* 1FA3 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F63 0345"},
/* 1FA4 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX ACCENT AIGU ET IOTA SOUSCRIT","	: 1F64 0345"},
/* 1FA5 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE ACCENT AIGU ET IOTA SOUSCRIT","	: 1F65 0345"},
/* 1FA6 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT DOUX CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F66 0345"},
/* 1FA7 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ESPRIT RUDE CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F67 0345"},
/* 1FA8 */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX IOTA SOUSCRIT","	: 1F68 0345"},
/* 1FA9 */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE IOTA SOUSCRIT","	: 1F69 0345"},
/* 1FAA */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F6A 0345"},
/* 1FAB */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE ACCENT GRAVE ET IOTA SOUSCRIT","	: 1F6B 0345"},
/* 1FAC */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX ACCENT AIGU ET IOTA SOUSCRIT","	: 1F6C 0345"},
/* 1FAD */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE ACCENT AIGU ET IOTA SOUSCRIT","	: 1F6D 0345"},
/* 1FAE */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT DOUX CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F6E 0345"},
/* 1FAF */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ESPRIT RUDE CIRCONFLEXE ET IOTA SOUSCRIT","	: 1F6F 0345"},
/* 1FB0 */ { "LETTRE MINUSCULE GRECQUE ALPHA BRÈVE","	: 03B1 0306"},
/* 1FB1 */ { "LETTRE MINUSCULE GRECQUE ALPHA MACRON","	: 03B1 0304"},
/* 1FB2 */ { "LETTRE MINUSCULE GRECQUE ALPHA ACCENT GRAVE IOTA SOUSCRIT","	: 1F70 0345"},
/* 1FB3 */ { "LETTRE MINUSCULE GRECQUE ALPHA IOTA SOUSCRIT","	: 03B1 0345"},
/* 1FB4 */ { "LETTRE MINUSCULE GRECQUE ALPHA ACCENT AIGU IOTA SOUSCRIT","	: 03AC 0345"},
/* 1FB5 */ { NULL,NULL},
/* 1FB6 */ { "LETTRE MINUSCULE GRECQUE ALPHA CIRCONFLEXE","	: 03B1 0342"},
/* 1FB7 */ { "LETTRE MINUSCULE GRECQUE ALPHA CIRCONFLEXE IOTA SOUSCRIT","	: 1FB6 0345"},
/* 1FB8 */ { "LETTRE MAJUSCULE GRECQUE ALPHA BRÈVE","	: 0391 0306"},
/* 1FB9 */ { "LETTRE MAJUSCULE GRECQUE ALPHA MACRON","	: 0391 0304"},
/* 1FBA */ { "LETTRE MAJUSCULE GRECQUE ALPHA ACCENT GRAVE","	: 0391 0300"},
/* 1FBB */ { "LETTRE MAJUSCULE GRECQUE ALPHA ACCENT AIGU","	: 0386 lettre majuscule grecque alpha accent"},
/* 1FBC */ { "LETTRE MAJUSCULE GRECQUE ALPHA IOTA SOUSCRIT","	: 0391 0345"},
/* 1FBD */ { "CORONIS GRECQUE","	# 0020 0313"},
/* 1FBE */ { "IOTA GREC SOUSCRIT","	: 03B9 lettre minuscule grecque iota"},
/* 1FBF */ { "ESPRIT DOUX GREC","	x (lettre modificative apostrophe - 02BC)\n"
	"	# 0020 0313"},
/* 1FC0 */ { "ACCENT CIRCONFLEXE GREC","	# 0020 0342"},
/* 1FC1 */ { "TRÉMA ET ACCENT CIRCONFLEXE GRECS","	: 00A8 0342"},
/* 1FC2 */ { "LETTRE MINUSCULE GRECQUE ÊTA ACCENT GRAVE IOTA SOUSCRIT","	: 1F74 0345"},
/* 1FC3 */ { "LETTRE MINUSCULE GRECQUE ÊTA IOTA SOUSCRIT","	: 03B7 0345"},
/* 1FC4 */ { "LETTRE MINUSCULE GRECQUE ÊTA ACCENT AIGU IOTA SOUSCRIT","	: 03AE 0345"},
/* 1FC5 */ { NULL,NULL},
/* 1FC6 */ { "LETTRE MINUSCULE GRECQUE ÊTA CIRCONFLEXE","	: 03B7 0342"},
/* 1FC7 */ { "LETTRE MINUSCULE GRECQUE ÊTA CIRCONFLEXE IOTA SOUSCRIT","	: 1FC6 0345"},
/* 1FC8 */ { "LETTRE MAJUSCULE GRECQUE EPSILON ACCENT GRAVE","	: 0395 0300"},
/* 1FC9 */ { "LETTRE MAJUSCULE GRECQUE EPSILON ACCENT AIGU","	: 0388 lettre majuscule grecque epsilon accent"},
/* 1FCA */ { "LETTRE MAJUSCULE GRECQUE ÊTA ACCENT GRAVE","	: 0397 0300"},
/* 1FCB */ { "LETTRE MAJUSCULE GRECQUE ÊTA ACCENT AIGU","	: 0389 lettre majuscule grecque êta accent"},
/* 1FCC */ { "LETTRE MAJUSCULE GRECQUE ÊTA IOTA SOUSCRIT","	: 0397 0345"},
/* 1FCD */ { "ESPRIT DOUX ET ACCENT GRAVE GRECS","	: 1FBF 0300"},
/* 1FCE */ { "ESPRIT DOUX ET ACCENT AIGU GRECS","	: 1FBF 0301"},
/* 1FCF */ { "ESPRIT DOUX ET ACCENT CIRCONFLEXE GRECS","	: 1FBF 0342"},
/* 1FD0 */ { "LETTRE MINUSCULE GRECQUE IOTA BRÈVE","	: 03B9 0306"},
/* 1FD1 */ { "LETTRE MINUSCULE GRECQUE IOTA MACRON","	: 03B9 0304"},
/* 1FD2 */ { "LETTRE MINUSCULE GRECQUE IOTA TRÉMA ET ACCENT GRAVE","	: 03CA 0300"},
/* 1FD3 */ { "LETTRE MINUSCULE GRECQUE IOTA TRÉMA ET ACCENT AIGU","	: 0390 lettre minuscule grecque iota tréma et accent"},
/* 1FD4 */ { NULL,NULL},
/* 1FD5 */ { NULL,NULL},
/* 1FD6 */ { "LETTRE MINUSCULE GRECQUE IOTA CIRCONFLEXE","	: 03B9 0342"},
/* 1FD7 */ { "LETTRE MINUSCULE GRECQUE IOTA TRÉMA ET CIRCONFLEXE","	: 03CA 0342"},
/* 1FD8 */ { "LETTRE MAJUSCULE GRECQUE IOTA BRÈVE","	: 0399 0306"},
/* 1FD9 */ { "LETTRE MAJUSCULE GRECQUE IOTA MACRON","	: 0399 0304"},
/* 1FDA */ { "LETTRE MAJUSCULE GRECQUE IOTA ACCENT GRAVE","	: 0399 0300"},
/* 1FDB */ { "LETTRE MAJUSCULE GRECQUE IOTA ACCENT AIGU","	: 038A lettre majuscule grecque iota accent"},
/* 1FDC */ { NULL,NULL},
/* 1FDD */ { "ESPRIT RUDE ET ACCENT GRAVE GRECS","	: 1FFE 0300"},
/* 1FDE */ { "ESPRIT RUDE ET ACCENT AIGU GRECS","	: 1FFE 0301"},
/* 1FDF */ { "ESPRIT RUDE ET ACCENT CIRCONFLEXE GRECS","	: 1FFE 0342"},
/* 1FE0 */ { "LETTRE MINUSCULE GRECQUE UPSILON BRÈVE","	: 03C5 0306"},
/* 1FE1 */ { "LETTRE MINUSCULE GRECQUE UPSILON MACRON","	: 03C5 0304"},
/* 1FE2 */ { "LETTRE MINUSCULE GRECQUE UPSILON TRÉMA ET ACCENT GRAVE","	: 03CB 0300"},
/* 1FE3 */ { "LETTRE MINUSCULE GRECQUE UPSILON TRÉMA ET ACCENT AIGU","	: 03B0 lettre minuscule grecque upsilon tréma et accent"},
/* 1FE4 */ { "LETTRE MINUSCULE GRECQUE RHÔ ESPRIT DOUX","	: 03C1 0313"},
/* 1FE5 */ { "LETTRE MINUSCULE GRECQUE RHÔ ESPRIT RUDE","	: 03C1 0314"},
/* 1FE6 */ { "LETTRE MINUSCULE GRECQUE UPSILON CIRCONFLEXE","	: 03C5 0342"},
/* 1FE7 */ { "LETTRE MINUSCULE GRECQUE UPSILON TRÉMA ET CIRCONFLEXE","	: 03CB 0342"},
/* 1FE8 */ { "LETTRE MAJUSCULE GRECQUE UPSILON BRÈVE","	: 03A5 0306"},
/* 1FE9 */ { "LETTRE MAJUSCULE GRECQUE UPSILON MACRON","	: 03A5 0304"},
/* 1FEA */ { "LETTRE MAJUSCULE GRECQUE UPSILON ACCENT GRAVE","	: 03A5 0300"},
/* 1FEB */ { "LETTRE MAJUSCULE GRECQUE UPSILON ACCENT AIGU","	: 038E lettre majuscule grecque upsilon accent"},
/* 1FEC */ { "LETTRE MAJUSCULE GRECQUE RHÔ ESPRIT RUDE","	: 03A1 0314"},
/* 1FED */ { "TRÉMA ET ACCENT GRAVE GRECS","	: 00A8 0300"},
/* 1FEE */ { "TRÉMA ET ACCENT AIGU GRECS","	: 0385 tréma accent grec"},
/* 1FEF */ { "ACCENT GRAVE GREC","	: 0060 accent grave"},
/* 1FF0 */ { NULL,NULL},
/* 1FF1 */ { NULL,NULL},
/* 1FF2 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ACCENT GRAVE IOTA SOUSCRIT","	: 1F7C 0345"},
/* 1FF3 */ { "LETTRE MINUSCULE GRECQUE OMÉGA IOTA SOUSCRIT","	: 03C9 0345"},
/* 1FF4 */ { "LETTRE MINUSCULE GRECQUE OMÉGA ACCENT AIGU IOTA SOUSCRIT","	: 03CE 0345"},
/* 1FF5 */ { NULL,NULL},
/* 1FF6 */ { "LETTRE MINUSCULE GRECQUE OMÉGA CIRCONFLEXE","	: 03C9 0342"},
/* 1FF7 */ { "LETTRE MINUSCULE GRECQUE OMÉGA CIRCONFLEXE IOTA SOUSCRIT","	: 1FF6 0345"},
/* 1FF8 */ { "LETTRE MAJUSCULE GRECQUE OMICRON ACCENT GRAVE","	: 039F 0300"},
/* 1FF9 */ { "LETTRE MAJUSCULE GRECQUE OMICRON ACCENT AIGU","	: 038C lettre majuscule grecque omicron accent"},
/* 1FFA */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ACCENT GRAVE","	: 03A9 0300"},
/* 1FFB */ { "LETTRE MAJUSCULE GRECQUE OMÉGA ACCENT AIGU","	: 038F lettre majuscule grecque oméga accent"},
/* 1FFC */ { "LETTRE MAJUSCULE GRECQUE OMÉGA IOTA SOUSCRIT","	: 03A9 0345"},
/* 1FFD */ { "ACCENT AIGU GREC","	: 00B4 accent aigu"},
/* 1FFE */ { "ESPRIT RUDE GREC","	x (lettre modificative virgule réfléchie - 02BD)\n"
	"	# 0020 0314"},
/* 1FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_20[] = {
/* 2000 */ { "DEMI-CADRATIN","	* ce caractère est en pratique équivalent à l'espace demi-cadratin\n"
	"	: 2002 espace demi-cadratin"},
/* 2001 */ { "CADRATIN","	* ce caractère est en pratique équivalent à l'espace cadratin\n"
	"	: 2003 espace cadratin"},
/* 2002 */ { "ESPACE DEMI-CADRATIN","	# 0020 espace"},
/* 2003 */ { "ESPACE CADRATIN","	* espace dont la largeur correspond à la force de corps utilisée\n"
	"	* elle peut cependant varier en fonction du degré de modification de la chasse\n"
	"	# 0020 espace"},
/* 2004 */ { "ESPACE TIERS DE CADRATIN","	# 0020 espace"},
/* 2005 */ { "ESPACE QUART DE CADRATIN","	# 0020 espace"},
/* 2006 */ { "ESPACE SIXIÈME DE CADRATIN","	* en typographie informatique, espace parfois assimilée à l'espace fine\n"
	"	# 0020 espace"},
/* 2007 */ { "ESPACE TABULAIRE","	= espace-nombre\n"
	"	* espace de largeur égale à un chiffre dans une police à chasse fixe\n"
	"	# <insécable> 0020"},
/* 2008 */ { "ESPACE PONCTUATION","	* espace de largeur égale à la ponctuation étroite d'une police, généralement du point 002E\n"
	"	# 0020 espace"},
/* 2009 */ { "ESPACE FINE","	= espace étroite\n"
	"	* cette espace doit être bien plus étroite que l'espace 0020 ; elle est généralement définie comme 1/5 ou 1/6 de cadratin dans la typographie anglo-saxonne, et comme 1/4 de cadratin, en principe, dans la typographie française\n"
	"	x (espace insécable étroite - 202F)\n"
	"	# 0020 espace"},
/* 200A */ { "ESPACE ULTRAFINE","	* plus étroite qu'une espace fine ; généralement définie entre 1/10 et 1/16 de cadratin\n"
	"	* dans la typographie traditionnelle, la plus étroite des espaces disponibles\n"
	"	# 0020 espace"},
/* 200B */ { "ESPACE SANS CHASSE","	= espace à chasse nulle\n"
	"	* communément abrégée en ZWSP (zero width space)\n"
	"	* caractère destiné à maîtriser la coupure de ligne ; au sens strict, caractère à chasse nulle, bien qu'il puisse s'étirer lors de la justification"},
/* 200C */ { "ANTILIANT SANS CHASSE","	* communément abrégé en ZWNJ (zero width non-joiner)"},
/* 200D */ { "LIANT SANS CHASSE","	* communément abrégé en ZWJ (zero width joiner)"},
/* 200E */ { "MARQUE GAUCHE-À-DROITE","	* communément abrégée en LRM (left-to-right mark)"},
/* 200F */ { "MARQUE DROITE-À-GAUCHE","	* communément abrégée en RLM (right-to-left mark)\n"
	"	x (marque de lettre arabe - 061C)"},
/* 2010 */ { "TRAIT D'UNION","	= division\n"
	"	x (trait d'union-signe moins - 002D)\n"
	"	x (trait d'union conditionnel - 00AD)"},
/* 2011 */ { "TRAIT D'UNION INSÉCABLE","	# <insécable> 2010"},
/* 2012 */ { "TIRET NUMÉRIQUE",NULL},
/* 2013 */ { "TIRET DEMI-CADRATIN","	* dans la typographie anglo-saxonne, il peut être utilisé pour séparer les bornes d'un intervalle\n"
	"	* dans la typographie française, il est utilisé (en remplacement du tiret cadratin) pour encadrer les propositions incises dans la fonction de quasi-parenthèse ou pour introduire les répliques des dialogues"},
/* 2014 */ { "TIRET CADRATIN","	= tiret sur cadratin\n"
	"	* parfois appelé « tiret » ou « moins » par les typographes\n"
	"	* dans la typographie française, il est utilisé pour encadrer les propositions incises dans la fonction de quasi-parenthèse et pour introduire les répliques des dialogues\n"
	"	x (tiret double cadratin - 2E3A)\n"
	"	x (marque katakana-hiragana de son prolongé - 30FC)"},
/* 2015 */ { "BARRE HORIZONTALE","	* peut s'utiliser pour introduire les répliques des dialogues ; le tiret cadratin remplit la même fonction"},
/* 2016 */ { "DOUBLE LIGNE VERTICALE","	* s'utilise par paire pour indiquer une norme matricielle\n"
	"	x (diacritique double barre verticale couvrante - 20E6)\n"
	"	x (parallèle à - 2225)\n"
	"	x (double barre verticale - 23F8)"},
/* 2017 */ { "DOUBLE TIRET BAS","	* ce caractère chasse\n"
	"	x (tiret bas - 005F)\n"
	"	x (diacritique double trait souscrit - 0333)\n"
	"	# 0020 0333"},
/* 2018 */ { "GUILLEMET-APOSTROPHE CULBUTÉ","	* caractère recommandé (par opposition avec 201B)\n"
	"	x (apostrophe - 0027)\n"
	"	x (lettre modificative virgule culbutée - 02BB)\n"
	"	x (guillemet de fantaisie en forme de grosse virgule simple culbutée - 275B)\n"
	"	~ 2018 FE00 forme à largeur proportionnelle\n"
	"	~ 2018 FE01 forme à pleine chasse justifiée à droite\n"
	"	~ 2018 FE02 forme sîbé"},
/* 2019 */ { "GUILLEMET-APOSTROPHE","	= apostrophe typographique\n"
	"	* caractère recommandé pour indiquer l'apostrophe\n"
	"	* son tracé est plus ou moins incliné et généralement courbe\n"
	"	* en allemand, ce caractère est appelé « Hochkomma » (« virgule haute ») dans le langage courant\n"
	"	x (apostrophe - 0027)\n"
	"	x (lettre modificative apostrophe - 02BC)\n"
	"	x (guillemet de fantaisie en forme de grosse virgule simple - 275C)\n"
	"	~ 2019 FE00 forme à largeur proportionnelle\n"
	"	~ 2019 FE01 forme à pleine chasse justifiée à gauche\n"
	"	~ 2019 FE02 forme sîbé"},
/* 201A */ { "GUILLEMET-VIRGULE INFÉRIEUR","	* s'utilise comme guillemet simple ouvrant dans certaines langues"},
/* 201B */ { "GUILLEMET-VIRGULE SUPÉRIEUR CULBUTÉ","	* a la même signification que 2018, mais diffère dans sa forme\n"
	"	x (lettre modificative virgule réfléchie - 02BD)"},
/* 201C */ { "GUILLEMET-APOSTROPHE DOUBLE CULBUTÉ","	* caractère recommandé (par opposition avec 201F)\n"
	"	x (guillemet anglais - 0022)\n"
	"	x (guillemet de fantaisie en forme de grosse virgule double culbutée - 275D)\n"
	"	x (guillemet double prime réfléchi - 301D)\n"
	"	~ 201C FE00 forme à largeur proportionnelle\n"
	"	~ 201C FE01 forme à pleine chasse justifiée à droite\n"
	"	~ 201C FE02 forme sîbé"},
/* 201D */ { "GUILLEMET-APOSTROPHE DOUBLE","	x (guillemet anglais - 0022)\n"
	"	x (double prime - 2033)\n"
	"	x (guillemet de fantaisie en forme de grosse virgule double - 275E)\n"
	"	x (guillemet double prime - 301E)\n"
	"	~ 201D FE00 forme à largeur proportionnelle\n"
	"	~ 201D FE01 forme à pleine chasse justifiée à gauche\n"
	"	~ 201D FE02 forme sîbé"},
/* 201E */ { "GUILLEMET-VIRGULE DOUBLE INFÉRIEUR","	* s'utilise comme guillemet double ouvrant dans certaines langues\n"
	"	x (guillemet-virgule double inférieur réfléchi - 2E42)\n"
	"	x (guillemet double prime inférieur - 301F)"},
/* 201F */ { "GUILLEMET-VIRGULE DOUBLE SUPÉRIEUR CULBUTÉ","	* a la même signification que 201C, mais diffère dans sa forme"},
/* 2020 */ { "OBÈLE","	* en typographie, signe permettant de signifier un appel de note\n"
	"	x (obèle culbuté - 2E38)"},
/* 2021 */ { "DOUBLE OBÈLE","	* en typographie, signe permettant de signifier un appel de note\n"
	"	x (triple obèle - 2E4B)"},
/* 2022 */ { "PUCE","	= petit cercle noir\n"
	"	x (point médian - 00B7)\n"
	"	x (point de conduite simple - 2024)\n"
	"	x (opérateur puce - 2219)\n"
	"	x (puce noir au blanc - 25D8)\n"
	"	x (puce blanche - 25E6)"},
/* 2023 */ { "PUCE TRIANGULAIRE","	x (ce qu'il fallait démontrer - 220E)\n"
	"	x (petit triangle noir pointant vers la droite - 25B8)"},
/* 2024 */ { "POINT DE CONDUITE SIMPLE","	* sert également de point-virgule arménien (midjaket)\n"
	"	x (point médian - 00B7)\n"
	"	x (puce - 2022)\n"
	"	x (opérateur puce - 2219)\n"
	"	# 002E point"},
/* 2025 */ { "POINT DE CONDUITE DOUBLE","	# 002E 002E"},
/* 2026 */ { "POINTS DE SUSPENSION","	x (trois points suspendus - 22EE)\n"
	"	x (forme de présentation de points de suspension verticaux - FE19)\n"
	"	# 002E 002E 002E"},
/* 2027 */ { "POINT DE COUPURE DE MOT","	* symbole visible utilisé pour indiquer les positions correctes pour la division d'un mot, comme dans dic·tion·nai·res"},
/* 2028 */ { "SÉPARATEUR DE LIGNES","	* peut s'utiliser pour représenter sans équivoque ce concept"},
/* 2029 */ { "SÉPARATEUR DE PARAGRAPHES","	* peut s'utiliser pour représenter sans équivoque ce concept"},
/* 202A */ { "ENCHÂSSEMENT GAUCHE-À-DROITE","	* communément abrégé en LRE (left-to-right embedding)"},
/* 202B */ { "ENCHÂSSEMENT DROITE-À-GAUCHE","	* communément abrégé en RLE (right-to-left embedding)"},
/* 202C */ { "DÉPILEMENT DE FORMATAGE DIRECTIONNEL","	* communément abrégé en PDF (pop directional formatting)"},
/* 202D */ { "FORÇAGE GAUCHE-À-DROITE","	* communément abrégé en LRO (left-to-right override)"},
/* 202E */ { "FORÇAGE DROITE-À-GAUCHE","	* communément abrégé en RLO (right-to-left override)"},
/* 202F */ { "ESPACE INSÉCABLE ÉTROITE","	= espace fine insécable\n"
	"	* communément abrégée en NNBSP (narrow no-break space)\n"
	"	* une forme étroite de l'espace insécable ; doit avoir la même largeur que l'espace fine 2009\n"
	"	x (espace insécable - 00A0)\n"
	"	x (espace quart de cadratin - 2005)\n"
	"	x (espace fine - 2009)\n"
	"	# <insécable> 0020"},
/* 2030 */ { "SYMBOLE POUR MILLE","	* utilisé en mesure de salinité, d'alcoolémie, etc.\n"
	"	x (symbole pour cent - 0025)\n"
	"	x (symbole arabo-indien pour mille - 0609)"},
/* 2031 */ { "SYMBOLE POUR DIX MILLE","	= par myriade\n"
	"	* pourcentage d'un pourcentage, rarement utilisé\n"
	"	x (symbole pour cent - 0025)\n"
	"	x (symbole arabo-indien pour dix mille - 060A)"},
/* 2032 */ { "PRIME","	= minute, pied\n"
	"	x (apostrophe - 0027)\n"
	"	x (accent aigu - 00B4)\n"
	"	x (lettre modificative prime - 02B9)"},
/* 2033 */ { "DOUBLE PRIME","	= seconde, pouce\n"
	"	x (guillemet anglais - 0022)\n"
	"	x (lettre modificative seconde - 02BA)\n"
	"	x (guillemet-apostrophe double - 201D)\n"
	"	x (guillemet de répétition - 3003)\n"
	"	x (guillemet double prime - 301E)\n"
	"	# 2032 2032"},
/* 2034 */ { "TRIPLE PRIME","	= ligne (unité de mesure archaïque, utilisée notamment dans l'horlogerie)\n"
	"	# 2032 2032 2032"},
/* 2035 */ { "PRIME RÉFLÉCHI","	x (accent grave - 0060)"},
/* 2036 */ { "DOUBLE PRIME RÉFLÉCHI","	x (guillemet double prime réfléchi - 301D)\n"
	"	# 2035 2035"},
/* 2037 */ { "TRIPLE PRIME RÉFLÉCHI","	# 2035 2035 2035"},
/* 2038 */ { "CHEVRON D'INSERTION","	x (pointe de flèche vers le haut - 2303)\n"
	"	x (lettre modificative accent circonflexe bas - A788)"},
/* 2039 */ { "GUILLEMET SIMPLE VERS LA GAUCHE","	* habituellement ouvrant, mais dans certaines langues fermant\n"
	"	x (signe inférieur à - 003C)\n"
	"	x (chevron pointant à gauche - 2329)\n"
	"	x (chevron gauche - 3008)"},
/* 203A */ { "GUILLEMET SIMPLE VERS LA DROITE","	* habituellement fermant, mais dans certaines langues ouvrant\n"
	"	x (signe supérieur à - 003E)\n"
	"	x (chevron pointant à droite - 232A)\n"
	"	x (chevron droit - 3009)"},
/* 203B */ { "MARQUE DE RÉFÉRENCE","	= komé japonais\n"
	"	= séparateur de paragraphes ourdou\n"
	"	* marque de cahier en reliure, indice de collationnement\n"
	"	x (signe tibétain kou rou kha bzhi mig tchan - 0FBF)\n"
	"	x 200AD"},
/* 203C */ { "DOUBLE POINT D'EXCLAMATION","	x (point d'exclamation - 0021)\n"
	"	# 0021 0021"},
/* 203D */ { "POINT EXCLARROGATIF","	x (point d'exclamation - 0021)\n"
	"	x (point d'interrogation - 003F)\n"
	"	x (point exclarrogatif culbuté - 2E18)\n"
	"	x (ornement point exclarrogatif au trait fort - 1F679)"},
/* 203E */ { "TIRET HAUT","	= trait suscrit à chasse\n"
	"	# 0020 0305"},
/* 203F */ { "TIRANT BAS","	= énotikon grec\n"
	"	x (sourire - 2323)"},
/* 2040 */ { "TIRANT HAUT","	= concaténation d'une séquence en notation Z\n"
	"	= dos-d'âne suscrit\n"
	"	x (moue - 2322)"},
/* 2041 */ { "LAMBDA D'INSERTION","	* signe de correcteur : insérer ici\n"
	"	x (produit semi-direct à droite - 22CC)"},
/* 2042 */ { "ASTÉRISME",NULL},
/* 2043 */ { "PUCE TRAIT D'UNION","	x (trait d'union-signe moins - 002D)"},
/* 2044 */ { "BARRE DE FRACTION","	= barre fractionnaire\n"
	"	* pour composer des fractions arbitraires\n"
	"	x (barre oblique - 002F)\n"
	"	x (barre oblique de division - 2215)"},
/* 2045 */ { "CROCHET GAUCHE AVEC PIQUE","	x (échasse gauche - 2E20)\n"
	"	x (crochet gauche avec barre - 2E55)"},
/* 2046 */ { "CROCHET DROIT AVEC PIQUE",NULL},
/* 2047 */ { "DOUBLE POINT D'INTERROGATION","	# 003F 003F"},
/* 2048 */ { "POINT D'INTERROGATION-EXCLAMATION","	# 003F 0021"},
/* 2049 */ { "POINT D'EXCLAMATION-INTERROGATION","	# 0021 003F"},
/* 204A */ { "NOTE TIRONIENNE ET","	* gaélique irlandais, vieil anglais\n"
	"	x (perluète - 0026)\n"
	"	x (note tironienne majuscule et - 2E52)\n"
	"	x (ornement ligature et cursif - 1F670)"},
/* 204B */ { "PIED-DE-MOUCHE RÉFLÉCHI","	x (pied-de-mouche - 00B6)\n"
	"	x (signe paragraphus - 2E4D)"},
/* 204C */ { "PUCE NOIRE TRONQUÉE À DROITE",NULL},
/* 204D */ { "PUCE NOIRE TRONQUÉE À GAUCHE",NULL},
/* 204E */ { "ASTÉRISQUE BAISSÉ","	x (astérisque - 002A)\n"
	"	x (diacritique astérisque souscrit - 0359)"},
/* 204F */ { "POINT-VIRGULE RÉFLÉCHI","	* utilisation occasionnelle en sindhi, lorsqu'il est écrit au moyen de l'alphabet arabe\n"
	"	x (point-virgule - 003B)\n"
	"	x (point-virgule arabe - 061B)"},
/* 2050 */ { "RESSERRER","	* signe de correcteur : diminuer une espace ou joindre deux signes\n"
	"	x (brève modificative et brève renversée - AB5B)"},
/* 2051 */ { "DEUX ASTÉRISQUES ALIGNÉS VERTICALEMENT",NULL},
/* 2052 */ { "SIGNE MOINS COMMERCIAL","	= « abzüglich » (déduction en allemand), « med avdrag av » (déduction en suédois), « piska » (fouet en suédois)\n"
	"	* une variante commune de repli ressemble à « ./. »\n"
	"	* peut également servir de dingbat pour indiquer que l'option est correcte\n"
	"	* utilisé dans l'alphabet phonétique finno-ougrien pour indiquer qu'une forme empruntée voisine se prononce différemment\n"
	"	x (symbole pour cent - 0025)\n"
	"	x (symbole arabe pour cent - 066A)\n"
	"	x (signe de division - 00F7)"},
/* 2053 */ { "TIRET ONDÉ","	x (tilde - 007E)"},
/* 2054 */ { "TIRANT BAS RENVERSÉ",NULL},
/* 2055 */ { "POINT-FLEUR","	= phoul, pouspika\n"
	"	* sert de signe de ponctuation en sylotî nâgrî, en bengali et dans d'autres écritures indiennes\n"
	"	x (gros astérisque-hélice à huit branches larmées - 274B)"},
/* 2056 */ { "TROIS-POINTS","	x (séparateur de paragraphes géorgien - 10FB)"},
/* 2057 */ { "QUADRUPLE PRIME","	# 2032 2032 2032 2032"},
/* 2058 */ { "QUATRE-POINTS EN LOSANGE",NULL},
/* 2059 */ { "CINQ-POINTS EN QUINCONCE","	= pentonkion grec\n"
	"	x (face de dé-5 - 2684)"},
/* 205A */ { "DEUX-POINTS EN CAPITALE","	* autrefois utilisé pour indiquer la fin d'une phrase ou le changement de locuteur\n"
	"	* va de la ligne de base à celle de la hauteur des capitales\n"
	"	x (forme de présentation de point de conduite double vertical - FE30)\n"
	"	x (deux acrophonique grec épidaurien - 1015B)"},
/* 205B */ { "QUATRE-POINTS EN CROIX","	* signe marginal de mise en évidence utilisé par les scribes\n"
	"	* le signe est centré dans la ligne, mais s'étend au-delà du haut et du bas de la ligne"},
/* 205C */ { "CROIX POINTÉE","	* signe marginal de mise en évidence utilisé par les scribes"},
/* 205D */ { "TROIS-POINTS VERTICAL","	= symbole trois acrophonique épidaurien\n"
	"	x (trois points suspendus - 22EE)\n"
	"	x (opérateur trois-points - 2AF6)\n"
	"	x (forme de présentation de points de suspension verticaux - FE19)"},
/* 205E */ { "QUATRE-POINTS VERTICAL","	* sert dans les dictionnaires anglo-saxons pour indiquer une coupure de mot licite mais peu souhaitable\n"
	"	* couvre la hauteur totale de la ligne\n"
	"	x (six-points vertical - 2E3D)"},
/* 205F */ { "ESPACE MOYENNE MATHÉMATIQUE","	* parfois abrégée en MMSP (medium mathematical space)\n"
	"	* quatre dix-huitièmes d'un cadratin\n"
	"	# 0020 espace"},
/* 2060 */ { "GLUON DE MOTS","	* communément abrégé en WJ (word joiner)\n"
	"	* une espace insécable sans chasse (rien de plus)\n"
	"	* permet de désambiguïser les fonctions pour l'indicateur d'ordre des octets\n"
	"	x (indicateur d'ordre des octets - FEFF)"},
/* 2061 */ { "APPLICATION D'UNE FONCTION","	* type de juxtaposition séparant une fonction de son argument"},
/* 2062 */ { "SIGNE DE MULTIPLICATION INVISIBLE","	* type de juxtaposition indiquant une multiplication"},
/* 2063 */ { "SÉPARATEUR INVISIBLE","	= virgule invisible\n"
	"	* type de juxtaposition indiquant qu'une suite de symboles mathématiques forme une liste (comme pour les indices qui ne sont pas séparés par des virgules visibles)"},
/* 2064 */ { "PLUS INVISIBLE","	* type de juxtaposition indiquant une addition"},
/* 2065 */ { NULL,NULL},
/* 2066 */ { "ISOLAT GAUCHE-À-DROITE","	* communément abrégé en LRI (left-to-right isolate)"},
/* 2067 */ { "ISOLAT DROITE-À-GAUCHE","	* communément abrégé en RLI (right-to-left isolate)"},
/* 2068 */ { "ISOLAT À DIRECTION DU PREMIER FORT","	* communément abrégé en FSI (first strong isolate)"},
/* 2069 */ { "DÉPILEMENT D'ISOLAT DIRECTIONNEL","	* communément abrégé en PDI (pop directional isolate)"},
/* 206A */ { "INHIBITEUR D'ÉCHANGE SYMÉTRIQUE",NULL},
/* 206B */ { "ACTIVATEUR D'ÉCHANGE SYMÉTRIQUE",NULL},
/* 206C */ { "INHIBITEUR DE FORMAGE ARABE",NULL},
/* 206D */ { "ACTIVATEUR DE FORMAGE ARABE",NULL},
/* 206E */ { "SÉLECTEUR DE FORMES NUMÉRALES NATIONALES",NULL},
/* 206F */ { "SÉLECTEUR DE FORMES NUMÉRALES DE RÉFÉRENCE",NULL},
/* 2070 */ { "EXPOSANT ZÉRO","	# <exp> 0030"},
/* 2071 */ { "EXPOSANT LETTRE MINUSCULE LATINE I","	* fonctionne comme une lettre modificative\n"
	"	# <exp> 0069"},
/* 2072 */ { NULL,"	x (exposant deux - 00B2)"},
/* 2073 */ { NULL,"	x (exposant trois - 00B3)"},
/* 2074 */ { "EXPOSANT QUATRE","	# <exp> 0034"},
/* 2075 */ { "EXPOSANT CINQ","	# <exp> 0035"},
/* 2076 */ { "EXPOSANT SIX","	# <exp> 0036"},
/* 2077 */ { "EXPOSANT SEPT","	# <exp> 0037"},
/* 2078 */ { "EXPOSANT HUIT","	# <exp> 0038"},
/* 2079 */ { "EXPOSANT NEUF","	# <exp> 0039"},
/* 207A */ { "EXPOSANT SIGNE PLUS","	# <exp> 002B"},
/* 207B */ { "EXPOSANT SIGNE MOINS","	# <exp> 2212"},
/* 207C */ { "EXPOSANT SIGNE ÉGAL","	# <exp> 003D"},
/* 207D */ { "EXPOSANT PARENTHÈSE GAUCHE","	# <exp> 0028"},
/* 207E */ { "EXPOSANT PARENTHÈSE DROITE","	# <exp> 0029"},
/* 207F */ { "EXPOSANT LETTRE MINUSCULE LATINE N","	* fonctionne comme une lettre modificative\n"
	"	# <exp> 006E"},
/* 2080 */ { "INDICE ZÉRO","	# <souscrite> 0030"},
/* 2081 */ { "INDICE UN","	# <souscrite> 0031"},
/* 2082 */ { "INDICE DEUX","	# <souscrite> 0032"},
/* 2083 */ { "INDICE TROIS","	# <souscrite> 0033"},
/* 2084 */ { "INDICE QUATRE","	# <souscrite> 0034"},
/* 2085 */ { "INDICE CINQ","	# <souscrite> 0035"},
/* 2086 */ { "INDICE SIX","	# <souscrite> 0036"},
/* 2087 */ { "INDICE SEPT","	# <souscrite> 0037"},
/* 2088 */ { "INDICE HUIT","	# <souscrite> 0038"},
/* 2089 */ { "INDICE NEUF","	# <souscrite> 0039"},
/* 208A */ { "INDICE SIGNE PLUS","	# <souscrite> 002B"},
/* 208B */ { "INDICE SIGNE MOINS","	# <souscrite> 2212"},
/* 208C */ { "INDICE SIGNE ÉGAL","	# <souscrite> 003D"},
/* 208D */ { "INDICE PARENTHÈSE GAUCHE","	# <souscrite> 0028"},
/* 208E */ { "INDICE PARENTHÈSE DROITE","	# <souscrite> 0029"},
/* 208F */ { NULL,NULL},
/* 2090 */ { "INDICE LETTRE MINUSCULE LATINE A","	# <souscrite> 0061"},
/* 2091 */ { "INDICE LETTRE MINUSCULE LATINE E","	# <souscrite> 0065"},
/* 2092 */ { "INDICE LETTRE MINUSCULE LATINE O","	# <souscrite> 006F"},
/* 2093 */ { "INDICE LETTRE MINUSCULE LATINE X","	# <souscrite> 0078"},
/* 2094 */ { "INDICE LETTRE MINUSCULE LATINE SCHWA","	# <souscrite> 0259"},
/* 2095 */ { "INDICE LETTRE MINUSCULE LATINE H","	# <souscrite> 0068"},
/* 2096 */ { "INDICE LETTRE MINUSCULE LATINE K","	# <souscrite> 006B"},
/* 2097 */ { "INDICE LETTRE MINUSCULE LATINE L","	# <souscrite> 006C"},
/* 2098 */ { "INDICE LETTRE MINUSCULE LATINE M","	# <souscrite> 006D"},
/* 2099 */ { "INDICE LETTRE MINUSCULE LATINE N","	# <souscrite> 006E"},
/* 209A */ { "INDICE LETTRE MINUSCULE LATINE P","	# <souscrite> 0070"},
/* 209B */ { "INDICE LETTRE MINUSCULE LATINE S","	# <souscrite> 0073"},
/* 209C */ { "INDICE LETTRE MINUSCULE LATINE T","	# <souscrite> 0074"},
/* 209D */ { NULL,NULL},
/* 209E */ { NULL,NULL},
/* 209F */ { NULL,NULL},
/* 20A0 */ { "SYMBOLE ÉCU","	* caractère prévu pour l'ECU, unité de compte électronique obsolète de la Communauté européenne ; ce caractère est caduc et n'a guère été utilisé\n"
	"	* l'ECU n'est pas l'euro !\n"
	"	x (symbole euro - 20AC)"},
/* 20A1 */ { "SYMBOLE COLON","	* Costa Rica, Salvador"},
/* 20A2 */ { "SYMBOLE CRUZEIRO","	* Brésil"},
/* 20A3 */ { "SYMBOLE FRANC FRANÇAIS","	* France\n"
	"	x (lettre majuscule latine f barré - A798)"},
/* 20A4 */ { "SYMBOLE LIRE","	* destiné à représenter la lire, mais le symbole est peu utilisé\n"
	"	* le caractère recommandé pour la lire est 00A3\n"
	"	x (symbole livre - 00A3)\n"
	"	x (symbole lire turque - 20BA)"},
/* 20A5 */ { "SYMBOLE MILLIÈME","	* États-Unis (1/10 de cent)"},
/* 20A6 */ { "SYMBOLE NAIRA","	* Nigeria"},
/* 20A7 */ { "SYMBOLE PESETA","	* Espagne\n"
	"	x (symbole peso - 20B1)"},
/* 20A8 */ { "SYMBOLE ROUPIE","	* symbole générique utilisé pour la roupie au Sri Lanka, au Pakistan et au Népal (abandonné officiellement en Inde)\n"
	"	x (symbole roupie indienne - 20B9)\n"
	"	# 0052 0073"},
/* 20A9 */ { "SYMBOLE WON","	* Corée du Sud et Corée du Nord\n"
	"	* le glyphe peut présenter une ou deux barres transversales, mais la forme la plus courante n'en présente qu'une seule"},
/* 20AA */ { "SYMBOLE NOUVEAU CHÉKEL","	= shekel, sheqel\n"
	"	* Israël"},
/* 20AB */ { "SYMBOLE DONG","	* Viêt Nam"},
/* 20AC */ { "SYMBOLE EURO","	* symbole monétaire pour l'Union monétaire européenne\n"
	"	* l'euro n'est pas l'ECU\n"
	"	x (symbole écu - 20A0)"},
/* 20AD */ { "SYMBOLE KIP","	* Laos"},
/* 20AE */ { "SYMBOLE TOUGRIK","	* Mongolie\n"
	"	* translittération aussi en tougroug, tougric, tougrog, togrog"},
/* 20AF */ { "SYMBOLE DRACHME","	* Grèce"},
/* 20B0 */ { "SYMBOLE PFENNIG","	* Allemagne\n"
	"	* forme stylisée de la lettre minuscule d (pour « denarius », denier) en écriture cursive allemande (Kurrentschrift)"},
/* 20B1 */ { "SYMBOLE PESO","	= symbole peso philippin\n"
	"	* Philippines\n"
	"	* le symbole dollar s'utilise pour le peso dans de nombreux pays d'Amérique latine\n"
	"	x (symbole dollar - 0024)\n"
	"	x (symbole peseta - 20A7)"},
/* 20B2 */ { "SYMBOLE GUARANI","	* Paraguay\n"
	"	* souvent représenté au moyen de « G. » ou de « Gs. »"},
/* 20B3 */ { "SYMBOLE AUSTRAL","	* Argentine\n"
	"	* symbole pour l'austral, unité monétaire remplacée par le peso argentin"},
/* 20B4 */ { "SYMBOLE HRYVNIA","	* Ukraine"},
/* 20B5 */ { "SYMBOLE CEDI","	* Ghana\n"
	"	* le glyphe peut ressembler à 023B ou à un C avec une petite barre verticale traversant l'arc supérieur\n"
	"	x (symbole centime - 00A2)\n"
	"	x (lettre majuscule latine c barré - 023B)"},
/* 20B6 */ { "SYMBOLE LIVRE TOURNOIS","	* unité de compte monétaire utilisée en France du XIIIe au XVIIIe siècle"},
/* 20B7 */ { "SYMBOLE SPESMILO","	* unité monétaire transnationale obsolète associée au monde de l'espéranto"},
/* 20B8 */ { "SYMBOLE TENGE","	* Kazakhstan\n"
	"	x (symbole de fonction apl taquet vers le haut barre en chef - 2351)\n"
	"	x (filet simple vers le bas et double horizontal - 2564)\n"
	"	x (marque postale - 3012)"},
/* 20B9 */ { "SYMBOLE ROUPIE INDIENNE","	* symbole monétaire officiel de la roupie pour l'Inde\n"
	"	* contraste avec les symboles de la roupie propres à certaines polices\n"
	"	x (lettre dévanâgarî ra - 0930)"},
/* 20BA */ { "SYMBOLE LIRE TURQUE","	* symbole monétaire officiel de la lire pour la Turquie"},
/* 20BB */ { "SYMBOLE MARK NORDIQUE","	* représentation primitive du mark utilisé au Danemark et en Norvège\n"
	"	x (majuscule m de ronde - 2133)"},
/* 20BC */ { "SYMBOLE MANAT","	* Azerbaïdjan"},
/* 20BD */ { "SYMBOLE ROUBLE","	* Russie"},
/* 20BE */ { "SYMBOLE LARI","	* Géorgie"},
/* 20BF */ { "SYMBOLE BITCOIN","	* une crypto-monnaie"},
/* 20C0 */ { "SYMBOLE SOM","	* Kirghizistan"},
/* 20C1 */ { "SYMBOLE RIYAL SAOUDIEN","	* Arabie saoudite"},
/* 20C2 */ { NULL,NULL},
/* 20C3 */ { NULL,NULL},
/* 20C4 */ { NULL,NULL},
/* 20C5 */ { NULL,NULL},
/* 20C6 */ { NULL,NULL},
/* 20C7 */ { NULL,NULL},
/* 20C8 */ { NULL,NULL},
/* 20C9 */ { NULL,NULL},
/* 20CA */ { NULL,NULL},
/* 20CB */ { NULL,NULL},
/* 20CC */ { NULL,NULL},
/* 20CD */ { NULL,NULL},
/* 20CE */ { NULL,NULL},
/* 20CF */ { NULL,NULL},
/* 20D0 */ { "DIACRITIQUE VECTEUR VERS LA GAUCHE EN CHEF",NULL},
/* 20D1 */ { "DIACRITIQUE VECTEUR VERS LA DROITE EN CHEF","	* vecteur"},
/* 20D2 */ { "DIACRITIQUE LIGNE VERTICALE LONGUE COUVRANTE","	* négation"},
/* 20D3 */ { "DIACRITIQUE LIGNE VERTICALE COURTE COUVRANTE","	* variante occasionnelle pour la négation"},
/* 20D4 */ { "DIACRITIQUE FLÈCHE SENS ANTIHORAIRE EN CHEF",NULL},
/* 20D5 */ { "DIACRITIQUE FLÈCHE SENS HORAIRE EN CHEF","	* rotation"},
/* 20D6 */ { "DIACRITIQUE FLÈCHE VERS LA GAUCHE EN CHEF",NULL},
/* 20D7 */ { "DIACRITIQUE FLÈCHE VERS LA DROITE EN CHEF","	* vecteur"},
/* 20D8 */ { "DIACRITIQUE ROND COUVRANT",NULL},
/* 20D9 */ { "DIACRITIQUE ROND SENS HORAIRE COUVRANT",NULL},
/* 20DA */ { "DIACRITIQUE ROND SENS ANTIHORAIRE COUVRANT",NULL},
/* 20DB */ { "DIACRITIQUE TROIS POINTS EN CHEF","	= dérivée troisième"},
/* 20DC */ { "DIACRITIQUE QUATRE POINTS EN CHEF","	= dérivée quatrième"},
/* 20DD */ { "DIACRITIQUE CERCLE ENGLOBANT","	= cercle de composition JIS\n"
	"	= diacritique cyrillique dizaines de milliers\n"
	"	x (cercle blanc - 25CB)\n"
	"	x (grand cercle - 25EF)\n"
	"	x (zéro idéographique - 3007)"},
/* 20DE */ { "DIACRITIQUE CARRÉ ENGLOBANT","	x (carré blanc - 25A1)"},
/* 20DF */ { "DIACRITIQUE LOSANGE ENGLOBANT","	x (losange blanc - 25C7)"},
/* 20E0 */ { "DIACRITIQUE CERCLE ENGLOBANT ET BARRE OBLIQUE INVERSÉE","	* interdiction\n"
	"	x (symbole d'interdiction - 1F6C7)"},
/* 20E1 */ { "DIACRITIQUE FLÈCHE GAUCHE-DROITE EN CHEF","	* tenseur\n"
	"	x (diacritique flèche gauche-droite souscrite - 034D)"},
/* 20E2 */ { "DIACRITIQUE ÉCRAN ENGLOBANT","	x (symbole effacer écran - 239A)\n"
	"	x (écran - 1F5B5)"},
/* 20E3 */ { "DIACRITIQUE TOUCHE ENGLOBANTE",NULL},
/* 20E4 */ { "DIACRITIQUE TRIANGLE ENGLOBANT POINTANT VERS LE HAUT","	x (triangle blanc pointant vers le haut - 25B3)"},
/* 20E5 */ { "DIACRITIQUE BARRE OBLIQUE INVERSÉE COUVRANTE","	= diacritique contre-oblique couvrante, diacritique contre-cotice couvrante\n"
	"	x (barre oblique inversée - 005C)"},
/* 20E6 */ { "DIACRITIQUE DOUBLE BARRE VERTICALE COUVRANTE","	= diacritique fonction finie en notation Z\n"
	"	x (double ligne verticale - 2016)\n"
	"	x (flèche vers la droite barrée deux fois verticalement - 21FB)\n"
	"	x (flèche à deux pointes vers la droite barrée deux fois verticalement - 2901)\n"
	"	x (flèche empennée vers la droite barrée deux fois verticalement - 2915)"},
/* 20E7 */ { "DIACRITIQUE SYMBOLE DE RENTE","	= anglet actuariel\n"
	"	x (plafond à droite - 2309)"},
/* 20E8 */ { "DIACRITIQUE TROIS POINTS SOUSCRITS",NULL},
/* 20E9 */ { "DIACRITIQUE PONT EN CHEF","	= opérateur de contraction\n"
	"	* couvre toute la largeur du caractère de base\n"
	"	x (diacritique pontet en chef - 0346)"},
/* 20EA */ { "DIACRITIQUE FLÈCHE VERS LA GAUCHE COUVRANTE","	x (flèche vers la gauche - 2190)"},
/* 20EB */ { "DIACRITIQUE DOUBLE BARRE OBLIQUE LONGUE COUVRANTE","	= diacritique longue double oblique couvrante, diacritique longue double cotice couvrante"},
/* 20EC */ { "DIACRITIQUE HARPON VERS LA DROITE AVEC BARBILLON VERS LE BAS",NULL},
/* 20ED */ { "DIACRITIQUE HARPON VERS LA GAUCHE AVEC BARBILLON VERS LE BAS",NULL},
/* 20EE */ { "DIACRITIQUE FLÈCHE VERS LA GAUCHE SOUSCRITE",NULL},
/* 20EF */ { "DIACRITIQUE FLÈCHE VERS LA DROITE SOUSCRITE",NULL},
/* 20F0 */ { "DIACRITIQUE ASTÉRISQUE SUSCRIT",NULL},
/* 20F1 */ { NULL,NULL},
/* 20F2 */ { NULL,NULL},
/* 20F3 */ { NULL,NULL},
/* 20F4 */ { NULL,NULL},
/* 20F5 */ { NULL,NULL},
/* 20F6 */ { NULL,NULL},
/* 20F7 */ { NULL,NULL},
/* 20F8 */ { NULL,NULL},
/* 20F9 */ { NULL,NULL},
/* 20FA */ { NULL,NULL},
/* 20FB */ { NULL,NULL},
/* 20FC */ { NULL,NULL},
/* 20FD */ { NULL,NULL},
/* 20FE */ { NULL,NULL},
/* 20FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_21[] = {
/* 2100 */ { "AU COMPTE DE","	# 0061 002F 0063"},
/* 2101 */ { "AUX BONS SOINS DE","	= aux soins (de)\n"
	"	* il ne faut pas confondre « Aux bons soins de » avec « À l'attention de »\n"
	"	x (aktieselskab - 214D)\n"
	"	# 0061 002F 0073"},
/* 2102 */ { "MAJUSCULE C AJOURÉ","	= majuscule c éclairé\n"
	"	= l'ensemble des nombres complexes\n"
	"	# <police> 0043 lettre majuscule latine c"},
/* 2103 */ { "DEGRÉ CELSIUS","	* on sépare ce symbole du nombre qui le précède à l'aide d'une espace, alors que le symbole degré (00B0) non suivi par l'abréviation précisant l'échelle utilisée suit immédiatement son nombre ; on composera, par exemple, « 20 °C » (mais « 20° »)\n"
	"	# 00B0 0043"},
/* 2104 */ { "SYMBOLE LIGNE DE CENTRE","	= clone"},
/* 2105 */ { "CARE OF","	* en français : a/s (aux soins de), et l'on utilise 2101\n"
	"	* compte ouvert\n"
	"	# 0063 002F 006F"},
/* 2106 */ { "CADA UNA","	= cada uno\n"
	"	* espagnol : « chacun » (cada uno), « chacune » (cada una)\n"
	"	# 0063 002F 0075"},
/* 2107 */ { "CONSTANTE D'EULER","	x (lettre majuscule latine e - 0045)\n"
	"	# 0190 lettre majuscule latine e ouvert"},
/* 2108 */ { "SCRUPULE",NULL},
/* 2109 */ { "DEGRÉ FAHRENHEIT","	* on sépare ce symbole du nombre qui le précède à l'aide d'une espace, alors que le symbole degré (00B0) non suivi par l'abréviation précisant l'échelle utilisée suit immédiatement son nombre ; on composera, par exemple, « 68 °F » (mais « 68° »)\n"
	"	# 00B0 0046"},
/* 210A */ { "MINUSCULE G DE RONDE","	= symbole nombre réel\n"
	"	# <police> 0067 lettre minuscule latine g"},
/* 210B */ { "MAJUSCULE H DE RONDE","	= opérateur hamiltonien\n"
	"	~ 210B FE00 écriture chancelière\n"
	"	~ 210B FE01 écriture anglaise\n"
	"	# <police> 0048 lettre majuscule latine h"},
/* 210C */ { "MAJUSCULE H GOTHIQUE","	= espace de Hilbert\n"
	"	# <police> 0048 lettre majuscule latine h"},
/* 210D */ { "MAJUSCULE H AJOURÉ","	= majuscule h éclairé\n"
	"	# <police> 0048 lettre majuscule latine h"},
/* 210E */ { "CONSTANTE DE PLANCK","	= hauteur, enthalpie spécifique\n"
	"	* simplement un h mathématique italique ; le nom de ce caractère trouve son origine dans un usage historique\n"
	"	# <police> 0068 lettre minuscule latine h"},
/* 210F */ { "CONSTANTE DE PLANCK SUR DEUX PI","	= constante de Planck réduite, constante de Dirac\n"
	"	x (lettre minuscule cyrillique tié - 045B)\n"
	"	# <police> 0127 lettre minuscule latine h barré"},
/* 2110 */ { "MAJUSCULE I DE RONDE","	~ 2110 FE00 écriture chancelière\n"
	"	~ 2110 FE01 écriture anglaise\n"
	"	# <police> 0049 lettre majuscule latine i"},
/* 2111 */ { "MAJUSCULE I GOTHIQUE","	= partie imaginaire\n"
	"	# <police> 0049 lettre majuscule latine i"},
/* 2112 */ { "MAJUSCULE L DE RONDE","	= transformation de Laplace\n"
	"	~ 2112 FE00 écriture chancelière\n"
	"	~ 2112 FE01 écriture anglaise\n"
	"	# <police> 004C lettre majuscule latine l"},
/* 2113 */ { "MINUSCULE L DE RONDE","	= litre (symbole traditionnel)\n"
	"	* en dépit de son nom, ce symbole trouve son origine dans une variante italique particulière du l minuscule\n"
	"	* le symbole SI recommandé du litre est 006C\n"
	"	x (minuscule mathématique l de ronde - 1D4C1)\n"
	"	# <police> 006C lettre minuscule latine l"},
/* 2114 */ { "SYMBOLE L B BARRÉ","	= livre poids\n"
	"	x (croisillon - 0023)"},
/* 2115 */ { "MAJUSCULE N AJOURÉ","	= majuscule n éclairé\n"
	"	= l'ensemble des nombres entiers naturels\n"
	"	* il existe une variante de glyphe avec des hastes doublées\n"
	"	# <police> 004E lettre majuscule latine n"},
/* 2116 */ { "SYMBOLE NUMÉRO","	x (croisillon - 0023)\n"
	"	x (indicateur ordinal masculin - 00BA)\n"
	"	# 004E 006F"},
/* 2117 */ { "COPYRIGHT DE PHONOGRAMME","	x (symbole copyright - 00A9)\n"
	"	x (lettre majuscule latine p cerclée - 24C5)"},
/* 2118 */ { "SYMBOLE FONCTION ELLIPTIQUE DE WEIERSTRASS","	* le nom formel de ce caractère en anglais est erroné\n"
	"	* ce symbole a la forme d'un p calligraphique minuscule"},
/* 2119 */ { "MAJUSCULE P AJOURÉ","	= majuscule p éclairé\n"
	"	# <police> 0050 lettre majuscule latine p"},
/* 211A */ { "MAJUSCULE Q AJOURÉ","	= majuscule q éclairé\n"
	"	= l'ensemble des nombres rationnels\n"
	"	# <police> 0051 lettre majuscule latine q"},
/* 211B */ { "MAJUSCULE R DE RONDE","	= intégrale de Riemann\n"
	"	~ 211B FE00 écriture chancelière\n"
	"	~ 211B FE01 écriture anglaise\n"
	"	# <police> 0052 lettre majuscule latine r"},
/* 211C */ { "MAJUSCULE R GOTHIQUE","	= partie réelle\n"
	"	# <police> 0052 lettre majuscule latine r"},
/* 211D */ { "MAJUSCULE R AJOURÉ","	= majuscule r éclairé\n"
	"	= l'ensemble des nombres réels\n"
	"	# <police> 0052 lettre majuscule latine r"},
/* 211E */ { "ORDONNANCES","	= prescriptions"},
/* 211F */ { "RÉPONS",NULL},
/* 2120 */ { "SYMBOLE MARQUE DE SERVICE","	# <exp> 0053 004D"},
/* 2121 */ { "SYMBOLE TÉLÉPHONE","	* le symbole peut être présenté sous la forme d'une minuscule, d'une petite capitale ou d'une lettre suscrite\n"
	"	x (téléphone noir - 260E)\n"
	"	x (symbole d'emplacement du téléphone - 2706)\n"
	"	x (récepteur téléphonique - 1F4DE)\n"
	"	# 0054 0045 004C"},
/* 2122 */ { "SYMBOLE MARQUE DE COMMERCE","	x (wz cerclé - 1F12E)\n"
	"	# <exp> 0054 004D"},
/* 2123 */ { "VERSICULE","	= verset"},
/* 2124 */ { "MAJUSCULE Z AJOURÉ","	= majuscule z éclairé\n"
	"	= l'ensemble des nombres entiers relatifs\n"
	"	# <police> 005A lettre majuscule latine z"},
/* 2125 */ { "SYMBOLE ONCE","	x (lettre minuscule latine ej - 0292)\n"
	"	x (symbole alchimique de la demi-once - 1F773)\n"
	"	x 2CF04"},
/* 2126 */ { "SYMBOLE OHM","	* unité SI de la résistance électrique, du nom du physicien allemand Georg Ohm\n"
	"	* 03A9 est la représentation recommandée\n"
	"	x (nœud ascendant - 260A)\n"
	"	: 03A9 lettre majuscule grecque oméga"},
/* 2127 */ { "SYMBOLE OHM RENVERSÉ","	= symbole mho (ohm épelé à l'envers)\n"
	"	* unité SI désuète de la conductance électrique, remplacée par l'unité siemens\n"
	"	* typographiquement, une lettre majuscule grecque oméga culbutée\n"
	"	x (lettre majuscule latine upsilon - 01B1)\n"
	"	x (lettre majuscule grecque oméga - 03A9)\n"
	"	x (nœud descendant - 260B)"},
/* 2128 */ { "MAJUSCULE Z GOTHIQUE","	# <police> 005A lettre majuscule latine z"},
/* 2129 */ { "LETTRE MINUSCULE GRECQUE IOTA CULBUTÉ","	* seul élément qui corresponde à la description (en logique)\n"
	"	x (lettre minuscule grecque iota - 03B9)"},
/* 212A */ { "SYMBOLE KELVIN","	: 004B lettre majuscule latine k"},
/* 212B */ { "SYMBOLE ANGSTRÖM","	* unité de longueur non SI (= 0,1 nm), du nom du physicien suédois Anders Ångström\n"
	"	* 00C5 est la représentation recommandée\n"
	"	: 00C5 lettre majuscule latine a rond en chef"},
/* 212C */ { "MAJUSCULE B DE RONDE","	= fonction de Bernoulli\n"
	"	~ 212C FE00 écriture chancelière\n"
	"	~ 212C FE01 écriture anglaise\n"
	"	# <police> 0042 lettre majuscule latine b"},
/* 212D */ { "MAJUSCULE C GOTHIQUE","	# <police> 0043 lettre majuscule latine c"},
/* 212E */ { "SYMBOLE ESTIMÉ","	* utilisé sur les emballages européens\n"
	"	x (lettre minuscule latine e - 0065)"},
/* 212F */ { "MINUSCULE E DE RONDE","	= erreur\n"
	"	= exposant naturel\n"
	"	# <police> 0065 lettre minuscule latine e"},
/* 2130 */ { "MAJUSCULE E DE RONDE","	= fem (force électromotrice)\n"
	"	~ 2130 FE00 écriture chancelière\n"
	"	~ 2130 FE01 écriture anglaise\n"
	"	# <police> 0045 lettre majuscule latine e"},
/* 2131 */ { "MAJUSCULE F DE RONDE","	= transformée de Fourier, transformation de Fourier\n"
	"	~ 2131 FE00 écriture chancelière\n"
	"	~ 2131 FE01 écriture anglaise\n"
	"	# <police> 0046 lettre majuscule latine f"},
/* 2132 */ { "MAJUSCULE F CULBUTÉ","	= digamma inversé claudien\n"
	"	* la minuscule est 214E\n"
	"	x (lettre majuscule latine f - 0046)\n"
	"	x (lettre grecque digamma - 03DC)"},
/* 2133 */ { "MAJUSCULE M DE RONDE","	= matrice M\n"
	"	= moment d'une force\n"
	"	= symbole du mark allemand avant la Seconde Guerre mondiale\n"
	"	* lorsqu'elle est utilisée pour le symbole du mark, la gamme de variation du glyphe est limitée\n"
	"	x (symbole mark nordique - 20BB)\n"
	"	~ 2133 FE00 écriture chancelière\n"
	"	~ 2133 FE01 écriture anglaise\n"
	"	# <police> 004D lettre majuscule latine m"},
/* 2134 */ { "MINUSCULE O DE RONDE","	= ordre\n"
	"	# <police> 006F lettre minuscule latine o"},
/* 2135 */ { "SYMBOLE ALEF","	= aleph\n"
	"	= premier nombre transfini\n"
	"	= dénombrable\n"
	"	# 05D0 lettre hébraïque alef"},
/* 2136 */ { "SYMBOLE BÈT","	= beth\n"
	"	= deuxième nombre transfini\n"
	"	= le continu\n"
	"	# 05D1 lettre hébraïque bèt"},
/* 2137 */ { "SYMBOLE GUIMEL","	= gimel\n"
	"	= troisième nombre transfini\n"
	"	= fonctions d'une variable réelle\n"
	"	# 05D2 lettre hébraïque guimel"},
/* 2138 */ { "SYMBOLE DALÈT","	= daleth\n"
	"	= quatrième nombre transfini\n"
	"	# 05D3 lettre hébraïque dalèt"},
/* 2139 */ { "SOURCE D'INFORMATION","	* destiné à être utilisé avec 20DD\n"
	"	x (symbole source d'information cerclé - 1F6C8)\n"
	"	# <police> 0069 lettre minuscule latine i"},
/* 213A */ { "MAJUSCULE Q COUCHÉ","	* marque de cahier en reliure, indice de collationnement\n"
	"	* tiré de la norme ISO 5426-2:1996"},
/* 213B */ { "SYMBOLE TÉLÉCOPIE","	* le symbole peut être présenté sous la forme d'une minuscule, d'une petite capitale ou d'une lettre suscrite\n"
	"	x (symbole téléphone - 2121)\n"
	"	x (télécopieur - 1F4E0)\n"
	"	# 0046 0041 0058"},
/* 213C */ { "MINUSCULE PI AJOURÉ","	# <police> 03C0 lettre minuscule grecque pi"},
/* 213D */ { "MINUSCULE GAMMA AJOURÉ","	# <police> 03B3 lettre minuscule grecque gamma"},
/* 213E */ { "MAJUSCULE GAMMA AJOURÉ","	# <police> 0393 lettre majuscule grecque gamma"},
/* 213F */ { "MAJUSCULE PI AJOURÉ","	# <police> 03A0 lettre majuscule grecque pi"},
/* 2140 */ { "SOMMATION DE LA FAMILLE AJOURÉ","	# <police> 2211 sommation de la famille"},
/* 2141 */ { "MAJUSCULE G CULBUTÉ SANS EMPATTEMENT","	x (lettre lissou hha - A4E8)"},
/* 2142 */ { "MAJUSCULE L CULBUTÉ SANS EMPATTEMENT","	x (lettre lissou uh - A4F6)"},
/* 2143 */ { "MAJUSCULE L RÉFLÉCHI SANS EMPATTEMENT",NULL},
/* 2144 */ { "MAJUSCULE Y CULBUTÉ SANS EMPATTEMENT","	x (lettre lissou yha - 11FB0)"},
/* 2145 */ { "MAJUSCULE D ITALIQUE AJOURÉ","	* représente parfois la différentielle\n"
	"	# <police> 0044 lettre majuscule latine d"},
/* 2146 */ { "MINUSCULE D ITALIQUE AJOURÉ","	* représente parfois la différentielle\n"
	"	# <police> 0064 lettre minuscule latine d"},
/* 2147 */ { "MINUSCULE E ITALIQUE AJOURÉ","	* représente parfois l'exposant naturel\n"
	"	# <police> 0065 lettre minuscule latine e"},
/* 2148 */ { "MINUSCULE I ITALIQUE AJOURÉ","	* représente parfois l'unité imaginaire\n"
	"	# <police> 0069 lettre minuscule latine i"},
/* 2149 */ { "MINUSCULE J ITALIQUE AJOURÉ","	* représente parfois l'unité imaginaire\n"
	"	# <police> 006A lettre minuscule latine j"},
/* 214A */ { "LIMITE DE PROPRIÉTÉ",NULL},
/* 214B */ { "PERLUÈTE CULBUTÉE","	* utilisée en logique linéaire\n"
	"	x (perluète - 0026)"},
/* 214C */ { "SYMBOLE PER","	* représente le mot latin « per »"},
/* 214D */ { "AKTIESELSKAB","	x (aux bons soins de - 2101)"},
/* 214E */ { "MINUSCULE F CULBUTÉ","	* la majuscule est 2132\n"
	"	x (lettre minuscule grecque digamma - 03DD)"},
/* 214F */ { "SYMBOLE INDIQUANT UNE SOURCE SAMARITAINE",NULL},
/* 2150 */ { "FRACTION ORDINAIRE UN SEPTIÈME","	# <fraction> 0031 2044 0037"},
/* 2151 */ { "FRACTION ORDINAIRE UN NEUVIÈME","	# <fraction> 0031 2044 0039"},
/* 2152 */ { "FRACTION ORDINAIRE UN DIXIÈME","	# <fraction> 0031 2044 0031 0030"},
/* 2153 */ { "FRACTION ORDINAIRE UN TIERS","	# <fraction> 0031 2044 0033"},
/* 2154 */ { "FRACTION ORDINAIRE DEUX TIERS","	# <fraction> 0032 2044 0033"},
/* 2155 */ { "FRACTION ORDINAIRE UN CINQUIÈME","	# <fraction> 0031 2044 0035"},
/* 2156 */ { "FRACTION ORDINAIRE DEUX CINQUIÈMES","	# <fraction> 0032 2044 0035"},
/* 2157 */ { "FRACTION ORDINAIRE TROIS CINQUIÈMES","	# <fraction> 0033 2044 0035"},
/* 2158 */ { "FRACTION ORDINAIRE QUATRE CINQUIÈMES","	# <fraction> 0034 2044 0035"},
/* 2159 */ { "FRACTION ORDINAIRE UN SIXIÈME","	# <fraction> 0031 2044 0036"},
/* 215A */ { "FRACTION ORDINAIRE CINQ SIXIÈMES","	# <fraction> 0035 2044 0036"},
/* 215B */ { "FRACTION ORDINAIRE UN HUITIÈME","	# <fraction> 0031 2044 0038"},
/* 215C */ { "FRACTION ORDINAIRE TROIS HUITIÈMES","	# <fraction> 0033 2044 0038"},
/* 215D */ { "FRACTION ORDINAIRE CINQ HUITIÈMES","	# <fraction> 0035 2044 0038"},
/* 215E */ { "FRACTION ORDINAIRE SEPT HUITIÈMES","	# <fraction> 0037 2044 0038"},
/* 215F */ { "NUMÉRATEUR FRACTIONNAIRE UN","	# <fraction> 0031 2044"},
/* 2160 */ { "CHIFFRE ROMAIN UN","	# 0049 lettre majuscule latine i"},
/* 2161 */ { "CHIFFRE ROMAIN DEUX","	# 0049 0049"},
/* 2162 */ { "CHIFFRE ROMAIN TROIS","	# 0049 0049 0049"},
/* 2163 */ { "CHIFFRE ROMAIN QUATRE","	* parfois écrit IIII (en horlogerie, notoirement)\n"
	"	# 0049 0056"},
/* 2164 */ { "CHIFFRE ROMAIN CINQ","	# 0056 lettre majuscule latine v"},
/* 2165 */ { "CHIFFRE ROMAIN SIX","	# 0056 0049"},
/* 2166 */ { "CHIFFRE ROMAIN SEPT","	# 0056 0049 0049"},
/* 2167 */ { "CHIFFRE ROMAIN HUIT","	# 0056 0049 0049 0049"},
/* 2168 */ { "CHIFFRE ROMAIN NEUF","	# 0049 0058"},
/* 2169 */ { "CHIFFRE ROMAIN DIX","	# 0058 lettre majuscule latine x"},
/* 216A */ { "CHIFFRE ROMAIN ONZE","	# 0058 0049"},
/* 216B */ { "CHIFFRE ROMAIN DOUZE","	# 0058 0049 0049"},
/* 216C */ { "CHIFFRE ROMAIN CINQUANTE","	# 004C lettre majuscule latine l"},
/* 216D */ { "CHIFFRE ROMAIN CENT","	# 0043 lettre majuscule latine c"},
/* 216E */ { "CHIFFRE ROMAIN CINQ CENTS","	# 0044 lettre majuscule latine d"},
/* 216F */ { "CHIFFRE ROMAIN MILLE","	# 004D lettre majuscule latine m"},
/* 2170 */ { "CHIFFRE ROMAIN MINUSCULE UN","	# 0069 lettre minuscule latine i"},
/* 2171 */ { "CHIFFRE ROMAIN MINUSCULE DEUX","	# 0069 0069"},
/* 2172 */ { "CHIFFRE ROMAIN MINUSCULE TROIS","	# 0069 0069 0069"},
/* 2173 */ { "CHIFFRE ROMAIN MINUSCULE QUATRE","	# 0069 0076"},
/* 2174 */ { "CHIFFRE ROMAIN MINUSCULE CINQ","	# 0076 lettre minuscule latine v"},
/* 2175 */ { "CHIFFRE ROMAIN MINUSCULE SIX","	# 0076 0069"},
/* 2176 */ { "CHIFFRE ROMAIN MINUSCULE SEPT","	# 0076 0069 0069"},
/* 2177 */ { "CHIFFRE ROMAIN MINUSCULE HUIT","	# 0076 0069 0069 0069"},
/* 2178 */ { "CHIFFRE ROMAIN MINUSCULE NEUF","	# 0069 0078"},
/* 2179 */ { "CHIFFRE ROMAIN MINUSCULE DIX","	# 0078 lettre minuscule latine x"},
/* 217A */ { "CHIFFRE ROMAIN MINUSCULE ONZE","	# 0078 0069"},
/* 217B */ { "CHIFFRE ROMAIN MINUSCULE DOUZE","	# 0078 0069 0069"},
/* 217C */ { "CHIFFRE ROMAIN MINUSCULE CINQUANTE","	# 006C lettre minuscule latine l"},
/* 217D */ { "CHIFFRE ROMAIN MINUSCULE CENT","	# 0063 lettre minuscule latine c"},
/* 217E */ { "CHIFFRE ROMAIN MINUSCULE CINQ CENTS","	# 0064 lettre minuscule latine d"},
/* 217F */ { "CHIFFRE ROMAIN MINUSCULE MILLE","	# 006D lettre minuscule latine m"},
/* 2180 */ { "CHIFFRE ROMAIN MILLE C D",NULL},
/* 2181 */ { "CHIFFRE ROMAIN CINQ MILLE",NULL},
/* 2182 */ { "CHIFFRE ROMAIN DIX MILLE",NULL},
/* 2183 */ { "CHIFFRE ROMAIN CENT RÉFLÉCHI","	= C apostrophique\n"
	"	= antisigma claudien\n"
	"	* s'utilise avec C et I pour former de grands nombres\n"
	"	* la minuscule est 2184\n"
	"	x (lettre majuscule latine o ouvert - 0186)\n"
	"	x (symbole grec sigma lunaire majuscule réfléchi - 03FD)"},
/* 2184 */ { "LETTRE MINUSCULE LATINE C RÉFLÉCHI","	x (lettre minuscule latine o ouvert - 0254)\n"
	"	x (symbole grec sigma lunaire minuscule réfléchi - 037B)"},
/* 2185 */ { "CHIFFRE ROMAIN SIX FORME TARDIVE","	x (lettre grecque stigma - 03DA)"},
/* 2186 */ { "CHIFFRE ROMAIN CINQUANTE FORME ARCHAÏQUE","	x (lettre runique z - 16CE)\n"
	"	x (flèche vers le bas - 2193)"},
/* 2187 */ { "CHIFFRE ROMAIN CINQUANTE MILLE",NULL},
/* 2188 */ { "CHIFFRE ROMAIN CENT MILLE",NULL},
/* 2189 */ { "FRACTION ORDINAIRE ZÉRO TIERS","	* s'utilise pour les scores de baseball, tiré d'ARIB STD-B24\n"
	"	# <fraction> 0030 2044 0033"},
/* 218A */ { "CHIFFRE DEUX CULBUTÉ","	* chiffre pour 10 dans certains systèmes duodécimaux"},
/* 218B */ { "CHIFFRE TROIS CULBUTÉ","	* chiffre pour 11 dans certains systèmes duodécimaux\n"
	"	x (lettre majuscule latine e ouvert - 0190)\n"
	"	x (constante d'euler - 2107)\n"
	"	x (lettre minuscule latine tresillo - A72B)"},
/* 218C */ { NULL,NULL},
/* 218D */ { NULL,NULL},
/* 218E */ { NULL,NULL},
/* 218F */ { NULL,NULL},
/* 2190 */ { "FLÈCHE VERS LA GAUCHE","	x (diacritique flèche vers la gauche couvrante - 20EA)"},
/* 2191 */ { "FLÈCHE VERS LE HAUT","	* API : phonation égressive"},
/* 2192 */ { "FLÈCHE VERS LA DROITE","	= fonction totale en notation Z"},
/* 2193 */ { "FLÈCHE VERS LE BAS","	* API : phonation ingressive\n"
	"	x (flèche vers la gauche depuis une flèche vers le bas - 1F8C0)"},
/* 2194 */ { "FLÈCHE GAUCHE-DROITE","	= relation binaire en notation Z"},
/* 2195 */ { "FLÈCHE HAUT-BAS",NULL},
/* 2196 */ { "FLÈCHE NORD-OUEST",NULL},
/* 2197 */ { "FLÈCHE NORD-EST",NULL},
/* 2198 */ { "FLÈCHE SUD-EST",NULL},
/* 2199 */ { "FLÈCHE SUD-OUEST",NULL},
/* 219A */ { "FLÈCHE VERS LA GAUCHE BARRÉE","	* négation de 2190\n"
	"	: 2190 0338"},
/* 219B */ { "FLÈCHE VERS LA DROITE BARRÉE","	* négation de 2192\n"
	"	: 2192 0338"},
/* 219C */ { "FLÈCHE VERS LA GAUCHE ONDULÉE","	x (flèche ondulée pointant directement à gauche - 2B3F)"},
/* 219D */ { "FLÈCHE VERS LA DROITE ONDULÉE",NULL},
/* 219E */ { "FLÈCHE À DEUX POINTES VERS LA GAUCHE","	= déplacement rapide du curseur vers la gauche\n"
	"	x (flèche à deux pointes triangulaires vers la gauche - 2BEC)"},
/* 219F */ { "FLÈCHE À DEUX POINTES VERS LE HAUT","	= déplacement rapide du curseur vers le haut"},
/* 21A0 */ { "FLÈCHE À DEUX POINTES VERS LA DROITE","	= déplacement rapide du curseur vers la droite\n"
	"	= surjection totale en notation Z"},
/* 21A1 */ { "FLÈCHE À DEUX POINTES VERS LE BAS","	= déplacement rapide du curseur vers le bas\n"
	"	= page suivante"},
/* 21A2 */ { "FLÈCHE VERS LA GAUCHE EMPENNÉE",NULL},
/* 21A3 */ { "FLÈCHE VERS LA DROITE EMPENNÉE","	= injection totale en notation Z"},
/* 21A4 */ { "FLÈCHE D'UN TAQUET VERS LA GAUCHE","	= flèche à socle vers la gauche\n"
	"	= flèche à béquillon vers la gauche"},
/* 21A5 */ { "FLÈCHE D'UN TAQUET VERS LE HAUT","	= flèche à socle vers le haut\n"
	"	= flèche à béquillon vers le haut"},
/* 21A6 */ { "FLÈCHE D'UN TAQUET VERS LA DROITE","	= flèche à socle vers la droite\n"
	"	= flèche à béquillon vers la droite\n"
	"	= opérateur maplet en notation Z (« a pour image »)"},
/* 21A7 */ { "FLÈCHE D'UN TAQUET VERS LE BAS","	= flèche à socle vers le bas\n"
	"	= flèche à béquillon vers le bas\n"
	"	= symbole de profondeur"},
/* 21A8 */ { "FLÈCHE HAUT-BAS SUR BASE",NULL},
/* 21A9 */ { "FLÈCHE VERS LA GAUCHE À CROCHET",NULL},
/* 21AA */ { "FLÈCHE VERS LA DROITE À CROCHET",NULL},
/* 21AB */ { "FLÈCHE VERS LA GAUCHE À BOUCLE",NULL},
/* 21AC */ { "FLÈCHE VERS LA DROITE À BOUCLE",NULL},
/* 21AD */ { "FLÈCHE GAUCHE-DROITE ONDULÉE",NULL},
/* 21AE */ { "FLÈCHE GAUCHE-DROITE BARRÉE","	* négation de 2194\n"
	"	: 2194 0338"},
/* 21AF */ { "FLÈCHE VERS LE BAS EN ZIGZAG","	= électrolyse\n"
	"	x (flèche à pointe en triangle vers le bas en zigzag - 2B4D)"},
/* 21B0 */ { "FLÈCHE VERS LE HAUT À POINTE VERS LA GAUCHE",NULL},
/* 21B1 */ { "FLÈCHE VERS LE HAUT À POINTE VERS LA DROITE",NULL},
/* 21B2 */ { "FLÈCHE VERS LE BAS À POINTE VERS LA GAUCHE","	x (flèche vers le bas à pointe vers la gauche noir au blanc - 1FBB4)"},
/* 21B3 */ { "FLÈCHE VERS LE BAS À POINTE VERS LA DROITE",NULL},
/* 21B4 */ { "FLÈCHE VERS LA DROITE AVEC COIN VERS LE BAS","	= ligne suivante"},
/* 21B5 */ { "FLÈCHE VERS LE BAS AVEC COIN VERS LA GAUCHE","	* peut représenter un retour de chariot ou un passage à la ligne\n"
	"	x (symbole retour de chariot - 23CE)"},
/* 21B6 */ { "FLÈCHE SEMI-CIRCULAIRE SENS ANTIHORAIRE EN CHEF",NULL},
/* 21B7 */ { "FLÈCHE SEMI-CIRCULAIRE SENS HORAIRE EN CHEF",NULL},
/* 21B8 */ { "FLÈCHE NORD-OUEST JUSQU'À UN LONG TAQUET","	= début"},
/* 21B9 */ { "FLÈCHE VERS LA GAUCHE JUSQU'À UN TAQUET SUR FLÈCHE VERS LA DROITE JUSQU'À UN TAQUET","	= tabulation et tabulation arrière\n"
	"	x (touche de tabulation horizontale - 2B7E)"},
/* 21BA */ { "FLÈCHE CIRCULAIRE OUVERTE SENS ANTIHORAIRE",NULL},
/* 21BB */ { "FLÈCHE CIRCULAIRE OUVERTE SENS HORAIRE",NULL},
/* 21BC */ { "HARPON VERS LA GAUCHE AVEC BARBILLON VERS LE HAUT",NULL},
/* 21BD */ { "HARPON VERS LA GAUCHE AVEC BARBILLON VERS LE BAS",NULL},
/* 21BE */ { "HARPON VERS LE HAUT AVEC BARBILLON VERS LA DROITE",NULL},
/* 21BF */ { "HARPON VERS LE HAUT AVEC BARBILLON VERS LA GAUCHE",NULL},
/* 21C0 */ { "HARPON VERS LA DROITE AVEC BARBILLON VERS LE HAUT",NULL},
/* 21C1 */ { "HARPON VERS LA DROITE AVEC BARBILLON VERS LE BAS",NULL},
/* 21C2 */ { "HARPON VERS LE BAS AVEC BARBILLON VERS LA DROITE",NULL},
/* 21C3 */ { "HARPON VERS LE BAS AVEC BARBILLON VERS LA GAUCHE",NULL},
/* 21C4 */ { "FLÈCHE VERS LA DROITE SUR FLÈCHE VERS LA GAUCHE","	x (flèche longue vers la droite sur flèche longue vers la gauche - 1F8D0)"},
/* 21C5 */ { "FLÈCHE VERS LE HAUT À GAUCHE D'UNE FLÈCHE VERS LE BAS",NULL},
/* 21C6 */ { "FLÈCHE VERS LA GAUCHE SUR FLÈCHE VERS LA DROITE",NULL},
/* 21C7 */ { "PAIRE DE FLÈCHES VERS LA GAUCHE",NULL},
/* 21C8 */ { "PAIRE DE FLÈCHES VERS LE HAUT",NULL},
/* 21C9 */ { "PAIRE DE FLÈCHES VERS LA DROITE",NULL},
/* 21CA */ { "PAIRE DE FLÈCHES VERS LE BAS",NULL},
/* 21CB */ { "HARPON VERS LA GAUCHE SUR HARPON VERS LA DROITE",NULL},
/* 21CC */ { "HARPON VERS LA DROITE SUR HARPON VERS LA GAUCHE","	x (harpon long vers la droite sur harpon long vers la gauche - 1F8D1)"},
/* 21CD */ { "DOUBLE FLÈCHE VERS LA GAUCHE BARRÉE","	* négation de 21D0\n"
	"	: 21D0 0338"},
/* 21CE */ { "DOUBLE FLÈCHE GAUCHE-DROITE BARRÉE","	* négation de 21D4\n"
	"	: 21D4 0338"},
/* 21CF */ { "DOUBLE FLÈCHE VERS LA DROITE BARRÉE","	* négation de 21D2\n"
	"	: 21D2 0338"},
/* 21D0 */ { "DOUBLE FLÈCHE VERS LA GAUCHE",NULL},
/* 21D1 */ { "DOUBLE FLÈCHE VERS LE HAUT",NULL},
/* 21D2 */ { "DOUBLE FLÈCHE VERS LA DROITE",NULL},
/* 21D3 */ { "DOUBLE FLÈCHE VERS LE BAS",NULL},
/* 21D4 */ { "DOUBLE FLÈCHE GAUCHE-DROITE",NULL},
/* 21D5 */ { "DOUBLE FLÈCHE HAUT-BAS",NULL},
/* 21D6 */ { "DOUBLE FLÈCHE NORD-OUEST",NULL},
/* 21D7 */ { "DOUBLE FLÈCHE NORD-EST",NULL},
/* 21D8 */ { "DOUBLE FLÈCHE SUD-EST",NULL},
/* 21D9 */ { "DOUBLE FLÈCHE SUD-OUEST",NULL},
/* 21DA */ { "TRIPLE FLÈCHE VERS LA GAUCHE",NULL},
/* 21DB */ { "TRIPLE FLÈCHE VERS LA DROITE",NULL},
/* 21DC */ { "FLÈCHE VERS LA GAUCHE EN TIRE-BOUCHON","	= flèche gauche dentée\n"
	"	x (flèche longue vers la gauche en tire-bouchon - 2B33)"},
/* 21DD */ { "FLÈCHE VERS LA DROITE EN TIRE-BOUCHON","	= flèche droite dentée"},
/* 21DE */ { "FLÈCHE VERS LE HAUT AVEC DOUBLE BARRE","	= page précédente"},
/* 21DF */ { "FLÈCHE VERS LE BAS AVEC DOUBLE BARRE","	= page suivante"},
/* 21E0 */ { "FLÈCHE À TRAITS DISCONTINUS VERS LA GAUCHE",NULL},
/* 21E1 */ { "FLÈCHE À TRAITS DISCONTINUS VERS LE HAUT",NULL},
/* 21E2 */ { "FLÈCHE À TRAITS DISCONTINUS VERS LA DROITE",NULL},
/* 21E3 */ { "FLÈCHE À TRAITS DISCONTINUS VERS LE BAS",NULL},
/* 21E4 */ { "FLÈCHE VERS LA GAUCHE JUSQU'À UN TAQUET","	= tabulation arrière"},
/* 21E5 */ { "FLÈCHE VERS LA DROITE JUSQU'À UN TAQUET","	= tabulation"},
/* 21E6 */ { "FLÈCHE BLANCHE VERS LA GAUCHE","	x (flèche blanche nord-est - 2B00)"},
/* 21E7 */ { "FLÈCHE BLANCHE VERS LE HAUT","	= majuscules\n"
	"	= sélection du niveau 2 (ISO 9995-7)"},
/* 21E8 */ { "FLÈCHE BLANCHE VERS LA DROITE","	= sélection de groupe (ISO 9995-7)"},
/* 21E9 */ { "FLÈCHE BLANCHE VERS LE BAS",NULL},
/* 21EA */ { "FLÈCHE BLANCHE D'UN TAQUET VERS LE HAUT","	= verrouillage des majuscules"},
/* 21EB */ { "FLÈCHE BLANCHE VERS LE HAUT SUR SOCLE","	= verrouillage niveau 2"},
/* 21EC */ { "FLÈCHE BLANCHE VERS LE HAUT SUR SOCLE ET TRAIT HORIZONTAL","	= verrouillage des majuscules\n"
	"	* pour la norme ISO/CEI 9995-7, cette fonction est l'équivalent de 21EB sur certains claviers et pour certaines touches\n"
	"	x (flèche blanche d'un taquet vers le haut barrée horizontalement - 2BB8)"},
/* 21ED */ { "FLÈCHE BLANCHE VERS LE HAUT SUR SOCLE ET BARRE VERTICALE","	= verrouillage numérique"},
/* 21EE */ { "DOUBLE FLÈCHE BLANCHE VERS LE HAUT","	= sélection du niveau 3"},
/* 21EF */ { "DOUBLE FLÈCHE BLANCHE VERS LE HAUT SUR SOCLE","	= verrouillage niveau 3"},
/* 21F0 */ { "FLÈCHE BLANCHE D'UN MUR VERS LA DROITE","	= verrouillage de groupe"},
/* 21F1 */ { "FLÈCHE NORD-OUEST EN ENCOIGNURE","	= début"},
/* 21F2 */ { "FLÈCHE SUD-EST EN ENCOIGNURE","	= fin"},
/* 21F3 */ { "FLÈCHE BLANCHE HAUT-BAS","	= défilement\n"
	"	x (flèche blanche gauche-droite - 2B04)"},
/* 21F4 */ { "FLÈCHE VERS LA DROITE À PETIT CERCLE","	x (flèche vers la gauche à petit cercle - 2B30)"},
/* 21F5 */ { "FLÈCHE VERS LE BAS À GAUCHE D'UNE FLÈCHE VERS LE HAUT",NULL},
/* 21F6 */ { "TROIS FLÈCHES VERS LA DROITE","	x (trois flèches vers la gauche - 2B31)"},
/* 21F7 */ { "FLÈCHE VERS LA GAUCHE BARRÉE VERTICALEMENT",NULL},
/* 21F8 */ { "FLÈCHE VERS LA DROITE BARRÉE VERTICALEMENT","	= fonction partielle en notation Z"},
/* 21F9 */ { "FLÈCHE GAUCHE-DROITE BARRÉE VERTICALEMENT","	= relation partielle en notation Z"},
/* 21FA */ { "FLÈCHE VERS LA GAUCHE BARRÉE DEUX FOIS VERTICALEMENT",NULL},
/* 21FB */ { "FLÈCHE VERS LA DROITE BARRÉE DEUX FOIS VERTICALEMENT","	= fonction finie en notation Z"},
/* 21FC */ { "FLÈCHE GAUCHE-DROITE BARRÉE DEUX FOIS VERTICALEMENT","	= relation finie en notation Z"},
/* 21FD */ { "FLÈCHE VERS LA GAUCHE À TÊTE CREUSE",NULL},
/* 21FE */ { "FLÈCHE VERS LA DROITE À TÊTE CREUSE",NULL},
/* 21FF */ { "FLÈCHE GAUCHE-DROITE À TÊTES CREUSES",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_22[] = {
/* 2200 */ { "POUR TOUT","	= quel que soit\n"
	"	= quantificateur universel, quanteur universel"},
/* 2201 */ { "COMPLÉMENT","	x (lettre latine c étiré - 0297)"},
/* 2202 */ { "DÉRIVÉE PARTIELLE","	= d rond"},
/* 2203 */ { "IL EXISTE","	= quantificateur existentiel, quanteur existentiel"},
/* 2204 */ { "IL N'EXISTE PAS","	: 2203 0338"},
/* 2205 */ { "ENSEMBLE VIDE","	* s'utilise en linguistique pour indiquer un morphème nul ou un « zéro » phonologique\n"
	"	x (lettre majuscule latine o barré obliquement - 00D8)\n"
	"	x (symbole diamètre - 2300)\n"
	"	~ 2205 FE00 sous la forme d'un zéro avec une longue barre diagonale couvrante"},
/* 2206 */ { "INCRÉMENT","	= laplacien (ou opérateur laplacien)\n"
	"	= différence avant\n"
	"	= différence symétrique (dans la théorie des ensembles)\n"
	"	* d'autres symboles peuvent être utilisés pour la différence symétrique\n"
	"	x (lettre majuscule grecque delta - 0394)\n"
	"	x (triangle blanc pointant vers le haut - 25B3)"},
/* 2207 */ { "NABLA","	= différence arrière\n"
	"	= gradient d'une fonction (en analyse vectorielle)\n"
	"	= connexion de Koszul (en géométrie différentielle)\n"
	"	* utilisé pour l'opérateur laplacien avec un exposant 2\n"
	"	* a été temporairement surnommé avec malice « atled » (équivalent dextroverse de « delta ») par James Maxwell\n"
	"	x (triangle blanc pointant vers le bas - 25BD)"},
/* 2208 */ { "APPARTIENT À",NULL},
/* 2209 */ { "N'APPARTIENT PAS À","	: 2208 0338"},
/* 220A */ { "PETIT APPARTIENT À","	* trouve son origine dans les « fontes pi » mathématiques ; il ne s'agit pas de l'epsilon normal\n"
	"	x (symbole grec epsilon lunaire - 03F5)"},
/* 220B */ { "CONTIENT COMME ÉLÉMENT",NULL},
/* 220C */ { "NE CONTIENT PAS COMME ÉLÉMENT","	: 220B 0338"},
/* 220D */ { "PETIT CONTIENT COMME ÉLÉMENT","	x (symbole grec epsilon lunaire réfléchi - 03F6)"},
/* 220E */ { "CE QU'IL FALLAIT DÉMONTRER","	= CQFD\n"
	"	x (puce triangulaire - 2023)\n"
	"	x (rectangle vertical noir - 25AE)"},
/* 220F */ { "PRODUIT DE LA FAMILLE","	= signe produit\n"
	"	x (lettre majuscule grecque pi - 03A0)"},
/* 2210 */ { "COPRODUIT DE LA FAMILLE","	= signe coproduit"},
/* 2211 */ { "SOMMATION DE LA FAMILLE","	= signe somme\n"
	"	x (lettre majuscule grecque sigma - 03A3)\n"
	"	x (sommation de la famille ajouré - 2140)"},
/* 2212 */ { "SIGNE MOINS","	= soustraction\n"
	"	x (trait d'union-signe moins - 002D)\n"
	"	x (signe moins épais - 2796)"},
/* 2213 */ { "SIGNE MOINS-OU-PLUS","	x (signe plus-ou-moins - 00B1)"},
/* 2214 */ { "PLUS POINTÉ",NULL},
/* 2215 */ { "BARRE OBLIQUE DE DIVISION","	* opérateur de division générique\n"
	"	x (barre oblique - 002F)\n"
	"	x (barre de fraction - 2044)\n"
	"	x (diagonale mathématique ascendante - 27CB)"},
/* 2216 */ { "DIFFÉRENCE D'ENSEMBLES","	x (barre oblique inversée - 005C)\n"
	"	x (diagonale mathématique descendante - 27CD)\n"
	"	x (opérateur barre oblique inversée - 29F5)"},
/* 2217 */ { "OPÉRATEUR ASTÉRISQUE","	= produit de convolution\n"
	"	* peut servir à représenter l'astérisque téléphonique présent sur les claviers\n"
	"	x (astérisque - 002A)"},
/* 2218 */ { "OPÉRATEUR ROND","	= fonction composée\n"
	"	x (symbole degré - 00B0)\n"
	"	x (signe d'abréviation dévanâgarî - 0970)\n"
	"	x (puce blanche - 25E6)\n"
	"	x (signe d'abréviation avestique - 10B39)"},
/* 2219 */ { "OPÉRATEUR PUCE","	x (point médian - 00B7)\n"
	"	x (puce - 2022)\n"
	"	x (point de conduite simple - 2024)"},
/* 221A */ { "RACINE CARRÉE","	= radical\n"
	"	x (coche - 2713)"},
/* 221B */ { "RACINE CUBIQUE","	x (racine cubique arabo-indienne - 0606)"},
/* 221C */ { "RACINE QUATRIÈME","	x (racine quatrième arabo-indienne - 0607)"},
/* 221D */ { "PROPORTIONNEL À","	x (lettre minuscule grecque alpha - 03B1)"},
/* 221E */ { "INFINI",NULL},
/* 221F */ { "ANGLE DROIT","	= avec (dans la notation des échecs)\n"
	"	x (angle droit réfléchi - 2BFE)"},
/* 2220 */ { "ANGLE","	* utilisé dans des contextes astrologiques pour l'aspect semi-carré\n"
	"	x (angle aigu - 299F)"},
/* 2221 */ { "ANGLE MESURÉ",NULL},
/* 2222 */ { "ANGLE SPHÉRIQUE","	= arc angulaire"},
/* 2223 */ { "EST UN DIVISEUR DE","	= tel que\n"
	"	= tige APL\n"
	"	x (barre verticale - 007C)\n"
	"	x (lettre latine clic dental - 01C0)"},
/* 2224 */ { "N'EST PAS UN DIVISEUR DE","	: 2223 0338"},
/* 2225 */ { "PARALLÈLE À","	x (lettre latine clic latéral - 01C1)\n"
	"	x (double ligne verticale - 2016)"},
/* 2226 */ { "NON PARALLÈLE À","	: 2225 0338"},
/* 2227 */ { "ET LOGIQUE","	= conjonction\n"
	"	x (et logique de la famille - 22C0)\n"
	"	x (pointe de flèche vers le haut - 2303)\n"
	"	x (et pointé - 27D1)"},
/* 2228 */ { "OU LOGIQUE","	= disjonction non exclusive (« vel » latin)\n"
	"	x (ou logique de la famille - 22C1)\n"
	"	x (pointe de flèche vers le bas - 2304)\n"
	"	x (ou avec point inscrit - 27C7)"},
/* 2229 */ { "INTERSECTION","	* peut se lire « inter » (« A inter B »)\n"
	"	x (intersection de la famille - 22C2)\n"
	"	~ 2229 FE00 avec des empattements"},
/* 222A */ { "UNION","	= réunion\n"
	"	x (réunion de la famille - 22C3)\n"
	"	~ 222A FE00 avec des empattements"},
/* 222B */ { "INTÉGRALE","	x (lettre minuscule latine ech - 0283)"},
/* 222C */ { "INTÉGRALE DOUBLE","	# 222B 222B"},
/* 222D */ { "INTÉGRALE TRIPLE","	x (intégrale quadruple - 2A0C)\n"
	"	# 222B 222B 222B"},
/* 222E */ { "INTÉGRALE DE CONTOUR","	x (intégrale autour d'un opérateur point - 2A15)"},
/* 222F */ { "INTÉGRALE DE SURFACE","	# 222E 222E"},
/* 2230 */ { "INTÉGRALE DE VOLUME","	# 222E 222E 222E"},
/* 2231 */ { "INTÉGRALE SENS HORAIRE",NULL},
/* 2232 */ { "INTÉGRALE DE CONTOUR SENS HORAIRE",NULL},
/* 2233 */ { "INTÉGRALE DE CONTOUR SENS ANTIHORAIRE","	* les flèches sens horaire et sens antihoraire ne sont pas inversées lors de la composition en miroir, alors que le signe normal de l'intégrale sera réfléchi"},
/* 2234 */ { "PAR CONSÉQUENT","	= donc\n"
	"	x (site historique - 26EC)"},
/* 2235 */ { "PARCE QUE",NULL},
/* 2236 */ { "RAPPORT","	* préféré à 003A pour le signe de division ou d'échelle dans les emplois mathématiques\n"
	"	x (deux-points - 003A)"},
/* 2237 */ { "PROPORTION",NULL},
/* 2238 */ { "MOINS POINTÉ","	= soustraction saturée\n"
	"	* parfois présenté comme le symbole pour la différence symétrique de deux ensembles, mais l'emploi de 2206 est recommandé pour cet usage"},
/* 2239 */ { "EXCÈS",NULL},
/* 223A */ { "PROPORTION GÉOMÉTRIQUE",NULL},
/* 223B */ { "HOMOTHÉTIQUE","	x (opérateur tilde avec points ascendants - 2A6B)"},
/* 223C */ { "OPÉRATEUR TILDE","	= varie avec (proportionnel à)\n"
	"	= similaire à\n"
	"	= non\n"
	"	= cycle\n"
	"	= équivalent à\n"
	"	= tilde APL\n"
	"	x (tilde - 007E)\n"
	"	x (signe négation - 00AC)\n"
	"	x (petit tilde - 02DC)"},
/* 223D */ { "OPÉRATEUR TILDE RÉFLÉCHI","	= s couché\n"
	"	* le tilde renversé et le s couché sont des variantes de glyphes"},
/* 223E */ { "S COUCHÉ RENVERSÉ","	= le plus positif"},
/* 223F */ { "SINUSOÏDE","	= courant alternatif"},
/* 2240 */ { "PRODUIT EN COURONNE",NULL},
/* 2241 */ { "NON TILDE","	= pas équivalent à\n"
	"	: 223C 0338"},
/* 2242 */ { "MOINS TILDE",NULL},
/* 2243 */ { "ASYMPTOTIQUEMENT ÉGAL À",NULL},
/* 2244 */ { "NON ASYMPTOTIQUEMENT ÉGAL À","	: 2243 0338"},
/* 2245 */ { "APPROXIMATIVEMENT ÉGAL À","	x (approximativement égal ou égal à - 2A70)"},
/* 2246 */ { "APPROXIMATIVEMENT MAIS NON STRICTEMENT ÉGAL À",NULL},
/* 2247 */ { "NI APPROXIMATIVEMENT NI STRICTEMENT ÉGAL À","	: 2245 0338"},
/* 2248 */ { "PRESQUE ÉGAL À","	= asymptotique à"},
/* 2249 */ { "NON PRESQUE ÉGAL À","	: 2248 0338"},
/* 224A */ { "PRESQUE ÉGAL OU ÉGAL À",NULL},
/* 224B */ { "TRIPLE TILDE",NULL},
/* 224C */ { "ENTIÈREMENT ÉGAL À","	* le tilde renversé et le s couché sont des variantes de glyphes"},
/* 224D */ { "ÉQUIVALENT À",NULL},
/* 224E */ { "GÉOMÉTRIQUEMENT ÉQUIVALENT À",NULL},
/* 224F */ { "DIFFÉRENCE ENTRE",NULL},
/* 2250 */ { "TEND VERS LA LIMITE",NULL},
/* 2251 */ { "GÉOMÉTRIQUEMENT ÉGAL À",NULL},
/* 2252 */ { "APPROXIMATIVEMENT ÉGAL À OU IMAGE DE","	= presque égal à"},
/* 2253 */ { "IMAGE DE OU APPROXIMATIVEMENT ÉGAL À",NULL},
/* 2254 */ { "DEUX-POINTS ÉGAL",NULL},
/* 2255 */ { "ÉGAL DEUX-POINTS",NULL},
/* 2256 */ { "ROND DANS ÉGAL",NULL},
/* 2257 */ { "ÉGAL AVEC ROND EN CHEF","	= approximativement égal à"},
/* 2258 */ { "CORRESPOND À",NULL},
/* 2259 */ { "ESTIME","	= correspond à"},
/* 225A */ { "ÉQUIANGULAIRE À",NULL},
/* 225B */ { "ÉGAL AVEC ÉTOILE EN CHEF",NULL},
/* 225C */ { "ÉGAL DELTA","	= équiangulaire\n"
	"	= égal par définition à"},
/* 225D */ { "ÉGAL PAR DÉFINITION À",NULL},
/* 225E */ { "MESURÉ PAR",NULL},
/* 225F */ { "ÉGALITÉ EN DOUTE",NULL},
/* 2260 */ { "PAS ÉGAL À","	x (signe égal - 003D)\n"
	"	x (lettre latine clic alvéolaire - 01C2)\n"
	"	: 003D 0338"},
/* 2261 */ { "IDENTIQUE À","	= congru à, identiteur"},
/* 2262 */ { "NON IDENTIQUE À","	: 2261 0338"},
/* 2263 */ { "STRICTEMENT ÉQUIVALENT À",NULL},
/* 2264 */ { "INFÉRIEUR OU ÉGAL À","	x (signe inférieur à - 003C)"},
/* 2265 */ { "SUPÉRIEUR OU ÉGAL À","	x (signe supérieur à - 003E)"},
/* 2266 */ { "INFÉRIEUR À SUR ÉGAL À",NULL},
/* 2267 */ { "SUPÉRIEUR À SUR ÉGAL À",NULL},
/* 2268 */ { "INFÉRIEUR MAIS PAS ÉGAL À","	x (inférieur à et pas égal à en une ligne - 2A87)\n"
	"	~ 2268 FE00 avec une barre verticale"},
/* 2269 */ { "SUPÉRIEUR MAIS PAS ÉGAL À","	x (supérieur à et pas égal à en une ligne - 2A88)\n"
	"	~ 2269 FE00 avec une barre verticale"},
/* 226A */ { "TRÈS INFÉRIEUR À","	x (guillemet gauche - 00AB)"},
/* 226B */ { "TRÈS SUPÉRIEUR À","	x (guillemet droit - 00BB)"},
/* 226C */ { "ENTRE",NULL},
/* 226D */ { "NON ÉQUIVALENT À","	: 224D 0338"},
/* 226E */ { "PAS INFÉRIEUR À","	: 003C 0338"},
/* 226F */ { "PAS SUPÉRIEUR À","	: 003E 0338"},
/* 2270 */ { "NI INFÉRIEUR NI ÉGAL À","	: 2264 0338"},
/* 2271 */ { "NI SUPÉRIEUR NI ÉGAL À","	: 2265 0338"},
/* 2272 */ { "INFÉRIEUR OU ÉQUIVALENT À","	~ 2272 FE00 suivant l'inclinaison de la jambe inférieure"},
/* 2273 */ { "SUPÉRIEUR OU ÉQUIVALENT À","	~ 2273 FE00 suivant l'inclinaison de la jambe inférieure"},
/* 2274 */ { "NI INFÉRIEUR NI ÉQUIVALENT À","	: 2272 0338"},
/* 2275 */ { "NI SUPÉRIEUR NI ÉQUIVALENT À","	: 2273 0338"},
/* 2276 */ { "INFÉRIEUR OU SUPÉRIEUR À",NULL},
/* 2277 */ { "SUPÉRIEUR OU INFÉRIEUR À",NULL},
/* 2278 */ { "NI INFÉRIEUR NI SUPÉRIEUR À","	: 2276 0338"},
/* 2279 */ { "NI SUPÉRIEUR NI INFÉRIEUR À","	: 2277 0338"},
/* 227A */ { "PRÉCÈDE","	= est dominé (notation de Hardy)\n"
	"	x (précède sous relation - 22B0)"},
/* 227B */ { "SUIT","	x (suit sous relation - 22B1)"},
/* 227C */ { "PRÉCÈDE OU EST ÉGAL À",NULL},
/* 227D */ { "SUIT OU EST ÉGAL À",NULL},
/* 227E */ { "PRÉCÈDE OU EST ÉQUIVALENT À",NULL},
/* 227F */ { "SUIT OU EST ÉQUIVALENT À",NULL},
/* 2280 */ { "NE PRÉCÈDE PAS","	: 227A 0338"},
/* 2281 */ { "NE SUIT PAS","	: 227B 0338"},
/* 2282 */ { "SOUS-ENSEMBLE DE","	x (crampillon couché gauche - 2E26)"},
/* 2283 */ { "SUR-ENSEMBLE DE","	x (crampillon couché droit - 2E27)"},
/* 2284 */ { "PAS UN SOUS-ENSEMBLE DE","	: 2282 0338"},
/* 2285 */ { "PAS UN SUR-ENSEMBLE DE","	: 2283 0338"},
/* 2286 */ { "SOUS-ENSEMBLE DE OU ÉGAL À",NULL},
/* 2287 */ { "SUR-ENSEMBLE DE OU ÉGAL À",NULL},
/* 2288 */ { "NI UN SOUS-ENSEMBLE DE NI ÉGAL À","	: 2286 0338"},
/* 2289 */ { "NI UN SUR-ENSEMBLE DE NI ÉGAL À","	: 2287 0338"},
/* 228A */ { "SOUS-ENSEMBLE DE MAIS PAS ÉGAL À","	~ 228A FE00 avec une barre à travers les éléments inférieurs"},
/* 228B */ { "SUR-ENSEMBLE DE MAIS PAS ÉGAL À","	~ 228B FE00 avec une barre à travers les éléments inférieurs"},
/* 228C */ { "MULTIENSEMBLE",NULL},
/* 228D */ { "MULTIPLICATION DE MULTIENSEMBLE","	x (opérateur union n-aire pointé - 2A03)\n"
	"	x (intersection pointée - 2A40)"},
/* 228E */ { "UNION DE MULTIENSEMBLE","	= addition de sacs en notation Z\n"
	"	x (opérateur union n-aire avec plus - 2A04)"},
/* 228F */ { "IMAGE CARRÉE DE",NULL},
/* 2290 */ { "ORIGINAL CARRÉ DE",NULL},
/* 2291 */ { "IMAGE CARRÉE DE OU ÉGAL À",NULL},
/* 2292 */ { "ORIGINAL CARRÉ DE OU ÉGAL À",NULL},
/* 2293 */ { "CHAPEAU CARRÉ","	x (opérateur intersection carré n-aire - 2A05)\n"
	"	~ 2293 FE00 avec des empattements"},
/* 2294 */ { "COUPE CARRÉE","	x (opérateur union carré n-aire - 2A06)\n"
	"	~ 2294 FE00 avec des empattements"},
/* 2295 */ { "PLUS CERCLÉ","	= somme directe\n"
	"	= vecteur entrant dans le plan\n"
	"	x (opérateur plus cerclé n-aire - 2A01)\n"
	"	x (symbole alchimique du vert-de-gris - 1F728)\n"
	"	~ 2295 FE00 avec une bordure blanche"},
/* 2296 */ { "MOINS CERCLÉ","	= différence symétrique\n"
	"	x (cercle avec barre horizontale - 29B5)\n"
	"	x (symbole alchimique du sel - 1F714)"},
/* 2297 */ { "MULTIPLIÉ PAR CERCLÉ","	= produit tensoriel\n"
	"	= vecteur entrant dans le plan\n"
	"	x (voies croisées cerclées - 26D2)\n"
	"	x (opérateur de multiplication n-aire cerclé - 2A02)\n"
	"	x (x cerclé - 2BBE)\n"
	"	x (part de fortune - 1F774)\n"
	"	~ 2297 FE00 avec une bordure blanche"},
/* 2298 */ { "BARRE OBLIQUE DE DIVISION CERCLÉE",NULL},
/* 2299 */ { "OPÉRATEUR POINT CERCLÉ","	= produit direct\n"
	"	= vecteur sortant du plan\n"
	"	x (lettre latine clic bilabial - 0298)\n"
	"	x (soleil - 2609)\n"
	"	x (opérateur point cerclé n-aire - 2A00)"},
/* 229A */ { "OPÉRATEUR ROND CERCLÉ","	x (symbole de fonction apl beigne - 233E)\n"
	"	x (deux cercles concentriques - 25CE)"},
/* 229B */ { "OPÉRATEUR ASTÉRISQUE CERCLÉ","	x (symbole de fonction apl citron - 235F)"},
/* 229C */ { "ÉGAL CERCLÉ","	= pas de modification (symbole utilisé pour les licences Creative Commons)\n"
	"	x (cc cerclé - 1F16D)\n"
	"	~ 229C FE00 avec un signe égal touchant le cercle"},
/* 229D */ { "TIRET CERCLÉ",NULL},
/* 229E */ { "PLUS ENCADRÉ",NULL},
/* 229F */ { "MOINS ENCADRÉ",NULL},
/* 22A0 */ { "MULTIPLIÉ PAR ENCADRÉ","	x (case de bulletin marquée d'un x - 2612)\n"
	"	x (sautoir encadré - 26DD)\n"
	"	x (symbole alchimique du mois - 1F771)"},
/* 22A1 */ { "OPÉRATEUR POINT ENCADRÉ","	x (symbole alchimique de l'urine - 1F755)\n"
	"	x (point droit partiellement encadré - 1FBBC)"},
/* 22A2 */ { "TAQUET À DROITE","	= tourniquet, portillon\n"
	"	= prouve, implique, fournit\n"
	"	= réductible"},
/* 22A3 */ { "TAQUET À GAUCHE","	= tourniquet inversé, portillon inversé\n"
	"	= non-théorème, ne fournit pas"},
/* 22A4 */ { "TAQUET VERS LE BAS","	= dessus\n"
	"	x (signe d'interpolation élevé - 2E06)\n"
	"	x (symbole alchimique du creuset-4 - 1F768)"},
/* 22A5 */ { "TAQUET VERS LE HAUT","	= base, dessous\n"
	"	x (perpendiculaire à - 27C2)"},
/* 22A6 */ { "ASSERTION","	= se réduit à"},
/* 22A7 */ { "MODÉLISE","	= est valide (en logique mathématique)"},
/* 22A8 */ { "VRAI","	= l'énoncé est vrai\n"
	"	= valable\n"
	"	= est une tautologie\n"
	"	= satisfait"},
/* 22A9 */ { "OBLIGE",NULL},
/* 22AA */ { "BARRE VERTICALE TRIPLE AVEC TOURNIQUET À DROITE",NULL},
/* 22AB */ { "BARRE VERTICALE DOUBLE AVEC TOURNIQUET À DROITE DOUBLE",NULL},
/* 22AC */ { "NE PROUVE PAS","	: 22A2 0338"},
/* 22AD */ { "PAS VRAI","	: 22A8 0338"},
/* 22AE */ { "N'OBLIGE PAS","	: 22A9 0338"},
/* 22AF */ { "NON-BARRE VERTICALE DOUBLE AVEC TOURNIQUET À DROITE DOUBLE","	: 22AB 0338"},
/* 22B0 */ { "PRÉCÈDE SOUS RELATION","	x (précède - 227A)"},
/* 22B1 */ { "SUIT SOUS RELATION","	x (suit - 227B)"},
/* 22B2 */ { "SOUS-GROUPE NORMAL DE","	x (pointeur blanc vers la gauche - 25C5)"},
/* 22B3 */ { "CONTIENT COMME SOUS-GROUPE NORMAL","	x (pointeur blanc vers la droite - 25BB)"},
/* 22B4 */ { "SOUS-GROUPE NORMAL DE OU ÉGAL À",NULL},
/* 22B5 */ { "CONTIENT COMME SOUS-GROUPE NORMAL OU ÉGAL À",NULL},
/* 22B6 */ { "ORIGINAL DE",NULL},
/* 22B7 */ { "IMAGE DE",NULL},
/* 22B8 */ { "MULTIJECTION","	= multimap, liste associative"},
/* 22B9 */ { "MATRICE HERMITIENNE CONJUGUÉE",NULL},
/* 22BA */ { "INTERCALE",NULL},
/* 22BB */ { "OU EXCLUSIF","	= disjonction exclusive (« aut » latin)\n"
	"	x (demi-sextile - 26BA)"},
/* 22BC */ { "NON ET","	x (projective - 2305)\n"
	"	x (quinconce - 26BB)"},
/* 22BD */ { "NON OU",NULL},
/* 22BE */ { "ANGLE DROIT AVEC ARC",NULL},
/* 22BF */ { "TRIANGLE RECTANGLE",NULL},
/* 22C0 */ { "ET LOGIQUE DE LA FAMILLE","	* représente aussi le quantificateur universel\n"
	"	x (et logique - 2227)"},
/* 22C1 */ { "OU LOGIQUE DE LA FAMILLE","	* représente aussi le quantificateur existentiel\n"
	"	x (ou logique - 2228)"},
/* 22C2 */ { "INTERSECTION DE LA FAMILLE","	= intersection généralisée en notation Z\n"
	"	x (intersection - 2229)"},
/* 22C3 */ { "RÉUNION DE LA FAMILLE","	= union généralisée en notation Z\n"
	"	x (union - 222A)"},
/* 22C4 */ { "OPÉRATEUR LOSANGE","	x (losange blanc - 25C7)\n"
	"	x (petit losange noir - 2B29)"},
/* 22C5 */ { "OPÉRATEUR POINT","	* préféré à 00B7 pour noter la multiplication\n"
	"	x (point médian - 00B7)"},
/* 22C6 */ { "OPÉRATEUR ÉTOILE","	* APL\n"
	"	x (étoile à cinq branches arabe - 066D)\n"
	"	x (étoile noire - 2605)\n"
	"	x (étoile moyenne blanche - 2B50)"},
/* 22C7 */ { "DIVISÉ MULTIPLIÉ","	* signe ambigu combinant deux opérateurs\n"
	"	x (signe plus-ou-moins - 00B1)\n"
	"	x (signe de multiplication - 00D7)\n"
	"	x (signe de division - 00F7)\n"
	"	x (x de multiplication - 2715)"},
/* 22C8 */ { "NŒUD PAPILLON","	x (nœud papillon roc - 2445)"},
/* 22C9 */ { "PRODUIT SEMI-DIRECT À GAUCHE DE FACTEUR NORMAL",NULL},
/* 22CA */ { "PRODUIT SEMI-DIRECT À DROITE DE FACTEUR NORMAL",NULL},
/* 22CB */ { "PRODUIT SEMI-DIRECT À GAUCHE",NULL},
/* 22CC */ { "PRODUIT SEMI-DIRECT À DROITE","	x (lambda d'insertion - 2041)"},
/* 22CD */ { "ÉGAL TILDE RENVERSÉ",NULL},
/* 22CE */ { "OU LOGIQUE RECOURBÉ",NULL},
/* 22CF */ { "ET LOGIQUE RECOURBÉ",NULL},
/* 22D0 */ { "SOUS-ENSEMBLE DOUBLE",NULL},
/* 22D1 */ { "SUR-ENSEMBLE DOUBLE",NULL},
/* 22D2 */ { "INTERSECTION DOUBLE",NULL},
/* 22D3 */ { "UNION DOUBLE",NULL},
/* 22D4 */ { "FOURCHE","	= intersection stricte"},
/* 22D5 */ { "ÉGAL ET PARALLÈLE À","	x (carré de visualisation - 2317)"},
/* 22D6 */ { "INFÉRIEUR À AVEC POINT",NULL},
/* 22D7 */ { "SUPÉRIEUR À AVEC POINT",NULL},
/* 22D8 */ { "CONSIDÉRABLEMENT INFÉRIEUR À",NULL},
/* 22D9 */ { "CONSIDÉRABLEMENT SUPÉRIEUR À",NULL},
/* 22DA */ { "INFÉRIEUR OU ÉGAL OU SUPÉRIEUR À","	~ 22DA FE00 avec un égal incliné"},
/* 22DB */ { "SUPÉRIEUR OU ÉGAL OU INFÉRIEUR À","	~ 22DB FE00 avec un égal incliné"},
/* 22DC */ { "ÉGAL OU INFÉRIEUR À",NULL},
/* 22DD */ { "ÉGAL OU SUPÉRIEUR À",NULL},
/* 22DE */ { "ÉGAL OU PRÉCÈDE",NULL},
/* 22DF */ { "ÉGAL OU SUIT",NULL},
/* 22E0 */ { "NI PRÉCÉDANT NI ÉGAL À","	: 227C 0338"},
/* 22E1 */ { "NI SUIVANT NI ÉGAL À","	: 227D 0338"},
/* 22E2 */ { "NI IMAGE CARRÉE DE NI ÉGAL À","	: 2291 0338"},
/* 22E3 */ { "NI ORIGINAL CARRÉ DE NI ÉGAL À","	: 2292 0338"},
/* 22E4 */ { "IMAGE CARRÉE OU DIFFÉRENT DE",NULL},
/* 22E5 */ { "ORIGINAL CARRÉ OU DIFFÉRENT DE",NULL},
/* 22E6 */ { "INFÉRIEUR MAIS NON ÉQUIVALENT À",NULL},
/* 22E7 */ { "SUPÉRIEUR MAIS NON ÉQUIVALENT À",NULL},
/* 22E8 */ { "PRÉCÈDE MAIS NON ÉQUIVALENT À",NULL},
/* 22E9 */ { "SUIT MAIS NON ÉQUIVALENT À",NULL},
/* 22EA */ { "PAS UN SOUS-GROUPE NORMAL DE","	: 22B2 0338"},
/* 22EB */ { "NE CONTIENT PAS COMME SOUS-GROUPE NORMAL","	: 22B3 0338"},
/* 22EC */ { "PAS UN SOUS-GROUPE NORMAL DE NI ÉGAL À","	: 22B4 0338"},
/* 22ED */ { "NI ÉGAL NI CONTENANT COMME SOUS-GROUPE NORMAL","	: 22B5 0338"},
/* 22EE */ { "TROIS POINTS SUSPENDUS","	x (trois-points vertical - 205D)\n"
	"	x (points de suspension - 2026)\n"
	"	x (forme de présentation de points de suspension verticaux - FE19)"},
/* 22EF */ { "TROIS POINTS MÉDIANS",NULL},
/* 22F0 */ { "TROIS POINTS DIAGONAUX VERS LE COIN HAUT À DROITE",NULL},
/* 22F1 */ { "TROIS POINTS DIAGONAUX VERS LE COIN BAS À DROITE",NULL},
/* 22F2 */ { "APPARTIENT À AVEC LONG TRAIT HORIZONTAL",NULL},
/* 22F3 */ { "APPARTIENT À AVEC BARRE VERTICALE AU BOUT DU TRAIT HORIZONTAL",NULL},
/* 22F4 */ { "PETIT APPARTIENT À AVEC BARRE VERTICALE AU BOUT DU TRAIT HORIZONTAL",NULL},
/* 22F5 */ { "APPARTIENT À AVEC POINT EN CHEF",NULL},
/* 22F6 */ { "APPARTIENT À AVEC TRAIT EN CHEF",NULL},
/* 22F7 */ { "PETIT APPARTIENT À AVEC TRAIT EN CHEF",NULL},
/* 22F8 */ { "APPARTIENT À AVEC TRAIT SOUSCRIT",NULL},
/* 22F9 */ { "APPARTIENT À AVEC DEUX TRAITS HORIZONTAUX",NULL},
/* 22FA */ { "CONTIENT AVEC LONG TRAIT HORIZONTAL",NULL},
/* 22FB */ { "CONTIENT AVEC BARRE VERTICALE AU BOUT DU TRAIT HORIZONTAL",NULL},
/* 22FC */ { "PETIT CONTIENT AVEC BARRE VERTICALE AU BOUT DU TRAIT HORIZONTAL",NULL},
/* 22FD */ { "CONTIENT AVEC TRAIT EN CHEF",NULL},
/* 22FE */ { "PETIT CONTIENT AVEC TRAIT EN CHEF",NULL},
/* 22FF */ { "ÉLÉMENT D'UN SAC EN NOTATION Z","	= appartient à un multi-ensemble"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_23[] = {
/* 2300 */ { "SYMBOLE DIAMÈTRE","	x (lettre minuscule latine o barré obliquement - 00F8)\n"
	"	x (ensemble vide - 2205)"},
/* 2301 */ { "FLÈCHE ÉLECTRIQUE","	* tiré de la norme ISO 2047\n"
	"	* symbole représentant la fin de transmission"},
/* 2302 */ { "MAISON",NULL},
/* 2303 */ { "POINTE DE FLÈCHE VERS LE HAUT","	x (accent circonflexe - 005E)\n"
	"	x (lettre modificative pointe de flèche vers le haut - 02C4)\n"
	"	x (chevron d'insertion - 2038)\n"
	"	x (et logique - 2227)"},
/* 2304 */ { "POINTE DE FLÈCHE VERS LE BAS","	x (lettre modificative pointe de flèche vers le bas - 02C5)\n"
	"	x (ou logique - 2228)\n"
	"	x (fraisage - 2335)"},
/* 2305 */ { "PROJECTIVE","	x (non et - 22BC)"},
/* 2306 */ { "PERSPECTIVE",NULL},
/* 2307 */ { "LIGNE ONDULÉE","	x (ligne verticale ondulée - 2E3E)\n"
	"	x (tiret ondulé - 3030)"},
/* 2308 */ { "PLAFOND À GAUCHE","	= montant APL\n"
	"	x (anglet supérieur gauche - 2E22)\n"
	"	x (anglet gauche - 300C)"},
/* 2309 */ { "PLAFOND À DROITE","	x (diacritique symbole de rente - 20E7)\n"
	"	x (anglet supérieur droit - 2E23)"},
/* 230A */ { "PLANCHER À GAUCHE","	= descendant APL\n"
	"	x (anglet inférieur gauche - 2E24)"},
/* 230B */ { "PLANCHER À DROITE","	x (anglet droit - 300D)\n"
	"	x (anglet inférieur droit - 2E25)"},
/* 230C */ { "REPÈRE SUD-EST","	= hirondelle sud-est\n"
	"	* ensemble de quatre repères de coupe dont les branches pointent vers les marges"},
/* 230D */ { "REPÈRE SUD-OUEST","	= hirondelle sud-ouest"},
/* 230E */ { "REPÈRE NORD-EST","	= hirondelle nord-est"},
/* 230F */ { "REPÈRE NORD-OUEST","	= hirondelle nord-ouest"},
/* 2310 */ { "SIGNE NÉGATION RÉFLÉCHI","	= début de ligne\n"
	"	x (signe négation - 00AC)"},
/* 2311 */ { "PASTILLE CARRÉE","	= Kissen (oreiller)\n"
	"	* symbole utilisé par certains ordinateurs très anciens comme délimiteur de commande\n"
	"	x (valvule à quatre branches blanche couchée - 2BCF)"},
/* 2312 */ { "ARC","	= position d'une ligne\n"
	"	x (demi-cercle supérieur - 25E0)"},
/* 2313 */ { "SEGMENT","	= position d'une surface"},
/* 2314 */ { "SECTEUR",NULL},
/* 2315 */ { "ENREGISTREUR TÉLÉPHONIQUE",NULL},
/* 2316 */ { "REPÈRE DE CALAGE","	= croix de repérage\n"
	"	x (repère de calage carré - 2BD0)"},
/* 2317 */ { "CARRÉ DE VISUALISATION","	x (égal et parallèle à - 22D5)"},
/* 2318 */ { "SYMBOLE DE POINT D'INTÉRÊT","	= touche commande (1.0)\n"
	"	= touche du système d'exploitation (ISO 9995-7)"},
/* 2319 */ { "SIGNE NÉGATION CULBUTÉ","	= repère de ligne"},
/* 231A */ { "MONTRE","	x (réveille-matin - 23F0)\n"
	"	x (cadran d'horloge à une heure - 1F550)"},
/* 231B */ { "SABLIER","	= symbole alchimique de l'heure"},
/* 231C */ { "COIN NORD-OUEST","	x (anglet de substitution - 2E00)\n"
	"	x (anglet supérieur gauche - 2E22)"},
/* 231D */ { "COIN NORD-EST",NULL},
/* 231E */ { "COIN SUD-OUEST",NULL},
/* 231F */ { "COIN SUD-EST",NULL},
/* 2320 */ { "MOITIÉ SUPÉRIEURE D'INTÉGRALE","	x (rallonge d'intégrale - 23AE)"},
/* 2321 */ { "MOITIÉ INFÉRIEURE D'INTÉGRALE",NULL},
/* 2322 */ { "MOUE","	x (tirant haut - 2040)"},
/* 2323 */ { "SOURIRE","	x (tirant bas - 203F)"},
/* 2324 */ { "POINTE DE FLÈCHE VERS LE HAUT ENTRE DEUX TRAITS HORIZONTAUX","	= touche retour"},
/* 2325 */ { "TOUCHE OPTION",NULL},
/* 2326 */ { "EFFACEMENT À DROITE","	= touche d'effacement à droite"},
/* 2327 */ { "X DANS UN RECTANGLE","	= touche effacer\n"
	"	x (case de bulletin marquée d'un x - 2612)"},
/* 2328 */ { "CLAVIER","	x (clavier et souris - 1F5A6)\n"
	"	x (clavier filaire - 1F5AE)"},
/* 2329 */ { "CHEVRON POINTANT À GAUCHE","	x (signe inférieur à - 003C)\n"
	"	x (guillemet simple vers la gauche - 2039)\n"
	"	x (chevron mathématique gauche - 27E8)\n"
	"	: 3008 chevron gauche"},
/* 232A */ { "CHEVRON POINTANT À DROITE","	x (signe supérieur à - 003E)\n"
	"	x (guillemet simple vers la droite - 203A)\n"
	"	x (chevron mathématique droit - 27E9)\n"
	"	: 3009 chevron droit"},
/* 232B */ { "EFFACEMENT À GAUCHE","	= touche d'effacement à gauche, suppression arrière"},
/* 232C */ { "ANNEAU DE BENZÈNE",NULL},
/* 232D */ { "CYLINDRICITÉ",NULL},
/* 232E */ { "PROFIL HORS-TOUT",NULL},
/* 232F */ { "SYMÉTRIE",NULL},
/* 2330 */ { "COURSE TOTALE",NULL},
/* 2331 */ { "ORIGINE DE MESURE",NULL},
/* 2332 */ { "RÉTRÉCISSEMENT CONIQUE",NULL},
/* 2333 */ { "PENTE","	x (triangle rectangle inférieur gauche - 25FA)"},
/* 2334 */ { "ALÉSAGE","	x (boîte ouverte - 2423)"},
/* 2335 */ { "FRAISAGE","	x (pointe de flèche vers le bas - 2304)"},
/* 2336 */ { "SYMBOLE DE FONCTION APL RAIL","	= poutre en i"},
/* 2337 */ { "SYMBOLE DE FONCTION APL QUADRAT MINCE","	x (symbole de fonction apl quadrat - 2395)\n"
	"	x (rectangle vertical blanc - 25AF)\n"
	"	x (barre verticale blanche n-aire - 2AFF)"},
/* 2338 */ { "SYMBOLE DE FONCTION APL ÉTAGÈRE","	= baril"},
/* 2339 */ { "SYMBOLE DE FONCTION APL DOMINO",NULL},
/* 233A */ { "SYMBOLE DE FONCTION APL RIDEAUX","	x (losange blanc dans un carré - 26CB)"},
/* 233B */ { "SYMBOLE DE FONCTION APL AS","	x (petit cercle encadré - 29C7)"},
/* 233C */ { "SYMBOLE DE FONCTION APL RHÉOSTAT",NULL},
/* 233D */ { "SYMBOLE DE FONCTION APL FUSEAU",NULL},
/* 233E */ { "SYMBOLE DE FONCTION APL BEIGNE","	x (opérateur rond cerclé - 229A)\n"
	"	x (puce blanche cerclée - 29BE)"},
/* 233F */ { "SYMBOLE DE FONCTION APL COTICE BARRÉE","	x (symbole romain as - 1019A)"},
/* 2340 */ { "SYMBOLE DE FONCTION APL CONTRE-COTICE BARRÉE","	x (barre oblique inversée à traverse horizontale - 29F7)"},
/* 2341 */ { "SYMBOLE DE FONCTION APL QUADRAT OBLIQUE","	x (oblique encadrée - 29C4)"},
/* 2342 */ { "SYMBOLE DE FONCTION APL QUADRAT OBLIQUE INVERSÉE","	x (oblique inversée encadrée - 29C5)"},
/* 2343 */ { "SYMBOLE DE FONCTION APL QUADRAT PLUS PETIT QUE",NULL},
/* 2344 */ { "SYMBOLE DE FONCTION APL QUADRAT PLUS GRAND QUE",NULL},
/* 2345 */ { "SYMBOLE DE FONCTION APL BARBE VERS LA GAUCHE",NULL},
/* 2346 */ { "SYMBOLE DE FONCTION APL BARBE VERS LA DROITE",NULL},
/* 2347 */ { "SYMBOLE DE FONCTION APL QUADRAT LIBÉRAL",NULL},
/* 2348 */ { "SYMBOLE DE FONCTION APL QUADRAT CONSERVATEUR",NULL},
/* 2349 */ { "SYMBOLE DE FONCTION APL SATURNE","	x (ensemble vide réfléchi - 29B0)"},
/* 234A */ { "SYMBOLE DE FONCTION APL TAQUET VERS LE BAS BARRE SOUSCRITE","	* l'appellation recommandée pour les taquets APL suit maintenant la convention de Londres dans la norme ISO/CEI 13751:2000 (APL étendu)\n"
	"	x (taquet vers le haut - 22A5)"},
/* 234B */ { "SYMBOLE DE FONCTION APL SAPIN","	= parapluie"},
/* 234C */ { "SYMBOLE DE FONCTION APL QUADRAT CIRCONFLEXE RENVERSÉ",NULL},
/* 234D */ { "SYMBOLE DE FONCTION APL QUADRAT DELTA",NULL},
/* 234E */ { "SYMBOLE DE FONCTION APL FORMATAGE","	x (taquet vers le haut - 22A5)"},
/* 234F */ { "SYMBOLE DE FONCTION APL BARBE VERS LE HAUT",NULL},
/* 2350 */ { "SYMBOLE DE FONCTION APL QUADRAT CIEL",NULL},
/* 2351 */ { "SYMBOLE DE FONCTION APL TAQUET VERS LE HAUT BARRE EN CHEF","	x (taquet vers le bas - 22A4)\n"
	"	x (marque postale - 3012)"},
/* 2352 */ { "SYMBOLE DE FONCTION APL CAROTTE",NULL},
/* 2353 */ { "SYMBOLE DE FONCTION APL QUADRAT CIRCONFLEXE","	x (pointe de flèche vers le haut inscrite dans une boîte rectangulaire - 2BB9)"},
/* 2354 */ { "SYMBOLE DE FONCTION APL QUADRAT DEL",NULL},
/* 2355 */ { "SYMBOLE DE FONCTION APL EXÉCUTION","	x (taquet vers le bas - 22A4)"},
/* 2356 */ { "SYMBOLE DE FONCTION APL BARBE VERS LE BAS",NULL},
/* 2357 */ { "SYMBOLE DE FONCTION APL QUADRAT ENFER",NULL},
/* 2358 */ { "SYMBOLE DE FONCTION APL APOSTROPHE SOULIGNÉ",NULL},
/* 2359 */ { "SYMBOLE DE FONCTION APL DELTA SOULIGNÉ",NULL},
/* 235A */ { "SYMBOLE DE FONCTION APL LOSANGE SOULIGNÉ",NULL},
/* 235B */ { "SYMBOLE DE FONCTION APL PETIT ROND SOULIGNÉ","	= pof"},
/* 235C */ { "SYMBOLE DE FONCTION APL ROND SOULIGNÉ",NULL},
/* 235D */ { "SYMBOLE DE FONCTION APL ABAT-JOUR","	x (intersection pointée - 2A40)"},
/* 235E */ { "SYMBOLE DE FONCTION APL APOSTROPHE ENCADRÉ",NULL},
/* 235F */ { "SYMBOLE DE FONCTION APL CITRON","	x (opérateur astérisque cerclé - 229B)"},
/* 2360 */ { "SYMBOLE DE FONCTION APL BOUTON CARRÉ",NULL},
/* 2361 */ { "SYMBOLE DE FONCTION APL SÉRIEUX","	x (taquet vers le bas - 22A4)"},
/* 2362 */ { "SYMBOLE DE FONCTION APL CORBEAU","	= cigogne"},
/* 2363 */ { "SYMBOLE DE FONCTION APL SÛR",NULL},
/* 2364 */ { "SYMBOLE DE FONCTION APL MINNIE","	= hululement"},
/* 2365 */ { "SYMBOLE DE FONCTION APL DINGO","	= Goofy, braillement"},
/* 2366 */ { "SYMBOLE DE FONCTION APL FOURCHE",NULL},
/* 2367 */ { "SYMBOLE DE FONCTION APL CENTIME","	= cent"},
/* 2368 */ { "SYMBOLE DE FONCTION APL MOUE","	= sourire narquois"},
/* 2369 */ { "SYMBOLE DE FONCTION APL MOINEAU",NULL},
/* 236A */ { "SYMBOLE DE FONCTION APL BARBICHE",NULL},
/* 236B */ { "SYMBOLE DE FONCTION APL VERROU",NULL},
/* 236C */ { "SYMBOLE DE FONCTION APL ZILDE",NULL},
/* 236D */ { "SYMBOLE DE FONCTION APL ALOHA",NULL},
/* 236E */ { "SYMBOLE DE FONCTION APL POINT-VIRGULE SOULIGNÉ",NULL},
/* 236F */ { "SYMBOLE DE FONCTION APL QUADRAT DIFFÉRENT DE",NULL},
/* 2370 */ { "SYMBOLE DE FONCTION APL QUADRAT INFO","	x (signe d'incertitude - 2BD1)"},
/* 2371 */ { "SYMBOLE DE FONCTION APL NON-ET",NULL},
/* 2372 */ { "SYMBOLE DE FONCTION APL NON-OU",NULL},
/* 2373 */ { "SYMBOLE DE FONCTION APL IOTA",NULL},
/* 2374 */ { "SYMBOLE DE FONCTION APL RHÔ",NULL},
/* 2375 */ { "SYMBOLE DE FONCTION APL OMÉGA",NULL},
/* 2376 */ { "SYMBOLE DE FONCTION APL ALPHA SOULIGNÉ",NULL},
/* 2377 */ { "SYMBOLE DE FONCTION APL EPSILON SOULIGNÉ",NULL},
/* 2378 */ { "SYMBOLE DE FONCTION APL IOTA SOULIGNÉ",NULL},
/* 2379 */ { "SYMBOLE DE FONCTION APL OMÉGA SOULIGNÉ",NULL},
/* 237A */ { "SYMBOLE DE FONCTION APL ALPHA",NULL},
/* 237B */ { "SIGNE DE NON-VÉRIFICATION","	* tiré de la norme ISO 2047\n"
	"	* symbole pour « accusé de réception négatif »"},
/* 237C */ { "ANGLE DROIT AVEC FLÈCHE EN ZIGZAG VERS LE BAS",NULL},
/* 237D */ { "BOÎTE OUVERTE À ÉPAULEMENT","	* tiré de la norme ISO 9995-7\n"
	"	* symbole de touche pour « espace insécable »\n"
	"	x (boîte ouverte - 2423)"},
/* 237E */ { "SYMBOLE SONNERIE","	* tiré de la norme ISO 2047\n"
	"	x (symbole de cloche d'alarme - 1FBFA)"},
/* 237F */ { "LIGNE VERTICALE À POINT MÉDIAN","	* tiré de la norme ISO 2047\n"
	"	* symbole pour « fin de support »"},
/* 2380 */ { "SYMBOLE INSERTION",NULL},
/* 2381 */ { "SYMBOLE SOULIGNEMENT CONTINU",NULL},
/* 2382 */ { "SYMBOLE SOULIGNEMENT DISCONTINU",NULL},
/* 2383 */ { "SYMBOLE INSISTANCE","	= mise en valeur"},
/* 2384 */ { "SYMBOLE COMPOSITION",NULL},
/* 2385 */ { "CARRÉ BLANC AVEC LIGNE MÉDIANE VERTICALE","	= centrage"},
/* 2386 */ { "SYMBOLE ENTRÉE",NULL},
/* 2387 */ { "SYMBOLE DE TOUCHE ALTERNATIVE","	= touche alt"},
/* 2388 */ { "SYMBOLE BARRE À ROUE","	= contrôle\n"
	"	x (roue de dharma - 2638)"},
/* 2389 */ { "BARRE HORIZONTALE ENCOCHÉE CERCLÉE","	= pause"},
/* 238A */ { "TRIANGLE POINTE VERS LE BAS CERCLÉ","	= arrêt"},
/* 238B */ { "CERCLE BRISÉ À FLÈCHE NORD-OUEST","	= échappement"},
/* 238C */ { "SYMBOLE DÉFAIRE","	= renoncement"},
/* 238D */ { "SYMBOLE MONOSTABLE",NULL},
/* 238E */ { "SYMBOLE HYSTÉRÉSIS",NULL},
/* 238F */ { "SYMBOLE SORTIE EN CIRCUIT OUVERT DE TYPE H",NULL},
/* 2390 */ { "SYMBOLE SORTIE EN CIRCUIT OUVERT DE TYPE L",NULL},
/* 2391 */ { "SYMBOLE SORTIE PASSIVE ABAISSEUSE",NULL},
/* 2392 */ { "SYMBOLE SORTIE PASSIVE ÉLEVEUSE",NULL},
/* 2393 */ { "SYMBOLE COURANT CONTINU FORME DEUX",NULL},
/* 2394 */ { "SYMBOLE FONCTION LOGICIELLE","	x (hexagone blanc - 2B21)"},
/* 2395 */ { "SYMBOLE DE FONCTION APL QUADRAT","	x (symbole de fonction apl quadrat mince - 2337)\n"
	"	x (rectangle vertical blanc - 25AF)"},
/* 2396 */ { "SYMBOLE DE TOUCHE SÉPARATEUR DÉCIMAL",NULL},
/* 2397 */ { "PAGE PRÉCÉDENTE","	x (back avec flèche vers la gauche suscrite - 1F519)"},
/* 2398 */ { "PAGE SUIVANTE",NULL},
/* 2399 */ { "SYMBOLE IMPRIMER ÉCRAN",NULL},
/* 239A */ { "SYMBOLE EFFACER ÉCRAN","	x (diacritique écran englobant - 20E2)"},
/* 239B */ { "ARC SUPÉRIEUR DE PARENTHÈSE GAUCHE",NULL},
/* 239C */ { "RALLONGE DE PARENTHÈSE GAUCHE",NULL},
/* 239D */ { "ARC INFÉRIEUR DE PARENTHÈSE GAUCHE",NULL},
/* 239E */ { "ARC SUPÉRIEUR DE PARENTHÈSE DROITE",NULL},
/* 239F */ { "RALLONGE DE PARENTHÈSE DROITE",NULL},
/* 23A0 */ { "ARC INFÉRIEUR DE PARENTHÈSE DROITE",NULL},
/* 23A1 */ { "COIN SUPÉRIEUR DE CROCHET GAUCHE",NULL},
/* 23A2 */ { "RALLONGE DE CROCHET GAUCHE",NULL},
/* 23A3 */ { "COIN INFÉRIEUR DE CROCHET GAUCHE",NULL},
/* 23A4 */ { "COIN SUPÉRIEUR DE CROCHET DROIT",NULL},
/* 23A5 */ { "RALLONGE DE CROCHET DROIT",NULL},
/* 23A6 */ { "COIN INFÉRIEUR DE CROCHET DROIT",NULL},
/* 23A7 */ { "ARC SUPÉRIEUR D'ACCOLADE GAUCHE",NULL},
/* 23A8 */ { "MILIEU D'ACCOLADE GAUCHE",NULL},
/* 23A9 */ { "ARC INFÉRIEUR D'ACCOLADE GAUCHE",NULL},
/* 23AA */ { "RALLONGE D'ACCOLADE",NULL},
/* 23AB */ { "ARC SUPÉRIEUR D'ACCOLADE DROITE",NULL},
/* 23AC */ { "MILIEU D'ACCOLADE DROITE",NULL},
/* 23AD */ { "ARC INFÉRIEUR D'ACCOLADE DROITE",NULL},
/* 23AE */ { "RALLONGE D'INTÉGRALE","	x (moitié supérieure d'intégrale - 2320)\n"
	"	x (moitié inférieure d'intégrale - 2321)"},
/* 23AF */ { "RALLONGE DE LIGNE HORIZONTALE","	* sert pour l'allongement des flèches\n"
	"	x (rallonge de ligne verticale - 23D0)"},
/* 23B0 */ { "MOITIÉ SUPÉRIEURE GAUCHE OU INFÉRIEURE DROITE D'ACCOLADE","	= moustache gauche"},
/* 23B1 */ { "MOITIÉ SUPÉRIEURE DROITE OU INFÉRIEURE GAUCHE D'ACCOLADE","	= moustache droite"},
/* 23B2 */ { "HAUT DU SIGNE DE SOMME",NULL},
/* 23B3 */ { "BAS DU SIGNE DE SOMME","	x (sommation de la famille - 2211)"},
/* 23B4 */ { "CROCHET SUPÉRIEUR","	x (forme de présentation de crochet gauche vertical - FE47)"},
/* 23B5 */ { "CROCHET INFÉRIEUR","	x (forme de présentation de crochet droit vertical - FE48)"},
/* 23B6 */ { "CROCHET INFÉRIEUR SUR CROCHET SUPÉRIEUR","	* ne s'utilise qu'en émulation de terminal CJC"},
/* 23B7 */ { "BAS DU RADICAL",NULL},
/* 23B8 */ { "FILET VERTICAL GAUCHE",NULL},
/* 23B9 */ { "FILET VERTICAL DROIT",NULL},
/* 23BA */ { "LIGNE DE BALAYAGE HORIZONTAL 1",NULL},
/* 23BB */ { "LIGNE DE BALAYAGE HORIZONTAL 3","	* la ligne de balayage 5 est unifiée avec le caractère 2500"},
/* 23BC */ { "LIGNE DE BALAYAGE HORIZONTAL 7",NULL},
/* 23BD */ { "LIGNE DE BALAYAGE HORIZONTAL 9",NULL},
/* 23BE */ { "SYMBOLE DENTAIRE TRAITS VERTICAL ET SUPÉRIEUR DROIT MAIGRES","	x (plafond à gauche - 2308)"},
/* 23BF */ { "SYMBOLE DENTAIRE TRAITS VERTICAL ET INFÉRIEUR DROIT MAIGRES","	x (plancher à gauche - 230A)"},
/* 23C0 */ { "SYMBOLE DENTAIRE TRAIT VERTICAL ET CERCLE MAIGRES",NULL},
/* 23C1 */ { "SYMBOLE DENTAIRE T ET CERCLE MAIGRES",NULL},
/* 23C2 */ { "SYMBOLE DENTAIRE T CULBUTÉ ET CERCLE MAIGRES",NULL},
/* 23C3 */ { "SYMBOLE DENTAIRE TRAIT VERTICAL ET TRIANGLE MAIGRES",NULL},
/* 23C4 */ { "SYMBOLE DENTAIRE T ET TRIANGLE MAIGRES",NULL},
/* 23C5 */ { "SYMBOLE DENTAIRE T CULBUTÉ ET TRIANGLE MAIGRES",NULL},
/* 23C6 */ { "SYMBOLE DENTAIRE TRAIT VERTICAL ET ONDE MAIGRES",NULL},
/* 23C7 */ { "SYMBOLE DENTAIRE T ET ONDE MAIGRES",NULL},
/* 23C8 */ { "SYMBOLE DENTAIRE T CULBUTÉ ET ONDE MAIGRES",NULL},
/* 23C9 */ { "SYMBOLE DENTAIRE T MAIGRE","	x (taquet vers le bas - 22A4)\n"
	"	x (filet fin vers le bas et horizontal - 252C)"},
/* 23CA */ { "SYMBOLE DENTAIRE T CULBUTÉ MAIGRE","	x (taquet vers le haut - 22A5)\n"
	"	x (filet fin vers le haut et horizontal - 2534)"},
/* 23CB */ { "SYMBOLE DENTAIRE TRAITS VERTICAL ET SUPÉRIEUR GAUCHE MAIGRES","	x (plafond à droite - 2309)"},
/* 23CC */ { "SYMBOLE DENTAIRE TRAITS VERTICAL ET INFÉRIEUR GAUCHE MAIGRES","	x (plancher à droite - 230B)"},
/* 23CD */ { "PIED CARRÉ",NULL},
/* 23CE */ { "SYMBOLE RETOUR DE CHARIOT","	* le glyphe peut être évidé ou plein\n"
	"	x (flèche vers le bas avec coin vers la gauche - 21B5)\n"
	"	x (retour de chariot à gauche - 2B90)"},
/* 23CF */ { "SYMBOLE ÉJECTION","	* symbole utilisé pour représenter l'éjection du support"},
/* 23D0 */ { "RALLONGE DE LIGNE VERTICALE","	* sert pour l'allongement des flèches\n"
	"	x (rallonge de ligne horizontale - 23AF)"},
/* 23D1 */ { "BRÈVE MÉTRIQUE",NULL},
/* 23D2 */ { "LONGUE SURMONTANT BRÈVE MÉTRIQUE","	= habituellement brève"},
/* 23D3 */ { "BRÈVE SURMONTANT LONGUE MÉTRIQUE","	= habituellement longue"},
/* 23D4 */ { "LONGUE SURMONTANT DEUX BRÈVES MÉTRIQUE","	= contraction"},
/* 23D5 */ { "DEUX BRÈVES SURMONTANT LONGUE MÉTRIQUE","	= résolution"},
/* 23D6 */ { "DEUX BRÈVES JOINTES MÉTRIQUE","	= long résolu"},
/* 23D7 */ { "TRISÈME LONGUE-BRÈVE MÉTRIQUE","	= trois temps irrationnel\n"
	"	x (diacritique musical grec trisème - 1D242)"},
/* 23D8 */ { "TÉTRASÈME MÉTRIQUE","	= quatre temps irrationnel\n"
	"	x (diacritique musical grec tétrasème - 1D243)"},
/* 23D9 */ { "PENTASÈME MÉTRIQUE","	= cinq temps irrationnel\n"
	"	x (diacritique musical grec pentasème - 1D244)"},
/* 23DA */ { "MISE À LA TERRE",NULL},
/* 23DB */ { "FUSIBLE",NULL},
/* 23DC */ { "PARENTHÈSE SUPÉRIEURE","	x (forme de présentation de parenthèse gauche verticale - FE35)"},
/* 23DD */ { "PARENTHÈSE INFÉRIEURE","	x (forme de présentation de parenthèse droite verticale - FE36)"},
/* 23DE */ { "ACCOLADE SUPÉRIEURE","	x (forme de présentation d'accolade gauche verticale - FE37)"},
/* 23DF */ { "ACCOLADE INFÉRIEURE","	x (forme de présentation d'accolade droite verticale - FE38)"},
/* 23E0 */ { "CROCHET EN ÉCAILLE SUPÉRIEUR","	x (forme de présentation de crochet en écaille gauche vertical - FE39)"},
/* 23E1 */ { "CROCHET EN ÉCAILLE INFÉRIEUR","	x (forme de présentation de crochet en écaille droit vertical - FE3A)"},
/* 23E2 */ { "TRAPÈZE BLANC",NULL},
/* 23E3 */ { "ANNEAU DE BENZÈNE AVEC CERCLE",NULL},
/* 23E4 */ { "RECTITUDE",NULL},
/* 23E5 */ { "PLANÉITÉ",NULL},
/* 23E6 */ { "COURANT ALTERNATIF",NULL},
/* 23E7 */ { "INTERSECTION ÉLECTRIQUE",NULL},
/* 23E8 */ { "SYMBOLE EXPOSANT DÉCIMAL","	* jeton Algol-60 pour les littéraux en notation scientifique"},
/* 23E9 */ { "DOUBLE TRIANGLE NOIR POINTANT VERS LA DROITE","	= avance rapide"},
/* 23EA */ { "DOUBLE TRIANGLE NOIR POINTANT VERS LA GAUCHE","	= rembobinage, recul rapide"},
/* 23EB */ { "DOUBLE TRIANGLE NOIR POINTANT VERS LE HAUT",NULL},
/* 23EC */ { "DOUBLE TRIANGLE NOIR POINTANT VERS LE BAS",NULL},
/* 23ED */ { "DOUBLE TRIANGLE NOIR POINTANT VERS LA DROITE AVEC BARRE VERTICALE","	= aller à la fin du fichier/chapitre, aller à la fin de la plage\n"
	"	= aller au fichier/chapitre suivant, aller à la plage suivante"},
/* 23EE */ { "DOUBLE TRIANGLE NOIR POINTANT VERS LA GAUCHE AVEC BARRE VERTICALE","	= aller au début du fichier/chapitre, aller au début de la plage\n"
	"	= aller au fichier/chapitre précédent, aller à la plage précédente"},
/* 23EF */ { "TRIANGLE NOIR POINTANT VERS LA DROITE AVEC DOUBLE BARRE VERTICALE","	= basculement lecture/pause"},
/* 23F0 */ { "RÉVEILLE-MATIN","	x (montre - 231A)\n"
	"	x (cadran d'horloge à une heure - 1F550)\n"
	"	x (horloge de cheminée - 1F570)"},
/* 23F1 */ { "CHRONOMÈTRE",NULL},
/* 23F2 */ { "MINUTERIE",NULL},
/* 23F3 */ { "SABLIER AVEC COULÉE DE SABLE","	x (sablier - 231B)"},
/* 23F4 */ { "TRIANGLE NOIR MOYEN POINTANT VERS LA GAUCHE","	= arrière\n"
	"	* préféré à 25C0\n"
	"	x (triangle moyen noir vers la gauche centré - 2BC7)\n"
	"	x (triangle isocèle droit noir pointant vers la gauche - 1F780)"},
/* 23F5 */ { "TRIANGLE NOIR MOYEN POINTANT VERS LA DROITE","	= avant\n"
	"	* préféré à 25B6\n"
	"	x (triangle moyen noir vers la droite centré - 2BC8)\n"
	"	x (triangle isocèle droit noir pointant vers la droite - 1F782)"},
/* 23F6 */ { "TRIANGLE NOIR MOYEN POINTANT VERS LE HAUT","	= augmenter\n"
	"	* préféré à 25B2\n"
	"	x (triangle moyen noir vers le haut centré - 2BC5)\n"
	"	x (triangle isocèle droit noir pointant vers le haut - 1F781)"},
/* 23F7 */ { "TRIANGLE NOIR MOYEN POINTANT VERS LE BAS","	= diminuer\n"
	"	* préféré à 25BC\n"
	"	x (triangle moyen noir vers le bas centré - 2BC6)\n"
	"	x (triangle isocèle droit noir pointant vers le bas - 1F783)"},
/* 23F8 */ { "DOUBLE BARRE VERTICALE","	= pause\n"
	"	x (double ligne verticale - 2016)"},
/* 23F9 */ { "CARRÉ NOIR POUR ARRÊT","	= arrêt\n"
	"	x (carré moyen noir - 25FC)"},
/* 23FA */ { "CERCLE NOIR POUR ENREGISTREMENT","	= enregistrer\n"
	"	x (cercle noir moyen - 26AB)\n"
	"	x (grand cercle rouge - 1F534)"},
/* 23FB */ { "SYMBOLE MISE SOUS TENSION","	* symbole de veille CEI 5009\n"
	"	* symbole d'alimentation IEEE 1621"},
/* 23FC */ { "SYMBOLE MARCHE-ARRÊT","	* symbole de marche-arrêt CEI 5010"},
/* 23FD */ { "SYMBOLE MISE EN MARCHE","	* utilisez 2B58 pour le symbole d'arrêt\n"
	"	x (cercle épais - 2B58)"},
/* 23FE */ { "SYMBOLE MISE EN VEILLE","	x (dernier quartier de lune - 263E)"},
/* 23FF */ { "SYMBOLE DE L'ŒIL OBSERVATEUR",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_24[] = {
/* 2400 */ { "SYMBOLE POUR NUL",NULL},
/* 2401 */ { "SYMBOLE POUR DÉBUT D'EN-TÊTE",NULL},
/* 2402 */ { "SYMBOLE POUR DÉBUT DE TEXTE",NULL},
/* 2403 */ { "SYMBOLE POUR FIN DE TEXTE",NULL},
/* 2404 */ { "SYMBOLE POUR FIN DE TRANSMISSION",NULL},
/* 2405 */ { "SYMBOLE POUR DEMANDE",NULL},
/* 2406 */ { "SYMBOLE POUR ACCUSÉ DE RÉCEPTION",NULL},
/* 2407 */ { "SYMBOLE POUR SONNERIE",NULL},
/* 2408 */ { "SYMBOLE POUR ESPACE ARRIÈRE",NULL},
/* 2409 */ { "SYMBOLE POUR TABULATION HORIZONTALE",NULL},
/* 240A */ { "SYMBOLE POUR CHANGEMENT DE LIGNE",NULL},
/* 240B */ { "SYMBOLE POUR TABULATION VERTICALE",NULL},
/* 240C */ { "SYMBOLE POUR SAUT DE PAGE",NULL},
/* 240D */ { "SYMBOLE POUR RETOUR DE CHARIOT",NULL},
/* 240E */ { "SYMBOLE POUR HORS CODE",NULL},
/* 240F */ { "SYMBOLE POUR EN CODE",NULL},
/* 2410 */ { "SYMBOLE POUR ÉCHAPPEMENT TRANSMISSION",NULL},
/* 2411 */ { "SYMBOLE POUR COMMANDE DE DISPOSITIF UN",NULL},
/* 2412 */ { "SYMBOLE POUR COMMANDE DE DISPOSITIF DEUX",NULL},
/* 2413 */ { "SYMBOLE POUR COMMANDE DE DISPOSITIF TROIS",NULL},
/* 2414 */ { "SYMBOLE POUR COMMANDE DE DISPOSITIF QUATRE",NULL},
/* 2415 */ { "SYMBOLE POUR ACCUSÉ DE RÉCEPTION NÉGATIF",NULL},
/* 2416 */ { "SYMBOLE POUR SYNCHRONISATION",NULL},
/* 2417 */ { "SYMBOLE POUR FIN DE BLOC DE TRANSMISSION",NULL},
/* 2418 */ { "SYMBOLE POUR ANNULATION",NULL},
/* 2419 */ { "SYMBOLE POUR FIN DE SUPPORT",NULL},
/* 241A */ { "SYMBOLE POUR SUBSTITUTION",NULL},
/* 241B */ { "SYMBOLE POUR ÉCHAPPEMENT",NULL},
/* 241C */ { "SYMBOLE POUR SÉPARATEUR DE FICHIERS",NULL},
/* 241D */ { "SYMBOLE POUR SÉPARATEUR DE GROUPES",NULL},
/* 241E */ { "SYMBOLE POUR SÉPARATEUR D'ENREGISTREMENTS",NULL},
/* 241F */ { "SYMBOLE POUR SÉPARATEUR D'UNITÉS",NULL},
/* 2420 */ { "SYMBOLE POUR ESPACE",NULL},
/* 2421 */ { "SYMBOLE POUR SUPPRESSION",NULL},
/* 2422 */ { "SYMBOLE BLANC","	* symbole visuel pour l'espace\n"
	"	x (lettre minuscule latine b barré - 0180)"},
/* 2423 */ { "BOÎTE OUVERTE","	* symbole visuel pour l'espace\n"
	"	x (alésage - 2334)"},
/* 2424 */ { "SYMBOLE POUR NOUVELLE LIGNE",NULL},
/* 2425 */ { "SYMBOLE POUR SUPPRESSION FORME DEUX","	* tiré de la norme ISO 9995-7\n"
	"	* symbole sur le clavier pour la suppression irréversible"},
/* 2426 */ { "SYMBOLE POUR SUBSTITUTION FORME DEUX","	* tiré de la norme ISO 2047\n"
	"	x (point d'interrogation arabe - 061F)"},
/* 2427 */ { "SYMBOLE POUR SUPPRESSION EN FORME DE DAMIER CARRÉ",NULL},
/* 2428 */ { "SYMBOLE POUR SUPPRESSION EN FORME DE DAMIER RECTANGULAIRE",NULL},
/* 2429 */ { "SYMBOLE POUR SUPPRESSION EN FORME D'OMBRAGE MOYEN",NULL},
/* 242A */ { NULL,NULL},
/* 242B */ { NULL,NULL},
/* 242C */ { NULL,NULL},
/* 242D */ { NULL,NULL},
/* 242E */ { NULL,NULL},
/* 242F */ { NULL,NULL},
/* 2430 */ { NULL,NULL},
/* 2431 */ { NULL,NULL},
/* 2432 */ { NULL,NULL},
/* 2433 */ { NULL,NULL},
/* 2434 */ { NULL,NULL},
/* 2435 */ { NULL,NULL},
/* 2436 */ { NULL,NULL},
/* 2437 */ { NULL,NULL},
/* 2438 */ { NULL,NULL},
/* 2439 */ { NULL,NULL},
/* 243A */ { NULL,NULL},
/* 243B */ { NULL,NULL},
/* 243C */ { NULL,NULL},
/* 243D */ { NULL,NULL},
/* 243E */ { NULL,NULL},
/* 243F */ { NULL,NULL},
/* 2440 */ { "CROCHET ROC",NULL},
/* 2441 */ { "CHAISE ROC",NULL},
/* 2442 */ { "FOURCHETTE ROC",NULL},
/* 2443 */ { "FOURCHETTE CULBUTÉE ROC",NULL},
/* 2444 */ { "BOUCLE DE CEINTURE ROC",NULL},
/* 2445 */ { "NŒUD PAPILLON ROC","	x (nœud papillon - 22C8)"},
/* 2446 */ { "IDENTIFICATION DE SUCCURSALE BANCAIRE ROC","	= domiciliation"},
/* 2447 */ { "MONTANT DU CHÈQUE ROC","	= montant"},
/* 2448 */ { "SYMBOLE RCEM SUR NOUS","	= sur nous\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 2449 */ { "SYMBOLE RCEM TIRET","	= tiret\n"
	"	* le nom formel de ce caractère en anglais est erroné"},
/* 244A */ { "DOUBLE BARRE OBLIQUE INVERSÉE ROC","	= double contre-oblique ROC, double contre-cotice ROC"},
/* 244B */ { NULL,NULL},
/* 244C */ { NULL,NULL},
/* 244D */ { NULL,NULL},
/* 244E */ { NULL,NULL},
/* 244F */ { NULL,NULL},
/* 2450 */ { NULL,NULL},
/* 2451 */ { NULL,NULL},
/* 2452 */ { NULL,NULL},
/* 2453 */ { NULL,NULL},
/* 2454 */ { NULL,NULL},
/* 2455 */ { NULL,NULL},
/* 2456 */ { NULL,NULL},
/* 2457 */ { NULL,NULL},
/* 2458 */ { NULL,NULL},
/* 2459 */ { NULL,NULL},
/* 245A */ { NULL,NULL},
/* 245B */ { NULL,NULL},
/* 245C */ { NULL,NULL},
/* 245D */ { NULL,NULL},
/* 245E */ { NULL,NULL},
/* 245F */ { NULL,NULL},
/* 2460 */ { "CHIFFRE UN CERCLÉ","	# <cerclée> 0031"},
/* 2461 */ { "CHIFFRE DEUX CERCLÉ","	# <cerclée> 0032"},
/* 2462 */ { "CHIFFRE TROIS CERCLÉ","	# <cerclée> 0033"},
/* 2463 */ { "CHIFFRE QUATRE CERCLÉ","	# <cerclée> 0034"},
/* 2464 */ { "CHIFFRE CINQ CERCLÉ","	# <cerclée> 0035"},
/* 2465 */ { "CHIFFRE SIX CERCLÉ","	# <cerclée> 0036"},
/* 2466 */ { "CHIFFRE SEPT CERCLÉ","	# <cerclée> 0037"},
/* 2467 */ { "CHIFFRE HUIT CERCLÉ","	# <cerclée> 0038"},
/* 2468 */ { "CHIFFRE NEUF CERCLÉ","	# <cerclée> 0039"},
/* 2469 */ { "NOMBRE DIX CERCLÉ","	# <cerclée> 0031 0030"},
/* 246A */ { "NOMBRE ONZE CERCLÉ","	# <cerclée> 0031 0031"},
/* 246B */ { "NOMBRE DOUZE CERCLÉ","	# <cerclée> 0031 0032"},
/* 246C */ { "NOMBRE TREIZE CERCLÉ","	# <cerclée> 0031 0033"},
/* 246D */ { "NOMBRE QUATORZE CERCLÉ","	# <cerclée> 0031 0034"},
/* 246E */ { "NOMBRE QUINZE CERCLÉ","	# <cerclée> 0031 0035"},
/* 246F */ { "NOMBRE SEIZE CERCLÉ","	# <cerclée> 0031 0036"},
/* 2470 */ { "NOMBRE DIX-SEPT CERCLÉ","	# <cerclée> 0031 0037"},
/* 2471 */ { "NOMBRE DIX-HUIT CERCLÉ","	# <cerclée> 0031 0038"},
/* 2472 */ { "NOMBRE DIX-NEUF CERCLÉ","	# <cerclée> 0031 0039"},
/* 2473 */ { "NOMBRE VINGT CERCLÉ","	# <cerclée> 0032 0030"},
/* 2474 */ { "CHIFFRE UN ENTRE PARENTHÈSES","	# 0028 0031 0029"},
/* 2475 */ { "CHIFFRE DEUX ENTRE PARENTHÈSES","	# 0028 0032 0029"},
/* 2476 */ { "CHIFFRE TROIS ENTRE PARENTHÈSES","	# 0028 0033 0029"},
/* 2477 */ { "CHIFFRE QUATRE ENTRE PARENTHÈSES","	# 0028 0034 0029"},
/* 2478 */ { "CHIFFRE CINQ ENTRE PARENTHÈSES","	# 0028 0035 0029"},
/* 2479 */ { "CHIFFRE SIX ENTRE PARENTHÈSES","	# 0028 0036 0029"},
/* 247A */ { "CHIFFRE SEPT ENTRE PARENTHÈSES","	# 0028 0037 0029"},
/* 247B */ { "CHIFFRE HUIT ENTRE PARENTHÈSES","	# 0028 0038 0029"},
/* 247C */ { "CHIFFRE NEUF ENTRE PARENTHÈSES","	# 0028 0039 0029"},
/* 247D */ { "NOMBRE DIX ENTRE PARENTHÈSES","	# 0028 0031 0030 0029"},
/* 247E */ { "NOMBRE ONZE ENTRE PARENTHÈSES","	# 0028 0031 0031 0029"},
/* 247F */ { "NOMBRE DOUZE ENTRE PARENTHÈSES","	# 0028 0031 0032 0029"},
/* 2480 */ { "NOMBRE TREIZE ENTRE PARENTHÈSES","	# 0028 0031 0033 0029"},
/* 2481 */ { "NOMBRE QUATORZE ENTRE PARENTHÈSES","	# 0028 0031 0034 0029"},
/* 2482 */ { "NOMBRE QUINZE ENTRE PARENTHÈSES","	# 0028 0031 0035 0029"},
/* 2483 */ { "NOMBRE SEIZE ENTRE PARENTHÈSES","	# 0028 0031 0036 0029"},
/* 2484 */ { "NOMBRE DIX-SEPT ENTRE PARENTHÈSES","	# 0028 0031 0037 0029"},
/* 2485 */ { "NOMBRE DIX-HUIT ENTRE PARENTHÈSES","	# 0028 0031 0038 0029"},
/* 2486 */ { "NOMBRE DIX-NEUF ENTRE PARENTHÈSES","	# 0028 0031 0039 0029"},
/* 2487 */ { "NOMBRE VINGT ENTRE PARENTHÈSES","	# 0028 0032 0030 0029"},
/* 2488 */ { "CHIFFRE UN POINT","	# 0031 002E"},
/* 2489 */ { "CHIFFRE DEUX POINT","	# 0032 002E"},
/* 248A */ { "CHIFFRE TROIS POINT","	# 0033 002E"},
/* 248B */ { "CHIFFRE QUATRE POINT","	# 0034 002E"},
/* 248C */ { "CHIFFRE CINQ POINT","	# 0035 002E"},
/* 248D */ { "CHIFFRE SIX POINT","	# 0036 002E"},
/* 248E */ { "CHIFFRE SEPT POINT","	# 0037 002E"},
/* 248F */ { "CHIFFRE HUIT POINT","	# 0038 002E"},
/* 2490 */ { "CHIFFRE NEUF POINT","	# 0039 002E"},
/* 2491 */ { "NOMBRE DIX POINT","	# 0031 0030 002E"},
/* 2492 */ { "NOMBRE ONZE POINT","	# 0031 0031 002E"},
/* 2493 */ { "NOMBRE DOUZE POINT","	# 0031 0032 002E"},
/* 2494 */ { "NOMBRE TREIZE POINT","	# 0031 0033 002E"},
/* 2495 */ { "NOMBRE QUATORZE POINT","	# 0031 0034 002E"},
/* 2496 */ { "NOMBRE QUINZE POINT","	# 0031 0035 002E"},
/* 2497 */ { "NOMBRE SEIZE POINT","	# 0031 0036 002E"},
/* 2498 */ { "NOMBRE DIX-SEPT POINT","	# 0031 0037 002E"},
/* 2499 */ { "NOMBRE DIX-HUIT POINT","	# 0031 0038 002E"},
/* 249A */ { "NOMBRE DIX-NEUF POINT","	# 0031 0039 002E"},
/* 249B */ { "NOMBRE VINGT POINT","	# 0032 0030 002E"},
/* 249C */ { "LETTRE MINUSCULE LATINE A ENTRE PARENTHÈSES","	# 0028 0061 0029"},
/* 249D */ { "LETTRE MINUSCULE LATINE B ENTRE PARENTHÈSES","	# 0028 0062 0029"},
/* 249E */ { "LETTRE MINUSCULE LATINE C ENTRE PARENTHÈSES","	# 0028 0063 0029"},
/* 249F */ { "LETTRE MINUSCULE LATINE D ENTRE PARENTHÈSES","	# 0028 0064 0029"},
/* 24A0 */ { "LETTRE MINUSCULE LATINE E ENTRE PARENTHÈSES","	# 0028 0065 0029"},
/* 24A1 */ { "LETTRE MINUSCULE LATINE F ENTRE PARENTHÈSES","	# 0028 0066 0029"},
/* 24A2 */ { "LETTRE MINUSCULE LATINE G ENTRE PARENTHÈSES","	# 0028 0067 0029"},
/* 24A3 */ { "LETTRE MINUSCULE LATINE H ENTRE PARENTHÈSES","	# 0028 0068 0029"},
/* 24A4 */ { "LETTRE MINUSCULE LATINE I ENTRE PARENTHÈSES","	# 0028 0069 0029"},
/* 24A5 */ { "LETTRE MINUSCULE LATINE J ENTRE PARENTHÈSES","	# 0028 006A 0029"},
/* 24A6 */ { "LETTRE MINUSCULE LATINE K ENTRE PARENTHÈSES","	# 0028 006B 0029"},
/* 24A7 */ { "LETTRE MINUSCULE LATINE L ENTRE PARENTHÈSES","	# 0028 006C 0029"},
/* 24A8 */ { "LETTRE MINUSCULE LATINE M ENTRE PARENTHÈSES","	# 0028 006D 0029"},
/* 24A9 */ { "LETTRE MINUSCULE LATINE N ENTRE PARENTHÈSES","	# 0028 006E 0029"},
/* 24AA */ { "LETTRE MINUSCULE LATINE O ENTRE PARENTHÈSES","	# 0028 006F 0029"},
/* 24AB */ { "LETTRE MINUSCULE LATINE P ENTRE PARENTHÈSES","	# 0028 0070 0029"},
/* 24AC */ { "LETTRE MINUSCULE LATINE Q ENTRE PARENTHÈSES","	# 0028 0071 0029"},
/* 24AD */ { "LETTRE MINUSCULE LATINE R ENTRE PARENTHÈSES","	# 0028 0072 0029"},
/* 24AE */ { "LETTRE MINUSCULE LATINE S ENTRE PARENTHÈSES","	# 0028 0073 0029"},
/* 24AF */ { "LETTRE MINUSCULE LATINE T ENTRE PARENTHÈSES","	# 0028 0074 0029"},
/* 24B0 */ { "LETTRE MINUSCULE LATINE U ENTRE PARENTHÈSES","	# 0028 0075 0029"},
/* 24B1 */ { "LETTRE MINUSCULE LATINE V ENTRE PARENTHÈSES","	# 0028 0076 0029"},
/* 24B2 */ { "LETTRE MINUSCULE LATINE W ENTRE PARENTHÈSES","	# 0028 0077 0029"},
/* 24B3 */ { "LETTRE MINUSCULE LATINE X ENTRE PARENTHÈSES","	# 0028 0078 0029"},
/* 24B4 */ { "LETTRE MINUSCULE LATINE Y ENTRE PARENTHÈSES","	# 0028 0079 0029"},
/* 24B5 */ { "LETTRE MINUSCULE LATINE Z ENTRE PARENTHÈSES","	# 0028 007A 0029"},
/* 24B6 */ { "LETTRE MAJUSCULE LATINE A CERCLÉE","	# <cerclée> 0041"},
/* 24B7 */ { "LETTRE MAJUSCULE LATINE B CERCLÉE","	# <cerclée> 0042"},
/* 24B8 */ { "LETTRE MAJUSCULE LATINE C CERCLÉE","	x (symbole copyright - 00A9)\n"
	"	# <cerclée> 0043"},
/* 24B9 */ { "LETTRE MAJUSCULE LATINE D CERCLÉE","	# <cerclée> 0044"},
/* 24BA */ { "LETTRE MAJUSCULE LATINE E CERCLÉE","	# <cerclée> 0045"},
/* 24BB */ { "LETTRE MAJUSCULE LATINE F CERCLÉE","	# <cerclée> 0046"},
/* 24BC */ { "LETTRE MAJUSCULE LATINE G CERCLÉE","	# <cerclée> 0047"},
/* 24BD */ { "LETTRE MAJUSCULE LATINE H CERCLÉE","	# <cerclée> 0048"},
/* 24BE */ { "LETTRE MAJUSCULE LATINE I CERCLÉE","	# <cerclée> 0049"},
/* 24BF */ { "LETTRE MAJUSCULE LATINE J CERCLÉE","	# <cerclée> 004A"},
/* 24C0 */ { "LETTRE MAJUSCULE LATINE K CERCLÉE","	# <cerclée> 004B"},
/* 24C1 */ { "LETTRE MAJUSCULE LATINE L CERCLÉE","	# <cerclée> 004C"},
/* 24C2 */ { "LETTRE MAJUSCULE LATINE M CERCLÉE","	x (symbole de topographie de circuit intégré - 1F1AD)\n"
	"	# <cerclée> 004D"},
/* 24C3 */ { "LETTRE MAJUSCULE LATINE N CERCLÉE","	# <cerclée> 004E"},
/* 24C4 */ { "LETTRE MAJUSCULE LATINE O CERCLÉE","	# <cerclée> 004F"},
/* 24C5 */ { "LETTRE MAJUSCULE LATINE P CERCLÉE","	x (copyright de phonogramme - 2117)\n"
	"	# <cerclée> 0050"},
/* 24C6 */ { "LETTRE MAJUSCULE LATINE Q CERCLÉE","	# <cerclée> 0051"},
/* 24C7 */ { "LETTRE MAJUSCULE LATINE R CERCLÉE","	x (symbole marque déposée - 00AE)\n"
	"	# <cerclée> 0052"},
/* 24C8 */ { "LETTRE MAJUSCULE LATINE S CERCLÉE","	# <cerclée> 0053"},
/* 24C9 */ { "LETTRE MAJUSCULE LATINE T CERCLÉE","	# <cerclée> 0054"},
/* 24CA */ { "LETTRE MAJUSCULE LATINE U CERCLÉE","	# <cerclée> 0055"},
/* 24CB */ { "LETTRE MAJUSCULE LATINE V CERCLÉE","	# <cerclée> 0056"},
/* 24CC */ { "LETTRE MAJUSCULE LATINE W CERCLÉE","	# <cerclée> 0057"},
/* 24CD */ { "LETTRE MAJUSCULE LATINE X CERCLÉE","	# <cerclée> 0058"},
/* 24CE */ { "LETTRE MAJUSCULE LATINE Y CERCLÉE","	# <cerclée> 0059"},
/* 24CF */ { "LETTRE MAJUSCULE LATINE Z CERCLÉE","	# <cerclée> 005A"},
/* 24D0 */ { "LETTRE MINUSCULE LATINE A CERCLÉE","	# <cerclée> 0061"},
/* 24D1 */ { "LETTRE MINUSCULE LATINE B CERCLÉE","	# <cerclée> 0062"},
/* 24D2 */ { "LETTRE MINUSCULE LATINE C CERCLÉE","	# <cerclée> 0063"},
/* 24D3 */ { "LETTRE MINUSCULE LATINE D CERCLÉE","	# <cerclée> 0064"},
/* 24D4 */ { "LETTRE MINUSCULE LATINE E CERCLÉE","	# <cerclée> 0065"},
/* 24D5 */ { "LETTRE MINUSCULE LATINE F CERCLÉE","	# <cerclée> 0066"},
/* 24D6 */ { "LETTRE MINUSCULE LATINE G CERCLÉE","	# <cerclée> 0067"},
/* 24D7 */ { "LETTRE MINUSCULE LATINE H CERCLÉE","	# <cerclée> 0068"},
/* 24D8 */ { "LETTRE MINUSCULE LATINE I CERCLÉE","	# <cerclée> 0069"},
/* 24D9 */ { "LETTRE MINUSCULE LATINE J CERCLÉE","	# <cerclée> 006A"},
/* 24DA */ { "LETTRE MINUSCULE LATINE K CERCLÉE","	# <cerclée> 006B"},
/* 24DB */ { "LETTRE MINUSCULE LATINE L CERCLÉE","	# <cerclée> 006C"},
/* 24DC */ { "LETTRE MINUSCULE LATINE M CERCLÉE","	# <cerclée> 006D"},
/* 24DD */ { "LETTRE MINUSCULE LATINE N CERCLÉE","	# <cerclée> 006E"},
/* 24DE */ { "LETTRE MINUSCULE LATINE O CERCLÉE","	# <cerclée> 006F"},
/* 24DF */ { "LETTRE MINUSCULE LATINE P CERCLÉE","	# <cerclée> 0070"},
/* 24E0 */ { "LETTRE MINUSCULE LATINE Q CERCLÉE","	# <cerclée> 0071"},
/* 24E1 */ { "LETTRE MINUSCULE LATINE R CERCLÉE","	# <cerclée> 0072"},
/* 24E2 */ { "LETTRE MINUSCULE LATINE S CERCLÉE","	# <cerclée> 0073"},
/* 24E3 */ { "LETTRE MINUSCULE LATINE T CERCLÉE","	# <cerclée> 0074"},
/* 24E4 */ { "LETTRE MINUSCULE LATINE U CERCLÉE","	# <cerclée> 0075"},
/* 24E5 */ { "LETTRE MINUSCULE LATINE V CERCLÉE","	# <cerclée> 0076"},
/* 24E6 */ { "LETTRE MINUSCULE LATINE W CERCLÉE","	# <cerclée> 0077"},
/* 24E7 */ { "LETTRE MINUSCULE LATINE X CERCLÉE","	# <cerclée> 0078"},
/* 24E8 */ { "LETTRE MINUSCULE LATINE Y CERCLÉE","	# <cerclée> 0079"},
/* 24E9 */ { "LETTRE MINUSCULE LATINE Z CERCLÉE","	# <cerclée> 007A"},
/* 24EA */ { "CHIFFRE ZÉRO CERCLÉ","	# <cerclée> 0030"},
/* 24EB */ { "NOMBRE ONZE CERCLÉ NOIR AU BLANC",NULL},
/* 24EC */ { "NOMBRE DOUZE CERCLÉ NOIR AU BLANC",NULL},
/* 24ED */ { "NOMBRE TREIZE CERCLÉ NOIR AU BLANC",NULL},
/* 24EE */ { "NOMBRE QUATORZE CERCLÉ NOIR AU BLANC",NULL},
/* 24EF */ { "NOMBRE QUINZE CERCLÉ NOIR AU BLANC",NULL},
/* 24F0 */ { "NOMBRE SEIZE CERCLÉ NOIR AU BLANC",NULL},
/* 24F1 */ { "NOMBRE DIX-SEPT CERCLÉ NOIR AU BLANC",NULL},
/* 24F2 */ { "NOMBRE DIX-HUIT CERCLÉ NOIR AU BLANC",NULL},
/* 24F3 */ { "NOMBRE DIX-NEUF CERCLÉ NOIR AU BLANC",NULL},
/* 24F4 */ { "NOMBRE VINGT CERCLÉ NOIR AU BLANC",NULL},
/* 24F5 */ { "CHIFFRE UN DOUBLEMENT CERCLÉ",NULL},
/* 24F6 */ { "CHIFFRE DEUX DOUBLEMENT CERCLÉ",NULL},
/* 24F7 */ { "CHIFFRE TROIS DOUBLEMENT CERCLÉ",NULL},
/* 24F8 */ { "CHIFFRE QUATRE DOUBLEMENT CERCLÉ",NULL},
/* 24F9 */ { "CHIFFRE CINQ DOUBLEMENT CERCLÉ",NULL},
/* 24FA */ { "CHIFFRE SIX DOUBLEMENT CERCLÉ",NULL},
/* 24FB */ { "CHIFFRE SEPT DOUBLEMENT CERCLÉ",NULL},
/* 24FC */ { "CHIFFRE HUIT DOUBLEMENT CERCLÉ",NULL},
/* 24FD */ { "CHIFFRE NEUF DOUBLEMENT CERCLÉ",NULL},
/* 24FE */ { "NOMBRE DIX DOUBLEMENT CERCLÉ",NULL},
/* 24FF */ { "CHIFFRE ZÉRO CERCLÉ NOIR AU BLANC","	x (vignette chiffre un cerclé noir au blanc - 2776)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_25[] = {
/* 2500 */ { "FILET FIN HORIZONTAL","	= mosaïque Vidéotex DG 15\n"
	"	x (filet fin horizontal à barre verticale - 1FBAF)"},
/* 2501 */ { "FILET ÉPAIS HORIZONTAL",NULL},
/* 2502 */ { "FILET FIN VERTICAL","	= mosaïque Vidéotex DG 14"},
/* 2503 */ { "FILET ÉPAIS VERTICAL",NULL},
/* 2504 */ { "FILET FIN HORIZONTAL TRIPLEMENT TIRETÉ",NULL},
/* 2505 */ { "FILET ÉPAIS HORIZONTAL TRIPLEMENT TIRETÉ",NULL},
/* 2506 */ { "FILET FIN VERTICAL TRIPLEMENT TIRETÉ",NULL},
/* 2507 */ { "FILET ÉPAIS VERTICAL TRIPLEMENT TIRETÉ",NULL},
/* 2508 */ { "FILET FIN HORIZONTAL QUADRUPLEMENT TIRETÉ",NULL},
/* 2509 */ { "FILET ÉPAIS HORIZONTAL QUADRUPLEMENT TIRETÉ",NULL},
/* 250A */ { "FILET FIN VERTICAL QUADRUPLEMENT TIRETÉ",NULL},
/* 250B */ { "FILET ÉPAIS VERTICAL QUADRUPLEMENT TIRETÉ",NULL},
/* 250C */ { "FILET FIN VERS LE BAS ET VERS LA DROITE","	= mosaïque Vidéotex DG 16"},
/* 250D */ { "FILET FIN VERS LE BAS ET ÉPAIS VERS LA DROITE",NULL},
/* 250E */ { "FILET ÉPAIS VERS LE BAS ET FIN VERS LA DROITE",NULL},
/* 250F */ { "FILET ÉPAIS VERS LE BAS ET VERS LA DROITE",NULL},
/* 2510 */ { "FILET FIN VERS LE BAS ET VERS LA GAUCHE","	= mosaïque Vidéotex DG 17"},
/* 2511 */ { "FILET FIN VERS LE BAS ET ÉPAIS VERS LA GAUCHE",NULL},
/* 2512 */ { "FILET ÉPAIS VERS LE BAS ET FIN VERS LA GAUCHE",NULL},
/* 2513 */ { "FILET ÉPAIS VERS LE BAS ET VERS LA GAUCHE",NULL},
/* 2514 */ { "FILET FIN VERS LE HAUT ET VERS LA DROITE","	= mosaïque Vidéotex DG 18"},
/* 2515 */ { "FILET FIN VERS LE HAUT ET ÉPAIS VERS LA DROITE",NULL},
/* 2516 */ { "FILET ÉPAIS VERS LE HAUT ET FIN VERS LA DROITE",NULL},
/* 2517 */ { "FILET ÉPAIS VERS LE HAUT ET VERS LA DROITE",NULL},
/* 2518 */ { "FILET FIN VERS LE HAUT ET VERS LA GAUCHE","	= mosaïque Vidéotex DG 19"},
/* 2519 */ { "FILET FIN VERS LE HAUT ET ÉPAIS VERS LA GAUCHE",NULL},
/* 251A */ { "FILET ÉPAIS VERS LE HAUT ET FIN VERS LA GAUCHE",NULL},
/* 251B */ { "FILET ÉPAIS VERS LE HAUT ET VERS LA GAUCHE",NULL},
/* 251C */ { "FILET FIN VERTICAL ET VERS LA DROITE","	= mosaïque Vidéotex DG 20"},
/* 251D */ { "FILET FIN VERTICAL ET ÉPAIS VERS LA DROITE","	= mosaïque Vidéotex DG 03"},
/* 251E */ { "FILET ÉPAIS VERS LE HAUT ET FIN VERS LA DROITE ET VERS LE BAS",NULL},
/* 251F */ { "FILET ÉPAIS VERS LE BAS ET FIN VERS LA DROITE ET VERS LE HAUT",NULL},
/* 2520 */ { "FILET ÉPAIS VERTICAL ET FIN VERS LA DROITE",NULL},
/* 2521 */ { "FILET FIN VERS LE BAS ET ÉPAIS VERS LA DROITE ET VERS LE HAUT",NULL},
/* 2522 */ { "FILET FIN VERS LE HAUT ET ÉPAIS VERS LA DROITE ET VERS LE BAS",NULL},
/* 2523 */ { "FILET ÉPAIS VERTICAL ET VERS LA DROITE",NULL},
/* 2524 */ { "FILET FIN VERTICAL ET VERS LA GAUCHE","	= mosaïque Vidéotex DG 21"},
/* 2525 */ { "FILET FIN VERTICAL ET ÉPAIS VERS LA GAUCHE","	= mosaïque Vidéotex DG 04"},
/* 2526 */ { "FILET ÉPAIS VERS LE HAUT ET FIN VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 2527 */ { "FILET ÉPAIS VERS LE BAS ET FIN VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 2528 */ { "FILET ÉPAIS VERTICAL ET FIN VERS LA GAUCHE",NULL},
/* 2529 */ { "FILET FIN VERS LE BAS ET ÉPAIS VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 252A */ { "FILET FIN VERS LE HAUT ET ÉPAIS VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 252B */ { "FILET ÉPAIS VERTICAL ET VERS LA GAUCHE",NULL},
/* 252C */ { "FILET FIN VERS LE BAS ET HORIZONTAL","	= mosaïque Vidéotex DG 22"},
/* 252D */ { "FILET ÉPAIS VERS LA GAUCHE ET FIN VERS LA DROITE ET VERS LE BAS",NULL},
/* 252E */ { "FILET ÉPAIS VERS LA DROITE ET FIN VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 252F */ { "FILET FIN VERS LE BAS ET ÉPAIS HORIZONTAL","	= mosaïque Vidéotex DG 02"},
/* 2530 */ { "FILET ÉPAIS VERS LE BAS ET FIN HORIZONTAL",NULL},
/* 2531 */ { "FILET FIN VERS LA DROITE ET ÉPAIS VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 2532 */ { "FILET FIN VERS LA GAUCHE ET ÉPAIS VERS LA DROITE ET VERS LE BAS",NULL},
/* 2533 */ { "FILET ÉPAIS VERS LE BAS ET HORIZONTAL",NULL},
/* 2534 */ { "FILET FIN VERS LE HAUT ET HORIZONTAL","	= mosaïque Vidéotex DG 23"},
/* 2535 */ { "FILET ÉPAIS VERS LA GAUCHE ET FIN VERS LA DROITE ET VERS LE HAUT",NULL},
/* 2536 */ { "FILET ÉPAIS VERS LA DROITE ET FIN VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 2537 */ { "FILET FIN VERS LE HAUT ET ÉPAIS HORIZONTAL","	= mosaïque Vidéotex DG 01"},
/* 2538 */ { "FILET ÉPAIS VERS LE HAUT ET FIN HORIZONTAL",NULL},
/* 2539 */ { "FILET FIN VERS LA DROITE ET ÉPAIS VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 253A */ { "FILET FIN VERS LA GAUCHE ET ÉPAIS VERS LA DROITE ET VERS LE HAUT",NULL},
/* 253B */ { "FILET ÉPAIS VERS LE HAUT ET HORIZONTAL",NULL},
/* 253C */ { "FILET FIN VERTICAL ET HORIZONTAL","	= mosaïque Vidéotex DG 24"},
/* 253D */ { "FILET ÉPAIS VERS LA GAUCHE ET FIN VERS LA DROITE ET VERTICAL",NULL},
/* 253E */ { "FILET ÉPAIS VERS LA DROITE ET FIN VERS LA GAUCHE ET VERTICAL",NULL},
/* 253F */ { "FILET FIN VERTICAL ET ÉPAIS HORIZONTAL","	= mosaïque Vidéotex DG 13"},
/* 2540 */ { "FILET ÉPAIS VERS LE HAUT ET FIN VERS LE BAS ET HORIZONTAL",NULL},
/* 2541 */ { "FILET ÉPAIS VERS LE BAS ET FIN VERS LE HAUT ET HORIZONTAL",NULL},
/* 2542 */ { "FILET ÉPAIS VERTICAL ET FIN HORIZONTAL",NULL},
/* 2543 */ { "FILET ÉPAIS VERS LA GAUCHE ET VERS LE HAUT ET FIN VERS LA DROITE ET VERS LE BAS",NULL},
/* 2544 */ { "FILET ÉPAIS VERS LA DROITE ET VERS LE HAUT ET FIN VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 2545 */ { "FILET ÉPAIS VERS LA GAUCHE ET VERS LE BAS ET FIN VERS LA DROITE ET VERS LE HAUT",NULL},
/* 2546 */ { "FILET ÉPAIS VERS LA DROITE ET VERS LE BAS ET FIN VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 2547 */ { "FILET FIN VERS LE BAS ET ÉPAIS VERS LE HAUT ET HORIZONTAL",NULL},
/* 2548 */ { "FILET FIN VERS LE HAUT ET ÉPAIS VERS LE BAS ET HORIZONTAL",NULL},
/* 2549 */ { "FILET FIN VERS LA DROITE ET ÉPAIS VERS LA GAUCHE ET VERTICAL",NULL},
/* 254A */ { "FILET FIN VERS LA GAUCHE ET ÉPAIS VERS LA DROITE ET VERTICAL",NULL},
/* 254B */ { "FILET ÉPAIS VERTICAL ET HORIZONTAL",NULL},
/* 254C */ { "FILET FIN DOUBLEMENT TIRETÉ HORIZONTAL",NULL},
/* 254D */ { "FILET ÉPAIS DOUBLEMENT TIRETÉ HORIZONTAL",NULL},
/* 254E */ { "FILET FIN DOUBLEMENT TIRETÉ VERTICAL",NULL},
/* 254F */ { "FILET ÉPAIS DOUBLEMENT TIRETÉ VERTICAL",NULL},
/* 2550 */ { "FILET DOUBLE HORIZONTAL",NULL},
/* 2551 */ { "FILET DOUBLE VERTICAL",NULL},
/* 2552 */ { "FILET SIMPLE VERS LE BAS ET DOUBLE VERS LA DROITE",NULL},
/* 2553 */ { "FILET DOUBLE VERS LE BAS ET SIMPLE VERS LA DROITE",NULL},
/* 2554 */ { "FILET DOUBLE VERS LE BAS ET VERS LA DROITE",NULL},
/* 2555 */ { "FILET SIMPLE VERS LE BAS ET DOUBLE VERS LA GAUCHE",NULL},
/* 2556 */ { "FILET DOUBLE VERS LE BAS ET SIMPLE VERS LA GAUCHE",NULL},
/* 2557 */ { "FILET DOUBLE VERS LE BAS ET VERS LA GAUCHE",NULL},
/* 2558 */ { "FILET SIMPLE VERS LE HAUT ET DOUBLE VERS LA DROITE",NULL},
/* 2559 */ { "FILET DOUBLE VERS LE HAUT ET SIMPLE VERS LA DROITE",NULL},
/* 255A */ { "FILET DOUBLE VERS LE HAUT ET VERS LA DROITE",NULL},
/* 255B */ { "FILET SIMPLE VERS LE HAUT ET DOUBLE VERS LA GAUCHE",NULL},
/* 255C */ { "FILET DOUBLE VERS LE HAUT ET SIMPLE VERS LA GAUCHE",NULL},
/* 255D */ { "FILET DOUBLE VERS LE HAUT ET VERS LA GAUCHE",NULL},
/* 255E */ { "FILET SIMPLE VERTICAL ET DOUBLE VERS LA DROITE",NULL},
/* 255F */ { "FILET DOUBLE VERTICAL ET SIMPLE VERS LA DROITE",NULL},
/* 2560 */ { "FILET DOUBLE VERTICAL ET VERS LA DROITE",NULL},
/* 2561 */ { "FILET SIMPLE VERTICAL ET DOUBLE VERS LA GAUCHE",NULL},
/* 2562 */ { "FILET DOUBLE VERTICAL ET SIMPLE VERS LA GAUCHE",NULL},
/* 2563 */ { "FILET DOUBLE VERTICAL ET VERS LA GAUCHE",NULL},
/* 2564 */ { "FILET SIMPLE VERS LE BAS ET DOUBLE HORIZONTAL",NULL},
/* 2565 */ { "FILET DOUBLE VERS LE BAS ET SIMPLE HORIZONTAL",NULL},
/* 2566 */ { "FILET DOUBLE VERS LE BAS ET HORIZONTAL",NULL},
/* 2567 */ { "FILET SIMPLE VERS LE HAUT ET DOUBLE HORIZONTAL",NULL},
/* 2568 */ { "FILET DOUBLE VERS LE HAUT ET SIMPLE HORIZONTAL",NULL},
/* 2569 */ { "FILET DOUBLE VERS LE HAUT ET HORIZONTAL",NULL},
/* 256A */ { "FILET SIMPLE VERTICAL ET DOUBLE HORIZONTAL",NULL},
/* 256B */ { "FILET DOUBLE VERTICAL ET SIMPLE HORIZONTAL",NULL},
/* 256C */ { "FILET DOUBLE VERTICAL ET HORIZONTAL",NULL},
/* 256D */ { "FILET FIN ARQUÉ VERS LE BAS ET VERS LA DROITE",NULL},
/* 256E */ { "FILET FIN ARQUÉ VERS LE BAS ET VERS LA GAUCHE",NULL},
/* 256F */ { "FILET FIN ARQUÉ VERS LE HAUT ET VERS LA GAUCHE",NULL},
/* 2570 */ { "FILET FIN ARQUÉ VERS LE HAUT ET VERS LA DROITE",NULL},
/* 2571 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR DROIT AU COIN INFÉRIEUR GAUCHE","	= ligne diagonale tirée de droite à gauche\n"
	"	* pas destiné à représenter un symbole mathématique\n"
	"	x (barre oblique - 002F)\n"
	"	x (barre de fraction - 2044)\n"
	"	x (barre oblique de division - 2215)"},
/* 2572 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU COIN INFÉRIEUR DROIT","	= ligne diagonale tirée de gauche à droite\n"
	"	* pas destiné à représenter un symbole mathématique\n"
	"	x (barre oblique inversée - 005C)\n"
	"	x (différence d'ensembles - 2216)\n"
	"	x (opérateur barre oblique inversée - 29F5)"},
/* 2573 */ { "FILET FIN DIAGONAL EN CROIX","	x (sautoir - 2613)\n"
	"	x (x de multiplication - 2715)"},
/* 2574 */ { "FILET FIN VERS LA GAUCHE",NULL},
/* 2575 */ { "FILET FIN VERS LE HAUT",NULL},
/* 2576 */ { "FILET FIN VERS LA DROITE",NULL},
/* 2577 */ { "FILET FIN VERS LE BAS",NULL},
/* 2578 */ { "FILET ÉPAIS VERS LA GAUCHE",NULL},
/* 2579 */ { "FILET ÉPAIS VERS LE HAUT",NULL},
/* 257A */ { "FILET ÉPAIS VERS LA DROITE",NULL},
/* 257B */ { "FILET ÉPAIS VERS LE BAS",NULL},
/* 257C */ { "FILET FIN VERS LA GAUCHE ET ÉPAIS VERS LA DROITE",NULL},
/* 257D */ { "FILET FIN VERS LE HAUT ET ÉPAIS VERS LE BAS",NULL},
/* 257E */ { "FILET ÉPAIS VERS LA GAUCHE ET FIN VERS LA DROITE",NULL},
/* 257F */ { "FILET ÉPAIS VERS LE HAUT ET FIN VERS LE BAS",NULL},
/* 2580 */ { "MOITIÉ SUPÉRIEURE DE PAVÉ",NULL},
/* 2581 */ { "UN HUITIÈME INFÉRIEUR DE PAVÉ",NULL},
/* 2582 */ { "UN QUART INFÉRIEUR DE PAVÉ",NULL},
/* 2583 */ { "TROIS HUITIÈMES INFÉRIEURS DE PAVÉ",NULL},
/* 2584 */ { "MOITIÉ INFÉRIEURE DE PAVÉ",NULL},
/* 2585 */ { "CINQ HUITIÈMES INFÉRIEURS DE PAVÉ",NULL},
/* 2586 */ { "TROIS QUARTS INFÉRIEURS DE PAVÉ",NULL},
/* 2587 */ { "SEPT HUITIÈMES INFÉRIEURS DE PAVÉ",NULL},
/* 2588 */ { "PAVÉ PLEIN","	x (carré noir - 25A0)"},
/* 2589 */ { "SEPT HUITIÈMES GAUCHES DE PAVÉ",NULL},
/* 258A */ { "TROIS QUARTS GAUCHES DE PAVÉ",NULL},
/* 258B */ { "CINQ HUITIÈMES GAUCHES DE PAVÉ",NULL},
/* 258C */ { "MOITIÉ GAUCHE DE PAVÉ",NULL},
/* 258D */ { "TROIS HUITIÈMES GAUCHES DE PAVÉ",NULL},
/* 258E */ { "UN QUART GAUCHE DE PAVÉ",NULL},
/* 258F */ { "UN HUITIÈME GAUCHE DE PAVÉ",NULL},
/* 2590 */ { "MOITIÉ DROITE DE PAVÉ",NULL},
/* 2591 */ { "OMBRE LÉGÈRE","	* 25 %"},
/* 2592 */ { "OMBRE MOYENNE","	= remplissage de mouchetures, remplissage pointillé\n"
	"	* 50 %\n"
	"	* sert dans la correspondance avec cp949\n"
	"	x (ombre moyenne inversée - 1FB90)"},
/* 2593 */ { "OMBRE FONCÉE","	* 75 %"},
/* 2594 */ { "UN HUITIÈME SUPÉRIEUR DE PAVÉ",NULL},
/* 2595 */ { "UN HUITIÈME DROIT DE PAVÉ",NULL},
/* 2596 */ { "QUARTIER INFÉRIEUR GAUCHE",NULL},
/* 2597 */ { "QUARTIER INFÉRIEUR DROIT",NULL},
/* 2598 */ { "QUARTIER SUPÉRIEUR GAUCHE",NULL},
/* 2599 */ { "QUARTIERS SUPÉRIEUR GAUCHE ET INFÉRIEUR GAUCHE ET INFÉRIEUR DROIT",NULL},
/* 259A */ { "QUARTIERS SUPÉRIEUR GAUCHE ET INFÉRIEUR DROIT","	x (damier inversé - 1F67F)\n"
	"	x (remplissage échiqueté - 1FB95)"},
/* 259B */ { "QUARTIERS SUPÉRIEUR GAUCHE ET SUPÉRIEUR DROIT ET INFÉRIEUR GAUCHE",NULL},
/* 259C */ { "QUARTIERS SUPÉRIEUR GAUCHE ET SUPÉRIEUR DROIT ET INFÉRIEUR DROIT",NULL},
/* 259D */ { "QUARTIER SUPÉRIEUR DROIT",NULL},
/* 259E */ { "QUARTIERS SUPÉRIEUR DROIT ET INFÉRIEUR GAUCHE","	x (damier - 1F67E)\n"
	"	x (remplissage échiqueté inversé - 1FB96)"},
/* 259F */ { "QUARTIERS SUPÉRIEUR DROIT ET INFÉRIEUR GAUCHE ET INFÉRIEUR DROIT",NULL},
/* 25A0 */ { "CARRÉ NOIR","	= carré plein\n"
	"	= signe mòdîng (dans les textes idéographiques)\n"
	"	x (pavé plein - 2588)\n"
	"	x (grand carré noir - 2B1B)"},
/* 25A1 */ { "CARRÉ BLANC","	= carré vide\n"
	"	= quadrature astronomique\n"
	"	= symbole alchimique du sel\n"
	"	* utilisé dans des contextes astrologiques pour l'aspect carré\n"
	"	* peut servir à représenter un idéogramme manquant\n"
	"	x (diacritique carré englobant - 20DE)\n"
	"	x (carré moyen blanc - 25FB)\n"
	"	x (case de bulletin - 2610)\n"
	"	x (grand carré blanc - 2B1C)\n"
	"	x (signe geta - 3013)"},
/* 25A2 */ { "CARRÉ BLANC AUX COINS ARRONDIS",NULL},
/* 25A3 */ { "CARRÉ BLANC CONTENANT UN PETIT CARRÉ NOIR",NULL},
/* 25A4 */ { "CARRÉ HACHURÉ HORIZONTALEMENT","	= carré à rayures horizontales"},
/* 25A5 */ { "CARRÉ HACHURÉ VERTICALEMENT","	= carré à rayures verticales"},
/* 25A6 */ { "CARRÉ QUADRILLÉ",NULL},
/* 25A7 */ { "CARRÉ À RAYURES OBLIQUES DESCENDANT DE GAUCHE À DROITE","	x (remplissage à rayures obliques descendant de gauche à droite - 1FB98)"},
/* 25A8 */ { "CARRÉ À RAYURES OBLIQUES DESCENDANT DE DROITE À GAUCHE","	x (remplissage à rayures obliques descendant de droite à gauche - 1FB99)"},
/* 25A9 */ { "CARRÉ QUADRILLÉ EN DIAGONALE","	= carré losangé"},
/* 25AA */ { "PETIT CARRÉ NOIR","	= puce carrée\n"
	"	x (très petit carré noir - 2B1D)"},
/* 25AB */ { "PETIT CARRÉ BLANC","	x (très petit carré blanc - 2B1E)"},
/* 25AC */ { "RECTANGLE NOIR",NULL},
/* 25AD */ { "RECTANGLE BLANC",NULL},
/* 25AE */ { "RECTANGLE VERTICAL NOIR","	= billette noire\n"
	"	x (ce qu'il fallait démontrer - 220E)"},
/* 25AF */ { "RECTANGLE VERTICAL BLANC","	= billette blanche\n"
	"	x (symbole de fonction apl quadrat mince - 2337)\n"
	"	x (symbole de fonction apl quadrat - 2395)"},
/* 25B0 */ { "PARALLÉLOGRAMME NOIR",NULL},
/* 25B1 */ { "PARALLÉLOGRAMME BLANC",NULL},
/* 25B2 */ { "TRIANGLE NOIR POINTANT VERS LE HAUT","	x (triangle noir moyen pointant vers le haut - 23F6)\n"
	"	x (triangle moyen noir vers le haut centré - 2BC5)\n"
	"	x (triangle rouge pointant vers le haut - 1F53A)"},
/* 25B3 */ { "TRIANGLE BLANC POINTANT VERS LE HAUT","	x (diacritique triangle englobant pointant vers le haut - 20E4)\n"
	"	x (incrément - 2206)\n"
	"	x (triangle aux coins arrondis - 1F6C6)\n"
	"	x (symbole alchimique du feu - 1F702)"},
/* 25B4 */ { "PETIT TRIANGLE NOIR POINTANT VERS LE HAUT","	x (petit triangle rouge pointant vers le haut - 1F53C)"},
/* 25B5 */ { "PETIT TRIANGLE BLANC POINTANT VERS LE HAUT",NULL},
/* 25B6 */ { "TRIANGLE NOIR POINTANT VERS LA DROITE","	x (triangle noir moyen pointant vers la droite - 23F5)\n"
	"	x (triangle moyen noir vers la droite centré - 2BC8)"},
/* 25B7 */ { "TRIANGLE BLANC POINTANT VERS LA DROITE","	= restriction de codomaine en notation Z"},
/* 25B8 */ { "PETIT TRIANGLE NOIR POINTANT VERS LA DROITE","	x (puce triangulaire - 2023)"},
/* 25B9 */ { "PETIT TRIANGLE BLANC POINTANT VERS LA DROITE",NULL},
/* 25BA */ { "POINTEUR NOIR VERS LA DROITE",NULL},
/* 25BB */ { "POINTEUR BLANC VERS LA DROITE","	= indicateur de flèche avant\n"
	"	x (contient comme sous-groupe normal - 22B3)"},
/* 25BC */ { "TRIANGLE NOIR POINTANT VERS LE BAS","	x (triangle noir moyen pointant vers le bas - 23F7)\n"
	"	x (triangle moyen noir vers le bas centré - 2BC6)\n"
	"	x (triangle rouge pointant vers le bas - 1F53B)"},
/* 25BD */ { "TRIANGLE BLANC POINTANT VERS LE BAS","	= opérateur hamiltonien\n"
	"	x (nabla - 2207)\n"
	"	x (triangle épais blanc pointant vers le bas - 26DB)\n"
	"	x (symbole alchimique de l'eau - 1F704)"},
/* 25BE */ { "PETIT TRIANGLE NOIR POINTANT VERS LE BAS","	x (petit triangle rouge pointant vers le bas - 1F53D)"},
/* 25BF */ { "PETIT TRIANGLE BLANC POINTANT VERS LE BAS",NULL},
/* 25C0 */ { "TRIANGLE NOIR POINTANT VERS LA GAUCHE","	x (triangle noir moyen pointant vers la gauche - 23F4)\n"
	"	x (triangle moyen noir vers la gauche centré - 2BC7)"},
/* 25C1 */ { "TRIANGLE BLANC POINTANT VERS LA GAUCHE","	= restriction de domaine en notation Z"},
/* 25C2 */ { "PETIT TRIANGLE NOIR POINTANT VERS LA GAUCHE",NULL},
/* 25C3 */ { "PETIT TRIANGLE BLANC POINTANT VERS LA GAUCHE",NULL},
/* 25C4 */ { "POINTEUR NOIR VERS LA GAUCHE",NULL},
/* 25C5 */ { "POINTEUR BLANC VERS LA GAUCHE","	= indicateur de flèche arrière\n"
	"	x (sous-groupe normal de - 22B2)"},
/* 25C6 */ { "LOSANGE NOIR","	x (enseigne de carreau noire - 2666)\n"
	"	x (losange moyen noir - 2B25)\n"
	"	x (grand losange orange - 1F536)"},
/* 25C7 */ { "LOSANGE BLANC","	x (diacritique losange englobant - 20DF)\n"
	"	x (opérateur losange - 22C4)\n"
	"	x (enseigne de carreau blanche - 2662)\n"
	"	x (losange blanc à côtés concaves - 27E1)\n"
	"	x (losange moyen blanc - 2B26)\n"
	"	x (symbole alchimique du savon - 1F754)\n"
	"	x (filet fin tracé en losange - 1FBAE)"},
/* 25C8 */ { "LOSANGE BLANC CONTENANT UN PETIT LOSANGE NOIR","	= losange blanc avec petit losange noir en abyme, macle blanche"},
/* 25C9 */ { "CERCLE BLANC ÉVIDÉ","	= petit cercle noir inscrit dans un cercle blanc, annelet blanc, œil de poisson\n"
	"	= tainome (« œil de daurade », nom japonais pour cette puce typographique)"},
/* 25CA */ { "RHOMBE","	x (enseigne de carreau blanche - 2662)"},
/* 25CB */ { "CERCLE BLANC","	x (diacritique cercle englobant - 20DD)\n"
	"	x (grand cercle - 25EF)\n"
	"	x (cercle épais - 2B58)\n"
	"	x (zéro idéographique - 3007)\n"
	"	x (symbole de la pleine lune - 1F315)"},
/* 25CC */ { "CERCLE POINTILLÉ","	* remarquez que le glyphe-témoin utilisé pour ce caractère est à dessein plus grand que le glyphe circulaire pointillé qui est utilisé dans cette norme pour désigner un diacritique ; voir, par exemple, 0300"},
/* 25CD */ { "CERCLE HACHURÉ VERTICALEMENT",NULL},
/* 25CE */ { "DEUX CERCLES CONCENTRIQUES","	x (opérateur rond cerclé - 229A)\n"
	"	x (cercle épais avec cercle inscrit - 2B57)\n"
	"	x (coup direct - 1F3AF)\n"
	"	x (cible ronde - 1F78B)"},
/* 25CF */ { "CERCLE NOIR","	x (grand cercle noir - 2B24)\n"
	"	x (symbole de la nouvelle lune - 1F311)\n"
	"	x (grand cercle rouge - 1F534)"},
/* 25D0 */ { "CERCLE À MOITIÉ GAUCHE NOIRE","	x (symbole du premier quartier de lune - 1F313)"},
/* 25D1 */ { "CERCLE À MOITIÉ DROITE NOIRE","	x (symbole du dernier quartier de lune - 1F317)"},
/* 25D2 */ { "CERCLE À MOITIÉ INFÉRIEURE NOIRE",NULL},
/* 25D3 */ { "CERCLE À MOITIÉ SUPÉRIEURE NOIRE",NULL},
/* 25D4 */ { "CERCLE À QUADRANT SUPÉRIEUR DROIT NOIR",NULL},
/* 25D5 */ { "CERCLE À QUADRANT SUPÉRIEUR GAUCHE BLANC",NULL},
/* 25D6 */ { "DEMI-CERCLE GAUCHE NOIR",NULL},
/* 25D7 */ { "DEMI-CERCLE DROIT NOIR",NULL},
/* 25D8 */ { "PUCE NOIR AU BLANC","	x (puce - 2022)\n"
	"	x (puce blanche - 25E6)"},
/* 25D9 */ { "CERCLE NOIR AU BLANC",NULL},
/* 25DA */ { "DEMI-CERCLE SUPÉRIEUR NOIR AU BLANC",NULL},
/* 25DB */ { "DEMI-CERCLE INFÉRIEUR NOIR AU BLANC",NULL},
/* 25DC */ { "ARC DE CERCLE DANS LE QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 25DD */ { "ARC DE CERCLE DANS LE QUADRANT SUPÉRIEUR DROIT",NULL},
/* 25DE */ { "ARC DE CERCLE DANS LE QUADRANT INFÉRIEUR DROIT",NULL},
/* 25DF */ { "ARC DE CERCLE DANS LE QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 25E0 */ { "DEMI-CERCLE SUPÉRIEUR","	x (arc - 2312)"},
/* 25E1 */ { "DEMI-CERCLE INFÉRIEUR",NULL},
/* 25E2 */ { "COIN TRIANGULAIRE NOIR INFÉRIEUR DROIT","	x (ombre moyenne triangulaire inférieure droite - 1FB9E)"},
/* 25E3 */ { "COIN TRIANGULAIRE NOIR INFÉRIEUR GAUCHE","	x (ombre moyenne triangulaire inférieure gauche - 1FB9F)"},
/* 25E4 */ { "COIN TRIANGULAIRE NOIR SUPÉRIEUR GAUCHE","	x (ombre moyenne triangulaire supérieure gauche - 1FB9C)"},
/* 25E5 */ { "COIN TRIANGULAIRE NOIR SUPÉRIEUR DROIT","	x (ombre moyenne triangulaire supérieure droite - 1FB9D)"},
/* 25E6 */ { "PUCE BLANCHE","	x (puce - 2022)\n"
	"	x (opérateur rond - 2218)\n"
	"	x (puce noir au blanc - 25D8)"},
/* 25E7 */ { "CARRÉ À MOITIÉ GAUCHE NOIRE","	x (carré à moitié supérieure noire - 2B12)"},
/* 25E8 */ { "CARRÉ À MOITIÉ DROITE NOIRE",NULL},
/* 25E9 */ { "CARRÉ À MOITIÉ SUPÉRIEURE GAUCHE NOIRE",NULL},
/* 25EA */ { "CARRÉ À MOITIÉ INFÉRIEURE DROITE NOIRE",NULL},
/* 25EB */ { "CARRÉ BLANC À LIGNE BISSECTRICE VERTICALE",NULL},
/* 25EC */ { "TRIANGLE BLANC POINTANT VERS LE HAUT POINTÉ",NULL},
/* 25ED */ { "TRIANGLE POINTE VERS LE HAUT À MOITIÉ GAUCHE NOIRE",NULL},
/* 25EE */ { "TRIANGLE POINTE VERS LE HAUT À MOITIÉ DROITE NOIRE",NULL},
/* 25EF */ { "GRAND CERCLE","	x (diacritique cercle englobant - 20DD)\n"
	"	x (cercle blanc - 25CB)\n"
	"	x (grand cercle noir - 2B24)\n"
	"	x (grand cercle épais - 2B55)\n"
	"	x (zéro idéographique - 3007)"},
/* 25F0 */ { "CARRÉ BLANC À QUARTIER SUPÉRIEUR GAUCHE",NULL},
/* 25F1 */ { "CARRÉ BLANC À QUARTIER INFÉRIEUR GAUCHE",NULL},
/* 25F2 */ { "CARRÉ BLANC À QUARTIER INFÉRIEUR DROIT",NULL},
/* 25F3 */ { "CARRÉ BLANC À QUARTIER SUPÉRIEUR DROIT",NULL},
/* 25F4 */ { "CERCLE BLANC À QUARTIER SUPÉRIEUR GAUCHE",NULL},
/* 25F5 */ { "CERCLE BLANC À QUARTIER INFÉRIEUR GAUCHE",NULL},
/* 25F6 */ { "CERCLE BLANC À QUARTIER INFÉRIEUR DROIT",NULL},
/* 25F7 */ { "CERCLE BLANC À QUARTIER SUPÉRIEUR DROIT",NULL},
/* 25F8 */ { "TRIANGLE RECTANGLE SUPÉRIEUR GAUCHE",NULL},
/* 25F9 */ { "TRIANGLE RECTANGLE SUPÉRIEUR DROIT",NULL},
/* 25FA */ { "TRIANGLE RECTANGLE INFÉRIEUR GAUCHE","	x (triangle rectangle - 22BF)"},
/* 25FB */ { "CARRÉ MOYEN BLANC","	= toujours (opérateur modal)\n"
	"	x (carré blanc - 25A1)\n"
	"	x (carré blanc avec trait à gauche - 27E4)"},
/* 25FC */ { "CARRÉ MOYEN NOIR","	x (carré noir pour arrêt - 23F9)\n"
	"	x (carré noir - 25A0)"},
/* 25FD */ { "CARRÉ MODÉRÉMENT PETIT BLANC","	x (petit carré blanc - 25AB)"},
/* 25FE */ { "CARRÉ MODÉRÉMENT PETIT NOIR","	x (petit carré noir - 25AA)"},
/* 25FF */ { "TRIANGLE RECTANGLE INFÉRIEUR DROIT","	x (triangle rectangle - 22BF)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_26[] = {
/* 2600 */ { "SOLEIL NOIR AVEC RAYONS","	= temps clair\n"
	"	x (soleil - 2609)\n"
	"	x (symbole de la forte intensité - 1F506)"},
/* 2601 */ { "NUAGE","	= temps couvert"},
/* 2602 */ { "PARAPLUIE","	= temps pluvieux\n"
	"	x (parapluie fermé - 1F302)\n"
	"	x (nuage avec pluie - 1F327)"},
/* 2603 */ { "BONHOMME DE NEIGE","	= temps de neige"},
/* 2604 */ { "COMÈTE",NULL},
/* 2605 */ { "ÉTOILE NOIRE","	= étoile pleine\n"
	"	x (opérateur étoile - 22C6)\n"
	"	x (petite étoile noire - 2B51)\n"
	"	x (demi-étoile gauche noire - 2BE8)\n"
	"	x (étoile noire à cinq branches fine - 1F7C9)"},
/* 2606 */ { "ÉTOILE BLANCHE","	= étoile vide\n"
	"	x (étoile blanche à contour accentué - 2729)\n"
	"	x (étoile moyenne blanche - 2B50)\n"
	"	x (étoile brillante - 1F31F)"},
/* 2607 */ { "ÉCLAIR",NULL},
/* 2608 */ { "ORAGE",NULL},
/* 2609 */ { "SOLEIL","	= symbole alchimique de l'or\n"
	"	x (opérateur point cerclé - 2299)\n"
	"	x (soleil noir avec rayons - 2600)\n"
	"	x (soleil blanc avec rayons - 263C)\n"
	"	x (soleil avec visage - 1F31E)"},
/* 260A */ { "NŒUD ASCENDANT","	= symbole alchimique sublimer\n"
	"	x (symbole alchimique sublimer - 1F75E)"},
/* 260B */ { "NŒUD DESCENDANT","	= symbole alchimique purifier\n"
	"	x (symbole alchimique purifier - 1F763)"},
/* 260C */ { "CONJONCTION","	= symbole alchimique du jour\n"
	"	x (occultation - 1F775)"},
/* 260D */ { "OPPOSITION","	x (éclipse lunaire - 1F776)"},
/* 260E */ { "TÉLÉPHONE NOIR","	x (symbole téléphone - 2121)\n"
	"	x (symbole d'emplacement du téléphone - 2706)\n"
	"	x (récepteur téléphonique - 1F4DE)\n"
	"	x (téléphone à clavier noir - 1F57F)"},
/* 260F */ { "TÉLÉPHONE BLANC","	x (téléphone à clavier blanc - 1F57E)"},
/* 2610 */ { "CASE DE BULLETIN","	x (carré blanc - 25A1)"},
/* 2611 */ { "CASE DE BULLETIN MARQUÉE D'UNE COCHE","	= coche encadrée\n"
	"	x (case de bulletin marquée d'une coche grasse - 1F5F9)"},
/* 2612 */ { "CASE DE BULLETIN MARQUÉE D'UN X","	x (multiplié par encadré - 22A0)\n"
	"	x (x dans un rectangle - 2327)\n"
	"	x (case de bulletin marquée d'un x fin - 2BBD)\n"
	"	x (urne avec bulletin - 1F5F3)\n"
	"	x (case de bulletin marquée d'un x cursif - 1F5F5)"},
/* 2613 */ { "SAUTOIR","	= croix en sautoir, croix de saint André, croix décussée\n"
	"	x (x de vote - 2717)\n"
	"	x (sautoir fin - 1F7A9)"},
/* 2614 */ { "PARAPLUIE AVEC GOUTTES DE PLUIE","	= temps pluvieux"},
/* 2615 */ { "BOISSON CHAUDE","	= thé ou café selon le profil culturel\n"
	"	* peut indiquer une attente\n"
	"	x (montre - 231A)\n"
	"	x (sablier - 231B)\n"
	"	x (tasse à thé sans anse - 1F375)"},
/* 2616 */ { "PIÈCE DE CHOGI BLANCHE",NULL},
/* 2617 */ { "PIÈCE DE CHOGI NOIRE",NULL},
/* 2618 */ { "TRÈFLE IRLANDAIS","	x (trèfle à quatre feuilles - 1F340)"},
/* 2619 */ { "CŒUR FLORAL COUCHÉ À DROITE","	* marque de cahier en reliure, indice de collationnement\n"
	"	x (cœur floral couché - 2767)\n"
	"	x (feuille de vigne sud-ouest - 1F659)"},
/* 261A */ { "INDEX NOIR POINTANT VERS LA GAUCHE",NULL},
/* 261B */ { "INDEX NOIR POINTANT VERS LA DROITE",NULL},
/* 261C */ { "INDEX BLANC POINTANT VERS LA GAUCHE","	x (index de revers de main blanc pointant vers la gauche - 1F448)\n"
	"	x (index blanc pointant vers la gauche couché - 1F598)"},
/* 261D */ { "INDEX BLANC POINTANT VERS LE HAUT","	x (index blanc pointant vers le haut couché - 1F59E)"},
/* 261E */ { "INDEX BLANC POINTANT VERS LA DROITE","	= main (terme typographique)\n"
	"	x (index blanc pointant vers la droite couché - 1F599)\n"
	"	x (tiers gauche d'index blanc pointant vers la droite - 1FBC1)"},
/* 261F */ { "INDEX BLANC POINTANT VERS LE BAS","	x (index de la main gauche blanc pointant vers le bas - 1F597)\n"
	"	x (index blanc pointant vers le bas couché - 1F59F)"},
/* 2620 */ { "TÊTE DE MORT","	= poison, produit chimique toxique\n"
	"	x (tête de mort noire - 1F571)"},
/* 2621 */ { "VIRAGES",NULL},
/* 2622 */ { "SYMBOLE POUR RADIOACTIF",NULL},
/* 2623 */ { "SYMBOLE DANGER BIOLOGIQUE",NULL},
/* 2624 */ { "CADUCÉE","	* à multiples lovements\n"
	"	x (bâton serpentaire d'esculape - 2695)\n"
	"	x (symbole alchimique de la caducée - 1F750)"},
/* 2625 */ { "ANKH","	= croix égyptienne"},
/* 2626 */ { "CROIX ORTHODOXE",NULL},
/* 2627 */ { "CHRISME","	= khi rhô, croix de Constantin\n"
	"	x (symbole copte khi rhô - 2CE9)"},
/* 2628 */ { "CROIX DE LORRAINE",NULL},
/* 2629 */ { "CROIX DE JÉRUSALEM","	= croix à béquilles\n"
	"	* se distingue de la croix de Jérusalem réelle, qui est composée d'une grande croix grecque cantonnée de quatre petites croix, également grecques\n"
	"	x (symbole alchimique du vinaigre - 1F70A)"},
/* 262A */ { "ÉTOILE ET CROISSANT",NULL},
/* 262B */ { "SYMBOLE FARSI","	= symbole de l'Iran (1.0)"},
/* 262C */ { "ÂDI ÇAKTI","	= khanda\n"
	"	* symbole religieux du sikhisme\n"
	"	x (khanda - 1FAAF)"},
/* 262D */ { "FAUCILLE ET MARTEAU",NULL},
/* 262E */ { "SYMBOLE DE LA PAIX",NULL},
/* 262F */ { "YIN ET YANG","	x (symbole tibétain nor bou ñis 'khyil - 0FCA)"},
/* 2630 */ { "TRIGRAMME DU CIEL","	= ts'ien, qian2"},
/* 2631 */ { "TRIGRAMME DU LAC","	= touei, dui4"},
/* 2632 */ { "TRIGRAMME DU FEU","	= li, li2"},
/* 2633 */ { "TRIGRAMME DU TONNERRE","	= tchen, zhen4"},
/* 2634 */ { "TRIGRAMME DU VENT","	= hsiun, xun4"},
/* 2635 */ { "TRIGRAMME DE L'EAU","	= k'an, kan3"},
/* 2636 */ { "TRIGRAMME DE LA MONTAGNE","	= ken, gen4"},
/* 2637 */ { "TRIGRAMME DE LA TERRE","	= k'ouen, kun1"},
/* 2638 */ { "ROUE DE DHARMA","	x (symbole barre à roue - 2388)"},
/* 2639 */ { "VISAGE BLANC GRIMAÇANT","	x (visage légèrement grimaçant - 1F641)"},
/* 263A */ { "VISAGE BLANC SOURIANT","	= « Bonne journée ! »\n"
	"	x (visage légèrement souriant - 1F642)"},
/* 263B */ { "VISAGE NOIR SOURIANT",NULL},
/* 263C */ { "SOLEIL BLANC AVEC RAYONS","	= compas\n"
	"	x (soleil - 2609)\n"
	"	x (soleil avec visage - 1F31E)\n"
	"	x (soleil blanc - 1F323)\n"
	"	x (symbole de la forte intensité - 1F506)"},
/* 263D */ { "PREMIER QUARTIER DE LUNE","	= symbole alchimique de l'argent\n"
	"	x (symbole du premier quartier de lune - 1F313)"},
/* 263E */ { "DERNIER QUARTIER DE LUNE","	= symbole alchimique de l'argent\n"
	"	x (symbole mise en veille - 23FE)\n"
	"	x (symbole du dernier quartier de lune - 1F317)\n"
	"	x (croissant de lune - 1F319)"},
/* 263F */ { "MERCURE","	= symbole alchimique du vif-argent\n"
	"	= intersexuation, intersexualité"},
/* 2640 */ { "SIGNE FEMELLE","	= Vénus\n"
	"	= symbole alchimique du cuivre\n"
	"	x (femme - 1F469)\n"
	"	x (symbole femmes - 1F6BA)"},
/* 2641 */ { "TERRE","	= symbole alchimique de l'antimoine\n"
	"	x (symbole alchimique du vert-de-gris - 1F728)"},
/* 2642 */ { "SIGNE MÂLE","	= Mars\n"
	"	= symbole alchimique du fer\n"
	"	x (symbole passé - 2BFD)\n"
	"	x (homme - 1F468)\n"
	"	x (symbole hommes - 1F6B9)"},
/* 2643 */ { "JUPITER","	= symbole alchimique de l'étain"},
/* 2644 */ { "SATURNE","	= symbole alchimique du plomb"},
/* 2645 */ { "URANUS","	= symbole alchimique du platine\n"
	"	x (symbole astronomique d'uranus - 26E2)"},
/* 2646 */ { "NEPTUNE","	= symbole alchimique du bismuth (de l'étain de glace)\n"
	"	x (neptune forme deux - 2BC9)"},
/* 2647 */ { "PLUTON","	x (pluton forme deux - 2BD3)"},
/* 2648 */ { "BÉLIER","	x (bouc - 1F40F)"},
/* 2649 */ { "TAUREAU",NULL},
/* 264A */ { "GÉMEAUX",NULL},
/* 264B */ { "CANCER","	x (crabe - 1F980)"},
/* 264C */ { "LION","	x (face de lion - 1F981)"},
/* 264D */ { "VIERGE","	* variante de glyphe pour la goutte impériale et la goutte américaine, unités de volume appelées « minim »"},
/* 264E */ { "BALANCE","	x (balance de thémis - 2696)\n"
	"	x (symbole alchimique sublimer - 1F75E)"},
/* 264F */ { "SCORPION","	= goutte impériale, goutte américaine (unités de volume appelées « minim »)\n"
	"	x (symbole scorpion - 1F982)"},
/* 2650 */ { "SAGITTAIRE","	x (arc et flèche - 1F3F9)"},
/* 2651 */ { "CAPRICORNE",NULL},
/* 2652 */ { "VERSEAU","	x (amphore - 1F3FA)"},
/* 2653 */ { "POISSONS",NULL},
/* 2654 */ { "ROI BLANC DU JEU D'ÉCHECS",NULL},
/* 2655 */ { "DAME BLANCHE DU JEU D'ÉCHECS",NULL},
/* 2656 */ { "TOUR BLANCHE DU JEU D'ÉCHECS",NULL},
/* 2657 */ { "FOU BLANC DU JEU D'ÉCHECS",NULL},
/* 2658 */ { "CAVALIER BLANC DU JEU D'ÉCHECS",NULL},
/* 2659 */ { "PION BLANC DU JEU D'ÉCHECS",NULL},
/* 265A */ { "ROI NOIR DU JEU D'ÉCHECS",NULL},
/* 265B */ { "DAME NOIRE DU JEU D'ÉCHECS",NULL},
/* 265C */ { "TOUR NOIRE DU JEU D'ÉCHECS",NULL},
/* 265D */ { "FOU NOIR DU JEU D'ÉCHECS",NULL},
/* 265E */ { "CAVALIER NOIR DU JEU D'ÉCHECS",NULL},
/* 265F */ { "PION NOIR DU JEU D'ÉCHECS",NULL},
/* 2660 */ { "ENSEIGNE DE PIQUE NOIRE",NULL},
/* 2661 */ { "ENSEIGNE DE CŒUR BLANCHE",NULL},
/* 2662 */ { "ENSEIGNE DE CARREAU BLANCHE","	x (losange blanc - 25C7)\n"
	"	x (rhombe - 25CA)"},
/* 2663 */ { "ENSEIGNE DE TRÈFLE NOIRE","	x (trèfle irlandais - 2618)"},
/* 2664 */ { "ENSEIGNE DE PIQUE BLANCHE",NULL},
/* 2665 */ { "ENSEIGNE DE CŒUR NOIRE","	x (cœur noir épais - 2764)\n"
	"	x (cœur avec pointe à gauche - 1F394)\n"
	"	x (cœur bleu - 1F499)\n"
	"	x (cœur noir - 1F5A4)"},
/* 2666 */ { "ENSEIGNE DE CARREAU NOIRE","	x (losange noir - 25C6)"},
/* 2667 */ { "ENSEIGNE DE TRÈFLE BLANCHE",NULL},
/* 2668 */ { "SOURCES CHAUDES",NULL},
/* 2669 */ { "NOTE NOIRE","	x (symbole musical noire - 1D15F)"},
/* 266A */ { "NOTE CROCHE","	x (symbole musical croche - 1D160)\n"
	"	x (note de musique - 1F3B5)"},
/* 266B */ { "DEUX CROCHES RAMÉES","	x (notes de musique descendantes ramées - 1F39D)\n"
	"	x (notes de musique multiples - 1F3B6)"},
/* 266C */ { "DEUX DOUBLES CROCHES RAMÉES",NULL},
/* 266D */ { "BÉMOL",NULL},
/* 266E */ { "BÉCARRE",NULL},
/* 266F */ { "DIÈSE","	= cardinalité d'un sac, taille d'un ensemble en notation Z\n"
	"	x (croisillon - 0023)"},
/* 2670 */ { "CROIX SYRIAQUE OCCIDENTALE",NULL},
/* 2671 */ { "CROIX SYRIAQUE ORIENTALE",NULL},
/* 2672 */ { "SYMBOLE DE RECYCLAGE UNIVERSEL","	* utilisé comme symbole générique pour le recyclage ou pour indiquer qu'un produit est recyclable\n"
	"	* représenté par trois flèches dont chacune pointe vers l'empennage d'une des deux autres, de façon à constituer un ruban de Möbius en forme de triangle"},
/* 2673 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 1","	* polytéréphtalate d'éthylène (PET)"},
/* 2674 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 2","	* polyéthylène haute densité (PEHD)"},
/* 2675 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 3","	* vinyle, polychlorure de vinyle (PVC)"},
/* 2676 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 4","	* polyéthylène basse densité (PEBD)"},
/* 2677 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 5","	* polypropylène (PP, PPi)"},
/* 2678 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 6","	* polystyrène (PS)"},
/* 2679 */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES PLASTIQUES DE TYPE 7","	* autres matières plastiques"},
/* 267A */ { "SYMBOLE DE RECYCLAGE POUR MATIÈRES GÉNÉRIQUES","	* s'utilise en compagnie d'un texte ou d'un dessin supplémentaire pour indiquer le produit à recycler"},
/* 267B */ { "SYMBOLE DE RECYCLAGE UNIVERSEL NOIR","	x (flèches vers la droite et vers la gauche sens horaire en cercle ouvert - 1F501)"},
/* 267C */ { "SYMBOLE PAPIER RECYCLÉ","	* indique un composé à base de papier 100 % recyclé"},
/* 267D */ { "SYMBOLE PAPIER PARTIELLEMENT RECYCLÉ","	* le pourcentage de papier recyclé est imprimé au-dessus ou à côté de ce symbole"},
/* 267E */ { "SYMBOLE PAPIER PERMANENT","	= papier non acide"},
/* 267F */ { "SYMBOLE FAUTEUIL ROULANT","	= endroit accessible"},
/* 2680 */ { "FACE DE DÉ-1","	x (dé à jouer - 1F3B2)"},
/* 2681 */ { "FACE DE DÉ-2",NULL},
/* 2682 */ { "FACE DE DÉ-3",NULL},
/* 2683 */ { "FACE DE DÉ-4",NULL},
/* 2684 */ { "FACE DE DÉ-5",NULL},
/* 2685 */ { "FACE DE DÉ-6",NULL},
/* 2686 */ { "CERCLE BLANC AVEC POINT À DROITE",NULL},
/* 2687 */ { "CERCLE BLANC AVEC DEUX POINTS","	x (visage sans bouche - 1F636)"},
/* 2688 */ { "CERCLE NOIR AVEC POINT BLANC À DROITE",NULL},
/* 2689 */ { "CERCLE NOIR AVEC DEUX POINTS BLANCS",NULL},
/* 268A */ { "MONOGRAMME DU YANG",NULL},
/* 268B */ { "MONOGRAMME DU YIN",NULL},
/* 268C */ { "DIGRAMME DU GRAND YANG",NULL},
/* 268D */ { "DIGRAMME DU PETIT YIN",NULL},
/* 268E */ { "DIGRAMME DU PETIT YANG",NULL},
/* 268F */ { "DIGRAMME DU GRAND YIN",NULL},
/* 2690 */ { "DRAPEAU BLANC","	x (drapeau blanc battant au vent - 1F3F3)"},
/* 2691 */ { "DRAPEAU NOIR",NULL},
/* 2692 */ { "MARTEAU ET PIOCHE","	= mine, jour ouvré (dans les horaires ou indicateurs)\n"
	"	x (pioche - 26CF)\n"
	"	x (marteau et clé à écrous - 1F6E0)"},
/* 2693 */ { "ANCRE","	= terme nautique, port (sur les cartes)"},
/* 2694 */ { "ÉPÉES CROISÉES","	= terme militaire, champ de bataille (sur les cartes), tué au combat\n"
	"	x (escrimeur - 1F93A)"},
/* 2695 */ { "BÂTON SERPENTAIRE D'ESCULAPE","	= terme médical\n"
	"	* les deux formes de représentation de ce symbole, inclinée ou droite, sont pareillement répandues\n"
	"	x (caducée - 2624)\n"
	"	x (coupe d'hygie - 1F54F)"},
/* 2696 */ { "BALANCE DE THÉMIS","	= terme juridique, jurisprudence\n"
	"	x (balance - 264E)"},
/* 2697 */ { "ALAMBIC","	= terme chimique, chimie\n"
	"	x (symbole alchimique de la cornue - 1F76D)"},
/* 2698 */ { "FLEUR","	= terme botanique\n"
	"	x (point-fleur - 2055)\n"
	"	x (fleuron blanc - 2740)\n"
	"	x (tulipe - 1F337)"},
/* 2699 */ { "ROUE DENTÉE","	= technique, outils"},
/* 269A */ { "CADUCÉE D'HERMÈS","	* symbole du commerce comme de l'éloquence\n"
	"	* le glyphe représente un bâton héraldique agrémenté d'une roue ailée"},
/* 269B */ { "SYMBOLE ATOME","	= centrale nucléaire (sur les cartes)"},
/* 269C */ { "FLEUR DE LIS",NULL},
/* 269D */ { "ÉTOILE BLANCHE À CONTOUR","	* autre forme du pentagramme tressé (un symbole du Maroc)\n"
	"	x (pentagramme tressé à droite - 26E5)"},
/* 269E */ { "TROIS LIGNES CONVERGENTES VERS LA DROITE","	= voix de premier plan\n"
	"	x (trois rayons vers la gauche - 1F5E6)"},
/* 269F */ { "TROIS LIGNES CONVERGENTES VERS LA GAUCHE","	= voix d'arrière-plan\n"
	"	x (trois rayons vers la droite - 1F5E7)"},
/* 26A0 */ { "SIGNAL DE DANGER","	x (panneau octogonal - 1F6D1)"},
/* 26A1 */ { "SIGNAL DE HAUTE TENSION","	= tonnerre\n"
	"	= symbole de la foudre\n"
	"	x (humeur de foudre - 1F5F2)"},
/* 26A2 */ { "SIGNE FEMELLE DOUBLE","	= homosexualité féminine, saphisme\n"
	"	x (deux femmes se tenant par la main - 1F46D)"},
/* 26A3 */ { "SIGNE MÂLE DOUBLE","	= homosexualité masculine\n"
	"	* une variante de glyphe représente les deux cercles sur la même ligne\n"
	"	x (deux hommes se tenant par la main - 1F46C)"},
/* 26A4 */ { "SIGNE MÂLE ET FEMELLE ENLACÉS","	= hétérosexualité\n"
	"	* une variante de glyphe représente les deux cercles sur la même ligne"},
/* 26A5 */ { "SIGNE MÂLE ET FEMELLE","	= intersexe, androgyne\n"
	"	= hermaphrodite (en botanique)"},
/* 26A6 */ { "SIGNE MÂLE À TRAIT","	= transgenre\n"
	"	= peroxide de fer (alchimie et ancienne chimie)"},
/* 26A7 */ { "SIGNE MÂLE À TRAIT ET MÂLE ET FEMELLE","	= transgenre"},
/* 26A8 */ { "SIGNE MÂLE VERTICAL AVEC TRAIT","	= sulfate ferreux (alchimie et ancienne chimie)"},
/* 26A9 */ { "SIGNE MÂLE HORIZONTAL AVEC TRAIT","	= magnésium (alchimie et ancienne chimie)"},
/* 26AA */ { "CERCLE BLANC MOYEN","	= asexualité, asexué, sans-genre\n"
	"	= fiancé\n"
	"	* base des signes mâle et femelle\n"
	"	x (cercle blanc moyennement gras - 1F785)"},
/* 26AB */ { "CERCLE NOIR MOYEN","	* symbole d'interface utilisateur pour l'enregistrement\n"
	"	x (cercle noir pour enregistrement - 23FA)"},
/* 26AC */ { "CERCLE BLANC MODÉRÉMENT PETIT","	= fiancé (en généalogie)\n"
	"	* peut représenter l'alliance, l'anneau nuptial"},
/* 26AD */ { "SYMBOLE DU MARIAGE","	x (infini - 221E)\n"
	"	x (mariage - 1F492)"},
/* 26AE */ { "SYMBOLE DU DIVORCE","	x (infini nié par une barre verticale - 29DE)\n"
	"	x (symbole lié - 2BFA)"},
/* 26AF */ { "SYMBOLE DE COUPLE NON MARIÉ","	x (multijection à deux têtes - 29DF)\n"
	"	x (symbole non lié - 2BFB)"},
/* 26B0 */ { "CERCUEIL","	= enterré (généalogie)\n"
	"	x (rectangle blanc - 25AD)"},
/* 26B1 */ { "URNE FUNÉRAIRE","	= incinéré (généalogie)"},
/* 26B2 */ { "NEUTRE",NULL},
/* 26B3 */ { "CÉRÈS",NULL},
/* 26B4 */ { "PALLAS",NULL},
/* 26B5 */ { "JUNON",NULL},
/* 26B6 */ { "VESTA","	x (vesta forme deux - 1F777)"},
/* 26B7 */ { "CHIRON",NULL},
/* 26B8 */ { "LUNE NOIRE LILITH",NULL},
/* 26B9 */ { "SEXTILE","	* un aspect de 60 degrés\n"
	"	x (astérisque - 002A)\n"
	"	x (étoile noire à six branches - 2736)\n"
	"	x (symbole alchimique du sel ammoniac - 1F739)"},
/* 26BA */ { "DEMI-SEXTILE","	* un aspect de 30 degrés\n"
	"	x (ou exclusif - 22BB)"},
/* 26BB */ { "QUINCONCE","	* un aspect de 150 degrés\n"
	"	x (non et - 22BC)"},
/* 26BC */ { "SESQUICARRÉ","	* un aspect de 135 degrés"},
/* 26BD */ { "BALLON DE FOOTBALL",NULL},
/* 26BE */ { "BALLE DE BASEBALL",NULL},
/* 26BF */ { "CLÉ ENCADRÉE","	= contrôle parental\n"
	"	x (clé - 1F511)"},
/* 26C0 */ { "PION BLANC DE DAMES",NULL},
/* 26C1 */ { "DAME BLANCHE DE DAMES",NULL},
/* 26C2 */ { "PION NOIR DE DAMES",NULL},
/* 26C3 */ { "DAME NOIRE DE DAMES",NULL},
/* 26C4 */ { "BONHOMME DE NEIGE SANS NEIGE","	= neige peu abondante"},
/* 26C5 */ { "SOLEIL DERRIÈRE UN NUAGE","	= partiellement nuageux\n"
	"	x (soleil blanc avec petit nuage - 1F324)"},
/* 26C6 */ { "PLUIE","	= temps pluvieux"},
/* 26C7 */ { "BONHOMME DE NEIGE NOIR","	= neige abondante"},
/* 26C8 */ { "NUAGE ORAGEUX ET PLUIE","	= orage\n"
	"	x (nuage avec éclair - 1F329)"},
/* 26C9 */ { "PIÈCE DE CHOGI BLANCHE CULBUTÉE",NULL},
/* 26CA */ { "PIÈCE DE CHOGI NOIRE CULBUTÉE",NULL},
/* 26CB */ { "LOSANGE BLANC DANS UN CARRÉ","	x (symbole de fonction apl rideaux - 233A)"},
/* 26CC */ { "VOIES CROISÉES","	= accident\n"
	"	x (diagonale descendante sur diagonale montante - 292C)"},
/* 26CD */ { "VOITURE EN PANNE",NULL},
/* 26CE */ { "SERPENTAIRE",NULL},
/* 26CF */ { "PIOCHE","	= en construction\n"
	"	x (marteau et pioche - 2692)\n"
	"	x (panneau indicateur de construction - 1F6A7)"},
/* 26D0 */ { "VOITURE EN DÉRAPAGE","	= route verglacée"},
/* 26D1 */ { "CASQUE AVEC CROIX BLANCHE","	= maintenance, entretien\n"
	"	x (ouvrier de la construction - 1F477)"},
/* 26D2 */ { "VOIES CROISÉES CERCLÉES","	= route barrée\n"
	"	x (multiplié par cerclé - 2297)"},
/* 26D3 */ { "CHAÎNES","	= chaînes à neige obligatoires"},
/* 26D4 */ { "ENTRÉE INTERDITE","	x (panneau entrée interdite - 1F6AB)"},
/* 26D5 */ { "CIRCULATION ALTERNÉE SUR LA VOIE DE GAUCHE","	* conduite à gauche"},
/* 26D6 */ { "CIRCULATION BIDIRECTIONNELLE CONDUITE À GAUCHE NOIR","	* conduite à gauche"},
/* 26D7 */ { "CIRCULATION BIDIRECTIONNELLE CONDUITE À GAUCHE BLANC","	* conduite à gauche"},
/* 26D8 */ { "CONVERGENCE À GAUCHE NOIR","	* conduite à gauche"},
/* 26D9 */ { "CONVERGENCE À GAUCHE BLANC","	* conduite à gauche"},
/* 26DA */ { "PANNEAU ROULEZ LENTEMENT",NULL},
/* 26DB */ { "TRIANGLE ÉPAIS BLANC POINTANT VERS LE BAS","	= roulez lentement\n"
	"	x (triangle blanc pointant vers le bas - 25BD)"},
/* 26DC */ { "ENTRÉE À GAUCHE FERMÉE",NULL},
/* 26DD */ { "SAUTOIR ENCADRÉ","	= entrée fermée\n"
	"	x (multiplié par encadré - 22A0)"},
/* 26DE */ { "DIAGONALE DESCENDANTE DANS UN CERCLE BLANC SUR CARRÉ NOIR","	= interdit aux poids lourds"},
/* 26DF */ { "CAMION NOIR","	= interdit aux poids lourds (variante)\n"
	"	x (camion de livraison - 1F69A)"},
/* 26E0 */ { "ENTRÉE GAUCHE RESTREINTE-1",NULL},
/* 26E1 */ { "ENTRÉE GAUCHE RESTREINTE-2",NULL},
/* 26E2 */ { "SYMBOLE ASTRONOMIQUE D'URANUS","	x (uranus - 2645)"},
/* 26E3 */ { "CERCLE ÉPAIS AVEC BARRE VERTICALE ENTRE DEUX POINTS EN CHEF",NULL},
/* 26E4 */ { "PENTAGRAMME","	= pentalpha\n"
	"	* symbole pour différents usages, incluant le symbole sur le drapeau marocain\n"
	"	x (étoile blanche - 2606)"},
/* 26E5 */ { "PENTAGRAMME TRESSÉ À DROITE","	* symbole de divers pays, incluant le Maroc\n"
	"	x (étoile blanche à contour - 269D)"},
/* 26E6 */ { "PENTAGRAMME TRESSÉ À GAUCHE","	* symbole de divers pays, incluant l'Éthiopie"},
/* 26E7 */ { "PENTAGRAMME RENVERSÉ",NULL},
/* 26E8 */ { "CROIX NOIRE SUR BOUCLIER","	= hôpital\n"
	"	x (hôpital - 1F3E5)"},
/* 26E9 */ { "SANCTUAIRE SHINTOÏSTE","	= torii"},
/* 26EA */ { "ÉGLISE",NULL},
/* 26EB */ { "CHÂTEAU","	x (château européen - 1F3F0)"},
/* 26EC */ { "SITE HISTORIQUE","	x (par conséquent - 2234)"},
/* 26ED */ { "ROUE D'ENGRENAGE SANS MOYEU","	= usine\n"
	"	x (roue dentée - 2699)\n"
	"	x (usine - 1F3ED)"},
/* 26EE */ { "ROUE D'ENGRENAGE AVEC POIGNÉES","	= centrale électrique"},
/* 26EF */ { "SYMBOLE CARTOGRAPHIQUE DE PHARE",NULL},
/* 26F0 */ { "MONTAGNE","	x (cime enneigée - 1F3D4)"},
/* 26F1 */ { "PARAPLUIE AU SOL","	= plage de baignade\n"
	"	x (parapluie - 2602)\n"
	"	x (plage avec parasol - 1F3D6)"},
/* 26F2 */ { "FONTAINE","	= parc"},
/* 26F3 */ { "FANION DANS UN TROU","	= parcours de golf\n"
	"	x (fanion triangulaire de localisation - 1F6A9)"},
/* 26F4 */ { "BAC","	= terminal de ferry\n"
	"	x (navire - 1F6A2)"},
/* 26F5 */ { "VOILIER","	= port de plaisance\n"
	"	x (canot à rames - 1F6A3)"},
/* 26F6 */ { "QUATRE COINS EN CARRÉ","	= carrefour"},
/* 26F7 */ { "SKIEUR","	= station de ski\n"
	"	x (ski et botte de ski - 1F3BF)"},
/* 26F8 */ { "PATIN À GLACE","	= patinoire"},
/* 26F9 */ { "PERSONNE AVEC BALLON","	= complexe d'athlétisme, gymnase"},
/* 26FA */ { "TENTE","	= aire de camping\n"
	"	x (camping - 1F3D5)"},
/* 26FB */ { "SYMBOLE JAPONAIS DE BANQUE","	x (banque - 1F3E6)"},
/* 26FC */ { "SYMBOLE DE CIMETIÈRE","	= nécropole"},
/* 26FD */ { "POMPE À ESSENCE","	= station-service\n"
	"	= poste d'essence (Canada)"},
/* 26FE */ { "TASSE SUR CARRÉ NOIR","	= restoroute\n"
	"	x (boisson chaude - 2615)\n"
	"	x (tasse à thé sans anse - 1F375)"},
/* 26FF */ { "DRAPEAU BLANC À BANDE MÉDIANE HORIZONTALE NOIRE","	= site des forces japonaises d'autodéfense"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_27[] = {
/* 2700 */ { "CISEAUX DE SÉCURITÉ NOIRS","	* forme une paire avec 2704"},
/* 2701 */ { "CISEAUX À LAME SUPÉRIEURE VISIBLE",NULL},
/* 2702 */ { "CISEAUX NOIRS",NULL},
/* 2703 */ { "CISEAUX À LAME INFÉRIEURE VISIBLE",NULL},
/* 2704 */ { "CISEAUX BLANCS",NULL},
/* 2705 */ { "COCHE ÉPAISSE BLANCHE","	x (coche épaisse - 2714)"},
/* 2706 */ { "SYMBOLE D'EMPLACEMENT DU TÉLÉPHONE","	x (symbole téléphone - 2121)\n"
	"	x (récepteur téléphonique - 1F4DE)"},
/* 2707 */ { "DÉROULEUR DE RUBAN",NULL},
/* 2708 */ { "AVION","	x (avion pointant vers le haut - 1F6E7)"},
/* 2709 */ { "ENVELOPPE","	= enveloppe cachetée\n"
	"	x (enveloppe de réception - 1F4E8)\n"
	"	x (dos d'enveloppe - 1F582)"},
/* 270A */ { "POING LEVÉ","	= pierre ou roche (dans le jeu des trois coups)\n"
	"	x (signe du coup de poing - 1F44A)"},
/* 270B */ { "MAIN LEVÉE","	= papier ou feuille (dans le jeu des trois coups)\n"
	"	x (salut de la main - 1F44B)\n"
	"	x (main levée avec doigts écartés - 1F590)"},
/* 270C */ { "MAIN DE LA VICTOIRE","	= ciseaux (dans le jeu des trois coups)\n"
	"	x (main de dos faisant le signe de la victoire - 1F594)"},
/* 270D */ { "MAIN ÉCRIVANT","	= lettre manuscrite\n"
	"	x (main gauche écrivant - 1F58E)"},
/* 270E */ { "CRAYON VERS LE BAS À DROITE","	x (crayon vers le bas à gauche - 1F589)"},
/* 270F */ { "CRAYON",NULL},
/* 2710 */ { "CRAYON VERS LE HAUT À DROITE",NULL},
/* 2711 */ { "BEC DE PLUME BLANC","	x (stylo plume vers le bas à gauche - 1F58B)"},
/* 2712 */ { "BEC DE PLUME NOIR",NULL},
/* 2713 */ { "COCHE","	x (racine carrée - 221A)\n"
	"	x (coche mince - 1F5F8)\n"
	"	x (coche noir au blanc - 1FBB1)"},
/* 2714 */ { "COCHE ÉPAISSE",NULL},
/* 2715 */ { "X DE MULTIPLICATION","	x (signe de multiplication - 00D7)\n"
	"	x (filet fin diagonal en croix - 2573)\n"
	"	x (sautoir mince - 1F7A8)"},
/* 2716 */ { "X DE MULTIPLICATION ÉPAIS","	x (sautoir extrêmement épais - 1F7AE)"},
/* 2717 */ { "X DE VOTE","	x (sautoir - 2613)\n"
	"	x (x cursif de vote - 1F5F4)"},
/* 2718 */ { "X DE VOTE ÉPAIS","	x (x cursif de vote gras - 1F5F6)"},
/* 2719 */ { "CROIX GRECQUE AVEC CONTOUR",NULL},
/* 271A */ { "CROIX GRECQUE ÉPAISSE","	x (croix grecque très grasse - 1F7A5)\n"
	"	x (croix grecque évidée - 1FBBB)"},
/* 271B */ { "CROIX PERCÉE D'UN CARRÉ",NULL},
/* 271C */ { "CROIX ÉPAISSE PERCÉE D'UN CARRÉ",NULL},
/* 271D */ { "CROIX LATINE",NULL},
/* 271E */ { "CROIX LATINE BLANCHE OMBRÉE","	x (croix latine blanche - 1F546)"},
/* 271F */ { "CROIX LATINE AVEC CONTOUR",NULL},
/* 2720 */ { "CROIX DE MALTE","	* la croix de Malte a pris plusieurs formes ; le dessin du caractère présenté est semblable à celui de la croix pattée\n"
	"	x (croix pattée à bras horizontal droit - 2E50)\n"
	"	x (croix pattée cerclée - 1F902)"},
/* 2721 */ { "ÉTOILE DE DAVID","	x (étoile à six branches avec point médian - 1F52F)"},
/* 2722 */ { "CROIX LARMÉE",NULL},
/* 2723 */ { "CROIX POMMETÉE",NULL},
/* 2724 */ { "GROSSE CROIX POMMETÉE",NULL},
/* 2725 */ { "CROIX TRÉFLÉE",NULL},
/* 2726 */ { "ÉTOILE À QUATRE BRANCHES NOIRE","	x (valvule fine à quatre branches noire - 2BCC)\n"
	"	x (étoile noire à quatre branches - 1F7C6)"},
/* 2727 */ { "ÉTOILE À QUATRE BRANCHES BLANCHE","	x (valvule à quatre branches blanche - 2BCE)"},
/* 2728 */ { "SCINTILLEMENTS",NULL},
/* 2729 */ { "ÉTOILE BLANCHE À CONTOUR ACCENTUÉ","	x (étoile blanche - 2606)"},
/* 272A */ { "ÉTOILE BLANCHE CERCLÉE",NULL},
/* 272B */ { "MOLETTE NOIRE",NULL},
/* 272C */ { "MOLETTE BLANCHE",NULL},
/* 272D */ { "ÉTOILE NOIRE À CONTOUR",NULL},
/* 272E */ { "ÉTOILE NOIRE À CONTOUR ÉPAIS",NULL},
/* 272F */ { "ÉTOILE EN MOULINET",NULL},
/* 2730 */ { "ÉTOILE BLANCHE OMBRÉE",NULL},
/* 2731 */ { "GROS ASTÉRISQUE","	x (astérisque - 002A)\n"
	"	x (astérisque à six branches épais - 1F7B8)"},
/* 2732 */ { "ASTÉRISQUE PERCÉ",NULL},
/* 2733 */ { "ASTÉRISQUE À HUIT BRANCHES","	x (astérisque à huit branches fin - 1F7BB)"},
/* 2734 */ { "ÉTOILE NOIRE À HUIT BRANCHES",NULL},
/* 2735 */ { "ÉTOILE EN MOULINET À HUIT BRANCHES","	x (étoile en moulinet à huit branches épaisse - 1F7D1)"},
/* 2736 */ { "ÉTOILE NOIRE À SIX BRANCHES","	x (sextile - 26B9)"},
/* 2737 */ { "ÉTOILE RECTILIGNE À HUIT BRANCHES","	x (étoile noire à huit branches demi-grasse - 1F7CE)"},
/* 2738 */ { "GROSSE ÉTOILE RECTILIGNE À HUIT BRANCHES","	x (étoile noire à huit branches épaisse - 1F7CF)"},
/* 2739 */ { "ÉTOILE NOIRE À DOUZE BRANCHES",NULL},
/* 273A */ { "ASTÉRISQUE À SEIZE BRANCHES","	= étoile rayonnante\n"
	"	= feu d'artifice"},
/* 273B */ { "ASTÉRISQUE LARMÉ",NULL},
/* 273C */ { "ASTÉRISQUE LARMÉ PERCÉ",NULL},
/* 273D */ { "GROS ASTÉRISQUE LARMÉ",NULL},
/* 273E */ { "FLEURON NOIR ET BLANC À SIX PÉTALES",NULL},
/* 273F */ { "FLEURON NOIR",NULL},
/* 2740 */ { "FLEURON BLANC","	x (rosette - 1F3F5)\n"
	"	x (fleur blanche - 1F4AE)"},
/* 2741 */ { "FLEURON NOIR À CONTOUR À HUIT PÉTALES","	x (rosette noire - 1F3F6)"},
/* 2742 */ { "ÉTOILE CERCLÉE PERCÉE À HUIT BRANCHES",NULL},
/* 2743 */ { "GROS ASTÉRISQUE RAYONNANT LARMÉ",NULL},
/* 2744 */ { "FLOCON DE NEIGE",NULL},
/* 2745 */ { "FLOCON DE NEIGE À TROIS FOLIOLES TRANSPERCÉ","	= flocon trifolié resserré"},
/* 2746 */ { "GROS FLOCON DE NEIGE À CHEVRONS",NULL},
/* 2747 */ { "ÉTINCELLEMENT",NULL},
/* 2748 */ { "GROS ÉTINCELLEMENT",NULL},
/* 2749 */ { "ASTÉRISQUE POMMETÉ",NULL},
/* 274A */ { "ASTÉRISQUE-HÉLICE À HUIT BRANCHES LARMÉES",NULL},
/* 274B */ { "GROS ASTÉRISQUE-HÉLICE À HUIT BRANCHES LARMÉES",NULL},
/* 274C */ { "SIGNE EN FORME DE CROIX","	* forme une paire pour le décompte de jeu avec 2B55\n"
	"	x (signe de multiplication - 00D7)\n"
	"	x (x d'annulation - 1F5D9)\n"
	"	x (sautoir épais - 1F7AC)\n"
	"	x (sautoir blanc épais à coins arrondis - 1FBC0)"},
/* 274D */ { "CERCLE BLANC OMBRÉ","	x (cercle blanc ombré en bas à droite - 1F53E)"},
/* 274E */ { "SIGNE EN FORME DE CROIX ENCADRÉ NOIR AU BLANC","	x (diagonales blanches tracées en croix - 1FBBD)"},
/* 274F */ { "CARRÉ BLANC À OMBRE PROJETÉE SOUS LE COIN INFÉRIEUR DROIT",NULL},
/* 2750 */ { "CARRÉ BLANC À OMBRE PROJETÉE SOUS LE COIN SUPÉRIEUR DROIT",NULL},
/* 2751 */ { "CARRÉ BLANC OMBRÉ AU COIN INFÉRIEUR DROIT",NULL},
/* 2752 */ { "CARRÉ BLANC OMBRÉ AU COIN SUPÉRIEUR DROIT",NULL},
/* 2753 */ { "POINT D'INTERROGATION NOIR DE FANTAISIE",NULL},
/* 2754 */ { "POINT D'INTERROGATION BLANC DE FANTAISIE",NULL},
/* 2755 */ { "POINT D'EXCLAMATION BLANC DE FANTAISIE",NULL},
/* 2756 */ { "LOSANGE NOIR MARQUÉ D'UN X BLANC",NULL},
/* 2757 */ { "SYMBOLE POINT D'EXCLAMATION ÉPAIS","	= obstacles sur la route (ARIB STD-B24)"},
/* 2758 */ { "BARRE VERTICALE FINE","	x (barre verticale - 007C)"},
/* 2759 */ { "BARRE VERTICALE MOYENNE",NULL},
/* 275A */ { "BARRE VERTICALE ÉPAISSE",NULL},
/* 275B */ { "GUILLEMET DE FANTAISIE EN FORME DE GROSSE VIRGULE SIMPLE CULBUTÉE","	x (guillemet-apostrophe culbuté - 2018)"},
/* 275C */ { "GUILLEMET DE FANTAISIE EN FORME DE GROSSE VIRGULE SIMPLE","	x (guillemet-apostrophe - 2019)"},
/* 275D */ { "GUILLEMET DE FANTAISIE EN FORME DE GROSSE VIRGULE DOUBLE CULBUTÉE","	x (guillemet-apostrophe double culbuté - 201C)\n"
	"	x (guillemet de fantaisie en forme de grosse virgule double culbutée sans empattement - 1F676)"},
/* 275E */ { "GUILLEMET DE FANTAISIE EN FORME DE GROSSE VIRGULE DOUBLE","	x (guillemet-apostrophe double - 201D)\n"
	"	x (guillemet de fantaisie en forme de grosse virgule double sans empattement - 1F677)"},
/* 275F */ { "GUILLEMET INFÉRIEUR DE FANTAISIE EN FORME DE GROSSE VIRGULE SIMPLE","	x (guillemet-virgule inférieur - 201A)"},
/* 2760 */ { "GUILLEMET INFÉRIEUR DE FANTAISIE EN FORME DE GROSSE VIRGULE DOUBLE","	x (guillemet-virgule double inférieur - 201E)\n"
	"	x (guillemet inférieur de fantaisie en forme de grosse virgule double sans empattement - 1F678)"},
/* 2761 */ { "PIED-DE-MOUCHE DE FANTAISIE À JAMBAGE COURBÉ","	x (pied-de-mouche - 00B6)"},
/* 2762 */ { "POINT D'EXCLAMATION DE FANTAISIE ÉPAIS","	x (point d'exclamation - 0021)"},
/* 2763 */ { "POINT D'EXCLAMATION DE FANTAISIE ÉPAIS EN FORME DE CŒUR",NULL},
/* 2764 */ { "CŒUR NOIR ÉPAIS","	* affiché avec une couleur rouge lorsqu'il est utilisé dans le style émoji\n"
	"	x (enseigne de cœur noire - 2665)\n"
	"	x (cœur noir - 1F5A4)\n"
	"	x (cœur blanc - 1F90D)"},
/* 2765 */ { "CŒUR NOIR ÉPAIS COUCHÉ",NULL},
/* 2766 */ { "CŒUR FLORAL","	= feuille aldine"},
/* 2767 */ { "CŒUR FLORAL COUCHÉ","	= hedera (en épigraphie), feuille de lierre\n"
	"	* une marque de cahier en reliure, un indice de collationnement\n"
	"	x (cœur floral couché à droite - 2619)\n"
	"	x (feuille de vigne sud-est - 1F65B)"},
/* 2768 */ { "PARENTHÈSE DE FANTAISIE GAUCHE DEMI-GRASSE","	x (parenthèse gauche - 0028)"},
/* 2769 */ { "PARENTHÈSE DE FANTAISIE DROITE DEMI-GRASSE","	x (parenthèse droite - 0029)"},
/* 276A */ { "PARENTHÈSE DE FANTAISIE APLATIE GAUCHE DEMI-GRASSE",NULL},
/* 276B */ { "PARENTHÈSE DE FANTAISIE APLATIE DROITE DEMI-GRASSE",NULL},
/* 276C */ { "CHEVRON DE FANTAISIE POINTANT À GAUCHE DEMI-GRAS","	x (chevron pointant à gauche - 2329)"},
/* 276D */ { "CHEVRON DE FANTAISIE POINTANT À DROITE DEMI-GRAS","	x (chevron pointant à droite - 232A)"},
/* 276E */ { "GUILLEMET DE FANTAISIE GAUCHE ÉPAIS","	x (guillemet simple vers la gauche - 2039)"},
/* 276F */ { "GUILLEMET DE FANTAISIE DROIT ÉPAIS","	x (guillemet simple vers la droite - 203A)"},
/* 2770 */ { "CHEVRON DE FANTAISIE POINTANT À GAUCHE ÉPAIS",NULL},
/* 2771 */ { "CHEVRON DE FANTAISIE POINTANT À DROITE ÉPAIS",NULL},
/* 2772 */ { "CROCHET DE FANTAISIE EN ÉCAILLE GAUCHE MAIGRE","	x (crochet en écaille gauche - 3014)"},
/* 2773 */ { "CROCHET DE FANTAISIE EN ÉCAILLE DROIT MAIGRE","	x (crochet en écaille droit - 3015)"},
/* 2774 */ { "ACCOLADE DE FANTAISIE GAUCHE DEMI-GRASSE","	x (accolade gauche - 007B)"},
/* 2775 */ { "ACCOLADE DE FANTAISIE DROITE DEMI-GRASSE","	x (accolade droite - 007D)"},
/* 2776 */ { "VIGNETTE CHIFFRE UN CERCLÉ NOIR AU BLANC",NULL},
/* 2777 */ { "VIGNETTE CHIFFRE DEUX CERCLÉ NOIR AU BLANC",NULL},
/* 2778 */ { "VIGNETTE CHIFFRE TROIS CERCLÉ NOIR AU BLANC",NULL},
/* 2779 */ { "VIGNETTE CHIFFRE QUATRE CERCLÉ NOIR AU BLANC",NULL},
/* 277A */ { "VIGNETTE CHIFFRE CINQ CERCLÉ NOIR AU BLANC",NULL},
/* 277B */ { "VIGNETTE CHIFFRE SIX CERCLÉ NOIR AU BLANC",NULL},
/* 277C */ { "VIGNETTE CHIFFRE SEPT CERCLÉ NOIR AU BLANC",NULL},
/* 277D */ { "VIGNETTE CHIFFRE HUIT CERCLÉ NOIR AU BLANC",NULL},
/* 277E */ { "VIGNETTE CHIFFRE NEUF CERCLÉ NOIR AU BLANC",NULL},
/* 277F */ { "VIGNETTE NOMBRE DIX CERCLÉ NOIR AU BLANC",NULL},
/* 2780 */ { "VIGNETTE CHIFFRE UN SANS EMPATTEMENT CERCLÉ",NULL},
/* 2781 */ { "VIGNETTE CHIFFRE DEUX SANS EMPATTEMENT CERCLÉ",NULL},
/* 2782 */ { "VIGNETTE CHIFFRE TROIS SANS EMPATTEMENT CERCLÉ",NULL},
/* 2783 */ { "VIGNETTE CHIFFRE QUATRE SANS EMPATTEMENT CERCLÉ",NULL},
/* 2784 */ { "VIGNETTE CHIFFRE CINQ SANS EMPATTEMENT CERCLÉ",NULL},
/* 2785 */ { "VIGNETTE CHIFFRE SIX SANS EMPATTEMENT CERCLÉ",NULL},
/* 2786 */ { "VIGNETTE CHIFFRE SEPT SANS EMPATTEMENT CERCLÉ",NULL},
/* 2787 */ { "VIGNETTE CHIFFRE HUIT SANS EMPATTEMENT CERCLÉ",NULL},
/* 2788 */ { "VIGNETTE CHIFFRE NEUF SANS EMPATTEMENT CERCLÉ",NULL},
/* 2789 */ { "VIGNETTE NOMBRE DIX SANS EMPATTEMENT CERCLÉ",NULL},
/* 278A */ { "VIGNETTE CHIFFRE UN SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 278B */ { "VIGNETTE CHIFFRE DEUX SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 278C */ { "VIGNETTE CHIFFRE TROIS SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 278D */ { "VIGNETTE CHIFFRE QUATRE SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 278E */ { "VIGNETTE CHIFFRE CINQ SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 278F */ { "VIGNETTE CHIFFRE SIX SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 2790 */ { "VIGNETTE CHIFFRE SEPT SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 2791 */ { "VIGNETTE CHIFFRE HUIT SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 2792 */ { "VIGNETTE CHIFFRE NEUF SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 2793 */ { "VIGNETTE NOMBRE DIX SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 2794 */ { "FLÈCHE VERS LA DROITE ÉPAISSE À POINTE LARGE","	x (flèche demi-grasse à pointe large vers la droite - 1F872)"},
/* 2795 */ { "SIGNE PLUS ÉPAIS","	x (signe plus - 002B)"},
/* 2796 */ { "SIGNE MOINS ÉPAIS","	x (signe moins - 2212)"},
/* 2797 */ { "SIGNE DE DIVISION ÉPAIS","	x (signe de division - 00F7)"},
/* 2798 */ { "FLÈCHE SUD-EST ÉPAISSE",NULL},
/* 2799 */ { "FLÈCHE VERS LA DROITE ÉPAISSE",NULL},
/* 279A */ { "FLÈCHE NORD-EST ÉPAISSE",NULL},
/* 279B */ { "FLÈCHE DE TRAÇAGE VERS LA DROITE",NULL},
/* 279C */ { "FLÈCHE VERS LA DROITE ÉPAISSE À POINTE ARRONDIE",NULL},
/* 279D */ { "FLÈCHE VERS LA DROITE À POINTE EN TRIANGLE",NULL},
/* 279E */ { "FLÈCHE VERS LA DROITE ÉPAISSE À POINTE EN TRIANGLE",NULL},
/* 279F */ { "FLÈCHE VERS LA DROITE À POINTE EN TRIANGLE ET À TRAITS DISCONTINUS",NULL},
/* 27A0 */ { "FLÈCHE VERS LA DROITE ÉPAISSE À POINTE EN TRIANGLE ET À TRAITS DISCONTINUS",NULL},
/* 27A1 */ { "FLÈCHE VERS LA DROITE NOIRE","	* les polices peuvent harmoniser ce glyphe avec le style des autres flèches noires\n"
	"	x (flèche noire vers la gauche - 2B05)\n"
	"	x (flèche noire vers la droite - 2B95)"},
/* 27A2 */ { "POINTE DE FLÈCHE VERS LA DROITE EN TROMPE-L'ŒIL ÉCLAIRÉE PAR LE HAUT","	x (pointe de flèche équilatérale vers la droite en trompe-l'œil éclairée par le haut - 2B9A)"},
/* 27A3 */ { "POINTE DE FLÈCHE VERS LA DROITE EN TROMPE-L'ŒIL ÉCLAIRÉE PAR LE BAS",NULL},
/* 27A4 */ { "POINTE DE FLÈCHE NOIRE VERS LA DROITE","	x (pointe de flèche équilatérale noire vers la droite - 2B9E)\n"
	"	x (pointeur en forme de tête de flèche - 1FBB0)"},
/* 27A5 */ { "FLÈCHE NOIRE ÉPAISSE COURBÉE VERS LE BAS ET VERS LA DROITE","	x (flèche noire courbée vers le bas et vers la droite - 2BA9)"},
/* 27A6 */ { "FLÈCHE NOIRE ÉPAISSE COURBÉE VERS LE HAUT ET VERS LA DROITE","	x (flèche noire courbée vers le haut et vers la droite - 2BAB)"},
/* 27A7 */ { "FLÈCHE NOIRE TRAPUE VERS LA DROITE","	x (flèche comprimée épaisse vers la droite - 1F842)"},
/* 27A8 */ { "FLÈCHE NOIRE ÉPAISSE VERS LA DROITE À POINTE CONCAVE",NULL},
/* 27A9 */ { "FLÈCHE BLANCHE VERS LA DROITE OMBRÉE À L'AVANT","	x (flèche blanche ombrée à droite vers la droite - 1F8A5)"},
/* 27AA */ { "FLÈCHE BLANCHE VERS LA DROITE OMBRÉE À L'ARRIÈRE","	x (flèche blanche ombrée à gauche vers la droite - 1F8A7)"},
/* 27AB */ { "FLÈCHE BLANCHE VERS LA DROITE PENCHÉE VERS L'ARRIÈRE ET OMBRÉE","	x (flèche blanche ombrée vers la droite penchée vers l'arrière - 1F8A9)"},
/* 27AC */ { "FLÈCHE BLANCHE VERS LA DROITE PENCHÉE VERS L'AVANT ET OMBRÉE","	x (flèche blanche ombrée vers la droite penchée vers l'avant - 1F8AB)"},
/* 27AD */ { "FLÈCHE BLANCHE ÉPAISSE VERS LA DROITE OMBRÉE À L'AVANT ET PAR-DESSOUS",NULL},
/* 27AE */ { "FLÈCHE BLANCHE ÉPAISSE VERS LA DROITE OMBRÉE À L'AVANT ET PAR-DESSUS",NULL},
/* 27AF */ { "FLÈCHE ENCOCHÉE BLANCHE VERS LA DROITE OMBRÉE À L'AVANT ET PAR-DESSOUS","	x (flèche vers la droite à talon encoché - 1F89A)"},
/* 27B0 */ { "BOUCLE RECOURBÉE","	= kururi"},
/* 27B1 */ { "FLÈCHE ENCOCHÉE BLANCHE VERS LA DROITE OMBRÉE À L'AVANT ET PAR-DESSUS",NULL},
/* 27B2 */ { "FLÈCHE BLANCHE ÉPAISSE VERS LA DROITE À CONTOUR CIRCULAIRE",NULL},
/* 27B3 */ { "FLÈCHE VERS LA DROITE À EMPENNAGE BLANC",NULL},
/* 27B4 */ { "FLÈCHE SUD-EST À EMPENNAGE NOIR",NULL},
/* 27B5 */ { "FLÈCHE VERS LA DROITE À EMPENNAGE NOIR",NULL},
/* 27B6 */ { "FLÈCHE NORD-EST À EMPENNAGE NOIR",NULL},
/* 27B7 */ { "FLÈCHE ÉPAISSE SUD-EST À EMPENNAGE NOIR",NULL},
/* 27B8 */ { "FLÈCHE ÉPAISSE VERS LA DROITE À EMPENNAGE NOIR",NULL},
/* 27B9 */ { "FLÈCHE ÉPAISSE NORD-EST À EMPENNAGE NOIR",NULL},
/* 27BA */ { "FLÈCHE VERS LA DROITE À POINTE LARMÉE",NULL},
/* 27BB */ { "FLÈCHE ÉPAISSE VERS LA DROITE À TIGE LARMÉE",NULL},
/* 27BC */ { "FLÈCHE VERS LA DROITE À TALON EN FORME DE COIN",NULL},
/* 27BD */ { "FLÈCHE ÉPAISSE VERS LA DROITE À TALON EN FORME DE COIN",NULL},
/* 27BE */ { "FLÈCHE VERS LA DROITE À CONTOUR OUVERT",NULL},
/* 27BF */ { "DOUBLE BOUCLE RECOURBÉE",NULL},
/* 27C0 */ { "ANGLE TRIDIMENSIONNEL","	* utilisé par Euclide"},
/* 27C1 */ { "TRIANGLE BLANC CONTENANT UN PETIT TRIANGLE BLANC","	* utilisé par Euclide"},
/* 27C2 */ { "PERPENDICULAIRE À","	= orthogonal à\n"
	"	* relation, composé avec plus de blanc\n"
	"	x (taquet vers le haut - 22A5)"},
/* 27C3 */ { "SOUS-ENSEMBLE OUVERT",NULL},
/* 27C4 */ { "SUR-ENSEMBLE OUVERT",NULL},
/* 27C5 */ { "DÉLIMITEUR DE SAC EN S GAUCHE",NULL},
/* 27C6 */ { "DÉLIMITEUR DE SAC EN S DROITE",NULL},
/* 27C7 */ { "OU AVEC POINT INSCRIT","	x (ou logique - 2228)\n"
	"	x (multiplication de multiensemble - 228D)\n"
	"	x (et pointé - 27D1)"},
/* 27C8 */ { "SOUS-ENSEMBLE PRÉCÉDÉ D'UNE BARRE OBLIQUE INVERSÉE","	= sous-ensemble précédé d'une contre-oblique"},
/* 27C9 */ { "SUR-ENSEMBLE SUIVI D'UNE BARRE OBLIQUE","	= sur-ensemble suivi d'une oblique"},
/* 27CA */ { "BARRE VERTICALE À UNE TRAVERSE","	x (parallèle à vertical à une traverse - 2AF2)\n"
	"	x (triple barre verticale à une traverse - 2AF5)"},
/* 27CB */ { "DIAGONALE MATHÉMATIQUE ASCENDANTE","	= \\diagup\n"
	"	x (barre oblique de division - 2215)"},
/* 27CC */ { "POTENCE DE DIVISION","	* s'étend graphiquement au-dessus du numérateur\n"
	"	x (signe de division - 00F7)\n"
	"	x (barre oblique de division - 2215)\n"
	"	x (racine carrée - 221A)"},
/* 27CD */ { "DIAGONALE MATHÉMATIQUE DESCENDANTE","	= \\diagdown\n"
	"	x (différence d'ensembles - 2216)\n"
	"	x (opérateur barre oblique inversée - 29F5)"},
/* 27CE */ { "ET LOGIQUE ENCADRÉ","	= minimum de boîte\n"
	"	* opérateur de produit min morphologique\n"
	"	* opérateur d'érosion morphologique\n"
	"	* opérateur du minimum additif"},
/* 27CF */ { "OU LOGIQUE ENCADRÉ","	= maximum de boîte\n"
	"	* opérateur de produit max morphologique\n"
	"	* opérateur de dilatation morphologique\n"
	"	* opérateur du maximum additif"},
/* 27D0 */ { "LOSANGE BLANC À POINT CENTRÉ","	x (forme de losange avec un point inscrit - 1F4A0)"},
/* 27D1 */ { "ET POINTÉ","	x (et logique - 2227)\n"
	"	x (ou avec point inscrit - 27C7)\n"
	"	x (intersection pointée - 2A40)"},
/* 27D2 */ { "APPARTIENT À OUVERT VERS LE HAUT","	x (appartient à ouvert vers le bas - 2AD9)"},
/* 27D3 */ { "COIN INFÉRIEUR DROIT POINTÉ","	= retrait\n"
	"	x (plancher à droite - 230B)"},
/* 27D4 */ { "COIN SUPÉRIEUR GAUCHE POINTÉ","	= refoulement\n"
	"	x (plafond à gauche - 2308)"},
/* 27D5 */ { "JOINTURE EXTERNE GAUCHE",NULL},
/* 27D6 */ { "JOINTURE EXTERNE DROITE",NULL},
/* 27D7 */ { "JOINTURE EXTERNE COMPLÈTE","	x (jointure - 2A1D)"},
/* 27D8 */ { "GRAND TAQUET VERS LE HAUT","	x (taquet vers le haut - 22A5)"},
/* 27D9 */ { "GRAND TAQUET VERS LE BAS","	x (taquet vers le bas - 22A4)"},
/* 27DA */ { "DOUBLE TOURNIQUET BILATÉRAL","	x (vrai - 22A8)\n"
	"	x (double tourniquet gauche à barre verticale - 2AE4)"},
/* 27DB */ { "TOURNIQUET BILATÉRAL","	= taquets vers la gauche et vers la droite, taquet gauche-droite\n"
	"	x (taquet à droite - 22A2)"},
/* 27DC */ { "MULTIJECTION GAUCHE","	= multimap gauche\n"
	"	x (multijection - 22B8)"},
/* 27DD */ { "TAQUET À DROITE LONG","	x (taquet à droite - 22A2)"},
/* 27DE */ { "TAQUET À GAUCHE LONG","	x (taquet à gauche - 22A3)"},
/* 27DF */ { "TAQUET VERS LE HAUT SURMONTÉ D'UN CERCLE","	= élément radial\n"
	"	x (taquet vers le bas surmontant un cercle - 2AF1)"},
/* 27E0 */ { "RHOMBE COUPÉ","	* désigne une forme de possibilité en logique modale\n"
	"	x (rhombe - 25CA)"},
/* 27E1 */ { "LOSANGE BLANC À CÔTÉS CONCAVES","	= jamais (opérateur modal)\n"
	"	x (losange blanc - 25C7)"},
/* 27E2 */ { "LOSANGE BLANC À CÔTÉS CONCAVES AVEC TRAIT À GAUCHE","	= ne fut jamais (opérateur modal)"},
/* 27E3 */ { "LOSANGE BLANC À CÔTÉS CONCAVES AVEC TRAIT À DROITE","	= ne sera jamais (opérateur modal)"},
/* 27E4 */ { "CARRÉ BLANC AVEC TRAIT À GAUCHE","	= fut toujours (opérateur modal)\n"
	"	x (carré blanc - 25A1)\n"
	"	x (carré moyen blanc - 25FB)"},
/* 27E5 */ { "CARRÉ BLANC AVEC TRAIT À DROITE","	= sera à jamais (opérateur modal)"},
/* 27E6 */ { "CROCHET MATHÉMATIQUE BLANC GAUCHE","	= crochet de sac gauche en notation Z\n"
	"	x (crochet blanc gauche - 301A)"},
/* 27E7 */ { "CROCHET MATHÉMATIQUE BLANC DROIT","	= crochet de sac droit en notation Z\n"
	"	x (crochet blanc droit - 301B)"},
/* 27E8 */ { "CHEVRON MATHÉMATIQUE GAUCHE","	= bra ou vecteur bra (notation de Dirac)\n"
	"	= crochet de séquence gauche en notation Z\n"
	"	x (chevron pointant à gauche - 2329)\n"
	"	x (chevron gauche - 3008)"},
/* 27E9 */ { "CHEVRON MATHÉMATIQUE DROIT","	= ket ou vecteur ket (notation de Dirac)\n"
	"	= crochet de séquence droit en notation Z\n"
	"	x (chevron pointant à droite - 232A)\n"
	"	x (chevron droit - 3009)"},
/* 27EA */ { "DOUBLE CHEVRON MATHÉMATIQUE GAUCHE","	= chevron gauche en notation Z\n"
	"	x (double chevron gauche - 300A)"},
/* 27EB */ { "DOUBLE CHEVRON MATHÉMATIQUE DROIT","	= chevron droit en notation Z\n"
	"	x (double chevron droit - 300B)"},
/* 27EC */ { "CROCHET EN ÉCAILLE MATHÉMATIQUE BLANC GAUCHE","	x (crochet en écaille noir gauche - 2997)\n"
	"	x (crochet en écaille blanc gauche - 3018)"},
/* 27ED */ { "CROCHET EN ÉCAILLE MATHÉMATIQUE BLANC DROIT","	x (crochet en écaille noir droit - 2998)\n"
	"	x (crochet en écaille blanc droit - 3019)"},
/* 27EE */ { "PARENTHÈSE MATHÉMATIQUE APLATIE GAUCHE","	= lgroup"},
/* 27EF */ { "PARENTHÈSE MATHÉMATIQUE APLATIE DROITE","	= rgroup"},
/* 27F0 */ { "QUADRUPLE FLÈCHE VERS LE HAUT","	x (triple flèche vers le haut - 290A)\n"
	"	x (quadruple flèche vers la gauche - 2B45)"},
/* 27F1 */ { "QUADRUPLE FLÈCHE VERS LE BAS","	x (triple flèche vers le bas - 290B)"},
/* 27F2 */ { "FLÈCHE CIRCULAIRE ENTROUVERTE SENS ANTIHORAIRE","	x (flèche circulaire ouverte sens antihoraire - 21BA)\n"
	"	x (cercle fléché sens antihoraire - 2940)"},
/* 27F3 */ { "FLÈCHE CIRCULAIRE ENTROUVERTE SENS HORAIRE","	x (flèche circulaire ouverte sens horaire - 21BB)\n"
	"	x (cercle fléché sens horaire - 2941)"},
/* 27F4 */ { "FLÈCHE VERS LA DROITE À SIGNE PLUS CERCLÉ","	x (flèche vers la gauche à signe plus cerclé - 2B32)"},
/* 27F5 */ { "FLÈCHE LONGUE VERS LA GAUCHE","	x (flèche vers la gauche - 2190)"},
/* 27F6 */ { "FLÈCHE LONGUE VERS LA DROITE","	x (flèche vers la droite - 2192)"},
/* 27F7 */ { "FLÈCHE LONGUE GAUCHE-DROITE","	x (flèche gauche-droite - 2194)"},
/* 27F8 */ { "DOUBLE FLÈCHE LONGUE VERS LA GAUCHE","	x (double flèche vers la gauche - 21D0)"},
/* 27F9 */ { "DOUBLE FLÈCHE LONGUE VERS LA DROITE","	x (double flèche vers la droite - 21D2)"},
/* 27FA */ { "DOUBLE FLÈCHE LONGUE GAUCHE-DROITE","	x (double flèche gauche-droite - 21D4)"},
/* 27FB */ { "FLÈCHE LONGUE D'UN TAQUET VERS LA GAUCHE","	= est l'image de\n"
	"	x (flèche d'un taquet vers la gauche - 21A4)"},
/* 27FC */ { "FLÈCHE LONGUE D'UN TAQUET VERS LA DROITE","	= a pour image\n"
	"	x (flèche d'un taquet vers la droite - 21A6)"},
/* 27FD */ { "DOUBLE FLÈCHE LONGUE D'UN TAQUET VERS LA GAUCHE","	x (double flèche d'un taquet vers la gauche - 2906)"},
/* 27FE */ { "DOUBLE FLÈCHE LONGUE D'UN TAQUET VERS LA DROITE","	x (double flèche d'un taquet vers la droite - 2907)"},
/* 27FF */ { "FLÈCHE LONGUE VERS LA DROITE EN TIRE-BOUCHON","	= flèche longue droite dentée\n"
	"	x (flèche vers la droite en tire-bouchon - 21DD)\n"
	"	x (flèche longue vers la gauche en tire-bouchon - 2B33)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_28[] = {
/* 2800 */ { "COMBINAISON BRAILLE BLANC","	* bien que ce caractère soit représenté par un blanc à chasse fixe dans de nombreuses polices, il ne joue pas le rôle d'une espace"},
/* 2801 */ { "COMBINAISON BRAILLE POINTS-1",NULL},
/* 2802 */ { "COMBINAISON BRAILLE POINTS-2",NULL},
/* 2803 */ { "COMBINAISON BRAILLE POINTS-12",NULL},
/* 2804 */ { "COMBINAISON BRAILLE POINTS-3",NULL},
/* 2805 */ { "COMBINAISON BRAILLE POINTS-13",NULL},
/* 2806 */ { "COMBINAISON BRAILLE POINTS-23",NULL},
/* 2807 */ { "COMBINAISON BRAILLE POINTS-123",NULL},
/* 2808 */ { "COMBINAISON BRAILLE POINTS-4",NULL},
/* 2809 */ { "COMBINAISON BRAILLE POINTS-14",NULL},
/* 280A */ { "COMBINAISON BRAILLE POINTS-24",NULL},
/* 280B */ { "COMBINAISON BRAILLE POINTS-124",NULL},
/* 280C */ { "COMBINAISON BRAILLE POINTS-34",NULL},
/* 280D */ { "COMBINAISON BRAILLE POINTS-134",NULL},
/* 280E */ { "COMBINAISON BRAILLE POINTS-234",NULL},
/* 280F */ { "COMBINAISON BRAILLE POINTS-1234",NULL},
/* 2810 */ { "COMBINAISON BRAILLE POINTS-5",NULL},
/* 2811 */ { "COMBINAISON BRAILLE POINTS-15",NULL},
/* 2812 */ { "COMBINAISON BRAILLE POINTS-25",NULL},
/* 2813 */ { "COMBINAISON BRAILLE POINTS-125",NULL},
/* 2814 */ { "COMBINAISON BRAILLE POINTS-35",NULL},
/* 2815 */ { "COMBINAISON BRAILLE POINTS-135",NULL},
/* 2816 */ { "COMBINAISON BRAILLE POINTS-235",NULL},
/* 2817 */ { "COMBINAISON BRAILLE POINTS-1235",NULL},
/* 2818 */ { "COMBINAISON BRAILLE POINTS-45",NULL},
/* 2819 */ { "COMBINAISON BRAILLE POINTS-145",NULL},
/* 281A */ { "COMBINAISON BRAILLE POINTS-245",NULL},
/* 281B */ { "COMBINAISON BRAILLE POINTS-1245",NULL},
/* 281C */ { "COMBINAISON BRAILLE POINTS-345",NULL},
/* 281D */ { "COMBINAISON BRAILLE POINTS-1345",NULL},
/* 281E */ { "COMBINAISON BRAILLE POINTS-2345",NULL},
/* 281F */ { "COMBINAISON BRAILLE POINTS-12345",NULL},
/* 2820 */ { "COMBINAISON BRAILLE POINTS-6",NULL},
/* 2821 */ { "COMBINAISON BRAILLE POINTS-16",NULL},
/* 2822 */ { "COMBINAISON BRAILLE POINTS-26",NULL},
/* 2823 */ { "COMBINAISON BRAILLE POINTS-126",NULL},
/* 2824 */ { "COMBINAISON BRAILLE POINTS-36",NULL},
/* 2825 */ { "COMBINAISON BRAILLE POINTS-136",NULL},
/* 2826 */ { "COMBINAISON BRAILLE POINTS-236",NULL},
/* 2827 */ { "COMBINAISON BRAILLE POINTS-1236",NULL},
/* 2828 */ { "COMBINAISON BRAILLE POINTS-46",NULL},
/* 2829 */ { "COMBINAISON BRAILLE POINTS-146",NULL},
/* 282A */ { "COMBINAISON BRAILLE POINTS-246",NULL},
/* 282B */ { "COMBINAISON BRAILLE POINTS-1246",NULL},
/* 282C */ { "COMBINAISON BRAILLE POINTS-346",NULL},
/* 282D */ { "COMBINAISON BRAILLE POINTS-1346",NULL},
/* 282E */ { "COMBINAISON BRAILLE POINTS-2346",NULL},
/* 282F */ { "COMBINAISON BRAILLE POINTS-12346",NULL},
/* 2830 */ { "COMBINAISON BRAILLE POINTS-56",NULL},
/* 2831 */ { "COMBINAISON BRAILLE POINTS-156",NULL},
/* 2832 */ { "COMBINAISON BRAILLE POINTS-256",NULL},
/* 2833 */ { "COMBINAISON BRAILLE POINTS-1256",NULL},
/* 2834 */ { "COMBINAISON BRAILLE POINTS-356",NULL},
/* 2835 */ { "COMBINAISON BRAILLE POINTS-1356",NULL},
/* 2836 */ { "COMBINAISON BRAILLE POINTS-2356",NULL},
/* 2837 */ { "COMBINAISON BRAILLE POINTS-12356",NULL},
/* 2838 */ { "COMBINAISON BRAILLE POINTS-456",NULL},
/* 2839 */ { "COMBINAISON BRAILLE POINTS-1456",NULL},
/* 283A */ { "COMBINAISON BRAILLE POINTS-2456",NULL},
/* 283B */ { "COMBINAISON BRAILLE POINTS-12456",NULL},
/* 283C */ { "COMBINAISON BRAILLE POINTS-3456",NULL},
/* 283D */ { "COMBINAISON BRAILLE POINTS-13456",NULL},
/* 283E */ { "COMBINAISON BRAILLE POINTS-23456",NULL},
/* 283F */ { "COMBINAISON BRAILLE POINTS-123456",NULL},
/* 2840 */ { "COMBINAISON BRAILLE POINTS-7",NULL},
/* 2841 */ { "COMBINAISON BRAILLE POINTS-17",NULL},
/* 2842 */ { "COMBINAISON BRAILLE POINTS-27",NULL},
/* 2843 */ { "COMBINAISON BRAILLE POINTS-127",NULL},
/* 2844 */ { "COMBINAISON BRAILLE POINTS-37",NULL},
/* 2845 */ { "COMBINAISON BRAILLE POINTS-137",NULL},
/* 2846 */ { "COMBINAISON BRAILLE POINTS-237",NULL},
/* 2847 */ { "COMBINAISON BRAILLE POINTS-1237",NULL},
/* 2848 */ { "COMBINAISON BRAILLE POINTS-47",NULL},
/* 2849 */ { "COMBINAISON BRAILLE POINTS-147",NULL},
/* 284A */ { "COMBINAISON BRAILLE POINTS-247",NULL},
/* 284B */ { "COMBINAISON BRAILLE POINTS-1247",NULL},
/* 284C */ { "COMBINAISON BRAILLE POINTS-347",NULL},
/* 284D */ { "COMBINAISON BRAILLE POINTS-1347",NULL},
/* 284E */ { "COMBINAISON BRAILLE POINTS-2347",NULL},
/* 284F */ { "COMBINAISON BRAILLE POINTS-12347",NULL},
/* 2850 */ { "COMBINAISON BRAILLE POINTS-57",NULL},
/* 2851 */ { "COMBINAISON BRAILLE POINTS-157",NULL},
/* 2852 */ { "COMBINAISON BRAILLE POINTS-257",NULL},
/* 2853 */ { "COMBINAISON BRAILLE POINTS-1257",NULL},
/* 2854 */ { "COMBINAISON BRAILLE POINTS-357",NULL},
/* 2855 */ { "COMBINAISON BRAILLE POINTS-1357",NULL},
/* 2856 */ { "COMBINAISON BRAILLE POINTS-2357",NULL},
/* 2857 */ { "COMBINAISON BRAILLE POINTS-12357",NULL},
/* 2858 */ { "COMBINAISON BRAILLE POINTS-457",NULL},
/* 2859 */ { "COMBINAISON BRAILLE POINTS-1457",NULL},
/* 285A */ { "COMBINAISON BRAILLE POINTS-2457",NULL},
/* 285B */ { "COMBINAISON BRAILLE POINTS-12457",NULL},
/* 285C */ { "COMBINAISON BRAILLE POINTS-3457",NULL},
/* 285D */ { "COMBINAISON BRAILLE POINTS-13457",NULL},
/* 285E */ { "COMBINAISON BRAILLE POINTS-23457",NULL},
/* 285F */ { "COMBINAISON BRAILLE POINTS-123457",NULL},
/* 2860 */ { "COMBINAISON BRAILLE POINTS-67",NULL},
/* 2861 */ { "COMBINAISON BRAILLE POINTS-167",NULL},
/* 2862 */ { "COMBINAISON BRAILLE POINTS-267",NULL},
/* 2863 */ { "COMBINAISON BRAILLE POINTS-1267",NULL},
/* 2864 */ { "COMBINAISON BRAILLE POINTS-367",NULL},
/* 2865 */ { "COMBINAISON BRAILLE POINTS-1367",NULL},
/* 2866 */ { "COMBINAISON BRAILLE POINTS-2367",NULL},
/* 2867 */ { "COMBINAISON BRAILLE POINTS-12367",NULL},
/* 2868 */ { "COMBINAISON BRAILLE POINTS-467",NULL},
/* 2869 */ { "COMBINAISON BRAILLE POINTS-1467",NULL},
/* 286A */ { "COMBINAISON BRAILLE POINTS-2467",NULL},
/* 286B */ { "COMBINAISON BRAILLE POINTS-12467",NULL},
/* 286C */ { "COMBINAISON BRAILLE POINTS-3467",NULL},
/* 286D */ { "COMBINAISON BRAILLE POINTS-13467",NULL},
/* 286E */ { "COMBINAISON BRAILLE POINTS-23467",NULL},
/* 286F */ { "COMBINAISON BRAILLE POINTS-123467",NULL},
/* 2870 */ { "COMBINAISON BRAILLE POINTS-567",NULL},
/* 2871 */ { "COMBINAISON BRAILLE POINTS-1567",NULL},
/* 2872 */ { "COMBINAISON BRAILLE POINTS-2567",NULL},
/* 2873 */ { "COMBINAISON BRAILLE POINTS-12567",NULL},
/* 2874 */ { "COMBINAISON BRAILLE POINTS-3567",NULL},
/* 2875 */ { "COMBINAISON BRAILLE POINTS-13567",NULL},
/* 2876 */ { "COMBINAISON BRAILLE POINTS-23567",NULL},
/* 2877 */ { "COMBINAISON BRAILLE POINTS-123567",NULL},
/* 2878 */ { "COMBINAISON BRAILLE POINTS-4567",NULL},
/* 2879 */ { "COMBINAISON BRAILLE POINTS-14567",NULL},
/* 287A */ { "COMBINAISON BRAILLE POINTS-24567",NULL},
/* 287B */ { "COMBINAISON BRAILLE POINTS-124567",NULL},
/* 287C */ { "COMBINAISON BRAILLE POINTS-34567",NULL},
/* 287D */ { "COMBINAISON BRAILLE POINTS-134567",NULL},
/* 287E */ { "COMBINAISON BRAILLE POINTS-234567",NULL},
/* 287F */ { "COMBINAISON BRAILLE POINTS-1234567",NULL},
/* 2880 */ { "COMBINAISON BRAILLE POINTS-8",NULL},
/* 2881 */ { "COMBINAISON BRAILLE POINTS-18",NULL},
/* 2882 */ { "COMBINAISON BRAILLE POINTS-28",NULL},
/* 2883 */ { "COMBINAISON BRAILLE POINTS-128",NULL},
/* 2884 */ { "COMBINAISON BRAILLE POINTS-38",NULL},
/* 2885 */ { "COMBINAISON BRAILLE POINTS-138",NULL},
/* 2886 */ { "COMBINAISON BRAILLE POINTS-238",NULL},
/* 2887 */ { "COMBINAISON BRAILLE POINTS-1238",NULL},
/* 2888 */ { "COMBINAISON BRAILLE POINTS-48",NULL},
/* 2889 */ { "COMBINAISON BRAILLE POINTS-148",NULL},
/* 288A */ { "COMBINAISON BRAILLE POINTS-248",NULL},
/* 288B */ { "COMBINAISON BRAILLE POINTS-1248",NULL},
/* 288C */ { "COMBINAISON BRAILLE POINTS-348",NULL},
/* 288D */ { "COMBINAISON BRAILLE POINTS-1348",NULL},
/* 288E */ { "COMBINAISON BRAILLE POINTS-2348",NULL},
/* 288F */ { "COMBINAISON BRAILLE POINTS-12348",NULL},
/* 2890 */ { "COMBINAISON BRAILLE POINTS-58",NULL},
/* 2891 */ { "COMBINAISON BRAILLE POINTS-158",NULL},
/* 2892 */ { "COMBINAISON BRAILLE POINTS-258",NULL},
/* 2893 */ { "COMBINAISON BRAILLE POINTS-1258",NULL},
/* 2894 */ { "COMBINAISON BRAILLE POINTS-358",NULL},
/* 2895 */ { "COMBINAISON BRAILLE POINTS-1358",NULL},
/* 2896 */ { "COMBINAISON BRAILLE POINTS-2358",NULL},
/* 2897 */ { "COMBINAISON BRAILLE POINTS-12358",NULL},
/* 2898 */ { "COMBINAISON BRAILLE POINTS-458",NULL},
/* 2899 */ { "COMBINAISON BRAILLE POINTS-1458",NULL},
/* 289A */ { "COMBINAISON BRAILLE POINTS-2458",NULL},
/* 289B */ { "COMBINAISON BRAILLE POINTS-12458",NULL},
/* 289C */ { "COMBINAISON BRAILLE POINTS-3458",NULL},
/* 289D */ { "COMBINAISON BRAILLE POINTS-13458",NULL},
/* 289E */ { "COMBINAISON BRAILLE POINTS-23458",NULL},
/* 289F */ { "COMBINAISON BRAILLE POINTS-123458",NULL},
/* 28A0 */ { "COMBINAISON BRAILLE POINTS-68",NULL},
/* 28A1 */ { "COMBINAISON BRAILLE POINTS-168",NULL},
/* 28A2 */ { "COMBINAISON BRAILLE POINTS-268",NULL},
/* 28A3 */ { "COMBINAISON BRAILLE POINTS-1268",NULL},
/* 28A4 */ { "COMBINAISON BRAILLE POINTS-368",NULL},
/* 28A5 */ { "COMBINAISON BRAILLE POINTS-1368",NULL},
/* 28A6 */ { "COMBINAISON BRAILLE POINTS-2368",NULL},
/* 28A7 */ { "COMBINAISON BRAILLE POINTS-12368",NULL},
/* 28A8 */ { "COMBINAISON BRAILLE POINTS-468",NULL},
/* 28A9 */ { "COMBINAISON BRAILLE POINTS-1468",NULL},
/* 28AA */ { "COMBINAISON BRAILLE POINTS-2468",NULL},
/* 28AB */ { "COMBINAISON BRAILLE POINTS-12468",NULL},
/* 28AC */ { "COMBINAISON BRAILLE POINTS-3468",NULL},
/* 28AD */ { "COMBINAISON BRAILLE POINTS-13468",NULL},
/* 28AE */ { "COMBINAISON BRAILLE POINTS-23468",NULL},
/* 28AF */ { "COMBINAISON BRAILLE POINTS-123468",NULL},
/* 28B0 */ { "COMBINAISON BRAILLE POINTS-568",NULL},
/* 28B1 */ { "COMBINAISON BRAILLE POINTS-1568",NULL},
/* 28B2 */ { "COMBINAISON BRAILLE POINTS-2568",NULL},
/* 28B3 */ { "COMBINAISON BRAILLE POINTS-12568",NULL},
/* 28B4 */ { "COMBINAISON BRAILLE POINTS-3568",NULL},
/* 28B5 */ { "COMBINAISON BRAILLE POINTS-13568",NULL},
/* 28B6 */ { "COMBINAISON BRAILLE POINTS-23568",NULL},
/* 28B7 */ { "COMBINAISON BRAILLE POINTS-123568",NULL},
/* 28B8 */ { "COMBINAISON BRAILLE POINTS-4568",NULL},
/* 28B9 */ { "COMBINAISON BRAILLE POINTS-14568",NULL},
/* 28BA */ { "COMBINAISON BRAILLE POINTS-24568",NULL},
/* 28BB */ { "COMBINAISON BRAILLE POINTS-124568",NULL},
/* 28BC */ { "COMBINAISON BRAILLE POINTS-34568",NULL},
/* 28BD */ { "COMBINAISON BRAILLE POINTS-134568",NULL},
/* 28BE */ { "COMBINAISON BRAILLE POINTS-234568",NULL},
/* 28BF */ { "COMBINAISON BRAILLE POINTS-1234568",NULL},
/* 28C0 */ { "COMBINAISON BRAILLE POINTS-78",NULL},
/* 28C1 */ { "COMBINAISON BRAILLE POINTS-178",NULL},
/* 28C2 */ { "COMBINAISON BRAILLE POINTS-278",NULL},
/* 28C3 */ { "COMBINAISON BRAILLE POINTS-1278",NULL},
/* 28C4 */ { "COMBINAISON BRAILLE POINTS-378",NULL},
/* 28C5 */ { "COMBINAISON BRAILLE POINTS-1378",NULL},
/* 28C6 */ { "COMBINAISON BRAILLE POINTS-2378",NULL},
/* 28C7 */ { "COMBINAISON BRAILLE POINTS-12378",NULL},
/* 28C8 */ { "COMBINAISON BRAILLE POINTS-478",NULL},
/* 28C9 */ { "COMBINAISON BRAILLE POINTS-1478",NULL},
/* 28CA */ { "COMBINAISON BRAILLE POINTS-2478",NULL},
/* 28CB */ { "COMBINAISON BRAILLE POINTS-12478",NULL},
/* 28CC */ { "COMBINAISON BRAILLE POINTS-3478",NULL},
/* 28CD */ { "COMBINAISON BRAILLE POINTS-13478",NULL},
/* 28CE */ { "COMBINAISON BRAILLE POINTS-23478",NULL},
/* 28CF */ { "COMBINAISON BRAILLE POINTS-123478",NULL},
/* 28D0 */ { "COMBINAISON BRAILLE POINTS-578",NULL},
/* 28D1 */ { "COMBINAISON BRAILLE POINTS-1578",NULL},
/* 28D2 */ { "COMBINAISON BRAILLE POINTS-2578",NULL},
/* 28D3 */ { "COMBINAISON BRAILLE POINTS-12578",NULL},
/* 28D4 */ { "COMBINAISON BRAILLE POINTS-3578",NULL},
/* 28D5 */ { "COMBINAISON BRAILLE POINTS-13578",NULL},
/* 28D6 */ { "COMBINAISON BRAILLE POINTS-23578",NULL},
/* 28D7 */ { "COMBINAISON BRAILLE POINTS-123578",NULL},
/* 28D8 */ { "COMBINAISON BRAILLE POINTS-4578",NULL},
/* 28D9 */ { "COMBINAISON BRAILLE POINTS-14578",NULL},
/* 28DA */ { "COMBINAISON BRAILLE POINTS-24578",NULL},
/* 28DB */ { "COMBINAISON BRAILLE POINTS-124578",NULL},
/* 28DC */ { "COMBINAISON BRAILLE POINTS-34578",NULL},
/* 28DD */ { "COMBINAISON BRAILLE POINTS-134578",NULL},
/* 28DE */ { "COMBINAISON BRAILLE POINTS-234578",NULL},
/* 28DF */ { "COMBINAISON BRAILLE POINTS-1234578",NULL},
/* 28E0 */ { "COMBINAISON BRAILLE POINTS-678",NULL},
/* 28E1 */ { "COMBINAISON BRAILLE POINTS-1678",NULL},
/* 28E2 */ { "COMBINAISON BRAILLE POINTS-2678",NULL},
/* 28E3 */ { "COMBINAISON BRAILLE POINTS-12678",NULL},
/* 28E4 */ { "COMBINAISON BRAILLE POINTS-3678",NULL},
/* 28E5 */ { "COMBINAISON BRAILLE POINTS-13678",NULL},
/* 28E6 */ { "COMBINAISON BRAILLE POINTS-23678",NULL},
/* 28E7 */ { "COMBINAISON BRAILLE POINTS-123678",NULL},
/* 28E8 */ { "COMBINAISON BRAILLE POINTS-4678",NULL},
/* 28E9 */ { "COMBINAISON BRAILLE POINTS-14678",NULL},
/* 28EA */ { "COMBINAISON BRAILLE POINTS-24678",NULL},
/* 28EB */ { "COMBINAISON BRAILLE POINTS-124678",NULL},
/* 28EC */ { "COMBINAISON BRAILLE POINTS-34678",NULL},
/* 28ED */ { "COMBINAISON BRAILLE POINTS-134678",NULL},
/* 28EE */ { "COMBINAISON BRAILLE POINTS-234678",NULL},
/* 28EF */ { "COMBINAISON BRAILLE POINTS-1234678",NULL},
/* 28F0 */ { "COMBINAISON BRAILLE POINTS-5678",NULL},
/* 28F1 */ { "COMBINAISON BRAILLE POINTS-15678",NULL},
/* 28F2 */ { "COMBINAISON BRAILLE POINTS-25678",NULL},
/* 28F3 */ { "COMBINAISON BRAILLE POINTS-125678",NULL},
/* 28F4 */ { "COMBINAISON BRAILLE POINTS-35678",NULL},
/* 28F5 */ { "COMBINAISON BRAILLE POINTS-135678",NULL},
/* 28F6 */ { "COMBINAISON BRAILLE POINTS-235678",NULL},
/* 28F7 */ { "COMBINAISON BRAILLE POINTS-1235678",NULL},
/* 28F8 */ { "COMBINAISON BRAILLE POINTS-45678",NULL},
/* 28F9 */ { "COMBINAISON BRAILLE POINTS-145678",NULL},
/* 28FA */ { "COMBINAISON BRAILLE POINTS-245678",NULL},
/* 28FB */ { "COMBINAISON BRAILLE POINTS-1245678",NULL},
/* 28FC */ { "COMBINAISON BRAILLE POINTS-345678",NULL},
/* 28FD */ { "COMBINAISON BRAILLE POINTS-1345678",NULL},
/* 28FE */ { "COMBINAISON BRAILLE POINTS-2345678",NULL},
/* 28FF */ { "COMBINAISON BRAILLE POINTS-12345678",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_29[] = {
/* 2900 */ { "FLÈCHE À DEUX POINTES VERS LA DROITE BARRÉE VERTICALEMENT","	= surjection partielle en notation Z\n"
	"	x (flèche à deux pointes vers la gauche barrée verticalement - 2B34)"},
/* 2901 */ { "FLÈCHE À DEUX POINTES VERS LA DROITE BARRÉE DEUX FOIS VERTICALEMENT","	= surjection finie en notation Z\n"
	"	x (flèche à deux pointes vers la gauche barrée deux fois verticalement - 2B35)"},
/* 2902 */ { "DOUBLE FLÈCHE VERS LA GAUCHE BARRÉE VERTICALEMENT",NULL},
/* 2903 */ { "DOUBLE FLÈCHE VERS LA DROITE BARRÉE VERTICALEMENT",NULL},
/* 2904 */ { "DOUBLE FLÈCHE GAUCHE-DROITE BARRÉE VERTICALEMENT",NULL},
/* 2905 */ { "FLÈCHE À DEUX POINTES D'UN TAQUET VERS LA DROITE","	= a pour image\n"
	"	x (flèche à deux pointes d'un taquet vers la gauche - 2B36)"},
/* 2906 */ { "DOUBLE FLÈCHE D'UN TAQUET VERS LA GAUCHE","	= est l'image de\n"
	"	x (flèche longue d'un taquet vers la gauche - 27FB)"},
/* 2907 */ { "DOUBLE FLÈCHE D'UN TAQUET VERS LA DROITE","	= a pour image\n"
	"	x (flèche longue d'un taquet vers la droite - 27FC)"},
/* 2908 */ { "FLÈCHE VERS LE BAS BARRÉE HORIZONTALEMENT",NULL},
/* 2909 */ { "FLÈCHE VERS LE HAUT BARRÉE HORIZONTALEMENT",NULL},
/* 290A */ { "TRIPLE FLÈCHE VERS LE HAUT","	x (double flèche vers le haut - 21D1)\n"
	"	x (quadruple flèche vers le haut - 27F0)"},
/* 290B */ { "TRIPLE FLÈCHE VERS LE BAS","	x (double flèche vers le bas - 21D3)\n"
	"	x (quadruple flèche vers le bas - 27F1)"},
/* 290C */ { "FLÈCHE À DEUX TRAITS VERS LA GAUCHE",NULL},
/* 290D */ { "FLÈCHE À DEUX TRAITS VERS LA DROITE",NULL},
/* 290E */ { "FLÈCHE À TROIS TRAITS VERS LA GAUCHE",NULL},
/* 290F */ { "FLÈCHE À TROIS TRAITS VERS LA DROITE",NULL},
/* 2910 */ { "FLÈCHE À TROIS TRAITS ET À DEUX TÊTES VERS LA DROITE","	x (flèche à trois traits et à deux têtes vers la gauche - 2B37)"},
/* 2911 */ { "FLÈCHE VERS LA DROITE À FÛT POINTILLÉ","	x (flèche vers la gauche à fût pointillé - 2B38)"},
/* 2912 */ { "FLÈCHE VERS LE HAUT JUSQU'À UN TAQUET",NULL},
/* 2913 */ { "FLÈCHE VERS LE BAS JUSQU'À UN TAQUET",NULL},
/* 2914 */ { "FLÈCHE EMPENNÉE VERS LA DROITE BARRÉE VERTICALEMENT","	= injection partielle en notation Z\n"
	"	x (flèche empennée vers la gauche barrée verticalement - 2B39)"},
/* 2915 */ { "FLÈCHE EMPENNÉE VERS LA DROITE BARRÉE DEUX FOIS VERTICALEMENT","	= injection finie en notation Z\n"
	"	x (flèche empennée vers la gauche barrée deux fois verticalement - 2B3A)"},
/* 2916 */ { "FLÈCHE EMPENNÉE À DEUX POINTES VERS LA DROITE","	= correspondance bijective\n"
	"	= bijection en notation Z\n"
	"	x (flèche empennée à deux pointes vers la gauche - 2B3B)"},
/* 2917 */ { "FLÈCHE EMPENNÉE À DEUX POINTES VERS LA DROITE BARRÉE VERTICALEMENT","	= injection surjective en notation Z\n"
	"	x (flèche empennée à deux pointes vers la gauche barrée verticalement - 2B3C)"},
/* 2918 */ { "FLÈCHE EMPENNÉE À DEUX POINTES VERS LA DROITE BARRÉE DEUX FOIS VERTICALEMENT","	= injection surjective finie en notation Z\n"
	"	x (flèche empennée à deux pointes vers la gauche barrée deux fois verticalement - 2B3D)"},
/* 2919 */ { "EMPENNE VERS LA GAUCHE",NULL},
/* 291A */ { "EMPENNE VERS LA DROITE",NULL},
/* 291B */ { "DOUBLE EMPENNE VERS LA GAUCHE",NULL},
/* 291C */ { "DOUBLE EMPENNE VERS LA DROITE",NULL},
/* 291D */ { "FLÈCHE VERS UN LOSANGE NOIR À GAUCHE",NULL},
/* 291E */ { "FLÈCHE VERS UN LOSANGE NOIR À DROITE",NULL},
/* 291F */ { "FLÈCHE D'UN TAQUET VERS UN LOSANGE NOIR À GAUCHE",NULL},
/* 2920 */ { "FLÈCHE D'UN TAQUET VERS UN LOSANGE NOIR À DROITE",NULL},
/* 2921 */ { "FLÈCHE NORD-OUEST ET SUD-EST",NULL},
/* 2922 */ { "FLÈCHE NORD-EST ET SUD-OUEST",NULL},
/* 2923 */ { "FLÈCHE NORD-OUEST À CROCHET",NULL},
/* 2924 */ { "FLÈCHE NORD-EST À CROCHET",NULL},
/* 2925 */ { "FLÈCHE SUD-EST À CROCHET",NULL},
/* 2926 */ { "FLÈCHE SUD-OUEST À CROCHET",NULL},
/* 2927 */ { "FLÈCHES NORD-OUEST ET NORD-EST",NULL},
/* 2928 */ { "FLÈCHES NORD-EST ET SUD-EST",NULL},
/* 2929 */ { "FLÈCHES SUD-EST ET SUD-OUEST",NULL},
/* 292A */ { "FLÈCHES SUD-OUEST ET NORD-OUEST",NULL},
/* 292B */ { "DIAGONALE MONTANTE SUR DIAGONALE DESCENDANTE",NULL},
/* 292C */ { "DIAGONALE DESCENDANTE SUR DIAGONALE MONTANTE","	x (voies croisées - 26CC)"},
/* 292D */ { "FLÈCHE SUD-EST SUR FLÈCHE NORD-EST",NULL},
/* 292E */ { "FLÈCHE NORD-EST SUR FLÈCHE SUD-EST",NULL},
/* 292F */ { "DIAGONALE DESCENDANTE SUR FLÈCHE NORD-EST",NULL},
/* 2930 */ { "DIAGONALE MONTANTE SUR FLÈCHE SUD-EST",NULL},
/* 2931 */ { "FLÈCHE NORD-EST SUR FLÈCHE NORD-OUEST",NULL},
/* 2932 */ { "FLÈCHE NORD-OUEST SUR FLÈCHE NORD-EST",NULL},
/* 2933 */ { "FLÈCHE ONDULÉE POINTANT DIRECTEMENT À DROITE","	x (flèche vers la droite ondulée - 219D)\n"
	"	x (flèche ondulée pointant directement à gauche - 2B3F)"},
/* 2934 */ { "FLÈCHE DIRIGÉE VERS LA DROITE PUIS TOURNANT VERS LE HAUT",NULL},
/* 2935 */ { "FLÈCHE DIRIGÉE VERS LA DROITE PUIS TOURNANT VERS LE BAS",NULL},
/* 2936 */ { "FLÈCHE DIRIGÉE VERS LE BAS PUIS TOURNANT VERS LA GAUCHE",NULL},
/* 2937 */ { "FLÈCHE DIRIGÉE VERS LE BAS PUIS TOURNANT VERS LA DROITE",NULL},
/* 2938 */ { "ARC DE CERCLE DROIT FLÉCHÉ SENS HORAIRE",NULL},
/* 2939 */ { "ARC DE CERCLE GAUCHE FLÉCHÉ SENS ANTIHORAIRE",NULL},
/* 293A */ { "ARC DE CERCLE SUPÉRIEUR FLÉCHÉ SENS ANTIHORAIRE",NULL},
/* 293B */ { "ARC DE CERCLE INFÉRIEUR FLÉCHÉ SENS ANTIHORAIRE",NULL},
/* 293C */ { "ARC DE CERCLE SUPÉRIEUR FLÉCHÉ SENS HORAIRE ET SIGNE MOINS",NULL},
/* 293D */ { "ARC DE CERCLE SUPÉRIEUR FLÉCHÉ SENS ANTIHORAIRE ET SIGNE PLUS",NULL},
/* 293E */ { "DEMI-CERCLE FLÉCHÉ INFÉRIEUR DROIT SENS HORAIRE",NULL},
/* 293F */ { "DEMI-CERCLE FLÉCHÉ INFÉRIEUR GAUCHE SENS ANTIHORAIRE",NULL},
/* 2940 */ { "CERCLE FLÉCHÉ SENS ANTIHORAIRE","	x (diacritique rond sens antihoraire couvrant - 20DA)"},
/* 2941 */ { "CERCLE FLÉCHÉ SENS HORAIRE","	x (diacritique rond sens horaire couvrant - 20D9)"},
/* 2942 */ { "FLÈCHE VERS LA DROITE SURMONTANT FLÉCHETTE VERS LA GAUCHE",NULL},
/* 2943 */ { "FLÈCHE VERS LA GAUCHE SURMONTANT FLÉCHETTE VERS LA DROITE",NULL},
/* 2944 */ { "FLÉCHETTE VERS LA DROITE SURMONTANT FLÈCHE VERS LA GAUCHE",NULL},
/* 2945 */ { "FLÈCHE VERS LA DROITE SURMONTANT SIGNE MOINS",NULL},
/* 2946 */ { "FLÈCHE VERS LA GAUCHE SURMONTANT SIGNE MOINS",NULL},
/* 2947 */ { "FLÈCHE VERS LA DROITE À TRAVERS X","	x (flèche vers la gauche à travers x - 2B3E)"},
/* 2948 */ { "PETIT CERCLE TRAVERSÉ D'UNE FLÈCHE GAUCHE-DROITE",NULL},
/* 2949 */ { "PETIT CERCLE SURMONTÉ D'UNE FLÈCHE MONTANTE À DEUX POINTES",NULL},
/* 294A */ { "HARPON À BARBILLON GAUCHE DRESSÉ ET BARBILLON DROIT BAISSÉ",NULL},
/* 294B */ { "HARPON À BARBILLON GAUCHE BAISSÉ ET BARBILLON DROIT DRESSÉ",NULL},
/* 294C */ { "HARPON À BARBILLON SUPÉRIEUR DROIT ET BARBILLON INFÉRIEUR GAUCHE",NULL},
/* 294D */ { "HARPON À BARBILLON SUPÉRIEUR GAUCHE ET BARBILLON INFÉRIEUR DROIT",NULL},
/* 294E */ { "HARPON À BARBILLON GAUCHE DRESSÉ ET BARBILLON DROIT DRESSÉ",NULL},
/* 294F */ { "HARPON À BARBILLON SUPÉRIEUR DROIT ET BARBILLON INFÉRIEUR DROIT",NULL},
/* 2950 */ { "HARPON À BARBILLON GAUCHE BAISSÉ ET BARBILLON DROIT BAISSÉ",NULL},
/* 2951 */ { "HARPON À BARBILLON SUPÉRIEUR GAUCHE ET BARBILLON INFÉRIEUR GAUCHE",NULL},
/* 2952 */ { "HARPON À BARBILLON DRESSÉ VERS UN TAQUET À GAUCHE",NULL},
/* 2953 */ { "HARPON À BARBILLON DRESSÉ VERS UN TAQUET À DROITE",NULL},
/* 2954 */ { "HARPON À BARBILLON DROIT VERS UN TAQUET EN HAUT",NULL},
/* 2955 */ { "HARPON À BARBILLON DROIT VERS UN TAQUET EN BAS",NULL},
/* 2956 */ { "HARPON À BARBILLON BAISSÉ VERS UN TAQUET À GAUCHE",NULL},
/* 2957 */ { "HARPON À BARBILLON BAISSÉ VERS UN TAQUET À DROITE",NULL},
/* 2958 */ { "HARPON À BARBILLON GAUCHE VERS UN TAQUET EN HAUT",NULL},
/* 2959 */ { "HARPON À BARBILLON GAUCHE VERS UN TAQUET EN BAS",NULL},
/* 295A */ { "HARPON À BARBILLON DRESSÉ D'UN TAQUET VERS LA GAUCHE",NULL},
/* 295B */ { "HARPON À BARBILLON DRESSÉ D'UN TAQUET VERS LA DROITE",NULL},
/* 295C */ { "HARPON À BARBILLON DROIT D'UN TAQUET VERS LE HAUT",NULL},
/* 295D */ { "HARPON À BARBILLON DROIT D'UN TAQUET VERS LE BAS",NULL},
/* 295E */ { "HARPON À BARBILLON BAISSÉ D'UN TAQUET VERS LA GAUCHE",NULL},
/* 295F */ { "HARPON À BARBILLON BAISSÉ D'UN TAQUET VERS LA DROITE",NULL},
/* 2960 */ { "HARPON À BARBILLON GAUCHE D'UN TAQUET VERS LE HAUT",NULL},
/* 2961 */ { "HARPON À BARBILLON GAUCHE D'UN TAQUET VERS LE BAS",NULL},
/* 2962 */ { "HARPON VERS LA GAUCHE À BARBILLON DRESSÉ SUR HARPON VERS LA GAUCHE À BARBILLON BAISSÉ",NULL},
/* 2963 */ { "HARPON VERS LE HAUT À BARBILLON GAUCHE À CÔTÉ DE HARPON VERS LE HAUT À BARBILLON DROIT",NULL},
/* 2964 */ { "HARPON VERS LA DROITE À BARBILLON DRESSÉ SUR HARPON VERS LA DROITE À BARBILLON BAISSÉ",NULL},
/* 2965 */ { "HARPON VERS LE BAS À BARBILLON GAUCHE À CÔTÉ DE HARPON VERS LE BAS À BARBILLON DROIT",NULL},
/* 2966 */ { "HARPON VERS LA GAUCHE À BARBILLON DRESSÉ SUR HARPON VERS LA DROITE À BARBILLON DRESSÉ",NULL},
/* 2967 */ { "HARPON VERS LA GAUCHE À BARBILLON BAISSÉ SUR HARPON VERS LA DROITE À BARBILLON BAISSÉ",NULL},
/* 2968 */ { "HARPON VERS LA DROITE À BARBILLON DRESSÉ SUR HARPON VERS LA GAUCHE À BARBILLON DRESSÉ",NULL},
/* 2969 */ { "HARPON VERS LA DROITE À BARBILLON BAISSÉ SUR HARPON VERS LA GAUCHE À BARBILLON BAISSÉ",NULL},
/* 296A */ { "HARPON VERS LA GAUCHE À BARBILLON DRESSÉ SUR TIRET LONG",NULL},
/* 296B */ { "HARPON VERS LA GAUCHE À BARBILLON BAISSÉ SOUS TIRET LONG",NULL},
/* 296C */ { "HARPON VERS LA DROITE À BARBILLON DRESSÉ SUR TIRET LONG",NULL},
/* 296D */ { "HARPON VERS LA DROITE À BARBILLON BAISSÉ SOUS TIRET LONG",NULL},
/* 296E */ { "HARPON VERS LE HAUT À BARBILLON GAUCHE À CÔTÉ DE HARPON VERS LE BAS À BARBILLON DROIT",NULL},
/* 296F */ { "HARPON VERS LE BAS À BARBILLON GAUCHE À CÔTÉ DE HARPON VERS LE HAUT À BARBILLON DROIT",NULL},
/* 2970 */ { "FLÈCHE EN ÉPINGLE À CHEVEU VERS LA DROITE","	x (sur-ensemble de - 2283)"},
/* 2971 */ { "SIGNE ÉGAL SUR FLÈCHE VERS LA DROITE","	x (signe égal sur flèche vers la gauche - 2B40)"},
/* 2972 */ { "OPÉRATEUR TILDE SUR FLÈCHE VERS LA DROITE","	x (opérateur tilde réfléchi sur flèche vers la gauche - 2B41)"},
/* 2973 */ { "FLÈCHE VERS LA GAUCHE SUR OPÉRATEUR TILDE","	x (flèche vers la droite sur opérateur tilde réfléchi - 2B4C)"},
/* 2974 */ { "FLÈCHE VERS LA DROITE SUR OPÉRATEUR TILDE","	x (flèche vers la gauche sur opérateur tilde réfléchi - 2B4B)"},
/* 2975 */ { "FLÈCHE VERS LA DROITE SUR PRESQUE ÉGAL À","	x (flèche vers la gauche sur presque égal à réfléchi - 2B42)"},
/* 2976 */ { "INFÉRIEUR À SUR FLÈCHE VERS LA GAUCHE",NULL},
/* 2977 */ { "FLÈCHE VERS LA GAUCHE À TRAVERS INFÉRIEUR À","	x (flèche vers la droite à travers supérieur à - 2B43)"},
/* 2978 */ { "SUPÉRIEUR À SUR FLÈCHE VERS LA DROITE",NULL},
/* 2979 */ { "SOUS-ENSEMBLE SUR FLÈCHE VERS LA DROITE",NULL},
/* 297A */ { "FLÈCHE VERS LA GAUCHE À TRAVERS SOUS-ENSEMBLE","	x (flèche vers la droite à travers sur-ensemble - 2B44)"},
/* 297B */ { "SUR-ENSEMBLE SUR FLÈCHE VERS LA GAUCHE",NULL},
/* 297C */ { "ANCRE VERS LA GAUCHE",NULL},
/* 297D */ { "ANCRE VERS LA DROITE",NULL},
/* 297E */ { "ANCRE VERS LE HAUT",NULL},
/* 297F */ { "ANCRE VERS LE BAS",NULL},
/* 2980 */ { "DÉLIMITEUR TRIPLE BARRE VERTICALE","	x (relation binaire triple barre verticale - 2AF4)\n"
	"	x (grand opérateur à trois barres verticales - 2AFC)"},
/* 2981 */ { "BOULET","	* cercle noir de petite à moyenne taille\n"
	"	x (opérateur puce - 2219)\n"
	"	x (cercle noir - 25CF)"},
/* 2982 */ { "DEUX-POINTS EN NOTATION Z","	x (diacritique tibétain rnam btchad - 0F7F)"},
/* 2983 */ { "ACCOLADE BLANCHE GAUCHE",NULL},
/* 2984 */ { "ACCOLADE BLANCHE DROITE",NULL},
/* 2985 */ { "PARENTHÈSE BLANCHE GAUCHE","	x (double parenthèse gauche - 2E28)\n"
	"	x (parenthèse blanche gauche pleine chasse - FF5F)"},
/* 2986 */ { "PARENTHÈSE BLANCHE DROITE","	* ces parenthèses sont utilisées pour les intervalles bourbakistes\n"
	"	x (double parenthèse droite - 2E29)\n"
	"	x (parenthèse blanche droite pleine chasse - FF60)"},
/* 2987 */ { "PARENTHÈSE IMAGE DE GAUCHE EN NOTATION Z",NULL},
/* 2988 */ { "PARENTHÈSE IMAGE DE DROITE EN NOTATION Z",NULL},
/* 2989 */ { "PARENTHÈSE LIEN GAUCHE EN NOTATION Z",NULL},
/* 298A */ { "PARENTHÈSE LIEN DROITE EN NOTATION Z",NULL},
/* 298B */ { "CROCHET GAUCHE AVEC BARRE SOUSCRITE",NULL},
/* 298C */ { "CROCHET DROIT AVEC BARRE SOUSCRITE",NULL},
/* 298D */ { "CROCHET GAUCHE AVEC TRAIT DANS LE COIN SUPÉRIEUR",NULL},
/* 298E */ { "CROCHET DROIT AVEC TRAIT DANS LE COIN INFÉRIEUR",NULL},
/* 298F */ { "CROCHET GAUCHE AVEC TRAIT DANS LE COIN INFÉRIEUR",NULL},
/* 2990 */ { "CROCHET DROIT AVEC TRAIT DANS LE COIN SUPÉRIEUR",NULL},
/* 2991 */ { "CHEVRON POINTÉ GAUCHE",NULL},
/* 2992 */ { "CHEVRON POINTÉ DROIT",NULL},
/* 2993 */ { "PARENTHÈSE ARC GAUCHE ET INFÉRIEUR À",NULL},
/* 2994 */ { "PARENTHÈSE ARC DROITE ET SUPÉRIEUR À",NULL},
/* 2995 */ { "PARENTHÈSE DOUBLE ARC DROITE ET SUPÉRIEUR À",NULL},
/* 2996 */ { "PARENTHÈSE DOUBLE ARC GAUCHE ET INFÉRIEUR À",NULL},
/* 2997 */ { "CROCHET EN ÉCAILLE NOIR GAUCHE","	x (crochet en écaille mathématique blanc gauche - 27EC)\n"
	"	x (crochet en écaille gauche - 3014)\n"
	"	x (crochet en écaille blanc gauche - 3018)"},
/* 2998 */ { "CROCHET EN ÉCAILLE NOIR DROIT",NULL},
/* 2999 */ { "CLÔTURE POINTILLÉE","	* quatre points verticaux rapprochés"},
/* 299A */ { "LIGNE VERTICALE EN ZIGZAG","	x (ligne ondulée - 2307)"},
/* 299B */ { "ANGLE MESURÉ S'OUVRANT VERS LA GAUCHE","	x (angle mesuré - 2221)"},
/* 299C */ { "VARIANTE D'ANGLE AVEC CARRÉ","	x (angle droit - 221F)"},
/* 299D */ { "ANGLE DROIT MESURÉ POINTÉ",NULL},
/* 299E */ { "ANGLE AVEC S INSCRIT",NULL},
/* 299F */ { "ANGLE AIGU","	x (angle - 2220)"},
/* 29A0 */ { "ANGLE SPHÉRIQUE S'OUVRANT VERS LA GAUCHE","	x (angle sphérique - 2222)"},
/* 29A1 */ { "ANGLE SPHÉRIQUE S'OUVRANT VERS LE HAUT",NULL},
/* 29A2 */ { "ANGLE CULBUTÉ","	x (angle - 2220)"},
/* 29A3 */ { "ANGLE RÉFLÉCHI",NULL},
/* 29A4 */ { "ANGLE AVEC BARRE SOUSCRITE",NULL},
/* 29A5 */ { "ANGLE RÉFLÉCHI AVEC BARRE SOUSCRITE",NULL},
/* 29A6 */ { "ANGLE OBLIQUE S'OUVRANT VERS LE HAUT",NULL},
/* 29A7 */ { "ANGLE OBLIQUE S'OUVRANT VERS LE BAS",NULL},
/* 29A8 */ { "ANGLE CALCULÉ À BRAS VERS L'EST ET BRAS FLÉCHÉ VERS LE NORD-EST",NULL},
/* 29A9 */ { "ANGLE CALCULÉ À BRAS VERS L'OUEST ET BRAS FLÉCHÉ VERS LE NORD-OUEST",NULL},
/* 29AA */ { "ANGLE CALCULÉ À BRAS VERS L'EST ET BRAS FLÉCHÉ VERS LE SUD-EST",NULL},
/* 29AB */ { "ANGLE CALCULÉ À BRAS VERS L'OUEST ET BRAS FLÉCHÉ VERS LE SUD-OUEST",NULL},
/* 29AC */ { "ANGLE CALCULÉ À BRAS VERS LE NORD ET BRAS FLÉCHÉ VERS LE NORD-EST",NULL},
/* 29AD */ { "ANGLE CALCULÉ À BRAS VERS LE NORD ET BRAS FLÉCHÉ VERS LE NORD-OUEST",NULL},
/* 29AE */ { "ANGLE CALCULÉ À BRAS VERS LE SUD ET BRAS FLÉCHÉ VERS LE SUD-EST",NULL},
/* 29AF */ { "ANGLE CALCULÉ À BRAS VERS LE SUD ET BRAS FLÉCHÉ VERS LE SUD-OUEST",NULL},
/* 29B0 */ { "ENSEMBLE VIDE RÉFLÉCHI","	x (ensemble vide - 2205)\n"
	"	x (symbole de fonction apl saturne - 2349)"},
/* 29B1 */ { "ENSEMBLE VIDE AVEC BARRE EN CHEF",NULL},
/* 29B2 */ { "ENSEMBLE VIDE AVEC PETIT CERCLE EN CHEF",NULL},
/* 29B3 */ { "ENSEMBLE VIDE AVEC FLÈCHE DROITE EN CHEF",NULL},
/* 29B4 */ { "ENSEMBLE VIDE AVEC FLÈCHE GAUCHE EN CHEF",NULL},
/* 29B5 */ { "CERCLE AVEC BARRE HORIZONTALE","	x (moins cerclé - 2296)\n"
	"	x (cercle blanc modérément petit avec barre horizontale - 1CEF0)"},
/* 29B6 */ { "BARRE VERTICALE CERCLÉE","	x (symbole alchimique du salpêtre - 1F715)"},
/* 29B7 */ { "PARALLÈLES CERCLÉES","	~ 29B7 FE00 avec des lignes parallèles touchant le cercle"},
/* 29B8 */ { "BARRE OBLIQUE INVERSÉE CERCLÉE","	= contre-oblique cerclée, contre-cotice cerclée"},
/* 29B9 */ { "PERPENDICULAIRE CERCLÉ",NULL},
/* 29BA */ { "CERCLE DIVISÉ PAR UNE BARRE HORIZONTALE ET UNE BARRE VERTICALE DANS LA MOITIÉ SUPÉRIEURE",NULL},
/* 29BB */ { "CERCLE SUPERPOSÉ D'UN X","	x (multiplié par cerclé - 2297)"},
/* 29BC */ { "SIGNE DE DIVISION PIVOTÉ SENS ANTIHORAIRE CERCLÉ",NULL},
/* 29BD */ { "CERCLE TRAVERSÉ D'UNE FLÈCHE MONTANTE",NULL},
/* 29BE */ { "PUCE BLANCHE CERCLÉE","	x (opérateur rond cerclé - 229A)\n"
	"	x (symbole de fonction apl beigne - 233E)\n"
	"	x (deux cercles concentriques - 25CE)"},
/* 29BF */ { "PUCE CERCLÉE","	* fait partie d'un jeu étalonné de cercles dont le cercle plein intérieur varie en taille\n"
	"	x (opérateur point cerclé - 2299)\n"
	"	x (cercle blanc évidé - 25C9)\n"
	"	x (opérateur point cerclé n-aire - 2A00)"},
/* 29C0 */ { "INFÉRIEUR À CERCLÉ",NULL},
/* 29C1 */ { "SUPÉRIEUR À CERCLÉ",NULL},
/* 29C2 */ { "CERCLE AVEC PETIT CERCLE À DROITE",NULL},
/* 29C3 */ { "CERCLE AVEC DEUX PETITS TRAITS HORIZONTAUX À DROITE",NULL},
/* 29C4 */ { "OBLIQUE ENCADRÉE","	= cotice encadrée\n"
	"	x (symbole de fonction apl quadrat oblique - 2341)\n"
	"	x (signe masu - 303C)"},
/* 29C5 */ { "OBLIQUE INVERSÉE ENCADRÉE","	= contre-oblique encadrée, contre-cotice encadrée\n"
	"	x (symbole de fonction apl quadrat oblique inversée - 2342)"},
/* 29C6 */ { "ASTÉRISQUE ENCADRÉ",NULL},
/* 29C7 */ { "PETIT CERCLE ENCADRÉ","	x (symbole de fonction apl as - 233B)"},
/* 29C8 */ { "CARRÉ ENCADRÉ","	= deux carrés concentriques"},
/* 29C9 */ { "CARRÉS SE CHEVAUCHANT","	x (carrés blancs se chevauchant - 2BBA)"},
/* 29CA */ { "TRIANGLE AVEC POINT EN CHEF",NULL},
/* 29CB */ { "TRIANGLE AVEC BARRE SOUSCRITE",NULL},
/* 29CC */ { "S INSCRIT DANS UN TRIANGLE",NULL},
/* 29CD */ { "TRIANGLE À EMPATTEMENTS INFÉRIEURS","	x (triangle blanc pointant vers le haut - 25B3)"},
/* 29CE */ { "TRIANGLE DROIT SUR TRIANGLE GAUCHE",NULL},
/* 29CF */ { "TRIANGLE GAUCHE À CÔTÉ D'UNE BARRE VERTICALE",NULL},
/* 29D0 */ { "BARRE VERTICALE À CÔTÉ D'UN TRIANGLE DROIT",NULL},
/* 29D1 */ { "NŒUD PAPILLON À AILE GAUCHE NOIRE","	x (nœud papillon - 22C8)"},
/* 29D2 */ { "NŒUD PAPILLON À AILE DROITE NOIRE",NULL},
/* 29D3 */ { "NŒUD PAPILLON NOIR","	x (moitiés de pavé triangulaires gauche et droite - 1FB9B)"},
/* 29D4 */ { "SIGNE DE MULTIPLICATION À MOITIÉ GAUCHE NOIRE","	x (produit semi-direct à gauche de facteur normal - 22C9)"},
/* 29D5 */ { "SIGNE DE MULTIPLICATION À MOITIÉ DROITE NOIRE","	x (produit semi-direct à droite de facteur normal - 22CA)"},
/* 29D6 */ { "SABLIER BLANC","	= nœud papillon vertical\n"
	"	x (sablier - 231B)\n"
	"	x (symbole alchimique de l'heure - 1F76E)"},
/* 29D7 */ { "SABLIER NOIR","	x (moitiés de pavé triangulaires supérieure et inférieure - 1FB9A)"},
/* 29D8 */ { "CLÔTURE DENTELÉE GAUCHE","	x (forme de présentation de tiret bas ondulé vertical - FE34)"},
/* 29D9 */ { "CLÔTURE DENTELÉE DROITE",NULL},
/* 29DA */ { "DOUBLE CLÔTURE DENTELÉE GAUCHE",NULL},
/* 29DB */ { "DOUBLE CLÔTURE DENTELÉE DROITE",NULL},
/* 29DC */ { "INFINI INCOMPLET","	= entité ISOtech &iinfin;\n"
	"	x (infini - 221E)"},
/* 29DD */ { "BOUCLE SUR INFINI","	= infini surmonté d'une boucle"},
/* 29DE */ { "INFINI NIÉ PAR UNE BARRE VERTICALE",NULL},
/* 29DF */ { "MULTIJECTION À DEUX TÊTES","	x (multijection - 22B8)\n"
	"	x (symbole alchimique de l'arsenic - 1F73A)"},
/* 29E0 */ { "CARRÉ OMBRÉ","	= d'alembertien\n"
	"	x (carré blanc à ombre projetée sous le coin inférieur droit - 274F)"},
/* 29E1 */ { "AUGMENTE AVEC","	x (sous-groupe normal de ou égal à - 22B4)"},
/* 29E2 */ { "PRODUIT DE PERMUTATION","	x (élément d'un sac en notation z - 22FF)"},
/* 29E3 */ { "SIGNE ÉGAL ET PARALLÈLE INCLINÉ","	x (croisillon - 0023)\n"
	"	x (égal et parallèle à - 22D5)"},
/* 29E4 */ { "SIGNE ÉGAL ET PARALLÈLE INCLINÉ SURMONTÉS D'UN TILDE",NULL},
/* 29E5 */ { "IDENTIQUE À ET PARALLÈLE INCLINÉ","	x (deux barres verticales à trois traverses - 2A68)"},
/* 29E6 */ { "GLEICH STARK","	= équivalent tautologique"},
/* 29E7 */ { "THERMODYNAMIQUE","	= marque d'enregistrement\n"
	"	* barre verticale à deux traverses\n"
	"	x (pas égal à - 2260)\n"
	"	x (marque de groupe - 2BD2)"},
/* 29E8 */ { "TRIANGLE POINTE VERS LE BAS À MOITIÉ GAUCHE NOIRE","	x (triangle pointe vers le haut à moitié gauche noire - 25ED)"},
/* 29E9 */ { "TRIANGLE POINTE VERS LE BAS À MOITIÉ DROITE NOIRE","	x (triangle pointe vers le haut à moitié droite noire - 25EE)"},
/* 29EA */ { "LOSANGE NOIR AVEC FLÈCHE VERS LE BAS",NULL},
/* 29EB */ { "RHOMBE NOIR","	x (rhombe - 25CA)"},
/* 29EC */ { "CERCLE BLANC AVEC FLÈCHE VERS LE BAS",NULL},
/* 29ED */ { "CERCLE NOIR AVEC FLÈCHE VERS LE BAS",NULL},
/* 29EE */ { "BARRE D'ERREUR AVEC CARRÉ BLANC",NULL},
/* 29EF */ { "BARRE D'ERREUR AVEC CARRÉ NOIR",NULL},
/* 29F0 */ { "BARRE D'ERREUR AVEC LOSANGE BLANC",NULL},
/* 29F1 */ { "BARRE D'ERREUR AVEC LOSANGE NOIR",NULL},
/* 29F2 */ { "BARRE D'ERREUR AVEC CERCLE BLANC",NULL},
/* 29F3 */ { "BARRE D'ERREUR AVEC CERCLE NOIR",NULL},
/* 29F4 */ { "RÈGLE DIFFÉRÉE","	= deux-points suivi d'une flèche"},
/* 29F5 */ { "OPÉRATEUR BARRE OBLIQUE INVERSÉE","	= opérateur contre-oblique, opérateur contre-cotice\n"
	"	x (barre oblique inversée - 005C)\n"
	"	x (différence d'ensembles - 2216)\n"
	"	x (diagonale mathématique descendante - 27CD)"},
/* 29F6 */ { "BARRE OBLIQUE AVEC BARRE EN CHEF","	= oblique barre en chef, cotice barre en chef"},
/* 29F7 */ { "BARRE OBLIQUE INVERSÉE À TRAVERSE HORIZONTALE","	= contre-oblique à traverse horizontale, contre-cotice à traverse horizontale\n"
	"	x (symbole de fonction apl contre-cotice barrée - 2340)"},
/* 29F8 */ { "GRANDE BARRE OBLIQUE","	x (barre oblique de division - 2215)"},
/* 29F9 */ { "GRANDE BARRE OBLIQUE INVERSÉE","	= grande contre-oblique, grande contre-cotice\n"
	"	= masquage de schémas en notation Z\n"
	"	x (différence d'ensembles - 2216)"},
/* 29FA */ { "DOUBLE PLUS",NULL},
/* 29FB */ { "TRIPLE PLUS",NULL},
/* 29FC */ { "CHEVRON COURBÉ POINTANT À GAUCHE","	x (précède - 227A)\n"
	"	x (chevron pointant à gauche - 2329)"},
/* 29FD */ { "CHEVRON COURBÉ POINTANT À DROITE","	x (suit - 227B)\n"
	"	x (chevron pointant à droite - 232A)"},
/* 29FE */ { "TINY","	x (signe plus - 002B)"},
/* 29FF */ { "MINY","	x (signe moins - 2212)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_2A[] = {
/* 2A00 */ { "OPÉRATEUR POINT CERCLÉ N-AIRE","	x (opérateur point cerclé - 2299)\n"
	"	x (cercle blanc évidé - 25C9)"},
/* 2A01 */ { "OPÉRATEUR PLUS CERCLÉ N-AIRE","	x (plus cerclé - 2295)"},
/* 2A02 */ { "OPÉRATEUR DE MULTIPLICATION N-AIRE CERCLÉ","	x (multiplié par cerclé - 2297)\n"
	"	x (sautoir cerclé épais - 2B59)"},
/* 2A03 */ { "OPÉRATEUR UNION N-AIRE POINTÉ","	x (multiplication de multiensemble - 228D)"},
/* 2A04 */ { "OPÉRATEUR UNION N-AIRE AVEC PLUS","	x (union de multiensemble - 228E)"},
/* 2A05 */ { "OPÉRATEUR INTERSECTION CARRÉ N-AIRE","	x (chapeau carré - 2293)"},
/* 2A06 */ { "OPÉRATEUR UNION CARRÉ N-AIRE","	x (coupe carrée - 2294)"},
/* 2A07 */ { "OPÉRATEUR DEUX ET LOGIQUES","	= fusion\n"
	"	x (deux et logiques entrecroisés - 2A55)"},
/* 2A08 */ { "OPÉRATEUR DEUX OU LOGIQUES","	x (deux ou logiques entrecroisés - 2A56)"},
/* 2A09 */ { "OPÉRATEUR DE MULTIPLICATION N-AIRE","	x (signe de multiplication - 00D7)"},
/* 2A0A */ { "SOMMATION MODULO DEUX","	x (sommation de la famille - 2211)"},
/* 2A0B */ { "SOMMATION AVEC INTÉGRALE",NULL},
/* 2A0C */ { "INTÉGRALE QUADRUPLE","	x (intégrale triple - 222D)\n"
	"	# 222B 222B 222B 222B"},
/* 2A0D */ { "INTÉGRALE À PARTIE FINIE",NULL},
/* 2A0E */ { "INTÉGRALE AVEC DEUX BARRES HORIZONTALES",NULL},
/* 2A0F */ { "MOYENNE D'INTÉGRALE AVEC BARRE OBLIQUE",NULL},
/* 2A10 */ { "FONCTION DE CIRCULATION",NULL},
/* 2A11 */ { "INTÉGRALE SENS ANTIHORAIRE",NULL},
/* 2A12 */ { "INTÉGRALE DE LIGNE À CHEMIN RECTANGULAIRE AUTOUR DU PÔLE",NULL},
/* 2A13 */ { "INTÉGRALE DE LIGNE À CHEMIN SEMI-CIRCULAIRE AUTOUR DU PÔLE",NULL},
/* 2A14 */ { "INTÉGRALE DE LIGNE ÉVITANT LE PÔLE",NULL},
/* 2A15 */ { "INTÉGRALE AUTOUR D'UN OPÉRATEUR POINT","	x (intégrale de contour - 222E)"},
/* 2A16 */ { "INTÉGRALE QUATERNION",NULL},
/* 2A17 */ { "INTÉGRALE AVEC FLÈCHE VERS LA GAUCHE À CROCHET",NULL},
/* 2A18 */ { "INTÉGRALE AVEC SIGNE DE MULTIPLICATION",NULL},
/* 2A19 */ { "INTÉGRALE AVEC SIGNE D'INTERSECTION",NULL},
/* 2A1A */ { "INTÉGRALE AVEC SIGNE D'UNION",NULL},
/* 2A1B */ { "INTÉGRALE AVEC BARRE EN CHEF","	= intégrale supérieure"},
/* 2A1C */ { "INTÉGRALE AVEC BARRE SOUSCRITE","	= intégrale inférieure"},
/* 2A1D */ { "JOINTURE","	= gros nœud papillon\n"
	"	* théorie des bases de données relationnelles\n"
	"	x (nœud papillon - 22C8)\n"
	"	x (jointure externe complète - 27D7)"},
/* 2A1E */ { "GROS OPÉRATEUR TRIANGLE GAUCHE","	* théorie des bases de données relationnelles\n"
	"	x (triangle blanc pointant vers la gauche - 25C1)"},
/* 2A1F */ { "COMPOSITION DE SCHÉMAS EN NOTATION Z","	x (composition relationnelle en notation z - 2A3E)"},
/* 2A20 */ { "TUBAGE DE SCHÉMAS EN NOTATION Z","	x (très supérieur à - 226B)"},
/* 2A21 */ { "PROJECTION DE SCHÉMAS EN NOTATION Z","	x (harpon vers le haut avec barbillon vers la droite - 21BE)"},
/* 2A22 */ { "SIGNE PLUS AVEC ROND EN CHEF",NULL},
/* 2A23 */ { "SIGNE PLUS AVEC ACCENT CIRCONFLEXE EN CHEF",NULL},
/* 2A24 */ { "SIGNE PLUS AVEC TILDE EN CHEF","	= différence positive ou somme"},
/* 2A25 */ { "SIGNE PLUS AVEC POINT SOUSCRIT","	x (plus pointé - 2214)"},
/* 2A26 */ { "SIGNE PLUS AVEC TILDE SOUSCRIT","	= somme ou différence positive"},
/* 2A27 */ { "SIGNE PLUS AVEC INDICE DEUX","	= addition nim"},
/* 2A28 */ { "SIGNE PLUS AVEC TRIANGLE NOIR",NULL},
/* 2A29 */ { "SIGNE MOINS AVEC VIRGULE EN CHEF",NULL},
/* 2A2A */ { "SIGNE MOINS AVEC POINT SOUSCRIT","	x (moins pointé - 2238)"},
/* 2A2B */ { "SIGNE MOINS AVEC POINTS DESCENDANTS",NULL},
/* 2A2C */ { "SIGNE MOINS AVEC POINTS ASCENDANTS",NULL},
/* 2A2D */ { "SIGNE PLUS DANS UN DEMI-CERCLE GAUCHE",NULL},
/* 2A2E */ { "SIGNE PLUS DANS UN DEMI-CERCLE DROIT",NULL},
/* 2A2F */ { "PRODUIT VECTORIEL","	x (signe de multiplication - 00D7)"},
/* 2A30 */ { "SIGNE DE MULTIPLICATION AVEC POINT EN CHEF",NULL},
/* 2A31 */ { "SIGNE DE MULTIPLICATION AVEC BARRE SOUSCRITE",NULL},
/* 2A32 */ { "PRODUIT SEMI-DIRECT FERMÉ EN BAS",NULL},
/* 2A33 */ { "PRODUIT FUSIONNÉ",NULL},
/* 2A34 */ { "SIGNE DE MULTIPLICATION DANS UN DEMI-CERCLE GAUCHE",NULL},
/* 2A35 */ { "SIGNE DE MULTIPLICATION DANS UN DEMI-CERCLE DROIT",NULL},
/* 2A36 */ { "SIGNE DE MULTIPLICATION CERCLÉ AVEC ACCENT CIRCONFLEXE",NULL},
/* 2A37 */ { "SIGNE DE MULTIPLICATION DOUBLEMENT CERCLÉ",NULL},
/* 2A38 */ { "SIGNE DE DIVISION CERCLÉ",NULL},
/* 2A39 */ { "SIGNE PLUS DANS UN TRIANGLE",NULL},
/* 2A3A */ { "SIGNE MOINS DANS UN TRIANGLE",NULL},
/* 2A3B */ { "SIGNE DE MULTIPLICATION DANS UN TRIANGLE",NULL},
/* 2A3C */ { "PRODUIT INTÉRIEUR","	x (plancher à droite - 230B)\n"
	"	~ 2A3C FE00 variante haute à pied étroit"},
/* 2A3D */ { "PRODUIT INTÉRIEUR À DROITE","	x (plancher à gauche - 230A)\n"
	"	x (signe négation culbuté - 2319)\n"
	"	~ 2A3D FE00 variante haute à pied étroit"},
/* 2A3E */ { "COMPOSITION RELATIONNELLE EN NOTATION Z","	x (composition de schémas en notation z - 2A1F)"},
/* 2A3F */ { "AMALGAMATION OU COPRODUIT","	x (coproduit de la famille - 2210)"},
/* 2A40 */ { "INTERSECTION POINTÉE","	x (et logique - 2227)\n"
	"	x (et pointé - 27D1)"},
/* 2A41 */ { "UNION À SIGNE MOINS","	= différence de sacs en notation Z\n"
	"	x (union de multiensemble - 228E)"},
/* 2A42 */ { "UNION À BARRE EN CHEF",NULL},
/* 2A43 */ { "INTERSECTION À BARRE EN CHEF",NULL},
/* 2A44 */ { "INTERSECTION AVEC ET LOGIQUE",NULL},
/* 2A45 */ { "UNION AVEC OU LOGIQUE",NULL},
/* 2A46 */ { "UNION SUR INTERSECTION",NULL},
/* 2A47 */ { "INTERSECTION SUR UNION",NULL},
/* 2A48 */ { "UNION SUR TRAIT SUR INTERSECTION",NULL},
/* 2A49 */ { "INTERSECTION SUR TRAIT SUR UNION",NULL},
/* 2A4A */ { "DEUX UNIONS SOUDÉES CÔTE À CÔTE",NULL},
/* 2A4B */ { "DEUX INTERSECTIONS SOUDÉES CÔTE À CÔTE",NULL},
/* 2A4C */ { "UNION FERMÉE À EMPATTEMENTS","	x (union - 222A)"},
/* 2A4D */ { "INTERSECTION FERMÉE À EMPATTEMENTS","	x (intersection - 2229)"},
/* 2A4E */ { "DEUX INTERSECTIONS CARRÉES EMBOÎTÉES",NULL},
/* 2A4F */ { "DEUX UNIONS CARRÉES EMBOÎTÉES",NULL},
/* 2A50 */ { "UNION FERMÉE À EMPATTEMENTS ET PRODUIT FUSIONNÉ",NULL},
/* 2A51 */ { "ET LOGIQUE À POINT EN CHEF",NULL},
/* 2A52 */ { "OU LOGIQUE À POINT EN CHEF",NULL},
/* 2A53 */ { "DOUBLE ET LOGIQUE",NULL},
/* 2A54 */ { "DOUBLE OU LOGIQUE",NULL},
/* 2A55 */ { "DEUX ET LOGIQUES ENTRECROISÉS","	x (opérateur deux et logiques - 2A07)"},
/* 2A56 */ { "DEUX OU LOGIQUES ENTRECROISÉS","	x (opérateur deux ou logiques - 2A08)"},
/* 2A57 */ { "GRAND OU INCLINÉ",NULL},
/* 2A58 */ { "GRAND ET INCLINÉ",NULL},
/* 2A59 */ { "ET ET OU LOGIQUES ENTRECROISÉS",NULL},
/* 2A5A */ { "ET LOGIQUE À HAMPE MÉDIANE",NULL},
/* 2A5B */ { "OU LOGIQUE À HAMPE MÉDIANE",NULL},
/* 2A5C */ { "ET LOGIQUE À TIRET HORIZONTAL",NULL},
/* 2A5D */ { "OU LOGIQUE À TIRET HORIZONTAL",NULL},
/* 2A5E */ { "ET LOGIQUE À DEUX BARRES EN CHEF","	x (perspective - 2306)"},
/* 2A5F */ { "ET LOGIQUE À BARRE SOUSCRITE",NULL},
/* 2A60 */ { "ET LOGIQUE À DEUX BARRES SOUSCRITES","	x (estime - 2259)"},
/* 2A61 */ { "PETIT V À BARRE SOUSCRITE","	x (équiangulaire à - 225A)"},
/* 2A62 */ { "OU LOGIQUE À DEUX BARRES EN CHEF",NULL},
/* 2A63 */ { "OU LOGIQUE À DEUX BARRES SOUSCRITES","	x (équiangulaire à - 225A)"},
/* 2A64 */ { "ANTIRESTRICTION DE DOMAINE EN NOTATION Z",NULL},
/* 2A65 */ { "ANTIRESTRICTION DE CODOMAINE EN NOTATION Z","	x (rétrécissement conique - 2332)"},
/* 2A66 */ { "SIGNE ÉGAL AVEC POINT SOUSCRIT","	x (tend vers la limite - 2250)"},
/* 2A67 */ { "IDENTIQUE AVEC POINT EN CHEF",NULL},
/* 2A68 */ { "DEUX BARRES VERTICALES À TROIS TRAVERSES","	= identique et parallèle à\n"
	"	x (égal et parallèle à - 22D5)\n"
	"	x (identique à et parallèle incliné - 29E5)"},
/* 2A69 */ { "TROIS BARRES VERTICALES À TROIS TRAVERSES",NULL},
/* 2A6A */ { "OPÉRATEUR TILDE AVEC POINT EN CHEF",NULL},
/* 2A6B */ { "OPÉRATEUR TILDE AVEC POINTS ASCENDANTS","	x (homothétique - 223B)"},
/* 2A6C */ { "SIMILAIRE MOINS SIMILAIRE",NULL},
/* 2A6D */ { "CONGRUENT AVEC POINT EN CHEF","	x (approximativement égal à - 2245)"},
/* 2A6E */ { "ÉGAL AVEC ASTÉRISQUE","	x (égal avec étoile en chef - 225B)"},
/* 2A6F */ { "PRESQUE ÉGAL À AVEC ACCENT CIRCONFLEXE",NULL},
/* 2A70 */ { "APPROXIMATIVEMENT ÉGAL OU ÉGAL À","	x (approximativement égal à - 2245)"},
/* 2A71 */ { "SIGNE ÉGAL SUR SIGNE PLUS","	* indique que les Noirs ont un léger avantage (notation échiquéenne)"},
/* 2A72 */ { "SIGNE PLUS SUR SIGNE ÉGAL","	* indique que les Blancs ont un léger avantage (notation échiquéenne)"},
/* 2A73 */ { "SIGNE ÉGAL SUR OPÉRATEUR TILDE",NULL},
/* 2A74 */ { "DOUBLE DEUX-POINTS ÉGAL","	# 003A 003A 003D"},
/* 2A75 */ { "DEUX SIGNES ÉGAL CONSÉCUTIFS","	# 003D 003D"},
/* 2A76 */ { "TROIS SIGNES ÉGAL CONSÉCUTIFS","	# 003D 003D 003D"},
/* 2A77 */ { "SIGNE ÉGAL AVEC DEUX POINTS EN CHEF ET DEUX POINTS SOUSCRITS",NULL},
/* 2A78 */ { "ÉQUIVALENT AVEC QUATRE POINTS EN CHEF",NULL},
/* 2A79 */ { "INFÉRIEUR À AVEC CERCLE INSCRIT",NULL},
/* 2A7A */ { "SUPÉRIEUR À AVEC CERCLE INSCRIT",NULL},
/* 2A7B */ { "INFÉRIEUR À AVEC POINT D'INTERROGATION EN CHEF",NULL},
/* 2A7C */ { "SUPÉRIEUR À AVEC POINT D'INTERROGATION EN CHEF",NULL},
/* 2A7D */ { "INFÉRIEUR À OU ÉGAL À INCLINÉ","	x (inférieur ou égal à - 2264)"},
/* 2A7E */ { "SUPÉRIEUR À OU ÉGAL À INCLINÉ","	x (supérieur ou égal à - 2265)"},
/* 2A7F */ { "INFÉRIEUR À OU ÉGAL À INCLINÉ AVEC POINT INSCRIT",NULL},
/* 2A80 */ { "SUPÉRIEUR À OU ÉGAL À INCLINÉ AVEC POINT INSCRIT",NULL},
/* 2A81 */ { "INFÉRIEUR À OU ÉGAL À INCLINÉ AVEC POINT EN CHEF",NULL},
/* 2A82 */ { "SUPÉRIEUR À OU ÉGAL À INCLINÉ AVEC POINT EN CHEF",NULL},
/* 2A83 */ { "INFÉRIEUR À OU ÉGAL À INCLINÉ AVEC POINT EN CHEF À DROITE",NULL},
/* 2A84 */ { "SUPÉRIEUR À OU ÉGAL À INCLINÉ AVEC POINT EN CHEF À GAUCHE",NULL},
/* 2A85 */ { "INFÉRIEUR À OU PROCHE DE",NULL},
/* 2A86 */ { "SUPÉRIEUR À OU PROCHE DE",NULL},
/* 2A87 */ { "INFÉRIEUR À ET PAS ÉGAL À EN UNE LIGNE","	x (inférieur mais pas égal à - 2268)"},
/* 2A88 */ { "SUPÉRIEUR À ET PAS ÉGAL À EN UNE LIGNE","	x (supérieur mais pas égal à - 2269)"},
/* 2A89 */ { "INFÉRIEUR À ET NON PROCHE DE",NULL},
/* 2A8A */ { "SUPÉRIEUR À ET NON PROCHE DE",NULL},
/* 2A8B */ { "INFÉRIEUR À SUR ÉGAL EN DEUX LIGNES SUR SUPÉRIEUR À","	x (inférieur ou égal ou supérieur à - 22DA)"},
/* 2A8C */ { "SUPÉRIEUR À SUR ÉGAL EN DEUX LIGNES SUR INFÉRIEUR À","	x (supérieur ou égal ou inférieur à - 22DB)"},
/* 2A8D */ { "INFÉRIEUR À SUR SIMILAIRE OU ÉGAL",NULL},
/* 2A8E */ { "SUPÉRIEUR À SUR SIMILAIRE OU ÉGAL",NULL},
/* 2A8F */ { "INFÉRIEUR À SUR SIMILAIRE SUR SUPÉRIEUR À",NULL},
/* 2A90 */ { "SUPÉRIEUR À SUR SIMILAIRE SUR INFÉRIEUR À",NULL},
/* 2A91 */ { "INFÉRIEUR À SUR SUPÉRIEUR À SUR ÉGAL EN DEUX LIGNES",NULL},
/* 2A92 */ { "SUPÉRIEUR À SUR INFÉRIEUR À SUR ÉGAL EN DEUX LIGNES",NULL},
/* 2A93 */ { "INFÉRIEUR À SUR ÉGAL INCLINÉ SUR SUPÉRIEUR À SUR ÉGAL INCLINÉ",NULL},
/* 2A94 */ { "SUPÉRIEUR À SUR ÉGAL INCLINÉ SUR INFÉRIEUR À SUR ÉGAL INCLINÉ",NULL},
/* 2A95 */ { "ÉGAL À INCLINÉ OU INFÉRIEUR À","	x (égal ou inférieur à - 22DC)"},
/* 2A96 */ { "ÉGAL À INCLINÉ OU SUPÉRIEUR À","	x (égal ou supérieur à - 22DD)"},
/* 2A97 */ { "ÉGAL À INCLINÉ OU INFÉRIEUR À AVEC POINT INSCRIT",NULL},
/* 2A98 */ { "ÉGAL À INCLINÉ OU SUPÉRIEUR À AVEC POINT INSCRIT",NULL},
/* 2A99 */ { "ÉGAL EN DEUX LIGNES OU INFÉRIEUR À","	x (égal ou inférieur à - 22DC)"},
/* 2A9A */ { "ÉGAL EN DEUX LIGNES OU SUPÉRIEUR À","	x (égal ou supérieur à - 22DD)"},
/* 2A9B */ { "ÉGAL EN DEUX LIGNES INCLINÉES OU INFÉRIEUR À",NULL},
/* 2A9C */ { "ÉGAL EN DEUX LIGNES INCLINÉES OU SUPÉRIEUR À",NULL},
/* 2A9D */ { "SIMILAIRE OU INFÉRIEUR À","	~ 2A9D FE00 avec similaire suivant l'inclinaison de la jambe supérieure"},
/* 2A9E */ { "SIMILAIRE OU SUPÉRIEUR À","	~ 2A9E FE00 avec similaire suivant l'inclinaison de la jambe supérieure"},
/* 2A9F */ { "SIMILAIRE À SUR INFÉRIEUR À SUR SIGNE ÉGAL",NULL},
/* 2AA0 */ { "SIMILAIRE À SUR SUPÉRIEUR À SUR SIGNE ÉGAL",NULL},
/* 2AA1 */ { "DEUX INFÉRIEUR À EMBOÎTÉS","	= continuité absolue\n"
	"	x (très inférieur à - 226A)"},
/* 2AA2 */ { "DEUX SUPÉRIEUR À EMBOÎTÉS","	x (très supérieur à - 226B)"},
/* 2AA3 */ { "DEUX INFÉRIEUR À EMBOÎTÉS AVEC BARRE SOUSCRITE",NULL},
/* 2AA4 */ { "SUPÉRIEUR À ET INFÉRIEUR À ENTRECROISÉS",NULL},
/* 2AA5 */ { "SUPÉRIEUR À À CÔTÉ DE INFÉRIEUR À",NULL},
/* 2AA6 */ { "INFÉRIEUR À FERMÉ D'UN ARC",NULL},
/* 2AA7 */ { "SUPÉRIEUR À FERMÉ D'UN ARC",NULL},
/* 2AA8 */ { "INFÉRIEUR À FERMÉ D'UN ARC SUR ÉGAL INCLINÉ",NULL},
/* 2AA9 */ { "SUPÉRIEUR À FERMÉ D'UN ARC SUR ÉGAL INCLINÉ",NULL},
/* 2AAA */ { "PLUS PETIT QUE EN FOURCHE",NULL},
/* 2AAB */ { "PLUS GRAND QUE EN FOURCHE",NULL},
/* 2AAC */ { "PLUS PETIT OU ÉGAL À EN FOURCHE","	~ 2AAC FE00 avec un égal incliné"},
/* 2AAD */ { "PLUS GRAND OU ÉGAL À EN FOURCHE","	~ 2AAD FE00 avec un égal incliné"},
/* 2AAE */ { "SIGNE ÉGAL AVEC DOS-D'ÂNE EN CHEF","	x (différence entre - 224F)"},
/* 2AAF */ { "PRÉCÈDE SUR SIGNE ÉGAL EN UNE LIGNE","	x (précède ou est égal à - 227C)"},
/* 2AB0 */ { "SUIT SUR SIGNE ÉGAL EN UNE LIGNE","	x (suit ou est égal à - 227D)"},
/* 2AB1 */ { "PRÉCÈDE SUR PAS ÉGAL À EN UNE LIGNE",NULL},
/* 2AB2 */ { "SUIT SUR PAS ÉGAL À EN UNE LIGNE",NULL},
/* 2AB3 */ { "PRÉCÈDE SUR SIGNE ÉGAL",NULL},
/* 2AB4 */ { "SUIT SUR SIGNE ÉGAL",NULL},
/* 2AB5 */ { "PRÉCÈDE SUR PAS ÉGAL À",NULL},
/* 2AB6 */ { "SUIT SUR PAS ÉGAL À",NULL},
/* 2AB7 */ { "PRÉCÈDE SUR PRESQUE ÉGAL À",NULL},
/* 2AB8 */ { "SUIT SUR PRESQUE ÉGAL À",NULL},
/* 2AB9 */ { "PRÉCÈDE SUR NON PRESQUE ÉGAL À",NULL},
/* 2ABA */ { "SUIT SUR NON PRESQUE ÉGAL À",NULL},
/* 2ABB */ { "DOUBLE PRÉCÈDE",NULL},
/* 2ABC */ { "DOUBLE SUIT",NULL},
/* 2ABD */ { "SOUS-ENSEMBLE POINTÉ",NULL},
/* 2ABE */ { "SUR-ENSEMBLE POINTÉ",NULL},
/* 2ABF */ { "SOUS-ENSEMBLE AVEC SIGNE PLUS SOUSCRIT",NULL},
/* 2AC0 */ { "SUR-ENSEMBLE AVEC SIGNE PLUS SOUSCRIT",NULL},
/* 2AC1 */ { "SOUS-ENSEMBLE AVEC SIGNE DE MULTIPLICATION SOUSCRIT",NULL},
/* 2AC2 */ { "SUR-ENSEMBLE AVEC SIGNE DE MULTIPLICATION SOUSCRIT",NULL},
/* 2AC3 */ { "SOUS-ENSEMBLE DE OU ÉGAL À AVEC POINT EN CHEF",NULL},
/* 2AC4 */ { "SUR-ENSEMBLE DE OU ÉGAL À AVEC POINT EN CHEF",NULL},
/* 2AC5 */ { "SOUS-ENSEMBLE DE SUR SIGNE ÉGAL",NULL},
/* 2AC6 */ { "SUR-ENSEMBLE DE SUR SIGNE ÉGAL",NULL},
/* 2AC7 */ { "SOUS-ENSEMBLE DE SUR OPÉRATEUR TILDE",NULL},
/* 2AC8 */ { "SUR-ENSEMBLE DE SUR OPÉRATEUR TILDE",NULL},
/* 2AC9 */ { "SOUS-ENSEMBLE DE SUR PRESQUE ÉGAL À",NULL},
/* 2ACA */ { "SUR-ENSEMBLE DE SUR PRESQUE ÉGAL À",NULL},
/* 2ACB */ { "SOUS-ENSEMBLE DE SUR PAS ÉGAL À","	~ 2ACB FE00 avec une barre à travers les éléments inférieurs"},
/* 2ACC */ { "SUR-ENSEMBLE DE SUR PAS ÉGAL À","	~ 2ACC FE00 avec une barre à travers les éléments inférieurs"},
/* 2ACD */ { "OPÉRATEUR BOÎTE CARRÉE OUVERTE GAUCHE",NULL},
/* 2ACE */ { "OPÉRATEUR BOÎTE CARRÉE OUVERTE DROITE",NULL},
/* 2ACF */ { "SOUS-ENSEMBLE CLOS","	x (sous-ensemble de - 2282)"},
/* 2AD0 */ { "SUR-ENSEMBLE CLOS","	x (sur-ensemble de - 2283)"},
/* 2AD1 */ { "SOUS-ENSEMBLE CLOS OU ÉGAL À",NULL},
/* 2AD2 */ { "SUR-ENSEMBLE CLOS OU ÉGAL À",NULL},
/* 2AD3 */ { "SOUS-ENSEMBLE SUR SUR-ENSEMBLE",NULL},
/* 2AD4 */ { "SUR-ENSEMBLE SUR SOUS-ENSEMBLE",NULL},
/* 2AD5 */ { "SOUS-ENSEMBLE SUR SOUS-ENSEMBLE",NULL},
/* 2AD6 */ { "SUR-ENSEMBLE SUR SUR-ENSEMBLE",NULL},
/* 2AD7 */ { "SUR-ENSEMBLE À CÔTÉ DE SOUS-ENSEMBLE",NULL},
/* 2AD8 */ { "SUR-ENSEMBLE CHAÎNÉ À SOUS-ENSEMBLE",NULL},
/* 2AD9 */ { "APPARTIENT À OUVERT VERS LE BAS","	x (appartient à - 2208)\n"
	"	x (appartient à ouvert vers le haut - 27D2)"},
/* 2ADA */ { "FOURCHE SURMONTÉE D'UN T","	x (fourche - 22D4)"},
/* 2ADB */ { "INTERSECTION TRANSVERSALE","	x (fourche - 22D4)"},
/* 2ADC */ { "BIFURCATION","	= non indépendant\n"
	"	* symbole en logique équationnelle, pas un symbole informatique\n"
	"	* la non-indépendance (le concept d'origine) est apparentée à la bifurcation\n"
	"	: 2ADD 0338"},
/* 2ADD */ { "NON-BIFURCATION","	= indépendant\n"
	"	* symbole en logique équationnelle, pas un symbole informatique\n"
	"	* l'indépendance (le concept d'origine) est apparentée à la non-bifurcation"},
/* 2ADE */ { "TAQUET À GAUCHE COURT","	x (taquet à gauche - 22A3)"},
/* 2ADF */ { "TAQUET VERS LE BAS COURT","	x (taquet vers le bas - 22A4)"},
/* 2AE0 */ { "TAQUET VERS LE HAUT COURT","	x (taquet vers le haut - 22A5)"},
/* 2AE1 */ { "PERPENDICULAIRE À S",NULL},
/* 2AE2 */ { "TRIPLE TOURNIQUET DROIT À BARRE VERTICALE","	= satisfait habituellement"},
/* 2AE3 */ { "TOURNIQUET GAUCHE À DOUBLE BARRE VERTICALE","	x (oblige - 22A9)"},
/* 2AE4 */ { "DOUBLE TOURNIQUET GAUCHE À BARRE VERTICALE","	x (vrai - 22A8)"},
/* 2AE5 */ { "DOUBLE TOURNIQUET GAUCHE À DOUBLE BARRE VERTICALE",NULL},
/* 2AE6 */ { "DOUBLE BARRE VERTICALE GAUCHE À TRAVERSE","	x (oblige - 22A9)"},
/* 2AE7 */ { "TAQUET VERS LE BAS COURT AVEC BARRE EN CHEF","	x (taquet vers le bas - 22A4)\n"
	"	x (symbole de fonction apl taquet vers le haut barre en chef - 2351)\n"
	"	x (marque postale - 3012)"},
/* 2AE8 */ { "TAQUET VERS LE HAUT COURT AVEC BARRE SOUSCRITE","	x (taquet vers le haut - 22A5)\n"
	"	x (symbole de fonction apl taquet vers le bas barre souscrite - 234A)"},
/* 2AE9 */ { "TAQUET VERS LE HAUT COURT SUR TAQUET VERS LE BAS COURT",NULL},
/* 2AEA */ { "DOUBLE TAQUET VERS LE BAS",NULL},
/* 2AEB */ { "DOUBLE TAQUET VERS LE HAUT","	= indépendance\n"
	"	* théorie des probabilités"},
/* 2AEC */ { "SIGNE NÉGATION À DEUX TRAITS","	x (signe négation - 00AC)"},
/* 2AED */ { "SIGNE NÉGATION À DEUX TRAITS RÉFLÉCHI","	x (signe négation réfléchi - 2310)"},
/* 2AEE */ { "N'EST PAS UN DIVISEUR DE À BARRE DE NÉGATION RÉFLÉCHIE","	x (n'est pas un diviseur de - 2224)"},
/* 2AEF */ { "LIGNE VERTICALE CERCLE EN CHEF",NULL},
/* 2AF0 */ { "LIGNE VERTICALE CERCLE SOUSCRIT",NULL},
/* 2AF1 */ { "TAQUET VERS LE BAS SURMONTANT UN CERCLE","	= satisfait nécessairement\n"
	"	x (taquet vers le haut surmonté d'un cercle - 27DF)"},
/* 2AF2 */ { "PARALLÈLE À VERTICAL À UNE TRAVERSE","	x (non parallèle à - 2226)\n"
	"	x (barre verticale à une traverse - 27CA)"},
/* 2AF3 */ { "PARALLÈLE À AVEC OPÉRATEUR TILDE",NULL},
/* 2AF4 */ { "RELATION BINAIRE TRIPLE BARRE VERTICALE","	= imbriquer\n"
	"	x (délimiteur triple barre verticale - 2980)"},
/* 2AF5 */ { "TRIPLE BARRE VERTICALE À UNE TRAVERSE","	x (barre verticale à une traverse - 27CA)"},
/* 2AF6 */ { "OPÉRATEUR TROIS-POINTS","	* logique\n"
	"	x (trois-points vertical - 205D)\n"
	"	x (trois points suspendus - 22EE)"},
/* 2AF7 */ { "TROIS INFÉRIEUR À EMBOÎTÉS","	x (considérablement inférieur à - 22D8)"},
/* 2AF8 */ { "TROIS SUPÉRIEUR À EMBOÎTÉS","	x (considérablement supérieur à - 22D9)"},
/* 2AF9 */ { "INFÉRIEUR OU ÉGAL À EN DEUX LIGNES INCLINÉES","	x (inférieur à sur égal à - 2266)"},
/* 2AFA */ { "SUPÉRIEUR OU ÉGAL À EN DEUX LIGNES INCLINÉES","	x (supérieur à sur égal à - 2267)"},
/* 2AFB */ { "RELATION BINAIRE TRIPLE OBLIQUE","	x (relation binaire triple barre verticale - 2AF4)"},
/* 2AFC */ { "GRAND OPÉRATEUR À TROIS BARRES VERTICALES","	* souvent n-aire\n"
	"	x (relation binaire triple barre verticale - 2AF4)\n"
	"	x (délimiteur triple barre verticale - 2980)"},
/* 2AFD */ { "OPÉRATEUR DOUBLE OBLIQUE","	x (parallèle à - 2225)"},
/* 2AFE */ { "BARRE VERTICALE BLANCHE","	= choix de Dijkstra"},
/* 2AFF */ { "BARRE VERTICALE BLANCHE N-AIRE","	= choix n-aire de Dijkstra"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_2B[] = {
/* 2B00 */ { "FLÈCHE BLANCHE NORD-EST",NULL},
/* 2B01 */ { "FLÈCHE BLANCHE NORD-OUEST",NULL},
/* 2B02 */ { "FLÈCHE BLANCHE SUD-EST",NULL},
/* 2B03 */ { "FLÈCHE BLANCHE SUD-OUEST",NULL},
/* 2B04 */ { "FLÈCHE BLANCHE GAUCHE-DROITE","	x (flèche blanche vers la gauche - 21E6)\n"
	"	x (flèche blanche haut-bas - 21F3)"},
/* 2B05 */ { "FLÈCHE NOIRE VERS LA GAUCHE","	x (flèche vers la droite noire - 27A1)\n"
	"	x (flèche noire vers la droite - 2B95)"},
/* 2B06 */ { "FLÈCHE NOIRE VERS LE HAUT",NULL},
/* 2B07 */ { "FLÈCHE NOIRE VERS LE BAS",NULL},
/* 2B08 */ { "FLÈCHE NOIRE NORD-EST",NULL},
/* 2B09 */ { "FLÈCHE NOIRE NORD-OUEST",NULL},
/* 2B0A */ { "FLÈCHE NOIRE SUD-EST",NULL},
/* 2B0B */ { "FLÈCHE NOIRE SUD-OUEST",NULL},
/* 2B0C */ { "FLÈCHE NOIRE GAUCHE-DROITE",NULL},
/* 2B0D */ { "FLÈCHE NOIRE HAUT-BAS",NULL},
/* 2B0E */ { "FLÈCHE VERS LA DROITE À POINTE VERS LE BAS",NULL},
/* 2B0F */ { "FLÈCHE VERS LA DROITE À POINTE VERS LE HAUT",NULL},
/* 2B10 */ { "FLÈCHE VERS LA GAUCHE À POINTE VERS LE BAS",NULL},
/* 2B11 */ { "FLÈCHE VERS LA GAUCHE À POINTE VERS LE HAUT",NULL},
/* 2B12 */ { "CARRÉ À MOITIÉ SUPÉRIEURE NOIRE","	x (carré à moitié gauche noire - 25E7)"},
/* 2B13 */ { "CARRÉ À MOITIÉ INFÉRIEURE NOIRE",NULL},
/* 2B14 */ { "CARRÉ À MOITIÉ SUPÉRIEURE DROITE NOIRE",NULL},
/* 2B15 */ { "CARRÉ À MOITIÉ INFÉRIEURE GAUCHE NOIRE",NULL},
/* 2B16 */ { "LOSANGE À MOITIÉ GAUCHE NOIRE",NULL},
/* 2B17 */ { "LOSANGE À MOITIÉ DROITE NOIRE",NULL},
/* 2B18 */ { "LOSANGE À MOITIÉ SUPÉRIEURE NOIRE",NULL},
/* 2B19 */ { "LOSANGE À MOITIÉ INFÉRIEURE NOIRE",NULL},
/* 2B1A */ { "CARRÉ POINTILLÉ",NULL},
/* 2B1B */ { "GRAND CARRÉ NOIR","	x (carré noir - 25A0)"},
/* 2B1C */ { "GRAND CARRÉ BLANC","	x (carré blanc - 25A1)"},
/* 2B1D */ { "TRÈS PETIT CARRÉ NOIR","	x (petit carré noir - 25AA)"},
/* 2B1E */ { "TRÈS PETIT CARRÉ BLANC","	x (petit carré blanc - 25AB)"},
/* 2B1F */ { "PENTAGONE NOIR",NULL},
/* 2B20 */ { "PENTAGONE BLANC",NULL},
/* 2B21 */ { "HEXAGONE BLANC","	x (symbole fonction logicielle - 2394)"},
/* 2B22 */ { "HEXAGONE NOIR",NULL},
/* 2B23 */ { "HEXAGONE NOIR POSÉ SUR UN CÔTÉ",NULL},
/* 2B24 */ { "GRAND CERCLE NOIR","	x (cercle noir - 25CF)\n"
	"	x (grand cercle - 25EF)\n"
	"	x (grand cercle rouge - 1F534)"},
/* 2B25 */ { "LOSANGE MOYEN NOIR","	x (losange noir - 25C6)"},
/* 2B26 */ { "LOSANGE MOYEN BLANC","	x (losange blanc - 25C7)\n"
	"	x (symbole alchimique du savon - 1F754)"},
/* 2B27 */ { "RHOMBE MOYEN NOIR",NULL},
/* 2B28 */ { "RHOMBE MOYEN BLANC","	x (rhombe - 25CA)"},
/* 2B29 */ { "PETIT LOSANGE NOIR","	x (opérateur losange - 22C4)\n"
	"	x (petit losange orange - 1F538)"},
/* 2B2A */ { "PETIT RHOMBE NOIR",NULL},
/* 2B2B */ { "PETIT RHOMBE BLANC",NULL},
/* 2B2C */ { "ELLIPSE HORIZONTALE NOIRE",NULL},
/* 2B2D */ { "ELLIPSE HORIZONTALE BLANCHE",NULL},
/* 2B2E */ { "ELLIPSE VERTICALE NOIRE",NULL},
/* 2B2F */ { "ELLIPSE VERTICALE BLANCHE",NULL},
/* 2B30 */ { "FLÈCHE VERS LA GAUCHE À PETIT CERCLE","	x (flèche vers la droite à petit cercle - 21F4)"},
/* 2B31 */ { "TROIS FLÈCHES VERS LA GAUCHE","	x (trois flèches vers la droite - 21F6)"},
/* 2B32 */ { "FLÈCHE VERS LA GAUCHE À SIGNE PLUS CERCLÉ","	x (flèche vers la droite à signe plus cerclé - 27F4)"},
/* 2B33 */ { "FLÈCHE LONGUE VERS LA GAUCHE EN TIRE-BOUCHON","	= flèche longue gauche dentée\n"
	"	x (flèche longue vers la droite en tire-bouchon - 27FF)\n"
	"	x (flèche vers la gauche en tire-bouchon - 21DC)"},
/* 2B34 */ { "FLÈCHE À DEUX POINTES VERS LA GAUCHE BARRÉE VERTICALEMENT","	x (flèche à deux pointes vers la droite barrée verticalement - 2900)"},
/* 2B35 */ { "FLÈCHE À DEUX POINTES VERS LA GAUCHE BARRÉE DEUX FOIS VERTICALEMENT","	x (flèche à deux pointes vers la droite barrée deux fois verticalement - 2901)"},
/* 2B36 */ { "FLÈCHE À DEUX POINTES D'UN TAQUET VERS LA GAUCHE","	x (flèche à deux pointes d'un taquet vers la droite - 2905)"},
/* 2B37 */ { "FLÈCHE À TROIS TRAITS ET À DEUX TÊTES VERS LA GAUCHE","	x (flèche à trois traits et à deux têtes vers la droite - 2910)"},
/* 2B38 */ { "FLÈCHE VERS LA GAUCHE À FÛT POINTILLÉ","	x (flèche vers la droite à fût pointillé - 2911)"},
/* 2B39 */ { "FLÈCHE EMPENNÉE VERS LA GAUCHE BARRÉE VERTICALEMENT","	x (flèche empennée vers la droite barrée verticalement - 2914)"},
/* 2B3A */ { "FLÈCHE EMPENNÉE VERS LA GAUCHE BARRÉE DEUX FOIS VERTICALEMENT","	x (flèche empennée vers la droite barrée deux fois verticalement - 2915)"},
/* 2B3B */ { "FLÈCHE EMPENNÉE À DEUX POINTES VERS LA GAUCHE","	x (flèche empennée à deux pointes vers la droite - 2916)"},
/* 2B3C */ { "FLÈCHE EMPENNÉE À DEUX POINTES VERS LA GAUCHE BARRÉE VERTICALEMENT","	x (flèche empennée à deux pointes vers la droite barrée verticalement - 2917)"},
/* 2B3D */ { "FLÈCHE EMPENNÉE À DEUX POINTES VERS LA GAUCHE BARRÉE DEUX FOIS VERTICALEMENT","	x (flèche empennée à deux pointes vers la droite barrée deux fois verticalement - 2918)"},
/* 2B3E */ { "FLÈCHE VERS LA GAUCHE À TRAVERS X","	x (flèche vers la droite à travers x - 2947)"},
/* 2B3F */ { "FLÈCHE ONDULÉE POINTANT DIRECTEMENT À GAUCHE","	x (flèche ondulée pointant directement à droite - 2933)\n"
	"	x (flèche vers la gauche ondulée - 219C)"},
/* 2B40 */ { "SIGNE ÉGAL SUR FLÈCHE VERS LA GAUCHE","	x (signe égal sur flèche vers la droite - 2971)"},
/* 2B41 */ { "OPÉRATEUR TILDE RÉFLÉCHI SUR FLÈCHE VERS LA GAUCHE","	* image miroir de « ⥲ »\n"
	"	x (opérateur tilde sur flèche vers la droite - 2972)"},
/* 2B42 */ { "FLÈCHE VERS LA GAUCHE SUR PRESQUE ÉGAL À RÉFLÉCHI","	* image miroir de « ⥵ »\n"
	"	x (flèche vers la droite sur presque égal à - 2975)"},
/* 2B43 */ { "FLÈCHE VERS LA DROITE À TRAVERS SUPÉRIEUR À","	* image miroir de « ⥷ »\n"
	"	x (flèche vers la gauche à travers inférieur à - 2977)"},
/* 2B44 */ { "FLÈCHE VERS LA DROITE À TRAVERS SUR-ENSEMBLE","	* image miroir de « ⥺ »\n"
	"	x (flèche vers la gauche à travers sous-ensemble - 297A)"},
/* 2B45 */ { "QUADRUPLE FLÈCHE VERS LA GAUCHE","	x (quadruple flèche vers le haut - 27F0)"},
/* 2B46 */ { "QUADRUPLE FLÈCHE VERS LA DROITE",NULL},
/* 2B47 */ { "OPÉRATEUR TILDE RÉFLÉCHI SUR FLÈCHE VERS LA DROITE",NULL},
/* 2B48 */ { "FLÈCHE VERS LA DROITE SUR PRESQUE ÉGAL À RÉFLÉCHI",NULL},
/* 2B49 */ { "OPÉRATEUR TILDE SUR FLÈCHE VERS LA GAUCHE",NULL},
/* 2B4A */ { "FLÈCHE VERS LA GAUCHE SUR PRESQUE ÉGAL À",NULL},
/* 2B4B */ { "FLÈCHE VERS LA GAUCHE SUR OPÉRATEUR TILDE RÉFLÉCHI","	* image miroir de « ⥴ »\n"
	"	x (flèche vers la droite sur opérateur tilde - 2974)"},
/* 2B4C */ { "FLÈCHE VERS LA DROITE SUR OPÉRATEUR TILDE RÉFLÉCHI","	* image miroir de « ⥳ »\n"
	"	x (flèche vers la gauche sur opérateur tilde - 2973)"},
/* 2B4D */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE BAS EN ZIGZAG","	x (flèche vers le bas en zigzag - 21AF)"},
/* 2B4E */ { "FLÈCHE COURTE NORD INCLINÉE","	* indique une légère hausse du ton"},
/* 2B4F */ { "FLÈCHE COURTE SUD INCLINÉE EN ARRIÈRE","	* indique une légère baisse ou une baisse globale du ton, respectivement à la fin d'un mot ou au début d'une phrase"},
/* 2B50 */ { "ÉTOILE MOYENNE BLANCHE","	x (étoile blanche - 2606)"},
/* 2B51 */ { "PETITE ÉTOILE NOIRE","	x (étoile à cinq branches arabe - 066D)\n"
	"	x (opérateur étoile - 22C6)\n"
	"	x (étoile noire - 2605)"},
/* 2B52 */ { "PETITE ÉTOILE BLANCHE",NULL},
/* 2B53 */ { "PENTAGONE NOIR POINTANT VERS LA DROITE",NULL},
/* 2B54 */ { "PENTAGONE BLANC POINTANT VERS LA DROITE",NULL},
/* 2B55 */ { "GRAND CERCLE ÉPAIS","	= symbole de base pour les limitations de vitesse\n"
	"	* forme une paire pour le décompte de jeu avec 274C\n"
	"	x (grand cercle - 25EF)"},
/* 2B56 */ { "OVALE ÉPAIS AVEC OVALE INSCRIT","	= office préfectoral"},
/* 2B57 */ { "CERCLE ÉPAIS AVEC CERCLE INSCRIT","	= office municipal\n"
	"	x (deux cercles concentriques - 25CE)"},
/* 2B58 */ { "CERCLE ÉPAIS","	= office villageois\n"
	"	= symbole de mise en marche\n"
	"	x (symbole mise en marche - 23FD)\n"
	"	x (cercle blanc - 25CB)"},
/* 2B59 */ { "SAUTOIR CERCLÉ ÉPAIS","	= bureau de police\n"
	"	x (opérateur de multiplication n-aire cerclé - 2A02)"},
/* 2B5A */ { "FLÈCHE NORD INCLINÉE À TÊTE EN CROCHET","	* ton ascendant avec une tendance à la baisse à la fin"},
/* 2B5B */ { "FLÈCHE SUD INCLINÉE EN ARRIÈRE À TALON EN CROCHET","	* forte hausse et baisse du ton"},
/* 2B5C */ { "FLÈCHE NORD INCLINÉE À TALON HORIZONTAL","	* hausse continue du ton"},
/* 2B5D */ { "FLÈCHE SUD INCLINÉE EN ARRIÈRE À TALON HORIZONTAL","	* baisse continue du ton"},
/* 2B5E */ { "FLÈCHE COUDÉE POINTANT VERS LE BAS PUIS VERS LE NORD-EST","	* forte baisse du ton avec une tendance ascendante à la fin"},
/* 2B5F */ { "FLÈCHE COURTE COUDÉE POINTANT VERS LE BAS PUIS VERS LE NORD-EST","	* légère baisse du ton avec une tendance ascendante à la fin"},
/* 2B60 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA GAUCHE","	x (flèche vers la gauche - 2190)"},
/* 2B61 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE HAUT","	x (flèche vers le haut - 2191)"},
/* 2B62 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA DROITE","	x (flèche vers la droite - 2192)\n"
	"	x (flèche vers la droite à pointe en triangle - 279D)"},
/* 2B63 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE BAS","	x (flèche vers le bas - 2193)"},
/* 2B64 */ { "FLÈCHE GAUCHE-DROITE À POINTES EN TRIANGLE","	x (flèche gauche-droite - 2194)"},
/* 2B65 */ { "FLÈCHE HAUT-BAS À POINTES EN TRIANGLE","	x (flèche haut-bas - 2195)"},
/* 2B66 */ { "FLÈCHE À POINTE EN TRIANGLE NORD-OUEST","	x (flèche nord-ouest - 2196)"},
/* 2B67 */ { "FLÈCHE À POINTE EN TRIANGLE NORD-EST","	x (flèche nord-est - 2197)"},
/* 2B68 */ { "FLÈCHE À POINTE EN TRIANGLE SUD-EST","	x (flèche sud-est - 2198)"},
/* 2B69 */ { "FLÈCHE À POINTE EN TRIANGLE SUD-OUEST","	x (flèche sud-ouest - 2199)"},
/* 2B6A */ { "FLÈCHE À TRAITS DISCONTINUS À POINTE EN TRIANGLE VERS LA GAUCHE","	x (flèche à traits discontinus vers la gauche - 21E0)"},
/* 2B6B */ { "FLÈCHE À TRAITS DISCONTINUS À POINTE EN TRIANGLE VERS LE HAUT","	x (flèche à traits discontinus vers le haut - 21E1)"},
/* 2B6C */ { "FLÈCHE À TRAITS DISCONTINUS À POINTE EN TRIANGLE VERS LA DROITE","	x (flèche à traits discontinus vers la droite - 21E2)"},
/* 2B6D */ { "FLÈCHE À TRAITS DISCONTINUS À POINTE EN TRIANGLE VERS LE BAS","	x (flèche à traits discontinus vers le bas - 21E3)"},
/* 2B6E */ { "FLÈCHE CIRCULAIRE OUVERTE À POINTE EN TRIANGLE SENS HORAIRE","	x (flèche circulaire ouverte sens horaire - 21BB)"},
/* 2B6F */ { "FLÈCHE CIRCULAIRE OUVERTE À POINTE EN TRIANGLE SENS ANTIHORAIRE","	x (flèche circulaire ouverte sens antihoraire - 21BA)"},
/* 2B70 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA GAUCHE JUSQU'À UN TAQUET","	= tabulation arrière\n"
	"	x (flèche vers la gauche jusqu'à un taquet - 21E4)"},
/* 2B71 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE HAUT JUSQU'À UN TAQUET","	= tabulation vers le haut\n"
	"	x (flèche vers le haut jusqu'à un taquet - 2912)"},
/* 2B72 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA DROITE JUSQU'À UN TAQUET","	= tabulation\n"
	"	x (flèche vers la droite jusqu'à un taquet - 21E5)"},
/* 2B73 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE BAS JUSQU'À UN TAQUET","	= tabulation vers le bas\n"
	"	x (flèche vers le bas jusqu'à un taquet - 2913)"},
/* 2B74 */ { NULL,NULL},
/* 2B75 */ { NULL,NULL},
/* 2B76 */ { "FLÈCHE À POINTE EN TRIANGLE NORD-OUEST JUSQU'À UN TAQUET","	= début"},
/* 2B77 */ { "FLÈCHE À POINTE EN TRIANGLE NORD-EST JUSQU'À UN TAQUET",NULL},
/* 2B78 */ { "FLÈCHE À POINTE EN TRIANGLE SUD-EST JUSQU'À UN TAQUET","	= fin"},
/* 2B79 */ { "FLÈCHE À POINTE EN TRIANGLE SUD-OUEST JUSQU'À UN TAQUET",NULL},
/* 2B7A */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA GAUCHE À DOUBLE TRAIT VERTICAL","	* le nom formel de ce caractère en anglais est erroné"},
/* 2B7B */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE HAUT À DOUBLE TRAIT HORIZONTAL","	= page précédente"},
/* 2B7C */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA DROITE À DOUBLE TRAIT VERTICAL","	* le nom formel de ce caractère en anglais est erroné"},
/* 2B7D */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE BAS À DOUBLE TRAIT HORIZONTAL","	= page suivante"},
/* 2B7E */ { "TOUCHE DE TABULATION HORIZONTALE","	x (flèche vers la gauche jusqu'à un taquet sur flèche vers la droite jusqu'à un taquet - 21B9)"},
/* 2B7F */ { "TOUCHE DE TABULATION VERTICALE",NULL},
/* 2B80 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA GAUCHE SUR FLÈCHE À POINTE EN TRIANGLE VERS LA DROITE","	x (flèche vers la gauche sur flèche vers la droite - 21C6)"},
/* 2B81 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE HAUT À GAUCHE D'UNE FLÈCHE À POINTE EN TRIANGLE VERS LE BAS",NULL},
/* 2B82 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LA DROITE SUR FLÈCHE À POINTE EN TRIANGLE VERS LA GAUCHE",NULL},
/* 2B83 */ { "FLÈCHE À POINTE EN TRIANGLE VERS LE BAS À GAUCHE D'UNE FLÈCHE À POINTE EN TRIANGLE VERS LE HAUT","	x (flèche vers le bas à gauche d'une flèche vers le haut - 21F5)"},
/* 2B84 */ { "PAIRE DE FLÈCHES À POINTE EN TRIANGLE VERS LA GAUCHE","	x (paire de flèches vers la gauche - 21C7)"},
/* 2B85 */ { "PAIRE DE FLÈCHES À POINTE EN TRIANGLE VERS LE HAUT","	x (paire de flèches vers le haut - 21C8)"},
/* 2B86 */ { "PAIRE DE FLÈCHES À POINTE EN TRIANGLE VERS LA DROITE","	x (paire de flèches vers la droite - 21C9)"},
/* 2B87 */ { "PAIRE DE FLÈCHES À POINTE EN TRIANGLE VERS LE BAS","	x (paire de flèches vers le bas - 21CA)"},
/* 2B88 */ { "FLÈCHE BLANCHE CERCLÉE DE NOIR VERS LA GAUCHE",NULL},
/* 2B89 */ { "FLÈCHE BLANCHE CERCLÉE DE NOIR VERS LE HAUT",NULL},
/* 2B8A */ { "FLÈCHE BLANCHE CERCLÉE DE NOIR VERS LA DROITE","	x (flèche blanche épaisse vers la droite à contour circulaire - 27B2)"},
/* 2B8B */ { "FLÈCHE BLANCHE CERCLÉE DE NOIR VERS LE BAS",NULL},
/* 2B8C */ { "FLÈCHE EN U À DROITE À POINTE EN TRIANGLE SENS ANTIHORAIRE",NULL},
/* 2B8D */ { "FLÈCHE EN U EN BAS À POINTE EN TRIANGLE SENS ANTIHORAIRE",NULL},
/* 2B8E */ { "FLÈCHE EN U À GAUCHE À POINTE EN TRIANGLE SENS ANTIHORAIRE",NULL},
/* 2B8F */ { "FLÈCHE EN U EN HAUT À POINTE EN TRIANGLE SENS ANTIHORAIRE","	x (flèche semi-circulaire sens antihoraire en chef - 21B6)"},
/* 2B90 */ { "RETOUR DE CHARIOT À GAUCHE","	x (symbole retour de chariot - 23CE)"},
/* 2B91 */ { "RETOUR DE CHARIOT À DROITE",NULL},
/* 2B92 */ { "NOUVELLE LIGNE À GAUCHE",NULL},
/* 2B93 */ { "NOUVELLE LIGNE À DROITE",NULL},
/* 2B94 */ { "QUATRE FLÈCHES EN COIN TOURNANT EN SENS ANTIHORAIRE","	= boucle"},
/* 2B95 */ { "FLÈCHE NOIRE VERS LA DROITE","	x (flèche vers la droite noire - 27A1)\n"
	"	x (flèche noire vers la gauche - 2B05)"},
/* 2B96 */ { "SIGNE ÉGAL AVEC INFINI SUSCRIT","	= avec compensation pour le matériel"},
/* 2B97 */ { "SYMBOLE POUR APPAREIL ÉLECTRONIQUE DE TYPE A","	* pour les appareils électroniques de type B, utilisez 3036\n"
	"	x (marque postale cerclée - 3036)"},
/* 2B98 */ { "POINTE DE FLÈCHE ÉQUILATÉRALE VERS LA GAUCHE EN TROMPE-L'ŒIL ÉCLAIRÉE PAR LE HAUT",NULL},
/* 2B99 */ { "POINTE DE FLÈCHE ÉQUILATÉRALE VERS LE HAUT EN TROMPE-L'ŒIL ÉCLAIRÉE PAR LA DROITE",NULL},
/* 2B9A */ { "POINTE DE FLÈCHE ÉQUILATÉRALE VERS LA DROITE EN TROMPE-L'ŒIL ÉCLAIRÉE PAR LE HAUT","	x (pointe de flèche vers la droite en trompe-l'œil éclairée par le haut - 27A2)"},
/* 2B9B */ { "POINTE DE FLÈCHE ÉQUILATÉRALE VERS LE BAS EN TROMPE-L'ŒIL ÉCLAIRÉE PAR LA GAUCHE",NULL},
/* 2B9C */ { "POINTE DE FLÈCHE ÉQUILATÉRALE NOIRE VERS LA GAUCHE",NULL},
/* 2B9D */ { "POINTE DE FLÈCHE ÉQUILATÉRALE NOIRE VERS LE HAUT",NULL},
/* 2B9E */ { "POINTE DE FLÈCHE ÉQUILATÉRALE NOIRE VERS LA DROITE","	x (pointe de flèche noire vers la droite - 27A4)"},
/* 2B9F */ { "POINTE DE FLÈCHE ÉQUILATÉRALE NOIRE VERS LE BAS",NULL},
/* 2BA0 */ { "FLÈCHE VERS LE BAS À POINTE LONGUE EN TRIANGLE VERS LA GAUCHE","	x (flèche vers le bas à pointe vers la gauche - 21B2)"},
/* 2BA1 */ { "FLÈCHE VERS LE BAS À POINTE LONGUE EN TRIANGLE VERS LA DROITE","	x (flèche vers le bas à pointe vers la droite - 21B3)"},
/* 2BA2 */ { "FLÈCHE VERS LE HAUT À POINTE LONGUE EN TRIANGLE VERS LA GAUCHE","	x (flèche vers le haut à pointe vers la gauche - 21B0)"},
/* 2BA3 */ { "FLÈCHE VERS LE HAUT À POINTE LONGUE EN TRIANGLE VERS LA DROITE","	x (flèche vers le haut à pointe vers la droite - 21B1)"},
/* 2BA4 */ { "FLÈCHE VERS LA GAUCHE À POINTE LONGUE EN TRIANGLE VERS LE HAUT","	x (flèche vers la gauche à pointe vers le haut - 2B11)"},
/* 2BA5 */ { "FLÈCHE VERS LA DROITE À POINTE LONGUE EN TRIANGLE VERS LE HAUT","	x (flèche vers la droite à pointe vers le haut - 2B0F)"},
/* 2BA6 */ { "FLÈCHE VERS LA GAUCHE À POINTE LONGUE EN TRIANGLE VERS LE BAS","	x (flèche vers la gauche à pointe vers le bas - 2B10)"},
/* 2BA7 */ { "FLÈCHE VERS LA DROITE À POINTE LONGUE EN TRIANGLE VERS LE BAS","	x (flèche vers la droite à pointe vers le bas - 2B0E)"},
/* 2BA8 */ { "FLÈCHE NOIRE COURBÉE VERS LE BAS ET VERS LA GAUCHE",NULL},
/* 2BA9 */ { "FLÈCHE NOIRE COURBÉE VERS LE BAS ET VERS LA DROITE","	x (flèche noire épaisse courbée vers le bas et vers la droite - 27A5)"},
/* 2BAA */ { "FLÈCHE NOIRE COURBÉE VERS LE HAUT ET VERS LA GAUCHE",NULL},
/* 2BAB */ { "FLÈCHE NOIRE COURBÉE VERS LE HAUT ET VERS LA DROITE","	x (flèche noire épaisse courbée vers le haut et vers la droite - 27A6)"},
/* 2BAC */ { "FLÈCHE NOIRE COURBÉE VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 2BAD */ { "FLÈCHE NOIRE COURBÉE VERS LA DROITE ET VERS LE HAUT",NULL},
/* 2BAE */ { "FLÈCHE NOIRE COURBÉE VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 2BAF */ { "FLÈCHE NOIRE COURBÉE VERS LA DROITE ET VERS LE BAS",NULL},
/* 2BB0 */ { "FLÈCHE EN RUBAN VERS LE BAS ET VERS LA GAUCHE",NULL},
/* 2BB1 */ { "FLÈCHE EN RUBAN VERS LE BAS ET VERS LA DROITE",NULL},
/* 2BB2 */ { "FLÈCHE EN RUBAN VERS LE HAUT ET VERS LA GAUCHE",NULL},
/* 2BB3 */ { "FLÈCHE EN RUBAN VERS LE HAUT ET VERS LA DROITE",NULL},
/* 2BB4 */ { "FLÈCHE EN RUBAN VERS LA GAUCHE ET VERS LE HAUT",NULL},
/* 2BB5 */ { "FLÈCHE EN RUBAN VERS LA DROITE ET VERS LE HAUT",NULL},
/* 2BB6 */ { "FLÈCHE EN RUBAN VERS LA GAUCHE ET VERS LE BAS",NULL},
/* 2BB7 */ { "FLÈCHE EN RUBAN VERS LA DROITE ET VERS LE BAS",NULL},
/* 2BB8 */ { "FLÈCHE BLANCHE D'UN TAQUET VERS LE HAUT BARRÉE HORIZONTALEMENT","	= verrouillage des majuscules\n"
	"	x (flèche blanche vers le haut sur socle et trait horizontal - 21EC)"},
/* 2BB9 */ { "POINTE DE FLÈCHE VERS LE HAUT INSCRITE DANS UNE BOÎTE RECTANGULAIRE","	= échappement\n"
	"	x (symbole de fonction apl quadrat circonflexe - 2353)"},
/* 2BBA */ { "CARRÉS BLANCS SE CHEVAUCHANT","	= paire de fous\n"
	"	x (carrés se chevauchant - 29C9)"},
/* 2BBB */ { "CARRÉ BLANC ET CARRÉ NOIR SE CHEVAUCHANT","	= fous de couleurs opposées"},
/* 2BBC */ { "CARRÉS NOIRS SE CHEVAUCHANT","	= fous de la même couleur"},
/* 2BBD */ { "CASE DE BULLETIN MARQUÉE D'UN X FIN","	x (case de bulletin marquée d'un x - 2612)"},
/* 2BBE */ { "X CERCLÉ","	x (multiplié par cerclé - 2297)"},
/* 2BBF */ { "X GRAS CERCLÉ",NULL},
/* 2BC0 */ { "CARRÉ NOIR CENTRÉ",NULL},
/* 2BC1 */ { "LOSANGE NOIR CENTRÉ",NULL},
/* 2BC2 */ { "PENTAGONE NOIR CULBUTÉ",NULL},
/* 2BC3 */ { "OCTOGONE NOIR HORIZONTAL","	x (panneau octogonal - 1F6D1)"},
/* 2BC4 */ { "OCTOGONE NOIR",NULL},
/* 2BC5 */ { "TRIANGLE MOYEN NOIR VERS LE HAUT CENTRÉ","	x (triangle noir pointant vers le haut - 25B2)"},
/* 2BC6 */ { "TRIANGLE MOYEN NOIR VERS LE BAS CENTRÉ","	x (triangle noir pointant vers le bas - 25BC)"},
/* 2BC7 */ { "TRIANGLE MOYEN NOIR VERS LA GAUCHE CENTRÉ","	x (triangle noir pointant vers la gauche - 25C0)"},
/* 2BC8 */ { "TRIANGLE MOYEN NOIR VERS LA DROITE CENTRÉ","	x (triangle noir pointant vers la droite - 25B6)"},
/* 2BC9 */ { "NEPTUNE FORME DEUX","	x (neptune - 2646)"},
/* 2BCA */ { "MOITIÉ SUPÉRIEURE DE CERCLE NOIR",NULL},
/* 2BCB */ { "MOITIÉ INFÉRIEURE DE CERCLE NOIR",NULL},
/* 2BCC */ { "VALVULE FINE À QUATRE BRANCHES NOIRE","	x (étoile à quatre branches noire - 2726)"},
/* 2BCD */ { "VALVULE FINE À QUATRE BRANCHES NOIRE COUCHÉE",NULL},
/* 2BCE */ { "VALVULE À QUATRE BRANCHES BLANCHE","	x (étoile à quatre branches blanche - 2727)"},
/* 2BCF */ { "VALVULE À QUATRE BRANCHES BLANCHE COUCHÉE","	x (pastille carrée - 2311)"},
/* 2BD0 */ { "REPÈRE DE CALAGE CARRÉ","	x (repère de calage - 2316)"},
/* 2BD1 */ { "SIGNE D'INCERTITUDE","	x (symbole de fonction apl quadrat info - 2370)\n"
	"	x (caractère de remplacement - FFFD)"},
/* 2BD2 */ { "MARQUE DE GROUPE","	* utilisée jadis comme un caractère séparateur pour les opérations d'E/S\n"
	"	x (double obèle - 2021)\n"
	"	x (thermodynamique - 29E7)\n"
	"	x (triple obèle - 2E4B)"},
/* 2BD3 */ { "PLUTON FORME DEUX","	x (pluton - 2647)"},
/* 2BD4 */ { "PLUTON FORME TROIS",NULL},
/* 2BD5 */ { "PLUTON FORME QUATRE",NULL},
/* 2BD6 */ { "PLUTON FORME CINQ",NULL},
/* 2BD7 */ { "TRANSPLUTON",NULL},
/* 2BD8 */ { "PROSERPINE","	x (symbole astronomique pour l'astéroïde proserpine - 1CECD)"},
/* 2BD9 */ { "ASTRÉE","	x (astrée forme deux - 1F778)"},
/* 2BDA */ { "HYGIE","	= Hygée\n"
	"	x (hygie forme deux - 1F779)"},
/* 2BDB */ { "PHOLOS",NULL},
/* 2BDC */ { "NESSOS",NULL},
/* 2BDD */ { "LUNE BLANCHE SÉLÉNÉ",NULL},
/* 2BDE */ { "LOSANGE NOIR SUR CROIX","	= lune noire vraie Lilith"},
/* 2BDF */ { "LUNE CLAIRE VRAIE ARTA",NULL},
/* 2BE0 */ { "CUPIDON",NULL},
/* 2BE1 */ { "HADÈS",NULL},
/* 2BE2 */ { "ZEUS",NULL},
/* 2BE3 */ { "CRONOS",NULL},
/* 2BE4 */ { "APOLLON",NULL},
/* 2BE5 */ { "ADMÈTE",NULL},
/* 2BE6 */ { "VULCAIN",NULL},
/* 2BE7 */ { "POSÉIDON",NULL},
/* 2BE8 */ { "DEMI-ÉTOILE GAUCHE NOIRE","	x (étoile noire - 2605)"},
/* 2BE9 */ { "DEMI-ÉTOILE DROITE NOIRE",NULL},
/* 2BEA */ { "ÉTOILE À MOITIÉ GAUCHE NOIRE",NULL},
/* 2BEB */ { "ÉTOILE À MOITIÉ DROITE NOIRE",NULL},
/* 2BEC */ { "FLÈCHE À DEUX POINTES TRIANGULAIRES VERS LA GAUCHE","	= déplacement rapide du curseur vers la gauche\n"
	"	x (flèche à deux pointes vers la gauche - 219E)"},
/* 2BED */ { "FLÈCHE À DEUX POINTES TRIANGULAIRES VERS LE HAUT","	= déplacement rapide du curseur vers le haut"},
/* 2BEE */ { "FLÈCHE À DEUX POINTES TRIANGULAIRES VERS LA DROITE","	= déplacement rapide du curseur vers la droite"},
/* 2BEF */ { "FLÈCHE À DEUX POINTES TRIANGULAIRES VERS LE BAS","	= déplacement rapide du curseur vers le bas"},
/* 2BF0 */ { "ÉRIS FORME UN",NULL},
/* 2BF1 */ { "ÉRIS FORME DEUX",NULL},
/* 2BF2 */ { "SEDNA",NULL},
/* 2BF3 */ { "SYMBOLE ASTROLOGIQUE RUSSE VIGINTILE","	* cet aspect est habituellement representé par la lettre V"},
/* 2BF4 */ { "SYMBOLE ASTROLOGIQUE RUSSE NOVILE","	* cet aspect est habituellement representé par la lettre N"},
/* 2BF5 */ { "SYMBOLE ASTROLOGIQUE RUSSE QUINTILE","	* cet aspect est habituellement representé par la lettre Q"},
/* 2BF6 */ { "SYMBOLE ASTROLOGIQUE RUSSE BINOVILE","	* cet aspect est habituellement representé par le terme N²"},
/* 2BF7 */ { "SYMBOLE ASTROLOGIQUE RUSSE SENTAGON","	* représente un aspect de 100 degrés"},
/* 2BF8 */ { "SYMBOLE ASTROLOGIQUE RUSSE TRÉDÉCILE","	* cet aspect est habituellement representé par le terme D³"},
/* 2BF9 */ { "SIGNE ÉGAL AVEC INFINI SOUSCRIT","	= avec compensation pour le matériel\n"
	"	x (signe égal avec infini suscrit - 2B96)"},
/* 2BFA */ { "SYMBOLE LIÉ","	= pions liés\n"
	"	x (symbole du divorce - 26AE)\n"
	"	x (deux anneaux alignés horizontalement - 1CC88)"},
/* 2BFB */ { "SYMBOLE NON LIÉ","	= pions non liés\n"
	"	x (symbole de couple non marié - 26AF)\n"
	"	x (multijection à deux têtes - 29DF)\n"
	"	x (symbole alchimique de l'arsenic - 1F73A)"},
/* 2BFC */ { "SYMBOLE DOUBLÉ","	= pions doublés"},
/* 2BFD */ { "SYMBOLE PASSÉ","	= pion passé\n"
	"	x (signe mâle - 2642)"},
/* 2BFE */ { "ANGLE DROIT RÉFLÉCHI","	= sans\n"
	"	x (angle droit - 221F)"},
/* 2BFF */ { "SYMBOLE PAUSE DE HELLSCHREIBER",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_2C[] = {
/* 2C00 */ { "LETTRE MAJUSCULE GLAGOLITIQUE AZ",NULL},
/* 2C01 */ { "LETTRE MAJUSCULE GLAGOLITIQUE BOUKI",NULL},
/* 2C02 */ { "LETTRE MAJUSCULE GLAGOLITIQUE VÉDI",NULL},
/* 2C03 */ { "LETTRE MAJUSCULE GLAGOLITIQUE GLAGOL",NULL},
/* 2C04 */ { "LETTRE MAJUSCULE GLAGOLITIQUE DOBRO",NULL},
/* 2C05 */ { "LETTRE MAJUSCULE GLAGOLITIQUE IEST",NULL},
/* 2C06 */ { "LETTRE MAJUSCULE GLAGOLITIQUE JIVÉTÉ",NULL},
/* 2C07 */ { "LETTRE MAJUSCULE GLAGOLITIQUE DZÉLO",NULL},
/* 2C08 */ { "LETTRE MAJUSCULE GLAGOLITIQUE ZEMLIA",NULL},
/* 2C09 */ { "LETTRE MAJUSCULE GLAGOLITIQUE IJÉ",NULL},
/* 2C0A */ { "LETTRE MAJUSCULE GLAGOLITIQUE IJÉ INITIAL",NULL},
/* 2C0B */ { "LETTRE MAJUSCULE GLAGOLITIQUE I",NULL},
/* 2C0C */ { "LETTRE MAJUSCULE GLAGOLITIQUE DIERV",NULL},
/* 2C0D */ { "LETTRE MAJUSCULE GLAGOLITIQUE KAKO",NULL},
/* 2C0E */ { "LETTRE MAJUSCULE GLAGOLITIQUE LIOUDIÉ",NULL},
/* 2C0F */ { "LETTRE MAJUSCULE GLAGOLITIQUE MYSLÉTÉ",NULL},
/* 2C10 */ { "LETTRE MAJUSCULE GLAGOLITIQUE NACH",NULL},
/* 2C11 */ { "LETTRE MAJUSCULE GLAGOLITIQUE ON",NULL},
/* 2C12 */ { "LETTRE MAJUSCULE GLAGOLITIQUE POKOÏ",NULL},
/* 2C13 */ { "LETTRE MAJUSCULE GLAGOLITIQUE RTSY",NULL},
/* 2C14 */ { "LETTRE MAJUSCULE GLAGOLITIQUE SLOVO",NULL},
/* 2C15 */ { "LETTRE MAJUSCULE GLAGOLITIQUE TVERDO",NULL},
/* 2C16 */ { "LETTRE MAJUSCULE GLAGOLITIQUE OUK",NULL},
/* 2C17 */ { "LETTRE MAJUSCULE GLAGOLITIQUE FERT",NULL},
/* 2C18 */ { "LETTRE MAJUSCULE GLAGOLITIQUE KHER",NULL},
/* 2C19 */ { "LETTRE MAJUSCULE GLAGOLITIQUE OT",NULL},
/* 2C1A */ { "LETTRE MAJUSCULE GLAGOLITIQUE PÉ",NULL},
/* 2C1B */ { "LETTRE MAJUSCULE GLAGOLITIQUE CHTA",NULL},
/* 2C1C */ { "LETTRE MAJUSCULE GLAGOLITIQUE TSI",NULL},
/* 2C1D */ { "LETTRE MAJUSCULE GLAGOLITIQUE TCHERV",NULL},
/* 2C1E */ { "LETTRE MAJUSCULE GLAGOLITIQUE CHA",NULL},
/* 2C1F */ { "LETTRE MAJUSCULE GLAGOLITIQUE YÉROU",NULL},
/* 2C20 */ { "LETTRE MAJUSCULE GLAGOLITIQUE YER",NULL},
/* 2C21 */ { "LETTRE MAJUSCULE GLAGOLITIQUE IAT",NULL},
/* 2C22 */ { "LETTRE MAJUSCULE GLAGOLITIQUE KHER SOLAIRE","	= khère arachnéen"},
/* 2C23 */ { "LETTRE MAJUSCULE GLAGOLITIQUE IOU",NULL},
/* 2C24 */ { "LETTRE MAJUSCULE GLAGOLITIQUE PETIT IOUSSE","	= in\n"
	"	* son nasal « in », comme dans « vin »"},
/* 2C25 */ { "LETTRE MAJUSCULE GLAGOLITIQUE PETIT IOUSSE À QUEUE",NULL},
/* 2C26 */ { "LETTRE MAJUSCULE GLAGOLITIQUE IO",NULL},
/* 2C27 */ { "LETTRE MAJUSCULE GLAGOLITIQUE PETIT IOUSSE YODISÉ","	= ien\n"
	"	* son nasal « ien », comme dans « bien »"},
/* 2C28 */ { "LETTRE MAJUSCULE GLAGOLITIQUE GRAND IOUSSE","	= on\n"
	"	* son nasal « on », comme dans « mon »"},
/* 2C29 */ { "LETTRE MAJUSCULE GLAGOLITIQUE GRAND IOUSSE YODISÉ","	= ion\n"
	"	* son nasal « ion », comme dans « réunion »"},
/* 2C2A */ { "LETTRE MAJUSCULE GLAGOLITIQUE FITA",NULL},
/* 2C2B */ { "LETTRE MAJUSCULE GLAGOLITIQUE IJITSA",NULL},
/* 2C2C */ { "LETTRE MAJUSCULE GLAGOLITIQUE CHTAPITCH",NULL},
/* 2C2D */ { "LETTRE MAJUSCULE GLAGOLITIQUE A TROKOUTAST",NULL},
/* 2C2E */ { "LETTRE MAJUSCULE GLAGOLITIQUE MYSLÉTÉ LATINISANT",NULL},
/* 2C2F */ { "LETTRE MAJUSCULE GLAGOLITIQUE TCHERV CAUDÉ","		Elle est utilisée comme un substitut de la lettre glagolitique tcherv ; elle a notamment été associée avec 0303 diacritique tilde ou avec 0483 diacritique cyrillique titlo pour former le signe « et cetera »."},
/* 2C30 */ { "LETTRE MINUSCULE GLAGOLITIQUE AZ",NULL},
/* 2C31 */ { "LETTRE MINUSCULE GLAGOLITIQUE BOUKI",NULL},
/* 2C32 */ { "LETTRE MINUSCULE GLAGOLITIQUE VÉDI",NULL},
/* 2C33 */ { "LETTRE MINUSCULE GLAGOLITIQUE GLAGOL",NULL},
/* 2C34 */ { "LETTRE MINUSCULE GLAGOLITIQUE DOBRO",NULL},
/* 2C35 */ { "LETTRE MINUSCULE GLAGOLITIQUE IEST",NULL},
/* 2C36 */ { "LETTRE MINUSCULE GLAGOLITIQUE JIVÉTÉ",NULL},
/* 2C37 */ { "LETTRE MINUSCULE GLAGOLITIQUE DZÉLO",NULL},
/* 2C38 */ { "LETTRE MINUSCULE GLAGOLITIQUE ZEMLIA",NULL},
/* 2C39 */ { "LETTRE MINUSCULE GLAGOLITIQUE IJÉ",NULL},
/* 2C3A */ { "LETTRE MINUSCULE GLAGOLITIQUE IJÉ INITIAL","	x (lettre minuscule cyrillique iota - A647)"},
/* 2C3B */ { "LETTRE MINUSCULE GLAGOLITIQUE I",NULL},
/* 2C3C */ { "LETTRE MINUSCULE GLAGOLITIQUE DIERV",NULL},
/* 2C3D */ { "LETTRE MINUSCULE GLAGOLITIQUE KAKO",NULL},
/* 2C3E */ { "LETTRE MINUSCULE GLAGOLITIQUE LIOUDIÉ",NULL},
/* 2C3F */ { "LETTRE MINUSCULE GLAGOLITIQUE MYSLÉTÉ",NULL},
/* 2C40 */ { "LETTRE MINUSCULE GLAGOLITIQUE NACH",NULL},
/* 2C41 */ { "LETTRE MINUSCULE GLAGOLITIQUE ON",NULL},
/* 2C42 */ { "LETTRE MINUSCULE GLAGOLITIQUE POKOÏ",NULL},
/* 2C43 */ { "LETTRE MINUSCULE GLAGOLITIQUE RTSY",NULL},
/* 2C44 */ { "LETTRE MINUSCULE GLAGOLITIQUE SLOVO",NULL},
/* 2C45 */ { "LETTRE MINUSCULE GLAGOLITIQUE TVERDO",NULL},
/* 2C46 */ { "LETTRE MINUSCULE GLAGOLITIQUE OUK",NULL},
/* 2C47 */ { "LETTRE MINUSCULE GLAGOLITIQUE FERT",NULL},
/* 2C48 */ { "LETTRE MINUSCULE GLAGOLITIQUE KHER",NULL},
/* 2C49 */ { "LETTRE MINUSCULE GLAGOLITIQUE OT",NULL},
/* 2C4A */ { "LETTRE MINUSCULE GLAGOLITIQUE PÉ",NULL},
/* 2C4B */ { "LETTRE MINUSCULE GLAGOLITIQUE CHTA",NULL},
/* 2C4C */ { "LETTRE MINUSCULE GLAGOLITIQUE TSI",NULL},
/* 2C4D */ { "LETTRE MINUSCULE GLAGOLITIQUE TCHERV",NULL},
/* 2C4E */ { "LETTRE MINUSCULE GLAGOLITIQUE CHA",NULL},
/* 2C4F */ { "LETTRE MINUSCULE GLAGOLITIQUE YÉROU",NULL},
/* 2C50 */ { "LETTRE MINUSCULE GLAGOLITIQUE YER",NULL},
/* 2C51 */ { "LETTRE MINUSCULE GLAGOLITIQUE IAT",NULL},
/* 2C52 */ { "LETTRE MINUSCULE GLAGOLITIQUE KHER SOLAIRE",NULL},
/* 2C53 */ { "LETTRE MINUSCULE GLAGOLITIQUE IOU",NULL},
/* 2C54 */ { "LETTRE MINUSCULE GLAGOLITIQUE PETIT IOUSSE",NULL},
/* 2C55 */ { "LETTRE MINUSCULE GLAGOLITIQUE PETIT IOUSSE À QUEUE",NULL},
/* 2C56 */ { "LETTRE MINUSCULE GLAGOLITIQUE IO",NULL},
/* 2C57 */ { "LETTRE MINUSCULE GLAGOLITIQUE PETIT IOUSSE YODISÉ",NULL},
/* 2C58 */ { "LETTRE MINUSCULE GLAGOLITIQUE GRAND IOUSSE",NULL},
/* 2C59 */ { "LETTRE MINUSCULE GLAGOLITIQUE GRAND IOUSSE YODISÉ",NULL},
/* 2C5A */ { "LETTRE MINUSCULE GLAGOLITIQUE FITA",NULL},
/* 2C5B */ { "LETTRE MINUSCULE GLAGOLITIQUE IJITSA",NULL},
/* 2C5C */ { "LETTRE MINUSCULE GLAGOLITIQUE CHTAPITCH",NULL},
/* 2C5D */ { "LETTRE MINUSCULE GLAGOLITIQUE A TROKOUTAST",NULL},
/* 2C5E */ { "LETTRE MINUSCULE GLAGOLITIQUE MYSLÉTÉ LATINISANT",NULL},
/* 2C5F */ { "LETTRE MINUSCULE GLAGOLITIQUE TCHERV CAUDÉ",NULL},
/* 2C60 */ { "LETTRE MAJUSCULE LATINE L À DOUBLE BARRE","	x (lettre majuscule latine l rayé - 023D)"},
/* 2C61 */ { "LETTRE MINUSCULE LATINE L À DOUBLE BARRE","	x (lettre minuscule latine l rayé - 019A)\n"
	"	x (lettre minuscule latine l double tilde médian - AB38)"},
/* 2C62 */ { "LETTRE MAJUSCULE LATINE L TILDE MÉDIAN","	* la minuscule est 026B\n"
	"	x (lettre majuscule latine l barré - 0141)"},
/* 2C63 */ { "LETTRE MAJUSCULE LATINE P BARRÉ","	* la minuscule est 1D7D"},
/* 2C64 */ { "LETTRE MAJUSCULE LATINE R HAMEÇON RÉTROFLEXE","	* la minuscule est 027D"},
/* 2C65 */ { "LETTRE MINUSCULE LATINE A BARRÉ","	* la majuscule est 023A"},
/* 2C66 */ { "LETTRE MINUSCULE LATINE T BARRÉ DIAGONALEMENT","	* la majuscule est 023E"},
/* 2C67 */ { "LETTRE MAJUSCULE LATINE H CRAMPON","	x (lettre majuscule cyrillique enne crampon - 04A2)"},
/* 2C68 */ { "LETTRE MINUSCULE LATINE H CRAMPON",NULL},
/* 2C69 */ { "LETTRE MAJUSCULE LATINE K CRAMPON","	x (lettre majuscule cyrillique ka crampon - 049A)"},
/* 2C6A */ { "LETTRE MINUSCULE LATINE K CRAMPON",NULL},
/* 2C6B */ { "LETTRE MAJUSCULE LATINE Z CRAMPON","	x (lettre majuscule latine z hameçon - 0224)"},
/* 2C6C */ { "LETTRE MINUSCULE LATINE Z CRAMPON",NULL},
/* 2C6D */ { "LETTRE MAJUSCULE LATINE ALPHA","	= a cursif majuscule\n"
	"	* la minuscule est 0251"},
/* 2C6E */ { "LETTRE MAJUSCULE LATINE M HAMEÇON","	* la minuscule est 0271"},
/* 2C6F */ { "LETTRE MAJUSCULE LATINE A CULBUTÉ","	* la minuscule est 0250\n"
	"	x (pour tout - 2200)"},
/* 2C70 */ { "LETTRE MAJUSCULE LATINE ALPHA CULBUTÉ","	* la minuscule est 0252"},
/* 2C71 */ { "LETTRE MINUSCULE LATINE V CROSSE À DROITE","	* API : consonne battue labio-dentale sonore"},
/* 2C72 */ { "LETTRE MAJUSCULE LATINE W CROSSE",NULL},
/* 2C73 */ { "LETTRE MINUSCULE LATINE W CROSSE",NULL},
/* 2C74 */ { "LETTRE MINUSCULE LATINE V BOUCLÉ",NULL},
/* 2C75 */ { "LETTRE MAJUSCULE LATINE MOITIÉ DE H","	x (lettre majuscule grecque hêta - 0370)\n"
	"	x (majuscule f culbuté - 2132)\n"
	"	x (chiffre romain cent réfléchi - 2183)\n"
	"	x (lettre majuscule latine moitié de h réfléchie - A7F5)"},
/* 2C76 */ { "LETTRE MINUSCULE LATINE MOITIÉ DE H","	x (lettre minuscule grecque hêta - 0371)\n"
	"	x (lettre minuscule latine moitié de h réfléchie - A7F6)"},
/* 2C77 */ { "LETTRE MINUSCULE LATINE PHI SANS QUEUE","	* o moyen arrondi\n"
	"	x (lettre minuscule grecque phi - 03C6)"},
/* 2C78 */ { "LETTRE MINUSCULE LATINE E À CRAN",NULL},
/* 2C79 */ { "LETTRE MINUSCULE LATINE R HAMEÇON CULBUTÉ",NULL},
/* 2C7A */ { "LETTRE MINUSCULE LATINE O À PETIT ROND INSCRIT",NULL},
/* 2C7B */ { "LETTRE LATINE PETITE CAPITALE E CULBUTÉ","	x (lettre majuscule latine e culbuté - 018E)"},
/* 2C7C */ { "INDICE LETTRE MINUSCULE LATINE J","	# <souscrite> 006A"},
/* 2C7D */ { "LETTRE MODIFICATIVE MAJUSCULE V","	# <exp> 0056"},
/* 2C7E */ { "LETTRE MAJUSCULE LATINE S À PARAPHE","	* la minuscule est 023F\n"
	"	x (lettre majuscule latine s hameçon rétroflexe - A7C5)"},
/* 2C7F */ { "LETTRE MAJUSCULE LATINE Z À PARAPHE","	* la minuscule est 0240"},
/* 2C80 */ { "LETTRE MAJUSCULE COPTE ALPHA",NULL},
/* 2C81 */ { "LETTRE MINUSCULE COPTE ALPHA",NULL},
/* 2C82 */ { "LETTRE MAJUSCULE COPTE VITA",NULL},
/* 2C83 */ { "LETTRE MINUSCULE COPTE VITA",NULL},
/* 2C84 */ { "LETTRE MAJUSCULE COPTE GAMMA",NULL},
/* 2C85 */ { "LETTRE MINUSCULE COPTE GAMMA",NULL},
/* 2C86 */ { "LETTRE MAJUSCULE COPTE DELTA",NULL},
/* 2C87 */ { "LETTRE MINUSCULE COPTE DELTA",NULL},
/* 2C88 */ { "LETTRE MAJUSCULE COPTE EI",NULL},
/* 2C89 */ { "LETTRE MINUSCULE COPTE EI",NULL},
/* 2C8A */ { "LETTRE MAJUSCULE COPTE SOU",NULL},
/* 2C8B */ { "LETTRE MINUSCULE COPTE SOU",NULL},
/* 2C8C */ { "LETTRE MAJUSCULE COPTE ZITA",NULL},
/* 2C8D */ { "LETTRE MINUSCULE COPTE ZITA",NULL},
/* 2C8E */ { "LETTRE MAJUSCULE COPTE ITA",NULL},
/* 2C8F */ { "LETTRE MINUSCULE COPTE ITA",NULL},
/* 2C90 */ { "LETTRE MAJUSCULE COPTE THITA",NULL},
/* 2C91 */ { "LETTRE MINUSCULE COPTE THITA",NULL},
/* 2C92 */ { "LETTRE MAJUSCULE COPTE IOTA",NULL},
/* 2C93 */ { "LETTRE MINUSCULE COPTE IOTA",NULL},
/* 2C94 */ { "LETTRE MAJUSCULE COPTE KAPPA",NULL},
/* 2C95 */ { "LETTRE MINUSCULE COPTE KAPPA",NULL},
/* 2C96 */ { "LETTRE MAJUSCULE COPTE LAOULA",NULL},
/* 2C97 */ { "LETTRE MINUSCULE COPTE LAOULA",NULL},
/* 2C98 */ { "LETTRE MAJUSCULE COPTE MI",NULL},
/* 2C99 */ { "LETTRE MINUSCULE COPTE MI",NULL},
/* 2C9A */ { "LETTRE MAJUSCULE COPTE NI",NULL},
/* 2C9B */ { "LETTRE MINUSCULE COPTE NI",NULL},
/* 2C9C */ { "LETTRE MAJUSCULE COPTE KSI",NULL},
/* 2C9D */ { "LETTRE MINUSCULE COPTE KSI",NULL},
/* 2C9E */ { "LETTRE MAJUSCULE COPTE O",NULL},
/* 2C9F */ { "LETTRE MINUSCULE COPTE O",NULL},
/* 2CA0 */ { "LETTRE MAJUSCULE COPTE PI",NULL},
/* 2CA1 */ { "LETTRE MINUSCULE COPTE PI",NULL},
/* 2CA2 */ { "LETTRE MAJUSCULE COPTE RHÔ",NULL},
/* 2CA3 */ { "LETTRE MINUSCULE COPTE RHÔ",NULL},
/* 2CA4 */ { "LETTRE MAJUSCULE COPTE SIMA",NULL},
/* 2CA5 */ { "LETTRE MINUSCULE COPTE SIMA",NULL},
/* 2CA6 */ { "LETTRE MAJUSCULE COPTE TAU",NULL},
/* 2CA7 */ { "LETTRE MINUSCULE COPTE TAU",NULL},
/* 2CA8 */ { "LETTRE MAJUSCULE COPTE HEI",NULL},
/* 2CA9 */ { "LETTRE MINUSCULE COPTE HEI",NULL},
/* 2CAA */ { "LETTRE MAJUSCULE COPTE PHI",NULL},
/* 2CAB */ { "LETTRE MINUSCULE COPTE PHI",NULL},
/* 2CAC */ { "LETTRE MAJUSCULE COPTE KHI",NULL},
/* 2CAD */ { "LETTRE MINUSCULE COPTE KHI",NULL},
/* 2CAE */ { "LETTRE MAJUSCULE COPTE PSI",NULL},
/* 2CAF */ { "LETTRE MINUSCULE COPTE PSI",NULL},
/* 2CB0 */ { "LETTRE MAJUSCULE COPTE Ô",NULL},
/* 2CB1 */ { "LETTRE MINUSCULE COPTE Ô",NULL},
/* 2CB2 */ { "LETTRE MAJUSCULE COPTE DIALECTE-P ALEF",NULL},
/* 2CB3 */ { "LETTRE MINUSCULE COPTE DIALECTE-P ALEF",NULL},
/* 2CB4 */ { "LETTRE MAJUSCULE VIEUX COPTE 'AÏN",NULL},
/* 2CB5 */ { "LETTRE MINUSCULE VIEUX COPTE 'AÏN",NULL},
/* 2CB6 */ { "LETTRE MAJUSCULE COPTE CRYPTOGRAPHIQUE EI",NULL},
/* 2CB7 */ { "LETTRE MINUSCULE COPTE CRYPTOGRAPHIQUE EI",NULL},
/* 2CB8 */ { "LETTRE MAJUSCULE COPTE DIALECTE-P KAPPA",NULL},
/* 2CB9 */ { "LETTRE MINUSCULE COPTE DIALECTE-P KAPPA",NULL},
/* 2CBA */ { "LETTRE MAJUSCULE COPTE DIALECTE-P NI","	= nu en tiret"},
/* 2CBB */ { "LETTRE MINUSCULE COPTE DIALECTE-P NI",NULL},
/* 2CBC */ { "LETTRE MAJUSCULE COPTE CRYPTOGRAPHIQUE NI",NULL},
/* 2CBD */ { "LETTRE MINUSCULE COPTE CRYPTOGRAPHIQUE NI",NULL},
/* 2CBE */ { "LETTRE MAJUSCULE VIEUX COPTE Ô",NULL},
/* 2CBF */ { "LETTRE MINUSCULE VIEUX COPTE Ô",NULL},
/* 2CC0 */ { "LETTRE MAJUSCULE COPTE SAMPI",NULL},
/* 2CC1 */ { "LETTRE MINUSCULE COPTE SAMPI",NULL},
/* 2CC2 */ { "LETTRE MAJUSCULE COPTE CHAÏ À CROIX",NULL},
/* 2CC3 */ { "LETTRE MINUSCULE COPTE CHAÏ À CROIX",NULL},
/* 2CC4 */ { "LETTRE MAJUSCULE VIEUX COPTE CHAÏ",NULL},
/* 2CC5 */ { "LETTRE MINUSCULE VIEUX COPTE CHAÏ",NULL},
/* 2CC6 */ { "LETTRE MAJUSCULE VIEUX COPTE ECH","	= barre de fraction"},
/* 2CC7 */ { "LETTRE MINUSCULE VIEUX COPTE ECH",NULL},
/* 2CC8 */ { "LETTRE MAJUSCULE COPTE AKHMÎMIQUE KHAÏ",NULL},
/* 2CC9 */ { "LETTRE MINUSCULE COPTE AKHMÎMIQUE KHAÏ",NULL},
/* 2CCA */ { "LETTRE MAJUSCULE COPTE DIALECTE-P HORI","	= hori barré"},
/* 2CCB */ { "LETTRE MINUSCULE COPTE DIALECTE-P HORI",NULL},
/* 2CCC */ { "LETTRE MAJUSCULE VIEUX COPTE HORI",NULL},
/* 2CCD */ { "LETTRE MINUSCULE VIEUX COPTE HORI",NULL},
/* 2CCE */ { "LETTRE MAJUSCULE VIEUX COPTE HA",NULL},
/* 2CCF */ { "LETTRE MINUSCULE VIEUX COPTE HA",NULL},
/* 2CD0 */ { "LETTRE MAJUSCULE COPTE HA EN L",NULL},
/* 2CD1 */ { "LETTRE MINUSCULE COPTE HA EN L",NULL},
/* 2CD2 */ { "LETTRE MAJUSCULE VIEUX COPTE HEI",NULL},
/* 2CD3 */ { "LETTRE MINUSCULE VIEUX COPTE HEI",NULL},
/* 2CD4 */ { "LETTRE MAJUSCULE VIEUX COPTE HAT",NULL},
/* 2CD5 */ { "LETTRE MINUSCULE VIEUX COPTE HAT",NULL},
/* 2CD6 */ { "LETTRE MAJUSCULE VIEUX COPTE DJANDJA",NULL},
/* 2CD7 */ { "LETTRE MINUSCULE VIEUX COPTE DJANDJA",NULL},
/* 2CD8 */ { "LETTRE MAJUSCULE VIEUX COPTE DJA",NULL},
/* 2CD9 */ { "LETTRE MINUSCULE VIEUX COPTE DJA",NULL},
/* 2CDA */ { "LETTRE MAJUSCULE VIEUX COPTE TCHIMA","	= triangle divisé"},
/* 2CDB */ { "LETTRE MINUSCULE VIEUX COPTE TCHIMA",NULL},
/* 2CDC */ { "LETTRE MAJUSCULE COPTE VIEUX NUBIEN TCHIMA",NULL},
/* 2CDD */ { "LETTRE MINUSCULE COPTE VIEUX NUBIEN TCHIMA",NULL},
/* 2CDE */ { "LETTRE MAJUSCULE COPTE VIEUX NUBIEN NGI",NULL},
/* 2CDF */ { "LETTRE MINUSCULE COPTE VIEUX NUBIEN NGI",NULL},
/* 2CE0 */ { "LETTRE MAJUSCULE COPTE VIEUX NUBIEN ÑI",NULL},
/* 2CE1 */ { "LETTRE MINUSCULE COPTE VIEUX NUBIEN ÑI",NULL},
/* 2CE2 */ { "LETTRE MAJUSCULE COPTE VIEUX NUBIEN WAU",NULL},
/* 2CE3 */ { "LETTRE MINUSCULE COPTE VIEUX NUBIEN WAU",NULL},
/* 2CE4 */ { "SYMBOLE COPTE KAI","	x (symbole grec kai - 03D7)"},
/* 2CE5 */ { "SYMBOLE COPTE MI RHÔ",NULL},
/* 2CE6 */ { "SYMBOLE COPTE PI RHÔ",NULL},
/* 2CE7 */ { "SYMBOLE COPTE STAUROS","	* abréviation de croix"},
/* 2CE8 */ { "SYMBOLE COPTE TAU RHÔ","	x (symbole grec tau rhô - 101A0)"},
/* 2CE9 */ { "SYMBOLE COPTE KHI RHÔ","	x (chrisme - 2627)"},
/* 2CEA */ { "SYMBOLE COPTE TCHIMA SIMA","	* abréviation de Seigneur (« tchoïs »), habituellement surmontée de la barre de contraction"},
/* 2CEB */ { "LETTRE MAJUSCULE COPTE CRYPTOGRAPHIQUE CHAÏ",NULL},
/* 2CEC */ { "LETTRE MINUSCULE COPTE CRYPTOGRAPHIQUE CHAÏ",NULL},
/* 2CED */ { "LETTRE MAJUSCULE COPTE CRYPTOGRAPHIQUE DJANDJA",NULL},
/* 2CEE */ { "LETTRE MINUSCULE COPTE CRYPTOGRAPHIQUE DJANDJA",NULL},
/* 2CEF */ { "DIACRITIQUE COPTE NI SUSCRIT","	* ce signe est utilisé en position finale et s'étend au-dessus du caractère suivant (généralement une espace)"},
/* 2CF0 */ { "DIACRITIQUE COPTE ESPRIT RUDE","	x (diacritique virgule réfléchie en chef - 0314)\n"
	"	x (diacritique cyrillique dasia pneumata - 0485)"},
/* 2CF1 */ { "DIACRITIQUE COPTE ESPRIT DOUX","	x (diacritique virgule en chef - 0313)\n"
	"	x (diacritique cyrillique psili pneumata - 0486)"},
/* 2CF2 */ { "LETTRE MAJUSCULE COPTE BOHAÏRIQUE KHAÏ","	x (lettre majuscule copte khaï - 03E6)"},
/* 2CF3 */ { "LETTRE MINUSCULE COPTE BOHAÏRIQUE KHAÏ","	x (lettre minuscule copte khaï - 03E7)"},
/* 2CF4 */ { NULL,NULL},
/* 2CF5 */ { NULL,NULL},
/* 2CF6 */ { NULL,NULL},
/* 2CF7 */ { NULL,NULL},
/* 2CF8 */ { NULL,NULL},
/* 2CF9 */ { "POINT COPTE VIEUX NUBIEN",NULL},
/* 2CFA */ { "POINT D'INTERROGATION DIRECTE COPTE VIEUX NUBIEN",NULL},
/* 2CFB */ { "POINT D'INTERROGATION INDIRECTE COPTE VIEUX NUBIEN",NULL},
/* 2CFC */ { "DIVISEUR DE VERS COPTE VIEUX NUBIEN",NULL},
/* 2CFD */ { "FRACTION COPTE UN DEMI",NULL},
/* 2CFE */ { "POINT COPTE",NULL},
/* 2CFF */ { "DIVISEUR MORPHOLOGIQUE COPTE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_2D[] = {
/* 2D00 */ { "LETTRE GÉORGIENNE NOUSKHOURI AN","	x (lettre géorgienne assomtavrouli an - 10A0)"},
/* 2D01 */ { "LETTRE GÉORGIENNE NOUSKHOURI BAN",NULL},
/* 2D02 */ { "LETTRE GÉORGIENNE NOUSKHOURI GAN",NULL},
/* 2D03 */ { "LETTRE GÉORGIENNE NOUSKHOURI DON",NULL},
/* 2D04 */ { "LETTRE GÉORGIENNE NOUSKHOURI ÈN",NULL},
/* 2D05 */ { "LETTRE GÉORGIENNE NOUSKHOURI VIN",NULL},
/* 2D06 */ { "LETTRE GÉORGIENNE NOUSKHOURI ZÉN",NULL},
/* 2D07 */ { "LETTRE GÉORGIENNE NOUSKHOURI THAN",NULL},
/* 2D08 */ { "LETTRE GÉORGIENNE NOUSKHOURI IN",NULL},
/* 2D09 */ { "LETTRE GÉORGIENNE NOUSKHOURI K'AN",NULL},
/* 2D0A */ { "LETTRE GÉORGIENNE NOUSKHOURI LASS",NULL},
/* 2D0B */ { "LETTRE GÉORGIENNE NOUSKHOURI MAN",NULL},
/* 2D0C */ { "LETTRE GÉORGIENNE NOUSKHOURI NAR",NULL},
/* 2D0D */ { "LETTRE GÉORGIENNE NOUSKHOURI ON",NULL},
/* 2D0E */ { "LETTRE GÉORGIENNE NOUSKHOURI P'AR",NULL},
/* 2D0F */ { "LETTRE GÉORGIENNE NOUSKHOURI JAN",NULL},
/* 2D10 */ { "LETTRE GÉORGIENNE NOUSKHOURI RAÉ",NULL},
/* 2D11 */ { "LETTRE GÉORGIENNE NOUSKHOURI SAN",NULL},
/* 2D12 */ { "LETTRE GÉORGIENNE NOUSKHOURI T'AR",NULL},
/* 2D13 */ { "LETTRE GÉORGIENNE NOUSKHOURI OUN",NULL},
/* 2D14 */ { "LETTRE GÉORGIENNE NOUSKHOURI PHAR",NULL},
/* 2D15 */ { "LETTRE GÉORGIENNE NOUSKHOURI KHAR",NULL},
/* 2D16 */ { "LETTRE GÉORGIENNE NOUSKHOURI GHAN",NULL},
/* 2D17 */ { "LETTRE GÉORGIENNE NOUSKHOURI Q'AR",NULL},
/* 2D18 */ { "LETTRE GÉORGIENNE NOUSKHOURI CHIN",NULL},
/* 2D19 */ { "LETTRE GÉORGIENNE NOUSKHOURI TCHIN",NULL},
/* 2D1A */ { "LETTRE GÉORGIENNE NOUSKHOURI TSIN",NULL},
/* 2D1B */ { "LETTRE GÉORGIENNE NOUSKHOURI DZIL",NULL},
/* 2D1C */ { "LETTRE GÉORGIENNE NOUSKHOURI TS'IL",NULL},
/* 2D1D */ { "LETTRE GÉORGIENNE NOUSKHOURI TCH'AR",NULL},
/* 2D1E */ { "LETTRE GÉORGIENNE NOUSKHOURI KHAN",NULL},
/* 2D1F */ { "LETTRE GÉORGIENNE NOUSKHOURI DJAN",NULL},
/* 2D20 */ { "LETTRE GÉORGIENNE NOUSKHOURI HAÉ",NULL},
/* 2D21 */ { "LETTRE GÉORGIENNE NOUSKHOURI HÉ",NULL},
/* 2D22 */ { "LETTRE GÉORGIENNE NOUSKHOURI IÉ",NULL},
/* 2D23 */ { "LETTRE GÉORGIENNE NOUSKHOURI WIÉ",NULL},
/* 2D24 */ { "LETTRE GÉORGIENNE NOUSKHOURI QAR",NULL},
/* 2D25 */ { "LETTRE GÉORGIENNE NOUSKHOURI HOÉ",NULL},
/* 2D26 */ { NULL,NULL},
/* 2D27 */ { "LETTRE GÉORGIENNE NOUSKHOURI YN",NULL},
/* 2D28 */ { NULL,NULL},
/* 2D29 */ { NULL,NULL},
/* 2D2A */ { NULL,NULL},
/* 2D2B */ { NULL,NULL},
/* 2D2C */ { NULL,NULL},
/* 2D2D */ { "LETTRE GÉORGIENNE NOUSKHOURI AÈN",NULL},
/* 2D2E */ { NULL,NULL},
/* 2D2F */ { NULL,NULL},
/* 2D30 */ { "LETTRE TIFINAGHE YA",NULL},
/* 2D31 */ { "LETTRE TIFINAGHE YAB",NULL},
/* 2D32 */ { "LETTRE TIFINAGHE YABH",NULL},
/* 2D33 */ { "LETTRE TIFINAGHE YAG",NULL},
/* 2D34 */ { "LETTRE TIFINAGHE YAGHH",NULL},
/* 2D35 */ { "LETTRE TIFINAGHE YADJ ACADÉMIE BERBÈRE",NULL},
/* 2D36 */ { "LETTRE TIFINAGHE YADJ",NULL},
/* 2D37 */ { "LETTRE TIFINAGHE YAD",NULL},
/* 2D38 */ { "LETTRE TIFINAGHE YADH",NULL},
/* 2D39 */ { "LETTRE TIFINAGHE YADD",NULL},
/* 2D3A */ { "LETTRE TIFINAGHE YADDH",NULL},
/* 2D3B */ { "LETTRE TIFINAGHE YEY",NULL},
/* 2D3C */ { "LETTRE TIFINAGHE YAF",NULL},
/* 2D3D */ { "LETTRE TIFINAGHE YAK",NULL},
/* 2D3E */ { "LETTRE TIFINAGHE YAK TOUAREG",NULL},
/* 2D3F */ { "LETTRE TIFINAGHE YAKHH",NULL},
/* 2D40 */ { "LETTRE TIFINAGHE YAH","	= yab touareg"},
/* 2D41 */ { "LETTRE TIFINAGHE YAH ACADÉMIE BERBÈRE",NULL},
/* 2D42 */ { "LETTRE TIFINAGHE YAH TOUAREG",NULL},
/* 2D43 */ { "LETTRE TIFINAGHE YAHH",NULL},
/* 2D44 */ { "LETTRE TIFINAGHE YA'",NULL},
/* 2D45 */ { "LETTRE TIFINAGHE YAKH",NULL},
/* 2D46 */ { "LETTRE TIFINAGHE YAKH TOUAREG",NULL},
/* 2D47 */ { "LETTRE TIFINAGHE YAQ",NULL},
/* 2D48 */ { "LETTRE TIFINAGHE YAQ TOUAREG",NULL},
/* 2D49 */ { "LETTRE TIFINAGHE YI",NULL},
/* 2D4A */ { "LETTRE TIFINAGHE YAJ",NULL},
/* 2D4B */ { "LETTRE TIFINAGHE YAJ DE L'AHAGGAR",NULL},
/* 2D4C */ { "LETTRE TIFINAGHE YAJ TOUAREG",NULL},
/* 2D4D */ { "LETTRE TIFINAGHE YAL",NULL},
/* 2D4E */ { "LETTRE TIFINAGHE YAM",NULL},
/* 2D4F */ { "LETTRE TIFINAGHE YAN",NULL},
/* 2D50 */ { "LETTRE TIFINAGHE YAGN TOUAREG",NULL},
/* 2D51 */ { "LETTRE TIFINAGHE YANG TOUAREG",NULL},
/* 2D52 */ { "LETTRE TIFINAGHE YAP",NULL},
/* 2D53 */ { "LETTRE TIFINAGHE YOU","	= yaw touareg"},
/* 2D54 */ { "LETTRE TIFINAGHE YAR",NULL},
/* 2D55 */ { "LETTRE TIFINAGHE YARR",NULL},
/* 2D56 */ { "LETTRE TIFINAGHE YAGH",NULL},
/* 2D57 */ { "LETTRE TIFINAGHE YAGH TOUAREG",NULL},
/* 2D58 */ { "LETTRE TIFINAGHE YAGH DE L'AÏR","	= yadj de l'Adrar"},
/* 2D59 */ { "LETTRE TIFINAGHE YAS",NULL},
/* 2D5A */ { "LETTRE TIFINAGHE YASS",NULL},
/* 2D5B */ { "LETTRE TIFINAGHE YACH",NULL},
/* 2D5C */ { "LETTRE TIFINAGHE YAT",NULL},
/* 2D5D */ { "LETTRE TIFINAGHE YATH",NULL},
/* 2D5E */ { "LETTRE TIFINAGHE YATCH",NULL},
/* 2D5F */ { "LETTRE TIFINAGHE YATT",NULL},
/* 2D60 */ { "LETTRE TIFINAGHE YAV",NULL},
/* 2D61 */ { "LETTRE TIFINAGHE YAW",NULL},
/* 2D62 */ { "LETTRE TIFINAGHE YAY",NULL},
/* 2D63 */ { "LETTRE TIFINAGHE YAZ",NULL},
/* 2D64 */ { "LETTRE TIFINAGHE YAZ TAWELLEMET","	= yaz harpon"},
/* 2D65 */ { "LETTRE TIFINAGHE YAZZ",NULL},
/* 2D66 */ { "LETTRE TIFINAGHE YÉ",NULL},
/* 2D67 */ { "LETTRE TIFINAGHE YO",NULL},
/* 2D68 */ { NULL,NULL},
/* 2D69 */ { NULL,NULL},
/* 2D6A */ { NULL,NULL},
/* 2D6B */ { NULL,NULL},
/* 2D6C */ { NULL,NULL},
/* 2D6D */ { NULL,NULL},
/* 2D6E */ { NULL,NULL},
/* 2D6F */ { "LETTRE MODIFICATIVE TIFINAGHE DE LABIALISATION","	= tamatart\n"
	"	# <exp> 2D61"},
/* 2D70 */ { "SÉPARATEUR TIFINAGHE","	= tazarast"},
/* 2D71 */ { NULL,NULL},
/* 2D72 */ { NULL,NULL},
/* 2D73 */ { NULL,NULL},
/* 2D74 */ { NULL,NULL},
/* 2D75 */ { NULL,NULL},
/* 2D76 */ { NULL,NULL},
/* 2D77 */ { NULL,NULL},
/* 2D78 */ { NULL,NULL},
/* 2D79 */ { NULL,NULL},
/* 2D7A */ { NULL,NULL},
/* 2D7B */ { NULL,NULL},
/* 2D7C */ { NULL,NULL},
/* 2D7D */ { NULL,NULL},
/* 2D7E */ { NULL,NULL},
/* 2D7F */ { "LIANT DE CONSONNES TIFINAGHE","	* supprime la voyelle inhérente\n"
	"	* sert à indiquer que le caractère qui le précède et qui le suit forme un groupe biconsonnantique\n"
	"	* la forme choisie est arbitraire, invisible"},
/* 2D80 */ { "SYLLABE ÉTHIOPIENNE LOA",NULL},
/* 2D81 */ { "SYLLABE ÉTHIOPIENNE MOA",NULL},
/* 2D82 */ { "SYLLABE ÉTHIOPIENNE ROA",NULL},
/* 2D83 */ { "SYLLABE ÉTHIOPIENNE SOA",NULL},
/* 2D84 */ { "SYLLABE ÉTHIOPIENNE CHOA",NULL},
/* 2D85 */ { "SYLLABE ÉTHIOPIENNE BOA",NULL},
/* 2D86 */ { "SYLLABE ÉTHIOPIENNE TOA",NULL},
/* 2D87 */ { "SYLLABE ÉTHIOPIENNE TCHOA",NULL},
/* 2D88 */ { "SYLLABE ÉTHIOPIENNE NOA",NULL},
/* 2D89 */ { "SYLLABE ÉTHIOPIENNE ÑOA",NULL},
/* 2D8A */ { "SYLLABE ÉTHIOPIENNE OA GLOTTAL",NULL},
/* 2D8B */ { "SYLLABE ÉTHIOPIENNE ZOA",NULL},
/* 2D8C */ { "SYLLABE ÉTHIOPIENNE DOA",NULL},
/* 2D8D */ { "SYLLABE ÉTHIOPIENNE DDOA",NULL},
/* 2D8E */ { "SYLLABE ÉTHIOPIENNE DJOA",NULL},
/* 2D8F */ { "SYLLABE ÉTHIOPIENNE THOA",NULL},
/* 2D90 */ { "SYLLABE ÉTHIOPIENNE TTCHOA",NULL},
/* 2D91 */ { "SYLLABE ÉTHIOPIENNE PHOA",NULL},
/* 2D92 */ { "SYLLABE ÉTHIOPIENNE POA",NULL},
/* 2D93 */ { "SYLLABE ÉTHIOPIENNE GGWÄ",NULL},
/* 2D94 */ { "SYLLABE ÉTHIOPIENNE GGWI",NULL},
/* 2D95 */ { "SYLLABE ÉTHIOPIENNE GGWÉ",NULL},
/* 2D96 */ { "SYLLABE ÉTHIOPIENNE GGWE",NULL},
/* 2D97 */ { NULL,NULL},
/* 2D98 */ { NULL,NULL},
/* 2D99 */ { NULL,NULL},
/* 2D9A */ { NULL,NULL},
/* 2D9B */ { NULL,NULL},
/* 2D9C */ { NULL,NULL},
/* 2D9D */ { NULL,NULL},
/* 2D9E */ { NULL,NULL},
/* 2D9F */ { NULL,NULL},
/* 2DA0 */ { "SYLLABE ÉTHIOPIENNE SSÄ",NULL},
/* 2DA1 */ { "SYLLABE ÉTHIOPIENNE SSOU",NULL},
/* 2DA2 */ { "SYLLABE ÉTHIOPIENNE SSI",NULL},
/* 2DA3 */ { "SYLLABE ÉTHIOPIENNE SSA",NULL},
/* 2DA4 */ { "SYLLABE ÉTHIOPIENNE SSÉ",NULL},
/* 2DA5 */ { "SYLLABE ÉTHIOPIENNE SSE",NULL},
/* 2DA6 */ { "SYLLABE ÉTHIOPIENNE SSO",NULL},
/* 2DA7 */ { NULL,NULL},
/* 2DA8 */ { "SYLLABE ÉTHIOPIENNE TCHTCHÄ",NULL},
/* 2DA9 */ { "SYLLABE ÉTHIOPIENNE TCHTCHOU",NULL},
/* 2DAA */ { "SYLLABE ÉTHIOPIENNE TCHTCHI",NULL},
/* 2DAB */ { "SYLLABE ÉTHIOPIENNE TCHTCHA",NULL},
/* 2DAC */ { "SYLLABE ÉTHIOPIENNE TCHTCHÉ",NULL},
/* 2DAD */ { "SYLLABE ÉTHIOPIENNE TCHTCHE",NULL},
/* 2DAE */ { "SYLLABE ÉTHIOPIENNE TCHTCHO",NULL},
/* 2DAF */ { NULL,NULL},
/* 2DB0 */ { "SYLLABE ÉTHIOPIENNE ZZÄ",NULL},
/* 2DB1 */ { "SYLLABE ÉTHIOPIENNE ZZOU",NULL},
/* 2DB2 */ { "SYLLABE ÉTHIOPIENNE ZZI",NULL},
/* 2DB3 */ { "SYLLABE ÉTHIOPIENNE ZZA",NULL},
/* 2DB4 */ { "SYLLABE ÉTHIOPIENNE ZZÉ",NULL},
/* 2DB5 */ { "SYLLABE ÉTHIOPIENNE ZZE",NULL},
/* 2DB6 */ { "SYLLABE ÉTHIOPIENNE ZZO",NULL},
/* 2DB7 */ { NULL,NULL},
/* 2DB8 */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHÄ",NULL},
/* 2DB9 */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHOU",NULL},
/* 2DBA */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHI",NULL},
/* 2DBB */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHA",NULL},
/* 2DBC */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHÉ",NULL},
/* 2DBD */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHE",NULL},
/* 2DBE */ { "SYLLABE ÉTHIOPIENNE TTCHTTCHO",NULL},
/* 2DBF */ { NULL,NULL},
/* 2DC0 */ { "SYLLABE ÉTHIOPIENNE QYÄ",NULL},
/* 2DC1 */ { "SYLLABE ÉTHIOPIENNE QYOU",NULL},
/* 2DC2 */ { "SYLLABE ÉTHIOPIENNE QYI",NULL},
/* 2DC3 */ { "SYLLABE ÉTHIOPIENNE QYA",NULL},
/* 2DC4 */ { "SYLLABE ÉTHIOPIENNE QYÉ",NULL},
/* 2DC5 */ { "SYLLABE ÉTHIOPIENNE QYE",NULL},
/* 2DC6 */ { "SYLLABE ÉTHIOPIENNE QYO",NULL},
/* 2DC7 */ { NULL,NULL},
/* 2DC8 */ { "SYLLABE ÉTHIOPIENNE KYÄ",NULL},
/* 2DC9 */ { "SYLLABE ÉTHIOPIENNE KYOU",NULL},
/* 2DCA */ { "SYLLABE ÉTHIOPIENNE KYI",NULL},
/* 2DCB */ { "SYLLABE ÉTHIOPIENNE KYA",NULL},
/* 2DCC */ { "SYLLABE ÉTHIOPIENNE KYÉ",NULL},
/* 2DCD */ { "SYLLABE ÉTHIOPIENNE KYE",NULL},
/* 2DCE */ { "SYLLABE ÉTHIOPIENNE KYO",NULL},
/* 2DCF */ { NULL,NULL},
/* 2DD0 */ { "SYLLABE ÉTHIOPIENNE XYÄ","	x (syllabe éthiopienne hhyä - 1E7E0)"},
/* 2DD1 */ { "SYLLABE ÉTHIOPIENNE XYOU","	x (syllabe éthiopienne hhyou - 1E7E1)"},
/* 2DD2 */ { "SYLLABE ÉTHIOPIENNE XYI","	x (syllabe éthiopienne hhyi - 1E7E2)"},
/* 2DD3 */ { "SYLLABE ÉTHIOPIENNE XYA","	x (syllabe éthiopienne hhya - 1E7E3)"},
/* 2DD4 */ { "SYLLABE ÉTHIOPIENNE XYÉ","	x (syllabe éthiopienne hhyé - 1E7E4)"},
/* 2DD5 */ { "SYLLABE ÉTHIOPIENNE XYE","	x (syllabe éthiopienne hhye - 1E7E5)"},
/* 2DD6 */ { "SYLLABE ÉTHIOPIENNE XYO","	x (syllabe éthiopienne hhyo - 1E7E6)"},
/* 2DD7 */ { NULL,NULL},
/* 2DD8 */ { "SYLLABE ÉTHIOPIENNE GYÄ",NULL},
/* 2DD9 */ { "SYLLABE ÉTHIOPIENNE GYOU",NULL},
/* 2DDA */ { "SYLLABE ÉTHIOPIENNE GYI",NULL},
/* 2DDB */ { "SYLLABE ÉTHIOPIENNE GYA",NULL},
/* 2DDC */ { "SYLLABE ÉTHIOPIENNE GYÉ",NULL},
/* 2DDD */ { "SYLLABE ÉTHIOPIENNE GYE",NULL},
/* 2DDE */ { "SYLLABE ÉTHIOPIENNE GYO",NULL},
/* 2DDF */ { NULL,NULL},
/* 2DE0 */ { "DIACRITIQUE LETTRE CYRILLIQUE BÉ",NULL},
/* 2DE1 */ { "DIACRITIQUE LETTRE CYRILLIQUE VÉ",NULL},
/* 2DE2 */ { "DIACRITIQUE LETTRE CYRILLIQUE GUÉ",NULL},
/* 2DE3 */ { "DIACRITIQUE LETTRE CYRILLIQUE DÉ",NULL},
/* 2DE4 */ { "DIACRITIQUE LETTRE CYRILLIQUE JÉ",NULL},
/* 2DE5 */ { "DIACRITIQUE LETTRE CYRILLIQUE ZÉ",NULL},
/* 2DE6 */ { "DIACRITIQUE LETTRE CYRILLIQUE KA",NULL},
/* 2DE7 */ { "DIACRITIQUE LETTRE CYRILLIQUE ELLE",NULL},
/* 2DE8 */ { "DIACRITIQUE LETTRE CYRILLIQUE EMME","	x (diacritique lettre latine petite capitale m - 1DDF)"},
/* 2DE9 */ { "DIACRITIQUE LETTRE CYRILLIQUE ENNE",NULL},
/* 2DEA */ { "DIACRITIQUE LETTRE CYRILLIQUE O","	x (diacritique lettre minuscule latine o - 0366)"},
/* 2DEB */ { "DIACRITIQUE LETTRE CYRILLIQUE PÉ",NULL},
/* 2DEC */ { "DIACRITIQUE LETTRE CYRILLIQUE ERRE",NULL},
/* 2DED */ { "DIACRITIQUE LETTRE CYRILLIQUE ESSE","	x (diacritique lettre minuscule latine c - 0368)"},
/* 2DEE */ { "DIACRITIQUE LETTRE CYRILLIQUE TÉ",NULL},
/* 2DEF */ { "DIACRITIQUE LETTRE CYRILLIQUE KHA","	x (diacritique lettre minuscule latine x - 036F)"},
/* 2DF0 */ { "DIACRITIQUE LETTRE CYRILLIQUE TSÉ",NULL},
/* 2DF1 */ { "DIACRITIQUE LETTRE CYRILLIQUE TCHÉ",NULL},
/* 2DF2 */ { "DIACRITIQUE LETTRE CYRILLIQUE CHA",NULL},
/* 2DF3 */ { "DIACRITIQUE LETTRE CYRILLIQUE CHTCHA",NULL},
/* 2DF4 */ { "DIACRITIQUE LETTRE CYRILLIQUE FITA",NULL},
/* 2DF5 */ { "DIACRITIQUE LETTRE CYRILLIQUE ESTÉ","	* la représentation recommandée est la séquence 2DED 2DEE"},
/* 2DF6 */ { "DIACRITIQUE LETTRE CYRILLIQUE A","	x (diacritique lettre minuscule latine a - 0363)"},
/* 2DF7 */ { "DIACRITIQUE LETTRE CYRILLIQUE IÉ","	x (diacritique lettre minuscule latine e - 0364)"},
/* 2DF8 */ { "DIACRITIQUE LETTRE CYRILLIQUE DIERV",NULL},
/* 2DF9 */ { "DIACRITIQUE LETTRE CYRILLIQUE MONOGRAMME OUK",NULL},
/* 2DFA */ { "DIACRITIQUE LETTRE CYRILLIQUE IAT",NULL},
/* 2DFB */ { "DIACRITIQUE LETTRE CYRILLIQUE IOU",NULL},
/* 2DFC */ { "DIACRITIQUE LETTRE CYRILLIQUE A YODISÉ",NULL},
/* 2DFD */ { "DIACRITIQUE LETTRE CYRILLIQUE PETIT IOUSSE",NULL},
/* 2DFE */ { "DIACRITIQUE LETTRE CYRILLIQUE GRAND IOUSSE",NULL},
/* 2DFF */ { "DIACRITIQUE LETTRE CYRILLIQUE GRAND IOUSSE YODISÉ",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_2E[] = {
/* 2E00 */ { "ANGLET DE SUBSTITUTION","	x (coin nord-ouest - 231C)"},
/* 2E01 */ { "ANGLET DE SUBSTITUTION POINTÉ",NULL},
/* 2E02 */ { "CROCHET DE SUBSTITUTION GAUCHE",NULL},
/* 2E03 */ { "CROCHET DE SUBSTITUTION DROIT",NULL},
/* 2E04 */ { "CROCHET DE SUBSTITUTION GAUCHE POINTÉ",NULL},
/* 2E05 */ { "CROCHET DE SUBSTITUTION DROIT POINTÉ",NULL},
/* 2E06 */ { "SIGNE D'INTERPOLATION ÉLEVÉ","	x (taquet vers le bas - 22A4)"},
/* 2E07 */ { "SIGNE D'INTERPOLATION ÉLEVÉ POINTÉ",NULL},
/* 2E08 */ { "SIGNE DE TRANSPOSITION POINTÉ",NULL},
/* 2E09 */ { "ESSE DE TRANSPOSITION GAUCHE",NULL},
/* 2E0A */ { "ESSE DE TRANSPOSITION DROITE",NULL},
/* 2E0B */ { "CARRÉ ÉLEVÉ","	* s'utilise comme parenthèse d'omission ouvrante surélevée"},
/* 2E0C */ { "OBLIQUE D'OMISSION GAUCHE ÉLEVÉE","	* s'utilise comme parenthèse d'omission ouvrante ou fermante surélevée"},
/* 2E0D */ { "OBLIQUE D'OMISSION DROITE ÉLEVÉE","	* s'utilise comme parenthèse d'omission ouvrante surélevée"},
/* 2E0E */ { "CORONIS ÉDITORIALE","	* connaît de nombreuses variantes de glyphes\n"
	"	* indique la fin d'un poème ou d'une section\n"
	"	x (coronis grecque - 1FBD)"},
/* 2E0F */ { "PARAGRAPHOS","	* changement de locuteur ou de strophe"},
/* 2E10 */ { "PARAGRAPHOS FOURCHU",NULL},
/* 2E11 */ { "PARAGRAPHOS FOURCHU RÉFLÉCHI",NULL},
/* 2E12 */ { "HYPODIASTOLE",NULL},
/* 2E13 */ { "OBÈLE POINTÉ","	* les variantes de glyphes peuvent ressembler à 00F7 ou à 2238\n"
	"	x (signe moins commercial - 2052)"},
/* 2E14 */ { "ANCORA VERS LE HAUT","	* le nom formel de ce caractère en anglais est erroné"},
/* 2E15 */ { "ANCORA VERS LE BAS","	* le nom formel de ce caractère en anglais est erroné"},
/* 2E16 */ { "CHEVRON VERS LA DROITE POINTÉ","	= diplê périéstigménê"},
/* 2E17 */ { "TRAIT D'UNION DOUBLE OBLIQUE","	* utilisé dans l'ancienne linguistique du Proche-Orient\n"
	"	* le trait d'union dans les textes gothiques (Fraktur) se code à l'aide de 002D ou de 2010, mais les polices gothiques (Fraktur) afficheront un glyphe similaire à 2E17\n"
	"	x (trait d'union-signe moins - 002D)\n"
	"	x (signe égal - 003D)\n"
	"	x (trait d'union - 2010)\n"
	"	x (trait d'union double - 2E40)\n"
	"	x (trait d'union oblique - 2E5D)"},
/* 2E18 */ { "POINT EXCLARROGATIF CULBUTÉ","	x (point exclarrogatif - 203D)"},
/* 2E19 */ { "PALME","	* signe servant de séparateur"},
/* 2E1A */ { "TRAIT D'UNION À TRÉMA","	* indique l'inflexion de la voyelle thématique d'une forme plurielle"},
/* 2E1B */ { "TILDE À CERCLE SUSCRIT","	* indique le changement de casse pour une forme dérivée"},
/* 2E1C */ { "OBLIQUE DE PARAPHRASE OUVRANTE",NULL},
/* 2E1D */ { "OBLIQUE DE PARAPHRASE FERMANTE","	* utilisée en n'ko"},
/* 2E1E */ { "TILDE À POINT SUSCRIT","	* indique que le mot dérivé s'écrit avec une majuscule"},
/* 2E1F */ { "TILDE À POINT SOUSCRIT","	* indique que le mot dérivé s'écrit avec une minuscule"},
/* 2E20 */ { "ÉCHASSE GAUCHE","	x (crochet gauche avec pique - 2045)"},
/* 2E21 */ { "ÉCHASSE DROITE",NULL},
/* 2E22 */ { "ANGLET SUPÉRIEUR GAUCHE","	x (plafond à gauche - 2308)\n"
	"	x (coin nord-ouest - 231C)\n"
	"	x (anglet gauche - 300C)"},
/* 2E23 */ { "ANGLET SUPÉRIEUR DROIT",NULL},
/* 2E24 */ { "ANGLET INFÉRIEUR GAUCHE",NULL},
/* 2E25 */ { "ANGLET INFÉRIEUR DROIT",NULL},
/* 2E26 */ { "CRAMPILLON COUCHÉ GAUCHE","	x (sous-ensemble de - 2282)"},
/* 2E27 */ { "CRAMPILLON COUCHÉ DROIT","	x (sur-ensemble de - 2283)"},
/* 2E28 */ { "DOUBLE PARENTHÈSE GAUCHE","	x (parenthèse blanche gauche - 2985)\n"
	"	x (parenthèse blanche gauche pleine chasse - FF5F)"},
/* 2E29 */ { "DOUBLE PARENTHÈSE DROITE",NULL},
/* 2E2A */ { "PONCTUATION DEUX POINTS SUR UN POINT",NULL},
/* 2E2B */ { "PONCTUATION UN POINT SUR DEUX POINTS",NULL},
/* 2E2C */ { "PONCTUATION QUATRE POINTS EN CARRÉ",NULL},
/* 2E2D */ { "SIGNE À CINQ POINTS",NULL},
/* 2E2E */ { "POINT D'INTERROGATION RÉFLÉCHI","	= punctus percontativus\n"
	"	x (point d'interrogation - 003F)\n"
	"	x (point d'interrogation renversé - 00BF)\n"
	"	x (point d'interrogation arabe - 061F)"},
/* 2E2F */ { "TILDE VERTICAL","	* utilisé pour le yérik cyrillique\n"
	"	x (diacritique tilde vertical - 033E)\n"
	"	x (payérok cyrillique - A67F)"},
/* 2E30 */ { "POINT ÉVIDÉ","	* utilisé en avestique\n"
	"	x (opérateur rond - 2218)\n"
	"	x (puce blanche - 25E6)"},
/* 2E31 */ { "POINT MÉDIAN SÉPARATEUR DE MOTS","	* utilisé en avestique, en samaritain, etc.\n"
	"	x (point médian - 00B7)"},
/* 2E32 */ { "VIRGULE CULBUTÉE","	* indique la nasalisation\n"
	"	x (virgule arabe - 060C)"},
/* 2E33 */ { "POINT ÉLEVÉ","	* position du glyphe intermédiaire entre 002E et 00B7\n"
	"	x (point - 002E)\n"
	"	x (point médian - 00B7)"},
/* 2E34 */ { "VIRGULE ÉLEVÉE","	x (virgule - 002C)"},
/* 2E35 */ { "POINT-VIRGULE CULBUTÉ","	* indique un mouvement de fermeture soudain de la glotte\n"
	"	x (point-virgule arabe - 061B)"},
/* 2E36 */ { "OBÈLE GARDE GAUCHE","	* indique une prononciation rétractée"},
/* 2E37 */ { "OBÈLE GARDE DROITE","	* indique une prononciation avancée"},
/* 2E38 */ { "OBÈLE CULBUTÉ","	* indique une prononciation rétroflexe\n"
	"	x (obèle - 2020)"},
/* 2E39 */ { "MOITIÉ SUPÉRIEURE DE PARAGRAPHE","	* indique une prononciation réalisée d'un seul côté de la bouche\n"
	"	x (paragraphe - 00A7)"},
/* 2E3A */ { "TIRET DOUBLE CADRATIN","	* peut être utilisé en chinois pour un changement brusque de pensée, l'insertion d'un nouveau contenu ou la poursuite d'un ton ou d'un son\n"
	"	x (tiret cadratin - 2014)"},
/* 2E3B */ { "TIRET TRIPLE CADRATIN",NULL},
/* 2E3C */ { "POINT STÉNOGRAPHIQUE","	* utilisé en sténographie\n"
	"	x (point - 002E)\n"
	"	x (point syllabe canadienne - 166E)"},
/* 2E3D */ { "SIX-POINTS VERTICAL","	x (quatre-points vertical - 205E)\n"
	"	x (clôture pointillée - 2999)"},
/* 2E3E */ { "LIGNE VERTICALE ONDULÉE","	x (ligne ondulée - 2307)\n"
	"	x (ligne verticale en zigzag - 299A)"},
/* 2E3F */ { "CAPITULE","	* ancêtre du pied-de-mouche\n"
	"	x (pied-de-mouche - 00B6)"},
/* 2E40 */ { "TRAIT D'UNION DOUBLE","	x (signe égal - 003D)\n"
	"	x (trait d'union - 2010)\n"
	"	x (trait d'union double oblique - 2E17)\n"
	"	x (double trait katakana-hiragana - 30A0)\n"
	"	x (lettre modificative signe égal court - A78A)"},
/* 2E41 */ { "VIRGULE RÉFLÉCHIE","	* écriture runique hongroise\n"
	"	* utilisation occasionnelle en sindhi, lorsqu'il est écrit au moyen de l'alphabet arabe\n"
	"	x (virgule - 002C)\n"
	"	x (virgule arabe - 060C)"},
/* 2E42 */ { "GUILLEMET-VIRGULE DOUBLE INFÉRIEUR RÉFLÉCHI","	x (guillemet-virgule double inférieur - 201E)"},
/* 2E43 */ { "TIRET HAMPÉ À GAUCHE","	* équivalent d'un paragraphos dans certains textes slaves\n"
	"	x (paragraphos - 2E0F)"},
/* 2E44 */ { "POINT DE SUSPENSION DOUBLE","	* indique l'omission de lettres dans un mot sur certains sceaux et pièces grecs byzantins\n"
	"	x (signe numéral grec - 0374)"},
/* 2E45 */ { "KAVYKA BAS RENVERSÉ",NULL},
/* 2E46 */ { "KAVYKA BAS RENVERSÉ KAVYKA PAR-DESSUS","	x (union sur intersection - 2A46)\n"
	"	x (brève modificative et brève renversée - AB5B)"},
/* 2E47 */ { "KAVYKA BAS","	x (kavyka cyrillique - A67E)"},
/* 2E48 */ { "KAVYKA BAS AVEC POINT",NULL},
/* 2E49 */ { "DEUX VIRGULES SUPERPOSÉES",NULL},
/* 2E4A */ { "BARRE OBLIQUE POINTÉE","	= virgula suspensiva\n"
	"	* marque une disjonction plus importante que celle notée par une simple barre oblique, mais moins importante que celle notée par le punctus elevatus"},
/* 2E4B */ { "TRIPLE OBÈLE","	x (obèle - 2020)\n"
	"	x (double obèle - 2021)"},
/* 2E4C */ { "VIRGULE MÉDIÉVALE","	* marque une pause intermédiaire mineure ou une disjonction de sens"},
/* 2E4D */ { "SIGNE PARAGRAPHUS","	* indique le commencement d'un paragraphe, d'une section, d'une strophe ou d'une proposition\n"
	"	x (pied-de-mouche - 00B6)\n"
	"	x (pied-de-mouche réfléchi - 204B)\n"
	"	x (paragraphos - 2E0F)\n"
	"	x (capitule - 2E3F)"},
/* 2E4E */ { "SIGNE PUNCTUS ELEVATUS","		* Ce signe indique une pause intermédiaire majeure, correspondant à une unité de sens complète même si la phrase est inachevée ; ceci est similaire, à certains égards, à l'utilisation moderne d'un point-virgule."},
/* 2E4F */ { "DIVISEUR DE VERS CORNIQUE",NULL},
/* 2E50 */ { "CROIX PATTÉE À BRAS HORIZONTAL DROIT","	x (croix de malte - 2720)\n"
	"	x (lettre majuscule latine moitié de h - 2C75)"},
/* 2E51 */ { "CROIX PATTÉE À BRAS HORIZONTAL GAUCHE","	x (lettre majuscule latine moitié de h réfléchie - A7F5)"},
/* 2E52 */ { "NOTE TIRONIENNE MAJUSCULE ET","	x (note tironienne et - 204A)"},
/* 2E53 */ { "POINT D'EXCLAMATION MÉDIÉVAL",NULL},
/* 2E54 */ { "POINT D'INTERROGATION MÉDIÉVAL",NULL},
/* 2E55 */ { "CROCHET GAUCHE AVEC BARRE","	* ellipse optionnelle\n"
	"	x (crochet gauche avec pique - 2045)"},
/* 2E56 */ { "CROCHET DROIT AVEC BARRE",NULL},
/* 2E57 */ { "CROCHET GAUCHE AVEC DOUBLE BARRE","	* ellipse obligatoire"},
/* 2E58 */ { "CROCHET DROIT AVEC DOUBLE BARRE",NULL},
/* 2E59 */ { "MOITIÉ SUPÉRIEURE DE PARENTHÈSE GAUCHE",NULL},
/* 2E5A */ { "MOITIÉ SUPÉRIEURE DE PARENTHÈSE DROITE",NULL},
/* 2E5B */ { "MOITIÉ INFÉRIEURE DE PARENTHÈSE GAUCHE",NULL},
/* 2E5C */ { "MOITIÉ INFÉRIEURE DE PARENTHÈSE DROITE",NULL},
/* 2E5D */ { "TRAIT D'UNION OBLIQUE","	x (trait d'union - 2010)\n"
	"	x (trait d'union double oblique - 2E17)"},
/* 2E5E */ { NULL,NULL},
/* 2E5F */ { NULL,NULL},
/* 2E60 */ { NULL,NULL},
/* 2E61 */ { NULL,NULL},
/* 2E62 */ { NULL,NULL},
/* 2E63 */ { NULL,NULL},
/* 2E64 */ { NULL,NULL},
/* 2E65 */ { NULL,NULL},
/* 2E66 */ { NULL,NULL},
/* 2E67 */ { NULL,NULL},
/* 2E68 */ { NULL,NULL},
/* 2E69 */ { NULL,NULL},
/* 2E6A */ { NULL,NULL},
/* 2E6B */ { NULL,NULL},
/* 2E6C */ { NULL,NULL},
/* 2E6D */ { NULL,NULL},
/* 2E6E */ { NULL,NULL},
/* 2E6F */ { NULL,NULL},
/* 2E70 */ { NULL,NULL},
/* 2E71 */ { NULL,NULL},
/* 2E72 */ { NULL,NULL},
/* 2E73 */ { NULL,NULL},
/* 2E74 */ { NULL,NULL},
/* 2E75 */ { NULL,NULL},
/* 2E76 */ { NULL,NULL},
/* 2E77 */ { NULL,NULL},
/* 2E78 */ { NULL,NULL},
/* 2E79 */ { NULL,NULL},
/* 2E7A */ { NULL,NULL},
/* 2E7B */ { NULL,NULL},
/* 2E7C */ { NULL,NULL},
/* 2E7D */ { NULL,NULL},
/* 2E7E */ { NULL,NULL},
/* 2E7F */ { NULL,NULL},
/* 2E80 */ { "CLÉ CJC BIS","	* variante de la clé 3 du Kangxi"},
/* 2E81 */ { "CLÉ CJC FALAISE","	* variante de la clé 27 du Kangxi\n"
	"	x 5382\n"
	"	x 20086"},
/* 2E82 */ { "CLÉ CJC SECOND UN","	* variante de la clé 5 du Kangxi\n"
	"	x 4E5B"},
/* 2E83 */ { "CLÉ CJC SECOND DEUX","	* variante de la clé 5 du Kangxi\n"
	"	x 4E5A"},
/* 2E84 */ { "CLÉ CJC SECOND TROIS","	* variante de la clé 5 du Kangxi\n"
	"	x 4E59"},
/* 2E85 */ { "CLÉ CJC HOMME","	* variante de la clé 9 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 4EBB"},
/* 2E86 */ { "CLÉ CJC PLACE","	* variante de la clé 13 du Kangxi\n"
	"	x 5182"},
/* 2E87 */ { "CLÉ CJC TABLE BASSE","	* variante de la clé 16 du Kangxi\n"
	"	x 51E0\n"
	"	x 20628"},
/* 2E88 */ { "CLÉ CJC COUTEAU UN","	* variante de la clé 18 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 5200\n"
	"	x 2008A"},
/* 2E89 */ { "CLÉ CJC COUTEAU DEUX","	* variante de la clé 18 du Kangxi\n"
	"	* forme utilisée à droite\n"
	"	x 5202"},
/* 2E8A */ { "CLÉ CJC DIVINATION","	* variante de la clé 25 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 535C"},
/* 2E8B */ { "CLÉ CJC SCEAU","	* variante de la clé 26 du Kangxi\n"
	"	* forme utilisée en dessous\n"
	"	x 353E"},
/* 2E8C */ { "CLÉ CJC PETIT UN","	* variante de la clé 42 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 5C0F"},
/* 2E8D */ { "CLÉ CJC PETIT DEUX","	* variante de la clé 42 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 5C0F\n"
	"	x 2D544"},
/* 2E8E */ { "CLÉ CJC BOITEUX UN","	* variante de la clé 43 du Kangxi\n"
	"	x 5C22\n"
	"	x 5140"},
/* 2E8F */ { "CLÉ CJC BOITEUX DEUX","	* variante de la clé 43 du Kangxi\n"
	"	x 5C23"},
/* 2E90 */ { "CLÉ CJC BOITEUX TROIS","	* variante de la clé 43 du Kangxi\n"
	"	x 5C22"},
/* 2E91 */ { "CLÉ CJC BOITEUX QUATRE","	* variante de la clé 43 du Kangxi\n"
	"	x 5C23\n"
	"	x 21BC2"},
/* 2E92 */ { "CLÉ CJC SIGNE DU SERPENT","	* variante de la clé 49 du Kangxi\n"
	"	x 5DF3"},
/* 2E93 */ { "CLÉ CJC FIL","	* variante de la clé 52 du Kangxi\n"
	"	x 5E7A"},
/* 2E94 */ { "CLÉ CJC GROIN UN","	* variante de la clé 58 du Kangxi\n"
	"	x 5F51"},
/* 2E95 */ { "CLÉ CJC GROIN DEUX","	* variante de la clé 58 du Kangxi\n"
	"	* en réalité, une variante du radical pour la main, en dépit de sa ressemblance avec le radical pour le groin\n"
	"	x 5F50\n"
	"	x 2B739"},
/* 2E96 */ { "CLÉ CJC CŒUR UN","	* variante de la clé 61 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 5FC4"},
/* 2E97 */ { "CLÉ CJC CŒUR DEUX","	* variante de la clé 61 du Kangxi\n"
	"	* forme utilisée en dessous\n"
	"	x 38FA\n"
	"	x 5FC3"},
/* 2E98 */ { "CLÉ CJC MAIN","	* variante de la clé 64 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 624C"},
/* 2E99 */ { "CLÉ CJC TAPER","	* variante de la clé 66 du Kangxi\n"
	"	* forme utilisée à droite\n"
	"	x 6535"},
/* 2E9A */ { NULL,"	x (clé chinoise sans - 2F46)"},
/* 2E9B */ { "CLÉ CJC ÉTRANGLER","	* variante de la clé 71 du Kangxi\n"
	"	x 65E1"},
/* 2E9C */ { "CLÉ CJC SOLEIL","	* variante de la clé 72 du Kangxi\n"
	"	* en réalité, une forme de la clé pour « chapeau », malgré sa ressemblance avec la clé pour « soleil »\n"
	"	x 5183\n"
	"	x 65E5"},
/* 2E9D */ { "CLÉ CJC LUNE","	* variante de la clé 74 du Kangxi\n"
	"	x 6708"},
/* 2E9E */ { "CLÉ CJC MAUVAIS","	* variante de la clé 78 du Kangxi\n"
	"	x 6B7A"},
/* 2E9F */ { "CLÉ CJC MÈRE","	* variante de la clé 80 du Kangxi\n"
	"	# 6BCD"},
/* 2EA0 */ { "CLÉ CJC CIVIL","	* variante de la clé 83 du Kangxi\n"
	"	x 6C11"},
/* 2EA1 */ { "CLÉ CJC EAU UN","	* variante de la clé 85 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 6C35"},
/* 2EA2 */ { "CLÉ CJC EAU DEUX","	* variante de la clé 85 du Kangxi\n"
	"	* forme utilisée (rarement) en dessous\n"
	"	x 6C3A"},
/* 2EA3 */ { "CLÉ CJC FEU","	* variante de la clé 86 du Kangxi\n"
	"	* forme utilisée en dessous\n"
	"	x 706C"},
/* 2EA4 */ { "CLÉ CJC PATTE UN","	* variante de la clé 87 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 722B"},
/* 2EA5 */ { "CLÉ CJC PATTE DEUX","	* variante de la clé 87 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 722B"},
/* 2EA6 */ { "CLÉ CJC MOITIÉ DE TRONC FORME SIMPLIFIÉE","	* variante simplifiée de la clé 90 du Kangxi\n"
	"	x 4E2C"},
/* 2EA7 */ { "CLÉ CJC BŒUF","	* variante de la clé 93 du Kangxi\n"
	"	x 725B\n"
	"	x 20092"},
/* 2EA8 */ { "CLÉ CJC CHIEN","	* variante de la clé 94 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 72AD"},
/* 2EA9 */ { "CLÉ CJC JADE","	* variante de la clé 96 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 738B\n"
	"	x 248E9"},
/* 2EAA */ { "CLÉ CJC PIÈCE D'ÉTOFFE","	= clé CJC rouleau de tissu\n"
	"	* variante de la clé 103 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 758B\n"
	"	x 24D14"},
/* 2EAB */ { "CLÉ CJC ŒIL","	* variante de la clé 109 du Kangxi\n"
	"	* variante de la clé 122 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x (clé cjc filet deux - 2EB2)\n"
	"	x 76EE\n"
	"	x 7F52"},
/* 2EAC */ { "CLÉ CJC ESPRIT UN","	* variante de la clé 113 du Kangxi\n"
	"	x 793A"},
/* 2EAD */ { "CLÉ CJC ESPRIT DEUX","	* variante de la clé 113 du Kangxi\n"
	"	x 793B"},
/* 2EAE */ { "CLÉ CJC BAMBOU","	* variante de la clé 118 du Kangxi\n"
	"	x 7AF9\n"
	"	x 25AD7"},
/* 2EAF */ { "CLÉ CJC SOIE","	* variante de la clé 120 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 7CF9"},
/* 2EB0 */ { "CLÉ CJC SOIE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 120 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 7E9F"},
/* 2EB1 */ { "CLÉ CJC FILET UN","	* variante de la clé 122 du Kangxi\n"
	"	x 7F53"},
/* 2EB2 */ { "CLÉ CJC FILET DEUX","	* variante de la clé 109 du Kangxi\n"
	"	* variante de la clé 122 du Kangxi\n"
	"	x (clé cjc œil - 2EAB)\n"
	"	x 7F52\n"
	"	x 26270"},
/* 2EB3 */ { "CLÉ CJC FILET TROIS","	* variante de la clé 122 du Kangxi\n"
	"	x 34C1\n"
	"	x 7F51"},
/* 2EB4 */ { "CLÉ CJC FILET QUATRE","	* variante de la clé 122 du Kangxi\n"
	"	x 34C1\n"
	"	x 7F51"},
/* 2EB5 */ { "CLÉ CJC MAILLE","	* variante de la clé 122 du Kangxi\n"
	"	x 2626B"},
/* 2EB6 */ { "CLÉ CJC MOUTON","	* variante de la clé 123 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 7F8A"},
/* 2EB7 */ { "CLÉ CJC BÉLIER","	* variante de la clé 123 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 7F8A\n"
	"	x 2634C"},
/* 2EB8 */ { "CLÉ CJC BREBIS","	* variante de la clé 123 du Kangxi\n"
	"	x 7F8B\n"
	"	x 2634B"},
/* 2EB9 */ { "CLÉ CJC VIEUX","	* variante de la clé 125 du Kangxi\n"
	"	x 8002"},
/* 2EBA */ { "CLÉ CJC PINCEAU UN","	* variante de la clé 129 du Kangxi\n"
	"	x 8080"},
/* 2EBB */ { "CLÉ CJC PINCEAU DEUX","	* variante de la clé 129 du Kangxi\n"
	"	x 807F"},
/* 2EBC */ { "CLÉ CJC VIANDE","	* variante de la clé 130 du Kangxi\n"
	"	x 8089"},
/* 2EBD */ { "CLÉ CJC MORTIER","	* variante de la clé 134 du Kangxi\n"
	"	x 81FC\n"
	"	x 26951"},
/* 2EBE */ { "CLÉ CJC HERBE UN","	* variante simplifiée de la clé 140 du Kangxi\n"
	"	x 8279"},
/* 2EBF */ { "CLÉ CJC HERBE DEUX","	* variante de la clé 140 du Kangxi\n"
	"	x 8279"},
/* 2EC0 */ { "CLÉ CJC HERBE TROIS","	* variante de la clé 140 du Kangxi\n"
	"	x 8279"},
/* 2EC1 */ { "CLÉ CJC TIGRE","	* variante de la clé 141 du Kangxi\n"
	"	x 864E"},
/* 2EC2 */ { "CLÉ CJC HABITS","	* variante de la clé 145 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 8864"},
/* 2EC3 */ { "CLÉ CJC OUEST UN","	* variante de la clé 146 du Kangxi\n"
	"	* forme utilisée au-dessus\n"
	"	x 8980"},
/* 2EC4 */ { "CLÉ CJC OUEST DEUX","	* variante de la clé 146 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 897F"},
/* 2EC5 */ { "CLÉ CJC VOIR FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 147 du Kangxi\n"
	"	x 89C1"},
/* 2EC6 */ { "CLÉ CJC CORNE FORME SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 148 du Kangxi\n"
	"	x 89D2"},
/* 2EC7 */ { "CLÉ CJC CORNE","	* variante de la clé 148 du Kangxi\n"
	"	x 278B2"},
/* 2EC8 */ { "CLÉ CJC PAROLE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 149 du Kangxi\n"
	"	x 8BA0"},
/* 2EC9 */ { "CLÉ CJC COQUILLAGE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 154 du Kangxi\n"
	"	x 8D1D"},
/* 2ECA */ { "CLÉ CJC PIED","	* variante de la clé 157 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 8DB3\n"
	"	x 27FB7"},
/* 2ECB */ { "CLÉ CJC VÉHICULE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 159 du Kangxi\n"
	"	x 8F66"},
/* 2ECC */ { "CLÉ CJC MARCHE À PIED FORME SIMPLIFIÉE","	* variante simplifiée de la clé 162 du Kangxi\n"
	"	x 8FB6"},
/* 2ECD */ { "CLÉ CJC MARCHE À PIED UN","	* variante de la clé 162 du Kangxi\n"
	"	x 8FB6"},
/* 2ECE */ { "CLÉ CJC MARCHE À PIED DEUX","	* variante de la clé 162 du Kangxi\n"
	"	x 8FB6"},
/* 2ECF */ { "CLÉ CJC VILLE","	* variante de la clé 163 du Kangxi\n"
	"	* forme utilisée à droite\n"
	"	x 9091"},
/* 2ED0 */ { "CLÉ CJC OR FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 167 du Kangxi\n"
	"	x 9485"},
/* 2ED1 */ { "CLÉ CJC LONG UN","	* variante de la clé 168 du Kangxi\n"
	"	x 9577"},
/* 2ED2 */ { "CLÉ CJC LONG DEUX","	* variante de la clé 168 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 9578"},
/* 2ED3 */ { "CLÉ CJC LONG FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 168 du Kangxi\n"
	"	x 957F"},
/* 2ED4 */ { "CLÉ CJC PORTAIL FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 169 du Kangxi\n"
	"	x 95E8"},
/* 2ED5 */ { "CLÉ CJC TERTRE UN","	* variante de la clé 170 du Kangxi\n"
	"	x 961C\n"
	"	x 28E0F"},
/* 2ED6 */ { "CLÉ CJC TERTRE DEUX","	* variante de la clé 170 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 961D"},
/* 2ED7 */ { "CLÉ CJC PLUIE","	* variante de la clé 173 du Kangxi\n"
	"	x 96E8"},
/* 2ED8 */ { "CLÉ CJC BLEU","	* variante de la clé 174 du Kangxi\n"
	"	x 9752"},
/* 2ED9 */ { "CLÉ CJC CUIR TANNÉ FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 178 du Kangxi\n"
	"	x 97E6"},
/* 2EDA */ { "CLÉ CJC FEUILLE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 181 du Kangxi\n"
	"	x 9875"},
/* 2EDB */ { "CLÉ CJC VENT FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 182 du Kangxi\n"
	"	x 98CE"},
/* 2EDC */ { "CLÉ CJC S'ENVOLER FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 183 du Kangxi\n"
	"	x 98DE"},
/* 2EDD */ { "CLÉ CJC MANGER UN","	* variante de la clé 184 du Kangxi\n"
	"	* forme utilisée en dessous\n"
	"	x 98DF"},
/* 2EDE */ { "CLÉ CJC MANGER DEUX","	* variante de la clé 184 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 2967F"},
/* 2EDF */ { "CLÉ CJC MANGER TROIS","	* variante de la clé 184 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 98E0"},
/* 2EE0 */ { "CLÉ CJC MANGER FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 184 du Kangxi\n"
	"	* forme utilisée à gauche\n"
	"	x 9963"},
/* 2EE1 */ { "CLÉ CJC TÊTE","	* variante de la clé 185 du Kangxi\n"
	"	x 29810"},
/* 2EE2 */ { "CLÉ CJC CHEVAL FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 187 du Kangxi\n"
	"	x 9A6C"},
/* 2EE3 */ { "CLÉ CJC OS","	* variante chinoise simplifiée de la clé 188 du Kangxi\n"
	"	x 9AA8"},
/* 2EE4 */ { "CLÉ CJC DÉMON","	* variante de la clé 194 du Kangxi\n"
	"	x 9B3C"},
/* 2EE5 */ { "CLÉ CJC POISSON FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 195 du Kangxi\n"
	"	x 9C7C"},
/* 2EE6 */ { "CLÉ CJC OISEAU FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 196 du Kangxi\n"
	"	x 9E1F"},
/* 2EE7 */ { "CLÉ CJC SEL FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 197 du Kangxi\n"
	"	x 5364"},
/* 2EE8 */ { "CLÉ CJC BLÉ FORME SIMPLIFIÉE","	* variante simplifiée de la clé 199 du Kangxi\n"
	"	x 9EA6"},
/* 2EE9 */ { "CLÉ CJC JAUNE FORME SIMPLIFIÉE","	* variante simplifiée de la clé 201 du Kangxi\n"
	"	x 9EC4"},
/* 2EEA */ { "CLÉ CJC GRENOUILLE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 205 du Kangxi\n"
	"	x 9EFE"},
/* 2EEB */ { "CLÉ CJC RÉGULIER FORME JAPONAISE SIMPLIFIÉE","	* variante japonaise simplifiée de la clé 210 du Kangxi\n"
	"	x 6589"},
/* 2EEC */ { "CLÉ CJC RÉGULIER FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 210 du Kangxi\n"
	"	x 9F50"},
/* 2EED */ { "CLÉ CJC DENT FORME JAPONAISE SIMPLIFIÉE","	* variante japonaise simplifiée de la clé 211 du Kangxi\n"
	"	x 6B6F"},
/* 2EEE */ { "CLÉ CJC DENT FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 211 du Kangxi\n"
	"	x 9F7F"},
/* 2EEF */ { "CLÉ CJC DRAGON FORME JAPONAISE SIMPLIFIÉE","	* variante japonaise simplifiée de la clé 212 du Kangxi\n"
	"	x 7ADC\n"
	"	x 9F8D"},
/* 2EF0 */ { "CLÉ CJC DRAGON FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 212 du Kangxi\n"
	"	x 9F99"},
/* 2EF1 */ { "CLÉ CJC TORTUE","	* variante de la clé 213 du Kangxi\n"
	"	x 9F9C"},
/* 2EF2 */ { "CLÉ CJC TORTUE FORME JAPONAISE SIMPLIFIÉE","	* variante japonaise simplifiée de la clé 213 du Kangxi\n"
	"	x 4E80"},
/* 2EF3 */ { "CLÉ CJC TORTUE FORME CHINOISE SIMPLIFIÉE","	* variante chinoise simplifiée de la clé 213 du Kangxi\n"
	"	# 9F9F"},
/* 2EF4 */ { NULL,NULL},
/* 2EF5 */ { NULL,NULL},
/* 2EF6 */ { NULL,NULL},
/* 2EF7 */ { NULL,NULL},
/* 2EF8 */ { NULL,NULL},
/* 2EF9 */ { NULL,NULL},
/* 2EFA */ { NULL,NULL},
/* 2EFB */ { NULL,NULL},
/* 2EFC */ { NULL,NULL},
/* 2EFD */ { NULL,NULL},
/* 2EFE */ { NULL,NULL},
/* 2EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_2F[] = {
/* 2F00 */ { "CLÉ CHINOISE UN","	* clé 1 du Kangxi\n"
	"	# 4E00"},
/* 2F01 */ { "CLÉ CHINOISE TRAIT VERTICAL","	* clé 2 du Kangxi\n"
	"	# 4E28"},
/* 2F02 */ { "CLÉ CHINOISE POINT","	* clé 3 du Kangxi\n"
	"	# 4E36"},
/* 2F03 */ { "CLÉ CHINOISE TRAIT OBLIQUE","	* clé 4 du Kangxi\n"
	"	# 4E3F"},
/* 2F04 */ { "CLÉ CHINOISE SECOND","	* clé 5 du Kangxi\n"
	"	# 4E59"},
/* 2F05 */ { "CLÉ CHINOISE CROCHET","	* clé 6 du Kangxi\n"
	"	# 4E85"},
/* 2F06 */ { "CLÉ CHINOISE DEUX","	* clé 7 du Kangxi\n"
	"	# 4E8C"},
/* 2F07 */ { "CLÉ CHINOISE COUVERCLE","	* clé 8 du Kangxi\n"
	"	# 4EA0"},
/* 2F08 */ { "CLÉ CHINOISE HOMME","	* clé 9 du Kangxi\n"
	"	# 4EBA"},
/* 2F09 */ { "CLÉ CHINOISE JAMBES","	* clé 10 du Kangxi\n"
	"	# 513F"},
/* 2F0A */ { "CLÉ CHINOISE ENTRER","	* clé 11 du Kangxi\n"
	"	# 5165"},
/* 2F0B */ { "CLÉ CHINOISE HUIT","	* clé 12 du Kangxi\n"
	"	# 516B"},
/* 2F0C */ { "CLÉ CHINOISE PLACE","	* clé 13 du Kangxi\n"
	"	* ce caractère prend des significations telles que « campagne » ou « espace »\n"
	"	# 5182"},
/* 2F0D */ { "CLÉ CHINOISE COUVRIR","	* clé 14 du Kangxi\n"
	"	* en combinaison avec d'autres caractères, il prend des significations telles que « couverture » ou « couvre-chef »\n"
	"	# 5196"},
/* 2F0E */ { "CLÉ CHINOISE GLACE","	* clé 15 du Kangxi\n"
	"	# 51AB"},
/* 2F0F */ { "CLÉ CHINOISE TABLE BASSE","	* clé 16 du Kangxi\n"
	"	# 51E0"},
/* 2F10 */ { "CLÉ CHINOISE FOSSE","	* clé 17 du Kangxi\n"
	"	* en combinaison avec d'autres caractères, il prend historiquement des significations telles que « bouche ouverte », « cadre », « trou » ou « réceptacle »\n"
	"	# 51F5"},
/* 2F11 */ { "CLÉ CHINOISE COUTEAU","	* clé 18 du Kangxi\n"
	"	# 5200"},
/* 2F12 */ { "CLÉ CHINOISE FORCE","	* clé 19 du Kangxi\n"
	"	# 529B"},
/* 2F13 */ { "CLÉ CHINOISE ENVELOPPER","	* clé 20 du Kangxi\n"
	"	# 52F9"},
/* 2F14 */ { "CLÉ CHINOISE CUILLÈRE","	* clé 21 du Kangxi\n"
	"	# 5315"},
/* 2F15 */ { "CLÉ CHINOISE COFFRE","	* clé 22 du Kangxi\n"
	"	# 531A"},
/* 2F16 */ { "CLÉ CHINOISE CACHETTE","	* clé 23 du Kangxi\n"
	"	# 5338"},
/* 2F17 */ { "CLÉ CHINOISE DIX","	* clé 24 du Kangxi\n"
	"	# 5341"},
/* 2F18 */ { "CLÉ CHINOISE DIVINATION","	* clé 25 du Kangxi\n"
	"	# 535C"},
/* 2F19 */ { "CLÉ CHINOISE SCEAU","	* clé 26 du Kangxi\n"
	"	# 5369"},
/* 2F1A */ { "CLÉ CHINOISE FALAISE","	= clé chinoise escarpement\n"
	"	* clé 27 du Kangxi\n"
	"	# 5382"},
/* 2F1B */ { "CLÉ CHINOISE PRIVÉ","	* clé 28 du Kangxi\n"
	"	# 53B6"},
/* 2F1C */ { "CLÉ CHINOISE ENCORE","	* clé 29 du Kangxi\n"
	"	# 53C8"},
/* 2F1D */ { "CLÉ CHINOISE BOUCHE","	* clé 30 du Kangxi\n"
	"	# 53E3"},
/* 2F1E */ { "CLÉ CHINOISE ENCEINTE","	= clé chinoise clôture, bordure\n"
	"	* clé 31 du Kangxi\n"
	"	# 56D7"},
/* 2F1F */ { "CLÉ CHINOISE TERRE","	* clé 32 du Kangxi\n"
	"	# 571F"},
/* 2F20 */ { "CLÉ CHINOISE LETTRÉ","	* clé 33 du Kangxi\n"
	"	# 58EB"},
/* 2F21 */ { "CLÉ CHINOISE ALLER","	* clé 34 du Kangxi\n"
	"	* ce caractère prend aussi le sens de « suivre » (marcher sur les traces laissées par quelqu'un)\n"
	"	# 5902"},
/* 2F22 */ { "CLÉ CHINOISE SE TRAÎNER","	* clé 35 du Kangxi\n"
	"	# 590A"},
/* 2F23 */ { "CLÉ CHINOISE SOIR","	* clé 36 du Kangxi\n"
	"	# 5915"},
/* 2F24 */ { "CLÉ CHINOISE GRAND","	* clé 37 du Kangxi\n"
	"	# 5927"},
/* 2F25 */ { "CLÉ CHINOISE FEMME","	* clé 38 du Kangxi\n"
	"	# 5973"},
/* 2F26 */ { "CLÉ CHINOISE ENFANT","	* clé 39 du Kangxi\n"
	"	# 5B50"},
/* 2F27 */ { "CLÉ CHINOISE TOIT","	* clé 40 du Kangxi\n"
	"	# 5B80"},
/* 2F28 */ { "CLÉ CHINOISE POUCE","	* clé 41 du Kangxi\n"
	"	* le pouce (cùn) désigne une unité de longueur traditionnelle chinoise dont la mesure était à l'origine la largeur du pouce d'une personne à l'articulation\n"
	"	# 5BF8"},
/* 2F29 */ { "CLÉ CHINOISE PETIT","	* clé 42 du Kangxi\n"
	"	# 5C0F"},
/* 2F2A */ { "CLÉ CHINOISE BOITEUX","	* clé 43 du Kangxi\n"
	"	x 21BC1\n"
	"	# 5C22"},
/* 2F2B */ { "CLÉ CHINOISE CADAVRE","	= clé chinoise dépouille\n"
	"	* clé 44 du Kangxi\n"
	"	# 5C38"},
/* 2F2C */ { "CLÉ CHINOISE PLANTULE","	= clé chinoise jeune pousse\n"
	"	* clé 45 du Kangxi\n"
	"	# 5C6E"},
/* 2F2D */ { "CLÉ CHINOISE MONTAGNE","	* clé 46 du Kangxi\n"
	"	# 5C71"},
/* 2F2E */ { "CLÉ CHINOISE RIVIÈRE","	= clé chinoise ruisseau\n"
	"	* clé 47 du Kangxi\n"
	"	# 5DDB"},
/* 2F2F */ { "CLÉ CHINOISE TRAVAIL","	* clé 48 du Kangxi\n"
	"	# 5DE5"},
/* 2F30 */ { "CLÉ CHINOISE SOI-MÊME","	* clé 49 du Kangxi\n"
	"	# 5DF1"},
/* 2F31 */ { "CLÉ CHINOISE SERVIETTE","	* clé 50 du Kangxi\n"
	"	* désigne un morceau d'étoffe (un foulard, une écharpe, un turban)\n"
	"	# 5DFE"},
/* 2F32 */ { "CLÉ CHINOISE SEC","	* clé 51 du Kangxi\n"
	"	# 5E72"},
/* 2F33 */ { "CLÉ CHINOISE PETIT FIL","	* clé 52 du Kangxi\n"
	"	* ce caractère a pris le sens de « ténu » ou de « tendre »\n"
	"	# 5E7A"},
/* 2F34 */ { "CLÉ CHINOISE APPENTIS","	* clé 53 du Kangxi\n"
	"	* ce signe avait autrefois le sens d'« abri » ou de « hangar » ; aujourd'hui, il prend des significations telles que « vaste », « étendu » ou « large »\n"
	"	# 5E7F"},
/* 2F35 */ { "CLÉ CHINOISE LONGUE FOULÉE","	* clé 54 du Kangxi\n"
	"	* traduit généralement l'idée d'une progression (avancer à grands pas) et peut être utilisé parfois dans le sens de « progrès »\n"
	"	# 5EF4"},
/* 2F36 */ { "CLÉ CHINOISE DEUX MAINS","	* clé 55 du Kangxi\n"
	"	* prend des significations telles que « ensemble », « collaboration » ou « union »\n"
	"	# 5EFE"},
/* 2F37 */ { "CLÉ CHINOISE TIRER","	* clé 56 du Kangxi\n"
	"	# 5F0B"},
/* 2F38 */ { "CLÉ CHINOISE ARC","	* clé 57 du Kangxi\n"
	"	# 5F13"},
/* 2F39 */ { "CLÉ CHINOISE GROIN","	* clé 58 du Kangxi\n"
	"	# 5F50"},
/* 2F3A */ { "CLÉ CHINOISE POIL","	* clé 59 du Kangxi\n"
	"	* prend aussi le sens de « barbe »\n"
	"	# 5F61"},
/* 2F3B */ { "CLÉ CHINOISE PAS","	* clé 60 du Kangxi\n"
	"	* prend aussi le sens de « se promener »\n"
	"	# 5F73"},
/* 2F3C */ { "CLÉ CHINOISE CŒUR","	* clé 61 du Kangxi\n"
	"	# 5FC3"},
/* 2F3D */ { "CLÉ CHINOISE HALLEBARDE","	* clé 62 du Kangxi\n"
	"	# 6208"},
/* 2F3E */ { "CLÉ CHINOISE PORTE","	= clé chinoise huis\n"
	"	* clé 63 du Kangxi\n"
	"	* désigne aussi la famille, le foyer, la maison\n"
	"	# 6236"},
/* 2F3F */ { "CLÉ CHINOISE MAIN","	* clé 64 du Kangxi\n"
	"	# 624B"},
/* 2F40 */ { "CLÉ CHINOISE BRANCHE","	* clé 65 du Kangxi\n"
	"	# 652F"},
/* 2F41 */ { "CLÉ CHINOISE TAPER","	= clé chinoise frapper, battre\n"
	"	* clé 66 du Kangxi\n"
	"	# 6534"},
/* 2F42 */ { "CLÉ CHINOISE ÉCRITURE","	* clé 67 du Kangxi\n"
	"	# 6587"},
/* 2F43 */ { "CLÉ CHINOISE BOISSEAU","	* clé 68 du Kangxi\n"
	"	# 6597"},
/* 2F44 */ { "CLÉ CHINOISE HACHE","	* clé 69 du Kangxi\n"
	"	# 65A4"},
/* 2F45 */ { "CLÉ CHINOISE CARRÉ","	* clé 70 du Kangxi\n"
	"	# 65B9"},
/* 2F46 */ { "CLÉ CHINOISE SANS","	* clé 71 du Kangxi\n"
	"	* marque la négation (non, pas)\n"
	"	# 65E0"},
/* 2F47 */ { "CLÉ CHINOISE SOLEIL","	* clé 72 du Kangxi\n"
	"	* désigne aussi le jour\n"
	"	# 65E5"},
/* 2F48 */ { "CLÉ CHINOISE DIRE","	* clé 73 du Kangxi\n"
	"	# 66F0"},
/* 2F49 */ { "CLÉ CHINOISE LUNE","	* clé 74 du Kangxi\n"
	"	* désigne aussi le mois\n"
	"	# 6708"},
/* 2F4A */ { "CLÉ CHINOISE ARBRE","	* clé 75 du Kangxi\n"
	"	# 6728"},
/* 2F4B */ { "CLÉ CHINOISE MANQUE","	= clé chinoise pénurie, carence\n"
	"	* clé 76 du Kangxi\n"
	"	* désigne aussi le bâillement\n"
	"	# 6B20"},
/* 2F4C */ { "CLÉ CHINOISE ARRÊT","	* clé 77 du Kangxi\n"
	"	# 6B62"},
/* 2F4D */ { "CLÉ CHINOISE MORT","	* clé 78 du Kangxi\n"
	"	* prend aussi le sens de « décomposition »\n"
	"	# 6B79"},
/* 2F4E */ { "CLÉ CHINOISE ARME","	* clé 79 du Kangxi\n"
	"	# 6BB3"},
/* 2F4F */ { "CLÉ CHINOISE NE PAS","	* clé 80 du Kangxi\n"
	"	* n'avoir pas, ne pas faire, ne pas pouvoir, etc.\n"
	"	# 6BCB"},
/* 2F50 */ { "CLÉ CHINOISE COMPARER","	= clé chinoise confronter\n"
	"	* clé 81 du Kangxi\n"
	"	# 6BD4"},
/* 2F51 */ { "CLÉ CHINOISE PELAGE","	* clé 82 du Kangxi\n"
	"	# 6BDB"},
/* 2F52 */ { "CLÉ CHINOISE CLAN","	* clé 83 du Kangxi\n"
	"	# 6C0F"},
/* 2F53 */ { "CLÉ CHINOISE VAPEUR","	* clé 84 du Kangxi\n"
	"	# 6C14"},
/* 2F54 */ { "CLÉ CHINOISE EAU","	* clé 85 du Kangxi\n"
	"	# 6C34"},
/* 2F55 */ { "CLÉ CHINOISE FEU","	* clé 86 du Kangxi\n"
	"	# 706B"},
/* 2F56 */ { "CLÉ CHINOISE GRIFFE","	* clé 87 du Kangxi\n"
	"	# 722A"},
/* 2F57 */ { "CLÉ CHINOISE PÈRE","	* clé 88 du Kangxi\n"
	"	# 7236"},
/* 2F58 */ { "CLÉ CHINOISE ENTRELACÉ","	* clé 89 du Kangxi\n"
	"	* prend des significations telles que « nouer » ou « tresser »\n"
	"	# 723B"},
/* 2F59 */ { "CLÉ CHINOISE MOITIÉ DE TRONC","	* clé 90 du Kangxi\n"
	"	* prend aussi le sens de « bois fendu »\n"
	"	# 723F"},
/* 2F5A */ { "CLÉ CHINOISE TRANCHE","	* clé 91 du Kangxi\n"
	"	# 7247"},
/* 2F5B */ { "CLÉ CHINOISE CROC","	* clé 92 du Kangxi\n"
	"	# 7259"},
/* 2F5C */ { "CLÉ CHINOISE BŒUF","	* clé 93 du Kangxi\n"
	"	* désigne aussi le buffle ou le taureau\n"
	"	# 725B"},
/* 2F5D */ { "CLÉ CHINOISE CHIEN","	* clé 94 du Kangxi\n"
	"	# 72AC"},
/* 2F5E */ { "CLÉ CHINOISE OBSCUR","	= clé chinoise sombre, mystérieux\n"
	"	* clé 95 du Kangxi\n"
	"	# 7384"},
/* 2F5F */ { "CLÉ CHINOISE JADE","	* clé 96 du Kangxi\n"
	"	# 7389"},
/* 2F60 */ { "CLÉ CHINOISE MELON","	* clé 97 du Kangxi\n"
	"	# 74DC"},
/* 2F61 */ { "CLÉ CHINOISE TUILE","	* clé 98 du Kangxi\n"
	"	# 74E6"},
/* 2F62 */ { "CLÉ CHINOISE DOUX","	* clé 99 du Kangxi\n"
	"	* agréable au goût, savoureux ; s'applique plus généralement à tout ce qui plaît aux cinq sens\n"
	"	# 7518"},
/* 2F63 */ { "CLÉ CHINOISE NAÎTRE","	* clé 100 du Kangxi\n"
	"	# 751F"},
/* 2F64 */ { "CLÉ CHINOISE UTILISER","	* clé 101 du Kangxi\n"
	"	# 7528"},
/* 2F65 */ { "CLÉ CHINOISE CHAMP","	* clé 102 du Kangxi\n"
	"	# 7530"},
/* 2F66 */ { "CLÉ CHINOISE PIÈCE D'ÉTOFFE","	= clé chinoise rouleau de tissu\n"
	"	* clé 103 du Kangxi\n"
	"	# 758B"},
/* 2F67 */ { "CLÉ CHINOISE MALADIE","	* clé 104 du Kangxi\n"
	"	# 7592"},
/* 2F68 */ { "CLÉ CHINOISE MONTER","	* clé 105 du Kangxi\n"
	"	* prend aussi des significations telles que « empreintes de pas », « divergence » ou « séparation »\n"
	"	# 7676"},
/* 2F69 */ { "CLÉ CHINOISE BLANC","	* clé 106 du Kangxi\n"
	"	# 767D"},
/* 2F6A */ { "CLÉ CHINOISE PEAU","	* clé 107 du Kangxi\n"
	"	# 76AE"},
/* 2F6B */ { "CLÉ CHINOISE VAISSELLE","	* clé 108 du Kangxi\n"
	"	# 76BF"},
/* 2F6C */ { "CLÉ CHINOISE ŒIL","	* clé 109 du Kangxi\n"
	"	# 76EE"},
/* 2F6D */ { "CLÉ CHINOISE LANCE","	* clé 110 du Kangxi\n"
	"	# 77DB"},
/* 2F6E */ { "CLÉ CHINOISE FLÈCHE","	* clé 111 du Kangxi\n"
	"	# 77E2"},
/* 2F6F */ { "CLÉ CHINOISE PIERRE","	* clé 112 du Kangxi\n"
	"	# 77F3"},
/* 2F70 */ { "CLÉ CHINOISE ESPRIT","	* clé 113 du Kangxi\n"
	"	* prend aussi le sens d'« ancêtre »\n"
	"	# 793A"},
/* 2F71 */ { "CLÉ CHINOISE TRACES","	* clé 114 du Kangxi\n"
	"	# 79B8"},
/* 2F72 */ { "CLÉ CHINOISE CÉRÉALES","	= clé chinoise grain\n"
	"	* clé 115 du Kangxi\n"
	"	# 79BE"},
/* 2F73 */ { "CLÉ CHINOISE CAVERNE","	= clé chinoise grotte, cavité\n"
	"	* clé 116 du Kangxi\n"
	"	# 7A74"},
/* 2F74 */ { "CLÉ CHINOISE DEBOUT","	= clé chinoise se tenir debout, se lever\n"
	"	* clé 117 du Kangxi\n"
	"	# 7ACB"},
/* 2F75 */ { "CLÉ CHINOISE BAMBOU","	* clé 118 du Kangxi\n"
	"	# 7AF9"},
/* 2F76 */ { "CLÉ CHINOISE RIZ","	* clé 119 du Kangxi\n"
	"	# 7C73"},
/* 2F77 */ { "CLÉ CHINOISE SOIE","	* clé 120 du Kangxi\n"
	"	# 7CF8"},
/* 2F78 */ { "CLÉ CHINOISE POTERIE","	= clé chinoise jarre, cruche\n"
	"	* clé 121 du Kangxi\n"
	"	# 7F36"},
/* 2F79 */ { "CLÉ CHINOISE FILET","	* clé 122 du Kangxi\n"
	"	# 7F51"},
/* 2F7A */ { "CLÉ CHINOISE MOUTON","	* clé 123 du Kangxi\n"
	"	# 7F8A"},
/* 2F7B */ { "CLÉ CHINOISE PLUME","	* clé 124 du Kangxi\n"
	"	# 7FBD"},
/* 2F7C */ { "CLÉ CHINOISE VIEUX","	* clé 125 du Kangxi\n"
	"	# 8001"},
/* 2F7D */ { "CLÉ CHINOISE ET","	* clé 126 du Kangxi\n"
	"	# 800C"},
/* 2F7E */ { "CLÉ CHINOISE CHARRUE","	= clé chinoise herse\n"
	"	* clé 127 du Kangxi\n"
	"	# 8012"},
/* 2F7F */ { "CLÉ CHINOISE OREILLE","	* clé 128 du Kangxi\n"
	"	# 8033"},
/* 2F80 */ { "CLÉ CHINOISE PINCEAU","	* clé 129 du Kangxi\n"
	"	# 807F"},
/* 2F81 */ { "CLÉ CHINOISE VIANDE","	* clé 130 du Kangxi\n"
	"	# 8089"},
/* 2F82 */ { "CLÉ CHINOISE MINISTRE","	* clé 131 du Kangxi\n"
	"	# 81E3"},
/* 2F83 */ { "CLÉ CHINOISE SOI","	* clé 132 du Kangxi\n"
	"	# 81EA"},
/* 2F84 */ { "CLÉ CHINOISE ARRIVER","	* clé 133 du Kangxi\n"
	"	# 81F3"},
/* 2F85 */ { "CLÉ CHINOISE MORTIER","	* clé 134 du Kangxi\n"
	"	# 81FC"},
/* 2F86 */ { "CLÉ CHINOISE LANGUE","	* clé 135 du Kangxi\n"
	"	* désigne l'organe\n"
	"	# 820C"},
/* 2F87 */ { "CLÉ CHINOISE S'OPPOSER","	* clé 136 du Kangxi\n"
	"	# 821B"},
/* 2F88 */ { "CLÉ CHINOISE BATEAU","	* clé 137 du Kangxi\n"
	"	# 821F"},
/* 2F89 */ { "CLÉ CHINOISE S'ARRÊTER","	* clé 138 du Kangxi\n"
	"	* désigne aussi l'immobilité\n"
	"	# 826E"},
/* 2F8A */ { "CLÉ CHINOISE COULEUR","	* clé 139 du Kangxi\n"
	"	# 8272"},
/* 2F8B */ { "CLÉ CHINOISE HERBE","	* clé 140 du Kangxi\n"
	"	# 8278"},
/* 2F8C */ { "CLÉ CHINOISE TIGRE","	* clé 141 du Kangxi\n"
	"	# 864D"},
/* 2F8D */ { "CLÉ CHINOISE INSECTE","	* clé 142 du Kangxi\n"
	"	# 866B"},
/* 2F8E */ { "CLÉ CHINOISE SANG","	* clé 143 du Kangxi\n"
	"	# 8840"},
/* 2F8F */ { "CLÉ CHINOISE DÉFILER","	* clé 144 du Kangxi\n"
	"	* prend aussi des significations telles que « marcher », « voyager » ou « faire »\n"
	"	# 884C"},
/* 2F90 */ { "CLÉ CHINOISE HABITS","	* clé 145 du Kangxi\n"
	"	# 8863"},
/* 2F91 */ { "CLÉ CHINOISE OUEST","	* clé 146 du Kangxi\n"
	"	# 897E"},
/* 2F92 */ { "CLÉ CHINOISE VOIR","	* clé 147 du Kangxi\n"
	"	# 898B"},
/* 2F93 */ { "CLÉ CHINOISE CORNE","	* clé 148 du Kangxi\n"
	"	# 89D2"},
/* 2F94 */ { "CLÉ CHINOISE PAROLE","	* clé 149 du Kangxi\n"
	"	# 8A00"},
/* 2F95 */ { "CLÉ CHINOISE VALLÉE","	* clé 150 du Kangxi\n"
	"	# 8C37"},
/* 2F96 */ { "CLÉ CHINOISE HARICOT","	* clé 151 du Kangxi\n"
	"	# 8C46"},
/* 2F97 */ { "CLÉ CHINOISE COCHON","	* clé 152 du Kangxi\n"
	"	# 8C55"},
/* 2F98 */ { "CLÉ CHINOISE ANIMAL À POILS","	* clé 153 du Kangxi\n"
	"	# 8C78"},
/* 2F99 */ { "CLÉ CHINOISE COQUILLAGE","	* clé 154 du Kangxi\n"
	"	# 8C9D"},
/* 2F9A */ { "CLÉ CHINOISE ROUGE","	* clé 155 du Kangxi\n"
	"	# 8D64"},
/* 2F9B */ { "CLÉ CHINOISE COURIR","	* clé 156 du Kangxi\n"
	"	# 8D70"},
/* 2F9C */ { "CLÉ CHINOISE PIED","	* clé 157 du Kangxi\n"
	"	# 8DB3"},
/* 2F9D */ { "CLÉ CHINOISE CORPS","	* clé 158 du Kangxi\n"
	"	# 8EAB"},
/* 2F9E */ { "CLÉ CHINOISE VÉHICULE","	* clé 159 du Kangxi\n"
	"	# 8ECA"},
/* 2F9F */ { "CLÉ CHINOISE ÂCRE","	* clé 160 du Kangxi\n"
	"	# 8F9B"},
/* 2FA0 */ { "CLÉ CHINOISE MATIN","	* clé 161 du Kangxi\n"
	"	# 8FB0"},
/* 2FA1 */ { "CLÉ CHINOISE MARCHE À PIED","	* clé 162 du Kangxi\n"
	"	# 8FB5"},
/* 2FA2 */ { "CLÉ CHINOISE VILLE","	* clé 163 du Kangxi\n"
	"	# 9091"},
/* 2FA3 */ { "CLÉ CHINOISE VIN","	* clé 164 du Kangxi\n"
	"	* prend aussi le sens d'« alcool »\n"
	"	# 9149"},
/* 2FA4 */ { "CLÉ CHINOISE DISTINGUER","	= clé chinoise choisir\n"
	"	* clé 165 du Kangxi\n"
	"	# 91C6"},
/* 2FA5 */ { "CLÉ CHINOISE HAMEAU","	* clé 166 du Kangxi\n"
	"	* désigne aussi le li (unité de mesure chinoise)\n"
	"	# 91CC"},
/* 2FA6 */ { "CLÉ CHINOISE OR","	* clé 167 du Kangxi\n"
	"	# 91D1"},
/* 2FA7 */ { "CLÉ CHINOISE LONG","	* clé 168 du Kangxi\n"
	"	# 9577"},
/* 2FA8 */ { "CLÉ CHINOISE PORTAIL","	* clé 169 du Kangxi\n"
	"	# 9580"},
/* 2FA9 */ { "CLÉ CHINOISE TERTRE","	* clé 170 du Kangxi\n"
	"	* prend aussi le sens de « barrage »\n"
	"	# 961C"},
/* 2FAA */ { "CLÉ CHINOISE ESCLAVE","	* clé 171 du Kangxi\n"
	"	# 96B6"},
/* 2FAB */ { "CLÉ CHINOISE OISEAU À QUEUE COURTE","	* clé 172 du Kangxi\n"
	"	# 96B9"},
/* 2FAC */ { "CLÉ CHINOISE PLUIE","	* clé 173 du Kangxi\n"
	"	# 96E8"},
/* 2FAD */ { "CLÉ CHINOISE BLEU","	* clé 174 du Kangxi\n"
	"	# 9751"},
/* 2FAE */ { "CLÉ CHINOISE TORT","	* clé 175 du Kangxi\n"
	"	# 975E"},
/* 2FAF */ { "CLÉ CHINOISE VISAGE","	* clé 176 du Kangxi\n"
	"	# 9762"},
/* 2FB0 */ { "CLÉ CHINOISE CUIR","	* clé 177 du Kangxi\n"
	"	# 9769"},
/* 2FB1 */ { "CLÉ CHINOISE CUIR TANNÉ","	* clé 178 du Kangxi\n"
	"	# 97CB"},
/* 2FB2 */ { "CLÉ CHINOISE CIBOULETTE","	* clé 179 du Kangxi\n"
	"	# 97ED"},
/* 2FB3 */ { "CLÉ CHINOISE SON","	* clé 180 du Kangxi\n"
	"	# 97F3"},
/* 2FB4 */ { "CLÉ CHINOISE FEUILLE","	* clé 181 du Kangxi\n"
	"	# 9801"},
/* 2FB5 */ { "CLÉ CHINOISE VENT","	* clé 182 du Kangxi\n"
	"	# 98A8"},
/* 2FB6 */ { "CLÉ CHINOISE S'ENVOLER","	* clé 183 du Kangxi\n"
	"	# 98DB"},
/* 2FB7 */ { "CLÉ CHINOISE MANGER","	* clé 184 du Kangxi\n"
	"	# 98DF"},
/* 2FB8 */ { "CLÉ CHINOISE TÊTE","	* clé 185 du Kangxi\n"
	"	# 9996"},
/* 2FB9 */ { "CLÉ CHINOISE PARFUM","	* clé 186 du Kangxi\n"
	"	# 9999"},
/* 2FBA */ { "CLÉ CHINOISE CHEVAL","	* clé 187 du Kangxi\n"
	"	# 99AC"},
/* 2FBB */ { "CLÉ CHINOISE OS","	* clé 188 du Kangxi\n"
	"	# 9AA8"},
/* 2FBC */ { "CLÉ CHINOISE HAUT","	* clé 189 du Kangxi\n"
	"	# 9AD8"},
/* 2FBD */ { "CLÉ CHINOISE CHEVELURE","	* clé 190 du Kangxi\n"
	"	# 9ADF"},
/* 2FBE */ { "CLÉ CHINOISE LUTTE","	* clé 191 du Kangxi\n"
	"	# 9B25"},
/* 2FBF */ { "CLÉ CHINOISE VIN SACRIFICIEL","	* clé 192 du Kangxi\n"
	"	# 9B2F"},
/* 2FC0 */ { "CLÉ CHINOISE CHAUDRON","	* clé 193 du Kangxi\n"
	"	# 9B32"},
/* 2FC1 */ { "CLÉ CHINOISE DÉMON","	* clé 194 du Kangxi\n"
	"	# 9B3C"},
/* 2FC2 */ { "CLÉ CHINOISE POISSON","	* clé 195 du Kangxi\n"
	"	# 9B5A"},
/* 2FC3 */ { "CLÉ CHINOISE OISEAU","	* clé 196 du Kangxi\n"
	"	# 9CE5"},
/* 2FC4 */ { "CLÉ CHINOISE SEL","	* clé 197 du Kangxi\n"
	"	# 9E75"},
/* 2FC5 */ { "CLÉ CHINOISE CERF","	* clé 198 du Kangxi\n"
	"	# 9E7F"},
/* 2FC6 */ { "CLÉ CHINOISE BLÉ","	* clé 199 du Kangxi\n"
	"	# 9EA5"},
/* 2FC7 */ { "CLÉ CHINOISE CHANVRE","	* clé 200 du Kangxi\n"
	"	# 9EBB"},
/* 2FC8 */ { "CLÉ CHINOISE JAUNE","	* clé 201 du Kangxi\n"
	"	# 9EC3"},
/* 2FC9 */ { "CLÉ CHINOISE MILLET","	* clé 202 du Kangxi\n"
	"	# 9ECD"},
/* 2FCA */ { "CLÉ CHINOISE NOIR","	* clé 203 du Kangxi\n"
	"	# 9ED1"},
/* 2FCB */ { "CLÉ CHINOISE BRODERIE","	* clé 204 du Kangxi\n"
	"	# 9EF9"},
/* 2FCC */ { "CLÉ CHINOISE GRENOUILLE","	* clé 205 du Kangxi\n"
	"	# 9EFD"},
/* 2FCD */ { "CLÉ CHINOISE TRIPODE","	* clé 206 du Kangxi\n"
	"	# 9F0E"},
/* 2FCE */ { "CLÉ CHINOISE TAMBOUR","	* clé 207 du Kangxi\n"
	"	# 9F13"},
/* 2FCF */ { "CLÉ CHINOISE RAT","	* clé 208 du Kangxi\n"
	"	# 9F20"},
/* 2FD0 */ { "CLÉ CHINOISE NEZ","	* clé 209 du Kangxi\n"
	"	# 9F3B"},
/* 2FD1 */ { "CLÉ CHINOISE RÉGULIER","	= clé chinoise uniforme, homogène\n"
	"	* clé 210 du Kangxi\n"
	"	# 9F4A"},
/* 2FD2 */ { "CLÉ CHINOISE DENT","	* clé 211 du Kangxi\n"
	"	# 9F52"},
/* 2FD3 */ { "CLÉ CHINOISE DRAGON","	* clé 212 du Kangxi\n"
	"	# 9F8D"},
/* 2FD4 */ { "CLÉ CHINOISE TORTUE","	* clé 213 du Kangxi\n"
	"	# 9F9C"},
/* 2FD5 */ { "CLÉ CHINOISE FLÛTE","	* clé 214 du Kangxi\n"
	"	# 9FA0"},
/* 2FD6 */ { NULL,NULL},
/* 2FD7 */ { NULL,NULL},
/* 2FD8 */ { NULL,NULL},
/* 2FD9 */ { NULL,NULL},
/* 2FDA */ { NULL,NULL},
/* 2FDB */ { NULL,NULL},
/* 2FDC */ { NULL,NULL},
/* 2FDD */ { NULL,NULL},
/* 2FDE */ { NULL,NULL},
/* 2FDF */ { NULL,NULL},
/* 2FE0 */ { NULL,NULL},
/* 2FE1 */ { NULL,NULL},
/* 2FE2 */ { NULL,NULL},
/* 2FE3 */ { NULL,NULL},
/* 2FE4 */ { NULL,NULL},
/* 2FE5 */ { NULL,NULL},
/* 2FE6 */ { NULL,NULL},
/* 2FE7 */ { NULL,NULL},
/* 2FE8 */ { NULL,NULL},
/* 2FE9 */ { NULL,NULL},
/* 2FEA */ { NULL,NULL},
/* 2FEB */ { NULL,NULL},
/* 2FEC */ { NULL,NULL},
/* 2FED */ { NULL,NULL},
/* 2FEE */ { NULL,NULL},
/* 2FEF */ { NULL,NULL},
/* 2FF0 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE DE GAUCHE À DROITE",NULL},
/* 2FF1 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE DE HAUT EN BAS",NULL},
/* 2FF2 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE DE GAUCHE AU MILIEU ET À DROITE",NULL},
/* 2FF3 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE DU HAUT AU MILIEU ET EN BAS",NULL},
/* 2FF4 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER INTÉGRALEMENT",NULL},
/* 2FF5 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LE HAUT",NULL},
/* 2FF6 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LE BAS",NULL},
/* 2FF7 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LA GAUCHE",NULL},
/* 2FF8 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LE COIN SUPÉRIEUR GAUCHE",NULL},
/* 2FF9 */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LE COIN SUPÉRIEUR DROIT",NULL},
/* 2FFA */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LE COIN INFÉRIEUR GAUCHE",NULL},
/* 2FFB */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE SUPERPOSÉ",NULL},
/* 2FFC */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LA DROITE",NULL},
/* 2FFD */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ENTOURER PAR LE COIN INFÉRIEUR DROIT",NULL},
/* 2FFE */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE RÉFLEXION HORIZONTALE",NULL},
/* 2FFF */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE ROTATION",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_30[] = {
/* 3000 */ { "ESPACE IDÉOGRAPHIQUE","	x (espace - 0020)\n"
	"	# <large> 0020"},
/* 3001 */ { "VIRGULE IDÉOGRAPHIQUE","	* en chinois, délimite les éléments d'une liste ou d'une série\n"
	"	x (virgule - 002C)\n"
	"	x (virgule pleine chasse - FF0C)\n"
	"	x (virgule idéographique demi-chasse - FF64)\n"
	"	~ 3001 FE00 forme alignée dans le coin\n"
	"	~ 3001 FE01 forme centrée"},
/* 3002 */ { "POINT IDÉOGRAPHIQUE","	x (point - 002E)\n"
	"	x (point pleine chasse - FF0E)\n"
	"	x (point idéographique demi-chasse - FF61)\n"
	"	~ 3002 FE00 forme alignée dans le coin\n"
	"	~ 3002 FE01 forme centrée"},
/* 3003 */ { "GUILLEMET DE RÉPÉTITION","	x (double prime - 2033)"},
/* 3004 */ { "SYMBOLE DE NORME INDUSTRIELLE JAPONAISE",NULL},
/* 3005 */ { "MARQUE D'ITÉRATION IDÉOGRAPHIQUE","	x 206A4\n"
	"	x (marque d'itération tangoute - 16FE0)"},
/* 3006 */ { "MARQUE IDÉOGRAPHIQUE DE FERMETURE","	x 4E44"},
/* 3007 */ { "ZÉRO IDÉOGRAPHIQUE","	x (diacritique cercle englobant - 20DD)\n"
	"	x (cercle blanc - 25CB)\n"
	"	x (grand cercle - 25EF)"},
/* 3008 */ { "CHEVRON GAUCHE","	x (signe inférieur à - 003C)\n"
	"	x (guillemet simple vers la gauche - 2039)\n"
	"	x (chevron pointant à gauche - 2329)\n"
	"	x (chevron mathématique gauche - 27E8)"},
/* 3009 */ { "CHEVRON DROIT","	x (signe supérieur à - 003E)\n"
	"	x (guillemet simple vers la droite - 203A)\n"
	"	x (chevron pointant à droite - 232A)\n"
	"	x (chevron mathématique droit - 27E9)"},
/* 300A */ { "DOUBLE CHEVRON GAUCHE","	x (guillemet gauche - 00AB)\n"
	"	x (double chevron mathématique gauche - 27EA)"},
/* 300B */ { "DOUBLE CHEVRON DROIT","	x (guillemet droit - 00BB)\n"
	"	x (double chevron mathématique droit - 27EB)"},
/* 300C */ { "ANGLET GAUCHE","	x (plafond à gauche - 2308)"},
/* 300D */ { "ANGLET DROIT","	x (plancher à droite - 230B)"},
/* 300E */ { "ANGLET BLANC GAUCHE",NULL},
/* 300F */ { "ANGLET BLANC DROIT",NULL},
/* 3010 */ { "CROCHET LENTICULAIRE NOIR GAUCHE",NULL},
/* 3011 */ { "CROCHET LENTICULAIRE NOIR DROIT",NULL},
/* 3012 */ { "MARQUE POSTALE","	x (symbole tenge - 20B8)\n"
	"	x (taquet vers le bas court avec barre en chef - 2AE7)\n"
	"	x (bureau de poste japonais - 1F3E3)"},
/* 3013 */ { "SIGNE GETA","	* remplace un idéogramme absent de la police\n"
	"	* convention éditoriale pour représenter une lacune\n"
	"	x (carré blanc - 25A1)\n"
	"	x (signe égal épais - 1F7F0)"},
/* 3014 */ { "CROCHET EN ÉCAILLE GAUCHE",NULL},
/* 3015 */ { "CROCHET EN ÉCAILLE DROIT",NULL},
/* 3016 */ { "CROCHET LENTICULAIRE BLANC GAUCHE",NULL},
/* 3017 */ { "CROCHET LENTICULAIRE BLANC DROIT",NULL},
/* 3018 */ { "CROCHET EN ÉCAILLE BLANC GAUCHE","	x (crochet en écaille mathématique blanc gauche - 27EC)"},
/* 3019 */ { "CROCHET EN ÉCAILLE BLANC DROIT","	x (crochet en écaille mathématique blanc droit - 27ED)"},
/* 301A */ { "CROCHET BLANC GAUCHE","	= crochet gauche de syntaxe abstraite\n"
	"	x (crochet mathématique blanc gauche - 27E6)"},
/* 301B */ { "CROCHET BLANC DROIT","	= crochet droit de syntaxe abstraite\n"
	"	x (crochet mathématique blanc droit - 27E7)"},
/* 301C */ { "TIRET EN ESSE","		Ce caractère est repris pour la correspondance avec le « tiret ondulé » de JIS C 6226-1978 1-33.\n"
	"	x (tiret ondé - 2053)\n"
	"	x (tiret ondulé - 3030)\n"
	"	x (tilde pleine chasse - FF5E)"},
/* 301D */ { "GUILLEMET DOUBLE PRIME RÉFLÉCHI","	* parfois représenté comme un guillemet double prime\n"
	"	x (guillemet-apostrophe double culbuté - 201C)\n"
	"	x (double prime réfléchi - 2036)"},
/* 301E */ { "GUILLEMET DOUBLE PRIME","	* il s'agit d'une erreur analogue à 201D ; 301F est recommandé\n"
	"	x (guillemet-apostrophe double - 201D)\n"
	"	x (double prime - 2033)"},
/* 301F */ { "GUILLEMET DOUBLE PRIME INFÉRIEUR","	* peut être représenté comme un guillemet bas double prime inversé"},
/* 3020 */ { "VISAGE EN MARQUE POSTALE",NULL},
/* 3021 */ { "CHIFFRE DE SUZHOU UN",NULL},
/* 3022 */ { "CHIFFRE DE SUZHOU DEUX",NULL},
/* 3023 */ { "CHIFFRE DE SUZHOU TROIS",NULL},
/* 3024 */ { "CHIFFRE DE SUZHOU QUATRE",NULL},
/* 3025 */ { "CHIFFRE DE SUZHOU CINQ",NULL},
/* 3026 */ { "CHIFFRE DE SUZHOU SIX","	= signe yangqin « lent d'un demi-temps »\n"
	"	* représente une demi-mesure dans le système de notation du tempo du yangqin\n"
	"	x (signe yangqin lent d'un temps - 16FF4)"},
/* 3027 */ { "CHIFFRE DE SUZHOU SEPT",NULL},
/* 3028 */ { "CHIFFRE DE SUZHOU HUIT",NULL},
/* 3029 */ { "CHIFFRE DE SUZHOU NEUF",NULL},
/* 302A */ { "DIACRITIQUE IDÉOGRAPHIQUE TON FIXE",NULL},
/* 302B */ { "DIACRITIQUE IDÉOGRAPHIQUE TON ASCENDANT",NULL},
/* 302C */ { "DIACRITIQUE IDÉOGRAPHIQUE TON SORTANT",NULL},
/* 302D */ { "DIACRITIQUE IDÉOGRAPHIQUE TON ENTRANT",NULL},
/* 302E */ { "DIACRITIQUE TON HANGÛL POINT","	= pangtchom à un point"},
/* 302F */ { "DIACRITIQUE TON HANGÛL DOUBLE POINT","	= pangtchom à deux points"},
/* 3030 */ { "TIRET ONDULÉ","	x (ligne ondulée - 2307)\n"
	"	x (tiret en esse - 301C)"},
/* 3031 */ { "MARQUE VERTICALE KANA DE RÉPÉTITION",NULL},
/* 3032 */ { "MARQUE VERTICALE KANA DE RÉPÉTITION AVEC SON VOISÉ","	* caractères conçus de façon telle que les glyphes ont une hauteur correpondant à deux cadratins"},
/* 3033 */ { "MOITIÉ SUPÉRIEURE DE MARQUE VERTICALE KANA DE RÉPÉTITION",NULL},
/* 3034 */ { "MOITIÉ SUPÉRIEURE DE MARQUE VERTICALE KANA DE RÉPÉTITION AVEC SON VOISÉ","	* caractères conçus de façon telle que les glyphes ont une hauteur correpondant à un cadratin et se combinent avec le caractère qui suit pour former des glyphes liés d'une hauteur de deux cadratins pour les marques de répétition complètes"},
/* 3035 */ { "MOITIÉ INFÉRIEURE DE MARQUE VERTICALE KANA DE RÉPÉTITION",NULL},
/* 3036 */ { "MARQUE POSTALE CERCLÉE","	= symbole pour appareil électronique de type B\n"
	"	* ce caractère n'est pas utilisé comme une marque postale\n"
	"	x (symbole pour appareil électronique de type a - 2B97)\n"
	"	# 3012 marque postale"},
/* 3037 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE SÉPARATEUR DE CHANGEMENT DE LIGNE",NULL},
/* 3038 */ { "NOMBRE DE SUZHOU DIX","	# 5341"},
/* 3039 */ { "NOMBRE DE SUZHOU VINGT","	# 5344"},
/* 303A */ { "NOMBRE DE SUZHOU TRENTE","	# 5345"},
/* 303B */ { "MARQUE D'ITÉRATION IDÉOGRAPHIQUE VERTICALE",NULL},
/* 303C */ { "SIGNE MASU","	* abréviation japonaise courante représentant le suffixe -masu\n"
	"	x (oblique encadrée - 29C4)"},
/* 303D */ { "SIGNE DE CHANGEMENT DE PARTIE","	* signale le début d'une partie de chanson en japonais"},
/* 303E */ { "INDICATEUR DE VARIANTE IDÉOGRAPHIQUE","	* caractère visuel qui indique que l'on doit interpréter l'idéogramme suivant comme une variante du caractère désiré"},
/* 303F */ { "DEMI-ESPACE IDÉOGRAPHIQUE","	* caractère visuel qui indique une espace à l'écran de chasse égale à la moitié d'un idéogramme"},
/* 3040 */ { NULL,NULL},
/* 3041 */ { "CARACTÈRE HIRAGANA PETIT A",NULL},
/* 3042 */ { "CARACTÈRE HIRAGANA A",NULL},
/* 3043 */ { "CARACTÈRE HIRAGANA PETIT I",NULL},
/* 3044 */ { "CARACTÈRE HIRAGANA I",NULL},
/* 3045 */ { "CARACTÈRE HIRAGANA PETIT U",NULL},
/* 3046 */ { "CARACTÈRE HIRAGANA U",NULL},
/* 3047 */ { "CARACTÈRE HIRAGANA PETIT E",NULL},
/* 3048 */ { "CARACTÈRE HIRAGANA E",NULL},
/* 3049 */ { "CARACTÈRE HIRAGANA PETIT O",NULL},
/* 304A */ { "CARACTÈRE HIRAGANA O",NULL},
/* 304B */ { "CARACTÈRE HIRAGANA KA",NULL},
/* 304C */ { "CARACTÈRE HIRAGANA GA","	: 304B 3099"},
/* 304D */ { "CARACTÈRE HIRAGANA KI",NULL},
/* 304E */ { "CARACTÈRE HIRAGANA GI","	: 304D 3099"},
/* 304F */ { "CARACTÈRE HIRAGANA KU",NULL},
/* 3050 */ { "CARACTÈRE HIRAGANA GU","	: 304F 3099"},
/* 3051 */ { "CARACTÈRE HIRAGANA KE",NULL},
/* 3052 */ { "CARACTÈRE HIRAGANA GE","	: 3051 3099"},
/* 3053 */ { "CARACTÈRE HIRAGANA KO",NULL},
/* 3054 */ { "CARACTÈRE HIRAGANA GO","	: 3053 3099"},
/* 3055 */ { "CARACTÈRE HIRAGANA SA",NULL},
/* 3056 */ { "CARACTÈRE HIRAGANA ZA","	: 3055 3099"},
/* 3057 */ { "CARACTÈRE HIRAGANA SI","	= chi"},
/* 3058 */ { "CARACTÈRE HIRAGANA ZI","	= dji (pas unique)\n"
	"	: 3057 3099"},
/* 3059 */ { "CARACTÈRE HIRAGANA SU",NULL},
/* 305A */ { "CARACTÈRE HIRAGANA ZU","	: 3059 3099"},
/* 305B */ { "CARACTÈRE HIRAGANA SE",NULL},
/* 305C */ { "CARACTÈRE HIRAGANA ZE","	: 305B 3099"},
/* 305D */ { "CARACTÈRE HIRAGANA SO",NULL},
/* 305E */ { "CARACTÈRE HIRAGANA ZO","	: 305D 3099"},
/* 305F */ { "CARACTÈRE HIRAGANA TA",NULL},
/* 3060 */ { "CARACTÈRE HIRAGANA DA","	: 305F 3099"},
/* 3061 */ { "CARACTÈRE HIRAGANA TI","	= tchi"},
/* 3062 */ { "CARACTÈRE HIRAGANA DI","	= dji (pas unique)\n"
	"	: 3061 3099"},
/* 3063 */ { "CARACTÈRE HIRAGANA PETIT TU","	= petit tsou"},
/* 3064 */ { "CARACTÈRE HIRAGANA TU","	= tsou"},
/* 3065 */ { "CARACTÈRE HIRAGANA DU","	= zou (pas unique)\n"
	"	: 3064 3099"},
/* 3066 */ { "CARACTÈRE HIRAGANA TE",NULL},
/* 3067 */ { "CARACTÈRE HIRAGANA DE","	: 3066 3099"},
/* 3068 */ { "CARACTÈRE HIRAGANA TO",NULL},
/* 3069 */ { "CARACTÈRE HIRAGANA DO","	: 3068 3099"},
/* 306A */ { "CARACTÈRE HIRAGANA NA",NULL},
/* 306B */ { "CARACTÈRE HIRAGANA NI",NULL},
/* 306C */ { "CARACTÈRE HIRAGANA NU",NULL},
/* 306D */ { "CARACTÈRE HIRAGANA NE",NULL},
/* 306E */ { "CARACTÈRE HIRAGANA NO",NULL},
/* 306F */ { "CARACTÈRE HIRAGANA HA",NULL},
/* 3070 */ { "CARACTÈRE HIRAGANA BA","	: 306F 3099"},
/* 3071 */ { "CARACTÈRE HIRAGANA PA","	: 306F 309A"},
/* 3072 */ { "CARACTÈRE HIRAGANA HI",NULL},
/* 3073 */ { "CARACTÈRE HIRAGANA BI","	: 3072 3099"},
/* 3074 */ { "CARACTÈRE HIRAGANA PI","	: 3072 309A"},
/* 3075 */ { "CARACTÈRE HIRAGANA HU","	= fu, fou"},
/* 3076 */ { "CARACTÈRE HIRAGANA BU","	: 3075 3099"},
/* 3077 */ { "CARACTÈRE HIRAGANA PU","	: 3075 309A"},
/* 3078 */ { "CARACTÈRE HIRAGANA HE",NULL},
/* 3079 */ { "CARACTÈRE HIRAGANA BE","	: 3078 3099"},
/* 307A */ { "CARACTÈRE HIRAGANA PE","	: 3078 309A"},
/* 307B */ { "CARACTÈRE HIRAGANA HO",NULL},
/* 307C */ { "CARACTÈRE HIRAGANA BO","	: 307B 3099"},
/* 307D */ { "CARACTÈRE HIRAGANA PO","	: 307B 309A"},
/* 307E */ { "CARACTÈRE HIRAGANA MA",NULL},
/* 307F */ { "CARACTÈRE HIRAGANA MI",NULL},
/* 3080 */ { "CARACTÈRE HIRAGANA MU",NULL},
/* 3081 */ { "CARACTÈRE HIRAGANA ME",NULL},
/* 3082 */ { "CARACTÈRE HIRAGANA MO",NULL},
/* 3083 */ { "CARACTÈRE HIRAGANA PETIT YA",NULL},
/* 3084 */ { "CARACTÈRE HIRAGANA YA",NULL},
/* 3085 */ { "CARACTÈRE HIRAGANA PETIT YU",NULL},
/* 3086 */ { "CARACTÈRE HIRAGANA YU",NULL},
/* 3087 */ { "CARACTÈRE HIRAGANA PETIT YO",NULL},
/* 3088 */ { "CARACTÈRE HIRAGANA YO",NULL},
/* 3089 */ { "CARACTÈRE HIRAGANA RA",NULL},
/* 308A */ { "CARACTÈRE HIRAGANA RI",NULL},
/* 308B */ { "CARACTÈRE HIRAGANA RU",NULL},
/* 308C */ { "CARACTÈRE HIRAGANA RE",NULL},
/* 308D */ { "CARACTÈRE HIRAGANA RO",NULL},
/* 308E */ { "CARACTÈRE HIRAGANA PETIT WA",NULL},
/* 308F */ { "CARACTÈRE HIRAGANA WA",NULL},
/* 3090 */ { "CARACTÈRE HIRAGANA WI",NULL},
/* 3091 */ { "CARACTÈRE HIRAGANA WE",NULL},
/* 3092 */ { "CARACTÈRE HIRAGANA WO",NULL},
/* 3093 */ { "CARACTÈRE HIRAGANA N",NULL},
/* 3094 */ { "CARACTÈRE HIRAGANA VU","	: 3046 3099"},
/* 3095 */ { "CARACTÈRE HIRAGANA PETIT KA",NULL},
/* 3096 */ { "CARACTÈRE HIRAGANA PETIT KE",NULL},
/* 3097 */ { NULL,NULL},
/* 3098 */ { NULL,NULL},
/* 3099 */ { "DIACRITIQUE KATAKANA-HIRAGANA SON VOISÉ",NULL},
/* 309A */ { "DIACRITIQUE KATAKANA-HIRAGANA SON SEMI-VOISÉ",NULL},
/* 309B */ { "MARQUE KATAKANA-HIRAGANA DE SON VOISÉ","	# 0020 3099"},
/* 309C */ { "MARQUE KATAKANA-HIRAGANA DE SON SEMI-VOISÉ","	# 0020 309A"},
/* 309D */ { "MARQUE D'ITÉRATION HIRAGANA",NULL},
/* 309E */ { "MARQUE D'ITÉRATION VOISÉE HIRAGANA","	: 309D 3099"},
/* 309F */ { "DIGRAMME HIRAGANA YORI","	* représente la particule japonaise « yori », utilisée pour indiquer un point d'origine (« depuis », « à partir de ») ou pour introduire le second terme d'une comparaison (« que » dans « plus… que », « moins… que »).\n"
	"	* utilisé autrefois dans des compositions verticales, mais également employé aujourd'hui en disposition horizontale\n"
	"	# <verticale> 3088 308A"},
/* 30A0 */ { "DOUBLE TRAIT KATAKANA-HIRAGANA","	x (signe égal - 003D)\n"
	"	x (trait d'union double - 2E40)"},
/* 30A1 */ { "CARACTÈRE KATAKANA PETIT A",NULL},
/* 30A2 */ { "CARACTÈRE KATAKANA A",NULL},
/* 30A3 */ { "CARACTÈRE KATAKANA PETIT I",NULL},
/* 30A4 */ { "CARACTÈRE KATAKANA I",NULL},
/* 30A5 */ { "CARACTÈRE KATAKANA PETIT U",NULL},
/* 30A6 */ { "CARACTÈRE KATAKANA U",NULL},
/* 30A7 */ { "CARACTÈRE KATAKANA PETIT E",NULL},
/* 30A8 */ { "CARACTÈRE KATAKANA E",NULL},
/* 30A9 */ { "CARACTÈRE KATAKANA PETIT O",NULL},
/* 30AA */ { "CARACTÈRE KATAKANA O",NULL},
/* 30AB */ { "CARACTÈRE KATAKANA KA",NULL},
/* 30AC */ { "CARACTÈRE KATAKANA GA","	: 30AB 3099"},
/* 30AD */ { "CARACTÈRE KATAKANA KI",NULL},
/* 30AE */ { "CARACTÈRE KATAKANA GI","	: 30AD 3099"},
/* 30AF */ { "CARACTÈRE KATAKANA KU",NULL},
/* 30B0 */ { "CARACTÈRE KATAKANA GU","	: 30AF 3099"},
/* 30B1 */ { "CARACTÈRE KATAKANA KE",NULL},
/* 30B2 */ { "CARACTÈRE KATAKANA GE","	: 30B1 3099"},
/* 30B3 */ { "CARACTÈRE KATAKANA KO",NULL},
/* 30B4 */ { "CARACTÈRE KATAKANA GO","	: 30B3 3099"},
/* 30B5 */ { "CARACTÈRE KATAKANA SA",NULL},
/* 30B6 */ { "CARACTÈRE KATAKANA ZA","	: 30B5 3099"},
/* 30B7 */ { "CARACTÈRE KATAKANA SI","	= chi"},
/* 30B8 */ { "CARACTÈRE KATAKANA ZI","	= dji (pas unique)\n"
	"	: 30B7 3099"},
/* 30B9 */ { "CARACTÈRE KATAKANA SU",NULL},
/* 30BA */ { "CARACTÈRE KATAKANA ZU","	: 30B9 3099"},
/* 30BB */ { "CARACTÈRE KATAKANA SE",NULL},
/* 30BC */ { "CARACTÈRE KATAKANA ZE","	: 30BB 3099"},
/* 30BD */ { "CARACTÈRE KATAKANA SO",NULL},
/* 30BE */ { "CARACTÈRE KATAKANA ZO","	: 30BD 3099"},
/* 30BF */ { "CARACTÈRE KATAKANA TA",NULL},
/* 30C0 */ { "CARACTÈRE KATAKANA DA","	: 30BF 3099"},
/* 30C1 */ { "CARACTÈRE KATAKANA TI","	= tchi"},
/* 30C2 */ { "CARACTÈRE KATAKANA DI","	= dji (pas unique)\n"
	"	: 30C1 3099"},
/* 30C3 */ { "CARACTÈRE KATAKANA PETIT TU","	= petit tsou"},
/* 30C4 */ { "CARACTÈRE KATAKANA TU","	= tsou"},
/* 30C5 */ { "CARACTÈRE KATAKANA DU","	= zou (pas unique)\n"
	"	: 30C4 3099"},
/* 30C6 */ { "CARACTÈRE KATAKANA TE",NULL},
/* 30C7 */ { "CARACTÈRE KATAKANA DE","	: 30C6 3099"},
/* 30C8 */ { "CARACTÈRE KATAKANA TO",NULL},
/* 30C9 */ { "CARACTÈRE KATAKANA DO","	: 30C8 3099"},
/* 30CA */ { "CARACTÈRE KATAKANA NA",NULL},
/* 30CB */ { "CARACTÈRE KATAKANA NI",NULL},
/* 30CC */ { "CARACTÈRE KATAKANA NU",NULL},
/* 30CD */ { "CARACTÈRE KATAKANA NE",NULL},
/* 30CE */ { "CARACTÈRE KATAKANA NO",NULL},
/* 30CF */ { "CARACTÈRE KATAKANA HA",NULL},
/* 30D0 */ { "CARACTÈRE KATAKANA BA","	: 30CF 3099"},
/* 30D1 */ { "CARACTÈRE KATAKANA PA","	: 30CF 309A"},
/* 30D2 */ { "CARACTÈRE KATAKANA HI",NULL},
/* 30D3 */ { "CARACTÈRE KATAKANA BI","	: 30D2 3099"},
/* 30D4 */ { "CARACTÈRE KATAKANA PI","	: 30D2 309A"},
/* 30D5 */ { "CARACTÈRE KATAKANA HU","	= fu, fou"},
/* 30D6 */ { "CARACTÈRE KATAKANA BU","	: 30D5 3099"},
/* 30D7 */ { "CARACTÈRE KATAKANA PU","	: 30D5 309A"},
/* 30D8 */ { "CARACTÈRE KATAKANA HE",NULL},
/* 30D9 */ { "CARACTÈRE KATAKANA BE","	: 30D8 3099"},
/* 30DA */ { "CARACTÈRE KATAKANA PE","	: 30D8 309A"},
/* 30DB */ { "CARACTÈRE KATAKANA HO",NULL},
/* 30DC */ { "CARACTÈRE KATAKANA BO","	: 30DB 3099"},
/* 30DD */ { "CARACTÈRE KATAKANA PO","	: 30DB 309A"},
/* 30DE */ { "CARACTÈRE KATAKANA MA",NULL},
/* 30DF */ { "CARACTÈRE KATAKANA MI",NULL},
/* 30E0 */ { "CARACTÈRE KATAKANA MU",NULL},
/* 30E1 */ { "CARACTÈRE KATAKANA ME",NULL},
/* 30E2 */ { "CARACTÈRE KATAKANA MO",NULL},
/* 30E3 */ { "CARACTÈRE KATAKANA PETIT YA",NULL},
/* 30E4 */ { "CARACTÈRE KATAKANA YA",NULL},
/* 30E5 */ { "CARACTÈRE KATAKANA PETIT YU",NULL},
/* 30E6 */ { "CARACTÈRE KATAKANA YU",NULL},
/* 30E7 */ { "CARACTÈRE KATAKANA PETIT YO",NULL},
/* 30E8 */ { "CARACTÈRE KATAKANA YO",NULL},
/* 30E9 */ { "CARACTÈRE KATAKANA RA",NULL},
/* 30EA */ { "CARACTÈRE KATAKANA RI",NULL},
/* 30EB */ { "CARACTÈRE KATAKANA RU",NULL},
/* 30EC */ { "CARACTÈRE KATAKANA RE",NULL},
/* 30ED */ { "CARACTÈRE KATAKANA RO",NULL},
/* 30EE */ { "CARACTÈRE KATAKANA PETIT WA",NULL},
/* 30EF */ { "CARACTÈRE KATAKANA WA",NULL},
/* 30F0 */ { "CARACTÈRE KATAKANA WI",NULL},
/* 30F1 */ { "CARACTÈRE KATAKANA WE",NULL},
/* 30F2 */ { "CARACTÈRE KATAKANA WO",NULL},
/* 30F3 */ { "CARACTÈRE KATAKANA N",NULL},
/* 30F4 */ { "CARACTÈRE KATAKANA VU","	: 30A6 3099"},
/* 30F5 */ { "CARACTÈRE KATAKANA PETIT KA",NULL},
/* 30F6 */ { "CARACTÈRE KATAKANA PETIT KE",NULL},
/* 30F7 */ { "CARACTÈRE KATAKANA VA","	: 30EF 3099"},
/* 30F8 */ { "CARACTÈRE KATAKANA VI","	: 30F0 3099"},
/* 30F9 */ { "CARACTÈRE KATAKANA VE","	: 30F1 3099"},
/* 30FA */ { "CARACTÈRE KATAKANA VO","	: 30F2 3099"},
/* 30FB */ { "POINT MÉDIAN KATAKANA","	x (point médian - 00B7)"},
/* 30FC */ { "MARQUE KATAKANA-HIRAGANA DE SON PROLONGÉ","	x (tiret cadratin - 2014)"},
/* 30FD */ { "MARQUE D'ITÉRATION KATAKANA",NULL},
/* 30FE */ { "MARQUE D'ITÉRATION VOISÉE KATAKANA","	: 30FD 3099"},
/* 30FF */ { "DIGRAMME KATAKANA KOTO","	* représente une particule nominalisante qui transforme une phrase verbale en un nom abstrait, un peu comme ajouter « le fait de » ou transformer un verbe en infinitif en français\n"
	"	* utilisé autrefois dans des compositions verticales, mais également employé aujourd'hui en disposition horizontale\n"
	"	# <verticale> 30B3 30C8"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_31[] = {
/* 3100 */ { NULL,NULL},
/* 3101 */ { NULL,NULL},
/* 3102 */ { NULL,NULL},
/* 3103 */ { NULL,NULL},
/* 3104 */ { NULL,NULL},
/* 3105 */ { "LETTRE BOPOMOFO B",NULL},
/* 3106 */ { "LETTRE BOPOMOFO P",NULL},
/* 3107 */ { "LETTRE BOPOMOFO M",NULL},
/* 3108 */ { "LETTRE BOPOMOFO F",NULL},
/* 3109 */ { "LETTRE BOPOMOFO D",NULL},
/* 310A */ { "LETTRE BOPOMOFO T",NULL},
/* 310B */ { "LETTRE BOPOMOFO N",NULL},
/* 310C */ { "LETTRE BOPOMOFO L",NULL},
/* 310D */ { "LETTRE BOPOMOFO G",NULL},
/* 310E */ { "LETTRE BOPOMOFO K",NULL},
/* 310F */ { "LETTRE BOPOMOFO H",NULL},
/* 3110 */ { "LETTRE BOPOMOFO J",NULL},
/* 3111 */ { "LETTRE BOPOMOFO Q",NULL},
/* 3112 */ { "LETTRE BOPOMOFO X",NULL},
/* 3113 */ { "LETTRE BOPOMOFO ZH",NULL},
/* 3114 */ { "LETTRE BOPOMOFO CH",NULL},
/* 3115 */ { "LETTRE BOPOMOFO SH",NULL},
/* 3116 */ { "LETTRE BOPOMOFO R",NULL},
/* 3117 */ { "LETTRE BOPOMOFO Z",NULL},
/* 3118 */ { "LETTRE BOPOMOFO C",NULL},
/* 3119 */ { "LETTRE BOPOMOFO S",NULL},
/* 311A */ { "LETTRE BOPOMOFO A",NULL},
/* 311B */ { "LETTRE BOPOMOFO O",NULL},
/* 311C */ { "LETTRE BOPOMOFO E","	= lettre bopomofo ö"},
/* 311D */ { "LETTRE BOPOMOFO Ê",NULL},
/* 311E */ { "LETTRE BOPOMOFO AI",NULL},
/* 311F */ { "LETTRE BOPOMOFO EI",NULL},
/* 3120 */ { "LETTRE BOPOMOFO AO",NULL},
/* 3121 */ { "LETTRE BOPOMOFO OU",NULL},
/* 3122 */ { "LETTRE BOPOMOFO AN",NULL},
/* 3123 */ { "LETTRE BOPOMOFO EN",NULL},
/* 3124 */ { "LETTRE BOPOMOFO ANG",NULL},
/* 3125 */ { "LETTRE BOPOMOFO ENG",NULL},
/* 3126 */ { "LETTRE BOPOMOFO ER",NULL},
/* 3127 */ { "LETTRE BOPOMOFO YI","	* la forme verticale du trait est une variante d'affichage"},
/* 3128 */ { "LETTRE BOPOMOFO WU",NULL},
/* 3129 */ { "LETTRE BOPOMOFO YU",NULL},
/* 312A */ { "LETTRE BOPOMOFO V",NULL},
/* 312B */ { "LETTRE BOPOMOFO NG",NULL},
/* 312C */ { "LETTRE BOPOMOFO NY","	= ñ"},
/* 312D */ { "LETTRE BOPOMOFO IH","	* pour la représentation analytique de la voyelle apicale"},
/* 312E */ { "LETTRE BOPOMOFO O POINT EN CHEF","	* forme primitive de la lettre e"},
/* 312F */ { "LETTRE BOPOMOFO NN","	* nasale syllabique"},
/* 3130 */ { NULL,NULL},
/* 3131 */ { "LETTRE HANGÛL KIYOK","	# 1100 tch'ôsong hangûl kiyok"},
/* 3132 */ { "LETTRE HANGÛL SSANGKIYOK","	# 1101 tch'ôsong hangûl ssangkiyok"},
/* 3133 */ { "LETTRE HANGÛL KIYOK-SIÔS","	# 11AA djôngsong hangûl kiyok-siôs"},
/* 3134 */ { "LETTRE HANGÛL NIÛN","	# 1102 tch'ôsong hangûl niûn"},
/* 3135 */ { "LETTRE HANGÛL NIÛN-TCHIÛTCH","	# 11AC djôngsong hangûl niûn-tchiûtch"},
/* 3136 */ { "LETTRE HANGÛL NIÛN-HIÛH","	# 11AD djôngsong hangûl niûn-hiûh"},
/* 3137 */ { "LETTRE HANGÛL TIKÛT","	# 1103 tch'ôsong hangûl tikût"},
/* 3138 */ { "LETTRE HANGÛL SSANGTIKÛT","	# 1104 tch'ôsong hangûl ssangtikût"},
/* 3139 */ { "LETTRE HANGÛL RIÛL","	# 1105 tch'ôsong hangûl riûl"},
/* 313A */ { "LETTRE HANGÛL RIÛL-KIYOK","	# 11B0 djôngsong hangûl riûl-kiyok"},
/* 313B */ { "LETTRE HANGÛL RIÛL-MIÛM","	# 11B1 djôngsong hangûl riûl-miûm"},
/* 313C */ { "LETTRE HANGÛL RIÛL-PIÛP","	# 11B2 djôngsong hangûl riûl-piûp"},
/* 313D */ { "LETTRE HANGÛL RIÛL-SIÔS","	# 11B3 djôngsong hangûl riûl-siôs"},
/* 313E */ { "LETTRE HANGÛL RIÛL-T'IÛT'","	# 11B4 djôngsong hangûl riûl-t'iût'"},
/* 313F */ { "LETTRE HANGÛL RIÛL-P'IÛP'","	# 11B5 djôngsong hangûl riûl-p'iûp'"},
/* 3140 */ { "LETTRE HANGÛL RIÛL-HIÛH","	# 111A tch'ôsong hangûl riûl-hiûh"},
/* 3141 */ { "LETTRE HANGÛL MIÛM","	# 1106 tch'ôsong hangûl miûm"},
/* 3142 */ { "LETTRE HANGÛL PIÛP","	# 1107 tch'ôsong hangûl piûp"},
/* 3143 */ { "LETTRE HANGÛL SSANGPIÛP","	# 1108 tch'ôsong hangûl ssangpiûp"},
/* 3144 */ { "LETTRE HANGÛL PIÛP-SIÔS","	# 1121 tch'ôsong hangûl piûp-siôs"},
/* 3145 */ { "LETTRE HANGÛL SIÔS","	# 1109 tch'ôsong hangûl siôs"},
/* 3146 */ { "LETTRE HANGÛL SSANGSIÔS","	# 110A tch'ôsong hangûl ssangsiôs"},
/* 3147 */ { "LETTRE HANGÛL IÛNG","	* zéro phonique à l'initiale, consonne nasale vélaire sonore en finale\n"
	"	# 110B tch'ôsong hangûl iûng"},
/* 3148 */ { "LETTRE HANGÛL TCHIÛTCH","	# 110C tch'ôsong hangûl tchiûtch"},
/* 3149 */ { "LETTRE HANGÛL SSANGTCHIÛTCH","	# 110D tch'ôsong hangûl ssangtchiûtch"},
/* 314A */ { "LETTRE HANGÛL TCH'IÛTCH'","	# 110E tch'ôsong hangûl tch'iûtch'"},
/* 314B */ { "LETTRE HANGÛL K'IÛK'","	# 110F tch'ôsong hangûl k'iûk'"},
/* 314C */ { "LETTRE HANGÛL T'IÛT'","	# 1110 tch'ôsong hangûl t'iût'"},
/* 314D */ { "LETTRE HANGÛL P'IÛP'","	# 1111 tch'ôsong hangûl p'iûp'"},
/* 314E */ { "LETTRE HANGÛL HIÛH","	* fricative glottale sourde\n"
	"	# 1112 tch'ôsong hangûl hiûh"},
/* 314F */ { "LETTRE HANGÛL A","	# 1161 djoungsong hangûl a"},
/* 3150 */ { "LETTRE HANGÛL È","	# 1162 djoungsong hangûl è"},
/* 3151 */ { "LETTRE HANGÛL YA","	# 1163 djoungsong hangûl ya"},
/* 3152 */ { "LETTRE HANGÛL YÈ","	# 1164 djoungsong hangûl yè"},
/* 3153 */ { "LETTRE HANGÛL O","	# 1165 djoungsong hangûl o"},
/* 3154 */ { "LETTRE HANGÛL É","	# 1166 djoungsong hangûl é"},
/* 3155 */ { "LETTRE HANGÛL YO","	# 1167 djoungsong hangûl yo"},
/* 3156 */ { "LETTRE HANGÛL YÉ","	# 1168 djoungsong hangûl yé"},
/* 3157 */ { "LETTRE HANGÛL Ô","	# 1169 djoungsong hangûl ô"},
/* 3158 */ { "LETTRE HANGÛL WA","	# 116A djoungsong hangûl wa"},
/* 3159 */ { "LETTRE HANGÛL WÈ","	# 116B djoungsong hangûl wè"},
/* 315A */ { "LETTRE HANGÛL EU","	# 116C djoungsong hangûl eu"},
/* 315B */ { "LETTRE HANGÛL YÔ","	# 116D djoungsong hangûl yô"},
/* 315C */ { "LETTRE HANGÛL OU","	# 116E djoungsong hangûl ou"},
/* 315D */ { "LETTRE HANGÛL WO","	# 116F djoungsong hangûl wo"},
/* 315E */ { "LETTRE HANGÛL WÉ","	# 1170 djoungsong hangûl wé"},
/* 315F */ { "LETTRE HANGÛL WI","	# 1171 djoungsong hangûl wi"},
/* 3160 */ { "LETTRE HANGÛL YOU","	# 1172 djoungsong hangûl you"},
/* 3161 */ { "LETTRE HANGÛL Û","	# 1173 djoungsong hangûl û"},
/* 3162 */ { "LETTRE HANGÛL ÛI","	# 1174 djoungsong hangûl ûi"},
/* 3163 */ { "LETTRE HANGÛL I","	# 1175 djoungsong hangûl i"},
/* 3164 */ { "BOURRE HANGÛL","	= tch'è\n"
	"	# 1160 bourre djoungsong hangûl"},
/* 3165 */ { "LETTRE HANGÛL SSANGNIÛN","	# 1114 tch'ôsong hangûl ssangniûn"},
/* 3166 */ { "LETTRE HANGÛL NIÛN-TIKÛT","	# 1115 tch'ôsong hangûl niûn-tikût"},
/* 3167 */ { "LETTRE HANGÛL NIÛN-SIÔS","	# 11C7 djôngsong hangûl niûn-siôs"},
/* 3168 */ { "LETTRE HANGÛL NIÛN-PANSIÔS","	# 11C8 djôngsong hangûl niûn-pansiôs"},
/* 3169 */ { "LETTRE HANGÛL RIÛL-KIYOK-SIÔS","	# 11CC djôngsong hangûl riûl-kiyok-siôs"},
/* 316A */ { "LETTRE HANGÛL RIÛL-TIKÛT","	# 11CE djôngsong hangûl riûl-tikût"},
/* 316B */ { "LETTRE HANGÛL RIÛL-PIÛP-SIÔS","	# 11D3 djôngsong hangûl riûl-piûp-siôs"},
/* 316C */ { "LETTRE HANGÛL RIÛL-PANSIÔS","	# 11D7 djôngsong hangûl riûl-pansiôs"},
/* 316D */ { "LETTRE HANGÛL RIÛL-YORINHIÛH","	# 11D9 djôngsong hangûl riûl-yorinhiûh"},
/* 316E */ { "LETTRE HANGÛL MIÛM-PIÛP","	# 111C tch'ôsong hangûl miûm-piûp"},
/* 316F */ { "LETTRE HANGÛL MIÛM-SIÔS","	# 11DD djôngsong hangûl miûm-siôs"},
/* 3170 */ { "LETTRE HANGÛL MIÛM-PANSIÔS","	# 11DF djôngsong hangûl miûm-pansiôs"},
/* 3171 */ { "LETTRE HANGÛL KAPYO-OUNMIÛM","	# 111D tch'ôsong hangûl kapyo-ounmiûm"},
/* 3172 */ { "LETTRE HANGÛL PIÛP-KIYOK","	# 111E tch'ôsong hangûl piûp-kiyok"},
/* 3173 */ { "LETTRE HANGÛL PIÛP-TIKÛT","	# 1120 tch'ôsong hangûl piûp-tikût"},
/* 3174 */ { "LETTRE HANGÛL PIÛP-SIÔS-KIYOK","	# 1122 tch'ôsong hangûl piûp-siôs-kiyok"},
/* 3175 */ { "LETTRE HANGÛL PIÛP-SIÔS-TIKÛT","	# 1123 tch'ôsong hangûl piûp-siôs-tikût"},
/* 3176 */ { "LETTRE HANGÛL PIÛP-TCHIÛTCH","	# 1127 tch'ôsong hangûl piûp-tchiûtch"},
/* 3177 */ { "LETTRE HANGÛL PIÛP-T'IÛT'","	# 1129 tch'ôsong hangûl piûp-t'iût'"},
/* 3178 */ { "LETTRE HANGÛL KAPYO-OUNPIÛP","	# 112B tch'ôsong hangûl kapyo-ounpiûp"},
/* 3179 */ { "LETTRE HANGÛL KAPYO-OUNSSANGPIÛP","	# 112C tch'ôsong hangûl kapyo-ounssangpiûp"},
/* 317A */ { "LETTRE HANGÛL SIÔS-KIYOK","	# 112D tch'ôsong hangûl siôs-kiyok"},
/* 317B */ { "LETTRE HANGÛL SIÔS-NIÛN","	# 112E tch'ôsong hangûl siôs-niûn"},
/* 317C */ { "LETTRE HANGÛL SIÔS-TIKÛT","	# 112F tch'ôsong hangûl siôs-tikût"},
/* 317D */ { "LETTRE HANGÛL SIÔS-PIÛP","	# 1132 tch'ôsong hangûl siôs-piûp"},
/* 317E */ { "LETTRE HANGÛL SIÔS-TCHIÛTCH","	# 1136 tch'ôsong hangûl siôs-tchiûtch"},
/* 317F */ { "LETTRE HANGÛL PANSIÔS","	* fricative alvéolaire sonore\n"
	"	# 1140 tch'ôsong hangûl pansiôs"},
/* 3180 */ { "LETTRE HANGÛL SSANGIÛNG","	# 1147 tch'ôsong hangûl ssangiûng"},
/* 3181 */ { "LETTRE HANGÛL YESIÛNG","	* consonne nasale vélaire\n"
	"	# 114C tch'ôsong hangûl yesiûng"},
/* 3182 */ { "LETTRE HANGÛL YESIÛNG-SIÔS","	# 11F1 djôngsong hangûl yesiûng-siôs"},
/* 3183 */ { "LETTRE HANGÛL YESIÛNG-PANSIÔS","	# 11F2 djôngsong hangûl yesiûng-pansiôs"},
/* 3184 */ { "LETTRE HANGÛL KAPYO-OUNP'IÛP'","	# 1157 tch'ôsong hangûl kapyo-ounp'iûp'"},
/* 3185 */ { "LETTRE HANGÛL SSANGHIÛH","	# 1158 tch'ôsong hangûl ssanghiûh"},
/* 3186 */ { "LETTRE HANGÛL YORINHIÛH","	* coup de glotte\n"
	"	# 1159 tch'ôsong hangûl yorinhiûh"},
/* 3187 */ { "LETTRE HANGÛL YÔ-YA","	# 1184 djoungsong hangûl yô-ya"},
/* 3188 */ { "LETTRE HANGÛL YÔ-YÈ","	# 1185 djoungsong hangûl yô-yè"},
/* 3189 */ { "LETTRE HANGÛL YÔ-I","	# 1188 djoungsong hangûl yô-i"},
/* 318A */ { "LETTRE HANGÛL YOU-YO","	# 1191 djoungsong hangûl you-yo"},
/* 318B */ { "LETTRE HANGÛL YOU-YÉ","	# 1192 djoungsong hangûl you-yé"},
/* 318C */ { "LETTRE HANGÛL YOU-I","	# 1194 djoungsong hangûl you-i"},
/* 318D */ { "LETTRE HANGÛL ARÈA","	* voyelle mi-ouverte postérieure arrondie\n"
	"	# 119E djoungsong hangûl arèa"},
/* 318E */ { "LETTRE HANGÛL ARÈÈ","	# 11A1 djoungsong hangûl arèa-i"},
/* 318F */ { NULL,NULL},
/* 3190 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DE LIAISON","	= tatétén"},
/* 3191 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE D'INVERSION","	= kèritén ré"},
/* 3192 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE UN","	# <exp> 4E00"},
/* 3193 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DEUX","	# <exp> 4E8C"},
/* 3194 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE TROIS","	# <exp> 4E09"},
/* 3195 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE QUATRE","	# <exp> 56DB"},
/* 3196 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU HAUT","	# <exp> 4E0A"},
/* 3197 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU CENTRE","	# <exp> 4E2D"},
/* 3198 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU BAS","	# <exp> 4E0B"},
/* 3199 */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU PREMIER","	# <exp> 7532"},
/* 319A */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU SECOND","	# <exp> 4E59"},
/* 319B */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU TROISIÈME","	# <exp> 4E19"},
/* 319C */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU QUATRIÈME","	# <exp> 4E01"},
/* 319D */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DU CIEL","	# <exp> 5929"},
/* 319E */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DE LA TERRE","	# <exp> 5730"},
/* 319F */ { "MARQUE D'ANNOTATION IDÉOGRAPHIQUE DE L'HOMME","	# <exp> 4EBA"},
/* 31A0 */ { "LETTRE BOPOMOFO BU",NULL},
/* 31A1 */ { "LETTRE BOPOMOFO ZI",NULL},
/* 31A2 */ { "LETTRE BOPOMOFO JI",NULL},
/* 31A3 */ { "LETTRE BOPOMOFO GU",NULL},
/* 31A4 */ { "LETTRE BOPOMOFO EE",NULL},
/* 31A5 */ { "LETTRE BOPOMOFO ENN",NULL},
/* 31A6 */ { "LETTRE BOPOMOFO OO",NULL},
/* 31A7 */ { "LETTRE BOPOMOFO ONN",NULL},
/* 31A8 */ { "LETTRE BOPOMOFO IR",NULL},
/* 31A9 */ { "LETTRE BOPOMOFO ANN",NULL},
/* 31AA */ { "LETTRE BOPOMOFO INN",NULL},
/* 31AB */ { "LETTRE BOPOMOFO UNN",NULL},
/* 31AC */ { "LETTRE BOPOMOFO IM",NULL},
/* 31AD */ { "LETTRE BOPOMOFO NGG",NULL},
/* 31AE */ { "LETTRE BOPOMOFO AINN",NULL},
/* 31AF */ { "LETTRE BOPOMOFO AUNN",NULL},
/* 31B0 */ { "LETTRE BOPOMOFO AM",NULL},
/* 31B1 */ { "LETTRE BOPOMOFO OM",NULL},
/* 31B2 */ { "LETTRE BOPOMOFO ONG",NULL},
/* 31B3 */ { "LETTRE BOPOMOFO INNN",NULL},
/* 31B4 */ { "LETTRE BOPOMOFO P FINAL",NULL},
/* 31B5 */ { "LETTRE BOPOMOFO T FINAL",NULL},
/* 31B6 */ { "LETTRE BOPOMOFO K FINAL","	* l'emploi de 31BB est préférable"},
/* 31B7 */ { "LETTRE BOPOMOFO H FINAL",NULL},
/* 31B8 */ { "LETTRE BOPOMOFO GH",NULL},
/* 31B9 */ { "LETTRE BOPOMOFO LH",NULL},
/* 31BA */ { "LETTRE BOPOMOFO ZY",NULL},
/* 31BB */ { "LETTRE BOPOMOFO G FINAL",NULL},
/* 31BC */ { "LETTRE BOPOMOFO GW",NULL},
/* 31BD */ { "LETTRE BOPOMOFO KW",NULL},
/* 31BE */ { "LETTRE BOPOMOFO OE",NULL},
/* 31BF */ { "LETTRE BOPOMOFO AH",NULL},
/* 31C0 */ { "TRAIT CJC T","	* 2e trait de 51B0"},
/* 31C1 */ { "TRAIT CJC WG","	* 2e trait de 72D0"},
/* 31C2 */ { "TRAIT CJC XG","	* 5e trait de 6211"},
/* 31C3 */ { "TRAIT CJC BXG","	* n'apparaît que dans les polices de caractères de style kaiti\n"
	"	* équivalent au trait SWG dans les polices de caractères de style songti\n"
	"	* 2e trait de 5FC3"},
/* 31C4 */ { "TRAIT CJC SW","	* 3e trait de 4EA1\n"
	"	* 4e trait de 56DB"},
/* 31C5 */ { "TRAIT CJC HZZ","	* 1er trait de 534D"},
/* 31C6 */ { "TRAIT CJC HZG","	* 1er trait de 7FBD\n"
	"	* 1er trait de 4E5F"},
/* 31C7 */ { "TRAIT CJC HP","	* 1er trait de 53C8\n"
	"	* 4e trait de 4ECA"},
/* 31C8 */ { "TRAIT CJC HZWG","	* 2e trait de 4E5D"},
/* 31C9 */ { "TRAIT CJC SZWG","	* 3e trait de 5F13\n"
	"	* 2e trait de 9A6C"},
/* 31CA */ { "TRAIT CJC HZT","	* 2e trait de 8BA1\n"
	"	* 2e trait de 9CE9"},
/* 31CB */ { "TRAIT CJC HZZP","	* 1er trait de 53CA"},
/* 31CC */ { "TRAIT CJC HPWG","	* 1er trait de 961D\n"
	"	* 6e trait de 90AE"},
/* 31CD */ { "TRAIT CJC HZW","	* 5e trait de 6295"},
/* 31CE */ { "TRAIT CJC HZZZ","	* 1er trait de 51F8"},
/* 31CF */ { "TRAIT CJC N","	* 3e trait de 5927"},
/* 31D0 */ { "TRAIT CJC H","	* 1er trait de 5927\n"
	"	* 1er trait de 4E03"},
/* 31D1 */ { "TRAIT CJC S","	* 4e trait de 4E2D"},
/* 31D2 */ { "TRAIT CJC P","	* 1er trait de 4E4F"},
/* 31D3 */ { "TRAIT CJC SP","	* 1er trait de 6708"},
/* 31D4 */ { "TRAIT CJC D","	* 3e trait de 4E38"},
/* 31D5 */ { "TRAIT CJC HZ","	* 2e trait de 56DB"},
/* 31D6 */ { "TRAIT CJC HG","	* 1er trait de 758B\n"
	"	* 1er trait de 5B50"},
/* 31D7 */ { "TRAIT CJC SZ","	* 2e trait de 5C71\n"
	"	* 2e trait de 4E1C"},
/* 31D8 */ { "TRAIT CJC SWZ","	* 6e trait de 8085"},
/* 31D9 */ { "TRAIT CJC ST","	* 3e trait de 6C11"},
/* 31DA */ { "TRAIT CJC SG","	* 1er trait de 6C34"},
/* 31DB */ { "TRAIT CJC PD","	* 1er trait de 5DE1\n"
	"	* 1er trait de 5973"},
/* 31DC */ { "TRAIT CJC PZ","	* 3e trait de 516C\n"
	"	* 4e trait de 5F18"},
/* 31DD */ { "TRAIT CJC TN","	* 8e trait de 5EFB"},
/* 31DE */ { "TRAIT CJC SZZ","	* 1er trait de 5350\n"
	"	* 4e trait de 4E9E"},
/* 31DF */ { "TRAIT CJC SWG","	* 7e trait de 4E71\n"
	"	* 3e trait de 5DF1"},
/* 31E0 */ { "TRAIT CJC HXWG","	* 1er trait de 4E59"},
/* 31E1 */ { "TRAIT CJC HZZZG","	* 1er trait de 4E43"},
/* 31E2 */ { "TRAIT CJC PG","	* 1er trait de 4E44"},
/* 31E3 */ { "TRAIT CJC Q","	* 6e trait de 3514"},
/* 31E4 */ { "TRAIT CJC HXG","	* 1er trait de 98DE"},
/* 31E5 */ { "TRAIT CJC SZP","	* 8e trait de 594A"},
/* 31E6 */ { NULL,NULL},
/* 31E7 */ { NULL,NULL},
/* 31E8 */ { NULL,NULL},
/* 31E9 */ { NULL,NULL},
/* 31EA */ { NULL,NULL},
/* 31EB */ { NULL,NULL},
/* 31EC */ { NULL,NULL},
/* 31ED */ { NULL,NULL},
/* 31EE */ { NULL,NULL},
/* 31EF */ { "CARACTÈRE DE DESCRIPTION IDÉOGRAPHIQUE SOUSTRACTION","	* utilisé pour décrire un caractère ou un composant dont un trait (ou un autre composant) a été retiré"},
/* 31F0 */ { "CARACTÈRE KATAKANA PETIT KU",NULL},
/* 31F1 */ { "CARACTÈRE KATAKANA PETIT SI",NULL},
/* 31F2 */ { "CARACTÈRE KATAKANA PETIT SU",NULL},
/* 31F3 */ { "CARACTÈRE KATAKANA PETIT TO",NULL},
/* 31F4 */ { "CARACTÈRE KATAKANA PETIT NU",NULL},
/* 31F5 */ { "CARACTÈRE KATAKANA PETIT HA",NULL},
/* 31F6 */ { "CARACTÈRE KATAKANA PETIT HI",NULL},
/* 31F7 */ { "CARACTÈRE KATAKANA PETIT HU",NULL},
/* 31F8 */ { "CARACTÈRE KATAKANA PETIT HE",NULL},
/* 31F9 */ { "CARACTÈRE KATAKANA PETIT HO",NULL},
/* 31FA */ { "CARACTÈRE KATAKANA PETIT MU",NULL},
/* 31FB */ { "CARACTÈRE KATAKANA PETIT RA",NULL},
/* 31FC */ { "CARACTÈRE KATAKANA PETIT RI",NULL},
/* 31FD */ { "CARACTÈRE KATAKANA PETIT RU",NULL},
/* 31FE */ { "CARACTÈRE KATAKANA PETIT RE",NULL},
/* 31FF */ { "CARACTÈRE KATAKANA PETIT RO",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_32[] = {
/* 3200 */ { "KIYOK HANGÛL ENTRE PARENTHÈSES","	# 0028 1100 0029"},
/* 3201 */ { "NIÛN HANGÛL ENTRE PARENTHÈSES","	# 0028 1102 0029"},
/* 3202 */ { "TIKÛT HANGÛL ENTRE PARENTHÈSES","	# 0028 1103 0029"},
/* 3203 */ { "RIÛL HANGÛL ENTRE PARENTHÈSES","	# 0028 1105 0029"},
/* 3204 */ { "MIÛM HANGÛL ENTRE PARENTHÈSES","	# 0028 1106 0029"},
/* 3205 */ { "PIÛP HANGÛL ENTRE PARENTHÈSES","	# 0028 1107 0029"},
/* 3206 */ { "SIÔS HANGÛL ENTRE PARENTHÈSES","	# 0028 1109 0029"},
/* 3207 */ { "IÛNG HANGÛL ENTRE PARENTHÈSES","	# 0028 110B 0029"},
/* 3208 */ { "TCHIÛTCH HANGÛL ENTRE PARENTHÈSES","	# 0028 110C 0029"},
/* 3209 */ { "TCH'IÛTCH' HANGÛL ENTRE PARENTHÈSES","	# 0028 110E 0029"},
/* 320A */ { "K'IÛK' HANGÛL ENTRE PARENTHÈSES","	# 0028 110F 0029"},
/* 320B */ { "T'IÛT' HANGÛL ENTRE PARENTHÈSES","	# 0028 1110 0029"},
/* 320C */ { "P'IÛP' HANGÛL ENTRE PARENTHÈSES","	# 0028 1111 0029"},
/* 320D */ { "HIÛH HANGÛL ENTRE PARENTHÈSES","	# 0028 1112 0029"},
/* 320E */ { "KIYOK A HANGÛL ENTRE PARENTHÈSES","	# 0028 1100 1161 0029"},
/* 320F */ { "NIÛN A HANGÛL ENTRE PARENTHÈSES","	# 0028 1102 1161 0029"},
/* 3210 */ { "TIKÛT A HANGÛL ENTRE PARENTHÈSES","	# 0028 1103 1161 0029"},
/* 3211 */ { "RIÛL A HANGÛL ENTRE PARENTHÈSES","	# 0028 1105 1161 0029"},
/* 3212 */ { "MIÛM A HANGÛL ENTRE PARENTHÈSES","	# 0028 1106 1161 0029"},
/* 3213 */ { "PIÛP A HANGÛL ENTRE PARENTHÈSES","	# 0028 1107 1161 0029"},
/* 3214 */ { "SIÔS A HANGÛL ENTRE PARENTHÈSES","	# 0028 1109 1161 0029"},
/* 3215 */ { "IÛNG A HANGÛL ENTRE PARENTHÈSES","	# 0028 110B 1161 0029"},
/* 3216 */ { "TCHIÛTCH A HANGÛL ENTRE PARENTHÈSES","	# 0028 110C 1161 0029"},
/* 3217 */ { "TCH'IÛTCH' A HANGÛL ENTRE PARENTHÈSES","	# 0028 110E 1161 0029"},
/* 3218 */ { "K'IÛK' A HANGÛL ENTRE PARENTHÈSES","	# 0028 110F 1161 0029"},
/* 3219 */ { "T'IÛT' A HANGÛL ENTRE PARENTHÈSES","	# 0028 1110 1161 0029"},
/* 321A */ { "P'IÛP' A HANGÛL ENTRE PARENTHÈSES","	# 0028 1111 1161 0029"},
/* 321B */ { "HIÛH A HANGÛL ENTRE PARENTHÈSES","	# 0028 1112 1161 0029"},
/* 321C */ { "TCHIÛTCH OU HANGÛL ENTRE PARENTHÈSES","	# 0028 110C 116E 0029"},
/* 321D */ { "CARACTÈRE CORÉEN Ô TCHON ENTRE PARENTHÈSES","	# 0028 110B 1169 110C 1165 11AB 0029"},
/* 321E */ { "CARACTÈRE CORÉEN Ô HOU ENTRE PARENTHÈSES","	* l'orthographe recommandée pour le nom est ôhou\n"
	"	# 0028 110B 1169 1112 116E 0029"},
/* 321F */ { NULL,NULL},
/* 3220 */ { "IDÉOGRAMME UN ENTRE PARENTHÈSES","	# 0028 4E00 0029"},
/* 3221 */ { "IDÉOGRAMME DEUX ENTRE PARENTHÈSES","	# 0028 4E8C 0029"},
/* 3222 */ { "IDÉOGRAMME TROIS ENTRE PARENTHÈSES","	# 0028 4E09 0029"},
/* 3223 */ { "IDÉOGRAMME QUATRE ENTRE PARENTHÈSES","	# 0028 56DB 0029"},
/* 3224 */ { "IDÉOGRAMME CINQ ENTRE PARENTHÈSES","	# 0028 4E94 0029"},
/* 3225 */ { "IDÉOGRAMME SIX ENTRE PARENTHÈSES","	# 0028 516D 0029"},
/* 3226 */ { "IDÉOGRAMME SEPT ENTRE PARENTHÈSES","	# 0028 4E03 0029"},
/* 3227 */ { "IDÉOGRAMME HUIT ENTRE PARENTHÈSES","	# 0028 516B 0029"},
/* 3228 */ { "IDÉOGRAMME NEUF ENTRE PARENTHÈSES","	# 0028 4E5D 0029"},
/* 3229 */ { "IDÉOGRAMME DIX ENTRE PARENTHÈSES","	# 0028 5341 0029"},
/* 322A */ { "IDÉOGRAMME LUNE ENTRE PARENTHÈSES","	* lundi\n"
	"	# 0028 6708 0029"},
/* 322B */ { "IDÉOGRAMME FEU ENTRE PARENTHÈSES","	* mardi\n"
	"	# 0028 706B 0029"},
/* 322C */ { "IDÉOGRAMME EAU ENTRE PARENTHÈSES","	* mercredi\n"
	"	# 0028 6C34 0029"},
/* 322D */ { "IDÉOGRAMME BOIS ENTRE PARENTHÈSES","	* jeudi\n"
	"	# 0028 6728 0029"},
/* 322E */ { "IDÉOGRAMME MÉTAL ENTRE PARENTHÈSES","	* vendredi\n"
	"	# 0028 91D1 0029"},
/* 322F */ { "IDÉOGRAMME TERRE ENTRE PARENTHÈSES","	* samedi\n"
	"	# 0028 571F 0029"},
/* 3230 */ { "IDÉOGRAMME SOLEIL ENTRE PARENTHÈSES","	* dimanche\n"
	"	# 0028 65E5 0029"},
/* 3231 */ { "IDÉOGRAMME MARCHANDISES ENTRE PARENTHÈSES","	* société enregistrée, société anonyme\n"
	"	# 0028 682A 0029"},
/* 3232 */ { "IDÉOGRAMME AVOIR ENTRE PARENTHÈSES","	* à responsabilité limitée\n"
	"	# 0028 6709 0029"},
/* 3233 */ { "IDÉOGRAMME SOCIÉTÉ ENTRE PARENTHÈSES","	* société\n"
	"	# 0028 793E 0029"},
/* 3234 */ { "IDÉOGRAMME NOM ENTRE PARENTHÈSES","	# 0028 540D 0029"},
/* 3235 */ { "IDÉOGRAMME SPÉCIAL ENTRE PARENTHÈSES","	# 0028 7279 0029"},
/* 3236 */ { "IDÉOGRAMME FINANCIER ENTRE PARENTHÈSES","	# 0028 8CA1 0029"},
/* 3237 */ { "IDÉOGRAMME FÉLICITATIONS ENTRE PARENTHÈSES","	# 0028 795D 0029"},
/* 3238 */ { "IDÉOGRAMME TRAVAIL ENTRE PARENTHÈSES","	# 0028 52B4 0029"},
/* 3239 */ { "IDÉOGRAMME REPRÉSENTE ENTRE PARENTHÈSES","	# 0028 4EE3 0029"},
/* 323A */ { "IDÉOGRAMME APPEL ENTRE PARENTHÈSES","	# 0028 547C 0029"},
/* 323B */ { "IDÉOGRAMME ÉTUDE ENTRE PARENTHÈSES","	# 0028 5B66 0029"},
/* 323C */ { "IDÉOGRAMME SUPERVISE ENTRE PARENTHÈSES","	# 0028 76E3 0029"},
/* 323D */ { "IDÉOGRAMME ENTREPRISE ENTRE PARENTHÈSES","	# 0028 4F01 0029"},
/* 323E */ { "IDÉOGRAMME RESSOURCE ENTRE PARENTHÈSES","	# 0028 8CC7 0029"},
/* 323F */ { "IDÉOGRAMME ALLIANCE ENTRE PARENTHÈSES","	# 0028 5354 0029"},
/* 3240 */ { "IDÉOGRAMME FESTIVAL ENTRE PARENTHÈSES","	# 0028 796D 0029"},
/* 3241 */ { "IDÉOGRAMME REPOS ENTRE PARENTHÈSES","	# 0028 4F11 0029"},
/* 3242 */ { "IDÉOGRAMME SOI ENTRE PARENTHÈSES","	* expéditeur\n"
	"	# 0028 81EA 0029"},
/* 3243 */ { "IDÉOGRAMME ATTEINDRE ENTRE PARENTHÈSES","	* destinataire\n"
	"	# 0028 81F3 0029"},
/* 3244 */ { "IDÉOGRAMME CERCLÉ QUESTION","	# <cerclée> 554F"},
/* 3245 */ { "IDÉOGRAMME CERCLÉ MATERNELLE","	# <cerclée> 5E7C"},
/* 3246 */ { "IDÉOGRAMME CERCLÉ ÉCOLE","	# <cerclée> 6587"},
/* 3247 */ { "IDÉOGRAMME CERCLÉ KOTO","	# <cerclée> 7B8F"},
/* 3248 */ { "NOMBRE DIX CERCLÉ SUR CARRÉ NOIR","	= limite de vitesse 10 km/h"},
/* 3249 */ { "NOMBRE VINGT CERCLÉ SUR CARRÉ NOIR","	= limite de vitesse 20 km/h"},
/* 324A */ { "NOMBRE TRENTE CERCLÉ SUR CARRÉ NOIR","	= limite de vitesse 30 km/h"},
/* 324B */ { "NOMBRE QUARANTE CERCLÉ SUR CARRÉ NOIR","	= limite de vitesse 40 km/h"},
/* 324C */ { "NOMBRE CINQUANTE CERCLÉ SUR CARRÉ NOIR","	= limite de vitesse 50 km/h"},
/* 324D */ { "NOMBRE SOIXANTE CERCLÉ SUR CARRÉ NOIR","	= limite de vitesse 60 km/h"},
/* 324E */ { "NOMBRE SOIXANTE-DIX CERCLÉ SUR CARRÉ NOIR","	= nombre septante cerclé sur carré noir\n"
	"	= limite de vitesse 70 km/h"},
/* 324F */ { "NOMBRE QUATRE-VINGTS CERCLÉ SUR CARRÉ NOIR","	= nombre huitante cerclé sur carré noir\n"
	"	= limite de vitesse 80 km/h"},
/* 3250 */ { "SYMBOLE PARTENARIAT","	# <enCarré> 0050 0054 0045"},
/* 3251 */ { "NOMBRE VINGT ET UN CERCLÉ","	# <cerclée> 0032 0031"},
/* 3252 */ { "NOMBRE VINGT-DEUX CERCLÉ","	# <cerclée> 0032 0032"},
/* 3253 */ { "NOMBRE VINGT-TROIS CERCLÉ","	# <cerclée> 0032 0033"},
/* 3254 */ { "NOMBRE VINGT-QUATRE CERCLÉ","	# <cerclée> 0032 0034"},
/* 3255 */ { "NOMBRE VINGT-CINQ CERCLÉ","	# <cerclée> 0032 0035"},
/* 3256 */ { "NOMBRE VINGT-SIX CERCLÉ","	# <cerclée> 0032 0036"},
/* 3257 */ { "NOMBRE VINGT-SEPT CERCLÉ","	# <cerclée> 0032 0037"},
/* 3258 */ { "NOMBRE VINGT-HUIT CERCLÉ","	# <cerclée> 0032 0038"},
/* 3259 */ { "NOMBRE VINGT-NEUF CERCLÉ","	# <cerclée> 0032 0039"},
/* 325A */ { "NOMBRE TRENTE CERCLÉ","	# <cerclée> 0033 0030"},
/* 325B */ { "NOMBRE TRENTE ET UN CERCLÉ","	# <cerclée> 0033 0031"},
/* 325C */ { "NOMBRE TRENTE-DEUX CERCLÉ","	# <cerclée> 0033 0032"},
/* 325D */ { "NOMBRE TRENTE-TROIS CERCLÉ","	# <cerclée> 0033 0033"},
/* 325E */ { "NOMBRE TRENTE-QUATRE CERCLÉ","	# <cerclée> 0033 0034"},
/* 325F */ { "NOMBRE TRENTE-CINQ CERCLÉ","	# <cerclée> 0033 0035"},
/* 3260 */ { "KIYOK HANGÛL CERCLÉ","	# <cerclée> 1100"},
/* 3261 */ { "NIÛN HANGÛL CERCLÉ","	# <cerclée> 1102"},
/* 3262 */ { "TIKÛT HANGÛL CERCLÉ","	# <cerclée> 1103"},
/* 3263 */ { "RIÛL HANGÛL CERCLÉ","	# <cerclée> 1105"},
/* 3264 */ { "MIÛM HANGÛL CERCLÉ","	# <cerclée> 1106"},
/* 3265 */ { "PIÛP HANGÛL CERCLÉ","	# <cerclée> 1107"},
/* 3266 */ { "SIÔS HANGÛL CERCLÉ","	# <cerclée> 1109"},
/* 3267 */ { "IÛNG HANGÛL CERCLÉ","	# <cerclée> 110B"},
/* 3268 */ { "TCHIÛTCH HANGÛL CERCLÉ","	# <cerclée> 110C"},
/* 3269 */ { "TCH'IÛTCH' HANGÛL CERCLÉ","	# <cerclée> 110E"},
/* 326A */ { "K'IÛK' HANGÛL CERCLÉ","	# <cerclée> 110F"},
/* 326B */ { "T'IÛT' HANGÛL CERCLÉ","	# <cerclée> 1110"},
/* 326C */ { "P'IÛP' HANGÛL CERCLÉ","	# <cerclée> 1111"},
/* 326D */ { "HIÛH HANGÛL CERCLÉ","	# <cerclée> 1112"},
/* 326E */ { "KIYOK A HANGÛL CERCLÉ","	# <cerclée> 1100 1161"},
/* 326F */ { "NIÛN A HANGÛL CERCLÉ","	# <cerclée> 1102 1161"},
/* 3270 */ { "TIKÛT A HANGÛL CERCLÉ","	# <cerclée> 1103 1161"},
/* 3271 */ { "RIÛL A HANGÛL CERCLÉ","	# <cerclée> 1105 1161"},
/* 3272 */ { "MIÛM A HANGÛL CERCLÉ","	# <cerclée> 1106 1161"},
/* 3273 */ { "PIÛP A HANGÛL CERCLÉ","	# <cerclée> 1107 1161"},
/* 3274 */ { "SIÔS A HANGÛL CERCLÉ","	# <cerclée> 1109 1161"},
/* 3275 */ { "IÛNG A HANGÛL CERCLÉ","	# <cerclée> 110B 1161"},
/* 3276 */ { "TCHIÛTCH A HANGÛL CERCLÉ","	# <cerclée> 110C 1161"},
/* 3277 */ { "TCH'IÛTCH' A HANGÛL CERCLÉ","	# <cerclée> 110E 1161"},
/* 3278 */ { "K'IÛK' A HANGÛL CERCLÉ","	# <cerclée> 110F 1161"},
/* 3279 */ { "T'IÛT' A HANGÛL CERCLÉ","	# <cerclée> 1110 1161"},
/* 327A */ { "P'IÛP' A HANGÛL CERCLÉ","	# <cerclée> 1111 1161"},
/* 327B */ { "HIÛH A HANGÛL CERCLÉ","	# <cerclée> 1112 1161"},
/* 327C */ { "CARACTÈRE CORÉEN CERCLÉ TCH'AMKÔ","	# <cerclée> 110E 1161 11B7 1100 1169"},
/* 327D */ { "CARACTÈRE CORÉEN CERCLÉ TCHOUÛI","	# <cerclée> 110C 116E 110B 1174"},
/* 327E */ { "IÛNG OU HANGÛL CERCLÉ","	* symbole de code postal\n"
	"	# <cerclée> 110B 116E"},
/* 327F */ { "SYMBOLE DE NORME CORÉENNE",NULL},
/* 3280 */ { "IDÉOGRAMME UN CERCLÉ","	= marou-iti, symbole d'unification\n"
	"	# <cerclée> 4E00"},
/* 3281 */ { "IDÉOGRAMME DEUX CERCLÉ","	# <cerclée> 4E8C"},
/* 3282 */ { "IDÉOGRAMME TROIS CERCLÉ","	# <cerclée> 4E09"},
/* 3283 */ { "IDÉOGRAMME QUATRE CERCLÉ","	# <cerclée> 56DB"},
/* 3284 */ { "IDÉOGRAMME CINQ CERCLÉ","	# <cerclée> 4E94"},
/* 3285 */ { "IDÉOGRAMME SIX CERCLÉ","	# <cerclée> 516D"},
/* 3286 */ { "IDÉOGRAMME SEPT CERCLÉ","	# <cerclée> 4E03"},
/* 3287 */ { "IDÉOGRAMME HUIT CERCLÉ","	# <cerclée> 516B"},
/* 3288 */ { "IDÉOGRAMME NEUF CERCLÉ","	# <cerclée> 4E5D"},
/* 3289 */ { "IDÉOGRAMME DIX CERCLÉ","	# <cerclée> 5341"},
/* 328A */ { "IDÉOGRAMME LUNE CERCLÉ","	* lundi\n"
	"	# <cerclée> 6708"},
/* 328B */ { "IDÉOGRAMME FEU CERCLÉ","	* mardi\n"
	"	# <cerclée> 706B"},
/* 328C */ { "IDÉOGRAMME EAU CERCLÉ","	* mercredi\n"
	"	# <cerclée> 6C34"},
/* 328D */ { "IDÉOGRAMME BOIS CERCLÉ","	* jeudi\n"
	"	# <cerclée> 6728"},
/* 328E */ { "IDÉOGRAMME MÉTAL CERCLÉ","	* vendredi\n"
	"	# <cerclée> 91D1"},
/* 328F */ { "IDÉOGRAMME TERRE CERCLÉ","	* samedi\n"
	"	# <cerclée> 571F"},
/* 3290 */ { "IDÉOGRAMME SOLEIL CERCLÉ","	* dimanche\n"
	"	# <cerclée> 65E5"},
/* 3291 */ { "IDÉOGRAMME MARCHANDISES CERCLÉ","	# <cerclée> 682A"},
/* 3292 */ { "IDÉOGRAMME AVOIR CERCLÉ","	* à responsabilité limitée\n"
	"	# <cerclée> 6709"},
/* 3293 */ { "IDÉOGRAMME SOCIÉTÉ CERCLÉ","	* société\n"
	"	# <cerclée> 793E"},
/* 3294 */ { "IDÉOGRAMME NOM CERCLÉ","	# <cerclée> 540D"},
/* 3295 */ { "IDÉOGRAMME SPÉCIAL CERCLÉ","	# <cerclée> 7279"},
/* 3296 */ { "IDÉOGRAMME FINANCIER CERCLÉ","	# <cerclée> 8CA1"},
/* 3297 */ { "IDÉOGRAMME FÉLICITATIONS CERCLÉ","	# <cerclée> 795D"},
/* 3298 */ { "IDÉOGRAMME TRAVAIL CERCLÉ","	# <cerclée> 52B4"},
/* 3299 */ { "IDÉOGRAMME SECRET CERCLÉ","	# <cerclée> 79D8"},
/* 329A */ { "IDÉOGRAMME MÂLE CERCLÉ","	# <cerclée> 7537"},
/* 329B */ { "IDÉOGRAMME FEMELLE CERCLÉ","	# <cerclée> 5973"},
/* 329C */ { "IDÉOGRAMME ACCEPTABLE CERCLÉ","	# <cerclée> 9069"},
/* 329D */ { "IDÉOGRAMME EXCELLENT CERCLÉ","	# <cerclée> 512A"},
/* 329E */ { "IDÉOGRAMME IMPRIMER CERCLÉ","	* posez ici votre sceau\n"
	"	# <cerclée> 5370"},
/* 329F */ { "IDÉOGRAMME ATTENTION CERCLÉ","	# <cerclée> 6CE8"},
/* 32A0 */ { "IDÉOGRAMME ARTICLE CERCLÉ","	# <cerclée> 9805"},
/* 32A1 */ { "IDÉOGRAMME REPOS CERCLÉ","	* férié\n"
	"	# <cerclée> 4F11"},
/* 32A2 */ { "IDÉOGRAMME COPIE CERCLÉ","	# <cerclée> 5199"},
/* 32A3 */ { "IDÉOGRAMME CORRECT CERCLÉ","	# <cerclée> 6B63"},
/* 32A4 */ { "IDÉOGRAMME HAUT CERCLÉ","	# <cerclée> 4E0A"},
/* 32A5 */ { "IDÉOGRAMME CENTRE CERCLÉ","	# <cerclée> 4E2D"},
/* 32A6 */ { "IDÉOGRAMME BAS CERCLÉ","	# <cerclée> 4E0B"},
/* 32A7 */ { "IDÉOGRAMME GAUCHE CERCLÉ","	# <cerclée> 5DE6"},
/* 32A8 */ { "IDÉOGRAMME DROIT CERCLÉ","	# <cerclée> 53F3"},
/* 32A9 */ { "IDÉOGRAMME MÉDECINE CERCLÉ","	# <cerclée> 533B"},
/* 32AA */ { "IDÉOGRAMME RELIGION CERCLÉ","	# <cerclée> 5B97"},
/* 32AB */ { "IDÉOGRAMME ÉTUDE CERCLÉ","	# <cerclée> 5B66"},
/* 32AC */ { "IDÉOGRAMME SUPERVISER CERCLÉ","	# <cerclée> 76E3"},
/* 32AD */ { "IDÉOGRAMME ENTREPRISE CERCLÉ","	# <cerclée> 4F01"},
/* 32AE */ { "IDÉOGRAMME RESSOURCE CERCLÉ","	# <cerclée> 8CC7"},
/* 32AF */ { "IDÉOGRAMME ALLIANCE CERCLÉ","	# <cerclée> 5354"},
/* 32B0 */ { "IDÉOGRAMME NUIT CERCLÉ","	# <cerclée> 591C"},
/* 32B1 */ { "NOMBRE TRENTE-SIX CERCLÉ","	# <cerclée> 0033 0036"},
/* 32B2 */ { "NOMBRE TRENTE-SEPT CERCLÉ","	# <cerclée> 0033 0037"},
/* 32B3 */ { "NOMBRE TRENTE-HUIT CERCLÉ","	# <cerclée> 0033 0038"},
/* 32B4 */ { "NOMBRE TRENTE-NEUF CERCLÉ","	# <cerclée> 0033 0039"},
/* 32B5 */ { "NOMBRE QUARANTE CERCLÉ","	# <cerclée> 0034 0030"},
/* 32B6 */ { "NOMBRE QUARANTE ET UN CERCLÉ","	# <cerclée> 0034 0031"},
/* 32B7 */ { "NOMBRE QUARANTE-DEUX CERCLÉ","	# <cerclée> 0034 0032"},
/* 32B8 */ { "NOMBRE QUARANTE-TROIS CERCLÉ","	# <cerclée> 0034 0033"},
/* 32B9 */ { "NOMBRE QUARANTE-QUATRE CERCLÉ","	# <cerclée> 0034 0034"},
/* 32BA */ { "NOMBRE QUARANTE-CINQ CERCLÉ","	# <cerclée> 0034 0035"},
/* 32BB */ { "NOMBRE QUARANTE-SIX CERCLÉ","	# <cerclée> 0034 0036"},
/* 32BC */ { "NOMBRE QUARANTE-SEPT CERCLÉ","	# <cerclée> 0034 0037"},
/* 32BD */ { "NOMBRE QUARANTE-HUIT CERCLÉ","	# <cerclée> 0034 0038"},
/* 32BE */ { "NOMBRE QUARANTE-NEUF CERCLÉ","	# <cerclée> 0034 0039"},
/* 32BF */ { "NOMBRE CINQUANTE CERCLÉ","	# <cerclée> 0035 0030"},
/* 32C0 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JANVIER","	# 0031 6708"},
/* 32C1 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE FÉVRIER","	# 0032 6708"},
/* 32C2 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE MARS","	# 0033 6708"},
/* 32C3 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE AVRIL","	# 0034 6708"},
/* 32C4 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE MAI","	# 0035 6708"},
/* 32C5 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JUIN","	# 0036 6708"},
/* 32C6 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JUILLET","	# 0037 6708"},
/* 32C7 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE AOÛT","	# 0038 6708"},
/* 32C8 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE SEPTEMBRE","	# 0039 6708"},
/* 32C9 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE OCTOBRE","	# 0031 0030 6708"},
/* 32CA */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE NOVEMBRE","	# 0031 0031 6708"},
/* 32CB */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE DÉCEMBRE","	# 0031 0032 6708"},
/* 32CC */ { "HG DISPOSÉ EN CARRÉ","	# <enCarré> 0048 0067"},
/* 32CD */ { "ERG DISPOSÉ EN CARRÉ","	# <enCarré> 0065 0072 0067"},
/* 32CE */ { "EV DISPOSÉ EN CARRÉ","	# <enCarré> 0065 0056"},
/* 32CF */ { "RESPONSABILITÉ LIMITÉE DISPOSÉ EN CARRÉ","	# <enCarré> 004C 0054 0044"},
/* 32D0 */ { "KATAKANA CERCLÉ A","	# <cerclée> 30A2"},
/* 32D1 */ { "KATAKANA CERCLÉ I","	# <cerclée> 30A4"},
/* 32D2 */ { "KATAKANA CERCLÉ U","	# <cerclée> 30A6"},
/* 32D3 */ { "KATAKANA CERCLÉ E","	# <cerclée> 30A8"},
/* 32D4 */ { "KATAKANA CERCLÉ O","	# <cerclée> 30AA"},
/* 32D5 */ { "KATAKANA CERCLÉ KA","	# <cerclée> 30AB"},
/* 32D6 */ { "KATAKANA CERCLÉ KI","	# <cerclée> 30AD"},
/* 32D7 */ { "KATAKANA CERCLÉ KU","	# <cerclée> 30AF"},
/* 32D8 */ { "KATAKANA CERCLÉ KE","	# <cerclée> 30B1"},
/* 32D9 */ { "KATAKANA CERCLÉ KO","	# <cerclée> 30B3"},
/* 32DA */ { "KATAKANA CERCLÉ SA","	# <cerclée> 30B5"},
/* 32DB */ { "KATAKANA CERCLÉ SI","	# <cerclée> 30B7"},
/* 32DC */ { "KATAKANA CERCLÉ SU","	# <cerclée> 30B9"},
/* 32DD */ { "KATAKANA CERCLÉ SE","	# <cerclée> 30BB"},
/* 32DE */ { "KATAKANA CERCLÉ SO","	# <cerclée> 30BD"},
/* 32DF */ { "KATAKANA CERCLÉ TA","	# <cerclée> 30BF"},
/* 32E0 */ { "KATAKANA CERCLÉ TI","	# <cerclée> 30C1"},
/* 32E1 */ { "KATAKANA CERCLÉ TU","	# <cerclée> 30C4"},
/* 32E2 */ { "KATAKANA CERCLÉ TE","	# <cerclée> 30C6"},
/* 32E3 */ { "KATAKANA CERCLÉ TO","	# <cerclée> 30C8"},
/* 32E4 */ { "KATAKANA CERCLÉ NA","	# <cerclée> 30CA"},
/* 32E5 */ { "KATAKANA CERCLÉ NI","	# <cerclée> 30CB"},
/* 32E6 */ { "KATAKANA CERCLÉ NU","	# <cerclée> 30CC"},
/* 32E7 */ { "KATAKANA CERCLÉ NE","	# <cerclée> 30CD"},
/* 32E8 */ { "KATAKANA CERCLÉ NO","	# <cerclée> 30CE"},
/* 32E9 */ { "KATAKANA CERCLÉ HA","	# <cerclée> 30CF"},
/* 32EA */ { "KATAKANA CERCLÉ HI","	# <cerclée> 30D2"},
/* 32EB */ { "KATAKANA CERCLÉ HU","	# <cerclée> 30D5"},
/* 32EC */ { "KATAKANA CERCLÉ HE","	# <cerclée> 30D8"},
/* 32ED */ { "KATAKANA CERCLÉ HO","	# <cerclée> 30DB"},
/* 32EE */ { "KATAKANA CERCLÉ MA","	# <cerclée> 30DE"},
/* 32EF */ { "KATAKANA CERCLÉ MI","	# <cerclée> 30DF"},
/* 32F0 */ { "KATAKANA CERCLÉ MU","	# <cerclée> 30E0"},
/* 32F1 */ { "KATAKANA CERCLÉ ME","	# <cerclée> 30E1"},
/* 32F2 */ { "KATAKANA CERCLÉ MO","	# <cerclée> 30E2"},
/* 32F3 */ { "KATAKANA CERCLÉ YA","	# <cerclée> 30E4"},
/* 32F4 */ { "KATAKANA CERCLÉ YU","	# <cerclée> 30E6"},
/* 32F5 */ { "KATAKANA CERCLÉ YO","	# <cerclée> 30E8"},
/* 32F6 */ { "KATAKANA CERCLÉ RA","	# <cerclée> 30E9"},
/* 32F7 */ { "KATAKANA CERCLÉ RI","	# <cerclée> 30EA"},
/* 32F8 */ { "KATAKANA CERCLÉ RU","	# <cerclée> 30EB"},
/* 32F9 */ { "KATAKANA CERCLÉ RE","	# <cerclée> 30EC"},
/* 32FA */ { "KATAKANA CERCLÉ RO","	# <cerclée> 30ED"},
/* 32FB */ { "KATAKANA CERCLÉ WA","	# <cerclée> 30EF"},
/* 32FC */ { "KATAKANA CERCLÉ WI","	# <cerclée> 30F0"},
/* 32FD */ { "KATAKANA CERCLÉ WE","	# <cerclée> 30F1"},
/* 32FE */ { "KATAKANA CERCLÉ WO","	# <cerclée> 30F2"},
/* 32FF */ { "ÈRE REIWA DISPOSÉ EN CARRÉ","	# <enCarré> 4EE4 548C"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_33[] = {
/* 3300 */ { "APÂTO DISPOSÉ EN CARRÉ","	* appartement\n"
	"	# <enCarré> 30A2 30D1 30FC 30C8"},
/* 3301 */ { "ARUHUA DISPOSÉ EN CARRÉ","	* alpha\n"
	"	# <enCarré> 30A2 30EB 30D5 30A1"},
/* 3302 */ { "ANPEA DISPOSÉ EN CARRÉ","	* ampère\n"
	"	# <enCarré> 30A2 30F3 30DA 30A2"},
/* 3303 */ { "ÂRU DISPOSÉ EN CARRÉ","	* are (unité de superficie)\n"
	"	# <enCarré> 30A2 30FC 30EB"},
/* 3304 */ { "ININGU DISPOSÉ EN CARRÉ","	* manche (en baseball)\n"
	"	# <enCarré> 30A4 30CB 30F3 30B0"},
/* 3305 */ { "INTI DISPOSÉ EN CARRÉ","	* pouce\n"
	"	# <enCarré> 30A4 30F3 30C1"},
/* 3306 */ { "UON DISPOSÉ EN CARRÉ","	* won sud-coréen, won nord-coréen\n"
	"	# <enCarré> 30A6 30A9 30F3"},
/* 3307 */ { "ESUKÛDO DISPOSÉ EN CARRÉ","	* escudo (ancienne monnaie du Portugal)\n"
	"	# <enCarré> 30A8 30B9 30AF 30FC 30C9"},
/* 3308 */ { "ÊKÂ DISPOSÉ EN CARRÉ","	* acre, arpent\n"
	"	# <enCarré> 30A8 30FC 30AB 30FC"},
/* 3309 */ { "ONSU DISPOSÉ EN CARRÉ","	* once\n"
	"	# <enCarré> 30AA 30F3 30B9"},
/* 330A */ { "ÔMU DISPOSÉ EN CARRÉ","	* ohm\n"
	"	# <enCarré> 30AA 30FC 30E0"},
/* 330B */ { "KAIRI DISPOSÉ EN CARRÉ","	* kai-ri : mille marin\n"
	"	# <enCarré> 30AB 30A4 30EA"},
/* 330C */ { "KARATTO DISPOSÉ EN CARRÉ","	* carat\n"
	"	# <enCarré> 30AB 30E9 30C3 30C8"},
/* 330D */ { "KARORÎ DISPOSÉ EN CARRÉ","	* calorie\n"
	"	# <enCarré> 30AB 30ED 30EA 30FC"},
/* 330E */ { "GARON DISPOSÉ EN CARRÉ","	* gallon\n"
	"	# <enCarré> 30AC 30ED 30F3"},
/* 330F */ { "GANMA DISPOSÉ EN CARRÉ","	* gamma\n"
	"	# <enCarré> 30AC 30F3 30DE"},
/* 3310 */ { "GIGA DISPOSÉ EN CARRÉ","	* giga-\n"
	"	# <enCarré> 30AE 30AC"},
/* 3311 */ { "GINÎ DISPOSÉ EN CARRÉ","	* guinée\n"
	"	# <enCarré> 30AE 30CB 30FC"},
/* 3312 */ { "KYURÎ DISPOSÉ EN CARRÉ","	* curie\n"
	"	# <enCarré> 30AD 30E5 30EA 30FC"},
/* 3313 */ { "GIRUDÂ DISPOSÉ EN CARRÉ","	* florin\n"
	"	# <enCarré> 30AE 30EB 30C0 30FC"},
/* 3314 */ { "KIRO DISPOSÉ EN CARRÉ","	* kilo-\n"
	"	# <enCarré> 30AD 30ED"},
/* 3315 */ { "KIROGURAMU DISPOSÉ EN CARRÉ","	* kilogramme\n"
	"	# <enCarré> 30AD 30ED 30B0 30E9 30E0"},
/* 3316 */ { "KIROMÊTORU DISPOSÉ EN CARRÉ","	* kilomètre\n"
	"	# <enCarré> 30AD 30ED 30E1 30FC 30C8 30EB"},
/* 3317 */ { "KIROWATTO DISPOSÉ EN CARRÉ","	* kilowatt\n"
	"	# <enCarré> 30AD 30ED 30EF 30C3 30C8"},
/* 3318 */ { "GURAMU DISPOSÉ EN CARRÉ","	* gramme\n"
	"	# <enCarré> 30B0 30E9 30E0"},
/* 3319 */ { "GURAMUTON DISPOSÉ EN CARRÉ","	* gramme par tonne\n"
	"	# <enCarré> 30B0 30E9 30E0 30C8 30F3"},
/* 331A */ { "KURUZEIRO DISPOSÉ EN CARRÉ","	* cruzeiro (monnaie du Brésil)\n"
	"	# <enCarré> 30AF 30EB 30BC 30A4 30ED"},
/* 331B */ { "KURÔNE DISPOSÉ EN CARRÉ","	* krone, couronne scandinave\n"
	"	# <enCarré> 30AF 30ED 30FC 30CD"},
/* 331C */ { "KÊSU DISPOSÉ EN CARRÉ","	* caisse\n"
	"	# <enCarré> 30B1 30FC 30B9"},
/* 331D */ { "KORUNA DISPOSÉ EN CARRÉ","	* koruna, couronne (monnaie tchèque)\n"
	"	# <enCarré> 30B3 30EB 30CA"},
/* 331E */ { "KÔPO DISPOSÉ EN CARRÉ","	* coopérative\n"
	"	# <enCarré> 30B3 30FC 30DD"},
/* 331F */ { "SAIKURU DISPOSÉ EN CARRÉ","	* cycle\n"
	"	# <enCarré> 30B5 30A4 30AF 30EB"},
/* 3320 */ { "SANTÎMU DISPOSÉ EN CARRÉ","	* centime\n"
	"	# <enCarré> 30B5 30F3 30C1 30FC 30E0"},
/* 3321 */ { "SIRINGU DISPOSÉ EN CARRÉ","	* shilling\n"
	"	# <enCarré> 30B7 30EA 30F3 30B0"},
/* 3322 */ { "SENTI DISPOSÉ EN CARRÉ","	* centi-\n"
	"	# <enCarré> 30BB 30F3 30C1"},
/* 3323 */ { "SENTO DISPOSÉ EN CARRÉ","	* cent, centime\n"
	"	# <enCarré> 30BB 30F3 30C8"},
/* 3324 */ { "DÂSU DISPOSÉ EN CARRÉ","	* douzaine\n"
	"	# <enCarré> 30C0 30FC 30B9"},
/* 3325 */ { "DESI DISPOSÉ EN CARRÉ","	* déci-\n"
	"	# <enCarré> 30C7 30B7"},
/* 3326 */ { "DORU DISPOSÉ EN CARRÉ","	* dollar\n"
	"	# <enCarré> 30C9 30EB"},
/* 3327 */ { "TONNE DISPOSÉ EN CARRÉ","	* tonne\n"
	"	# <enCarré> 30C8 30F3"},
/* 3328 */ { "NANO DISPOSÉ EN CARRÉ","	* nano-\n"
	"	# <enCarré> 30CA 30CE"},
/* 3329 */ { "NOTTO DISPOSÉ EN CARRÉ","	* nœud, mille marin\n"
	"	# <enCarré> 30CE 30C3 30C8"},
/* 332A */ { "HAITU DISPOSÉ EN CARRÉ","	* hauteurs\n"
	"	# <enCarré> 30CF 30A4 30C4"},
/* 332B */ { "PÂSENTO DISPOSÉ EN CARRÉ","	* pour cent\n"
	"	# <enCarré> 30D1 30FC 30BB 30F3 30C8"},
/* 332C */ { "PÂTU DISPOSÉ EN CARRÉ","	* une représentation erronée et inusitée prévue initialement pour le symbole monétaire thaï baht\n"
	"	x (symbole monétaire thaï baht - 0E3F)\n"
	"	# <enCarré> 30D1 30FC 30C4"},
/* 332D */ { "BÂRERU DISPOSÉ EN CARRÉ","	* baril\n"
	"	# <enCarré> 30D0 30FC 30EC 30EB"},
/* 332E */ { "PIASUTORU DISPOSÉ EN CARRÉ","	* piastre\n"
	"	# <enCarré> 30D4 30A2 30B9 30C8 30EB"},
/* 332F */ { "PIKURU DISPOSÉ EN CARRÉ","	* picoul, picol (60 kg)\n"
	"	# <enCarré> 30D4 30AF 30EB"},
/* 3330 */ { "PIKO DISPOSÉ EN CARRÉ","	* pico-\n"
	"	# <enCarré> 30D4 30B3"},
/* 3331 */ { "BIRU DISPOSÉ EN CARRÉ","	* édifice\n"
	"	# <enCarré> 30D3 30EB"},
/* 3332 */ { "HUARADO DISPOSÉ EN CARRÉ","	* farad\n"
	"	# <enCarré> 30D5 30A1 30E9 30C3 30C9"},
/* 3333 */ { "HUÎTO DISPOSÉ EN CARRÉ","	* pied\n"
	"	# <enCarré> 30D5 30A3 30FC 30C8"},
/* 3334 */ { "BUSSYERU DISPOSÉ EN CARRÉ","	* boisseau\n"
	"	# <enCarré> 30D6 30C3 30B7 30A7 30EB"},
/* 3335 */ { "HURAN DISPOSÉ EN CARRÉ","	* franc\n"
	"	# <enCarré> 30D5 30E9 30F3"},
/* 3336 */ { "HEKUTÂRU DISPOSÉ EN CARRÉ","	* hectare\n"
	"	# <enCarré> 30D8 30AF 30BF 30FC 30EB"},
/* 3337 */ { "PESO DISPOSÉ EN CARRÉ","	* peso\n"
	"	# <enCarré> 30DA 30BD"},
/* 3338 */ { "PENIHI DISPOSÉ EN CARRÉ","	* pfennig\n"
	"	# <enCarré> 30DA 30CB 30D2"},
/* 3339 */ { "HERUTU DISPOSÉ EN CARRÉ","	* hertz\n"
	"	# <enCarré> 30D8 30EB 30C4"},
/* 333A */ { "PENSU DISPOSÉ EN CARRÉ","	* penny\n"
	"	# <enCarré> 30DA 30F3 30B9"},
/* 333B */ { "PÊZI DISPOSÉ EN CARRÉ","	* page\n"
	"	# <enCarré> 30DA 30FC 30B8"},
/* 333C */ { "BÊTA DISPOSÉ EN CARRÉ","	* bêta\n"
	"	# <enCarré> 30D9 30FC 30BF"},
/* 333D */ { "POINTO DISPOSÉ EN CARRÉ","	* point\n"
	"	# <enCarré> 30DD 30A4 30F3 30C8"},
/* 333E */ { "BORUTO DISPOSÉ EN CARRÉ","	* volt, boulon\n"
	"	# <enCarré> 30DC 30EB 30C8"},
/* 333F */ { "HON DISPOSÉ EN CARRÉ","	* hon : volume\n"
	"	# <enCarré> 30DB 30F3"},
/* 3340 */ { "PONDO DISPOSÉ EN CARRÉ","	* livre (unité de poids)\n"
	"	# <enCarré> 30DD 30F3 30C9"},
/* 3341 */ { "HÔRU DISPOSÉ EN CARRÉ","	* vestibule\n"
	"	# <enCarré> 30DB 30FC 30EB"},
/* 3342 */ { "HÔN DISPOSÉ EN CARRÉ","	* corne\n"
	"	# <enCarré> 30DB 30FC 30F3"},
/* 3343 */ { "MAYAKURO DISPOSÉ EN CARRÉ","	* micro-\n"
	"	# <enCarré> 30DE 30A4 30AF 30ED"},
/* 3344 */ { "MAYAKRU DISPOSÉ EN CARRÉ","	* mille (unité de distance)\n"
	"	# <enCarré> 30DE 30A4 30EB"},
/* 3345 */ { "MAHHA DISPOSÉ EN CARRÉ","	* mach\n"
	"	# <enCarré> 30DE 30C3 30CF"},
/* 3346 */ { "MAKKU DISPOSÉ EN CARRÉ","	* mark\n"
	"	# <enCarré> 30DE 30EB 30AF"},
/* 3347 */ { "MANSYON DISPOSÉ EN CARRÉ","	* appartement de luxe\n"
	"	# <enCarré> 30DE 30F3 30B7 30E7 30F3"},
/* 3348 */ { "MIKURON DISPOSÉ EN CARRÉ","	* micron\n"
	"	# <enCarré> 30DF 30AF 30ED 30F3"},
/* 3349 */ { "MIRI DISPOSÉ EN CARRÉ","	* milli-\n"
	"	# <enCarré> 30DF 30EA"},
/* 334A */ { "MIRIBÂRU DISPOSÉ EN CARRÉ","	* miilibar\n"
	"	# <enCarré> 30DF 30EA 30D0 30FC 30EB"},
/* 334B */ { "MÉGA DISPOSÉ EN CARRÉ","	* méga-\n"
	"	# <enCarré> 30E1 30AC"},
/* 334C */ { "MÉGATONNE DISPOSÉ EN CARRÉ","	* mégatonne\n"
	"	# <enCarré> 30E1 30AC 30C8 30F3"},
/* 334D */ { "MÊTORU DISPOSÉ EN CARRÉ","	* mètre\n"
	"	# <enCarré> 30E1 30FC 30C8 30EB"},
/* 334E */ { "YÂDO DISPOSÉ EN CARRÉ","	* yard, verge\n"
	"	# <enCarré> 30E4 30FC 30C9"},
/* 334F */ { "YÂRU DISPOSÉ EN CARRÉ","	* yard, verge\n"
	"	# <enCarré> 30E4 30FC 30EB"},
/* 3350 */ { "YUAN DISPOSÉ EN CARRÉ","	* yuan (devise nationale de la Chine)\n"
	"	# <enCarré> 30E6 30A2 30F3"},
/* 3351 */ { "RITTORU DISPOSÉ EN CARRÉ","	* litre\n"
	"	# <enCarré> 30EA 30C3 30C8 30EB"},
/* 3352 */ { "RIRA DISPOSÉ EN CARRÉ","	* lire\n"
	"	# <enCarré> 30EA 30E9"},
/* 3353 */ { "RUPÎ DISPOSÉ EN CARRÉ","	* roupie\n"
	"	# <enCarré> 30EB 30D4 30FC"},
/* 3354 */ { "RÛBURU DISPOSÉ EN CARRÉ","	* rouble\n"
	"	# <enCarré> 30EB 30FC 30D6 30EB"},
/* 3355 */ { "REMU DISPOSÉ EN CARRÉ","	* rem (unité de radiation)\n"
	"	# <enCarré> 30EC 30E0"},
/* 3356 */ { "RENTOGEN DISPOSÉ EN CARRÉ","	* röntgen\n"
	"	# <enCarré> 30EC 30F3 30C8 30B2 30F3"},
/* 3357 */ { "WATTO DISPOSÉ EN CARRÉ","	* watt\n"
	"	# <enCarré> 30EF 30C3 30C8"},
/* 3358 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE ZÉRO","	# 0030 70B9"},
/* 3359 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE UN","	# 0031 70B9"},
/* 335A */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE DEUX","	# 0032 70B9"},
/* 335B */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE TROIS","	# 0033 70B9"},
/* 335C */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE QUATRE","	# 0034 70B9"},
/* 335D */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE CINQ","	# 0035 70B9"},
/* 335E */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE SIX","	# 0036 70B9"},
/* 335F */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE SEPT","	# 0037 70B9"},
/* 3360 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE HUIT","	# 0038 70B9"},
/* 3361 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE NEUF","	# 0039 70B9"},
/* 3362 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE DIX","	# 0031 0030 70B9"},
/* 3363 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE ONZE","	# 0031 0031 70B9"},
/* 3364 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE DOUZE","	# 0031 0032 70B9"},
/* 3365 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE TREIZE","	# 0031 0033 70B9"},
/* 3366 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE QUATORZE","	# 0031 0034 70B9"},
/* 3367 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE QUINZE","	# 0031 0035 70B9"},
/* 3368 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE SEIZE","	# 0031 0036 70B9"},
/* 3369 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE DIX-SEPT","	# 0031 0037 70B9"},
/* 336A */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE DIX-HUIT","	# 0031 0038 70B9"},
/* 336B */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE DIX-NEUF","	# 0031 0039 70B9"},
/* 336C */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE VINGT","	# 0032 0030 70B9"},
/* 336D */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE VINGT ET UN","	# 0032 0031 70B9"},
/* 336E */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE VINGT-DEUX","	# 0032 0032 70B9"},
/* 336F */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE VINGT-TROIS","	# 0032 0033 70B9"},
/* 3370 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE HEURE VINGT-QUATRE","	# 0032 0034 70B9"},
/* 3371 */ { "HPA DISPOSÉ EN CARRÉ","	# <enCarré> 0068 0050 0061"},
/* 3372 */ { "DA DISPOSÉ EN CARRÉ","	# <enCarré> 0064 0061"},
/* 3373 */ { "AU DISPOSÉ EN CARRÉ","	# <enCarré> 0041 0055"},
/* 3374 */ { "BAR DISPOSÉ EN CARRÉ","	# <enCarré> 0062 0061 0072"},
/* 3375 */ { "OV DISPOSÉ EN CARRÉ","	# <enCarré> 006F 0056"},
/* 3376 */ { "PC DISPOSÉ EN CARRÉ","	# <enCarré> 0070 0063"},
/* 3377 */ { "DM DISPOSÉ EN CARRÉ","	# <enCarré> 0064 006D"},
/* 3378 */ { "DM AU CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 0064 006D 00B2"},
/* 3379 */ { "DM AU CUBE DISPOSÉ EN CARRÉ","	# <enCarré> 0064 006D 00B3"},
/* 337A */ { "IU DISPOSÉ EN CARRÉ","	# <enCarré> 0049 0055"},
/* 337B */ { "ÈRE HEISEI DISPOSÉ EN CARRÉ","	# <enCarré> 5E73 6210"},
/* 337C */ { "ÈRE CHÔWA DISPOSÉ EN CARRÉ","	# <enCarré> 662D 548C"},
/* 337D */ { "ÈRE TAÏCHÔ DISPOSÉ EN CARRÉ","	# <enCarré> 5927 6B63"},
/* 337E */ { "ÈRE MEIJI DISPOSÉ EN CARRÉ","	# <enCarré> 660E 6CBB"},
/* 337F */ { "SOCIÉTÉ DISPOSÉ EN CARRÉ","	= kabushiki gaisha\n"
	"	* société anonyme\n"
	"	# <enCarré> 682A 5F0F 4F1A 793E"},
/* 3380 */ { "PA AMPÈRES DISPOSÉ EN CARRÉ","	# <enCarré> 0070 0041"},
/* 3381 */ { "NA DISPOSÉ EN CARRÉ","	# <enCarré> 006E 0041"},
/* 3382 */ { "MU A DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 0041"},
/* 3383 */ { "MA DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0041"},
/* 3384 */ { "KA DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0041"},
/* 3385 */ { "KB DISPOSÉ EN CARRÉ","	# <enCarré> 004B 0042"},
/* 3386 */ { "MB DISPOSÉ EN CARRÉ","	# <enCarré> 004D 0042"},
/* 3387 */ { "GB DISPOSÉ EN CARRÉ","	# <enCarré> 0047 0042"},
/* 3388 */ { "CAL DISPOSÉ EN CARRÉ","	# <enCarré> 0063 0061 006C"},
/* 3389 */ { "KCAL DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0063 0061 006C"},
/* 338A */ { "PF DISPOSÉ EN CARRÉ","	# <enCarré> 0070 0046"},
/* 338B */ { "NF DISPOSÉ EN CARRÉ","	# <enCarré> 006E 0046"},
/* 338C */ { "MU F DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 0046"},
/* 338D */ { "MU G DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 0067"},
/* 338E */ { "MG DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0067"},
/* 338F */ { "KG DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0067"},
/* 3390 */ { "HZ DISPOSÉ EN CARRÉ","	# <enCarré> 0048 007A"},
/* 3391 */ { "KHZ DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0048 007A"},
/* 3392 */ { "MHZ DISPOSÉ EN CARRÉ","	# <enCarré> 004D 0048 007A"},
/* 3393 */ { "GHZ DISPOSÉ EN CARRÉ","	# <enCarré> 0047 0048 007A"},
/* 3394 */ { "THZ DISPOSÉ EN CARRÉ","	# <enCarré> 0054 0048 007A"},
/* 3395 */ { "MU L DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 2113"},
/* 3396 */ { "ML DISPOSÉ EN CARRÉ","	# <enCarré> 006D 2113"},
/* 3397 */ { "DL DISPOSÉ EN CARRÉ","	# <enCarré> 0064 2113"},
/* 3398 */ { "KL DISPOSÉ EN CARRÉ","	# <enCarré> 006B 2113"},
/* 3399 */ { "FM DISPOSÉ EN CARRÉ","	# <enCarré> 0066 006D"},
/* 339A */ { "NM DISPOSÉ EN CARRÉ","	# <enCarré> 006E 006D"},
/* 339B */ { "MU M DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 006D"},
/* 339C */ { "MM DISPOSÉ EN CARRÉ","	# <enCarré> 006D 006D"},
/* 339D */ { "CM DISPOSÉ EN CARRÉ","	# <enCarré> 0063 006D"},
/* 339E */ { "KM DISPOSÉ EN CARRÉ","	# <enCarré> 006B 006D"},
/* 339F */ { "MM CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 006D 006D 00B2"},
/* 33A0 */ { "CM CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 0063 006D 00B2"},
/* 33A1 */ { "M CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 006D 00B2"},
/* 33A2 */ { "KM CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 006B 006D 00B2"},
/* 33A3 */ { "MM CUBE DISPOSÉ EN CARRÉ","	# <enCarré> 006D 006D 00B3"},
/* 33A4 */ { "CM CUBE DISPOSÉ EN CARRÉ","	# <enCarré> 0063 006D 00B3"},
/* 33A5 */ { "M CUBE DISPOSÉ EN CARRÉ","	# <enCarré> 006D 00B3"},
/* 33A6 */ { "KM CUBE DISPOSÉ EN CARRÉ","	# <enCarré> 006B 006D 00B3"},
/* 33A7 */ { "M SUR S DISPOSÉ EN CARRÉ","	# <enCarré> 006D 2215 0073"},
/* 33A8 */ { "M SUR S CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 006D 2215 0073 00B2"},
/* 33A9 */ { "PA DISPOSÉ EN CARRÉ","	# <enCarré> 0050 0061"},
/* 33AA */ { "KPA DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0050 0061"},
/* 33AB */ { "MPA DISPOSÉ EN CARRÉ","	# <enCarré> 004D 0050 0061"},
/* 33AC */ { "GPA DISPOSÉ EN CARRÉ","	# <enCarré> 0047 0050 0061"},
/* 33AD */ { "RAD DISPOSÉ EN CARRÉ","	# <enCarré> 0072 0061 0064"},
/* 33AE */ { "RAD SUR S DISPOSÉ EN CARRÉ","	# <enCarré> 0072 0061 0064 2215 0073"},
/* 33AF */ { "RAD SUR S CARRÉ DISPOSÉ EN CARRÉ","	# <enCarré> 0072 0061 0064 2215 0073 00B2"},
/* 33B0 */ { "PS DISPOSÉ EN CARRÉ","	# <enCarré> 0070 0073"},
/* 33B1 */ { "NS DISPOSÉ EN CARRÉ","	# <enCarré> 006E 0073"},
/* 33B2 */ { "MU S DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 0073"},
/* 33B3 */ { "MS DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0073"},
/* 33B4 */ { "PV DISPOSÉ EN CARRÉ","	# <enCarré> 0070 0056"},
/* 33B5 */ { "NV DISPOSÉ EN CARRÉ","	# <enCarré> 006E 0056"},
/* 33B6 */ { "MU V DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 0056"},
/* 33B7 */ { "MV DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0056"},
/* 33B8 */ { "KV DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0056"},
/* 33B9 */ { "MV MÉGA DISPOSÉ EN CARRÉ","	# <enCarré> 004D 0056"},
/* 33BA */ { "PW DISPOSÉ EN CARRÉ","	# <enCarré> 0070 0057"},
/* 33BB */ { "NW DISPOSÉ EN CARRÉ","	# <enCarré> 006E 0057"},
/* 33BC */ { "MU W DISPOSÉ EN CARRÉ","	# <enCarré> 03BC 0057"},
/* 33BD */ { "MW DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0057"},
/* 33BE */ { "KW DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0057"},
/* 33BF */ { "MW MÉGA DISPOSÉ EN CARRÉ","	# <enCarré> 004D 0057"},
/* 33C0 */ { "K OHM DISPOSÉ EN CARRÉ","	# <enCarré> 006B 03A9"},
/* 33C1 */ { "M OHM DISPOSÉ EN CARRÉ","	# <enCarré> 004D 03A9"},
/* 33C2 */ { "AM DISPOSÉ EN CARRÉ","	# <enCarré> 0061 002E 006D 002E"},
/* 33C3 */ { "BQ DISPOSÉ EN CARRÉ","	# <enCarré> 0042 0071"},
/* 33C4 */ { "CC DISPOSÉ EN CARRÉ","	# <enCarré> 0063 0063"},
/* 33C5 */ { "CD DISPOSÉ EN CARRÉ","	x (cd cerclé - 1F12D)\n"
	"	# <enCarré> 0063 0064"},
/* 33C6 */ { "C SUR KG DISPOSÉ EN CARRÉ","	# <enCarré> 0043 2215 006B 0067"},
/* 33C7 */ { "CO DISPOSÉ EN CARRÉ","	# <enCarré> 0043 006F 002E"},
/* 33C8 */ { "DB DISPOSÉ EN CARRÉ","	# <enCarré> 0064 0042"},
/* 33C9 */ { "GY DISPOSÉ EN CARRÉ","	# <enCarré> 0047 0079"},
/* 33CA */ { "HA DISPOSÉ EN CARRÉ","	# <enCarré> 0068 0061"},
/* 33CB */ { "HP DISPOSÉ EN CARRÉ","	# <enCarré> 0048 0050"},
/* 33CC */ { "IN DISPOSÉ EN CARRÉ","	# <enCarré> 0069 006E"},
/* 33CD */ { "KK DISPOSÉ EN CARRÉ","	# <enCarré> 004B 004B"},
/* 33CE */ { "KM MAJUSCULE DISPOSÉ EN CARRÉ","	# <enCarré> 004B 004D"},
/* 33CF */ { "KT DISPOSÉ EN CARRÉ","	# <enCarré> 006B 0074"},
/* 33D0 */ { "LM DISPOSÉ EN CARRÉ","	# <enCarré> 006C 006D"},
/* 33D1 */ { "LN DISPOSÉ EN CARRÉ","	# <enCarré> 006C 006E"},
/* 33D2 */ { "LOG DISPOSÉ EN CARRÉ","	# <enCarré> 006C 006F 0067"},
/* 33D3 */ { "LX DISPOSÉ EN CARRÉ","	# <enCarré> 006C 0078"},
/* 33D4 */ { "MB MINUSCULE DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0062"},
/* 33D5 */ { "MIL DISPOSÉ EN CARRÉ","	# <enCarré> 006D 0069 006C"},
/* 33D6 */ { "MOL DISPOSÉ EN CARRÉ","	# <enCarré> 006D 006F 006C"},
/* 33D7 */ { "PH DISPOSÉ EN CARRÉ","	* l'incohérence relative à la casse dans la décomposition de compatibilité est une anomalie connue datant des représentations des glyphes dans les premières versions du standard\n"
	"	# <enCarré> 0050 0048"},
/* 33D8 */ { "PM DISPOSÉ EN CARRÉ","	# <enCarré> 0070 002E 006D 002E"},
/* 33D9 */ { "PPM DISPOSÉ EN CARRÉ","	# <enCarré> 0050 0050 004D"},
/* 33DA */ { "PR DISPOSÉ EN CARRÉ","	# <enCarré> 0050 0052"},
/* 33DB */ { "SR DISPOSÉ EN CARRÉ","	# <enCarré> 0073 0072"},
/* 33DC */ { "SV DISPOSÉ EN CARRÉ","	# <enCarré> 0053 0076"},
/* 33DD */ { "WB DISPOSÉ EN CARRÉ","	# <enCarré> 0057 0062"},
/* 33DE */ { "V SUR M DISPOSÉ EN CARRÉ","	# <enCarré> 0056 2215 006D"},
/* 33DF */ { "A SUR M DISPOSÉ EN CARRÉ","	# <enCarré> 0041 2215 006D"},
/* 33E0 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR UN","	# 0031 65E5"},
/* 33E1 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR DEUX","	# 0032 65E5"},
/* 33E2 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR TROIS","	# 0033 65E5"},
/* 33E3 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR QUATRE","	# 0034 65E5"},
/* 33E4 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR CINQ","	# 0035 65E5"},
/* 33E5 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR SIX","	# 0036 65E5"},
/* 33E6 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR SEPT","	# 0037 65E5"},
/* 33E7 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR HUIT","	# 0038 65E5"},
/* 33E8 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR NEUF","	# 0039 65E5"},
/* 33E9 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR DIX","	# 0031 0030 65E5"},
/* 33EA */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR ONZE","	# 0031 0031 65E5"},
/* 33EB */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR DOUZE","	# 0031 0032 65E5"},
/* 33EC */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR TREIZE","	# 0031 0033 65E5"},
/* 33ED */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR QUATORZE","	# 0031 0034 65E5"},
/* 33EE */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR QUINZE","	# 0031 0035 65E5"},
/* 33EF */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR SEIZE","	# 0031 0036 65E5"},
/* 33F0 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR DIX-SEPT","	# 0031 0037 65E5"},
/* 33F1 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR DIX-HUIT","	# 0031 0038 65E5"},
/* 33F2 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR DIX-NEUF","	# 0031 0039 65E5"},
/* 33F3 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT","	# 0032 0030 65E5"},
/* 33F4 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT ET UN","	# 0032 0031 65E5"},
/* 33F5 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-DEUX","	# 0032 0032 65E5"},
/* 33F6 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-TROIS","	# 0032 0033 65E5"},
/* 33F7 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-QUATRE","	# 0032 0034 65E5"},
/* 33F8 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-CINQ","	# 0032 0035 65E5"},
/* 33F9 */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-SIX","	# 0032 0036 65E5"},
/* 33FA */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-SEPT","	# 0032 0037 65E5"},
/* 33FB */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-HUIT","	# 0032 0038 65E5"},
/* 33FC */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR VINGT-NEUF","	# 0032 0039 65E5"},
/* 33FD */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR TRENTE","	# 0033 0030 65E5"},
/* 33FE */ { "SYMBOLE TÉLÉGRAPHIQUE IDÉOGRAPHIQUE JOUR TRENTE ET UN","	# 0033 0031 65E5"},
/* 33FF */ { "GAL DISPOSÉ EN CARRÉ","	# <enCarré> 0067 0061 006C"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_4D[] = {
/* 4D00 */ { NULL,NULL},
/* 4D01 */ { NULL,NULL},
/* 4D02 */ { NULL,NULL},
/* 4D03 */ { NULL,NULL},
/* 4D04 */ { NULL,NULL},
/* 4D05 */ { NULL,NULL},
/* 4D06 */ { NULL,NULL},
/* 4D07 */ { NULL,NULL},
/* 4D08 */ { NULL,NULL},
/* 4D09 */ { NULL,NULL},
/* 4D0A */ { NULL,NULL},
/* 4D0B */ { NULL,NULL},
/* 4D0C */ { NULL,NULL},
/* 4D0D */ { NULL,NULL},
/* 4D0E */ { NULL,NULL},
/* 4D0F */ { NULL,NULL},
/* 4D10 */ { NULL,NULL},
/* 4D11 */ { NULL,NULL},
/* 4D12 */ { NULL,NULL},
/* 4D13 */ { NULL,NULL},
/* 4D14 */ { NULL,NULL},
/* 4D15 */ { NULL,NULL},
/* 4D16 */ { NULL,NULL},
/* 4D17 */ { NULL,NULL},
/* 4D18 */ { NULL,NULL},
/* 4D19 */ { NULL,NULL},
/* 4D1A */ { NULL,NULL},
/* 4D1B */ { NULL,NULL},
/* 4D1C */ { NULL,NULL},
/* 4D1D */ { NULL,NULL},
/* 4D1E */ { NULL,NULL},
/* 4D1F */ { NULL,NULL},
/* 4D20 */ { NULL,NULL},
/* 4D21 */ { NULL,NULL},
/* 4D22 */ { NULL,NULL},
/* 4D23 */ { NULL,NULL},
/* 4D24 */ { NULL,NULL},
/* 4D25 */ { NULL,NULL},
/* 4D26 */ { NULL,NULL},
/* 4D27 */ { NULL,NULL},
/* 4D28 */ { NULL,NULL},
/* 4D29 */ { NULL,NULL},
/* 4D2A */ { NULL,NULL},
/* 4D2B */ { NULL,NULL},
/* 4D2C */ { NULL,NULL},
/* 4D2D */ { NULL,NULL},
/* 4D2E */ { NULL,NULL},
/* 4D2F */ { NULL,NULL},
/* 4D30 */ { NULL,NULL},
/* 4D31 */ { NULL,NULL},
/* 4D32 */ { NULL,NULL},
/* 4D33 */ { NULL,NULL},
/* 4D34 */ { NULL,NULL},
/* 4D35 */ { NULL,NULL},
/* 4D36 */ { NULL,NULL},
/* 4D37 */ { NULL,NULL},
/* 4D38 */ { NULL,NULL},
/* 4D39 */ { NULL,NULL},
/* 4D3A */ { NULL,NULL},
/* 4D3B */ { NULL,NULL},
/* 4D3C */ { NULL,NULL},
/* 4D3D */ { NULL,NULL},
/* 4D3E */ { NULL,NULL},
/* 4D3F */ { NULL,NULL},
/* 4D40 */ { NULL,NULL},
/* 4D41 */ { NULL,NULL},
/* 4D42 */ { NULL,NULL},
/* 4D43 */ { NULL,NULL},
/* 4D44 */ { NULL,NULL},
/* 4D45 */ { NULL,NULL},
/* 4D46 */ { NULL,NULL},
/* 4D47 */ { NULL,NULL},
/* 4D48 */ { NULL,NULL},
/* 4D49 */ { NULL,NULL},
/* 4D4A */ { NULL,NULL},
/* 4D4B */ { NULL,NULL},
/* 4D4C */ { NULL,NULL},
/* 4D4D */ { NULL,NULL},
/* 4D4E */ { NULL,NULL},
/* 4D4F */ { NULL,NULL},
/* 4D50 */ { NULL,NULL},
/* 4D51 */ { NULL,NULL},
/* 4D52 */ { NULL,NULL},
/* 4D53 */ { NULL,NULL},
/* 4D54 */ { NULL,NULL},
/* 4D55 */ { NULL,NULL},
/* 4D56 */ { NULL,NULL},
/* 4D57 */ { NULL,NULL},
/* 4D58 */ { NULL,NULL},
/* 4D59 */ { NULL,NULL},
/* 4D5A */ { NULL,NULL},
/* 4D5B */ { NULL,NULL},
/* 4D5C */ { NULL,NULL},
/* 4D5D */ { NULL,NULL},
/* 4D5E */ { NULL,NULL},
/* 4D5F */ { NULL,NULL},
/* 4D60 */ { NULL,NULL},
/* 4D61 */ { NULL,NULL},
/* 4D62 */ { NULL,NULL},
/* 4D63 */ { NULL,NULL},
/* 4D64 */ { NULL,NULL},
/* 4D65 */ { NULL,NULL},
/* 4D66 */ { NULL,NULL},
/* 4D67 */ { NULL,NULL},
/* 4D68 */ { NULL,NULL},
/* 4D69 */ { NULL,NULL},
/* 4D6A */ { NULL,NULL},
/* 4D6B */ { NULL,NULL},
/* 4D6C */ { NULL,NULL},
/* 4D6D */ { NULL,NULL},
/* 4D6E */ { NULL,NULL},
/* 4D6F */ { NULL,NULL},
/* 4D70 */ { NULL,NULL},
/* 4D71 */ { NULL,NULL},
/* 4D72 */ { NULL,NULL},
/* 4D73 */ { NULL,NULL},
/* 4D74 */ { NULL,NULL},
/* 4D75 */ { NULL,NULL},
/* 4D76 */ { NULL,NULL},
/* 4D77 */ { NULL,NULL},
/* 4D78 */ { NULL,NULL},
/* 4D79 */ { NULL,NULL},
/* 4D7A */ { NULL,NULL},
/* 4D7B */ { NULL,NULL},
/* 4D7C */ { NULL,NULL},
/* 4D7D */ { NULL,NULL},
/* 4D7E */ { NULL,NULL},
/* 4D7F */ { NULL,NULL},
/* 4D80 */ { NULL,NULL},
/* 4D81 */ { NULL,NULL},
/* 4D82 */ { NULL,NULL},
/* 4D83 */ { NULL,NULL},
/* 4D84 */ { NULL,NULL},
/* 4D85 */ { NULL,NULL},
/* 4D86 */ { NULL,NULL},
/* 4D87 */ { NULL,NULL},
/* 4D88 */ { NULL,NULL},
/* 4D89 */ { NULL,NULL},
/* 4D8A */ { NULL,NULL},
/* 4D8B */ { NULL,NULL},
/* 4D8C */ { NULL,NULL},
/* 4D8D */ { NULL,NULL},
/* 4D8E */ { NULL,NULL},
/* 4D8F */ { NULL,NULL},
/* 4D90 */ { NULL,NULL},
/* 4D91 */ { NULL,NULL},
/* 4D92 */ { NULL,NULL},
/* 4D93 */ { NULL,NULL},
/* 4D94 */ { NULL,NULL},
/* 4D95 */ { NULL,NULL},
/* 4D96 */ { NULL,NULL},
/* 4D97 */ { NULL,NULL},
/* 4D98 */ { NULL,NULL},
/* 4D99 */ { NULL,NULL},
/* 4D9A */ { NULL,NULL},
/* 4D9B */ { NULL,NULL},
/* 4D9C */ { NULL,NULL},
/* 4D9D */ { NULL,NULL},
/* 4D9E */ { NULL,NULL},
/* 4D9F */ { NULL,NULL},
/* 4DA0 */ { NULL,NULL},
/* 4DA1 */ { NULL,NULL},
/* 4DA2 */ { NULL,NULL},
/* 4DA3 */ { NULL,NULL},
/* 4DA4 */ { NULL,NULL},
/* 4DA5 */ { NULL,NULL},
/* 4DA6 */ { NULL,NULL},
/* 4DA7 */ { NULL,NULL},
/* 4DA8 */ { NULL,NULL},
/* 4DA9 */ { NULL,NULL},
/* 4DAA */ { NULL,NULL},
/* 4DAB */ { NULL,NULL},
/* 4DAC */ { NULL,NULL},
/* 4DAD */ { NULL,NULL},
/* 4DAE */ { NULL,NULL},
/* 4DAF */ { NULL,NULL},
/* 4DB0 */ { NULL,NULL},
/* 4DB1 */ { NULL,NULL},
/* 4DB2 */ { NULL,NULL},
/* 4DB3 */ { NULL,NULL},
/* 4DB4 */ { NULL,NULL},
/* 4DB5 */ { NULL,NULL},
/* 4DB6 */ { NULL,NULL},
/* 4DB7 */ { NULL,NULL},
/* 4DB8 */ { NULL,NULL},
/* 4DB9 */ { NULL,NULL},
/* 4DBA */ { NULL,NULL},
/* 4DBB */ { NULL,NULL},
/* 4DBC */ { NULL,NULL},
/* 4DBD */ { NULL,NULL},
/* 4DBE */ { NULL,NULL},
/* 4DBF */ { NULL,NULL},
/* 4DC0 */ { "HEXAGRAMME DE L'ÉLAN CÉLESTE","	= k'ien"},
/* 4DC1 */ { "HEXAGRAMME DE LA TERRE RÉCEPTIVE","	= k'ouen"},
/* 4DC2 */ { "HEXAGRAMME DE LA DIFFICULTÉ INITIALE","	= tchouen"},
/* 4DC3 */ { "HEXAGRAMME DU TÂTONNEMENT JUVÉNILE","	= mêng"},
/* 4DC4 */ { "HEXAGRAMME DE L'ATTENTE CONFIANTE","	= su"},
/* 4DC5 */ { "HEXAGRAMME DU CONFLIT","	= soung"},
/* 4DC6 */ { "HEXAGRAMME DE L'ARMÉE","	= che"},
/* 4DC7 */ { "HEXAGRAMME DE LA SOLIDARITÉ","	= pi"},
/* 4DC8 */ { "HEXAGRAMME DU DOUX APPRIVOISEMENT","	= siao tch'ou"},
/* 4DC9 */ { "HEXAGRAMME DE LA MARCHE PÉRILLEUSE","	= lü"},
/* 4DCA */ { "HEXAGRAMME DE LA PAIX","	= t'ai"},
/* 4DCB */ { "HEXAGRAMME DE LA STAGNATION","	= p'i"},
/* 4DCC */ { "HEXAGRAMME DE LA FRATERNITÉ","	= t'ong-jen"},
/* 4DCD */ { "HEXAGRAMME DU GRAND AVOIR","	= ta-yeou"},
/* 4DCE */ { "HEXAGRAMME DE L'INSUFFISANCE","	= k'ien"},
/* 4DCF */ { "HEXAGRAMME DE L'ENTHOUSIASME","	= yu"},
/* 4DD0 */ { "HEXAGRAMME DE LA SUITE","	= souei"},
/* 4DD1 */ { "HEXAGRAMME DU TRAVAIL SUR LE DÉCLIN","	= kou"},
/* 4DD2 */ { "HEXAGRAMME DE LA MONTÉE DE PUISSANCE","	= lin"},
/* 4DD3 */ { "HEXAGRAMME DE LA CONTEMPLATION","	= kouan"},
/* 4DD4 */ { "HEXAGRAMME DE MORDRE AU TRAVERS","	= che-hö"},
/* 4DD5 */ { "HEXAGRAMME DE LA GRÂCE","	= pi"},
/* 4DD6 */ { "HEXAGRAMME DE LA DÉCADENCE","	= po"},
/* 4DD7 */ { "HEXAGRAMME DU TOURNANT","	= fou"},
/* 4DD8 */ { "HEXAGRAMME DE LA NON-ERRANCE","	= wou-wang"},
/* 4DD9 */ { "HEXAGRAMME DU FERME APPRIVOISEMENT","	= ta-siu"},
/* 4DDA */ { "HEXAGRAMME DE L'ENTRETIEN DE LA VIE","	= yi"},
/* 4DDB */ { "HEXAGRAMME DE LA PRÉPONDÉRANCE DU GRAND","	= ta-kouo"},
/* 4DDC */ { "HEXAGRAMME DE L'EAU INSONDABLE","	= k'an"},
/* 4DDD */ { "HEXAGRAMME DU FEU QUI S'ATTACHE","	= li"},
/* 4DDE */ { "HEXAGRAMME DE L'INFLUENCE","	= hien"},
/* 4DDF */ { "HEXAGRAMME DE LA PÉRENNITÉ","	= heng"},
/* 4DE0 */ { "HEXAGRAMME DE LA RETRAITE","	= touen"},
/* 4DE1 */ { "HEXAGRAMME DE LA PUISSANCE DU GRAND","	= ta-tchouang"},
/* 4DE2 */ { "HEXAGRAMME DU PROGRÈS","	= tsin"},
/* 4DE3 */ { "HEXAGRAMME DE L'OBSCURCISSEMENT","	= ming-yi"},
/* 4DE4 */ { "HEXAGRAMME DU CLAN FAMILIAL","	= kia-jen"},
/* 4DE5 */ { "HEXAGRAMME DE L'OPPOSITION","	= k'ouei"},
/* 4DE6 */ { "HEXAGRAMME DE L'OBSTACLE","	= kien"},
/* 4DE7 */ { "HEXAGRAMME DE LA LIBÉRATION","	= sie"},
/* 4DE8 */ { "HEXAGRAMME DE LA DIMINUTION","	= souen"},
/* 4DE9 */ { "HEXAGRAMME DE L'ACCROISSEMENT","	= yi"},
/* 4DEA */ { "HEXAGRAMME DE LA PERCÉE","	= kouai"},
/* 4DEB */ { "HEXAGRAMME DE VENIR À LA RENCONTRE","	= keou"},
/* 4DEC */ { "HEXAGRAMME DU RASSEMBLEMENT","	= ts'ouei"},
/* 4DED */ { "HEXAGRAMME DE LA POUSSÉE VERS LE HAUT","	= cheng"},
/* 4DEE */ { "HEXAGRAMME DE L'ACCABLEMENT","	= k'ouen"},
/* 4DEF */ { "HEXAGRAMME DU PUITS","	= ching"},
/* 4DF0 */ { "HEXAGRAMME DE LA MUE","	= kö 333"},
/* 4DF1 */ { "HEXAGRAMME DU CHAUDRON","	= ting"},
/* 4DF2 */ { "HEXAGRAMME DU TONNERRE ÉVEILLEUR","	= tchen"},
/* 4DF3 */ { "HEXAGRAMME DE LA MONTAGNE IMMOBILE","	= ken"},
/* 4DF4 */ { "HEXAGRAMME DU PROGRÈS GRADUEL","	= tsien\n"
	"	= développement"},
/* 4DF5 */ { "HEXAGRAMME DE L'ÉPOUSÉE","	= kouei-mei"},
/* 4DF6 */ { "HEXAGRAMME DE LA PLÉNITUDE","	= fong"},
/* 4DF7 */ { "HEXAGRAMME DE L'ERRANT","	= liu"},
/* 4DF8 */ { "HEXAGRAMME DU VENT DOUX","	= siun, souen"},
/* 4DF9 */ { "HEXAGRAMME DU LAC JOYEUX","	= touei"},
/* 4DFA */ { "HEXAGRAMME DE LA DISPERSION","	= houan\n"
	"	= dissolution"},
/* 4DFB */ { "HEXAGRAMME DE LA MODÉRATION","	= tsie"},
/* 4DFC */ { "HEXAGRAMME DE LA VÉRITÉ INTÉRIEURE","	= tchoung-fou"},
/* 4DFD */ { "HEXAGRAMME DE LA PRÉPONDÉRANCE DU PETIT","	= siao-kouo"},
/* 4DFE */ { "HEXAGRAMME DU TERME DE L'ACCOMPLISSEMENT","	= ki-tsi"},
/* 4DFF */ { "HEXAGRAMME DE LA MARCHE VERS L'ACCOMPLISSEMENT","	= wei-tsi"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A0[] = {
/* A000 */ { "SYLLABE YI IT",NULL},
/* A001 */ { "SYLLABE YI IX",NULL},
/* A002 */ { "SYLLABE YI I",NULL},
/* A003 */ { "SYLLABE YI IP",NULL},
/* A004 */ { "SYLLABE YI IET",NULL},
/* A005 */ { "SYLLABE YI IEX",NULL},
/* A006 */ { "SYLLABE YI IE",NULL},
/* A007 */ { "SYLLABE YI IEP",NULL},
/* A008 */ { "SYLLABE YI AT",NULL},
/* A009 */ { "SYLLABE YI AX",NULL},
/* A00A */ { "SYLLABE YI A",NULL},
/* A00B */ { "SYLLABE YI AP",NULL},
/* A00C */ { "SYLLABE YI UOX",NULL},
/* A00D */ { "SYLLABE YI UO",NULL},
/* A00E */ { "SYLLABE YI UOP",NULL},
/* A00F */ { "SYLLABE YI OT",NULL},
/* A010 */ { "SYLLABE YI OX",NULL},
/* A011 */ { "SYLLABE YI O",NULL},
/* A012 */ { "SYLLABE YI OP",NULL},
/* A013 */ { "SYLLABE YI EX",NULL},
/* A014 */ { "SYLLABE YI E",NULL},
/* A015 */ { "MARQUE D'ITÉRATION SYLLABIQUE YI","	* le nom formel de ce caractère en anglais est erroné"},
/* A016 */ { "SYLLABE YI BIT",NULL},
/* A017 */ { "SYLLABE YI BIX",NULL},
/* A018 */ { "SYLLABE YI BI",NULL},
/* A019 */ { "SYLLABE YI BIP",NULL},
/* A01A */ { "SYLLABE YI BIET",NULL},
/* A01B */ { "SYLLABE YI BIEX",NULL},
/* A01C */ { "SYLLABE YI BIE",NULL},
/* A01D */ { "SYLLABE YI BIEP",NULL},
/* A01E */ { "SYLLABE YI BAT",NULL},
/* A01F */ { "SYLLABE YI BAX",NULL},
/* A020 */ { "SYLLABE YI BA",NULL},
/* A021 */ { "SYLLABE YI BAP",NULL},
/* A022 */ { "SYLLABE YI BUOX",NULL},
/* A023 */ { "SYLLABE YI BUO",NULL},
/* A024 */ { "SYLLABE YI BUOP",NULL},
/* A025 */ { "SYLLABE YI BOT",NULL},
/* A026 */ { "SYLLABE YI BOX",NULL},
/* A027 */ { "SYLLABE YI BO",NULL},
/* A028 */ { "SYLLABE YI BOP",NULL},
/* A029 */ { "SYLLABE YI BEX",NULL},
/* A02A */ { "SYLLABE YI BE",NULL},
/* A02B */ { "SYLLABE YI BEP",NULL},
/* A02C */ { "SYLLABE YI BUT",NULL},
/* A02D */ { "SYLLABE YI BUX",NULL},
/* A02E */ { "SYLLABE YI BU",NULL},
/* A02F */ { "SYLLABE YI BUP",NULL},
/* A030 */ { "SYLLABE YI BURX",NULL},
/* A031 */ { "SYLLABE YI BUR",NULL},
/* A032 */ { "SYLLABE YI BYT",NULL},
/* A033 */ { "SYLLABE YI BYX",NULL},
/* A034 */ { "SYLLABE YI BY",NULL},
/* A035 */ { "SYLLABE YI BYP",NULL},
/* A036 */ { "SYLLABE YI BYRX",NULL},
/* A037 */ { "SYLLABE YI BYR",NULL},
/* A038 */ { "SYLLABE YI PIT",NULL},
/* A039 */ { "SYLLABE YI PIX",NULL},
/* A03A */ { "SYLLABE YI PI",NULL},
/* A03B */ { "SYLLABE YI PIP",NULL},
/* A03C */ { "SYLLABE YI PIEX",NULL},
/* A03D */ { "SYLLABE YI PIE",NULL},
/* A03E */ { "SYLLABE YI PIEP",NULL},
/* A03F */ { "SYLLABE YI PAT",NULL},
/* A040 */ { "SYLLABE YI PAX",NULL},
/* A041 */ { "SYLLABE YI PA",NULL},
/* A042 */ { "SYLLABE YI PAP",NULL},
/* A043 */ { "SYLLABE YI PUOX",NULL},
/* A044 */ { "SYLLABE YI PUO",NULL},
/* A045 */ { "SYLLABE YI PUOP",NULL},
/* A046 */ { "SYLLABE YI POT",NULL},
/* A047 */ { "SYLLABE YI POX",NULL},
/* A048 */ { "SYLLABE YI PO",NULL},
/* A049 */ { "SYLLABE YI POP",NULL},
/* A04A */ { "SYLLABE YI PUT",NULL},
/* A04B */ { "SYLLABE YI PUX",NULL},
/* A04C */ { "SYLLABE YI PU",NULL},
/* A04D */ { "SYLLABE YI PUP",NULL},
/* A04E */ { "SYLLABE YI PURX",NULL},
/* A04F */ { "SYLLABE YI PUR",NULL},
/* A050 */ { "SYLLABE YI PYT",NULL},
/* A051 */ { "SYLLABE YI PYX",NULL},
/* A052 */ { "SYLLABE YI PY",NULL},
/* A053 */ { "SYLLABE YI PYP",NULL},
/* A054 */ { "SYLLABE YI PYRX",NULL},
/* A055 */ { "SYLLABE YI PYR",NULL},
/* A056 */ { "SYLLABE YI BBIT",NULL},
/* A057 */ { "SYLLABE YI BBIX",NULL},
/* A058 */ { "SYLLABE YI BBI",NULL},
/* A059 */ { "SYLLABE YI BBIP",NULL},
/* A05A */ { "SYLLABE YI BBIET",NULL},
/* A05B */ { "SYLLABE YI BBIEX",NULL},
/* A05C */ { "SYLLABE YI BBIE",NULL},
/* A05D */ { "SYLLABE YI BBIEP",NULL},
/* A05E */ { "SYLLABE YI BBAT",NULL},
/* A05F */ { "SYLLABE YI BBAX",NULL},
/* A060 */ { "SYLLABE YI BBA",NULL},
/* A061 */ { "SYLLABE YI BBAP",NULL},
/* A062 */ { "SYLLABE YI BBUOX",NULL},
/* A063 */ { "SYLLABE YI BBUO",NULL},
/* A064 */ { "SYLLABE YI BBUOP",NULL},
/* A065 */ { "SYLLABE YI BBOT",NULL},
/* A066 */ { "SYLLABE YI BBOX",NULL},
/* A067 */ { "SYLLABE YI BBO",NULL},
/* A068 */ { "SYLLABE YI BBOP",NULL},
/* A069 */ { "SYLLABE YI BBEX",NULL},
/* A06A */ { "SYLLABE YI BBE",NULL},
/* A06B */ { "SYLLABE YI BBEP",NULL},
/* A06C */ { "SYLLABE YI BBUT",NULL},
/* A06D */ { "SYLLABE YI BBUX",NULL},
/* A06E */ { "SYLLABE YI BBU",NULL},
/* A06F */ { "SYLLABE YI BBUP",NULL},
/* A070 */ { "SYLLABE YI BBURX",NULL},
/* A071 */ { "SYLLABE YI BBUR",NULL},
/* A072 */ { "SYLLABE YI BBYT",NULL},
/* A073 */ { "SYLLABE YI BBYX",NULL},
/* A074 */ { "SYLLABE YI BBY",NULL},
/* A075 */ { "SYLLABE YI BBYP",NULL},
/* A076 */ { "SYLLABE YI NBIT",NULL},
/* A077 */ { "SYLLABE YI NBIX",NULL},
/* A078 */ { "SYLLABE YI NBI",NULL},
/* A079 */ { "SYLLABE YI NBIP",NULL},
/* A07A */ { "SYLLABE YI NBIEX",NULL},
/* A07B */ { "SYLLABE YI NBIE",NULL},
/* A07C */ { "SYLLABE YI NBIEP",NULL},
/* A07D */ { "SYLLABE YI NBAT",NULL},
/* A07E */ { "SYLLABE YI NBAX",NULL},
/* A07F */ { "SYLLABE YI NBA",NULL},
/* A080 */ { "SYLLABE YI NBAP",NULL},
/* A081 */ { "SYLLABE YI NBOT",NULL},
/* A082 */ { "SYLLABE YI NBOX",NULL},
/* A083 */ { "SYLLABE YI NBO",NULL},
/* A084 */ { "SYLLABE YI NBOP",NULL},
/* A085 */ { "SYLLABE YI NBUT",NULL},
/* A086 */ { "SYLLABE YI NBUX",NULL},
/* A087 */ { "SYLLABE YI NBU",NULL},
/* A088 */ { "SYLLABE YI NBUP",NULL},
/* A089 */ { "SYLLABE YI NBURX",NULL},
/* A08A */ { "SYLLABE YI NBUR",NULL},
/* A08B */ { "SYLLABE YI NBYT",NULL},
/* A08C */ { "SYLLABE YI NBYX",NULL},
/* A08D */ { "SYLLABE YI NBY",NULL},
/* A08E */ { "SYLLABE YI NBYP",NULL},
/* A08F */ { "SYLLABE YI NBYRX",NULL},
/* A090 */ { "SYLLABE YI NBYR",NULL},
/* A091 */ { "SYLLABE YI HMIT",NULL},
/* A092 */ { "SYLLABE YI HMIX",NULL},
/* A093 */ { "SYLLABE YI HMI",NULL},
/* A094 */ { "SYLLABE YI HMIP",NULL},
/* A095 */ { "SYLLABE YI HMIEX",NULL},
/* A096 */ { "SYLLABE YI HMIE",NULL},
/* A097 */ { "SYLLABE YI HMIEP",NULL},
/* A098 */ { "SYLLABE YI HMAT",NULL},
/* A099 */ { "SYLLABE YI HMAX",NULL},
/* A09A */ { "SYLLABE YI HMA",NULL},
/* A09B */ { "SYLLABE YI HMAP",NULL},
/* A09C */ { "SYLLABE YI HMUOX",NULL},
/* A09D */ { "SYLLABE YI HMUO",NULL},
/* A09E */ { "SYLLABE YI HMUOP",NULL},
/* A09F */ { "SYLLABE YI HMOT",NULL},
/* A0A0 */ { "SYLLABE YI HMOX",NULL},
/* A0A1 */ { "SYLLABE YI HMO",NULL},
/* A0A2 */ { "SYLLABE YI HMOP",NULL},
/* A0A3 */ { "SYLLABE YI HMUT",NULL},
/* A0A4 */ { "SYLLABE YI HMUX",NULL},
/* A0A5 */ { "SYLLABE YI HMU",NULL},
/* A0A6 */ { "SYLLABE YI HMUP",NULL},
/* A0A7 */ { "SYLLABE YI HMURX",NULL},
/* A0A8 */ { "SYLLABE YI HMUR",NULL},
/* A0A9 */ { "SYLLABE YI HMYX",NULL},
/* A0AA */ { "SYLLABE YI HMY",NULL},
/* A0AB */ { "SYLLABE YI HMYP",NULL},
/* A0AC */ { "SYLLABE YI HMYRX",NULL},
/* A0AD */ { "SYLLABE YI HMYR",NULL},
/* A0AE */ { "SYLLABE YI MIT",NULL},
/* A0AF */ { "SYLLABE YI MIX",NULL},
/* A0B0 */ { "SYLLABE YI MI",NULL},
/* A0B1 */ { "SYLLABE YI MIP",NULL},
/* A0B2 */ { "SYLLABE YI MIEX",NULL},
/* A0B3 */ { "SYLLABE YI MIE",NULL},
/* A0B4 */ { "SYLLABE YI MIEP",NULL},
/* A0B5 */ { "SYLLABE YI MAT",NULL},
/* A0B6 */ { "SYLLABE YI MAX",NULL},
/* A0B7 */ { "SYLLABE YI MA",NULL},
/* A0B8 */ { "SYLLABE YI MAP",NULL},
/* A0B9 */ { "SYLLABE YI MUOT",NULL},
/* A0BA */ { "SYLLABE YI MUOX",NULL},
/* A0BB */ { "SYLLABE YI MUO",NULL},
/* A0BC */ { "SYLLABE YI MUOP",NULL},
/* A0BD */ { "SYLLABE YI MOT",NULL},
/* A0BE */ { "SYLLABE YI MOX",NULL},
/* A0BF */ { "SYLLABE YI MO",NULL},
/* A0C0 */ { "SYLLABE YI MOP",NULL},
/* A0C1 */ { "SYLLABE YI MEX",NULL},
/* A0C2 */ { "SYLLABE YI ME",NULL},
/* A0C3 */ { "SYLLABE YI MUT",NULL},
/* A0C4 */ { "SYLLABE YI MUX",NULL},
/* A0C5 */ { "SYLLABE YI MU",NULL},
/* A0C6 */ { "SYLLABE YI MUP",NULL},
/* A0C7 */ { "SYLLABE YI MURX",NULL},
/* A0C8 */ { "SYLLABE YI MUR",NULL},
/* A0C9 */ { "SYLLABE YI MYT",NULL},
/* A0CA */ { "SYLLABE YI MYX",NULL},
/* A0CB */ { "SYLLABE YI MY",NULL},
/* A0CC */ { "SYLLABE YI MYP",NULL},
/* A0CD */ { "SYLLABE YI FIT",NULL},
/* A0CE */ { "SYLLABE YI FIX",NULL},
/* A0CF */ { "SYLLABE YI FI",NULL},
/* A0D0 */ { "SYLLABE YI FIP",NULL},
/* A0D1 */ { "SYLLABE YI FAT",NULL},
/* A0D2 */ { "SYLLABE YI FAX",NULL},
/* A0D3 */ { "SYLLABE YI FA",NULL},
/* A0D4 */ { "SYLLABE YI FAP",NULL},
/* A0D5 */ { "SYLLABE YI FOX",NULL},
/* A0D6 */ { "SYLLABE YI FO",NULL},
/* A0D7 */ { "SYLLABE YI FOP",NULL},
/* A0D8 */ { "SYLLABE YI FUT",NULL},
/* A0D9 */ { "SYLLABE YI FUX",NULL},
/* A0DA */ { "SYLLABE YI FU",NULL},
/* A0DB */ { "SYLLABE YI FUP",NULL},
/* A0DC */ { "SYLLABE YI FURX",NULL},
/* A0DD */ { "SYLLABE YI FUR",NULL},
/* A0DE */ { "SYLLABE YI FYT",NULL},
/* A0DF */ { "SYLLABE YI FYX",NULL},
/* A0E0 */ { "SYLLABE YI FY",NULL},
/* A0E1 */ { "SYLLABE YI FYP",NULL},
/* A0E2 */ { "SYLLABE YI VIT",NULL},
/* A0E3 */ { "SYLLABE YI VIX",NULL},
/* A0E4 */ { "SYLLABE YI VI",NULL},
/* A0E5 */ { "SYLLABE YI VIP",NULL},
/* A0E6 */ { "SYLLABE YI VIET",NULL},
/* A0E7 */ { "SYLLABE YI VIEX",NULL},
/* A0E8 */ { "SYLLABE YI VIE",NULL},
/* A0E9 */ { "SYLLABE YI VIEP",NULL},
/* A0EA */ { "SYLLABE YI VAT",NULL},
/* A0EB */ { "SYLLABE YI VAX",NULL},
/* A0EC */ { "SYLLABE YI VA",NULL},
/* A0ED */ { "SYLLABE YI VAP",NULL},
/* A0EE */ { "SYLLABE YI VOT",NULL},
/* A0EF */ { "SYLLABE YI VOX",NULL},
/* A0F0 */ { "SYLLABE YI VO",NULL},
/* A0F1 */ { "SYLLABE YI VOP",NULL},
/* A0F2 */ { "SYLLABE YI VEX",NULL},
/* A0F3 */ { "SYLLABE YI VEP",NULL},
/* A0F4 */ { "SYLLABE YI VUT",NULL},
/* A0F5 */ { "SYLLABE YI VUX",NULL},
/* A0F6 */ { "SYLLABE YI VU",NULL},
/* A0F7 */ { "SYLLABE YI VUP",NULL},
/* A0F8 */ { "SYLLABE YI VURX",NULL},
/* A0F9 */ { "SYLLABE YI VUR",NULL},
/* A0FA */ { "SYLLABE YI VYT",NULL},
/* A0FB */ { "SYLLABE YI VYX",NULL},
/* A0FC */ { "SYLLABE YI VY",NULL},
/* A0FD */ { "SYLLABE YI VYP",NULL},
/* A0FE */ { "SYLLABE YI VYRX",NULL},
/* A0FF */ { "SYLLABE YI VYR",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A1[] = {
/* A100 */ { "SYLLABE YI DIT",NULL},
/* A101 */ { "SYLLABE YI DIX",NULL},
/* A102 */ { "SYLLABE YI DI",NULL},
/* A103 */ { "SYLLABE YI DIP",NULL},
/* A104 */ { "SYLLABE YI DIEX",NULL},
/* A105 */ { "SYLLABE YI DIE",NULL},
/* A106 */ { "SYLLABE YI DIEP",NULL},
/* A107 */ { "SYLLABE YI DAT",NULL},
/* A108 */ { "SYLLABE YI DAX",NULL},
/* A109 */ { "SYLLABE YI DA",NULL},
/* A10A */ { "SYLLABE YI DAP",NULL},
/* A10B */ { "SYLLABE YI DUOX",NULL},
/* A10C */ { "SYLLABE YI DUO",NULL},
/* A10D */ { "SYLLABE YI DOT",NULL},
/* A10E */ { "SYLLABE YI DOX",NULL},
/* A10F */ { "SYLLABE YI DO",NULL},
/* A110 */ { "SYLLABE YI DOP",NULL},
/* A111 */ { "SYLLABE YI DEX",NULL},
/* A112 */ { "SYLLABE YI DE",NULL},
/* A113 */ { "SYLLABE YI DEP",NULL},
/* A114 */ { "SYLLABE YI DUT",NULL},
/* A115 */ { "SYLLABE YI DUX",NULL},
/* A116 */ { "SYLLABE YI DU",NULL},
/* A117 */ { "SYLLABE YI DUP",NULL},
/* A118 */ { "SYLLABE YI DURX",NULL},
/* A119 */ { "SYLLABE YI DUR",NULL},
/* A11A */ { "SYLLABE YI TIT",NULL},
/* A11B */ { "SYLLABE YI TIX",NULL},
/* A11C */ { "SYLLABE YI TI",NULL},
/* A11D */ { "SYLLABE YI TIP",NULL},
/* A11E */ { "SYLLABE YI TIEX",NULL},
/* A11F */ { "SYLLABE YI TIE",NULL},
/* A120 */ { "SYLLABE YI TIEP",NULL},
/* A121 */ { "SYLLABE YI TAT",NULL},
/* A122 */ { "SYLLABE YI TAX",NULL},
/* A123 */ { "SYLLABE YI TA",NULL},
/* A124 */ { "SYLLABE YI TAP",NULL},
/* A125 */ { "SYLLABE YI TUOT",NULL},
/* A126 */ { "SYLLABE YI TUOX",NULL},
/* A127 */ { "SYLLABE YI TUO",NULL},
/* A128 */ { "SYLLABE YI TUOP",NULL},
/* A129 */ { "SYLLABE YI TOT",NULL},
/* A12A */ { "SYLLABE YI TOX",NULL},
/* A12B */ { "SYLLABE YI TO",NULL},
/* A12C */ { "SYLLABE YI TOP",NULL},
/* A12D */ { "SYLLABE YI TEX",NULL},
/* A12E */ { "SYLLABE YI TE",NULL},
/* A12F */ { "SYLLABE YI TEP",NULL},
/* A130 */ { "SYLLABE YI TUT",NULL},
/* A131 */ { "SYLLABE YI TUX",NULL},
/* A132 */ { "SYLLABE YI TU",NULL},
/* A133 */ { "SYLLABE YI TUP",NULL},
/* A134 */ { "SYLLABE YI TURX",NULL},
/* A135 */ { "SYLLABE YI TUR",NULL},
/* A136 */ { "SYLLABE YI DDIT",NULL},
/* A137 */ { "SYLLABE YI DDIX",NULL},
/* A138 */ { "SYLLABE YI DDI",NULL},
/* A139 */ { "SYLLABE YI DDIP",NULL},
/* A13A */ { "SYLLABE YI DDIEX",NULL},
/* A13B */ { "SYLLABE YI DDIE",NULL},
/* A13C */ { "SYLLABE YI DDIEP",NULL},
/* A13D */ { "SYLLABE YI DDAT",NULL},
/* A13E */ { "SYLLABE YI DDAX",NULL},
/* A13F */ { "SYLLABE YI DDA",NULL},
/* A140 */ { "SYLLABE YI DDAP",NULL},
/* A141 */ { "SYLLABE YI DDUOX",NULL},
/* A142 */ { "SYLLABE YI DDUO",NULL},
/* A143 */ { "SYLLABE YI DDUOP",NULL},
/* A144 */ { "SYLLABE YI DDOT",NULL},
/* A145 */ { "SYLLABE YI DDOX",NULL},
/* A146 */ { "SYLLABE YI DDO",NULL},
/* A147 */ { "SYLLABE YI DDOP",NULL},
/* A148 */ { "SYLLABE YI DDEX",NULL},
/* A149 */ { "SYLLABE YI DDE",NULL},
/* A14A */ { "SYLLABE YI DDEP",NULL},
/* A14B */ { "SYLLABE YI DDUT",NULL},
/* A14C */ { "SYLLABE YI DDUX",NULL},
/* A14D */ { "SYLLABE YI DDU",NULL},
/* A14E */ { "SYLLABE YI DDUP",NULL},
/* A14F */ { "SYLLABE YI DDURX",NULL},
/* A150 */ { "SYLLABE YI DDUR",NULL},
/* A151 */ { "SYLLABE YI NDIT",NULL},
/* A152 */ { "SYLLABE YI NDIX",NULL},
/* A153 */ { "SYLLABE YI NDI",NULL},
/* A154 */ { "SYLLABE YI NDIP",NULL},
/* A155 */ { "SYLLABE YI NDIEX",NULL},
/* A156 */ { "SYLLABE YI NDIE",NULL},
/* A157 */ { "SYLLABE YI NDAT",NULL},
/* A158 */ { "SYLLABE YI NDAX",NULL},
/* A159 */ { "SYLLABE YI NDA",NULL},
/* A15A */ { "SYLLABE YI NDAP",NULL},
/* A15B */ { "SYLLABE YI NDOT",NULL},
/* A15C */ { "SYLLABE YI NDOX",NULL},
/* A15D */ { "SYLLABE YI NDO",NULL},
/* A15E */ { "SYLLABE YI NDOP",NULL},
/* A15F */ { "SYLLABE YI NDEX",NULL},
/* A160 */ { "SYLLABE YI NDE",NULL},
/* A161 */ { "SYLLABE YI NDEP",NULL},
/* A162 */ { "SYLLABE YI NDUT",NULL},
/* A163 */ { "SYLLABE YI NDUX",NULL},
/* A164 */ { "SYLLABE YI NDU",NULL},
/* A165 */ { "SYLLABE YI NDUP",NULL},
/* A166 */ { "SYLLABE YI NDURX",NULL},
/* A167 */ { "SYLLABE YI NDUR",NULL},
/* A168 */ { "SYLLABE YI HNIT",NULL},
/* A169 */ { "SYLLABE YI HNIX",NULL},
/* A16A */ { "SYLLABE YI HNI",NULL},
/* A16B */ { "SYLLABE YI HNIP",NULL},
/* A16C */ { "SYLLABE YI HNIET",NULL},
/* A16D */ { "SYLLABE YI HNIEX",NULL},
/* A16E */ { "SYLLABE YI HNIE",NULL},
/* A16F */ { "SYLLABE YI HNIEP",NULL},
/* A170 */ { "SYLLABE YI HNAT",NULL},
/* A171 */ { "SYLLABE YI HNAX",NULL},
/* A172 */ { "SYLLABE YI HNA",NULL},
/* A173 */ { "SYLLABE YI HNAP",NULL},
/* A174 */ { "SYLLABE YI HNUOX",NULL},
/* A175 */ { "SYLLABE YI HNUO",NULL},
/* A176 */ { "SYLLABE YI HNOT",NULL},
/* A177 */ { "SYLLABE YI HNOX",NULL},
/* A178 */ { "SYLLABE YI HNOP",NULL},
/* A179 */ { "SYLLABE YI HNEX",NULL},
/* A17A */ { "SYLLABE YI HNE",NULL},
/* A17B */ { "SYLLABE YI HNEP",NULL},
/* A17C */ { "SYLLABE YI HNUT",NULL},
/* A17D */ { "SYLLABE YI NIT",NULL},
/* A17E */ { "SYLLABE YI NIX",NULL},
/* A17F */ { "SYLLABE YI NI",NULL},
/* A180 */ { "SYLLABE YI NIP",NULL},
/* A181 */ { "SYLLABE YI NIEX",NULL},
/* A182 */ { "SYLLABE YI NIE",NULL},
/* A183 */ { "SYLLABE YI NIEP",NULL},
/* A184 */ { "SYLLABE YI NAX",NULL},
/* A185 */ { "SYLLABE YI NA",NULL},
/* A186 */ { "SYLLABE YI NAP",NULL},
/* A187 */ { "SYLLABE YI NUOX",NULL},
/* A188 */ { "SYLLABE YI NUO",NULL},
/* A189 */ { "SYLLABE YI NUOP",NULL},
/* A18A */ { "SYLLABE YI NOT",NULL},
/* A18B */ { "SYLLABE YI NOX",NULL},
/* A18C */ { "SYLLABE YI NO",NULL},
/* A18D */ { "SYLLABE YI NOP",NULL},
/* A18E */ { "SYLLABE YI NEX",NULL},
/* A18F */ { "SYLLABE YI NE",NULL},
/* A190 */ { "SYLLABE YI NEP",NULL},
/* A191 */ { "SYLLABE YI NUT",NULL},
/* A192 */ { "SYLLABE YI NUX",NULL},
/* A193 */ { "SYLLABE YI NU",NULL},
/* A194 */ { "SYLLABE YI NUP",NULL},
/* A195 */ { "SYLLABE YI NURX",NULL},
/* A196 */ { "SYLLABE YI NUR",NULL},
/* A197 */ { "SYLLABE YI HLIT",NULL},
/* A198 */ { "SYLLABE YI HLIX",NULL},
/* A199 */ { "SYLLABE YI HLI",NULL},
/* A19A */ { "SYLLABE YI HLIP",NULL},
/* A19B */ { "SYLLABE YI HLIEX",NULL},
/* A19C */ { "SYLLABE YI HLIE",NULL},
/* A19D */ { "SYLLABE YI HLIEP",NULL},
/* A19E */ { "SYLLABE YI HLAT",NULL},
/* A19F */ { "SYLLABE YI HLAX",NULL},
/* A1A0 */ { "SYLLABE YI HLA",NULL},
/* A1A1 */ { "SYLLABE YI HLAP",NULL},
/* A1A2 */ { "SYLLABE YI HLUOX",NULL},
/* A1A3 */ { "SYLLABE YI HLUO",NULL},
/* A1A4 */ { "SYLLABE YI HLUOP",NULL},
/* A1A5 */ { "SYLLABE YI HLOX",NULL},
/* A1A6 */ { "SYLLABE YI HLO",NULL},
/* A1A7 */ { "SYLLABE YI HLOP",NULL},
/* A1A8 */ { "SYLLABE YI HLEX",NULL},
/* A1A9 */ { "SYLLABE YI HLE",NULL},
/* A1AA */ { "SYLLABE YI HLEP",NULL},
/* A1AB */ { "SYLLABE YI HLUT",NULL},
/* A1AC */ { "SYLLABE YI HLUX",NULL},
/* A1AD */ { "SYLLABE YI HLU",NULL},
/* A1AE */ { "SYLLABE YI HLUP",NULL},
/* A1AF */ { "SYLLABE YI HLURX",NULL},
/* A1B0 */ { "SYLLABE YI HLUR",NULL},
/* A1B1 */ { "SYLLABE YI HLYT",NULL},
/* A1B2 */ { "SYLLABE YI HLYX",NULL},
/* A1B3 */ { "SYLLABE YI HLY",NULL},
/* A1B4 */ { "SYLLABE YI HLYP",NULL},
/* A1B5 */ { "SYLLABE YI HLYRX",NULL},
/* A1B6 */ { "SYLLABE YI HLYR",NULL},
/* A1B7 */ { "SYLLABE YI LIT",NULL},
/* A1B8 */ { "SYLLABE YI LIX",NULL},
/* A1B9 */ { "SYLLABE YI LI",NULL},
/* A1BA */ { "SYLLABE YI LIP",NULL},
/* A1BB */ { "SYLLABE YI LIET",NULL},
/* A1BC */ { "SYLLABE YI LIEX",NULL},
/* A1BD */ { "SYLLABE YI LIE",NULL},
/* A1BE */ { "SYLLABE YI LIEP",NULL},
/* A1BF */ { "SYLLABE YI LAT",NULL},
/* A1C0 */ { "SYLLABE YI LAX",NULL},
/* A1C1 */ { "SYLLABE YI LA",NULL},
/* A1C2 */ { "SYLLABE YI LAP",NULL},
/* A1C3 */ { "SYLLABE YI LUOT",NULL},
/* A1C4 */ { "SYLLABE YI LUOX",NULL},
/* A1C5 */ { "SYLLABE YI LUO",NULL},
/* A1C6 */ { "SYLLABE YI LUOP",NULL},
/* A1C7 */ { "SYLLABE YI LOT",NULL},
/* A1C8 */ { "SYLLABE YI LOX",NULL},
/* A1C9 */ { "SYLLABE YI LO",NULL},
/* A1CA */ { "SYLLABE YI LOP",NULL},
/* A1CB */ { "SYLLABE YI LEX",NULL},
/* A1CC */ { "SYLLABE YI LE",NULL},
/* A1CD */ { "SYLLABE YI LEP",NULL},
/* A1CE */ { "SYLLABE YI LUT",NULL},
/* A1CF */ { "SYLLABE YI LUX",NULL},
/* A1D0 */ { "SYLLABE YI LU",NULL},
/* A1D1 */ { "SYLLABE YI LUP",NULL},
/* A1D2 */ { "SYLLABE YI LURX",NULL},
/* A1D3 */ { "SYLLABE YI LUR",NULL},
/* A1D4 */ { "SYLLABE YI LYT",NULL},
/* A1D5 */ { "SYLLABE YI LYX",NULL},
/* A1D6 */ { "SYLLABE YI LY",NULL},
/* A1D7 */ { "SYLLABE YI LYP",NULL},
/* A1D8 */ { "SYLLABE YI LYRX",NULL},
/* A1D9 */ { "SYLLABE YI LYR",NULL},
/* A1DA */ { "SYLLABE YI GIT",NULL},
/* A1DB */ { "SYLLABE YI GIX",NULL},
/* A1DC */ { "SYLLABE YI GI",NULL},
/* A1DD */ { "SYLLABE YI GIP",NULL},
/* A1DE */ { "SYLLABE YI GIET",NULL},
/* A1DF */ { "SYLLABE YI GIEX",NULL},
/* A1E0 */ { "SYLLABE YI GIE",NULL},
/* A1E1 */ { "SYLLABE YI GIEP",NULL},
/* A1E2 */ { "SYLLABE YI GAT",NULL},
/* A1E3 */ { "SYLLABE YI GAX",NULL},
/* A1E4 */ { "SYLLABE YI GA",NULL},
/* A1E5 */ { "SYLLABE YI GAP",NULL},
/* A1E6 */ { "SYLLABE YI GUOT",NULL},
/* A1E7 */ { "SYLLABE YI GUOX",NULL},
/* A1E8 */ { "SYLLABE YI GUO",NULL},
/* A1E9 */ { "SYLLABE YI GUOP",NULL},
/* A1EA */ { "SYLLABE YI GOT",NULL},
/* A1EB */ { "SYLLABE YI GOX",NULL},
/* A1EC */ { "SYLLABE YI GO",NULL},
/* A1ED */ { "SYLLABE YI GOP",NULL},
/* A1EE */ { "SYLLABE YI GET",NULL},
/* A1EF */ { "SYLLABE YI GEX",NULL},
/* A1F0 */ { "SYLLABE YI GE",NULL},
/* A1F1 */ { "SYLLABE YI GEP",NULL},
/* A1F2 */ { "SYLLABE YI GUT",NULL},
/* A1F3 */ { "SYLLABE YI GUX",NULL},
/* A1F4 */ { "SYLLABE YI GU",NULL},
/* A1F5 */ { "SYLLABE YI GUP",NULL},
/* A1F6 */ { "SYLLABE YI GURX",NULL},
/* A1F7 */ { "SYLLABE YI GUR",NULL},
/* A1F8 */ { "SYLLABE YI KIT",NULL},
/* A1F9 */ { "SYLLABE YI KIX",NULL},
/* A1FA */ { "SYLLABE YI KI",NULL},
/* A1FB */ { "SYLLABE YI KIP",NULL},
/* A1FC */ { "SYLLABE YI KIEX",NULL},
/* A1FD */ { "SYLLABE YI KIE",NULL},
/* A1FE */ { "SYLLABE YI KIEP",NULL},
/* A1FF */ { "SYLLABE YI KAT",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A2[] = {
/* A200 */ { "SYLLABE YI KAX",NULL},
/* A201 */ { "SYLLABE YI KA",NULL},
/* A202 */ { "SYLLABE YI KAP",NULL},
/* A203 */ { "SYLLABE YI KUOX",NULL},
/* A204 */ { "SYLLABE YI KUO",NULL},
/* A205 */ { "SYLLABE YI KUOP",NULL},
/* A206 */ { "SYLLABE YI KOT",NULL},
/* A207 */ { "SYLLABE YI KOX",NULL},
/* A208 */ { "SYLLABE YI KO",NULL},
/* A209 */ { "SYLLABE YI KOP",NULL},
/* A20A */ { "SYLLABE YI KET",NULL},
/* A20B */ { "SYLLABE YI KEX",NULL},
/* A20C */ { "SYLLABE YI KE",NULL},
/* A20D */ { "SYLLABE YI KEP",NULL},
/* A20E */ { "SYLLABE YI KUT",NULL},
/* A20F */ { "SYLLABE YI KUX",NULL},
/* A210 */ { "SYLLABE YI KU",NULL},
/* A211 */ { "SYLLABE YI KUP",NULL},
/* A212 */ { "SYLLABE YI KURX",NULL},
/* A213 */ { "SYLLABE YI KUR",NULL},
/* A214 */ { "SYLLABE YI GGIT",NULL},
/* A215 */ { "SYLLABE YI GGIX",NULL},
/* A216 */ { "SYLLABE YI GGI",NULL},
/* A217 */ { "SYLLABE YI GGIEX",NULL},
/* A218 */ { "SYLLABE YI GGIE",NULL},
/* A219 */ { "SYLLABE YI GGIEP",NULL},
/* A21A */ { "SYLLABE YI GGAT",NULL},
/* A21B */ { "SYLLABE YI GGAX",NULL},
/* A21C */ { "SYLLABE YI GGA",NULL},
/* A21D */ { "SYLLABE YI GGAP",NULL},
/* A21E */ { "SYLLABE YI GGUOT",NULL},
/* A21F */ { "SYLLABE YI GGUOX",NULL},
/* A220 */ { "SYLLABE YI GGUO",NULL},
/* A221 */ { "SYLLABE YI GGUOP",NULL},
/* A222 */ { "SYLLABE YI GGOT",NULL},
/* A223 */ { "SYLLABE YI GGOX",NULL},
/* A224 */ { "SYLLABE YI GGO",NULL},
/* A225 */ { "SYLLABE YI GGOP",NULL},
/* A226 */ { "SYLLABE YI GGET",NULL},
/* A227 */ { "SYLLABE YI GGEX",NULL},
/* A228 */ { "SYLLABE YI GGE",NULL},
/* A229 */ { "SYLLABE YI GGEP",NULL},
/* A22A */ { "SYLLABE YI GGUT",NULL},
/* A22B */ { "SYLLABE YI GGUX",NULL},
/* A22C */ { "SYLLABE YI GGU",NULL},
/* A22D */ { "SYLLABE YI GGUP",NULL},
/* A22E */ { "SYLLABE YI GGURX",NULL},
/* A22F */ { "SYLLABE YI GGUR",NULL},
/* A230 */ { "SYLLABE YI MGIEX",NULL},
/* A231 */ { "SYLLABE YI MGIE",NULL},
/* A232 */ { "SYLLABE YI MGAT",NULL},
/* A233 */ { "SYLLABE YI MGAX",NULL},
/* A234 */ { "SYLLABE YI MGA",NULL},
/* A235 */ { "SYLLABE YI MGAP",NULL},
/* A236 */ { "SYLLABE YI MGUOX",NULL},
/* A237 */ { "SYLLABE YI MGUO",NULL},
/* A238 */ { "SYLLABE YI MGUOP",NULL},
/* A239 */ { "SYLLABE YI MGOT",NULL},
/* A23A */ { "SYLLABE YI MGOX",NULL},
/* A23B */ { "SYLLABE YI MGO",NULL},
/* A23C */ { "SYLLABE YI MGOP",NULL},
/* A23D */ { "SYLLABE YI MGEX",NULL},
/* A23E */ { "SYLLABE YI MGE",NULL},
/* A23F */ { "SYLLABE YI MGEP",NULL},
/* A240 */ { "SYLLABE YI MGUT",NULL},
/* A241 */ { "SYLLABE YI MGUX",NULL},
/* A242 */ { "SYLLABE YI MGU",NULL},
/* A243 */ { "SYLLABE YI MGUP",NULL},
/* A244 */ { "SYLLABE YI MGURX",NULL},
/* A245 */ { "SYLLABE YI MGUR",NULL},
/* A246 */ { "SYLLABE YI HXIT",NULL},
/* A247 */ { "SYLLABE YI HXIX",NULL},
/* A248 */ { "SYLLABE YI HXI",NULL},
/* A249 */ { "SYLLABE YI HXIP",NULL},
/* A24A */ { "SYLLABE YI HXIET",NULL},
/* A24B */ { "SYLLABE YI HXIEX",NULL},
/* A24C */ { "SYLLABE YI HXIE",NULL},
/* A24D */ { "SYLLABE YI HXIEP",NULL},
/* A24E */ { "SYLLABE YI HXAT",NULL},
/* A24F */ { "SYLLABE YI HXAX",NULL},
/* A250 */ { "SYLLABE YI HXA",NULL},
/* A251 */ { "SYLLABE YI HXAP",NULL},
/* A252 */ { "SYLLABE YI HXUOT",NULL},
/* A253 */ { "SYLLABE YI HXUOX",NULL},
/* A254 */ { "SYLLABE YI HXUO",NULL},
/* A255 */ { "SYLLABE YI HXUOP",NULL},
/* A256 */ { "SYLLABE YI HXOT",NULL},
/* A257 */ { "SYLLABE YI HXOX",NULL},
/* A258 */ { "SYLLABE YI HXO",NULL},
/* A259 */ { "SYLLABE YI HXOP",NULL},
/* A25A */ { "SYLLABE YI HXEX",NULL},
/* A25B */ { "SYLLABE YI HXE",NULL},
/* A25C */ { "SYLLABE YI HXEP",NULL},
/* A25D */ { "SYLLABE YI NGIEX",NULL},
/* A25E */ { "SYLLABE YI NGIE",NULL},
/* A25F */ { "SYLLABE YI NGIEP",NULL},
/* A260 */ { "SYLLABE YI NGAT",NULL},
/* A261 */ { "SYLLABE YI NGAX",NULL},
/* A262 */ { "SYLLABE YI NGA",NULL},
/* A263 */ { "SYLLABE YI NGAP",NULL},
/* A264 */ { "SYLLABE YI NGUOT",NULL},
/* A265 */ { "SYLLABE YI NGUOX",NULL},
/* A266 */ { "SYLLABE YI NGUO",NULL},
/* A267 */ { "SYLLABE YI NGOT",NULL},
/* A268 */ { "SYLLABE YI NGOX",NULL},
/* A269 */ { "SYLLABE YI NGO",NULL},
/* A26A */ { "SYLLABE YI NGOP",NULL},
/* A26B */ { "SYLLABE YI NGEX",NULL},
/* A26C */ { "SYLLABE YI NGE",NULL},
/* A26D */ { "SYLLABE YI NGEP",NULL},
/* A26E */ { "SYLLABE YI HIT",NULL},
/* A26F */ { "SYLLABE YI HIEX",NULL},
/* A270 */ { "SYLLABE YI HIE",NULL},
/* A271 */ { "SYLLABE YI HAT",NULL},
/* A272 */ { "SYLLABE YI HAX",NULL},
/* A273 */ { "SYLLABE YI HA",NULL},
/* A274 */ { "SYLLABE YI HAP",NULL},
/* A275 */ { "SYLLABE YI HUOT",NULL},
/* A276 */ { "SYLLABE YI HUOX",NULL},
/* A277 */ { "SYLLABE YI HUO",NULL},
/* A278 */ { "SYLLABE YI HUOP",NULL},
/* A279 */ { "SYLLABE YI HOT",NULL},
/* A27A */ { "SYLLABE YI HOX",NULL},
/* A27B */ { "SYLLABE YI HO",NULL},
/* A27C */ { "SYLLABE YI HOP",NULL},
/* A27D */ { "SYLLABE YI HEX",NULL},
/* A27E */ { "SYLLABE YI HE",NULL},
/* A27F */ { "SYLLABE YI HEP",NULL},
/* A280 */ { "SYLLABE YI WAT",NULL},
/* A281 */ { "SYLLABE YI WAX",NULL},
/* A282 */ { "SYLLABE YI WA",NULL},
/* A283 */ { "SYLLABE YI WAP",NULL},
/* A284 */ { "SYLLABE YI WUOX",NULL},
/* A285 */ { "SYLLABE YI WUO",NULL},
/* A286 */ { "SYLLABE YI WUOP",NULL},
/* A287 */ { "SYLLABE YI WOX",NULL},
/* A288 */ { "SYLLABE YI WO",NULL},
/* A289 */ { "SYLLABE YI WOP",NULL},
/* A28A */ { "SYLLABE YI WEX",NULL},
/* A28B */ { "SYLLABE YI WE",NULL},
/* A28C */ { "SYLLABE YI WEP",NULL},
/* A28D */ { "SYLLABE YI ZIT",NULL},
/* A28E */ { "SYLLABE YI ZIX",NULL},
/* A28F */ { "SYLLABE YI ZI",NULL},
/* A290 */ { "SYLLABE YI ZIP",NULL},
/* A291 */ { "SYLLABE YI ZIEX",NULL},
/* A292 */ { "SYLLABE YI ZIE",NULL},
/* A293 */ { "SYLLABE YI ZIEP",NULL},
/* A294 */ { "SYLLABE YI ZAT",NULL},
/* A295 */ { "SYLLABE YI ZAX",NULL},
/* A296 */ { "SYLLABE YI ZA",NULL},
/* A297 */ { "SYLLABE YI ZAP",NULL},
/* A298 */ { "SYLLABE YI ZUOX",NULL},
/* A299 */ { "SYLLABE YI ZUO",NULL},
/* A29A */ { "SYLLABE YI ZUOP",NULL},
/* A29B */ { "SYLLABE YI ZOT",NULL},
/* A29C */ { "SYLLABE YI ZOX",NULL},
/* A29D */ { "SYLLABE YI ZO",NULL},
/* A29E */ { "SYLLABE YI ZOP",NULL},
/* A29F */ { "SYLLABE YI ZEX",NULL},
/* A2A0 */ { "SYLLABE YI ZE",NULL},
/* A2A1 */ { "SYLLABE YI ZEP",NULL},
/* A2A2 */ { "SYLLABE YI ZUT",NULL},
/* A2A3 */ { "SYLLABE YI ZUX",NULL},
/* A2A4 */ { "SYLLABE YI ZU",NULL},
/* A2A5 */ { "SYLLABE YI ZUP",NULL},
/* A2A6 */ { "SYLLABE YI ZURX",NULL},
/* A2A7 */ { "SYLLABE YI ZUR",NULL},
/* A2A8 */ { "SYLLABE YI ZYT",NULL},
/* A2A9 */ { "SYLLABE YI ZYX",NULL},
/* A2AA */ { "SYLLABE YI ZY",NULL},
/* A2AB */ { "SYLLABE YI ZYP",NULL},
/* A2AC */ { "SYLLABE YI ZYRX",NULL},
/* A2AD */ { "SYLLABE YI ZYR",NULL},
/* A2AE */ { "SYLLABE YI CIT",NULL},
/* A2AF */ { "SYLLABE YI CIX",NULL},
/* A2B0 */ { "SYLLABE YI CI",NULL},
/* A2B1 */ { "SYLLABE YI CIP",NULL},
/* A2B2 */ { "SYLLABE YI CIET",NULL},
/* A2B3 */ { "SYLLABE YI CIEX",NULL},
/* A2B4 */ { "SYLLABE YI CIE",NULL},
/* A2B5 */ { "SYLLABE YI CIEP",NULL},
/* A2B6 */ { "SYLLABE YI CAT",NULL},
/* A2B7 */ { "SYLLABE YI CAX",NULL},
/* A2B8 */ { "SYLLABE YI CA",NULL},
/* A2B9 */ { "SYLLABE YI CAP",NULL},
/* A2BA */ { "SYLLABE YI CUOX",NULL},
/* A2BB */ { "SYLLABE YI CUO",NULL},
/* A2BC */ { "SYLLABE YI CUOP",NULL},
/* A2BD */ { "SYLLABE YI COT",NULL},
/* A2BE */ { "SYLLABE YI COX",NULL},
/* A2BF */ { "SYLLABE YI CO",NULL},
/* A2C0 */ { "SYLLABE YI COP",NULL},
/* A2C1 */ { "SYLLABE YI CEX",NULL},
/* A2C2 */ { "SYLLABE YI CE",NULL},
/* A2C3 */ { "SYLLABE YI CEP",NULL},
/* A2C4 */ { "SYLLABE YI CUT",NULL},
/* A2C5 */ { "SYLLABE YI CUX",NULL},
/* A2C6 */ { "SYLLABE YI CU",NULL},
/* A2C7 */ { "SYLLABE YI CUP",NULL},
/* A2C8 */ { "SYLLABE YI CURX",NULL},
/* A2C9 */ { "SYLLABE YI CUR",NULL},
/* A2CA */ { "SYLLABE YI CYT",NULL},
/* A2CB */ { "SYLLABE YI CYX",NULL},
/* A2CC */ { "SYLLABE YI CY",NULL},
/* A2CD */ { "SYLLABE YI CYP",NULL},
/* A2CE */ { "SYLLABE YI CYRX",NULL},
/* A2CF */ { "SYLLABE YI CYR",NULL},
/* A2D0 */ { "SYLLABE YI ZZIT",NULL},
/* A2D1 */ { "SYLLABE YI ZZIX",NULL},
/* A2D2 */ { "SYLLABE YI ZZI",NULL},
/* A2D3 */ { "SYLLABE YI ZZIP",NULL},
/* A2D4 */ { "SYLLABE YI ZZIET",NULL},
/* A2D5 */ { "SYLLABE YI ZZIEX",NULL},
/* A2D6 */ { "SYLLABE YI ZZIE",NULL},
/* A2D7 */ { "SYLLABE YI ZZIEP",NULL},
/* A2D8 */ { "SYLLABE YI ZZAT",NULL},
/* A2D9 */ { "SYLLABE YI ZZAX",NULL},
/* A2DA */ { "SYLLABE YI ZZA",NULL},
/* A2DB */ { "SYLLABE YI ZZAP",NULL},
/* A2DC */ { "SYLLABE YI ZZOX",NULL},
/* A2DD */ { "SYLLABE YI ZZO",NULL},
/* A2DE */ { "SYLLABE YI ZZOP",NULL},
/* A2DF */ { "SYLLABE YI ZZEX",NULL},
/* A2E0 */ { "SYLLABE YI ZZE",NULL},
/* A2E1 */ { "SYLLABE YI ZZEP",NULL},
/* A2E2 */ { "SYLLABE YI ZZUX",NULL},
/* A2E3 */ { "SYLLABE YI ZZU",NULL},
/* A2E4 */ { "SYLLABE YI ZZUP",NULL},
/* A2E5 */ { "SYLLABE YI ZZURX",NULL},
/* A2E6 */ { "SYLLABE YI ZZUR",NULL},
/* A2E7 */ { "SYLLABE YI ZZYT",NULL},
/* A2E8 */ { "SYLLABE YI ZZYX",NULL},
/* A2E9 */ { "SYLLABE YI ZZY",NULL},
/* A2EA */ { "SYLLABE YI ZZYP",NULL},
/* A2EB */ { "SYLLABE YI ZZYRX",NULL},
/* A2EC */ { "SYLLABE YI ZZYR",NULL},
/* A2ED */ { "SYLLABE YI NZIT",NULL},
/* A2EE */ { "SYLLABE YI NZIX",NULL},
/* A2EF */ { "SYLLABE YI NZI",NULL},
/* A2F0 */ { "SYLLABE YI NZIP",NULL},
/* A2F1 */ { "SYLLABE YI NZIEX",NULL},
/* A2F2 */ { "SYLLABE YI NZIE",NULL},
/* A2F3 */ { "SYLLABE YI NZIEP",NULL},
/* A2F4 */ { "SYLLABE YI NZAT",NULL},
/* A2F5 */ { "SYLLABE YI NZAX",NULL},
/* A2F6 */ { "SYLLABE YI NZA",NULL},
/* A2F7 */ { "SYLLABE YI NZAP",NULL},
/* A2F8 */ { "SYLLABE YI NZUOX",NULL},
/* A2F9 */ { "SYLLABE YI NZUO",NULL},
/* A2FA */ { "SYLLABE YI NZOX",NULL},
/* A2FB */ { "SYLLABE YI NZOP",NULL},
/* A2FC */ { "SYLLABE YI NZEX",NULL},
/* A2FD */ { "SYLLABE YI NZE",NULL},
/* A2FE */ { "SYLLABE YI NZUX",NULL},
/* A2FF */ { "SYLLABE YI NZU",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A3[] = {
/* A300 */ { "SYLLABE YI NZUP",NULL},
/* A301 */ { "SYLLABE YI NZURX",NULL},
/* A302 */ { "SYLLABE YI NZUR",NULL},
/* A303 */ { "SYLLABE YI NZYT",NULL},
/* A304 */ { "SYLLABE YI NZYX",NULL},
/* A305 */ { "SYLLABE YI NZY",NULL},
/* A306 */ { "SYLLABE YI NZYP",NULL},
/* A307 */ { "SYLLABE YI NZYRX",NULL},
/* A308 */ { "SYLLABE YI NZYR",NULL},
/* A309 */ { "SYLLABE YI SIT",NULL},
/* A30A */ { "SYLLABE YI SIX",NULL},
/* A30B */ { "SYLLABE YI SI",NULL},
/* A30C */ { "SYLLABE YI SIP",NULL},
/* A30D */ { "SYLLABE YI SIEX",NULL},
/* A30E */ { "SYLLABE YI SIE",NULL},
/* A30F */ { "SYLLABE YI SIEP",NULL},
/* A310 */ { "SYLLABE YI SAT",NULL},
/* A311 */ { "SYLLABE YI SAX",NULL},
/* A312 */ { "SYLLABE YI SA",NULL},
/* A313 */ { "SYLLABE YI SAP",NULL},
/* A314 */ { "SYLLABE YI SUOX",NULL},
/* A315 */ { "SYLLABE YI SUO",NULL},
/* A316 */ { "SYLLABE YI SUOP",NULL},
/* A317 */ { "SYLLABE YI SOT",NULL},
/* A318 */ { "SYLLABE YI SOX",NULL},
/* A319 */ { "SYLLABE YI SO",NULL},
/* A31A */ { "SYLLABE YI SOP",NULL},
/* A31B */ { "SYLLABE YI SEX",NULL},
/* A31C */ { "SYLLABE YI SE",NULL},
/* A31D */ { "SYLLABE YI SEP",NULL},
/* A31E */ { "SYLLABE YI SUT",NULL},
/* A31F */ { "SYLLABE YI SUX",NULL},
/* A320 */ { "SYLLABE YI SU",NULL},
/* A321 */ { "SYLLABE YI SUP",NULL},
/* A322 */ { "SYLLABE YI SURX",NULL},
/* A323 */ { "SYLLABE YI SUR",NULL},
/* A324 */ { "SYLLABE YI SYT",NULL},
/* A325 */ { "SYLLABE YI SYX",NULL},
/* A326 */ { "SYLLABE YI SY",NULL},
/* A327 */ { "SYLLABE YI SYP",NULL},
/* A328 */ { "SYLLABE YI SYRX",NULL},
/* A329 */ { "SYLLABE YI SYR",NULL},
/* A32A */ { "SYLLABE YI SSIT",NULL},
/* A32B */ { "SYLLABE YI SSIX",NULL},
/* A32C */ { "SYLLABE YI SSI",NULL},
/* A32D */ { "SYLLABE YI SSIP",NULL},
/* A32E */ { "SYLLABE YI SSIEX",NULL},
/* A32F */ { "SYLLABE YI SSIE",NULL},
/* A330 */ { "SYLLABE YI SSIEP",NULL},
/* A331 */ { "SYLLABE YI SSAT",NULL},
/* A332 */ { "SYLLABE YI SSAX",NULL},
/* A333 */ { "SYLLABE YI SSA",NULL},
/* A334 */ { "SYLLABE YI SSAP",NULL},
/* A335 */ { "SYLLABE YI SSOT",NULL},
/* A336 */ { "SYLLABE YI SSOX",NULL},
/* A337 */ { "SYLLABE YI SSO",NULL},
/* A338 */ { "SYLLABE YI SSOP",NULL},
/* A339 */ { "SYLLABE YI SSEX",NULL},
/* A33A */ { "SYLLABE YI SSE",NULL},
/* A33B */ { "SYLLABE YI SSEP",NULL},
/* A33C */ { "SYLLABE YI SSUT",NULL},
/* A33D */ { "SYLLABE YI SSUX",NULL},
/* A33E */ { "SYLLABE YI SSU",NULL},
/* A33F */ { "SYLLABE YI SSUP",NULL},
/* A340 */ { "SYLLABE YI SSYT",NULL},
/* A341 */ { "SYLLABE YI SSYX",NULL},
/* A342 */ { "SYLLABE YI SSY",NULL},
/* A343 */ { "SYLLABE YI SSYP",NULL},
/* A344 */ { "SYLLABE YI SSYRX",NULL},
/* A345 */ { "SYLLABE YI SSYR",NULL},
/* A346 */ { "SYLLABE YI ZHAT",NULL},
/* A347 */ { "SYLLABE YI ZHAX",NULL},
/* A348 */ { "SYLLABE YI ZHA",NULL},
/* A349 */ { "SYLLABE YI ZHAP",NULL},
/* A34A */ { "SYLLABE YI ZHUOX",NULL},
/* A34B */ { "SYLLABE YI ZHUO",NULL},
/* A34C */ { "SYLLABE YI ZHUOP",NULL},
/* A34D */ { "SYLLABE YI ZHOT",NULL},
/* A34E */ { "SYLLABE YI ZHOX",NULL},
/* A34F */ { "SYLLABE YI ZHO",NULL},
/* A350 */ { "SYLLABE YI ZHOP",NULL},
/* A351 */ { "SYLLABE YI ZHET",NULL},
/* A352 */ { "SYLLABE YI ZHEX",NULL},
/* A353 */ { "SYLLABE YI ZHE",NULL},
/* A354 */ { "SYLLABE YI ZHEP",NULL},
/* A355 */ { "SYLLABE YI ZHUT",NULL},
/* A356 */ { "SYLLABE YI ZHUX",NULL},
/* A357 */ { "SYLLABE YI ZHU",NULL},
/* A358 */ { "SYLLABE YI ZHUP",NULL},
/* A359 */ { "SYLLABE YI ZHURX",NULL},
/* A35A */ { "SYLLABE YI ZHUR",NULL},
/* A35B */ { "SYLLABE YI ZHYT",NULL},
/* A35C */ { "SYLLABE YI ZHYX",NULL},
/* A35D */ { "SYLLABE YI ZHY",NULL},
/* A35E */ { "SYLLABE YI ZHYP",NULL},
/* A35F */ { "SYLLABE YI ZHYRX",NULL},
/* A360 */ { "SYLLABE YI ZHYR",NULL},
/* A361 */ { "SYLLABE YI CHAT",NULL},
/* A362 */ { "SYLLABE YI CHAX",NULL},
/* A363 */ { "SYLLABE YI CHA",NULL},
/* A364 */ { "SYLLABE YI CHAP",NULL},
/* A365 */ { "SYLLABE YI CHUOT",NULL},
/* A366 */ { "SYLLABE YI CHUOX",NULL},
/* A367 */ { "SYLLABE YI CHUO",NULL},
/* A368 */ { "SYLLABE YI CHUOP",NULL},
/* A369 */ { "SYLLABE YI CHOT",NULL},
/* A36A */ { "SYLLABE YI CHOX",NULL},
/* A36B */ { "SYLLABE YI CHO",NULL},
/* A36C */ { "SYLLABE YI CHOP",NULL},
/* A36D */ { "SYLLABE YI CHET",NULL},
/* A36E */ { "SYLLABE YI CHEX",NULL},
/* A36F */ { "SYLLABE YI CHE",NULL},
/* A370 */ { "SYLLABE YI CHEP",NULL},
/* A371 */ { "SYLLABE YI CHUX",NULL},
/* A372 */ { "SYLLABE YI CHU",NULL},
/* A373 */ { "SYLLABE YI CHUP",NULL},
/* A374 */ { "SYLLABE YI CHURX",NULL},
/* A375 */ { "SYLLABE YI CHUR",NULL},
/* A376 */ { "SYLLABE YI CHYT",NULL},
/* A377 */ { "SYLLABE YI CHYX",NULL},
/* A378 */ { "SYLLABE YI CHY",NULL},
/* A379 */ { "SYLLABE YI CHYP",NULL},
/* A37A */ { "SYLLABE YI CHYRX",NULL},
/* A37B */ { "SYLLABE YI CHYR",NULL},
/* A37C */ { "SYLLABE YI RRAX",NULL},
/* A37D */ { "SYLLABE YI RRA",NULL},
/* A37E */ { "SYLLABE YI RRUOX",NULL},
/* A37F */ { "SYLLABE YI RRUO",NULL},
/* A380 */ { "SYLLABE YI RROT",NULL},
/* A381 */ { "SYLLABE YI RROX",NULL},
/* A382 */ { "SYLLABE YI RRO",NULL},
/* A383 */ { "SYLLABE YI RROP",NULL},
/* A384 */ { "SYLLABE YI RRET",NULL},
/* A385 */ { "SYLLABE YI RREX",NULL},
/* A386 */ { "SYLLABE YI RRE",NULL},
/* A387 */ { "SYLLABE YI RREP",NULL},
/* A388 */ { "SYLLABE YI RRUT",NULL},
/* A389 */ { "SYLLABE YI RRUX",NULL},
/* A38A */ { "SYLLABE YI RRU",NULL},
/* A38B */ { "SYLLABE YI RRUP",NULL},
/* A38C */ { "SYLLABE YI RRURX",NULL},
/* A38D */ { "SYLLABE YI RRUR",NULL},
/* A38E */ { "SYLLABE YI RRYT",NULL},
/* A38F */ { "SYLLABE YI RRYX",NULL},
/* A390 */ { "SYLLABE YI RRY",NULL},
/* A391 */ { "SYLLABE YI RRYP",NULL},
/* A392 */ { "SYLLABE YI RRYRX",NULL},
/* A393 */ { "SYLLABE YI RRYR",NULL},
/* A394 */ { "SYLLABE YI NRAT",NULL},
/* A395 */ { "SYLLABE YI NRAX",NULL},
/* A396 */ { "SYLLABE YI NRA",NULL},
/* A397 */ { "SYLLABE YI NRAP",NULL},
/* A398 */ { "SYLLABE YI NROX",NULL},
/* A399 */ { "SYLLABE YI NRO",NULL},
/* A39A */ { "SYLLABE YI NROP",NULL},
/* A39B */ { "SYLLABE YI NRET",NULL},
/* A39C */ { "SYLLABE YI NREX",NULL},
/* A39D */ { "SYLLABE YI NRE",NULL},
/* A39E */ { "SYLLABE YI NREP",NULL},
/* A39F */ { "SYLLABE YI NRUT",NULL},
/* A3A0 */ { "SYLLABE YI NRUX",NULL},
/* A3A1 */ { "SYLLABE YI NRU",NULL},
/* A3A2 */ { "SYLLABE YI NRUP",NULL},
/* A3A3 */ { "SYLLABE YI NRURX",NULL},
/* A3A4 */ { "SYLLABE YI NRUR",NULL},
/* A3A5 */ { "SYLLABE YI NRYT",NULL},
/* A3A6 */ { "SYLLABE YI NRYX",NULL},
/* A3A7 */ { "SYLLABE YI NRY",NULL},
/* A3A8 */ { "SYLLABE YI NRYP",NULL},
/* A3A9 */ { "SYLLABE YI NRYRX",NULL},
/* A3AA */ { "SYLLABE YI NRYR",NULL},
/* A3AB */ { "SYLLABE YI SHAT",NULL},
/* A3AC */ { "SYLLABE YI SHAX",NULL},
/* A3AD */ { "SYLLABE YI SHA",NULL},
/* A3AE */ { "SYLLABE YI SHAP",NULL},
/* A3AF */ { "SYLLABE YI SHUOX",NULL},
/* A3B0 */ { "SYLLABE YI SHUO",NULL},
/* A3B1 */ { "SYLLABE YI SHUOP",NULL},
/* A3B2 */ { "SYLLABE YI SHOT",NULL},
/* A3B3 */ { "SYLLABE YI SHOX",NULL},
/* A3B4 */ { "SYLLABE YI SHO",NULL},
/* A3B5 */ { "SYLLABE YI SHOP",NULL},
/* A3B6 */ { "SYLLABE YI SHET",NULL},
/* A3B7 */ { "SYLLABE YI SHEX",NULL},
/* A3B8 */ { "SYLLABE YI SHE",NULL},
/* A3B9 */ { "SYLLABE YI SHEP",NULL},
/* A3BA */ { "SYLLABE YI SHUT",NULL},
/* A3BB */ { "SYLLABE YI SHUX",NULL},
/* A3BC */ { "SYLLABE YI SHU",NULL},
/* A3BD */ { "SYLLABE YI SHUP",NULL},
/* A3BE */ { "SYLLABE YI SHURX",NULL},
/* A3BF */ { "SYLLABE YI SHUR",NULL},
/* A3C0 */ { "SYLLABE YI SHYT",NULL},
/* A3C1 */ { "SYLLABE YI SHYX",NULL},
/* A3C2 */ { "SYLLABE YI SHY",NULL},
/* A3C3 */ { "SYLLABE YI SHYP",NULL},
/* A3C4 */ { "SYLLABE YI SHYRX",NULL},
/* A3C5 */ { "SYLLABE YI SHYR",NULL},
/* A3C6 */ { "SYLLABE YI RAT",NULL},
/* A3C7 */ { "SYLLABE YI RAX",NULL},
/* A3C8 */ { "SYLLABE YI RA",NULL},
/* A3C9 */ { "SYLLABE YI RAP",NULL},
/* A3CA */ { "SYLLABE YI RUOX",NULL},
/* A3CB */ { "SYLLABE YI RUO",NULL},
/* A3CC */ { "SYLLABE YI RUOP",NULL},
/* A3CD */ { "SYLLABE YI ROT",NULL},
/* A3CE */ { "SYLLABE YI ROX",NULL},
/* A3CF */ { "SYLLABE YI RO",NULL},
/* A3D0 */ { "SYLLABE YI ROP",NULL},
/* A3D1 */ { "SYLLABE YI REX",NULL},
/* A3D2 */ { "SYLLABE YI RE",NULL},
/* A3D3 */ { "SYLLABE YI REP",NULL},
/* A3D4 */ { "SYLLABE YI RUT",NULL},
/* A3D5 */ { "SYLLABE YI RUX",NULL},
/* A3D6 */ { "SYLLABE YI RU",NULL},
/* A3D7 */ { "SYLLABE YI RUP",NULL},
/* A3D8 */ { "SYLLABE YI RURX",NULL},
/* A3D9 */ { "SYLLABE YI RUR",NULL},
/* A3DA */ { "SYLLABE YI RYT",NULL},
/* A3DB */ { "SYLLABE YI RYX",NULL},
/* A3DC */ { "SYLLABE YI RY",NULL},
/* A3DD */ { "SYLLABE YI RYP",NULL},
/* A3DE */ { "SYLLABE YI RYRX",NULL},
/* A3DF */ { "SYLLABE YI RYR",NULL},
/* A3E0 */ { "SYLLABE YI JIT",NULL},
/* A3E1 */ { "SYLLABE YI JIX",NULL},
/* A3E2 */ { "SYLLABE YI JI",NULL},
/* A3E3 */ { "SYLLABE YI JIP",NULL},
/* A3E4 */ { "SYLLABE YI JIET",NULL},
/* A3E5 */ { "SYLLABE YI JIEX",NULL},
/* A3E6 */ { "SYLLABE YI JIE",NULL},
/* A3E7 */ { "SYLLABE YI JIEP",NULL},
/* A3E8 */ { "SYLLABE YI JUOT",NULL},
/* A3E9 */ { "SYLLABE YI JUOX",NULL},
/* A3EA */ { "SYLLABE YI JUO",NULL},
/* A3EB */ { "SYLLABE YI JUOP",NULL},
/* A3EC */ { "SYLLABE YI JOT",NULL},
/* A3ED */ { "SYLLABE YI JOX",NULL},
/* A3EE */ { "SYLLABE YI JO",NULL},
/* A3EF */ { "SYLLABE YI JOP",NULL},
/* A3F0 */ { "SYLLABE YI JUT",NULL},
/* A3F1 */ { "SYLLABE YI JUX",NULL},
/* A3F2 */ { "SYLLABE YI JU",NULL},
/* A3F3 */ { "SYLLABE YI JUP",NULL},
/* A3F4 */ { "SYLLABE YI JURX",NULL},
/* A3F5 */ { "SYLLABE YI JUR",NULL},
/* A3F6 */ { "SYLLABE YI JYT",NULL},
/* A3F7 */ { "SYLLABE YI JYX",NULL},
/* A3F8 */ { "SYLLABE YI JY",NULL},
/* A3F9 */ { "SYLLABE YI JYP",NULL},
/* A3FA */ { "SYLLABE YI JYRX",NULL},
/* A3FB */ { "SYLLABE YI JYR",NULL},
/* A3FC */ { "SYLLABE YI QIT",NULL},
/* A3FD */ { "SYLLABE YI QIX",NULL},
/* A3FE */ { "SYLLABE YI QI",NULL},
/* A3FF */ { "SYLLABE YI QIP",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A4[] = {
/* A400 */ { "SYLLABE YI QIET",NULL},
/* A401 */ { "SYLLABE YI QIEX",NULL},
/* A402 */ { "SYLLABE YI QIE",NULL},
/* A403 */ { "SYLLABE YI QIEP",NULL},
/* A404 */ { "SYLLABE YI QUOT",NULL},
/* A405 */ { "SYLLABE YI QUOX",NULL},
/* A406 */ { "SYLLABE YI QUO",NULL},
/* A407 */ { "SYLLABE YI QUOP",NULL},
/* A408 */ { "SYLLABE YI QOT",NULL},
/* A409 */ { "SYLLABE YI QOX",NULL},
/* A40A */ { "SYLLABE YI QO",NULL},
/* A40B */ { "SYLLABE YI QOP",NULL},
/* A40C */ { "SYLLABE YI QUT",NULL},
/* A40D */ { "SYLLABE YI QUX",NULL},
/* A40E */ { "SYLLABE YI QU",NULL},
/* A40F */ { "SYLLABE YI QUP",NULL},
/* A410 */ { "SYLLABE YI QURX",NULL},
/* A411 */ { "SYLLABE YI QUR",NULL},
/* A412 */ { "SYLLABE YI QYT",NULL},
/* A413 */ { "SYLLABE YI QYX",NULL},
/* A414 */ { "SYLLABE YI QY",NULL},
/* A415 */ { "SYLLABE YI QYP",NULL},
/* A416 */ { "SYLLABE YI QYRX",NULL},
/* A417 */ { "SYLLABE YI QYR",NULL},
/* A418 */ { "SYLLABE YI JJIT",NULL},
/* A419 */ { "SYLLABE YI JJIX",NULL},
/* A41A */ { "SYLLABE YI JJI",NULL},
/* A41B */ { "SYLLABE YI JJIP",NULL},
/* A41C */ { "SYLLABE YI JJIET",NULL},
/* A41D */ { "SYLLABE YI JJIEX",NULL},
/* A41E */ { "SYLLABE YI JJIE",NULL},
/* A41F */ { "SYLLABE YI JJIEP",NULL},
/* A420 */ { "SYLLABE YI JJUOX",NULL},
/* A421 */ { "SYLLABE YI JJUO",NULL},
/* A422 */ { "SYLLABE YI JJUOP",NULL},
/* A423 */ { "SYLLABE YI JJOT",NULL},
/* A424 */ { "SYLLABE YI JJOX",NULL},
/* A425 */ { "SYLLABE YI JJO",NULL},
/* A426 */ { "SYLLABE YI JJOP",NULL},
/* A427 */ { "SYLLABE YI JJUT",NULL},
/* A428 */ { "SYLLABE YI JJUX",NULL},
/* A429 */ { "SYLLABE YI JJU",NULL},
/* A42A */ { "SYLLABE YI JJUP",NULL},
/* A42B */ { "SYLLABE YI JJURX",NULL},
/* A42C */ { "SYLLABE YI JJUR",NULL},
/* A42D */ { "SYLLABE YI JJYT",NULL},
/* A42E */ { "SYLLABE YI JJYX",NULL},
/* A42F */ { "SYLLABE YI JJY",NULL},
/* A430 */ { "SYLLABE YI JJYP",NULL},
/* A431 */ { "SYLLABE YI NJIT",NULL},
/* A432 */ { "SYLLABE YI NJIX",NULL},
/* A433 */ { "SYLLABE YI NJI",NULL},
/* A434 */ { "SYLLABE YI NJIP",NULL},
/* A435 */ { "SYLLABE YI NJIET",NULL},
/* A436 */ { "SYLLABE YI NJIEX",NULL},
/* A437 */ { "SYLLABE YI NJIE",NULL},
/* A438 */ { "SYLLABE YI NJIEP",NULL},
/* A439 */ { "SYLLABE YI NJUOX",NULL},
/* A43A */ { "SYLLABE YI NJUO",NULL},
/* A43B */ { "SYLLABE YI NJOT",NULL},
/* A43C */ { "SYLLABE YI NJOX",NULL},
/* A43D */ { "SYLLABE YI NJO",NULL},
/* A43E */ { "SYLLABE YI NJOP",NULL},
/* A43F */ { "SYLLABE YI NJUX",NULL},
/* A440 */ { "SYLLABE YI NJU",NULL},
/* A441 */ { "SYLLABE YI NJUP",NULL},
/* A442 */ { "SYLLABE YI NJURX",NULL},
/* A443 */ { "SYLLABE YI NJUR",NULL},
/* A444 */ { "SYLLABE YI NJYT",NULL},
/* A445 */ { "SYLLABE YI NJYX",NULL},
/* A446 */ { "SYLLABE YI NJY",NULL},
/* A447 */ { "SYLLABE YI NJYP",NULL},
/* A448 */ { "SYLLABE YI NJYRX",NULL},
/* A449 */ { "SYLLABE YI NJYR",NULL},
/* A44A */ { "SYLLABE YI NYIT",NULL},
/* A44B */ { "SYLLABE YI NYIX",NULL},
/* A44C */ { "SYLLABE YI NYI",NULL},
/* A44D */ { "SYLLABE YI NYIP",NULL},
/* A44E */ { "SYLLABE YI NYIET",NULL},
/* A44F */ { "SYLLABE YI NYIEX",NULL},
/* A450 */ { "SYLLABE YI NYIE",NULL},
/* A451 */ { "SYLLABE YI NYIEP",NULL},
/* A452 */ { "SYLLABE YI NYUOX",NULL},
/* A453 */ { "SYLLABE YI NYUO",NULL},
/* A454 */ { "SYLLABE YI NYUOP",NULL},
/* A455 */ { "SYLLABE YI NYOT",NULL},
/* A456 */ { "SYLLABE YI NYOX",NULL},
/* A457 */ { "SYLLABE YI NYO",NULL},
/* A458 */ { "SYLLABE YI NYOP",NULL},
/* A459 */ { "SYLLABE YI NYUT",NULL},
/* A45A */ { "SYLLABE YI NYUX",NULL},
/* A45B */ { "SYLLABE YI NYU",NULL},
/* A45C */ { "SYLLABE YI NYUP",NULL},
/* A45D */ { "SYLLABE YI XIT",NULL},
/* A45E */ { "SYLLABE YI XIX",NULL},
/* A45F */ { "SYLLABE YI XI",NULL},
/* A460 */ { "SYLLABE YI XIP",NULL},
/* A461 */ { "SYLLABE YI XIET",NULL},
/* A462 */ { "SYLLABE YI XIEX",NULL},
/* A463 */ { "SYLLABE YI XIE",NULL},
/* A464 */ { "SYLLABE YI XIEP",NULL},
/* A465 */ { "SYLLABE YI XUOX",NULL},
/* A466 */ { "SYLLABE YI XUO",NULL},
/* A467 */ { "SYLLABE YI XOT",NULL},
/* A468 */ { "SYLLABE YI XOX",NULL},
/* A469 */ { "SYLLABE YI XO",NULL},
/* A46A */ { "SYLLABE YI XOP",NULL},
/* A46B */ { "SYLLABE YI XYT",NULL},
/* A46C */ { "SYLLABE YI XYX",NULL},
/* A46D */ { "SYLLABE YI XY",NULL},
/* A46E */ { "SYLLABE YI XYP",NULL},
/* A46F */ { "SYLLABE YI XYRX",NULL},
/* A470 */ { "SYLLABE YI XYR",NULL},
/* A471 */ { "SYLLABE YI YIT",NULL},
/* A472 */ { "SYLLABE YI YIX",NULL},
/* A473 */ { "SYLLABE YI YI",NULL},
/* A474 */ { "SYLLABE YI YIP",NULL},
/* A475 */ { "SYLLABE YI YIET",NULL},
/* A476 */ { "SYLLABE YI YIEX",NULL},
/* A477 */ { "SYLLABE YI YIE",NULL},
/* A478 */ { "SYLLABE YI YIEP",NULL},
/* A479 */ { "SYLLABE YI YUOT",NULL},
/* A47A */ { "SYLLABE YI YUOX",NULL},
/* A47B */ { "SYLLABE YI YUO",NULL},
/* A47C */ { "SYLLABE YI YUOP",NULL},
/* A47D */ { "SYLLABE YI YOT",NULL},
/* A47E */ { "SYLLABE YI YOX",NULL},
/* A47F */ { "SYLLABE YI YO",NULL},
/* A480 */ { "SYLLABE YI YOP",NULL},
/* A481 */ { "SYLLABE YI YUT",NULL},
/* A482 */ { "SYLLABE YI YUX",NULL},
/* A483 */ { "SYLLABE YI YU",NULL},
/* A484 */ { "SYLLABE YI YUP",NULL},
/* A485 */ { "SYLLABE YI YURX",NULL},
/* A486 */ { "SYLLABE YI YUR",NULL},
/* A487 */ { "SYLLABE YI YYT",NULL},
/* A488 */ { "SYLLABE YI YYX",NULL},
/* A489 */ { "SYLLABE YI YY",NULL},
/* A48A */ { "SYLLABE YI YYP",NULL},
/* A48B */ { "SYLLABE YI YYRX",NULL},
/* A48C */ { "SYLLABE YI YYR",NULL},
/* A48D */ { NULL,NULL},
/* A48E */ { NULL,NULL},
/* A48F */ { NULL,NULL},
/* A490 */ { "CLÉ YI QOT","	x (syllabe yi qot - A408)"},
/* A491 */ { "CLÉ YI LI","	x (syllabe yi li - A1B9)"},
/* A492 */ { "CLÉ YI KIT",NULL},
/* A493 */ { "CLÉ YI NYIP",NULL},
/* A494 */ { "CLÉ YI CYP",NULL},
/* A495 */ { "CLÉ YI SSI",NULL},
/* A496 */ { "CLÉ YI GGOP",NULL},
/* A497 */ { "CLÉ YI GEP",NULL},
/* A498 */ { "CLÉ YI MI",NULL},
/* A499 */ { "CLÉ YI HXIT",NULL},
/* A49A */ { "CLÉ YI LYR",NULL},
/* A49B */ { "CLÉ YI BBUT",NULL},
/* A49C */ { "CLÉ YI MOP",NULL},
/* A49D */ { "CLÉ YI YO",NULL},
/* A49E */ { "CLÉ YI PUT",NULL},
/* A49F */ { "CLÉ YI HXUO",NULL},
/* A4A0 */ { "CLÉ YI HXOT",NULL},
/* A4A1 */ { "CLÉ YI GA",NULL},
/* A4A2 */ { "CLÉ YI ZUP",NULL},
/* A4A3 */ { "CLÉ YI CYT",NULL},
/* A4A4 */ { "CLÉ YI DDUR",NULL},
/* A4A5 */ { "CLÉ YI BUR",NULL},
/* A4A6 */ { "CLÉ YI GGUO",NULL},
/* A4A7 */ { "CLÉ YI NYOP",NULL},
/* A4A8 */ { "CLÉ YI TU",NULL},
/* A4A9 */ { "CLÉ YI OP",NULL},
/* A4AA */ { "CLÉ YI JJUT",NULL},
/* A4AB */ { "CLÉ YI ZOT",NULL},
/* A4AC */ { "CLÉ YI PYT",NULL},
/* A4AD */ { "CLÉ YI HMO",NULL},
/* A4AE */ { "CLÉ YI YIT",NULL},
/* A4AF */ { "CLÉ YI VUR",NULL},
/* A4B0 */ { "CLÉ YI SHY",NULL},
/* A4B1 */ { "CLÉ YI VEP",NULL},
/* A4B2 */ { "CLÉ YI ZA",NULL},
/* A4B3 */ { "CLÉ YI JO",NULL},
/* A4B4 */ { "CLÉ YI NZUP",NULL},
/* A4B5 */ { "CLÉ YI JJY",NULL},
/* A4B6 */ { "CLÉ YI GOT",NULL},
/* A4B7 */ { "CLÉ YI BE",NULL},
/* A4B8 */ { "CLÉ YI WO",NULL},
/* A4B9 */ { "CLÉ YI DU",NULL},
/* A4BA */ { "CLÉ YI SHUR",NULL},
/* A4BB */ { "CLÉ YI LIE",NULL},
/* A4BC */ { "CLÉ YI CY",NULL},
/* A4BD */ { "CLÉ YI CUOP",NULL},
/* A4BE */ { "CLÉ YI CIP",NULL},
/* A4BF */ { "CLÉ YI HXOP",NULL},
/* A4C0 */ { "CLÉ YI SHAT",NULL},
/* A4C1 */ { "CLÉ YI ZUR",NULL},
/* A4C2 */ { "CLÉ YI SHOP",NULL},
/* A4C3 */ { "CLÉ YI CHE",NULL},
/* A4C4 */ { "CLÉ YI ZZIET",NULL},
/* A4C5 */ { "CLÉ YI NBIE",NULL},
/* A4C6 */ { "CLÉ YI KE",NULL},
/* A4C7 */ { NULL,NULL},
/* A4C8 */ { NULL,NULL},
/* A4C9 */ { NULL,NULL},
/* A4CA */ { NULL,NULL},
/* A4CB */ { NULL,NULL},
/* A4CC */ { NULL,NULL},
/* A4CD */ { NULL,NULL},
/* A4CE */ { NULL,NULL},
/* A4CF */ { NULL,NULL},
/* A4D0 */ { "LETTRE LISSOU BA",NULL},
/* A4D1 */ { "LETTRE LISSOU PA",NULL},
/* A4D2 */ { "LETTRE LISSOU PHA","	= lettre lissou p'a"},
/* A4D3 */ { "LETTRE LISSOU DA",NULL},
/* A4D4 */ { "LETTRE LISSOU TA",NULL},
/* A4D5 */ { "LETTRE LISSOU THA",NULL},
/* A4D6 */ { "LETTRE LISSOU GA",NULL},
/* A4D7 */ { "LETTRE LISSOU KA",NULL},
/* A4D8 */ { "LETTRE LISSOU KHA",NULL},
/* A4D9 */ { "LETTRE LISSOU DJA",NULL},
/* A4DA */ { "LETTRE LISSOU TCHA",NULL},
/* A4DB */ { "LETTRE LISSOU TCHHA",NULL},
/* A4DC */ { "LETTRE LISSOU DZA",NULL},
/* A4DD */ { "LETTRE LISSOU TSA",NULL},
/* A4DE */ { "LETTRE LISSOU TÇA",NULL},
/* A4DF */ { "LETTRE LISSOU MA",NULL},
/* A4E0 */ { "LETTRE LISSOU NA",NULL},
/* A4E1 */ { "LETTRE LISSOU LA",NULL},
/* A4E2 */ { "LETTRE LISSOU SA",NULL},
/* A4E3 */ { "LETTRE LISSOU ZHA",NULL},
/* A4E4 */ { "LETTRE LISSOU ZA",NULL},
/* A4E5 */ { "LETTRE LISSOU NGA",NULL},
/* A4E6 */ { "LETTRE LISSOU HA",NULL},
/* A4E7 */ { "LETTRE LISSOU XA",NULL},
/* A4E8 */ { "LETTRE LISSOU HHA",NULL},
/* A4E9 */ { "LETTRE LISSOU FA",NULL},
/* A4EA */ { "LETTRE LISSOU WA",NULL},
/* A4EB */ { "LETTRE LISSOU ÇA",NULL},
/* A4EC */ { "LETTRE LISSOU YA",NULL},
/* A4ED */ { "LETTRE LISSOU GHA",NULL},
/* A4EE */ { "LETTRE LISSOU A",NULL},
/* A4EF */ { "LETTRE LISSOU Æ",NULL},
/* A4F0 */ { "LETTRE LISSOU É",NULL},
/* A4F1 */ { "LETTRE LISSOU EU",NULL},
/* A4F2 */ { "LETTRE LISSOU I",NULL},
/* A4F3 */ { "LETTRE LISSOU O",NULL},
/* A4F4 */ { "LETTRE LISSOU OU",NULL},
/* A4F5 */ { "LETTRE LISSOU U",NULL},
/* A4F6 */ { "LETTRE LISSOU UH",NULL},
/* A4F7 */ { "LETTRE LISSOU E",NULL},
/* A4F8 */ { "LETTRE LISSOU TON MYA TI",NULL},
/* A4F9 */ { "LETTRE LISSOU TON NA PO",NULL},
/* A4FA */ { "LETTRE LISSOU TON MYA TCHYA",NULL},
/* A4FB */ { "LETTRE LISSOU TON MYA BO",NULL},
/* A4FC */ { "LETTRE LISSOU TON MYA NA",NULL},
/* A4FD */ { "LETTRE LISSOU TON MYA DJEU",NULL},
/* A4FE */ { "PONCTUATION LISSOU VIRGULE",NULL},
/* A4FF */ { "PONCTUATION LISSOU POINT",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A5[] = {
/* A500 */ { "SYLLABE VAÏE É",NULL},
/* A501 */ { "SYLLABE VAÏE ÉN",NULL},
/* A502 */ { "SYLLABE VAÏE HÉ",NULL},
/* A503 */ { "SYLLABE VAÏE WÉ",NULL},
/* A504 */ { "SYLLABE VAÏE WÉN",NULL},
/* A505 */ { "SYLLABE VAÏE PÉ",NULL},
/* A506 */ { "SYLLABE VAÏE BHÉ",NULL},
/* A507 */ { "SYLLABE VAÏE BÉ",NULL},
/* A508 */ { "SYLLABE VAÏE MBÉ",NULL},
/* A509 */ { "SYLLABE VAÏE KPÉ",NULL},
/* A50A */ { "SYLLABE VAÏE MGBÉ",NULL},
/* A50B */ { "SYLLABE VAÏE GBÉ",NULL},
/* A50C */ { "SYLLABE VAÏE FÉ",NULL},
/* A50D */ { "SYLLABE VAÏE VÉ",NULL},
/* A50E */ { "SYLLABE VAÏE TÉ",NULL},
/* A50F */ { "SYLLABE VAÏE THÉ",NULL},
/* A510 */ { "SYLLABE VAÏE DHÉ",NULL},
/* A511 */ { "SYLLABE VAÏE DHHÉ",NULL},
/* A512 */ { "SYLLABE VAÏE LÉ",NULL},
/* A513 */ { "SYLLABE VAÏE RÉ",NULL},
/* A514 */ { "SYLLABE VAÏE DÉ","	* lu comme le logogramme deeng « enfant, petit » dans le Livre de Ndole"},
/* A515 */ { "SYLLABE VAÏE NDÉ",NULL},
/* A516 */ { "SYLLABE VAÏE SÉ",NULL},
/* A517 */ { "SYLLABE VAÏE CHÉ",NULL},
/* A518 */ { "SYLLABE VAÏE ZÉ",NULL},
/* A519 */ { "SYLLABE VAÏE ZHÉ",NULL},
/* A51A */ { "SYLLABE VAÏE TCHÉ",NULL},
/* A51B */ { "SYLLABE VAÏE JÉ",NULL},
/* A51C */ { "SYLLABE VAÏE NJÉ",NULL},
/* A51D */ { "SYLLABE VAÏE YÉ",NULL},
/* A51E */ { "SYLLABE VAÏE KÉ",NULL},
/* A51F */ { "SYLLABE VAÏE NGGÉ",NULL},
/* A520 */ { "SYLLABE VAÏE GÉ",NULL},
/* A521 */ { "SYLLABE VAÏE MÉ",NULL},
/* A522 */ { "SYLLABE VAÏE NÉ",NULL},
/* A523 */ { "SYLLABE VAÏE ÑÉ",NULL},
/* A524 */ { "SYLLABE VAÏE I",NULL},
/* A525 */ { "SYLLABE VAÏE IN",NULL},
/* A526 */ { "SYLLABE VAÏE HI",NULL},
/* A527 */ { "SYLLABE VAÏE HIN",NULL},
/* A528 */ { "SYLLABE VAÏE WI",NULL},
/* A529 */ { "SYLLABE VAÏE WIN",NULL},
/* A52A */ { "SYLLABE VAÏE PI",NULL},
/* A52B */ { "SYLLABE VAÏE BHI",NULL},
/* A52C */ { "SYLLABE VAÏE BI",NULL},
/* A52D */ { "SYLLABE VAÏE MBI",NULL},
/* A52E */ { "SYLLABE VAÏE KPI",NULL},
/* A52F */ { "SYLLABE VAÏE MGBI",NULL},
/* A530 */ { "SYLLABE VAÏE GBI",NULL},
/* A531 */ { "SYLLABE VAÏE FI",NULL},
/* A532 */ { "SYLLABE VAÏE VI",NULL},
/* A533 */ { "SYLLABE VAÏE TI",NULL},
/* A534 */ { "SYLLABE VAÏE THI",NULL},
/* A535 */ { "SYLLABE VAÏE DHI",NULL},
/* A536 */ { "SYLLABE VAÏE DHHI",NULL},
/* A537 */ { "SYLLABE VAÏE LI",NULL},
/* A538 */ { "SYLLABE VAÏE RI",NULL},
/* A539 */ { "SYLLABE VAÏE DI",NULL},
/* A53A */ { "SYLLABE VAÏE NDI",NULL},
/* A53B */ { "SYLLABE VAÏE SI",NULL},
/* A53C */ { "SYLLABE VAÏE CHI",NULL},
/* A53D */ { "SYLLABE VAÏE ZI",NULL},
/* A53E */ { "SYLLABE VAÏE ZHI",NULL},
/* A53F */ { "SYLLABE VAÏE TCHI",NULL},
/* A540 */ { "SYLLABE VAÏE JI",NULL},
/* A541 */ { "SYLLABE VAÏE NJI",NULL},
/* A542 */ { "SYLLABE VAÏE YI",NULL},
/* A543 */ { "SYLLABE VAÏE KI",NULL},
/* A544 */ { "SYLLABE VAÏE NGGI",NULL},
/* A545 */ { "SYLLABE VAÏE GI",NULL},
/* A546 */ { "SYLLABE VAÏE MI",NULL},
/* A547 */ { "SYLLABE VAÏE NI",NULL},
/* A548 */ { "SYLLABE VAÏE ÑI",NULL},
/* A549 */ { "SYLLABE VAÏE A",NULL},
/* A54A */ { "SYLLABE VAÏE AN",NULL},
/* A54B */ { "SYLLABE VAÏE NGAN",NULL},
/* A54C */ { "SYLLABE VAÏE HA",NULL},
/* A54D */ { "SYLLABE VAÏE HAN",NULL},
/* A54E */ { "SYLLABE VAÏE WA",NULL},
/* A54F */ { "SYLLABE VAÏE WAN",NULL},
/* A550 */ { "SYLLABE VAÏE PA",NULL},
/* A551 */ { "SYLLABE VAÏE BHA",NULL},
/* A552 */ { "SYLLABE VAÏE BA",NULL},
/* A553 */ { "SYLLABE VAÏE MBA",NULL},
/* A554 */ { "SYLLABE VAÏE KPA",NULL},
/* A555 */ { "SYLLABE VAÏE KPAN",NULL},
/* A556 */ { "SYLLABE VAÏE MGBA",NULL},
/* A557 */ { "SYLLABE VAÏE GBA",NULL},
/* A558 */ { "SYLLABE VAÏE FA","	x (syllabe vaïe fa ndole - A610)"},
/* A559 */ { "SYLLABE VAÏE VA",NULL},
/* A55A */ { "SYLLABE VAÏE TA",NULL},
/* A55B */ { "SYLLABE VAÏE THA",NULL},
/* A55C */ { "SYLLABE VAÏE DHA",NULL},
/* A55D */ { "SYLLABE VAÏE DHHA",NULL},
/* A55E */ { "SYLLABE VAÏE LA",NULL},
/* A55F */ { "SYLLABE VAÏE RA",NULL},
/* A560 */ { "SYLLABE VAÏE DA",NULL},
/* A561 */ { "SYLLABE VAÏE NDA",NULL},
/* A562 */ { "SYLLABE VAÏE SA",NULL},
/* A563 */ { "SYLLABE VAÏE CHA",NULL},
/* A564 */ { "SYLLABE VAÏE ZA",NULL},
/* A565 */ { "SYLLABE VAÏE ZHA",NULL},
/* A566 */ { "SYLLABE VAÏE TCHA",NULL},
/* A567 */ { "SYLLABE VAÏE JA",NULL},
/* A568 */ { "SYLLABE VAÏE NJA",NULL},
/* A569 */ { "SYLLABE VAÏE YA",NULL},
/* A56A */ { "SYLLABE VAÏE KA","	* lu comme le logogramme kai « homme » dans le Livre de Ndole\n"
	"	x (syllabe vaïe ka ndole - A611)"},
/* A56B */ { "SYLLABE VAÏE KAN",NULL},
/* A56C */ { "SYLLABE VAÏE NGGA",NULL},
/* A56D */ { "SYLLABE VAÏE GA",NULL},
/* A56E */ { "SYLLABE VAÏE MA","	x (syllabe vaïe ma ndole - A62A)"},
/* A56F */ { "SYLLABE VAÏE NA",NULL},
/* A570 */ { "SYLLABE VAÏE ÑA",NULL},
/* A571 */ { "SYLLABE VAÏE Ô",NULL},
/* A572 */ { "SYLLABE VAÏE ÔN",NULL},
/* A573 */ { "SYLLABE VAÏE HÔ",NULL},
/* A574 */ { "SYLLABE VAÏE WÔ",NULL},
/* A575 */ { "SYLLABE VAÏE WÔN",NULL},
/* A576 */ { "SYLLABE VAÏE PÔ",NULL},
/* A577 */ { "SYLLABE VAÏE BHÔ",NULL},
/* A578 */ { "SYLLABE VAÏE BÔ",NULL},
/* A579 */ { "SYLLABE VAÏE MBÔ",NULL},
/* A57A */ { "SYLLABE VAÏE KPÔ",NULL},
/* A57B */ { "SYLLABE VAÏE MGBÔ",NULL},
/* A57C */ { "SYLLABE VAÏE GBÔ",NULL},
/* A57D */ { "SYLLABE VAÏE FÔ",NULL},
/* A57E */ { "SYLLABE VAÏE VÔ",NULL},
/* A57F */ { "SYLLABE VAÏE TÔ",NULL},
/* A580 */ { "SYLLABE VAÏE THÔ",NULL},
/* A581 */ { "SYLLABE VAÏE DHÔ",NULL},
/* A582 */ { "SYLLABE VAÏE DHHÔ",NULL},
/* A583 */ { "SYLLABE VAÏE LÔ",NULL},
/* A584 */ { "SYLLABE VAÏE RÔ",NULL},
/* A585 */ { "SYLLABE VAÏE DÔ",NULL},
/* A586 */ { "SYLLABE VAÏE NDÔ",NULL},
/* A587 */ { "SYLLABE VAÏE SÔ","	x (syllabe vaïe sô ndole - A612)"},
/* A588 */ { "SYLLABE VAÏE CHÔ",NULL},
/* A589 */ { "SYLLABE VAÏE ZÔ",NULL},
/* A58A */ { "SYLLABE VAÏE ZHÔ",NULL},
/* A58B */ { "SYLLABE VAÏE TCHÔ",NULL},
/* A58C */ { "SYLLABE VAÏE JÔ",NULL},
/* A58D */ { "SYLLABE VAÏE NJÔ",NULL},
/* A58E */ { "SYLLABE VAÏE YÔ",NULL},
/* A58F */ { "SYLLABE VAÏE KÔ",NULL},
/* A590 */ { "SYLLABE VAÏE NGGÔ",NULL},
/* A591 */ { "SYLLABE VAÏE GÔ",NULL},
/* A592 */ { "SYLLABE VAÏE MÔ",NULL},
/* A593 */ { "SYLLABE VAÏE NÔ",NULL},
/* A594 */ { "SYLLABE VAÏE ÑÔ",NULL},
/* A595 */ { "SYLLABE VAÏE OU",NULL},
/* A596 */ { "SYLLABE VAÏE OUN",NULL},
/* A597 */ { "SYLLABE VAÏE HOU",NULL},
/* A598 */ { "SYLLABE VAÏE HOUN",NULL},
/* A599 */ { "SYLLABE VAÏE WOU",NULL},
/* A59A */ { "SYLLABE VAÏE WOUN",NULL},
/* A59B */ { "SYLLABE VAÏE POU",NULL},
/* A59C */ { "SYLLABE VAÏE BHOU",NULL},
/* A59D */ { "SYLLABE VAÏE BOU",NULL},
/* A59E */ { "SYLLABE VAÏE MBOU",NULL},
/* A59F */ { "SYLLABE VAÏE KPOU",NULL},
/* A5A0 */ { "SYLLABE VAÏE MGBOU",NULL},
/* A5A1 */ { "SYLLABE VAÏE GBOU",NULL},
/* A5A2 */ { "SYLLABE VAÏE FOU",NULL},
/* A5A3 */ { "SYLLABE VAÏE VOU",NULL},
/* A5A4 */ { "SYLLABE VAÏE TOU",NULL},
/* A5A5 */ { "SYLLABE VAÏE THOU",NULL},
/* A5A6 */ { "SYLLABE VAÏE DHOU",NULL},
/* A5A7 */ { "SYLLABE VAÏE DHHOU",NULL},
/* A5A8 */ { "SYLLABE VAÏE LOU",NULL},
/* A5A9 */ { "SYLLABE VAÏE ROU",NULL},
/* A5AA */ { "SYLLABE VAÏE DOU",NULL},
/* A5AB */ { "SYLLABE VAÏE NDOU",NULL},
/* A5AC */ { "SYLLABE VAÏE SOU",NULL},
/* A5AD */ { "SYLLABE VAÏE CHOU",NULL},
/* A5AE */ { "SYLLABE VAÏE ZOU",NULL},
/* A5AF */ { "SYLLABE VAÏE ZHOU",NULL},
/* A5B0 */ { "SYLLABE VAÏE TCHOU",NULL},
/* A5B1 */ { "SYLLABE VAÏE JOU",NULL},
/* A5B2 */ { "SYLLABE VAÏE NJOU",NULL},
/* A5B3 */ { "SYLLABE VAÏE YOU",NULL},
/* A5B4 */ { "SYLLABE VAÏE KOU",NULL},
/* A5B5 */ { "SYLLABE VAÏE NGGOU",NULL},
/* A5B6 */ { "SYLLABE VAÏE GOU",NULL},
/* A5B7 */ { "SYLLABE VAÏE MOU",NULL},
/* A5B8 */ { "SYLLABE VAÏE NOU",NULL},
/* A5B9 */ { "SYLLABE VAÏE ÑOU",NULL},
/* A5BA */ { "SYLLABE VAÏE O",NULL},
/* A5BB */ { "SYLLABE VAÏE ON",NULL},
/* A5BC */ { "SYLLABE VAÏE NGON",NULL},
/* A5BD */ { "SYLLABE VAÏE HO",NULL},
/* A5BE */ { "SYLLABE VAÏE HON",NULL},
/* A5BF */ { "SYLLABE VAÏE WO",NULL},
/* A5C0 */ { "SYLLABE VAÏE WON",NULL},
/* A5C1 */ { "SYLLABE VAÏE PO",NULL},
/* A5C2 */ { "SYLLABE VAÏE BHO",NULL},
/* A5C3 */ { "SYLLABE VAÏE BO",NULL},
/* A5C4 */ { "SYLLABE VAÏE MBO",NULL},
/* A5C5 */ { "SYLLABE VAÏE KPO",NULL},
/* A5C6 */ { "SYLLABE VAÏE MGBO",NULL},
/* A5C7 */ { "SYLLABE VAÏE GBO",NULL},
/* A5C8 */ { "SYLLABE VAÏE GBON",NULL},
/* A5C9 */ { "SYLLABE VAÏE FO",NULL},
/* A5CA */ { "SYLLABE VAÏE VO",NULL},
/* A5CB */ { "SYLLABE VAÏE TO",NULL},
/* A5CC */ { "SYLLABE VAÏE THO",NULL},
/* A5CD */ { "SYLLABE VAÏE DHO",NULL},
/* A5CE */ { "SYLLABE VAÏE DHHO",NULL},
/* A5CF */ { "SYLLABE VAÏE LO",NULL},
/* A5D0 */ { "SYLLABE VAÏE RO",NULL},
/* A5D1 */ { "SYLLABE VAÏE DO","	* lu comme le logogramme lo « en » dans le Livre de Ndole\n"
	"	x (syllabe vaïe do ndole - A62B)"},
/* A5D2 */ { "SYLLABE VAÏE NDO",NULL},
/* A5D3 */ { "SYLLABE VAÏE SO",NULL},
/* A5D4 */ { "SYLLABE VAÏE CHO",NULL},
/* A5D5 */ { "SYLLABE VAÏE ZO",NULL},
/* A5D6 */ { "SYLLABE VAÏE ZHO",NULL},
/* A5D7 */ { "SYLLABE VAÏE TCHO",NULL},
/* A5D8 */ { "SYLLABE VAÏE JO",NULL},
/* A5D9 */ { "SYLLABE VAÏE NJO",NULL},
/* A5DA */ { "SYLLABE VAÏE YO",NULL},
/* A5DB */ { "SYLLABE VAÏE KO",NULL},
/* A5DC */ { "SYLLABE VAÏE NGGO",NULL},
/* A5DD */ { "SYLLABE VAÏE GO",NULL},
/* A5DE */ { "SYLLABE VAÏE MO",NULL},
/* A5DF */ { "SYLLABE VAÏE NO",NULL},
/* A5E0 */ { "SYLLABE VAÏE ÑO",NULL},
/* A5E1 */ { "SYLLABE VAÏE Ê",NULL},
/* A5E2 */ { "SYLLABE VAÏE ÊN",NULL},
/* A5E3 */ { "SYLLABE VAÏE NGÊN",NULL},
/* A5E4 */ { "SYLLABE VAÏE HÊ",NULL},
/* A5E5 */ { "SYLLABE VAÏE HÊN",NULL},
/* A5E6 */ { "SYLLABE VAÏE WÊ",NULL},
/* A5E7 */ { "SYLLABE VAÏE WÊN",NULL},
/* A5E8 */ { "SYLLABE VAÏE PÊ",NULL},
/* A5E9 */ { "SYLLABE VAÏE BHÊ",NULL},
/* A5EA */ { "SYLLABE VAÏE BÊ",NULL},
/* A5EB */ { "SYLLABE VAÏE MBÊ",NULL},
/* A5EC */ { "SYLLABE VAÏE KPÊ",NULL},
/* A5ED */ { "SYLLABE VAÏE KPÊN",NULL},
/* A5EE */ { "SYLLABE VAÏE MGBÊ",NULL},
/* A5EF */ { "SYLLABE VAÏE GBÊ",NULL},
/* A5F0 */ { "SYLLABE VAÏE GBÊN",NULL},
/* A5F1 */ { "SYLLABE VAÏE FÊ",NULL},
/* A5F2 */ { "SYLLABE VAÏE VÊ",NULL},
/* A5F3 */ { "SYLLABE VAÏE TÊ",NULL},
/* A5F4 */ { "SYLLABE VAÏE THÊ",NULL},
/* A5F5 */ { "SYLLABE VAÏE DHÊ",NULL},
/* A5F6 */ { "SYLLABE VAÏE DHHÊ",NULL},
/* A5F7 */ { "SYLLABE VAÏE LÊ",NULL},
/* A5F8 */ { "SYLLABE VAÏE RÊ",NULL},
/* A5F9 */ { "SYLLABE VAÏE DÊ",NULL},
/* A5FA */ { "SYLLABE VAÏE NDÊ",NULL},
/* A5FB */ { "SYLLABE VAÏE SÊ",NULL},
/* A5FC */ { "SYLLABE VAÏE CHÊ",NULL},
/* A5FD */ { "SYLLABE VAÏE ZÊ",NULL},
/* A5FE */ { "SYLLABE VAÏE ZHÊ",NULL},
/* A5FF */ { "SYLLABE VAÏE TCHÊ",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A6[] = {
/* A600 */ { "SYLLABE VAÏE JÊ",NULL},
/* A601 */ { "SYLLABE VAÏE NJÊ",NULL},
/* A602 */ { "SYLLABE VAÏE YÊ",NULL},
/* A603 */ { "SYLLABE VAÏE KÊ",NULL},
/* A604 */ { "SYLLABE VAÏE NGGÊ",NULL},
/* A605 */ { "SYLLABE VAÏE NGGÊN",NULL},
/* A606 */ { "SYLLABE VAÏE GÊ",NULL},
/* A607 */ { "SYLLABE VAÏE GÊN",NULL},
/* A608 */ { "SYLLABE VAÏE MÊ",NULL},
/* A609 */ { "SYLLABE VAÏE NÊ",NULL},
/* A60A */ { "SYLLABE VAÏE ÑÊ",NULL},
/* A60B */ { "SYLLABE VAÏE NG",NULL},
/* A60C */ { "ALLONGE DE SYLLABE VAÏE",NULL},
/* A60D */ { "VIRGULE VAÏE",NULL},
/* A60E */ { "POINT FINAL VAÏ",NULL},
/* A60F */ { "POINT D'INTERROGATION VAÏ",NULL},
/* A610 */ { "SYLLABE VAÏE FA NDOLE","	x (syllabe vaïe fa - A558)"},
/* A611 */ { "SYLLABE VAÏE KA NDOLE","	x (syllabe vaïe ka - A56A)"},
/* A612 */ { "SYLLABE VAÏE SÔ NDOLE","	x (syllabe vaïe sô - A587)"},
/* A613 */ { "SYMBOLE VAÏ FÉNG","	* logogramme pour « chose »"},
/* A614 */ { "SYMBOLE VAÏ KÉNG","	* logogramme pour « pied »"},
/* A615 */ { "SYMBOLE VAÏ TING","	* logogramme pour « île »"},
/* A616 */ { "SYMBOLE VAÏ NÎ","	* logogramme pour « vache »\n"
	"	* également logogramme pour kpe kowu « caisse de gin »"},
/* A617 */ { "SYMBOLE VAÏ BANG","	* logogramme pour « terminé »"},
/* A618 */ { "SYMBOLE VAÏ FÂ","	* logogramme pour « mourir », « tuer »"},
/* A619 */ { "SYMBOLE VAÏ TÂ","	* logogramme pour « partir », « porter », « voyage »"},
/* A61A */ { "SYMBOLE VAÏ DANG","	* logogramme pour « entendre », « comprendre »"},
/* A61B */ { "SYMBOLE VAÏ DÔNG","	* logogramme pour « entrer »"},
/* A61C */ { "SYMBOLE VAÏ KOUNG","	* logogramme pour « tête », « être capable »"},
/* A61D */ { "SYMBOLE VAÏ TONG","	* logogramme pour « être nommé »"},
/* A61E */ { "SYMBOLE VAÏ DO-O","	* logogramme pour « être petit »"},
/* A61F */ { "SYMBOLE VAÏ JONG","	* logogramme pour « esclave »"},
/* A620 */ { "CHIFFRE VAÏ ZÉRO",NULL},
/* A621 */ { "CHIFFRE VAÏ UN",NULL},
/* A622 */ { "CHIFFRE VAÏ DEUX",NULL},
/* A623 */ { "CHIFFRE VAÏ TROIS",NULL},
/* A624 */ { "CHIFFRE VAÏ QUATRE",NULL},
/* A625 */ { "CHIFFRE VAÏ CINQ",NULL},
/* A626 */ { "CHIFFRE VAÏ SIX",NULL},
/* A627 */ { "CHIFFRE VAÏ SEPT",NULL},
/* A628 */ { "CHIFFRE VAÏ HUIT",NULL},
/* A629 */ { "CHIFFRE VAÏ NEUF",NULL},
/* A62A */ { "SYLLABE VAÏE MA NDOLE","	x (syllabe vaïe ma - A56E)"},
/* A62B */ { "SYLLABE VAÏE DO NDOLE","	x (syllabe vaïe do - A5D1)"},
/* A62C */ { NULL,NULL},
/* A62D */ { NULL,NULL},
/* A62E */ { NULL,NULL},
/* A62F */ { NULL,NULL},
/* A630 */ { NULL,NULL},
/* A631 */ { NULL,NULL},
/* A632 */ { NULL,NULL},
/* A633 */ { NULL,NULL},
/* A634 */ { NULL,NULL},
/* A635 */ { NULL,NULL},
/* A636 */ { NULL,NULL},
/* A637 */ { NULL,NULL},
/* A638 */ { NULL,NULL},
/* A639 */ { NULL,NULL},
/* A63A */ { NULL,NULL},
/* A63B */ { NULL,NULL},
/* A63C */ { NULL,NULL},
/* A63D */ { NULL,NULL},
/* A63E */ { NULL,NULL},
/* A63F */ { NULL,NULL},
/* A640 */ { "LETTRE MAJUSCULE CYRILLIQUE ZEMLIA",NULL},
/* A641 */ { "LETTRE MINUSCULE CYRILLIQUE ZEMLIA","	x (lettre minuscule cyrillique zé - 0437)"},
/* A642 */ { "LETTRE MAJUSCULE CYRILLIQUE DZÉLO",NULL},
/* A643 */ { "LETTRE MINUSCULE CYRILLIQUE DZÉLO","	x (lettre minuscule cyrillique dzé - 0455)"},
/* A644 */ { "LETTRE MAJUSCULE CYRILLIQUE DZÉ RÉFLÉCHI","	x (symbole romain sextule - 10193)"},
/* A645 */ { "LETTRE MINUSCULE CYRILLIQUE DZÉ RÉFLÉCHI",NULL},
/* A646 */ { "LETTRE MAJUSCULE CYRILLIQUE IOTA",NULL},
/* A647 */ { "LETTRE MINUSCULE CYRILLIQUE IOTA","	x (lettre minuscule glagolitique ijé initial - 2C3A)"},
/* A648 */ { "LETTRE MAJUSCULE CYRILLIQUE DIERV",NULL},
/* A649 */ { "LETTRE MINUSCULE CYRILLIQUE DIERV","	x (lettre minuscule cyrillique dié - 0452)\n"
	"	x (lettre minuscule cyrillique tié - 045B)"},
/* A64A */ { "LETTRE MAJUSCULE CYRILLIQUE MONOGRAMME OUK",NULL},
/* A64B */ { "LETTRE MINUSCULE CYRILLIQUE MONOGRAMME OUK","	x (lettre minuscule cyrillique ou - 0443)"},
/* A64C */ { "LETTRE MAJUSCULE CYRILLIQUE OMÉGA LARGE",NULL},
/* A64D */ { "LETTRE MINUSCULE CYRILLIQUE OMÉGA LARGE","	x (lettre minuscule cyrillique oméga - 0461)"},
/* A64E */ { "LETTRE MAJUSCULE CYRILLIQUE YER NEUTRE",NULL},
/* A64F */ { "LETTRE MINUSCULE CYRILLIQUE YER NEUTRE","	x (lettre minuscule cyrillique signe dur - 044A)\n"
	"	x (lettre minuscule cyrillique signe mou - 044C)"},
/* A650 */ { "LETTRE MAJUSCULE CYRILLIQUE YÉROU À YER POSTÉRIEUR",NULL},
/* A651 */ { "LETTRE MINUSCULE CYRILLIQUE YÉROU À YER POSTÉRIEUR","	x (lettre minuscule cyrillique yérou - 044B)"},
/* A652 */ { "LETTRE MAJUSCULE CYRILLIQUE IAT YODISÉ",NULL},
/* A653 */ { "LETTRE MINUSCULE CYRILLIQUE IAT YODISÉ","	x (lettre minuscule cyrillique iat - 0463)"},
/* A654 */ { "LETTRE MAJUSCULE CYRILLIQUE IOU RÉFLÉCHI",NULL},
/* A655 */ { "LETTRE MINUSCULE CYRILLIQUE IOU RÉFLÉCHI","	x (lettre minuscule cyrillique iou - 044E)"},
/* A656 */ { "LETTRE MAJUSCULE CYRILLIQUE A YODISÉ",NULL},
/* A657 */ { "LETTRE MINUSCULE CYRILLIQUE A YODISÉ",NULL},
/* A658 */ { "LETTRE MAJUSCULE CYRILLIQUE PETIT IOUSSE FERMÉ",NULL},
/* A659 */ { "LETTRE MINUSCULE CYRILLIQUE PETIT IOUSSE FERMÉ","	x (lettre minuscule cyrillique petit iousse - 0467)"},
/* A65A */ { "LETTRE MAJUSCULE CYRILLIQUE IOUSSE FUSIONNÉ",NULL},
/* A65B */ { "LETTRE MINUSCULE CYRILLIQUE IOUSSE FUSIONNÉ","	x (lettre minuscule cyrillique petit iousse - 0467)\n"
	"	x (lettre minuscule cyrillique grand iousse - 046B)"},
/* A65C */ { "LETTRE MAJUSCULE CYRILLIQUE PETIT IOUSSE YODISÉ FERMÉ",NULL},
/* A65D */ { "LETTRE MINUSCULE CYRILLIQUE PETIT IOUSSE YODISÉ FERMÉ","	x (lettre minuscule cyrillique petit iousse yodisé - 0469)"},
/* A65E */ { "LETTRE MAJUSCULE CYRILLIQUE YN",NULL},
/* A65F */ { "LETTRE MINUSCULE CYRILLIQUE YN","	* cyrillique roumain"},
/* A660 */ { "LETTRE MAJUSCULE CYRILLIQUE TSÉ RÉFLÉCHI",NULL},
/* A661 */ { "LETTRE MINUSCULE CYRILLIQUE TSÉ RÉFLÉCHI",NULL},
/* A662 */ { "LETTRE MAJUSCULE CYRILLIQUE DÉ MOU",NULL},
/* A663 */ { "LETTRE MINUSCULE CYRILLIQUE DÉ MOU",NULL},
/* A664 */ { "LETTRE MAJUSCULE CYRILLIQUE ELLE MOU",NULL},
/* A665 */ { "LETTRE MINUSCULE CYRILLIQUE ELLE MOU",NULL},
/* A666 */ { "LETTRE MAJUSCULE CYRILLIQUE EMME MOU",NULL},
/* A667 */ { "LETTRE MINUSCULE CYRILLIQUE EMME MOU",NULL},
/* A668 */ { "LETTRE MAJUSCULE CYRILLIQUE O MONOCULAIRE",NULL},
/* A669 */ { "LETTRE MINUSCULE CYRILLIQUE O MONOCULAIRE","	* utilisée dans les mots basés sur la racine pour « œil »"},
/* A66A */ { "LETTRE MAJUSCULE CYRILLIQUE O BINOCULAIRE",NULL},
/* A66B */ { "LETTRE MINUSCULE CYRILLIQUE O BINOCULAIRE","	* utilisée dans le duel des mots basés sur la racine pour « œil »"},
/* A66C */ { "LETTRE MAJUSCULE CYRILLIQUE DOUBLE O MONOCULAIRE",NULL},
/* A66D */ { "LETTRE MINUSCULE CYRILLIQUE DOUBLE O MONOCULAIRE","	* utilisée dans le duel des mots basés sur la racine pour « œil »"},
/* A66E */ { "LETTRE CYRILLIQUE O MULTI-OCULAIRE","	* utilisée dans l'épithète « aux multiples yeux »"},
/* A66F */ { "DIACRITIQUE CYRILLIQUE VZMET","	* marque l'abréviation avec les lettres cyrilliques et glagolitiques\n"
	"	x (diacritique cyrillique titlo - 0483)\n"
	"	x (diacritique cyrillique pokrytié - 0487)"},
/* A670 */ { "DIACRITIQUE CYRILLIQUE DIZAINES DE MILLIONS","	x (diacritique cyrillique millions - 0489)"},
/* A671 */ { "DIACRITIQUE CYRILLIQUE CENTAINES DE MILLIONS",NULL},
/* A672 */ { "DIACRITIQUE CYRILLIQUE MILLIARDS",NULL},
/* A673 */ { "ASTÉRISQUE SLAVON",NULL},
/* A674 */ { "DIACRITIQUE LETTRE CYRILLIQUE IÉ UKRAINIEN",NULL},
/* A675 */ { "DIACRITIQUE LETTRE CYRILLIQUE I",NULL},
/* A676 */ { "DIACRITIQUE LETTRE CYRILLIQUE YI",NULL},
/* A677 */ { "DIACRITIQUE LETTRE CYRILLIQUE OU",NULL},
/* A678 */ { "DIACRITIQUE LETTRE CYRILLIQUE SIGNE DUR",NULL},
/* A679 */ { "DIACRITIQUE LETTRE CYRILLIQUE YÉROU",NULL},
/* A67A */ { "DIACRITIQUE LETTRE CYRILLIQUE SIGNE MOU",NULL},
/* A67B */ { "DIACRITIQUE LETTRE CYRILLIQUE OMÉGA",NULL},
/* A67C */ { "DIACRITIQUE CYRILLIQUE KAVYKA","	* indique qu'une partie de mot peut être lue autrement\n"
	"	x (diacritique brève - 0306)\n"
	"	x (diacritique kavyka en chef à droite - 1DF6)\n"
	"	x (diacritique kavyka en chef à gauche - 1DF7)"},
/* A67D */ { "DIACRITIQUE CYRILLIQUE PAYÉROK","	* peut indiquer l'omission d'un yer\n"
	"	x (diacritique tilde vertical - 033E)"},
/* A67E */ { "KAVYKA CYRILLIQUE","	* permet d'indiquer qu'un mot peut être lu autrement\n"
	"	x (kavyka bas - 2E47)"},
/* A67F */ { "PAYÉROK CYRILLIQUE","	* peut indiquer l'omission d'un yer\n"
	"	x (tilde vertical - 2E2F)"},
/* A680 */ { "LETTRE MAJUSCULE CYRILLIQUE DWÉ",NULL},
/* A681 */ { "LETTRE MINUSCULE CYRILLIQUE DWÉ",NULL},
/* A682 */ { "LETTRE MAJUSCULE CYRILLIQUE DZWÉ",NULL},
/* A683 */ { "LETTRE MINUSCULE CYRILLIQUE DZWÉ",NULL},
/* A684 */ { "LETTRE MAJUSCULE CYRILLIQUE JWÉ",NULL},
/* A685 */ { "LETTRE MINUSCULE CYRILLIQUE JWÉ",NULL},
/* A686 */ { "LETTRE MAJUSCULE CYRILLIQUE TCHTCHÉ",NULL},
/* A687 */ { "LETTRE MINUSCULE CYRILLIQUE TCHTCHÉ",NULL},
/* A688 */ { "LETTRE MAJUSCULE CYRILLIQUE DZZÉ",NULL},
/* A689 */ { "LETTRE MINUSCULE CYRILLIQUE DZZÉ",NULL},
/* A68A */ { "LETTRE MAJUSCULE CYRILLIQUE TÉ CROCHET MÉDIAN",NULL},
/* A68B */ { "LETTRE MINUSCULE CYRILLIQUE TÉ CROCHET MÉDIAN",NULL},
/* A68C */ { "LETTRE MAJUSCULE CYRILLIQUE TWÉ",NULL},
/* A68D */ { "LETTRE MINUSCULE CYRILLIQUE TWÉ",NULL},
/* A68E */ { "LETTRE MAJUSCULE CYRILLIQUE TSWÉ",NULL},
/* A68F */ { "LETTRE MINUSCULE CYRILLIQUE TSWÉ",NULL},
/* A690 */ { "LETTRE MAJUSCULE CYRILLIQUE TSIÉ",NULL},
/* A691 */ { "LETTRE MINUSCULE CYRILLIQUE TSIÉ",NULL},
/* A692 */ { "LETTRE MAJUSCULE CYRILLIQUE TCHIÉ",NULL},
/* A693 */ { "LETTRE MINUSCULE CYRILLIQUE TCHIÉ",NULL},
/* A694 */ { "LETTRE MAJUSCULE CYRILLIQUE HWÉ",NULL},
/* A695 */ { "LETTRE MINUSCULE CYRILLIQUE HWÉ",NULL},
/* A696 */ { "LETTRE MAJUSCULE CYRILLIQUE CHWÉ",NULL},
/* A697 */ { "LETTRE MINUSCULE CYRILLIQUE CHWÉ",NULL},
/* A698 */ { "LETTRE MAJUSCULE CYRILLIQUE DOUBLE O",NULL},
/* A699 */ { "LETTRE MINUSCULE CYRILLIQUE DOUBLE O",NULL},
/* A69A */ { "LETTRE MAJUSCULE CYRILLIQUE O À CROIX",NULL},
/* A69B */ { "LETTRE MINUSCULE CYRILLIQUE O À CROIX",NULL},
/* A69C */ { "LETTRE MODIFICATIVE CYRILLIQUE SIGNE DUR","	# <exp> 044A"},
/* A69D */ { "LETTRE MODIFICATIVE CYRILLIQUE SIGNE MOU","	# <exp> 044C"},
/* A69E */ { "DIACRITIQUE LETTRE CYRILLIQUE EFFE",NULL},
/* A69F */ { "DIACRITIQUE LETTRE CYRILLIQUE É YODISÉ",NULL},
/* A6A0 */ { "LETTRE BAMOUM A",NULL},
/* A6A1 */ { "LETTRE BAMOUM KA",NULL},
/* A6A2 */ { "LETTRE BAMOUM U",NULL},
/* A6A3 */ { "LETTRE BAMOUM KU",NULL},
/* A6A4 */ { "LETTRE BAMOUM EE",NULL},
/* A6A5 */ { "LETTRE BAMOUM REE",NULL},
/* A6A6 */ { "LETTRE BAMOUM TAE",NULL},
/* A6A7 */ { "LETTRE BAMOUM O",NULL},
/* A6A8 */ { "LETTRE BAMOUM NYI",NULL},
/* A6A9 */ { "LETTRE BAMOUM I",NULL},
/* A6AA */ { "LETTRE BAMOUM LA",NULL},
/* A6AB */ { "LETTRE BAMOUM PA",NULL},
/* A6AC */ { "LETTRE BAMOUM RII",NULL},
/* A6AD */ { "LETTRE BAMOUM RIEE",NULL},
/* A6AE */ { "LETTRE BAMOUM LEEEE",NULL},
/* A6AF */ { "LETTRE BAMOUM MEEEE",NULL},
/* A6B0 */ { "LETTRE BAMOUM TAA",NULL},
/* A6B1 */ { "LETTRE BAMOUM NDAA",NULL},
/* A6B2 */ { "LETTRE BAMOUM NJAEM",NULL},
/* A6B3 */ { "LETTRE BAMOUM M",NULL},
/* A6B4 */ { "LETTRE BAMOUM SUU",NULL},
/* A6B5 */ { "LETTRE BAMOUM MU",NULL},
/* A6B6 */ { "LETTRE BAMOUM SHII",NULL},
/* A6B7 */ { "LETTRE BAMOUM SI",NULL},
/* A6B8 */ { "LETTRE BAMOUM SHEUX",NULL},
/* A6B9 */ { "LETTRE BAMOUM SEUX",NULL},
/* A6BA */ { "LETTRE BAMOUM KYEE",NULL},
/* A6BB */ { "LETTRE BAMOUM KET",NULL},
/* A6BC */ { "LETTRE BAMOUM NUAE",NULL},
/* A6BD */ { "LETTRE BAMOUM NU",NULL},
/* A6BE */ { "LETTRE BAMOUM NJUAE",NULL},
/* A6BF */ { "LETTRE BAMOUM YOQ",NULL},
/* A6C0 */ { "LETTRE BAMOUM SHU",NULL},
/* A6C1 */ { "LETTRE BAMOUM YUQ",NULL},
/* A6C2 */ { "LETTRE BAMOUM YA",NULL},
/* A6C3 */ { "LETTRE BAMOUM NSHA",NULL},
/* A6C4 */ { "LETTRE BAMOUM KEUX",NULL},
/* A6C5 */ { "LETTRE BAMOUM PEUX",NULL},
/* A6C6 */ { "LETTRE BAMOUM NJEE",NULL},
/* A6C7 */ { "LETTRE BAMOUM NTEE",NULL},
/* A6C8 */ { "LETTRE BAMOUM PUE",NULL},
/* A6C9 */ { "LETTRE BAMOUM WUE",NULL},
/* A6CA */ { "LETTRE BAMOUM PEE",NULL},
/* A6CB */ { "LETTRE BAMOUM FEE",NULL},
/* A6CC */ { "LETTRE BAMOUM RU",NULL},
/* A6CD */ { "LETTRE BAMOUM LU",NULL},
/* A6CE */ { "LETTRE BAMOUM MI",NULL},
/* A6CF */ { "LETTRE BAMOUM NI",NULL},
/* A6D0 */ { "LETTRE BAMOUM REUX",NULL},
/* A6D1 */ { "LETTRE BAMOUM RAE",NULL},
/* A6D2 */ { "LETTRE BAMOUM KEN",NULL},
/* A6D3 */ { "LETTRE BAMOUM NGKWAEN",NULL},
/* A6D4 */ { "LETTRE BAMOUM NGGA",NULL},
/* A6D5 */ { "LETTRE BAMOUM NGA",NULL},
/* A6D6 */ { "LETTRE BAMOUM SHO",NULL},
/* A6D7 */ { "LETTRE BAMOUM PUAE",NULL},
/* A6D8 */ { "LETTRE BAMOUM FU",NULL},
/* A6D9 */ { "LETTRE BAMOUM FOM",NULL},
/* A6DA */ { "LETTRE BAMOUM WA",NULL},
/* A6DB */ { "LETTRE BAMOUM NA",NULL},
/* A6DC */ { "LETTRE BAMOUM LI",NULL},
/* A6DD */ { "LETTRE BAMOUM PI",NULL},
/* A6DE */ { "LETTRE BAMOUM LOQ",NULL},
/* A6DF */ { "LETTRE BAMOUM KO",NULL},
/* A6E0 */ { "LETTRE BAMOUM MBEN",NULL},
/* A6E1 */ { "LETTRE BAMOUM REN",NULL},
/* A6E2 */ { "LETTRE BAMOUM MEN",NULL},
/* A6E3 */ { "LETTRE BAMOUM MA",NULL},
/* A6E4 */ { "LETTRE BAMOUM TI",NULL},
/* A6E5 */ { "LETTRE BAMOUM KI",NULL},
/* A6E6 */ { "LETTRE BAMOUM MO","	* s'utilise aussi pour le chiffre un"},
/* A6E7 */ { "LETTRE BAMOUM MBAA","	* s'utilise aussi pour le chiffre deux"},
/* A6E8 */ { "LETTRE BAMOUM TET","	* s'utilise aussi pour le chiffre trois"},
/* A6E9 */ { "LETTRE BAMOUM KPA","	* s'utilise aussi pour le chiffre quatre"},
/* A6EA */ { "LETTRE BAMOUM TEN","	* s'utilise aussi pour le chiffre cinq"},
/* A6EB */ { "LETTRE BAMOUM NTUU","	* s'utilise aussi pour le chiffre six"},
/* A6EC */ { "LETTRE BAMOUM SAMBA","	* s'utilise aussi pour le chiffre sept"},
/* A6ED */ { "LETTRE BAMOUM FAAMAE","	* s'utilise aussi pour le chiffre huit"},
/* A6EE */ { "LETTRE BAMOUM KOVUU","	* s'utilise aussi pour le chiffre neuf"},
/* A6EF */ { "LETTRE BAMOUM KOGHOM","	* s'utilise aussi pour le chiffre zéro\n"
	"	* anciennement employée pour le numéro dix"},
/* A6F0 */ { "DIACRITIQUE BAMOUM KOQNDON",NULL},
/* A6F1 */ { "DIACRITIQUE BAMOUM TUKWENTIS",NULL},
/* A6F2 */ { "NJAEMLI BAMOUM",NULL},
/* A6F3 */ { "POINT BAMOUM",NULL},
/* A6F4 */ { "DEUX-POINTS BAMOUM",NULL},
/* A6F5 */ { "VIRGULE BAMOUM",NULL},
/* A6F6 */ { "POINT-VIRGULE BAMOUM",NULL},
/* A6F7 */ { "POINT D'INTERROGATION BAMOUM",NULL},
/* A6F8 */ { NULL,NULL},
/* A6F9 */ { NULL,NULL},
/* A6FA */ { NULL,NULL},
/* A6FB */ { NULL,NULL},
/* A6FC */ { NULL,NULL},
/* A6FD */ { NULL,NULL},
/* A6FE */ { NULL,NULL},
/* A6FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A7[] = {
/* A700 */ { "LETTRE MODIFICATIVE CHINOISE TON YIN PING","	* yin p'ing"},
/* A701 */ { "LETTRE MODIFICATIVE CHINOISE TON YANG PING","	* yang p'ing"},
/* A702 */ { "LETTRE MODIFICATIVE CHINOISE TON YIN SHANG","	* yin chang"},
/* A703 */ { "LETTRE MODIFICATIVE CHINOISE TON YANG SHANG","	* yang chang"},
/* A704 */ { "LETTRE MODIFICATIVE CHINOISE TON YIN QU","	* yin ts'iu"},
/* A705 */ { "LETTRE MODIFICATIVE CHINOISE TON YANG QU","	* yang ts'iu"},
/* A706 */ { "LETTRE MODIFICATIVE CHINOISE TON YIN RU","	* yin jou"},
/* A707 */ { "LETTRE MODIFICATIVE CHINOISE TON YANG RU","	* yang jou"},
/* A708 */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE EXTRA-HAUT",NULL},
/* A709 */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE HAUT",NULL},
/* A70A */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE MÉDIAN",NULL},
/* A70B */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE BAS",NULL},
/* A70C */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE EXTRA-BAS",NULL},
/* A70D */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE À DROITE EXTRA-HAUT",NULL},
/* A70E */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE À DROITE HAUT",NULL},
/* A70F */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE À DROITE MÉDIAN",NULL},
/* A710 */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE À DROITE BAS",NULL},
/* A711 */ { "LETTRE MODIFICATIVE BARRE DE TON POINTÉE À DROITE EXTRA-BAS",NULL},
/* A712 */ { "LETTRE MODIFICATIVE BARRE DE TON TRAIT À DROITE EXTRA-HAUT",NULL},
/* A713 */ { "LETTRE MODIFICATIVE BARRE DE TON TRAIT À DROITE HAUT",NULL},
/* A714 */ { "LETTRE MODIFICATIVE BARRE DE TON TRAIT À DROITE MÉDIAN",NULL},
/* A715 */ { "LETTRE MODIFICATIVE BARRE DE TON TRAIT À DROITE BAS",NULL},
/* A716 */ { "LETTRE MODIFICATIVE BARRE DE TON TRAIT À DROITE EXTRA-BAS",NULL},
/* A717 */ { "LETTRE MODIFICATIVE BARRE DE TON VERTICALE POINTÉE",NULL},
/* A718 */ { "LETTRE MODIFICATIVE BARRE DE TON OBLIQUE POINTÉE",NULL},
/* A719 */ { "LETTRE MODIFICATIVE BARRE DE TON HORIZONTALE POINTÉE",NULL},
/* A71A */ { "LETTRE MODIFICATIVE BARRE DE TON À BOUT DROIT PLIÉ VERS LE HAUT",NULL},
/* A71B */ { "LETTRE MODIFICATIVE FLÈCHE MONTANTE HAUTE",NULL},
/* A71C */ { "LETTRE MODIFICATIVE FLÈCHE DESCENDANTE HAUTE",NULL},
/* A71D */ { "LETTRE MODIFICATIVE POINT D'EXCLAMATION HAUT","	x (lettre latine clic rétroflexe - 01C3)\n"
	"	x (lettre modificative clic rétroflexe avec hameçon rétroflexe - 107B9)"},
/* A71E */ { "LETTRE MODIFICATIVE POINT D'EXCLAMATION RENVERSÉ HAUT",NULL},
/* A71F */ { "LETTRE MODIFICATIVE POINT D'EXCLAMATION RENVERSÉ BAS",NULL},
/* A720 */ { "LETTRE MODIFICATIVE ACCENT D'INTENSITÉ ET TON HAUT",NULL},
/* A721 */ { "LETTRE MODIFICATIVE ACCENT D'INTENSITÉ ET TON BAS",NULL},
/* A722 */ { "LETTRE MAJUSCULE LATINE ALEF ÉGYPTOLOGIQUE",NULL},
/* A723 */ { "LETTRE MINUSCULE LATINE ALEF ÉGYPTOLOGIQUE","	x (lettre hébraïque alef - 05D0)\n"
	"	x (lettre arabe alif hamza en chef - 0623)"},
/* A724 */ { "LETTRE MAJUSCULE LATINE 'AÏN ÉGYPTOLOGIQUE",NULL},
/* A725 */ { "LETTRE MINUSCULE LATINE 'AÏN ÉGYPTOLOGIQUE","	x (lettre modificative demi-rond gauche - 02BF)\n"
	"	x (lettre hébraïque 'aïn - 05E2)\n"
	"	x (lettre arabe 'aïn - 0639)\n"
	"	x (lettre latine 'aïn - 1D25)\n"
	"	x (lettre modificative minuscule 'aïn - 1D5C)\n"
	"	x (lettre minuscule latine i glottal - A7BD)"},
/* A726 */ { "LETTRE MAJUSCULE LATINE HENG","	x (lettre majuscule cyrillique enne hameçon - 04C7)\n"
	"	x (lettre majuscule latine h crampon - 2C67)"},
/* A727 */ { "LETTRE MINUSCULE LATINE HENG","	* fricative uvulaire, voir 0281\n"
	"	* également utilisée en linguistique bantoue pour la fricative latérale alvéolaire sonore, voir 026E\n"
	"	x (lettre minuscule latine heng crosse - 0267)\n"
	"	x (lettre minuscule latine h hameçon palatal - A795)\n"
	"	x (lettre modificative minuscule heng - AB5C)"},
/* A728 */ { "LETTRE MAJUSCULE LATINE TZ",NULL},
/* A729 */ { "LETTRE MINUSCULE LATINE TZ","	= digramme tezh\n"
	"	* affriquée palato-alvéolaire [ts]\n"
	"	x (lettre minuscule latine digramme ts - 02A6)\n"
	"	x (lettre minuscule latine digramme tech - 02A7)"},
/* A72A */ { "LETTRE MAJUSCULE LATINE TRESILLO",NULL},
/* A72B */ { "LETTRE MINUSCULE LATINE TRESILLO","	* occlusive éjective uvulaire [qʼ]\n"
	"	x (chiffre trois culbuté - 218B)"},
/* A72C */ { "LETTRE MAJUSCULE LATINE CUATRILLO",NULL},
/* A72D */ { "LETTRE MINUSCULE LATINE CUATRILLO","	* occlusive éjective vélaire [kʼ]\n"
	"	x (chiffre quatre - 0034)"},
/* A72E */ { "LETTRE MAJUSCULE LATINE CUATRILLO À VIRGULE",NULL},
/* A72F */ { "LETTRE MINUSCULE LATINE CUATRILLO À VIRGULE","	* affriquée éjective alvéolaire [tsʼ]"},
/* A730 */ { "LETTRE LATINE PETITE CAPITALE F",NULL},
/* A731 */ { "LETTRE LATINE PETITE CAPITALE S",NULL},
/* A732 */ { "LETTRE MAJUSCULE LATINE AA","	x (lettre modificative petite capitale aa - 10780)"},
/* A733 */ { "LETTRE MINUSCULE LATINE AA",NULL},
/* A734 */ { "LETTRE MAJUSCULE LATINE AO",NULL},
/* A735 */ { "LETTRE MINUSCULE LATINE AO",NULL},
/* A736 */ { "LETTRE MAJUSCULE LATINE AU",NULL},
/* A737 */ { "LETTRE MINUSCULE LATINE AU",NULL},
/* A738 */ { "LETTRE MAJUSCULE LATINE AV",NULL},
/* A739 */ { "LETTRE MINUSCULE LATINE AV",NULL},
/* A73A */ { "LETTRE MAJUSCULE LATINE AV À BARRE HORIZONTALE",NULL},
/* A73B */ { "LETTRE MINUSCULE LATINE AV À BARRE HORIZONTALE",NULL},
/* A73C */ { "LETTRE MAJUSCULE LATINE AY",NULL},
/* A73D */ { "LETTRE MINUSCULE LATINE AY",NULL},
/* A73E */ { "LETTRE MAJUSCULE LATINE C RÉFLÉCHI POINTÉ","	x (symbole grec sigma lunaire majuscule pointé réfléchi - 03FF)"},
/* A73F */ { "LETTRE MINUSCULE LATINE C RÉFLÉCHI POINTÉ","	x (symbole grec sigma lunaire minuscule pointé réfléchi - 037D)"},
/* A740 */ { "LETTRE MAJUSCULE LATINE K À TRAIT HORIZONTAL",NULL},
/* A741 */ { "LETTRE MINUSCULE LATINE K À TRAIT HORIZONTAL",NULL},
/* A742 */ { "LETTRE MAJUSCULE LATINE K BARRÉ",NULL},
/* A743 */ { "LETTRE MINUSCULE LATINE K BARRÉ",NULL},
/* A744 */ { "LETTRE MAJUSCULE LATINE K BARRÉ À TRAIT HORIZONTAL",NULL},
/* A745 */ { "LETTRE MINUSCULE LATINE K BARRÉ À TRAIT HORIZONTAL",NULL},
/* A746 */ { "LETTRE MAJUSCULE LATINE L BRISÉ",NULL},
/* A747 */ { "LETTRE MINUSCULE LATINE L BRISÉ",NULL},
/* A748 */ { "LETTRE MAJUSCULE LATINE L À TRAIT ÉLEVÉ","	x (lettre majuscule latine l rayé - 023D)"},
/* A749 */ { "LETTRE MINUSCULE LATINE L À TRAIT ÉLEVÉ","	x (lettre minuscule latine l rayé - 019A)"},
/* A74A */ { "LETTRE MAJUSCULE LATINE O À TRAIT LONG COUVRANT","	x (lettre majuscule latine o tilde médian - 019F)"},
/* A74B */ { "LETTRE MINUSCULE LATINE O À TRAIT LONG COUVRANT","	x (lettre minuscule latine o barré obliquement - 00F8)\n"
	"	x (lettre minuscule latine o barré - 0275)"},
/* A74C */ { "LETTRE MAJUSCULE LATINE O BOUCLÉ",NULL},
/* A74D */ { "LETTRE MINUSCULE LATINE O BOUCLÉ",NULL},
/* A74E */ { "LETTRE MAJUSCULE LATINE OO",NULL},
/* A74F */ { "LETTRE MINUSCULE LATINE OO","	x (lettre minuscule cyrillique double o - A699)"},
/* A750 */ { "LETTRE MAJUSCULE LATINE P À JAMBAGE BARRÉ","	x (symbole rouble - 20BD)"},
/* A751 */ { "LETTRE MINUSCULE LATINE P À JAMBAGE BARRÉ","	x (symbole grec rhô barré - 03FC)\n"
	"	x (lettre minuscule latine p tilde médian - 1D71)"},
/* A752 */ { "LETTRE MAJUSCULE LATINE P À FIORITURE",NULL},
/* A753 */ { "LETTRE MINUSCULE LATINE P À FIORITURE",NULL},
/* A754 */ { "LETTRE MAJUSCULE LATINE P À QUEUE D'ÉCUREUIL",NULL},
/* A755 */ { "LETTRE MINUSCULE LATINE P À QUEUE D'ÉCUREUIL",NULL},
/* A756 */ { "LETTRE MAJUSCULE LATINE Q À QUEUE BARRÉE",NULL},
/* A757 */ { "LETTRE MINUSCULE LATINE Q À QUEUE BARRÉE",NULL},
/* A758 */ { "LETTRE MAJUSCULE LATINE Q À BARRE DIAGONALE",NULL},
/* A759 */ { "LETTRE MINUSCULE LATINE Q À BARRE DIAGONALE",NULL},
/* A75A */ { "LETTRE MAJUSCULE LATINE R ROTUNDA",NULL},
/* A75B */ { "LETTRE MINUSCULE LATINE R ROTUNDA",NULL},
/* A75C */ { "LETTRE MAJUSCULE LATINE RUM ROTUNDA",NULL},
/* A75D */ { "LETTRE MINUSCULE LATINE RUM ROTUNDA",NULL},
/* A75E */ { "LETTRE MAJUSCULE LATINE V À BARRE DIAGONALE",NULL},
/* A75F */ { "LETTRE MINUSCULE LATINE V À BARRE DIAGONALE",NULL},
/* A760 */ { "LETTRE MAJUSCULE LATINE VY",NULL},
/* A761 */ { "LETTRE MINUSCULE LATINE VY",NULL},
/* A762 */ { "LETTRE MAJUSCULE LATINE Z VISIGOTHIQUE",NULL},
/* A763 */ { "LETTRE MINUSCULE LATINE Z VISIGOTHIQUE","	x (lettre minuscule latine c cédille - 00E7)"},
/* A764 */ { "LETTRE MAJUSCULE LATINE THORN À TRAIT",NULL},
/* A765 */ { "LETTRE MINUSCULE LATINE THORN À TRAIT","	* vieil anglais, norrois\n"
	"	* le glyphe représentatif est privilégié dans des textes en vieil anglais\n"
	"	* les polices pour le norrois affichent un trait plus horizontal"},
/* A766 */ { "LETTRE MAJUSCULE LATINE THORN À DESCENDANTE BARRÉE",NULL},
/* A767 */ { "LETTRE MINUSCULE LATINE THORN À DESCENDANTE BARRÉE",NULL},
/* A768 */ { "LETTRE MAJUSCULE LATINE VEND",NULL},
/* A769 */ { "LETTRE MINUSCULE LATINE VEND",NULL},
/* A76A */ { "LETTRE MAJUSCULE LATINE ET","	x (lettre majuscule latine e ouvert réfléchi - A7AB)"},
/* A76B */ { "LETTRE MINUSCULE LATINE ET","	x (lettre minuscule latine yogh - 021D)"},
/* A76C */ { "LETTRE MAJUSCULE LATINE IS",NULL},
/* A76D */ { "LETTRE MINUSCULE LATINE IS",NULL},
/* A76E */ { "LETTRE MAJUSCULE LATINE CON","	x (chiffre neuf - 0039)"},
/* A76F */ { "LETTRE MINUSCULE LATINE CON",NULL},
/* A770 */ { "LETTRE MODIFICATIVE US","	x (exposant neuf - 2079)\n"
	"	# <exp> A76F"},
/* A771 */ { "LETTRE MINUSCULE LATINE DUM",NULL},
/* A772 */ { "LETTRE MINUSCULE LATINE LUM",NULL},
/* A773 */ { "LETTRE MINUSCULE LATINE MUM",NULL},
/* A774 */ { "LETTRE MINUSCULE LATINE NUM",NULL},
/* A775 */ { "LETTRE MINUSCULE LATINE RUM",NULL},
/* A776 */ { "LETTRE LATINE PETITE CAPITALE RUM",NULL},
/* A777 */ { "LETTRE MINUSCULE LATINE TUM",NULL},
/* A778 */ { "LETTRE MINUSCULE LATINE UM",NULL},
/* A779 */ { "LETTRE MAJUSCULE LATINE D INSULAIRE",NULL},
/* A77A */ { "LETTRE MINUSCULE LATINE D INSULAIRE","	* fricative dentale [ð]\n"
	"	x (lettre minuscule latine ed - 00F0)\n"
	"	x (lettre minuscule latine delta - 1E9F)"},
/* A77B */ { "LETTRE MAJUSCULE LATINE F INSULAIRE",NULL},
/* A77C */ { "LETTRE MINUSCULE LATINE F INSULAIRE",NULL},
/* A77D */ { "LETTRE MAJUSCULE LATINE G INSULAIRE","	* la minuscule est 1D79\n"
	"	x (lettre majuscule latine g insulaire fermé - A7D0)"},
/* A77E */ { "LETTRE MAJUSCULE LATINE G INSULAIRE CULBUTÉ",NULL},
/* A77F */ { "LETTRE MINUSCULE LATINE G INSULAIRE CULBUTÉ","	* nasale vélaire [ŋ]\n"
	"	x (lettre minuscule latine g culbuté - 1D77)"},
/* A780 */ { "LETTRE MAJUSCULE LATINE L CULBUTÉ",NULL},
/* A781 */ { "LETTRE MINUSCULE LATINE L CULBUTÉ","	* fricative latérale alvéolaire sourde [ɬ]"},
/* A782 */ { "LETTRE MAJUSCULE LATINE R INSULAIRE",NULL},
/* A783 */ { "LETTRE MINUSCULE LATINE R INSULAIRE","	x (lettre minuscule latine r à long fût - 027C)"},
/* A784 */ { "LETTRE MAJUSCULE LATINE S INSULAIRE",NULL},
/* A785 */ { "LETTRE MINUSCULE LATINE S INSULAIRE","	x (lettre minuscule latine s long - 017F)"},
/* A786 */ { "LETTRE MAJUSCULE LATINE T INSULAIRE",NULL},
/* A787 */ { "LETTRE MINUSCULE LATINE T INSULAIRE","	* fricative dentale sourde [θ]"},
/* A788 */ { "LETTRE MODIFICATIVE ACCENT CIRCONFLEXE BAS","	* utilisée comme une lettre de ton pour le lahu et l'akha\n"
	"	x (lettre modificative accent circonflexe - 02C6)\n"
	"	x (lettre modificative pointe de flèche vers le haut basse - 02F0)\n"
	"	x (chevron d'insertion - 2038)"},
/* A789 */ { "LETTRE MODIFICATIVE DEUX-POINTS","	* s'utilise comme une lettre de ton dans certaines écritures\n"
	"	* budu (Congo), sabaot (Kenya), grebo (Liberia) et plusieurs langues de Papouasie-Nouvelle-Guinée\n"
	"	x (deux-points - 003A)\n"
	"	x (lettre modificative deux points triangulaires - 02D0)\n"
	"	x (lettre modificative deux-points élevé - 02F8)\n"
	"	x (lettre lissou ton mya djeu - A4FD)"},
/* A78A */ { "LETTRE MODIFICATIVE SIGNE ÉGAL COURT","	* utilisée comme une lettre de ton pour le budu\n"
	"	x (signe égal - 003D)\n"
	"	x (lettre modificative non aspirée - 02ED)\n"
	"	x (trait d'union double - 2E40)\n"
	"	x (signe égal minuscule - FE66)"},
/* A78B */ { "LETTRE MAJUSCULE LATINE SALTILLO","	* tlapanèque ou me'phaa (Mexique)"},
/* A78C */ { "LETTRE MINUSCULE LATINE SALTILLO","	* ces deux lettres sont utilisés dans quelques langues pour l'écriture du coup de glotte\n"
	"	* la forme minuscule est largement utilisée dans de nombreuses langues du Mexique et dans d'autres régions\n"
	"	x (apostrophe - 0027)\n"
	"	x (lettre minuscule latine coup de glotte - 0242)\n"
	"	x (lettre latine coup de glotte - 0294)\n"
	"	x (lettre modificative apostrophe - 02BC)\n"
	"	x (lettre modificative coup de glotte - 02C0)"},
/* A78D */ { "LETTRE MAJUSCULE LATINE H CULBUTÉ","	* s'utilise dans l'écriture du dan (ou gio, ou yacouba) au Liberia\n"
	"	* également utilisée historiquement dans les orthographes latines pour l'abaza et l'abkhaze\n"
	"	* la minuscule est 0265\n"
	"	x (lettre majuscule cyrillique tché - 0427)"},
/* A78E */ { "LETTRE MINUSCULE LATINE L SANGLÉ HAMEÇON RÉTROFLEXE","	* consonne fricative latérale rétroflexe sourde\n"
	"	* s'utilise pour la transcription du toda\n"
	"	x (lettre minuscule latine l sanglé - 026C)"},
/* A78F */ { "LETTRE LATINE POINT SINOLOGIQUE","	* s'utilise dans la translittération du phags-pa et dans la transcription phonétique du tangoute\n"
	"	x (point médian - 00B7)\n"
	"	x (puce - 2022)"},
/* A790 */ { "LETTRE MAJUSCULE LATINE N CRAMPON",NULL},
/* A791 */ { "LETTRE MINUSCULE LATINE N CRAMPON","	* nasale vélaire [ŋ]\n"
	"	* yanalif\n"
	"	x (lettre minuscule latine eng - 014B)\n"
	"	x (lettre minuscule latine n à long fût à droite - 019E)\n"
	"	x (lettre minuscule cyrillique enne crampon - 04A3)"},
/* A792 */ { "LETTRE MAJUSCULE LATINE C RAYÉ","	= symbole cambrien\n"
	"	x (symbole euro - 20AC)"},
/* A793 */ { "LETTRE MINUSCULE LATINE C RAYÉ","	* affriquée palato-alvéolaire sourde [tʃ]\n"
	"	* nanaï, etc.\n"
	"	x (lettre minuscule cyrillique ié ukrainien - 0454)"},
/* A794 */ { "LETTRE MINUSCULE LATINE C HAMEÇON PALATAL","	* la majuscule est A7C4"},
/* A795 */ { "LETTRE MINUSCULE LATINE H HAMEÇON PALATAL","	x (lettre minuscule latine heng - A727)"},
/* A796 */ { "LETTRE MAJUSCULE LATINE B À FIORITURE",NULL},
/* A797 */ { "LETTRE MINUSCULE LATINE B À FIORITURE",NULL},
/* A798 */ { "LETTRE MAJUSCULE LATINE F BARRÉ","	x (lettre majuscule latine f hameçon - 0191)\n"
	"	x (symbole franc français - 20A3)"},
/* A799 */ { "LETTRE MINUSCULE LATINE F BARRÉ","	* ancienne orthographe éwé\n"
	"	* également utilisée dans l'alphabet phonétique Anthropos"},
/* A79A */ { "LETTRE MAJUSCULE LATINE VOLAPÜK AE",NULL},
/* A79B */ { "LETTRE MINUSCULE LATINE VOLAPÜK AE",NULL},
/* A79C */ { "LETTRE MAJUSCULE LATINE VOLAPÜK OE",NULL},
/* A79D */ { "LETTRE MINUSCULE LATINE VOLAPÜK OE",NULL},
/* A79E */ { "LETTRE MAJUSCULE LATINE VOLAPÜK UE",NULL},
/* A79F */ { "LETTRE MINUSCULE LATINE VOLAPÜK UE",NULL},
/* A7A0 */ { "LETTRE MAJUSCULE LATINE G BARRE OBLIQUE",NULL},
/* A7A1 */ { "LETTRE MINUSCULE LATINE G BARRE OBLIQUE",NULL},
/* A7A2 */ { "LETTRE MAJUSCULE LATINE K BARRE OBLIQUE",NULL},
/* A7A3 */ { "LETTRE MINUSCULE LATINE K BARRE OBLIQUE",NULL},
/* A7A4 */ { "LETTRE MAJUSCULE LATINE N BARRE OBLIQUE",NULL},
/* A7A5 */ { "LETTRE MINUSCULE LATINE N BARRE OBLIQUE",NULL},
/* A7A6 */ { "LETTRE MAJUSCULE LATINE R BARRE OBLIQUE",NULL},
/* A7A7 */ { "LETTRE MINUSCULE LATINE R BARRE OBLIQUE",NULL},
/* A7A8 */ { "LETTRE MAJUSCULE LATINE S BARRE OBLIQUE",NULL},
/* A7A9 */ { "LETTRE MINUSCULE LATINE S BARRE OBLIQUE","	* s'utilise aussi dans l'orthographe du bas-sorabe d'avant 1950\n"
	"	x (lettre minuscule latine s long à barre diagonale - 1E9C)\n"
	"	x (lettre minuscule latine s à petit trait couvrant - A7CA)"},
/* A7AA */ { "LETTRE MAJUSCULE LATINE H CROSSE","	* la minuscule est 0266\n"
	"	* utilisée au Tchad"},
/* A7AB */ { "LETTRE MAJUSCULE LATINE E OUVERT RÉFLÉCHI","	* la minuscule est 025C\n"
	"	x (lettre majuscule latine ej - 01B7)\n"
	"	x (lettre majuscule latine yogh - 021C)\n"
	"	x (lettre majuscule cyrillique zé - 0417)"},
/* A7AC */ { "LETTRE MAJUSCULE LATINE G CURSIF","	* la minuscule est 0261"},
/* A7AD */ { "LETTRE MAJUSCULE LATINE L SANGLÉ","	* la minuscule est 026C\n"
	"	x (lettre majuscule latine l rayé - 023D)\n"
	"	x (lettre latine petite capitale l sanglé - 1DF04)"},
/* A7AE */ { "LETTRE MAJUSCULE LATINE PETITE CAPITALE I","	* la minuscule est 026A\n"
	"	* utilisée aussi dans Unifon\n"
	"	x (lettre majuscule latine i - 0049)\n"
	"	x (lettre latine petite capitale i - 026A)"},
/* A7AF */ { "LETTRE LATINE PETITE CAPITALE Q","	* s'utilise pour représenter la gémination\n"
	"	x (lettre modificative majuscule q - A7F4)"},
/* A7B0 */ { "LETTRE MAJUSCULE LATINE K CULBUTÉ","	* la minuscule est 029E"},
/* A7B1 */ { "LETTRE MAJUSCULE LATINE T CULBUTÉ","	* la minuscule est 0287\n"
	"	* utilisée aussi dans Unifon"},
/* A7B2 */ { "LETTRE MAJUSCULE LATINE J À QUEUE CROISÉE","	* la minuscule est 029D"},
/* A7B3 */ { "LETTRE MAJUSCULE LATINE KHI","	* la minuscule est AB53\n"
	"	x (lettre majuscule grecque khi - 03A7)"},
/* A7B4 */ { "LETTRE MAJUSCULE LATINE BÊTA",NULL},
/* A7B5 */ { "LETTRE MINUSCULE LATINE BÊTA","	x (lettre minuscule latine s dur - 00DF)\n"
	"	x (lettre minuscule grecque bêta - 03B2)"},
/* A7B6 */ { "LETTRE MAJUSCULE LATINE OMÉGA",NULL},
/* A7B7 */ { "LETTRE MINUSCULE LATINE OMÉGA","	x (lettre minuscule latine oméga fermé - 0277)\n"
	"	x (lettre minuscule grecque oméga - 03C9)\n"
	"	x (lettre minuscule cyrillique oméga - 0461)\n"
	"	x (lettre minuscule cyrillique oméga large - A64D)"},
/* A7B8 */ { "LETTRE MAJUSCULE LATINE U BARRÉ OBLIQUEMENT",NULL},
/* A7B9 */ { "LETTRE MINUSCULE LATINE U BARRÉ OBLIQUEMENT",NULL},
/* A7BA */ { "LETTRE MAJUSCULE LATINE A GLOTTAL",NULL},
/* A7BB */ { "LETTRE MINUSCULE LATINE A GLOTTAL",NULL},
/* A7BC */ { "LETTRE MAJUSCULE LATINE I GLOTTAL",NULL},
/* A7BD */ { "LETTRE MINUSCULE LATINE I GLOTTAL","	= yod égyptologique\n"
	"	x (lettre minuscule latine alef égyptologique - A723)\n"
	"	x (lettre minuscule latine 'aïn égyptologique - A725)"},
/* A7BE */ { "LETTRE MAJUSCULE LATINE U GLOTTAL",NULL},
/* A7BF */ { "LETTRE MINUSCULE LATINE U GLOTTAL",NULL},
/* A7C0 */ { "LETTRE MAJUSCULE LATINE O POLONAIS ANCIEN",NULL},
/* A7C1 */ { "LETTRE MINUSCULE LATINE O POLONAIS ANCIEN","	* utilisées en polonais ancien comme voyelle nasale\n"
	"	x (lettre minuscule latine o barré obliquement - 00F8)"},
/* A7C2 */ { "LETTRE MAJUSCULE LATINE W ANGLICANA",NULL},
/* A7C3 */ { "LETTRE MINUSCULE LATINE W ANGLICANA","	* utilisées en anglais médiéval et en cornique"},
/* A7C4 */ { "LETTRE MAJUSCULE LATINE C HAMEÇON PALATAL","	* la minuscule est A794"},
/* A7C5 */ { "LETTRE MAJUSCULE LATINE S HAMEÇON RÉTROFLEXE","	* la minuscule est 0282"},
/* A7C6 */ { "LETTRE MAJUSCULE LATINE Z HAMEÇON PALATAL","	* la minuscule est 1D8E"},
/* A7C7 */ { "LETTRE MAJUSCULE LATINE D À PETIT TRAIT COUVRANT","	x (lettre majuscule latine ed - 00D0)\n"
	"	x (lettre majuscule latine d barré - 0110)"},
/* A7C8 */ { "LETTRE MINUSCULE LATINE D À PETIT TRAIT COUVRANT","	= tau gallicum\n"
	"	* indique une affriquée dentale\n"
	"	x (lettre minuscule latine d barré - 0111)"},
/* A7C9 */ { "LETTRE MAJUSCULE LATINE S À PETIT TRAIT COUVRANT",NULL},
/* A7CA */ { "LETTRE MINUSCULE LATINE S À PETIT TRAIT COUVRANT","	* attestée dans des documents manuscrits, utilisée par paire comme un substitut du tau gallicum"},
/* A7CB */ { "LETTRE MAJUSCULE LATINE CORNES DE BÉLIER","	* la minuscule est 0264"},
/* A7CC */ { "LETTRE MAJUSCULE LATINE S À BARRE DIAGONALE",NULL},
/* A7CD */ { "LETTRE MINUSCULE LATINE S À BARRE DIAGONALE",NULL},
/* A7CE */ { "LETTRE MAJUSCULE LATINE FRICATIVE PHARYNGALE SONORE",NULL},
/* A7CF */ { "LETTRE MINUSCULE LATINE FRICATIVE PHARYNGALE SONORE","	x (lettre latine fricative pharyngale sonore - 0295)"},
/* A7D0 */ { "LETTRE MAJUSCULE LATINE G INSULAIRE FERMÉ",NULL},
/* A7D1 */ { "LETTRE MINUSCULE LATINE G INSULAIRE FERMÉ","	x (lettre minuscule latine g insulaire - 1D79)"},
/* A7D2 */ { "LETTRE MAJUSCULE LATINE DOUBLE THORN",NULL},
/* A7D3 */ { "LETTRE MINUSCULE LATINE DOUBLE THORN","	x (lettre minuscule latine thorn - 00FE)"},
/* A7D4 */ { "LETTRE MAJUSCULE LATINE DOUBLE WYNN",NULL},
/* A7D5 */ { "LETTRE MINUSCULE LATINE DOUBLE WYNN","	x (lettre latine wynn - 01BF)"},
/* A7D6 */ { "LETTRE MAJUSCULE LATINE S MOYEN SCOTS",NULL},
/* A7D7 */ { "LETTRE MINUSCULE LATINE S MOYEN SCOTS","	* utilisées en moyen scots pour s, ss, ser, sir, is, sis, etc.\n"
	"	x (lettre minuscule latine s dur - 00DF)"},
/* A7D8 */ { "LETTRE MAJUSCULE LATINE S SIGMOÏDE",NULL},
/* A7D9 */ { "LETTRE MINUSCULE LATINE S SIGMOÏDE","	* utilisées en moyen cornique, moyen anglais et moyen scots"},
/* A7DA */ { "LETTRE MAJUSCULE LATINE LAMBDA",NULL},
/* A7DB */ { "LETTRE MINUSCULE LATINE LAMBDA","	x (lettre minuscule grecque lambda - 03BB)"},
/* A7DC */ { "LETTRE LATINE PETITE CAPITALE LAMBDA BARRÉ","	* la minuscule est 019B"},
/* A7DD */ { NULL,NULL},
/* A7DE */ { NULL,NULL},
/* A7DF */ { NULL,NULL},
/* A7E0 */ { NULL,NULL},
/* A7E1 */ { NULL,NULL},
/* A7E2 */ { NULL,NULL},
/* A7E3 */ { NULL,NULL},
/* A7E4 */ { NULL,NULL},
/* A7E5 */ { NULL,NULL},
/* A7E6 */ { NULL,NULL},
/* A7E7 */ { NULL,NULL},
/* A7E8 */ { NULL,NULL},
/* A7E9 */ { NULL,NULL},
/* A7EA */ { NULL,NULL},
/* A7EB */ { NULL,NULL},
/* A7EC */ { NULL,NULL},
/* A7ED */ { NULL,NULL},
/* A7EE */ { NULL,NULL},
/* A7EF */ { NULL,NULL},
/* A7F0 */ { NULL,NULL},
/* A7F1 */ { "LETTRE MODIFICATIVE MAJUSCULE S","	# <exp> 0053"},
/* A7F2 */ { "LETTRE MODIFICATIVE MAJUSCULE C","	# <exp> 0043"},
/* A7F3 */ { "LETTRE MODIFICATIVE MAJUSCULE F","	# <exp> 0046"},
/* A7F4 */ { "LETTRE MODIFICATIVE MAJUSCULE Q","	x (lettre latine petite capitale q - A7AF)\n"
	"	# <exp> 0051"},
/* A7F5 */ { "LETTRE MAJUSCULE LATINE MOITIÉ DE H RÉFLÉCHIE","	= H dimidié\n"
	"	* apparaît dans des inscriptions des provinces romaines de la Gaule\n"
	"	x (lettre majuscule latine moitié de h - 2C75)"},
/* A7F6 */ { "LETTRE MINUSCULE LATINE MOITIÉ DE H RÉFLÉCHIE","	* la minuscule n'est pas attestée dans les inscriptions mais est utilisée par les chercheurs lors de la transcription"},
/* A7F7 */ { "LETTRE LATINE ÉPIGRAPHIQUE I COUCHÉ","	* inscriptions celtiques"},
/* A7F8 */ { "LETTRE MODIFICATIVE MAJUSCULE H BARRÉ","	# <exp> 0126\n"
	"		Une différence typographique entre une majuscule et une petite capitale ne constitue pas un signe distinctif pour ce caractère dans le contexte de l'alphabet phonétique international.\n"
	"	* faucalisé\n"
	"	x (lettre latine petite capitale h - 029C)"},
/* A7F9 */ { "LETTRE MODIFICATIVE MINUSCULE LIGATURE OE","	* labialisé : ouvert arrondi\n"
	"	# <exp> 0153"},
/* A7FA */ { "LETTRE LATINE PETITE CAPITALE M CULBUTÉ","	* voyelle fermée centrale sourde\n"
	"	x (lettre minuscule latine m culbuté - 026F)\n"
	"	x (lettre minuscule cyrillique cha - 0448)"},
/* A7FB */ { "LETTRE LATINE ÉPIGRAPHIQUE F RÉFLÉCHI","	= filia (fille), femina (femme, femelle)"},
/* A7FC */ { "LETTRE LATINE ÉPIGRAPHIQUE P RÉFLÉCHI","	= puella (jeune fille)"},
/* A7FD */ { "LETTRE LATINE ÉPIGRAPHIQUE M CULBUTÉ","	= mulier, matrona (femme mariée)\n"
	"	x (lettre majuscule latine m culbuté - 019C)"},
/* A7FE */ { "LETTRE LATINE ÉPIGRAPHIQUE I ALLONGÉ",NULL},
/* A7FF */ { "LETTRE LATINE ÉPIGRAPHIQUE M ARCHAÏQUE","	* logogramme pour le prénom « Manius »"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A8[] = {
/* A800 */ { "LETTRE SYLOTÎ NÂGRÎ Â",NULL},
/* A801 */ { "LETTRE SYLOTÎ NÂGRÎ I",NULL},
/* A802 */ { "DIACRITIQUE SYLOTÎ NÂGRÎ DVISVARA",NULL},
/* A803 */ { "LETTRE SYLOTÎ NÂGRÎ OU",NULL},
/* A804 */ { "LETTRE SYLOTÎ NÂGRÎ É",NULL},
/* A805 */ { "LETTRE SYLOTÎ NÂGRÎ O",NULL},
/* A806 */ { "DIACRITIQUE SYLOTÎ NÂGRÎ HASANTA","	= halant, virâma\n"
	"	* forme des ligatures"},
/* A807 */ { "LETTRE SYLOTÎ NÂGRÎ KO",NULL},
/* A808 */ { "LETTRE SYLOTÎ NÂGRÎ KHO",NULL},
/* A809 */ { "LETTRE SYLOTÎ NÂGRÎ GO",NULL},
/* A80A */ { "LETTRE SYLOTÎ NÂGRÎ GHO",NULL},
/* A80B */ { "DIACRITIQUE SYLOTÎ NÂGRÎ ANOUSVÂRA",NULL},
/* A80C */ { "LETTRE SYLOTÎ NÂGRÎ TCHO",NULL},
/* A80D */ { "LETTRE SYLOTÎ NÂGRÎ TCHHO",NULL},
/* A80E */ { "LETTRE SYLOTÎ NÂGRÎ DJO",NULL},
/* A80F */ { "LETTRE SYLOTÎ NÂGRÎ DJHO",NULL},
/* A810 */ { "LETTRE SYLOTÎ NÂGRÎ TTO",NULL},
/* A811 */ { "LETTRE SYLOTÎ NÂGRÎ TTHO",NULL},
/* A812 */ { "LETTRE SYLOTÎ NÂGRÎ DDO",NULL},
/* A813 */ { "LETTRE SYLOTÎ NÂGRÎ DDHO",NULL},
/* A814 */ { "LETTRE SYLOTÎ NÂGRÎ TO",NULL},
/* A815 */ { "LETTRE SYLOTÎ NÂGRÎ THO",NULL},
/* A816 */ { "LETTRE SYLOTÎ NÂGRÎ DO",NULL},
/* A817 */ { "LETTRE SYLOTÎ NÂGRÎ DHO",NULL},
/* A818 */ { "LETTRE SYLOTÎ NÂGRÎ NO",NULL},
/* A819 */ { "LETTRE SYLOTÎ NÂGRÎ PO",NULL},
/* A81A */ { "LETTRE SYLOTÎ NÂGRÎ PHO",NULL},
/* A81B */ { "LETTRE SYLOTÎ NÂGRÎ BO",NULL},
/* A81C */ { "LETTRE SYLOTÎ NÂGRÎ BHO",NULL},
/* A81D */ { "LETTRE SYLOTÎ NÂGRÎ MO",NULL},
/* A81E */ { "LETTRE SYLOTÎ NÂGRÎ RO",NULL},
/* A81F */ { "LETTRE SYLOTÎ NÂGRÎ LO",NULL},
/* A820 */ { "LETTRE SYLOTÎ NÂGRÎ RRO",NULL},
/* A821 */ { "LETTRE SYLOTÎ NÂGRÎ SO",NULL},
/* A822 */ { "LETTRE SYLOTÎ NÂGRÎ HO",NULL},
/* A823 */ { "DIACRITIQUE VOYELLE SYLOTÎ NÂGRÎ Â",NULL},
/* A824 */ { "DIACRITIQUE VOYELLE SYLOTÎ NÂGRÎ I",NULL},
/* A825 */ { "DIACRITIQUE VOYELLE SYLOTÎ NÂGRÎ OU",NULL},
/* A826 */ { "DIACRITIQUE VOYELLE SYLOTÎ NÂGRÎ É",NULL},
/* A827 */ { "DIACRITIQUE VOYELLE SYLOTÎ NÂGRÎ Ô",NULL},
/* A828 */ { "SYMBOLE DE POÉSIE SYLOTÎ NÂGRÎ 1",NULL},
/* A829 */ { "SYMBOLE DE POÉSIE SYLOTÎ NÂGRÎ 2",NULL},
/* A82A */ { "SYMBOLE DE POÉSIE SYLOTÎ NÂGRÎ 3",NULL},
/* A82B */ { "SYMBOLE DE POÉSIE SYLOTÎ NÂGRÎ 4",NULL},
/* A82C */ { "DIACRITIQUE SYLOTÎ NÂGRÎ VARIANTE DE HASANTA","	= signe « tueur »\n"
	"	* ne forme pas de ligatures"},
/* A82D */ { NULL,NULL},
/* A82E */ { NULL,NULL},
/* A82F */ { NULL,NULL},
/* A830 */ { "FRACTION INDIENNE DU NORD UN QUART","	* cette fraction et certaines des fractions suivantes sont également utilisées dans plusieurs écritures indiennes du Sud, en ce compris le kannara et le malayalam"},
/* A831 */ { "FRACTION INDIENNE DU NORD UN DEMI",NULL},
/* A832 */ { "FRACTION INDIENNE DU NORD TROIS QUARTS",NULL},
/* A833 */ { "FRACTION INDIENNE DU NORD UN SEIXIÈME",NULL},
/* A834 */ { "FRACTION INDIENNE DU NORD UN HUITIÈME",NULL},
/* A835 */ { "FRACTION INDIENNE DU NORD TROIS SEIXIÈMES",NULL},
/* A836 */ { "SIGNE INDIEN DU NORD UN QUART",NULL},
/* A837 */ { "SIGNE INDIEN DU NORD D'ABSENCE D'UNITÉ","	* indique l'absence d'une unité intermédiaire dans une valeur monétaire"},
/* A838 */ { "SYMBOLE INDIEN DU NORD ROUPIE","	x (signe bengali roupie - 09F2)"},
/* A839 */ { "SIGNE DE QUANTITÉ INDIEN DU NORD","	* une marque unitaire pour différents poids et mesures"},
/* A83A */ { NULL,NULL},
/* A83B */ { NULL,NULL},
/* A83C */ { NULL,NULL},
/* A83D */ { NULL,NULL},
/* A83E */ { NULL,NULL},
/* A83F */ { NULL,NULL},
/* A840 */ { "LETTRE PHAGS-PA KA","	* mongol, chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine ka - 0F40)"},
/* A841 */ { "LETTRE PHAGS-PA KHA","	= lettre phags-pa k'a\n"
	"	x (lettre tibétaine kha - 0F41)"},
/* A842 */ { "LETTRE PHAGS-PA GA","	x (lettre tibétaine ga - 0F42)"},
/* A843 */ { "LETTRE PHAGS-PA NGA","	* mongol, chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine nga - 0F44)"},
/* A844 */ { "LETTRE PHAGS-PA TCHA","	* chinois, tibétain\n"
	"	x (lettre tibétaine tcha - 0F45)"},
/* A845 */ { "LETTRE PHAGS-PA TCHHA","	= lettre phags-pa tch'a\n"
	"	* mongol, chinois, ouïgour, tibétain\n"
	"	x (lettre tibétaine tchha - 0F46)"},
/* A846 */ { "LETTRE PHAGS-PA DJA","	* mongol, chinois, ouïgour, tibétain\n"
	"	x (lettre tibétaine dja - 0F47)"},
/* A847 */ { "LETTRE PHAGS-PA ÑA","	* chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine ña - 0F49)"},
/* A848 */ { "LETTRE PHAGS-PA TA","	* mongol, chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine ta - 0F4F)"},
/* A849 */ { "LETTRE PHAGS-PA THA","	= lettre phags-pa t'a\n"
	"	x (lettre tibétaine tha - 0F50)"},
/* A84A */ { "LETTRE PHAGS-PA DA","	x (lettre tibétaine da - 0F51)"},
/* A84B */ { "LETTRE PHAGS-PA NA","	x (lettre tibétaine na - 0F53)"},
/* A84C */ { "LETTRE PHAGS-PA PA","	* mongol, chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine pa - 0F54)"},
/* A84D */ { "LETTRE PHAGS-PA PHA","	= lettre phags-pa p'a\n"
	"	* chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine pha - 0F55)"},
/* A84E */ { "LETTRE PHAGS-PA BA","	x (lettre tibétaine ba - 0F56)"},
/* A84F */ { "LETTRE PHAGS-PA MA","	x (lettre tibétaine ma - 0F58)"},
/* A850 */ { "LETTRE PHAGS-PA TSA","	* chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine tsa - 0F59)"},
/* A851 */ { "LETTRE PHAGS-PA TÇA","	= lettre phags-pa ts'a\n"
	"	* mongol, chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine tça - 0F5A)"},
/* A852 */ { "LETTRE PHAGS-PA DZA","	* chinois, tibétain, sanskrit\n"
	"	x (lettre tibétaine dza - 0F5B)"},
/* A853 */ { "LETTRE PHAGS-PA WA","	x (lettre tibétaine wa - 0F5D)"},
/* A854 */ { "LETTRE PHAGS-PA ZHA","	* chinois, tibétain\n"
	"	x (lettre tibétaine zha - 0F5E)"},
/* A855 */ { "LETTRE PHAGS-PA ZA","	* mongol, chinois, tibétain\n"
	"	x (lettre tibétaine za - 0F5F)"},
/* A856 */ { "LETTRE PHAGS-PA PETIT A","	x (lettre tibétaine 'a - 0F60)\n"
	"	~ A856 FE00 lettre phags-pa petit a forme renversée"},
/* A857 */ { "LETTRE PHAGS-PA YA","	x (lettre tibétaine ya - 0F61)"},
/* A858 */ { "LETTRE PHAGS-PA RA","	* mongol, ouïgour, tibétain, sanskrit\n"
	"	x (lettre tibétaine ra - 0F62)"},
/* A859 */ { "LETTRE PHAGS-PA LA","	x (lettre tibétaine la - 0F63)"},
/* A85A */ { "LETTRE PHAGS-PA ÇA","	x (lettre tibétaine ça - 0F64)"},
/* A85B */ { "LETTRE PHAGS-PA SA","	x (lettre tibétaine sa - 0F66)"},
/* A85C */ { "LETTRE PHAGS-PA HA","	x (lettre tibétaine ha - 0F67)\n"
	"	~ A85C FE00 lettre phags-pa ha forme renversée"},
/* A85D */ { "LETTRE PHAGS-PA A","	x (lettre tibétaine a - 0F68)"},
/* A85E */ { "LETTRE PHAGS-PA I","	x (diacritique voyelle tibétaine i - 0F72)\n"
	"	~ A85E FE00 lettre phags-pa i forme renversée"},
/* A85F */ { "LETTRE PHAGS-PA OU","	x (diacritique voyelle tibétaine ou - 0F74)\n"
	"	~ A85F FE00 lettre phags-pa ou forme renversée"},
/* A860 */ { "LETTRE PHAGS-PA È","	x (diacritique voyelle tibétaine é - 0F7A)\n"
	"	~ A860 FE00 lettre phags-pa é forme renversée"},
/* A861 */ { "LETTRE PHAGS-PA O","	x (diacritique voyelle tibétaine o - 0F7C)"},
/* A862 */ { "LETTRE PHAGS-PA QA","	* mongol, ouïgour"},
/* A863 */ { "LETTRE PHAGS-PA XA","	* mongol, chinois"},
/* A864 */ { "LETTRE PHAGS-PA FA","	* chinois, ouïgour\n"
	"	x (lettre phags-pa ha - A85C)"},
/* A865 */ { "LETTRE PHAGS-PA GGA","	* distribution linguistique inconnue\n"
	"	* forme réfléchie de A862"},
/* A866 */ { "LETTRE PHAGS-PA É","	* mongol, chinois, ouïgour"},
/* A867 */ { "LETTRE SUBJOINTE PHAGS-PA WA","	* chinois, tibétain, sanskrit\n"
	"	x (lettre subjointe tibétaine wa - 0FAD)"},
/* A868 */ { "LETTRE SUBJOINTE PHAGS-PA YA","	* chinois, tibétain, sanskrit\n"
	"	x (lettre subjointe tibétaine ya - 0FB1)\n"
	"	~ A868 FE00 lettre subjointe phags-pa ya forme renversée"},
/* A869 */ { "LETTRE PHAGS-PA TTA","	* sanskrit\n"
	"	x (lettre tibétaine tta - 0F4A)"},
/* A86A */ { "LETTRE PHAGS-PA TTHA","	= lettre phags-pa tt'a\n"
	"	* sanskrit\n"
	"	x (lettre tibétaine ttha - 0F4B)"},
/* A86B */ { "LETTRE PHAGS-PA DDA","	* sanskrit\n"
	"	x (lettre tibétaine dda - 0F4C)"},
/* A86C */ { "LETTRE PHAGS-PA NNA","	* sanskrit\n"
	"	x (lettre tibétaine nna - 0F4E)"},
/* A86D */ { "LETTRE PHAGS-PA VARIANTE DE YA","	* chinois\n"
	"	x (lettre phags-pa ya - A857)"},
/* A86E */ { "LETTRE PHAGS-PA ÇA SOURD","	* chinois\n"
	"	x (lettre phags-pa ça - A85A)"},
/* A86F */ { "LETTRE PHAGS-PA HA VOISÉ","	= lettre phags-pa ha sonore\n"
	"	* chinois\n"
	"	x (lettre phags-pa ha - A85C)"},
/* A870 */ { "LETTRE PHAGS-PA FA ASPIRÉ","	* chinois\n"
	"	x (lettre phags-pa fa - A864)"},
/* A871 */ { "LETTRE SUBJOINTE PHAGS-PA RA","	* tibétain, sanskrit\n"
	"	x (lettre subjointe tibétaine ra - 0FB2)"},
/* A872 */ { "LETTRE PHAGS-PA RA SUSCRIT","	* tibétain\n"
	"	x (lettre tibétaine ra - 0F62)"},
/* A873 */ { "LETTRE PHAGS-PA TCHANDRABINDOU","	* sanskrit\n"
	"	x (diacritique tibétain sna ldan - 0F83)\n"
	"	x (diacritique tibétain rdjes sou nga ro - 0F7E)\n"
	"	x (lettre mongole anousvâra un ali gali - 1880)"},
/* A874 */ { "REPÈRE DE DÉBUT PHAGS-PA SIMPLE","	* tibétain\n"
	"	* indique le début d'un texte\n"
	"	x (signe tibétain yig mgo mdoun ma ouvrant - 0F04)\n"
	"	x (birga mongol - 1800)"},
/* A875 */ { "REPÈRE DE DÉBUT PHAGS-PA DOUBLE","	* tibétain\n"
	"	* indique le début d'un texte"},
/* A876 */ { "SIGNE PHAGS-PA ÇAD","	* tibétain\n"
	"	x (signe tibétain çad - 0F0D)"},
/* A877 */ { "SIGNE PHAGS-PA DOUBLE ÇAD","	* tibétain\n"
	"	x (signe tibétain ñis çad - 0F0E)"},
/* A878 */ { NULL,NULL},
/* A879 */ { NULL,NULL},
/* A87A */ { NULL,NULL},
/* A87B */ { NULL,NULL},
/* A87C */ { NULL,NULL},
/* A87D */ { NULL,NULL},
/* A87E */ { NULL,NULL},
/* A87F */ { NULL,NULL},
/* A880 */ { "DIACRITIQUE SAURACHTRA ANOUSVÂRA",NULL},
/* A881 */ { "DIACRITIQUE SAURACHTRA VISARGA",NULL},
/* A882 */ { "LETTRE SAURACHTRA A",NULL},
/* A883 */ { "LETTRE SAURACHTRA Â",NULL},
/* A884 */ { "LETTRE SAURACHTRA I",NULL},
/* A885 */ { "LETTRE SAURACHTRA Î",NULL},
/* A886 */ { "LETTRE SAURACHTRA OU",NULL},
/* A887 */ { "LETTRE SAURACHTRA OÛ",NULL},
/* A888 */ { "LETTRE SAURACHTRA R VOCALIQUE",NULL},
/* A889 */ { "LETTRE SAURACHTRA RR VOCALIQUE",NULL},
/* A88A */ { "LETTRE SAURACHTRA L VOCALIQUE",NULL},
/* A88B */ { "LETTRE SAURACHTRA LL VOCALIQUE",NULL},
/* A88C */ { "LETTRE SAURACHTRA É",NULL},
/* A88D */ { "LETTRE SAURACHTRA ÉÉ",NULL},
/* A88E */ { "LETTRE SAURACHTRA AI",NULL},
/* A88F */ { "LETTRE SAURACHTRA O",NULL},
/* A890 */ { "LETTRE SAURACHTRA Ô",NULL},
/* A891 */ { "LETTRE SAURACHTRA AOU",NULL},
/* A892 */ { "LETTRE SAURACHTRA KA",NULL},
/* A893 */ { "LETTRE SAURACHTRA KHA",NULL},
/* A894 */ { "LETTRE SAURACHTRA GA",NULL},
/* A895 */ { "LETTRE SAURACHTRA GHA",NULL},
/* A896 */ { "LETTRE SAURACHTRA NGA",NULL},
/* A897 */ { "LETTRE SAURACHTRA TCHA",NULL},
/* A898 */ { "LETTRE SAURACHTRA TCHHA",NULL},
/* A899 */ { "LETTRE SAURACHTRA DJA",NULL},
/* A89A */ { "LETTRE SAURACHTRA DJHA",NULL},
/* A89B */ { "LETTRE SAURACHTRA ÑA",NULL},
/* A89C */ { "LETTRE SAURACHTRA TTA",NULL},
/* A89D */ { "LETTRE SAURACHTRA TTHA",NULL},
/* A89E */ { "LETTRE SAURACHTRA DDA",NULL},
/* A89F */ { "LETTRE SAURACHTRA DDHA",NULL},
/* A8A0 */ { "LETTRE SAURACHTRA NNA",NULL},
/* A8A1 */ { "LETTRE SAURACHTRA TA",NULL},
/* A8A2 */ { "LETTRE SAURACHTRA THA",NULL},
/* A8A3 */ { "LETTRE SAURACHTRA DA",NULL},
/* A8A4 */ { "LETTRE SAURACHTRA DHA",NULL},
/* A8A5 */ { "LETTRE SAURACHTRA NA",NULL},
/* A8A6 */ { "LETTRE SAURACHTRA PA",NULL},
/* A8A7 */ { "LETTRE SAURACHTRA PHA","	= lettre saurachtra p'a"},
/* A8A8 */ { "LETTRE SAURACHTRA BA",NULL},
/* A8A9 */ { "LETTRE SAURACHTRA BHA",NULL},
/* A8AA */ { "LETTRE SAURACHTRA MA",NULL},
/* A8AB */ { "LETTRE SAURACHTRA YA",NULL},
/* A8AC */ { "LETTRE SAURACHTRA RA",NULL},
/* A8AD */ { "LETTRE SAURACHTRA LA",NULL},
/* A8AE */ { "LETTRE SAURACHTRA VA",NULL},
/* A8AF */ { "LETTRE SAURACHTRA ÇA",NULL},
/* A8B0 */ { "LETTRE SAURACHTRA CHA",NULL},
/* A8B1 */ { "LETTRE SAURACHTRA SA",NULL},
/* A8B2 */ { "LETTRE SAURACHTRA HA",NULL},
/* A8B3 */ { "LETTRE SAURACHTRA LLA",NULL},
/* A8B4 */ { "DIACRITIQUE CONSONNE SAURACHTRA HÂROU",NULL},
/* A8B5 */ { "DIACRITIQUE VOYELLE SAURACHTRA Â",NULL},
/* A8B6 */ { "DIACRITIQUE VOYELLE SAURACHTRA I",NULL},
/* A8B7 */ { "DIACRITIQUE VOYELLE SAURACHTRA Î",NULL},
/* A8B8 */ { "DIACRITIQUE VOYELLE SAURACHTRA OU",NULL},
/* A8B9 */ { "DIACRITIQUE VOYELLE SAURACHTRA OÛ",NULL},
/* A8BA */ { "DIACRITIQUE VOYELLE SAURACHTRA R VOCALIQUE",NULL},
/* A8BB */ { "DIACRITIQUE VOYELLE SAURACHTRA RR VOCALIQUE",NULL},
/* A8BC */ { "DIACRITIQUE VOYELLE SAURACHTRA L VOCALIQUE",NULL},
/* A8BD */ { "DIACRITIQUE VOYELLE SAURACHTRA LL VOCALIQUE",NULL},
/* A8BE */ { "DIACRITIQUE VOYELLE SAURACHTRA É",NULL},
/* A8BF */ { "DIACRITIQUE VOYELLE SAURACHTRA ÉÉ",NULL},
/* A8C0 */ { "DIACRITIQUE VOYELLE SAURACHTRA AI",NULL},
/* A8C1 */ { "DIACRITIQUE VOYELLE SAURACHTRA O",NULL},
/* A8C2 */ { "DIACRITIQUE VOYELLE SAURACHTRA Ô",NULL},
/* A8C3 */ { "DIACRITIQUE VOYELLE SAURACHTRA AOU",NULL},
/* A8C4 */ { "DIACRITIQUE SAURACHTRA VIRÂMA",NULL},
/* A8C5 */ { "DIACRITIQUE SAURACHTRA TCHANDRABINDOU",NULL},
/* A8C6 */ { NULL,NULL},
/* A8C7 */ { NULL,NULL},
/* A8C8 */ { NULL,NULL},
/* A8C9 */ { NULL,NULL},
/* A8CA */ { NULL,NULL},
/* A8CB */ { NULL,NULL},
/* A8CC */ { NULL,NULL},
/* A8CD */ { NULL,NULL},
/* A8CE */ { "DANDA SAURACHTRA",NULL},
/* A8CF */ { "DOUBLE DANDA SAURACHTRA",NULL},
/* A8D0 */ { "CHIFFRE SAURACHTRA ZÉRO",NULL},
/* A8D1 */ { "CHIFFRE SAURACHTRA UN",NULL},
/* A8D2 */ { "CHIFFRE SAURACHTRA DEUX",NULL},
/* A8D3 */ { "CHIFFRE SAURACHTRA TROIS",NULL},
/* A8D4 */ { "CHIFFRE SAURACHTRA QUATRE",NULL},
/* A8D5 */ { "CHIFFRE SAURACHTRA CINQ",NULL},
/* A8D6 */ { "CHIFFRE SAURACHTRA SIX",NULL},
/* A8D7 */ { "CHIFFRE SAURACHTRA SEPT",NULL},
/* A8D8 */ { "CHIFFRE SAURACHTRA HUIT",NULL},
/* A8D9 */ { "CHIFFRE SAURACHTRA NEUF",NULL},
/* A8DA */ { NULL,NULL},
/* A8DB */ { NULL,NULL},
/* A8DC */ { NULL,NULL},
/* A8DD */ { NULL,NULL},
/* A8DE */ { NULL,NULL},
/* A8DF */ { NULL,NULL},
/* A8E0 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ ZÉRO","	= vaïdika sâmasvara anka tchhoûnya"},
/* A8E1 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ UN","	= vaïdika sâmasvara anka éka oudâtta"},
/* A8E2 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ DEUX","	= vaïdika sâmasvara anka dvi svarita"},
/* A8E3 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ TROIS","	= vaïdika sâmasvara anka tri anoudâtta"},
/* A8E4 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ QUATRE","	= vaïdika sâmasvara anka tchhatour"},
/* A8E5 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ CINQ","	= vaïdika sâmasvara anka pantchha"},
/* A8E6 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ SIX","	= vaïdika sâmasvara anka shatt"},
/* A8E7 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ SEPT","	= vaïdika sâmasvara anka sapta"},
/* A8E8 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ HUIT","	= vaïdika sâmasvara anka ashta"},
/* A8E9 */ { "DIACRITIQUE CHIFFRE DÉVANÂGARÎ NEUF","	= vaïdika sâmasvara anka nava"},
/* A8EA */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ A","	= vaïdika sâmasvara abhinihita"},
/* A8EB */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ OU","	= vaïdika sâmasvara ou"},
/* A8EC */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ KA","	= vaïdika sâmasvara ka"},
/* A8ED */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ NA","	= vaïdika sâmasvara namana"},
/* A8EE */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ PA","	= vaïdika sâmasvara prannatam"},
/* A8EF */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ RA","	= vaïdika sâmasvara ra"},
/* A8F0 */ { "DIACRITIQUE LETTRE DÉVANÂGARÎ VI","	= vaïdika sâmasvara vinata"},
/* A8F1 */ { "DIACRITIQUE DÉVANÂGARÎ AVAGRAHA","	= vaïdika sâmasvara dîrghîbhâva"},
/* A8F2 */ { "SIGNE DÉVANÂGARÎ TCHANDRABINDOU À CHASSE","	= vaïdika tchandrabindou\n"
	"	x (diacritique dévanâgarî tchandrabindou - 0901)"},
/* A8F3 */ { "SIGNE DÉVANÂGARÎ TCHANDRABINDOU VIRÂMA","	= vaïdika anousvâra tchandrabindou tiryak"},
/* A8F4 */ { "SIGNE DÉVANÂGARÎ TCHANDRABINDOU DOUBLE VIRÂMA","	= vaïdika anousvâra dvi tchandrabindou tiryak"},
/* A8F5 */ { "SIGNE DÉVANÂGARÎ TCHANDRABINDOU DEUX","	= vaïdika anousvâra tchandrabindou sa-dvi"},
/* A8F6 */ { "SIGNE DÉVANÂGARÎ TCHANDRABINDOU TROIS","	= vaïdika anousvâra tchandrabindou sa-tri"},
/* A8F7 */ { "SIGNE DÉVANÂGARÎ TCHANDRABINDOU AVAGRAHA","	= vaïdika anousvâra tchandrabindou sa-avagraha"},
/* A8F8 */ { "SIGNE DÉVANÂGARÎ POUSHPIKA","	= vaïdika poushpikâ\n"
	"	* utilisé comme support ou bouche-trou\n"
	"	* souvent flanqué de doubles dandas"},
/* A8F9 */ { "BOURRE D'ÉCART DÉVANÂGARÎ","	* s'utilise pour indiquer qu'un blanc ou un écart dans un manuscrit ou un texte n'est pas une lacune"},
/* A8FA */ { "CHEVRON DÉVANÂGARÎ","	= vaïdika troutikâ\n"
	"	* caractère à chasse nulle, centré sur le point entre deux syllabes orthographiques\n"
	"	* s'utilise pour l'insertion de caractères\n"
	"	x (chevron d'insertion - 2038)"},
/* A8FB */ { "BARRE DE TÊTE DÉVANÂGARÎ","	= tchhirorékhâ\n"
	"	* s'utilise pour indiquer des passages dont la lecture n'est pas sûre (parce que la source est corrompue)\n"
	"	x (barre de tête charada - 111DC)"},
/* A8FC */ { "SIGNE DÉVANÂGARÎ SIDDHAM","	= siddhirastou\n"
	"	* placé au début d'un texte comme une invocation\n"
	"	x (signe télougou siddham - 0C77)\n"
	"	x (signe kannara siddham - 0C84)\n"
	"	x (signe tibétain yig mgo mdoun ma ouvrant - 0F04)\n"
	"	x (birga mongol - 1800)\n"
	"	x (signe charada siddham - 111DB)"},
/* A8FD */ { "OM JAÏN DÉVANÂGARÎ",NULL},
/* A8FE */ { "LETTRE DÉVANÂGARÎ AY",NULL},
/* A8FF */ { "DIACRITIQUE VOYELLE DÉVANÂGARÎ AY",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_A9[] = {
/* A900 */ { "CHIFFRE KAYAH LI ZÉRO",NULL},
/* A901 */ { "CHIFFRE KAYAH LI UN",NULL},
/* A902 */ { "CHIFFRE KAYAH LI DEUX",NULL},
/* A903 */ { "CHIFFRE KAYAH LI TROIS",NULL},
/* A904 */ { "CHIFFRE KAYAH LI QUATRE",NULL},
/* A905 */ { "CHIFFRE KAYAH LI CINQ",NULL},
/* A906 */ { "CHIFFRE KAYAH LI SIX",NULL},
/* A907 */ { "CHIFFRE KAYAH LI SEPT",NULL},
/* A908 */ { "CHIFFRE KAYAH LI HUIT",NULL},
/* A909 */ { "CHIFFRE KAYAH LI NEUF",NULL},
/* A90A */ { "LETTRE KAYAH LI KA",NULL},
/* A90B */ { "LETTRE KAYAH LI KHA",NULL},
/* A90C */ { "LETTRE KAYAH LI GA",NULL},
/* A90D */ { "LETTRE KAYAH LI NGA",NULL},
/* A90E */ { "LETTRE KAYAH LI SA",NULL},
/* A90F */ { "LETTRE KAYAH LI ÇA",NULL},
/* A910 */ { "LETTRE KAYAH LI ZA",NULL},
/* A911 */ { "LETTRE KAYAH LI ÑA",NULL},
/* A912 */ { "LETTRE KAYAH LI TA",NULL},
/* A913 */ { "LETTRE KAYAH LI HTA",NULL},
/* A914 */ { "LETTRE KAYAH LI NA",NULL},
/* A915 */ { "LETTRE KAYAH LI PA",NULL},
/* A916 */ { "LETTRE KAYAH LI PHA","	= lettre kayah li p'a"},
/* A917 */ { "LETTRE KAYAH LI MA",NULL},
/* A918 */ { "LETTRE KAYAH LI DA",NULL},
/* A919 */ { "LETTRE KAYAH LI BA",NULL},
/* A91A */ { "LETTRE KAYAH LI RA",NULL},
/* A91B */ { "LETTRE KAYAH LI YA",NULL},
/* A91C */ { "LETTRE KAYAH LI LA",NULL},
/* A91D */ { "LETTRE KAYAH LI WA",NULL},
/* A91E */ { "LETTRE KAYAH LI THA",NULL},
/* A91F */ { "LETTRE KAYAH LI HA",NULL},
/* A920 */ { "LETTRE KAYAH LI VA",NULL},
/* A921 */ { "LETTRE KAYAH LI TCHA",NULL},
/* A922 */ { "LETTRE KAYAH LI A","	* sert de support pour les voyelles représentées par des signes combinatoires"},
/* A923 */ { "LETTRE KAYAH LI E","	* sert également de support de voyelle"},
/* A924 */ { "LETTRE KAYAH LI I",NULL},
/* A925 */ { "LETTRE KAYAH LI Ô",NULL},
/* A926 */ { "DIACRITIQUE VOYELLE KAYAH LI U",NULL},
/* A927 */ { "DIACRITIQUE VOYELLE KAYAH LI É",NULL},
/* A928 */ { "DIACRITIQUE VOYELLE KAYAH LI OU",NULL},
/* A929 */ { "DIACRITIQUE VOYELLE KAYAH LI ÉÉ",NULL},
/* A92A */ { "DIACRITIQUE VOYELLE KAYAH LI O",NULL},
/* A92B */ { "TON KAYAH LI PLOPHOU",NULL},
/* A92C */ { "TON KAYAH LI TCHALYA",NULL},
/* A92D */ { "TON KAYAH LI TCHALYA PLOPHOU",NULL},
/* A92E */ { "SIGNE KAYAH LI TCHWI",NULL},
/* A92F */ { "SIGNE KAYAH LI ÇYA",NULL},
/* A930 */ { "LETTRE REJANG KA",NULL},
/* A931 */ { "LETTRE REJANG GA",NULL},
/* A932 */ { "LETTRE REJANG NGA",NULL},
/* A933 */ { "LETTRE REJANG TA",NULL},
/* A934 */ { "LETTRE REJANG DA",NULL},
/* A935 */ { "LETTRE REJANG NA",NULL},
/* A936 */ { "LETTRE REJANG PA",NULL},
/* A937 */ { "LETTRE REJANG BA",NULL},
/* A938 */ { "LETTRE REJANG MA",NULL},
/* A939 */ { "LETTRE REJANG TCHA",NULL},
/* A93A */ { "LETTRE REJANG DJA",NULL},
/* A93B */ { "LETTRE REJANG ÑA",NULL},
/* A93C */ { "LETTRE REJANG SA",NULL},
/* A93D */ { "LETTRE REJANG RA",NULL},
/* A93E */ { "LETTRE REJANG LA",NULL},
/* A93F */ { "LETTRE REJANG YA",NULL},
/* A940 */ { "LETTRE REJANG WA",NULL},
/* A941 */ { "LETTRE REJANG HA",NULL},
/* A942 */ { "LETTRE REJANG MBA",NULL},
/* A943 */ { "LETTRE REJANG NGGA",NULL},
/* A944 */ { "LETTRE REJANG NDA",NULL},
/* A945 */ { "LETTRE REJANG ÑJA",NULL},
/* A946 */ { "LETTRE REJANG A",NULL},
/* A947 */ { "DIACRITIQUE VOYELLE REJANG I","	= kalouan"},
/* A948 */ { "DIACRITIQUE VOYELLE REJANG OU","	= kamitan"},
/* A949 */ { "DIACRITIQUE VOYELLE REJANG É","	= kamitcha"},
/* A94A */ { "DIACRITIQUE VOYELLE REJANG AÏ","	= katiling"},
/* A94B */ { "DIACRITIQUE VOYELLE REJANG O",NULL},
/* A94C */ { "DIACRITIQUE VOYELLE REJANG AOU","	= katouloung"},
/* A94D */ { "DIACRITIQUE VOYELLE REJANG EU",NULL},
/* A94E */ { "DIACRITIQUE VOYELLE REJANG ÈA","	= kadjina"},
/* A94F */ { "DIACRITIQUE CONSONNE REJANG NG","	= katoulang"},
/* A950 */ { "DIACRITIQUE CONSONNE REJANG N","	= douo déatas"},
/* A951 */ { "DIACRITIQUE CONSONNE REJANG R","	= kadjoundjoung"},
/* A952 */ { "DIACRITIQUE CONSONNE REJANG H",NULL},
/* A953 */ { "DIACRITIQUE REJANG VIRÂMA","	* ne forme pas de ligatures"},
/* A954 */ { NULL,NULL},
/* A955 */ { NULL,NULL},
/* A956 */ { NULL,NULL},
/* A957 */ { NULL,NULL},
/* A958 */ { NULL,NULL},
/* A959 */ { NULL,NULL},
/* A95A */ { NULL,NULL},
/* A95B */ { NULL,NULL},
/* A95C */ { NULL,NULL},
/* A95D */ { NULL,NULL},
/* A95E */ { NULL,NULL},
/* A95F */ { "SIGNE REJANG SECTION",NULL},
/* A960 */ { "TCH'ÔSONG HANGÛL TIKÛT-MIÛM",NULL},
/* A961 */ { "TCH'ÔSONG HANGÛL TIKÛT-PIÛP",NULL},
/* A962 */ { "TCH'ÔSONG HANGÛL TIKÛT-SIÔS",NULL},
/* A963 */ { "TCH'ÔSONG HANGÛL TIKÛT-TCHIÛTCH",NULL},
/* A964 */ { "TCH'ÔSONG HANGÛL RIÛL-KIYOK",NULL},
/* A965 */ { "TCH'ÔSONG HANGÛL RIÛL-SSANGKIYOK",NULL},
/* A966 */ { "TCH'ÔSONG HANGÛL RIÛL-TIKÛT",NULL},
/* A967 */ { "TCH'ÔSONG HANGÛL RIÛL-SSANGTIKÛT",NULL},
/* A968 */ { "TCH'ÔSONG HANGÛL RIÛL-MIÛM",NULL},
/* A969 */ { "TCH'ÔSONG HANGÛL RIÛL-PIÛP",NULL},
/* A96A */ { "TCH'ÔSONG HANGÛL RIÛL-SSANGPIÛP",NULL},
/* A96B */ { "TCH'ÔSONG HANGÛL RIÛL-KAPYO-OUNPIÛP",NULL},
/* A96C */ { "TCH'ÔSONG HANGÛL RIÛL-SIÔS",NULL},
/* A96D */ { "TCH'ÔSONG HANGÛL RIÛL-TCHIÛTCH",NULL},
/* A96E */ { "TCH'ÔSONG HANGÛL RIÛL-K'IÛK'",NULL},
/* A96F */ { "TCH'ÔSONG HANGÛL MIÛM-KIYOK",NULL},
/* A970 */ { "TCH'ÔSONG HANGÛL MIÛM-TIKÛT",NULL},
/* A971 */ { "TCH'ÔSONG HANGÛL MIÛM-SIÔS",NULL},
/* A972 */ { "TCH'ÔSONG HANGÛL PIÛP-SIÔS-T'IÛT'",NULL},
/* A973 */ { "TCH'ÔSONG HANGÛL PIÛP-K'IÛK'",NULL},
/* A974 */ { "TCH'ÔSONG HANGÛL PIÛP-HIÛH",NULL},
/* A975 */ { "TCH'ÔSONG HANGÛL SSANGSIÔS-PIÛP",NULL},
/* A976 */ { "TCH'ÔSONG HANGÛL IÛNG-RIÛL",NULL},
/* A977 */ { "TCH'ÔSONG HANGÛL IÛNG-HIÛH",NULL},
/* A978 */ { "TCH'ÔSONG HANGÛL SSANGTCHIÛTCH-HIÛH",NULL},
/* A979 */ { "TCH'ÔSONG HANGÛL SSANGT'IÛT'",NULL},
/* A97A */ { "TCH'ÔSONG HANGÛL P'IÛP'-HIÛH",NULL},
/* A97B */ { "TCH'ÔSONG HANGÛL HIÛH-SIÔS",NULL},
/* A97C */ { "TCH'ÔSONG HANGÛL SSANGYORINHIÛH",NULL},
/* A97D */ { NULL,NULL},
/* A97E */ { NULL,NULL},
/* A97F */ { NULL,NULL},
/* A980 */ { "DIACRITIQUE JAVANAIS PANYANGGA","	= tchandrabindou"},
/* A981 */ { "DIACRITIQUE JAVANAIS CECAK","	= anousvâra"},
/* A982 */ { "DIACRITIQUE JAVANAIS LAYAR","	= r final\n"
	"	* également utilisé pour le repha dans la translittération du kawi\n"
	"	x (diacritique balinais surang - 1B03)"},
/* A983 */ { "DIACRITIQUE JAVANAIS WIGNYAN","	= visarga"},
/* A984 */ { "LETTRE JAVANAISE A",NULL},
/* A985 */ { "LETTRE JAVANAISE I KAWI",NULL},
/* A986 */ { "LETTRE JAVANAISE I",NULL},
/* A987 */ { "LETTRE JAVANAISE II",NULL},
/* A988 */ { "LETTRE JAVANAISE U",NULL},
/* A989 */ { "LETTRE JAVANAISE PA CEREK","	= r vocalique\n"
	"	* rĕ en javanais"},
/* A98A */ { "LETTRE JAVANAISE NGA LELET","	= l vocalique\n"
	"	* lĕ en javanais"},
/* A98B */ { "LETTRE JAVANAISE NGA LELET RASWADI","	= ll vocalique\n"
	"	* leu en javanais"},
/* A98C */ { "LETTRE JAVANAISE E",NULL},
/* A98D */ { "LETTRE JAVANAISE AI",NULL},
/* A98E */ { "LETTRE JAVANAISE O",NULL},
/* A98F */ { "LETTRE JAVANAISE KA",NULL},
/* A990 */ { "LETTRE JAVANAISE KA SASAK","	= qa"},
/* A991 */ { "LETTRE JAVANAISE KA MURDA","	= kha"},
/* A992 */ { "LETTRE JAVANAISE GA",NULL},
/* A993 */ { "LETTRE JAVANAISE GA MURDA","	= gha"},
/* A994 */ { "LETTRE JAVANAISE NGA",NULL},
/* A995 */ { "LETTRE JAVANAISE CA",NULL},
/* A996 */ { "LETTRE JAVANAISE CA MURDA","	= cha"},
/* A997 */ { "LETTRE JAVANAISE JA",NULL},
/* A998 */ { "LETTRE JAVANAISE ÑA MURDA","	= jnya\n"
	"	x (lettre balinaise djña archaïque - 1B4C)"},
/* A999 */ { "LETTRE JAVANAISE JA MAHAPRANA","	= jha"},
/* A99A */ { "LETTRE JAVANAISE ÑA",NULL},
/* A99B */ { "LETTRE JAVANAISE TTA",NULL},
/* A99C */ { "LETTRE JAVANAISE TTA MAHAPRANA","	= ttha"},
/* A99D */ { "LETTRE JAVANAISE DDA",NULL},
/* A99E */ { "LETTRE JAVANAISE DDA MAHAPRANA","	= ddha"},
/* A99F */ { "LETTRE JAVANAISE NA MURDA","	= nna"},
/* A9A0 */ { "LETTRE JAVANAISE TA",NULL},
/* A9A1 */ { "LETTRE JAVANAISE TA MURDA","	= tha"},
/* A9A2 */ { "LETTRE JAVANAISE DA",NULL},
/* A9A3 */ { "LETTRE JAVANAISE DA MAHAPRANA","	= dha"},
/* A9A4 */ { "LETTRE JAVANAISE NA",NULL},
/* A9A5 */ { "LETTRE JAVANAISE PA",NULL},
/* A9A6 */ { "LETTRE JAVANAISE PA MURDA","	= pha (p'a)"},
/* A9A7 */ { "LETTRE JAVANAISE BA",NULL},
/* A9A8 */ { "LETTRE JAVANAISE BA MURDA","	= bha"},
/* A9A9 */ { "LETTRE JAVANAISE MA",NULL},
/* A9AA */ { "LETTRE JAVANAISE YA",NULL},
/* A9AB */ { "LETTRE JAVANAISE RA",NULL},
/* A9AC */ { "LETTRE JAVANAISE RA AGUNG",NULL},
/* A9AD */ { "LETTRE JAVANAISE LA",NULL},
/* A9AE */ { "LETTRE JAVANAISE WA",NULL},
/* A9AF */ { "LETTRE JAVANAISE SA MURDA","	= ça"},
/* A9B0 */ { "LETTRE JAVANAISE SA MAHAPRANA","	= cha"},
/* A9B1 */ { "LETTRE JAVANAISE SA",NULL},
/* A9B2 */ { "LETTRE JAVANAISE HA",NULL},
/* A9B3 */ { "DIACRITIQUE JAVANAIS CECAK TELU","	= noukta"},
/* A9B4 */ { "DIACRITIQUE VOYELLE JAVANAISE TARUNG","	= â\n"
	"	* o en soundanais, non utilisée de manière isolée en javanais"},
/* A9B5 */ { "DIACRITIQUE VOYELLE JAVANAISE TOLONG","	* une variante de glyphe de A9B4"},
/* A9B6 */ { "DIACRITIQUE VOYELLE JAVANAISE WULU","	= i"},
/* A9B7 */ { "DIACRITIQUE VOYELLE JAVANAISE WULU MELIK","	= î"},
/* A9B8 */ { "DIACRITIQUE VOYELLE JAVANAISE SUKU","	= ou"},
/* A9B9 */ { "DIACRITIQUE VOYELLE JAVANAISE SUKU MENDUT","	= oû"},
/* A9BA */ { "DIACRITIQUE VOYELLE JAVANAISE TALING","	= e"},
/* A9BB */ { "DIACRITIQUE VOYELLE JAVANAISE DIRGA MURE","	= aï"},
/* A9BC */ { "DIACRITIQUE VOYELLE JAVANAISE PEPET","	= ĕ"},
/* A9BD */ { "DIACRITIQUE CONSONNE JAVANAISE KERET","	= r vocalique\n"
	"	* rĕ médial en javanais"},
/* A9BE */ { "DIACRITIQUE CONSONNE JAVANAISE PENGKAL","	= ya médial"},
/* A9BF */ { "DIACRITIQUE CONSONNE JAVANAISE CAKRA","	= ra médial"},
/* A9C0 */ { "DIACRITIQUE JAVANAIS PANGKON","	= virâma"},
/* A9C1 */ { "RERENGGAN GAUCHE JAVANAIS",NULL},
/* A9C2 */ { "RERENGGAN DROIT JAVANAIS",NULL},
/* A9C3 */ { "PADA ANDAP JAVANAIS",NULL},
/* A9C4 */ { "PADA MADYA JAVANAIS",NULL},
/* A9C5 */ { "PADA LUHUR JAVANAIS",NULL},
/* A9C6 */ { "PADA WINDU JAVANAIS",NULL},
/* A9C7 */ { "PADA PANGKAT JAVANAIS",NULL},
/* A9C8 */ { "PADA LINGSA JAVANAIS","	= danda"},
/* A9C9 */ { "PADA LUNGSI JAVANAIS","	= double danda"},
/* A9CA */ { "PADA ADEG JAVANAIS",NULL},
/* A9CB */ { "PADA ADEG ADEG JAVANAIS",NULL},
/* A9CC */ { "PADA PISELEH JAVANAIS",NULL},
/* A9CD */ { "PADA PISELEH JAVANAIS CULBUTÉ",NULL},
/* A9CE */ { NULL,NULL},
/* A9CF */ { "PANGRANGKEP JAVANAIS","	* utilisé aussi en bougui\n"
	"	x (chiffre arabo-indien deux - 0662)"},
/* A9D0 */ { "CHIFFRE JAVANAIS ZÉRO",NULL},
/* A9D1 */ { "CHIFFRE JAVANAIS UN",NULL},
/* A9D2 */ { "CHIFFRE JAVANAIS DEUX",NULL},
/* A9D3 */ { "CHIFFRE JAVANAIS TROIS",NULL},
/* A9D4 */ { "CHIFFRE JAVANAIS QUATRE",NULL},
/* A9D5 */ { "CHIFFRE JAVANAIS CINQ",NULL},
/* A9D6 */ { "CHIFFRE JAVANAIS SIX",NULL},
/* A9D7 */ { "CHIFFRE JAVANAIS SEPT",NULL},
/* A9D8 */ { "CHIFFRE JAVANAIS HUIT",NULL},
/* A9D9 */ { "CHIFFRE JAVANAIS NEUF",NULL},
/* A9DA */ { NULL,NULL},
/* A9DB */ { NULL,NULL},
/* A9DC */ { NULL,NULL},
/* A9DD */ { NULL,NULL},
/* A9DE */ { "PADA TIRTA TUMETES JAVANAIS",NULL},
/* A9DF */ { "PADA ISEN-ISEN JAVANAIS",NULL},
/* A9E0 */ { "LETTRE BIRMANE CHAN GHA",NULL},
/* A9E1 */ { "LETTRE BIRMANE CHAN TCHHA",NULL},
/* A9E2 */ { "LETTRE BIRMANE CHAN DJHA",NULL},
/* A9E3 */ { "LETTRE BIRMANE CHAN NNA",NULL},
/* A9E4 */ { "LETTRE BIRMANE CHAN BHA",NULL},
/* A9E5 */ { "DIACRITIQUE BIRMAN CHAN SAW",NULL},
/* A9E6 */ { "LETTRE MODIFICATIVE BIRMANE CHAN RÉDUPLICATION","	x (lettre modificative birmane khamti réduplication - AA70)"},
/* A9E7 */ { "LETTRE BIRMANE TAÏ-LAING ÑA",NULL},
/* A9E8 */ { "LETTRE BIRMANE TAÏ-LAING FA",NULL},
/* A9E9 */ { "LETTRE BIRMANE TAÏ-LAING GA",NULL},
/* A9EA */ { "LETTRE BIRMANE TAÏ-LAING GHA",NULL},
/* A9EB */ { "LETTRE BIRMANE TAÏ-LAING DJA",NULL},
/* A9EC */ { "LETTRE BIRMANE TAÏ-LAING DJHA",NULL},
/* A9ED */ { "LETTRE BIRMANE TAÏ-LAING DDA",NULL},
/* A9EE */ { "LETTRE BIRMANE TAÏ-LAING DDHA",NULL},
/* A9EF */ { "LETTRE BIRMANE TAÏ-LAING NNA",NULL},
/* A9F0 */ { "CHIFFRE BIRMAN TAÏ-LAING ZÉRO",NULL},
/* A9F1 */ { "CHIFFRE BIRMAN TAÏ-LAING UN",NULL},
/* A9F2 */ { "CHIFFRE BIRMAN TAÏ-LAING DEUX",NULL},
/* A9F3 */ { "CHIFFRE BIRMAN TAÏ-LAING TROIS",NULL},
/* A9F4 */ { "CHIFFRE BIRMAN TAÏ-LAING QUATRE",NULL},
/* A9F5 */ { "CHIFFRE BIRMAN TAÏ-LAING CINQ",NULL},
/* A9F6 */ { "CHIFFRE BIRMAN TAÏ-LAING SIX",NULL},
/* A9F7 */ { "CHIFFRE BIRMAN TAÏ-LAING SEPT",NULL},
/* A9F8 */ { "CHIFFRE BIRMAN TAÏ-LAING HUIT",NULL},
/* A9F9 */ { "CHIFFRE BIRMAN TAÏ-LAING NEUF",NULL},
/* A9FA */ { "LETTRE BIRMANE TAÏ-LAING LLA",NULL},
/* A9FB */ { "LETTRE BIRMANE TAÏ-LAING DA",NULL},
/* A9FC */ { "LETTRE BIRMANE TAÏ-LAING DHA",NULL},
/* A9FD */ { "LETTRE BIRMANE TAÏ-LAING BA",NULL},
/* A9FE */ { "LETTRE BIRMANE TAÏ-LAING BHA",NULL},
/* A9FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_AA[] = {
/* AA00 */ { "LETTRE TCHAME A",NULL},
/* AA01 */ { "LETTRE TCHAME I",NULL},
/* AA02 */ { "LETTRE TCHAME OU",NULL},
/* AA03 */ { "LETTRE TCHAME É",NULL},
/* AA04 */ { "LETTRE TCHAME AI",NULL},
/* AA05 */ { "LETTRE TCHAME O",NULL},
/* AA06 */ { "LETTRE TCHAME KA",NULL},
/* AA07 */ { "LETTRE TCHAME KHA",NULL},
/* AA08 */ { "LETTRE TCHAME GA",NULL},
/* AA09 */ { "LETTRE TCHAME GHA",NULL},
/* AA0A */ { "LETTRE TCHAME NGU",NULL},
/* AA0B */ { "LETTRE TCHAME NGA",NULL},
/* AA0C */ { "LETTRE TCHAME TCHHA",NULL},
/* AA0D */ { "LETTRE TCHAME TCHHHA",NULL},
/* AA0E */ { "LETTRE TCHAME DJA",NULL},
/* AA0F */ { "LETTRE TCHAME DJHA",NULL},
/* AA10 */ { "LETTRE TCHAME NHU",NULL},
/* AA11 */ { "LETTRE TCHAME NHA",NULL},
/* AA12 */ { "LETTRE TCHAME NHDJA",NULL},
/* AA13 */ { "LETTRE TCHAME TA",NULL},
/* AA14 */ { "LETTRE TCHAME THA",NULL},
/* AA15 */ { "LETTRE TCHAME DA",NULL},
/* AA16 */ { "LETTRE TCHAME DHA",NULL},
/* AA17 */ { "LETTRE TCHAME NU",NULL},
/* AA18 */ { "LETTRE TCHAME NA",NULL},
/* AA19 */ { "LETTRE TCHAME DDA",NULL},
/* AA1A */ { "LETTRE TCHAME PA",NULL},
/* AA1B */ { "LETTRE TCHAME PPA",NULL},
/* AA1C */ { "LETTRE TCHAME PHA","	= lettre tchame p'a"},
/* AA1D */ { "LETTRE TCHAME BA",NULL},
/* AA1E */ { "LETTRE TCHAME BHA",NULL},
/* AA1F */ { "LETTRE TCHAME MU",NULL},
/* AA20 */ { "LETTRE TCHAME MA",NULL},
/* AA21 */ { "LETTRE TCHAME BBA",NULL},
/* AA22 */ { "LETTRE TCHAME YA",NULL},
/* AA23 */ { "LETTRE TCHAME RA",NULL},
/* AA24 */ { "LETTRE TCHAME LA",NULL},
/* AA25 */ { "LETTRE TCHAME VA",NULL},
/* AA26 */ { "LETTRE TCHAME CHA",NULL},
/* AA27 */ { "LETTRE TCHAME SA",NULL},
/* AA28 */ { "LETTRE TCHAME HA",NULL},
/* AA29 */ { "DIACRITIQUE VOYELLE TCHAME Â",NULL},
/* AA2A */ { "DIACRITIQUE VOYELLE TCHAME I",NULL},
/* AA2B */ { "DIACRITIQUE VOYELLE TCHAME Î",NULL},
/* AA2C */ { "DIACRITIQUE VOYELLE TCHAME EI",NULL},
/* AA2D */ { "DIACRITIQUE VOYELLE TCHAME OU",NULL},
/* AA2E */ { "DIACRITIQUE VOYELLE TCHAME E",NULL},
/* AA2F */ { "DIACRITIQUE VOYELLE TCHAME O",NULL},
/* AA30 */ { "DIACRITIQUE VOYELLE TCHAME AI",NULL},
/* AA31 */ { "DIACRITIQUE VOYELLE TCHAME AOU",NULL},
/* AA32 */ { "DIACRITIQUE VOYELLE TCHAME U",NULL},
/* AA33 */ { "DIACRITIQUE CONSONNE TCHAME YA",NULL},
/* AA34 */ { "DIACRITIQUE CONSONNE TCHAME RA",NULL},
/* AA35 */ { "DIACRITIQUE CONSONNE TCHAME LA",NULL},
/* AA36 */ { "DIACRITIQUE CONSONNE TCHAME WA",NULL},
/* AA37 */ { NULL,NULL},
/* AA38 */ { NULL,NULL},
/* AA39 */ { NULL,NULL},
/* AA3A */ { NULL,NULL},
/* AA3B */ { NULL,NULL},
/* AA3C */ { NULL,NULL},
/* AA3D */ { NULL,NULL},
/* AA3E */ { NULL,NULL},
/* AA3F */ { NULL,NULL},
/* AA40 */ { "LETTRE TCHAME K FINAL",NULL},
/* AA41 */ { "LETTRE TCHAME G FINAL",NULL},
/* AA42 */ { "LETTRE TCHAME NG FINAL",NULL},
/* AA43 */ { "DIACRITIQUE CONSONNE TCHAME NG FINAL",NULL},
/* AA44 */ { "LETTRE TCHAME TCH FINAL",NULL},
/* AA45 */ { "LETTRE TCHAME T FINAL",NULL},
/* AA46 */ { "LETTRE TCHAME N FINAL",NULL},
/* AA47 */ { "LETTRE TCHAME P FINAL",NULL},
/* AA48 */ { "LETTRE TCHAME Y FINAL",NULL},
/* AA49 */ { "LETTRE TCHAME R FINAL",NULL},
/* AA4A */ { "LETTRE TCHAME L FINAL",NULL},
/* AA4B */ { "LETTRE TCHAME CH FINAL",NULL},
/* AA4C */ { "DIACRITIQUE CONSONNE TCHAME M FINAL",NULL},
/* AA4D */ { "DIACRITIQUE CONSONNE TCHAME H FINAL",NULL},
/* AA4E */ { NULL,NULL},
/* AA4F */ { NULL,NULL},
/* AA50 */ { "CHIFFRE TCHAM ZÉRO",NULL},
/* AA51 */ { "CHIFFRE TCHAM UN",NULL},
/* AA52 */ { "CHIFFRE TCHAM DEUX",NULL},
/* AA53 */ { "CHIFFRE TCHAM TROIS",NULL},
/* AA54 */ { "CHIFFRE TCHAM QUATRE",NULL},
/* AA55 */ { "CHIFFRE TCHAM CINQ",NULL},
/* AA56 */ { "CHIFFRE TCHAM SIX",NULL},
/* AA57 */ { "CHIFFRE TCHAM SEPT",NULL},
/* AA58 */ { "CHIFFRE TCHAM HUIT",NULL},
/* AA59 */ { "CHIFFRE TCHAM NEUF",NULL},
/* AA5A */ { NULL,NULL},
/* AA5B */ { NULL,NULL},
/* AA5C */ { "PONCTUATION TCHAME SPIRALE",NULL},
/* AA5D */ { "PONCTUATION TCHAME DANDA",NULL},
/* AA5E */ { "PONCTUATION TCHAME DOUBLE DANDA",NULL},
/* AA5F */ { "PONCTUATION TCHAME TRIPLE DANDA",NULL},
/* AA60 */ { "LETTRE BIRMANE KHAMTI GA","	~ AA60 FE00 forme pointée"},
/* AA61 */ { "LETTRE BIRMANE KHAMTI TCHA","	~ AA61 FE00 forme pointée"},
/* AA62 */ { "LETTRE BIRMANE KHAMTI TCHHA","	~ AA62 FE00 forme pointée"},
/* AA63 */ { "LETTRE BIRMANE KHAMTI DJA","	~ AA63 FE00 forme pointée"},
/* AA64 */ { "LETTRE BIRMANE KHAMTI DJHA","	~ AA64 FE00 forme pointée"},
/* AA65 */ { "LETTRE BIRMANE KHAMTI ÑA","	~ AA65 FE00 forme pointée"},
/* AA66 */ { "LETTRE BIRMANE KHAMTI TTA","	~ AA66 FE00 forme pointée"},
/* AA67 */ { "LETTRE BIRMANE KHAMTI TTHA",NULL},
/* AA68 */ { "LETTRE BIRMANE KHAMTI DDA",NULL},
/* AA69 */ { "LETTRE BIRMANE KHAMTI DDHA",NULL},
/* AA6A */ { "LETTRE BIRMANE KHAMTI DHA",NULL},
/* AA6B */ { "LETTRE BIRMANE KHAMTI NA","	~ AA6B FE00 forme pointée"},
/* AA6C */ { "LETTRE BIRMANE KHAMTI SA","	~ AA6C FE00 forme pointée"},
/* AA6D */ { "LETTRE BIRMANE KHAMTI HA",NULL},
/* AA6E */ { "LETTRE BIRMANE KHAMTI LLA","	* le nom formel de ce caractère en anglais est erroné"},
/* AA6F */ { "LETTRE BIRMANE KHAMTI FA","	~ AA6F FE00 forme pointée"},
/* AA70 */ { "LETTRE MODIFICATIVE BIRMANE KHAMTI RÉDUPLICATION","	x (lettre modificative birmane chan réduplication - A9E6)"},
/* AA71 */ { "LETTRE BIRMANE KHAMTI XA",NULL},
/* AA72 */ { "LETTRE BIRMANE KHAMTI ZA",NULL},
/* AA73 */ { "LETTRE BIRMANE KHAMTI RA",NULL},
/* AA74 */ { "LOGOGRAMME BIRMAN KHAMTI OAY",NULL},
/* AA75 */ { "LOGOGRAMME BIRMAN KHAMTI QN",NULL},
/* AA76 */ { "LOGOGRAMME BIRMAN KHAMTI HM",NULL},
/* AA77 */ { "SYMBOLE BIRMAN AITON EXCLAMATION",NULL},
/* AA78 */ { "SYMBOLE BIRMAN AITON UN",NULL},
/* AA79 */ { "SYMBOLE BIRMAN AITON DEUX",NULL},
/* AA7A */ { "LETTRE BIRMANE AITON RA","	~ AA7A FE00 forme pointée"},
/* AA7B */ { "DIACRITIQUE TON BIRMAN KAREN PAO",NULL},
/* AA7C */ { "DIACRITIQUE BIRMAN TAÏ-LAING TON-2",NULL},
/* AA7D */ { "DIACRITIQUE BIRMAN TAÏ-LAING TON-5",NULL},
/* AA7E */ { "LETTRE BIRMANE PALAUNG CHWÉ TCHHA",NULL},
/* AA7F */ { "LETTRE BIRMANE PALAUNG CHWÉ ÇA",NULL},
/* AA80 */ { "LETTRE TAÏ-VIET KO BAS",NULL},
/* AA81 */ { "LETTRE TAÏ-VIET KO HAUT",NULL},
/* AA82 */ { "LETTRE TAÏ-VIET KHO BAS",NULL},
/* AA83 */ { "LETTRE TAÏ-VIET KHO HAUT",NULL},
/* AA84 */ { "LETTRE TAÏ-VIET KHHO BAS",NULL},
/* AA85 */ { "LETTRE TAÏ-VIET KHHO HAUT",NULL},
/* AA86 */ { "LETTRE TAÏ-VIET GO BAS",NULL},
/* AA87 */ { "LETTRE TAÏ-VIET GO HAUT",NULL},
/* AA88 */ { "LETTRE TAÏ-VIET NGO BAS",NULL},
/* AA89 */ { "LETTRE TAÏ-VIET NGO HAUT",NULL},
/* AA8A */ { "LETTRE TAÏ-VIET TCHO BAS",NULL},
/* AA8B */ { "LETTRE TAÏ-VIET TCHO HAUT",NULL},
/* AA8C */ { "LETTRE TAÏ-VIET TCHHO BAS",NULL},
/* AA8D */ { "LETTRE TAÏ-VIET TCHHO HAUT",NULL},
/* AA8E */ { "LETTRE TAÏ-VIET SO BAS",NULL},
/* AA8F */ { "LETTRE TAÏ-VIET SO HAUT",NULL},
/* AA90 */ { "LETTRE TAÏ-VIET ÑO BAS",NULL},
/* AA91 */ { "LETTRE TAÏ-VIET ÑO HAUT",NULL},
/* AA92 */ { "LETTRE TAÏ-VIET DO BAS",NULL},
/* AA93 */ { "LETTRE TAÏ-VIET DO HAUT",NULL},
/* AA94 */ { "LETTRE TAÏ-VIET TO BAS",NULL},
/* AA95 */ { "LETTRE TAÏ-VIET TO HAUT",NULL},
/* AA96 */ { "LETTRE TAÏ-VIET THO BAS",NULL},
/* AA97 */ { "LETTRE TAÏ-VIET THO HAUT",NULL},
/* AA98 */ { "LETTRE TAÏ-VIET NO BAS",NULL},
/* AA99 */ { "LETTRE TAÏ-VIET NO HAUT",NULL},
/* AA9A */ { "LETTRE TAÏ-VIET BO BAS",NULL},
/* AA9B */ { "LETTRE TAÏ-VIET BO HAUT",NULL},
/* AA9C */ { "LETTRE TAÏ-VIET PO BAS",NULL},
/* AA9D */ { "LETTRE TAÏ-VIET PO HAUT",NULL},
/* AA9E */ { "LETTRE TAÏ-VIET PHO BAS",NULL},
/* AA9F */ { "LETTRE TAÏ-VIET PHO HAUT",NULL},
/* AAA0 */ { "LETTRE TAÏ-VIET FO BAS",NULL},
/* AAA1 */ { "LETTRE TAÏ-VIET FO HAUT",NULL},
/* AAA2 */ { "LETTRE TAÏ-VIET MO BAS",NULL},
/* AAA3 */ { "LETTRE TAÏ-VIET MO HAUT",NULL},
/* AAA4 */ { "LETTRE TAÏ-VIET YO BAS",NULL},
/* AAA5 */ { "LETTRE TAÏ-VIET YO HAUT",NULL},
/* AAA6 */ { "LETTRE TAÏ-VIET RO BAS",NULL},
/* AAA7 */ { "LETTRE TAÏ-VIET RO HAUT",NULL},
/* AAA8 */ { "LETTRE TAÏ-VIET LO BAS",NULL},
/* AAA9 */ { "LETTRE TAÏ-VIET LO HAUT",NULL},
/* AAAA */ { "LETTRE TAÏ-VIET VO BAS",NULL},
/* AAAB */ { "LETTRE TAÏ-VIET VO HAUT",NULL},
/* AAAC */ { "LETTRE TAÏ-VIET HO BAS",NULL},
/* AAAD */ { "LETTRE TAÏ-VIET HO HAUT",NULL},
/* AAAE */ { "LETTRE TAÏ-VIET O BAS",NULL},
/* AAAF */ { "LETTRE TAÏ-VIET O HAUT",NULL},
/* AAB0 */ { "DIACRITIQUE TAÏ-VIET MAÏ KANG",NULL},
/* AAB1 */ { "VOYELLE TAÏ-VIET Â",NULL},
/* AAB2 */ { "DIACRITIQUE VOYELLE TAÏ-VIET I",NULL},
/* AAB3 */ { "DIACRITIQUE VOYELLE TAÏ-VIET U",NULL},
/* AAB4 */ { "DIACRITIQUE VOYELLE TAÏ-VIET OU",NULL},
/* AAB5 */ { "VOYELLE TAÏ-VIET É","	* précède la consonne en ordre visuel"},
/* AAB6 */ { "VOYELLE TAÏ-VIET O","	* précède la consonne en ordre visuel"},
/* AAB7 */ { "DIACRITIQUE TAÏ-VIET MAÏ KHIT",NULL},
/* AAB8 */ { "DIACRITIQUE VOYELLE TAÏ-VIET IA",NULL},
/* AAB9 */ { "VOYELLE TAÏ-VIET UA","	* précède la consonne en ordre visuel"},
/* AABA */ { "VOYELLE TAÏ-VIET OUA",NULL},
/* AABB */ { "VOYELLE TAÏ-VIET AU","	* précède la consonne en ordre visuel"},
/* AABC */ { "VOYELLE TAÏ-VIET AY","	* précède la consonne en ordre visuel"},
/* AABD */ { "VOYELLE TAÏ-VIET AN",NULL},
/* AABE */ { "DIACRITIQUE VOYELLE TAÏ-VIET AM",NULL},
/* AABF */ { "DIACRITIQUE TON TAÏ-VIET MAÏ EK",NULL},
/* AAC0 */ { "TON TAÏ-VIET MAÏ NUNG",NULL},
/* AAC1 */ { "DIACRITIQUE TON TAÏ-VIET MAÏ THO",NULL},
/* AAC2 */ { "TON TAÏ-VIET MAÏ SONG",NULL},
/* AAC3 */ { NULL,NULL},
/* AAC4 */ { NULL,NULL},
/* AAC5 */ { NULL,NULL},
/* AAC6 */ { NULL,NULL},
/* AAC7 */ { NULL,NULL},
/* AAC8 */ { NULL,NULL},
/* AAC9 */ { NULL,NULL},
/* AACA */ { NULL,NULL},
/* AACB */ { NULL,NULL},
/* AACC */ { NULL,NULL},
/* AACD */ { NULL,NULL},
/* AACE */ { NULL,NULL},
/* AACF */ { NULL,NULL},
/* AAD0 */ { NULL,NULL},
/* AAD1 */ { NULL,NULL},
/* AAD2 */ { NULL,NULL},
/* AAD3 */ { NULL,NULL},
/* AAD4 */ { NULL,NULL},
/* AAD5 */ { NULL,NULL},
/* AAD6 */ { NULL,NULL},
/* AAD7 */ { NULL,NULL},
/* AAD8 */ { NULL,NULL},
/* AAD9 */ { NULL,NULL},
/* AADA */ { NULL,NULL},
/* AADB */ { "SYMBOLE TAÏ-VIET KON","	= personne"},
/* AADC */ { "SYMBOLE TAÏ-VIET NUNG","	= un"},
/* AADD */ { "SYMBOLE TAÏ-VIET SAM","	x (caractère thaï maïyamok - 0E46)"},
/* AADE */ { "SYMBOLE TAÏ-VIET HO HOÏ","	* indique le début d'un texte dans des chants ou des poèmes"},
/* AADF */ { "SYMBOLE TAÏ-VIET KOÏ KOÏ","	* indique la fin d'un texte dans des chants ou des poèmes"},
/* AAE0 */ { "LETTRE MEITEI MAYEK É",NULL},
/* AAE1 */ { "LETTRE MEITEI MAYEK O",NULL},
/* AAE2 */ { "LETTRE MEITEI MAYEK TCHHA",NULL},
/* AAE3 */ { "LETTRE MEITEI MAYEK ÑA",NULL},
/* AAE4 */ { "LETTRE MEITEI MAYEK TTA",NULL},
/* AAE5 */ { "LETTRE MEITEI MAYEK TTHA",NULL},
/* AAE6 */ { "LETTRE MEITEI MAYEK DDA",NULL},
/* AAE7 */ { "LETTRE MEITEI MAYEK DDHA",NULL},
/* AAE8 */ { "LETTRE MEITEI MAYEK NNA",NULL},
/* AAE9 */ { "LETTRE MEITEI MAYEK ÇA",NULL},
/* AAEA */ { "LETTRE MEITEI MAYEK CHA",NULL},
/* AAEB */ { "DIACRITIQUE VOYELLE MEITEI MAYEK Î",NULL},
/* AAEC */ { "DIACRITIQUE VOYELLE MEITEI MAYEK OÛ",NULL},
/* AAED */ { "DIACRITIQUE VOYELLE MEITEI MAYEK ÂÏ",NULL},
/* AAEE */ { "DIACRITIQUE VOYELLE MEITEI MAYEK AOU",NULL},
/* AAEF */ { "DIACRITIQUE VOYELLE MEITEI MAYEK ÂOU",NULL},
/* AAF0 */ { "TCHEIKHAN MEITEI MAYEK","	= danda"},
/* AAF1 */ { "AHANG KHOUDAM MEITEI MAYEK","	= point d'interrogation"},
/* AAF2 */ { "ANDJI MEITEI MAYEK","	* un signe philosophique\n"
	"	x (om dévanâgarî - 0950)"},
/* AAF3 */ { "MARQUE DE RÉPÉTITION DE SYLLABE MEITEI MAYEK",NULL},
/* AAF4 */ { "MARQUE DE RÉPÉTITION DE MOT MEITEI MAYEK",NULL},
/* AAF5 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK VISARGA",NULL},
/* AAF6 */ { "DIACRITIQUE MEITEI MAYEK VIRÂMA","	* utilisé pour former des ligatures dans des orthographes historiques\n"
	"	x (diacritique birman virâma - 1039)"},
/* AAF7 */ { NULL,NULL},
/* AAF8 */ { NULL,NULL},
/* AAF9 */ { NULL,NULL},
/* AAFA */ { NULL,NULL},
/* AAFB */ { NULL,NULL},
/* AAFC */ { NULL,NULL},
/* AAFD */ { NULL,NULL},
/* AAFE */ { NULL,NULL},
/* AAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_AB[] = {
/* AB00 */ { NULL,NULL},
/* AB01 */ { "SYLLABE ÉTHIOPIENNE TTHU",NULL},
/* AB02 */ { "SYLLABE ÉTHIOPIENNE TTHI",NULL},
/* AB03 */ { "SYLLABE ÉTHIOPIENNE TTHAA",NULL},
/* AB04 */ { "SYLLABE ÉTHIOPIENNE TTHEE",NULL},
/* AB05 */ { "SYLLABE ÉTHIOPIENNE TTHE",NULL},
/* AB06 */ { "SYLLABE ÉTHIOPIENNE TTHO",NULL},
/* AB07 */ { NULL,NULL},
/* AB08 */ { NULL,NULL},
/* AB09 */ { "SYLLABE ÉTHIOPIENNE DDHU",NULL},
/* AB0A */ { "SYLLABE ÉTHIOPIENNE DDHI",NULL},
/* AB0B */ { "SYLLABE ÉTHIOPIENNE DDHAA",NULL},
/* AB0C */ { "SYLLABE ÉTHIOPIENNE DDHEE",NULL},
/* AB0D */ { "SYLLABE ÉTHIOPIENNE DDHE",NULL},
/* AB0E */ { "SYLLABE ÉTHIOPIENNE DDHO",NULL},
/* AB0F */ { NULL,NULL},
/* AB10 */ { NULL,NULL},
/* AB11 */ { "SYLLABE ÉTHIOPIENNE DZU",NULL},
/* AB12 */ { "SYLLABE ÉTHIOPIENNE DZI",NULL},
/* AB13 */ { "SYLLABE ÉTHIOPIENNE DZAA",NULL},
/* AB14 */ { "SYLLABE ÉTHIOPIENNE DZEE",NULL},
/* AB15 */ { "SYLLABE ÉTHIOPIENNE DZE",NULL},
/* AB16 */ { "SYLLABE ÉTHIOPIENNE DZO",NULL},
/* AB17 */ { NULL,NULL},
/* AB18 */ { NULL,NULL},
/* AB19 */ { NULL,NULL},
/* AB1A */ { NULL,NULL},
/* AB1B */ { NULL,NULL},
/* AB1C */ { NULL,NULL},
/* AB1D */ { NULL,NULL},
/* AB1E */ { NULL,NULL},
/* AB1F */ { NULL,NULL},
/* AB20 */ { "SYLLABE ÉTHIOPIENNE CCHHA",NULL},
/* AB21 */ { "SYLLABE ÉTHIOPIENNE CCHHU",NULL},
/* AB22 */ { "SYLLABE ÉTHIOPIENNE CCHHI",NULL},
/* AB23 */ { "SYLLABE ÉTHIOPIENNE CCHHAA",NULL},
/* AB24 */ { "SYLLABE ÉTHIOPIENNE CCHHEE",NULL},
/* AB25 */ { "SYLLABE ÉTHIOPIENNE CCHHE",NULL},
/* AB26 */ { "SYLLABE ÉTHIOPIENNE CCHHO",NULL},
/* AB27 */ { NULL,NULL},
/* AB28 */ { "SYLLABE ÉTHIOPIENNE BBA",NULL},
/* AB29 */ { "SYLLABE ÉTHIOPIENNE BBU",NULL},
/* AB2A */ { "SYLLABE ÉTHIOPIENNE BBI",NULL},
/* AB2B */ { "SYLLABE ÉTHIOPIENNE BBAA",NULL},
/* AB2C */ { "SYLLABE ÉTHIOPIENNE BBEE",NULL},
/* AB2D */ { "SYLLABE ÉTHIOPIENNE BBE",NULL},
/* AB2E */ { "SYLLABE ÉTHIOPIENNE BBO",NULL},
/* AB2F */ { NULL,NULL},
/* AB30 */ { "LETTRE MINUSCULE LATINE ALPHA BARRÉ","		* Cette lettre est un alpha latin traversé en son milieu par une ligne horizontale. Dans certaines polices, la ligne peut ne pas dépasser le bord de la lettre – en ce cas, il ne faut pas confondre cette lettre avec une ligature formée de l'epsilon et du iota."},
/* AB31 */ { "LETTRE MINUSCULE LATINE A SCHWA RÉFLÉCHI",NULL},
/* AB32 */ { "LETTRE MINUSCULE LATINE E GOTHIQUE","	x (minuscule mathématique gothique e - 1D522)"},
/* AB33 */ { "LETTRE MINUSCULE LATINE E BARRÉ HORIZONTALEMENT",NULL},
/* AB34 */ { "LETTRE MINUSCULE LATINE E À FIORITURE",NULL},
/* AB35 */ { "LETTRE MINUSCULE LATINE F DOUX","	x (lettre minuscule latine f - 0066)"},
/* AB36 */ { "LETTRE MINUSCULE LATINE G CURSIF À QUEUE CROISÉE",NULL},
/* AB37 */ { "LETTRE MINUSCULE LATINE L TRAVERSÉ D'UN S RENVERSÉ COUCHÉ",NULL},
/* AB38 */ { "LETTRE MINUSCULE LATINE L DOUBLE TILDE MÉDIAN","	x (lettre minuscule latine l tilde médian - 026B)\n"
	"	x (lettre minuscule latine l à double barre - 2C61)"},
/* AB39 */ { "LETTRE MINUSCULE LATINE L ROND MÉDIAN",NULL},
/* AB3A */ { "LETTRE MINUSCULE LATINE M À QUEUE CROISÉE",NULL},
/* AB3B */ { "LETTRE MINUSCULE LATINE N À QUEUE CROISÉE",NULL},
/* AB3C */ { "LETTRE MINUSCULE LATINE ENG À QUEUE CROISÉE",NULL},
/* AB3D */ { "LETTRE MINUSCULE LATINE O GOTHIQUE","	x (minuscule mathématique gothique o - 1D52C)"},
/* AB3E */ { "LETTRE MINUSCULE LATINE O GOTHIQUE BARRÉ","		* Cette lettre a été encodée sur la base d'une interprétation erronée d'une copie de mauvaise qualité de Sievers 1901. En réalité, elle n'est pas utilisée dans la dialectologie allemande.\n"
	"	x (lettre minuscule latine o barré obliquement - 00F8)"},
/* AB3F */ { "LETTRE MINUSCULE LATINE O OUVERT BARRÉ",NULL},
/* AB40 */ { "LETTRE MINUSCULE LATINE OE RENVERSÉ","	= lettre minuscule latine o schwa réfléchi"},
/* AB41 */ { "LETTRE MINUSCULE LATINE OE CULBUTÉ BARRÉ",NULL},
/* AB42 */ { "LETTRE MINUSCULE LATINE OE CULBUTÉ TRAIT HORIZONTAL",NULL},
/* AB43 */ { "LETTRE MINUSCULE LATINE O O OUVERT CULBUTÉ",NULL},
/* AB44 */ { "LETTRE MINUSCULE LATINE O O OUVERT CULBUTÉ BARRÉ",NULL},
/* AB45 */ { "LETTRE MINUSCULE LATINE R ÉTRIER",NULL},
/* AB46 */ { "LETTRE LATINE PETITE CAPITALE R À JAMBAGE À DROITE",NULL},
/* AB47 */ { "LETTRE MINUSCULE LATINE R SANS ANSE",NULL},
/* AB48 */ { "LETTRE MINUSCULE LATINE DOUBLE R",NULL},
/* AB49 */ { "LETTRE MINUSCULE LATINE R À QUEUE CROISÉE",NULL},
/* AB4A */ { "LETTRE MINUSCULE LATINE DOUBLE R À QUEUE CROISÉE",NULL},
/* AB4B */ { "LETTRE MINUSCULE LATINE R CURSIF","	x (minuscule mathématique r de ronde - 1D4C7)"},
/* AB4C */ { "LETTRE MINUSCULE LATINE R CURSIF ROND",NULL},
/* AB4D */ { "LETTRE MINUSCULE LATINE ECH SUR LA LIGNE","	x (lettre minuscule latine ech - 0283)"},
/* AB4E */ { "LETTRE MINUSCULE LATINE U À FÛT COURT À DROITE",NULL},
/* AB4F */ { "LETTRE MINUSCULE LATINE U BARRÉ À FÛT COURT À DROITE",NULL},
/* AB50 */ { "LETTRE MINUSCULE LATINE UI",NULL},
/* AB51 */ { "LETTRE MINUSCULE LATINE UI CULBUTÉ",NULL},
/* AB52 */ { "LETTRE MINUSCULE LATINE U CROSSE À GAUCHE",NULL},
/* AB53 */ { "LETTRE MINUSCULE LATINE KHI","	* la majuscule est A7B3\n"
	"	x (lettre minuscule grecque khi - 03C7)"},
/* AB54 */ { "LETTRE MINUSCULE LATINE KHI ROND BAS À DROITE",NULL},
/* AB55 */ { "LETTRE MINUSCULE LATINE KHI AVEC EMPATTEMENT INFÉRIEUR GAUCHE",NULL},
/* AB56 */ { "LETTRE MINUSCULE LATINE X ROND BAS À DROITE",NULL},
/* AB57 */ { "LETTRE MINUSCULE LATINE X À DIAGONALE LONGUE À GAUCHE",NULL},
/* AB58 */ { "LETTRE MINUSCULE LATINE X À DIAGONALE LONGUE À GAUCHE ET ROND BAS À DROITE",NULL},
/* AB59 */ { "LETTRE MINUSCULE LATINE X À DIAGONALE LONGUE À GAUCHE AVEC EMPATTEMENT",NULL},
/* AB5A */ { "LETTRE MINUSCULE LATINE Y À FÛT COURT À DROITE",NULL},
/* AB5B */ { "BRÈVE MODIFICATIVE ET BRÈVE RENVERSÉE","	* indique une voyelle brève\n"
	"	x (brève - 02D8)\n"
	"	x (équivalent à - 224D)\n"
	"	x (brève métrique - 23D1)\n"
	"	x (kavyka bas renversé kavyka par-dessus - 2E46)"},
/* AB5C */ { "LETTRE MODIFICATIVE MINUSCULE HENG","	# <exp> A727"},
/* AB5D */ { "LETTRE MODIFICATIVE MINUSCULE L TRAVERSÉ D'UN S RENVERSÉ COUCHÉ","	# <exp> AB37"},
/* AB5E */ { "LETTRE MODIFICATIVE MINUSCULE L TILDE MÉDIAN","	# <exp> 026B"},
/* AB5F */ { "LETTRE MODIFICATIVE MINUSCULE U CROSSE À GAUCHE","	# <exp> AB52"},
/* AB60 */ { "LETTRE LATINE MINUSCULE IAT SAKHA","	= iat iakoute\n"
	"	x (lettre minuscule cyrillique iat - 0463)"},
/* AB61 */ { "LETTRE LATINE MINUSCULE É YODISÉ","	x (lettre minuscule cyrillique é yodisé - 0465)"},
/* AB62 */ { "LETTRE LATINE MINUSCULE OE OUVERT","	x (lettre minuscule latine o ouvert - 0254)"},
/* AB63 */ { "LETTRE LATINE MINUSCULE UO",NULL},
/* AB64 */ { "LETTRE MINUSCULE LATINE ALPHA RENVERSÉ","	* voyelle ouverte postérieure non arrondie\n"
	"	x (lettre minuscule latine alpha culbuté - 0252)"},
/* AB65 */ { "LETTRE GRECQUE PETITE CAPITALE OMÉGA","	* obsolète pour désigner une voyelle moyenne postérieure arrondie\n"
	"		D'autres lettres petites capitales grecques se trouvent dans l'intervalle 1D26-1D2A.\n"
	"	x (lettre minuscule latine oméga fermé - 0277)\n"
	"	x (lettre majuscule grecque oméga - 03A9)"},
/* AB66 */ { "LETTRE MINUSCULE LATINE DIGRAMME DZ HAMEÇON RÉTROFLEXE","	* affriquée rétroflexe sonore\n"
	"	x (lettre minuscule latine z hameçon rétroflexe - 0290)\n"
	"	x (lettre minuscule latine digramme dz - 02A3)"},
/* AB67 */ { "LETTRE MINUSCULE LATINE DIGRAMME TS HAMEÇON RÉTROFLEXE","	* affriquée rétroflexe sourde\n"
	"	x (lettre minuscule latine s hameçon rétroflexe - 0282)\n"
	"	x (lettre minuscule latine digramme ts - 02A6)"},
/* AB68 */ { "LETTRE MINUSCULE LATINE R CULBUTÉ TILDE MÉDIAN","	* spirante alvéolaire vélarisée\n"
	"	x (lettre minuscule latine r tilde médian - 1D72)"},
/* AB69 */ { "LETTRE MODIFICATIVE MINUSCULE W RÉFLÉCHI","	* réalisation bilabiale sourde\n"
	"	x (diacritique lettre minuscule latine w culbuté souscrit - 1AC0)\n"
	"	# <exp> 028D"},
/* AB6A */ { "LETTRE MODIFICATIVE TAQUET À GAUCHE","	* réalisation vocalique antérieure\n"
	"	x (lettre modificative taquet vers le haut - 02D4)\n"
	"	x (diacritique taquet à gauche souscrit - 0318)"},
/* AB6B */ { "LETTRE MODIFICATIVE TAQUET À DROITE","	* réalisation vocalique postérieure\n"
	"	x (diacritique taquet à droite souscrit - 0319)"},
/* AB6C */ { NULL,NULL},
/* AB6D */ { NULL,NULL},
/* AB6E */ { NULL,NULL},
/* AB6F */ { NULL,NULL},
/* AB70 */ { "SYLLABE CHÉROKIE MINUSCULE A",NULL},
/* AB71 */ { "SYLLABE CHÉROKIE MINUSCULE É",NULL},
/* AB72 */ { "SYLLABE CHÉROKIE MINUSCULE I",NULL},
/* AB73 */ { "SYLLABE CHÉROKIE MINUSCULE O",NULL},
/* AB74 */ { "SYLLABE CHÉROKIE MINUSCULE OU",NULL},
/* AB75 */ { "SYLLABE CHÉROKIE MINUSCULE ËN","	= syllabe chérokie minuscule v"},
/* AB76 */ { "SYLLABE CHÉROKIE MINUSCULE GA",NULL},
/* AB77 */ { "SYLLABE CHÉROKIE MINUSCULE KA",NULL},
/* AB78 */ { "SYLLABE CHÉROKIE MINUSCULE GUÉ",NULL},
/* AB79 */ { "SYLLABE CHÉROKIE MINUSCULE GUI",NULL},
/* AB7A */ { "SYLLABE CHÉROKIE MINUSCULE GO",NULL},
/* AB7B */ { "SYLLABE CHÉROKIE MINUSCULE GOU",NULL},
/* AB7C */ { "SYLLABE CHÉROKIE MINUSCULE GUËN","	= syllabe chérokie minuscule gv"},
/* AB7D */ { "SYLLABE CHÉROKIE MINUSCULE HA",NULL},
/* AB7E */ { "SYLLABE CHÉROKIE MINUSCULE HÉ",NULL},
/* AB7F */ { "SYLLABE CHÉROKIE MINUSCULE HI",NULL},
/* AB80 */ { "SYLLABE CHÉROKIE MINUSCULE HO",NULL},
/* AB81 */ { "SYLLABE CHÉROKIE MINUSCULE HOU",NULL},
/* AB82 */ { "SYLLABE CHÉROKIE MINUSCULE HËN","	= syllabe chérokie minuscule hv"},
/* AB83 */ { "SYLLABE CHÉROKIE MINUSCULE LA",NULL},
/* AB84 */ { "SYLLABE CHÉROKIE MINUSCULE LÉ",NULL},
/* AB85 */ { "SYLLABE CHÉROKIE MINUSCULE LI",NULL},
/* AB86 */ { "SYLLABE CHÉROKIE MINUSCULE LO",NULL},
/* AB87 */ { "SYLLABE CHÉROKIE MINUSCULE LOU",NULL},
/* AB88 */ { "SYLLABE CHÉROKIE MINUSCULE LËN","	= syllabe chérokie minuscule lv"},
/* AB89 */ { "SYLLABE CHÉROKIE MINUSCULE MA",NULL},
/* AB8A */ { "SYLLABE CHÉROKIE MINUSCULE MÉ",NULL},
/* AB8B */ { "SYLLABE CHÉROKIE MINUSCULE MI",NULL},
/* AB8C */ { "SYLLABE CHÉROKIE MINUSCULE MO",NULL},
/* AB8D */ { "SYLLABE CHÉROKIE MINUSCULE MOU",NULL},
/* AB8E */ { "SYLLABE CHÉROKIE MINUSCULE NA",NULL},
/* AB8F */ { "SYLLABE CHÉROKIE MINUSCULE HNA",NULL},
/* AB90 */ { "SYLLABE CHÉROKIE MINUSCULE NAH",NULL},
/* AB91 */ { "SYLLABE CHÉROKIE MINUSCULE NÉ",NULL},
/* AB92 */ { "SYLLABE CHÉROKIE MINUSCULE NI",NULL},
/* AB93 */ { "SYLLABE CHÉROKIE MINUSCULE NO",NULL},
/* AB94 */ { "SYLLABE CHÉROKIE MINUSCULE NOU",NULL},
/* AB95 */ { "SYLLABE CHÉROKIE MINUSCULE NËN","	= syllabe chérokie minuscule nv"},
/* AB96 */ { "SYLLABE CHÉROKIE MINUSCULE KWA",NULL},
/* AB97 */ { "SYLLABE CHÉROKIE MINUSCULE KWÉ",NULL},
/* AB98 */ { "SYLLABE CHÉROKIE MINUSCULE KWI",NULL},
/* AB99 */ { "SYLLABE CHÉROKIE MINUSCULE KWO",NULL},
/* AB9A */ { "SYLLABE CHÉROKIE MINUSCULE KWOU",NULL},
/* AB9B */ { "SYLLABE CHÉROKIE MINUSCULE KWËN","	= syllabe chérokie minuscule quv"},
/* AB9C */ { "SYLLABE CHÉROKIE MINUSCULE SA",NULL},
/* AB9D */ { "SYLLABE CHÉROKIE MINUSCULE S",NULL},
/* AB9E */ { "SYLLABE CHÉROKIE MINUSCULE SÉ",NULL},
/* AB9F */ { "SYLLABE CHÉROKIE MINUSCULE SI",NULL},
/* ABA0 */ { "SYLLABE CHÉROKIE MINUSCULE SO",NULL},
/* ABA1 */ { "SYLLABE CHÉROKIE MINUSCULE SOU",NULL},
/* ABA2 */ { "SYLLABE CHÉROKIE MINUSCULE SËN","	= syllabe chérokie minuscule sv"},
/* ABA3 */ { "SYLLABE CHÉROKIE MINUSCULE DA",NULL},
/* ABA4 */ { "SYLLABE CHÉROKIE MINUSCULE TA",NULL},
/* ABA5 */ { "SYLLABE CHÉROKIE MINUSCULE DÉ",NULL},
/* ABA6 */ { "SYLLABE CHÉROKIE MINUSCULE TÉ",NULL},
/* ABA7 */ { "SYLLABE CHÉROKIE MINUSCULE DI",NULL},
/* ABA8 */ { "SYLLABE CHÉROKIE MINUSCULE TI",NULL},
/* ABA9 */ { "SYLLABE CHÉROKIE MINUSCULE DO",NULL},
/* ABAA */ { "SYLLABE CHÉROKIE MINUSCULE DOU",NULL},
/* ABAB */ { "SYLLABE CHÉROKIE MINUSCULE DËN","	= syllabe chérokie minuscule dv"},
/* ABAC */ { "SYLLABE CHÉROKIE MINUSCULE DLA",NULL},
/* ABAD */ { "SYLLABE CHÉROKIE MINUSCULE TLA",NULL},
/* ABAE */ { "SYLLABE CHÉROKIE MINUSCULE TLÉ",NULL},
/* ABAF */ { "SYLLABE CHÉROKIE MINUSCULE TLI",NULL},
/* ABB0 */ { "SYLLABE CHÉROKIE MINUSCULE TLO",NULL},
/* ABB1 */ { "SYLLABE CHÉROKIE MINUSCULE TLOU",NULL},
/* ABB2 */ { "SYLLABE CHÉROKIE MINUSCULE TLËN","	= syllabe chérokie minuscule tlv"},
/* ABB3 */ { "SYLLABE CHÉROKIE MINUSCULE TSA",NULL},
/* ABB4 */ { "SYLLABE CHÉROKIE MINUSCULE TSÉ",NULL},
/* ABB5 */ { "SYLLABE CHÉROKIE MINUSCULE TSI",NULL},
/* ABB6 */ { "SYLLABE CHÉROKIE MINUSCULE TSO",NULL},
/* ABB7 */ { "SYLLABE CHÉROKIE MINUSCULE TSOU",NULL},
/* ABB8 */ { "SYLLABE CHÉROKIE MINUSCULE TSËN","	= syllabe chérokie minuscule tsv"},
/* ABB9 */ { "SYLLABE CHÉROKIE MINUSCULE WA",NULL},
/* ABBA */ { "SYLLABE CHÉROKIE MINUSCULE WÉ",NULL},
/* ABBB */ { "SYLLABE CHÉROKIE MINUSCULE WI",NULL},
/* ABBC */ { "SYLLABE CHÉROKIE MINUSCULE WO",NULL},
/* ABBD */ { "SYLLABE CHÉROKIE MINUSCULE WOU",NULL},
/* ABBE */ { "SYLLABE CHÉROKIE MINUSCULE WËN","	= syllabe chérokie minuscule wv"},
/* ABBF */ { "SYLLABE CHÉROKIE MINUSCULE YA",NULL},
/* ABC0 */ { "LETTRE MEITEI MAYEK KOK","	= ka"},
/* ABC1 */ { "LETTRE MEITEI MAYEK SAM","	= sa"},
/* ABC2 */ { "LETTRE MEITEI MAYEK LAÏ","	= la"},
/* ABC3 */ { "LETTRE MEITEI MAYEK MIT","	= ma"},
/* ABC4 */ { "LETTRE MEITEI MAYEK PA",NULL},
/* ABC5 */ { "LETTRE MEITEI MAYEK NA",NULL},
/* ABC6 */ { "LETTRE MEITEI MAYEK TCHIL","	= tcha"},
/* ABC7 */ { "LETTRE MEITEI MAYEK TIL","	= ta"},
/* ABC8 */ { "LETTRE MEITEI MAYEK KHOOU","	= kha"},
/* ABC9 */ { "LETTRE MEITEI MAYEK NGOOU","	= nga"},
/* ABCA */ { "LETTRE MEITEI MAYEK THOOU","	= tha"},
/* ABCB */ { "LETTRE MEITEI MAYEK WAÏ","	= wa"},
/* ABCC */ { "LETTRE MEITEI MAYEK YANG","	= ya"},
/* ABCD */ { "LETTRE MEITEI MAYEK HOUK","	= ha"},
/* ABCE */ { "LETTRE MEITEI MAYEK OUN","	= ou"},
/* ABCF */ { "LETTRE MEITEI MAYEK I",NULL},
/* ABD0 */ { "LETTRE MEITEI MAYEK PHAM","	= pha"},
/* ABD1 */ { "LETTRE MEITEI MAYEK ATIYA","	= a"},
/* ABD2 */ { "LETTRE MEITEI MAYEK GOK","	= ga"},
/* ABD3 */ { "LETTRE MEITEI MAYEK DJHAM","	= djha"},
/* ABD4 */ { "LETTRE MEITEI MAYEK RAÏ","	= ra"},
/* ABD5 */ { "LETTRE MEITEI MAYEK BA",NULL},
/* ABD6 */ { "LETTRE MEITEI MAYEK DJIL","	= dja"},
/* ABD7 */ { "LETTRE MEITEI MAYEK DIL","	= da"},
/* ABD8 */ { "LETTRE MEITEI MAYEK GHOOU","	= gha"},
/* ABD9 */ { "LETTRE MEITEI MAYEK DHOOU","	= dha"},
/* ABDA */ { "LETTRE MEITEI MAYEK BHAM","	= bha"},
/* ABDB */ { "LETTRE MEITEI MAYEK KOK LONSOUM","	= k"},
/* ABDC */ { "LETTRE MEITEI MAYEK LAÏ LONSOUM","	= l"},
/* ABDD */ { "LETTRE MEITEI MAYEK MIT LONSOUM","	= m"},
/* ABDE */ { "LETTRE MEITEI MAYEK PA LONSOUM","	= p"},
/* ABDF */ { "LETTRE MEITEI MAYEK NA LONSOUM","	= n"},
/* ABE0 */ { "LETTRE MEITEI MAYEK TIL LONSOUM","	= t"},
/* ABE1 */ { "LETTRE MEITEI MAYEK NGOOU LONSOUM","	= ng"},
/* ABE2 */ { "LETTRE MEITEI MAYEK I LONSOUM","	= i"},
/* ABE3 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK ONAP","	= o"},
/* ABE4 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK INAP","	= i"},
/* ABE5 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK ANAP","	= â"},
/* ABE6 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK YÉNAP","	= é"},
/* ABE7 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK SOOUNAP","	= oou"},
/* ABE8 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK OUNAP","	= ou"},
/* ABE9 */ { "DIACRITIQUE VOYELLE MEITEI MAYEK TCHEINAP","	= ei"},
/* ABEA */ { "DIACRITIQUE VOYELLE MEITEI MAYEK NOUNG","	= anousvâra"},
/* ABEB */ { "TCHEIKHEI MEITEI MAYEK","	= double danda"},
/* ABEC */ { "LOUM IYEK MEITEI MAYEK","	= ton lourd"},
/* ABED */ { "APOUN IYEK MEITEI MAYEK","	= halant\n"
	"	x (diacritique birman asat - 103A)"},
/* ABEE */ { NULL,NULL},
/* ABEF */ { NULL,NULL},
/* ABF0 */ { "CHIFFRE MEITEI MAYEK ZÉRO","	= phoun"},
/* ABF1 */ { "CHIFFRE MEITEI MAYEK UN","	= ama"},
/* ABF2 */ { "CHIFFRE MEITEI MAYEK DEUX","	= ani"},
/* ABF3 */ { "CHIFFRE MEITEI MAYEK TROIS","	= ahoum"},
/* ABF4 */ { "CHIFFRE MEITEI MAYEK QUATRE","	= mari"},
/* ABF5 */ { "CHIFFRE MEITEI MAYEK CINQ","	= manga"},
/* ABF6 */ { "CHIFFRE MEITEI MAYEK SIX","	= tarouk"},
/* ABF7 */ { "CHIFFRE MEITEI MAYEK SEPT","	= taret"},
/* ABF8 */ { "CHIFFRE MEITEI MAYEK HUIT","	= nipal"},
/* ABF9 */ { "CHIFFRE MEITEI MAYEK NEUF","	= mapal"},
/* ABFA */ { NULL,NULL},
/* ABFB */ { NULL,NULL},
/* ABFC */ { NULL,NULL},
/* ABFD */ { NULL,NULL},
/* ABFE */ { NULL,NULL},
/* ABFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_D7[] = {
/* D700 */ { NULL,NULL},
/* D701 */ { NULL,NULL},
/* D702 */ { NULL,NULL},
/* D703 */ { NULL,NULL},
/* D704 */ { NULL,NULL},
/* D705 */ { NULL,NULL},
/* D706 */ { NULL,NULL},
/* D707 */ { NULL,NULL},
/* D708 */ { NULL,NULL},
/* D709 */ { NULL,NULL},
/* D70A */ { NULL,NULL},
/* D70B */ { NULL,NULL},
/* D70C */ { NULL,NULL},
/* D70D */ { NULL,NULL},
/* D70E */ { NULL,NULL},
/* D70F */ { NULL,NULL},
/* D710 */ { NULL,NULL},
/* D711 */ { NULL,NULL},
/* D712 */ { NULL,NULL},
/* D713 */ { NULL,NULL},
/* D714 */ { NULL,NULL},
/* D715 */ { NULL,NULL},
/* D716 */ { NULL,NULL},
/* D717 */ { NULL,NULL},
/* D718 */ { NULL,NULL},
/* D719 */ { NULL,NULL},
/* D71A */ { NULL,NULL},
/* D71B */ { NULL,NULL},
/* D71C */ { NULL,NULL},
/* D71D */ { NULL,NULL},
/* D71E */ { NULL,NULL},
/* D71F */ { NULL,NULL},
/* D720 */ { NULL,NULL},
/* D721 */ { NULL,NULL},
/* D722 */ { NULL,NULL},
/* D723 */ { NULL,NULL},
/* D724 */ { NULL,NULL},
/* D725 */ { NULL,NULL},
/* D726 */ { NULL,NULL},
/* D727 */ { NULL,NULL},
/* D728 */ { NULL,NULL},
/* D729 */ { NULL,NULL},
/* D72A */ { NULL,NULL},
/* D72B */ { NULL,NULL},
/* D72C */ { NULL,NULL},
/* D72D */ { NULL,NULL},
/* D72E */ { NULL,NULL},
/* D72F */ { NULL,NULL},
/* D730 */ { NULL,NULL},
/* D731 */ { NULL,NULL},
/* D732 */ { NULL,NULL},
/* D733 */ { NULL,NULL},
/* D734 */ { NULL,NULL},
/* D735 */ { NULL,NULL},
/* D736 */ { NULL,NULL},
/* D737 */ { NULL,NULL},
/* D738 */ { NULL,NULL},
/* D739 */ { NULL,NULL},
/* D73A */ { NULL,NULL},
/* D73B */ { NULL,NULL},
/* D73C */ { NULL,NULL},
/* D73D */ { NULL,NULL},
/* D73E */ { NULL,NULL},
/* D73F */ { NULL,NULL},
/* D740 */ { NULL,NULL},
/* D741 */ { NULL,NULL},
/* D742 */ { NULL,NULL},
/* D743 */ { NULL,NULL},
/* D744 */ { NULL,NULL},
/* D745 */ { NULL,NULL},
/* D746 */ { NULL,NULL},
/* D747 */ { NULL,NULL},
/* D748 */ { NULL,NULL},
/* D749 */ { NULL,NULL},
/* D74A */ { NULL,NULL},
/* D74B */ { NULL,NULL},
/* D74C */ { NULL,NULL},
/* D74D */ { NULL,NULL},
/* D74E */ { NULL,NULL},
/* D74F */ { NULL,NULL},
/* D750 */ { NULL,NULL},
/* D751 */ { NULL,NULL},
/* D752 */ { NULL,NULL},
/* D753 */ { NULL,NULL},
/* D754 */ { NULL,NULL},
/* D755 */ { NULL,NULL},
/* D756 */ { NULL,NULL},
/* D757 */ { NULL,NULL},
/* D758 */ { NULL,NULL},
/* D759 */ { NULL,NULL},
/* D75A */ { NULL,NULL},
/* D75B */ { NULL,NULL},
/* D75C */ { NULL,NULL},
/* D75D */ { NULL,NULL},
/* D75E */ { NULL,NULL},
/* D75F */ { NULL,NULL},
/* D760 */ { NULL,NULL},
/* D761 */ { NULL,NULL},
/* D762 */ { NULL,NULL},
/* D763 */ { NULL,NULL},
/* D764 */ { NULL,NULL},
/* D765 */ { NULL,NULL},
/* D766 */ { NULL,NULL},
/* D767 */ { NULL,NULL},
/* D768 */ { NULL,NULL},
/* D769 */ { NULL,NULL},
/* D76A */ { NULL,NULL},
/* D76B */ { NULL,NULL},
/* D76C */ { NULL,NULL},
/* D76D */ { NULL,NULL},
/* D76E */ { NULL,NULL},
/* D76F */ { NULL,NULL},
/* D770 */ { NULL,NULL},
/* D771 */ { NULL,NULL},
/* D772 */ { NULL,NULL},
/* D773 */ { NULL,NULL},
/* D774 */ { NULL,NULL},
/* D775 */ { NULL,NULL},
/* D776 */ { NULL,NULL},
/* D777 */ { NULL,NULL},
/* D778 */ { NULL,NULL},
/* D779 */ { NULL,NULL},
/* D77A */ { NULL,NULL},
/* D77B */ { NULL,NULL},
/* D77C */ { NULL,NULL},
/* D77D */ { NULL,NULL},
/* D77E */ { NULL,NULL},
/* D77F */ { NULL,NULL},
/* D780 */ { NULL,NULL},
/* D781 */ { NULL,NULL},
/* D782 */ { NULL,NULL},
/* D783 */ { NULL,NULL},
/* D784 */ { NULL,NULL},
/* D785 */ { NULL,NULL},
/* D786 */ { NULL,NULL},
/* D787 */ { NULL,NULL},
/* D788 */ { NULL,NULL},
/* D789 */ { NULL,NULL},
/* D78A */ { NULL,NULL},
/* D78B */ { NULL,NULL},
/* D78C */ { NULL,NULL},
/* D78D */ { NULL,NULL},
/* D78E */ { NULL,NULL},
/* D78F */ { NULL,NULL},
/* D790 */ { NULL,NULL},
/* D791 */ { NULL,NULL},
/* D792 */ { NULL,NULL},
/* D793 */ { NULL,NULL},
/* D794 */ { NULL,NULL},
/* D795 */ { NULL,NULL},
/* D796 */ { NULL,NULL},
/* D797 */ { NULL,NULL},
/* D798 */ { NULL,NULL},
/* D799 */ { NULL,NULL},
/* D79A */ { NULL,NULL},
/* D79B */ { NULL,NULL},
/* D79C */ { NULL,NULL},
/* D79D */ { NULL,NULL},
/* D79E */ { NULL,NULL},
/* D79F */ { NULL,NULL},
/* D7A0 */ { NULL,NULL},
/* D7A1 */ { NULL,NULL},
/* D7A2 */ { NULL,NULL},
/* D7A3 */ { NULL,NULL},
/* D7A4 */ { NULL,NULL},
/* D7A5 */ { NULL,NULL},
/* D7A6 */ { NULL,NULL},
/* D7A7 */ { NULL,NULL},
/* D7A8 */ { NULL,NULL},
/* D7A9 */ { NULL,NULL},
/* D7AA */ { NULL,NULL},
/* D7AB */ { NULL,NULL},
/* D7AC */ { NULL,NULL},
/* D7AD */ { NULL,NULL},
/* D7AE */ { NULL,NULL},
/* D7AF */ { NULL,NULL},
/* D7B0 */ { "DJOUNGSONG HANGÛL Ô-YO",NULL},
/* D7B1 */ { "DJOUNGSONG HANGÛL Ô-Ô-I",NULL},
/* D7B2 */ { "DJOUNGSONG HANGÛL YÔ-A",NULL},
/* D7B3 */ { "DJOUNGSONG HANGÛL YÔ-È",NULL},
/* D7B4 */ { "DJOUNGSONG HANGÛL YÔ-O",NULL},
/* D7B5 */ { "DJOUNGSONG HANGÛL OU-YO",NULL},
/* D7B6 */ { "DJOUNGSONG HANGÛL OU-I-I",NULL},
/* D7B7 */ { "DJOUNGSONG HANGÛL YOU-È",NULL},
/* D7B8 */ { "DJOUNGSONG HANGÛL YOU-Ô",NULL},
/* D7B9 */ { "DJOUNGSONG HANGÛL Û-A",NULL},
/* D7BA */ { "DJOUNGSONG HANGÛL Û-O",NULL},
/* D7BB */ { "DJOUNGSONG HANGÛL Û-É",NULL},
/* D7BC */ { "DJOUNGSONG HANGÛL Û-Ô",NULL},
/* D7BD */ { "DJOUNGSONG HANGÛL I-YA-Ô",NULL},
/* D7BE */ { "DJOUNGSONG HANGÛL I-YÈ",NULL},
/* D7BF */ { "DJOUNGSONG HANGÛL I-YO",NULL},
/* D7C0 */ { "DJOUNGSONG HANGÛL I-YÉ",NULL},
/* D7C1 */ { "DJOUNGSONG HANGÛL I-Ô-I",NULL},
/* D7C2 */ { "DJOUNGSONG HANGÛL I-YÔ",NULL},
/* D7C3 */ { "DJOUNGSONG HANGÛL I-YOU",NULL},
/* D7C4 */ { "DJOUNGSONG HANGÛL I-I",NULL},
/* D7C5 */ { "DJOUNGSONG HANGÛL ARÈA-A",NULL},
/* D7C6 */ { "DJOUNGSONG HANGÛL ARÈA-É",NULL},
/* D7C7 */ { NULL,NULL},
/* D7C8 */ { NULL,NULL},
/* D7C9 */ { NULL,NULL},
/* D7CA */ { NULL,NULL},
/* D7CB */ { "DJÔNGSONG HANGÛL NIÛN-RIÛL",NULL},
/* D7CC */ { "DJÔNGSONG HANGÛL NIÛN-TCH'IÛTCH'",NULL},
/* D7CD */ { "DJÔNGSONG HANGÛL SSANGTIKÛT",NULL},
/* D7CE */ { "DJÔNGSONG HANGÛL SSANGTIKÛT-PIÛP",NULL},
/* D7CF */ { "DJÔNGSONG HANGÛL TIKÛT-PIÛP",NULL},
/* D7D0 */ { "DJÔNGSONG HANGÛL TIKÛT-SIÔS",NULL},
/* D7D1 */ { "DJÔNGSONG HANGÛL TIKÛT-SIÔS-KIYOK",NULL},
/* D7D2 */ { "DJÔNGSONG HANGÛL TIKÛT-TCHIÛTCH",NULL},
/* D7D3 */ { "DJÔNGSONG HANGÛL TIKÛT-TCH'IÛTCH'",NULL},
/* D7D4 */ { "DJÔNGSONG HANGÛL TIKÛT-T'IÛT'",NULL},
/* D7D5 */ { "DJÔNGSONG HANGÛL RIÛL-SSANGKIYOK",NULL},
/* D7D6 */ { "DJÔNGSONG HANGÛL RIÛL-KIYOK-HIÛH",NULL},
/* D7D7 */ { "DJÔNGSONG HANGÛL SSANGRIÛL-K'IÛK'",NULL},
/* D7D8 */ { "DJÔNGSONG HANGÛL RIÛL-MIÛM-HIÛH",NULL},
/* D7D9 */ { "DJÔNGSONG HANGÛL RIÛL-PIÛP-TIKÛT",NULL},
/* D7DA */ { "DJÔNGSONG HANGÛL RIÛL-PIÛP-P'IÛP'",NULL},
/* D7DB */ { "DJÔNGSONG HANGÛL RIÛL-YESIÛNG",NULL},
/* D7DC */ { "DJÔNGSONG HANGÛL RIÛL-YORINHIÛH-HIÛH",NULL},
/* D7DD */ { "DJÔNGSONG HANGÛL KAPYO-OUNRIÛL",NULL},
/* D7DE */ { "DJÔNGSONG HANGÛL MIÛM-NIÛN",NULL},
/* D7DF */ { "DJÔNGSONG HANGÛL MIÛM-SSANGNIÛN",NULL},
/* D7E0 */ { "DJÔNGSONG HANGÛL SSANGMIÛM",NULL},
/* D7E1 */ { "DJÔNGSONG HANGÛL MIÛM-PIÛP-SIÔS",NULL},
/* D7E2 */ { "DJÔNGSONG HANGÛL MIÛM-TCHIÛTCH",NULL},
/* D7E3 */ { "DJÔNGSONG HANGÛL PIÛP-TIKÛT",NULL},
/* D7E4 */ { "DJÔNGSONG HANGÛL PIÛP-RIÛL-P'IÛP'",NULL},
/* D7E5 */ { "DJÔNGSONG HANGÛL PIÛP-MIÛM",NULL},
/* D7E6 */ { "DJÔNGSONG HANGÛL SSANGPIÛP",NULL},
/* D7E7 */ { "DJÔNGSONG HANGÛL PIÛP-SIÔS-TIKÛT",NULL},
/* D7E8 */ { "DJÔNGSONG HANGÛL PIÛP-TCHIÛTCH",NULL},
/* D7E9 */ { "DJÔNGSONG HANGÛL PIÛP-TCH'IÛTCH'",NULL},
/* D7EA */ { "DJÔNGSONG HANGÛL SIÔS-MIÛM",NULL},
/* D7EB */ { "DJÔNGSONG HANGÛL SIÔS-KAPYO-OUNPIÛP",NULL},
/* D7EC */ { "DJÔNGSONG HANGÛL SSANGSIÔS-KIYOK",NULL},
/* D7ED */ { "DJÔNGSONG HANGÛL SSANGSIÔS-TIKÛT",NULL},
/* D7EE */ { "DJÔNGSONG HANGÛL SIÔS-PANSIÔS",NULL},
/* D7EF */ { "DJÔNGSONG HANGÛL SIÔS-TCHIÛTCH",NULL},
/* D7F0 */ { "DJÔNGSONG HANGÛL SIÔS-TCH'IÛTCH'",NULL},
/* D7F1 */ { "DJÔNGSONG HANGÛL SIÔS-T'IÛT'",NULL},
/* D7F2 */ { "DJÔNGSONG HANGÛL SIÔS-HIÛH",NULL},
/* D7F3 */ { "DJÔNGSONG HANGÛL PANSIÔS-PIÛP",NULL},
/* D7F4 */ { "DJÔNGSONG HANGÛL PANSIÔS-KAPYO-OUNPIÛP",NULL},
/* D7F5 */ { "DJÔNGSONG HANGÛL YESIÛNG-MIÛM",NULL},
/* D7F6 */ { "DJÔNGSONG HANGÛL YESIÛNG-HIÛH",NULL},
/* D7F7 */ { "DJÔNGSONG HANGÛL TCHIÛTCH-PIÛP",NULL},
/* D7F8 */ { "DJÔNGSONG HANGÛL TCHIÛTCH-SSANGPIÛP",NULL},
/* D7F9 */ { "DJÔNGSONG HANGÛL SSANGTCHIÛTCH",NULL},
/* D7FA */ { "DJÔNGSONG HANGÛL P'IÛP'-SIÔS",NULL},
/* D7FB */ { "DJÔNGSONG HANGÛL P'IÛP'-T'IÛT'",NULL},
/* D7FC */ { NULL,NULL},
/* D7FD */ { NULL,NULL},
/* D7FE */ { NULL,NULL},
/* D7FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_F9[] = {
/* F900 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F900","	: 8C48"},
/* F901 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F901","	: 66F4"},
/* F902 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F902","	: 8ECA"},
/* F903 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F903","	: 8CC8"},
/* F904 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F904","	: 6ED1"},
/* F905 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F905","	: 4E32"},
/* F906 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F906","	: 53E5"},
/* F907 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F907","	: 9F9C"},
/* F908 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F908","	: 9F9C"},
/* F909 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F909","	: 5951"},
/* F90A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F90A","	: 91D1"},
/* F90B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F90B","	: 5587"},
/* F90C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F90C","	: 5948"},
/* F90D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F90D","	: 61F6"},
/* F90E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F90E","	: 7669"},
/* F90F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F90F","	: 7F85"},
/* F910 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F910","	: 863F"},
/* F911 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F911","	: 87BA"},
/* F912 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F912","	: 88F8"},
/* F913 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F913","	: 908F"},
/* F914 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F914","	: 6A02"},
/* F915 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F915","	: 6D1B"},
/* F916 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F916","	: 70D9"},
/* F917 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F917","	: 73DE"},
/* F918 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F918","	: 843D"},
/* F919 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F919","	: 916A"},
/* F91A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F91A","	: 99F1"},
/* F91B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F91B","	: 4E82"},
/* F91C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F91C","	: 5375"},
/* F91D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F91D","	: 6B04"},
/* F91E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F91E","	: 721B"},
/* F91F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F91F","	: 862D"},
/* F920 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F920","	: 9E1E"},
/* F921 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F921","	: 5D50"},
/* F922 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F922","	: 6FEB"},
/* F923 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F923","	: 85CD"},
/* F924 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F924","	: 8964"},
/* F925 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F925","	: 62C9"},
/* F926 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F926","	: 81D8"},
/* F927 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F927","	: 881F"},
/* F928 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F928","	: 5ECA"},
/* F929 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F929","	: 6717"},
/* F92A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F92A","	: 6D6A"},
/* F92B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F92B","	: 72FC"},
/* F92C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F92C","	x 90DE\n"
	"	x (idéogramme de compatibilité cjc-fa2e - FA2E)\n"
	"	: 90CE"},
/* F92D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F92D","	: 4F86"},
/* F92E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F92E","	: 51B7"},
/* F92F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F92F","	: 52DE"},
/* F930 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F930","	: 64C4"},
/* F931 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F931","	: 6AD3"},
/* F932 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F932","	: 7210"},
/* F933 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F933","	: 76E7"},
/* F934 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F934","	: 8001"},
/* F935 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F935","	: 8606"},
/* F936 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F936","	: 865C"},
/* F937 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F937","	: 8DEF"},
/* F938 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F938","	: 9732"},
/* F939 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F939","	: 9B6F"},
/* F93A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F93A","	: 9DFA"},
/* F93B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F93B","	: 788C"},
/* F93C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F93C","	: 797F"},
/* F93D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F93D","	: 7DA0"},
/* F93E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F93E","	: 83C9"},
/* F93F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F93F","	: 9304"},
/* F940 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F940","	: 9E7F"},
/* F941 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F941","	: 8AD6"},
/* F942 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F942","	: 58DF"},
/* F943 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F943","	: 5F04"},
/* F944 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F944","	: 7C60"},
/* F945 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F945","	: 807E"},
/* F946 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F946","	: 7262"},
/* F947 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F947","	: 78CA"},
/* F948 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F948","	: 8CC2"},
/* F949 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F949","	: 96F7"},
/* F94A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F94A","	: 58D8"},
/* F94B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F94B","	: 5C62"},
/* F94C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F94C","	: 6A13"},
/* F94D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F94D","	: 6DDA"},
/* F94E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F94E","	: 6F0F"},
/* F94F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F94F","	: 7D2F"},
/* F950 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F950","	: 7E37"},
/* F951 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F951","	: 964B"},
/* F952 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F952","	: 52D2"},
/* F953 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F953","	: 808B"},
/* F954 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F954","	: 51DC"},
/* F955 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F955","	: 51CC"},
/* F956 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F956","	: 7A1C"},
/* F957 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F957","	: 7DBE"},
/* F958 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F958","	: 83F1"},
/* F959 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F959","	: 9675"},
/* F95A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F95A","	: 8B80"},
/* F95B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F95B","	: 62CF"},
/* F95C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F95C","	: 6A02"},
/* F95D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F95D","	: 8AFE"},
/* F95E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F95E","	: 4E39"},
/* F95F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F95F","	: 5BE7"},
/* F960 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F960","	: 6012"},
/* F961 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F961","	: 7387"},
/* F962 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F962","	: 7570"},
/* F963 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F963","	: 5317"},
/* F964 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F964","	: 78FB"},
/* F965 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F965","	: 4FBF"},
/* F966 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F966","	: 5FA9"},
/* F967 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F967","	: 4E0D"},
/* F968 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F968","	: 6CCC"},
/* F969 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F969","	: 6578"},
/* F96A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F96A","	: 7D22"},
/* F96B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F96B","	: 53C3"},
/* F96C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F96C","	: 585E"},
/* F96D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F96D","	: 7701"},
/* F96E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F96E","	: 8449"},
/* F96F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F96F","	: 8AAA"},
/* F970 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F970","	: 6BBA"},
/* F971 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F971","	: 8FB0"},
/* F972 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F972","	: 6C88"},
/* F973 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F973","	: 62FE"},
/* F974 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F974","	: 82E5"},
/* F975 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F975","	: 63A0"},
/* F976 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F976","	: 7565"},
/* F977 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F977","	: 4EAE"},
/* F978 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F978","	: 5169"},
/* F979 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F979","	: 51C9"},
/* F97A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F97A","	: 6881"},
/* F97B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F97B","	: 7CE7"},
/* F97C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F97C","	: 826F"},
/* F97D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F97D","	: 8AD2"},
/* F97E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F97E","	: 91CF"},
/* F97F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F97F","	: 52F5"},
/* F980 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F980","	: 5442"},
/* F981 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F981","	: 5973"},
/* F982 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F982","	: 5EEC"},
/* F983 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F983","	: 65C5"},
/* F984 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F984","	: 6FFE"},
/* F985 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F985","	: 792A"},
/* F986 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F986","	: 95AD"},
/* F987 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F987","	: 9A6A"},
/* F988 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F988","	: 9E97"},
/* F989 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F989","	: 9ECE"},
/* F98A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F98A","	: 529B"},
/* F98B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F98B","	: 66C6"},
/* F98C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F98C","	: 6B77"},
/* F98D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F98D","	: 8F62"},
/* F98E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F98E","	: 5E74"},
/* F98F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F98F","	: 6190"},
/* F990 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F990","	: 6200"},
/* F991 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F991","	: 649A"},
/* F992 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F992","	: 6F23"},
/* F993 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F993","	: 7149"},
/* F994 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F994","	: 7489"},
/* F995 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F995","	: 79CA"},
/* F996 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F996","	: 7DF4"},
/* F997 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F997","	: 806F"},
/* F998 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F998","	: 8F26"},
/* F999 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F999","	: 84EE"},
/* F99A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F99A","	: 9023"},
/* F99B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F99B","	: 934A"},
/* F99C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F99C","	: 5217"},
/* F99D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F99D","	: 52A3"},
/* F99E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F99E","	: 54BD"},
/* F99F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F99F","	: 70C8"},
/* F9A0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A0","	: 88C2"},
/* F9A1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A1","	: 8AAA"},
/* F9A2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A2","	: 5EC9"},
/* F9A3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A3","	: 5FF5"},
/* F9A4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A4","	: 637B"},
/* F9A5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A5","	: 6BAE"},
/* F9A6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A6","	: 7C3E"},
/* F9A7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A7","	: 7375"},
/* F9A8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A8","	: 4EE4"},
/* F9A9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9A9","	: 56F9"},
/* F9AA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9AA","	: 5BE7"},
/* F9AB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9AB","	: 5DBA"},
/* F9AC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9AC","	: 601C"},
/* F9AD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9AD","	: 73B2"},
/* F9AE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9AE","	: 7469"},
/* F9AF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9AF","	: 7F9A"},
/* F9B0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B0","	: 8046"},
/* F9B1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B1","	: 9234"},
/* F9B2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B2","	: 96F6"},
/* F9B3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B3","	: 9748"},
/* F9B4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B4","	: 9818"},
/* F9B5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B5","	: 4F8B"},
/* F9B6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B6","	: 79AE"},
/* F9B7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B7","	: 91B4"},
/* F9B8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B8","	x 96B7\n"
	"	x (idéogramme de compatibilité cjc-fa2f - FA2F)\n"
	"	: 96B8"},
/* F9B9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9B9","	: 60E1"},
/* F9BA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9BA","	: 4E86"},
/* F9BB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9BB","	: 50DA"},
/* F9BC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9BC","	: 5BEE"},
/* F9BD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9BD","	: 5C3F"},
/* F9BE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9BE","	: 6599"},
/* F9BF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9BF","	: 6A02"},
/* F9C0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C0","	: 71CE"},
/* F9C1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C1","	: 7642"},
/* F9C2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C2","	: 84FC"},
/* F9C3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C3","	: 907C"},
/* F9C4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C4","	: 9F8D"},
/* F9C5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C5","	: 6688"},
/* F9C6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C6","	: 962E"},
/* F9C7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C7","	: 5289"},
/* F9C8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C8","	: 677B"},
/* F9C9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9C9","	: 67F3"},
/* F9CA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9CA","	: 6D41"},
/* F9CB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9CB","	: 6E9C"},
/* F9CC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9CC","	: 7409"},
/* F9CD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9CD","	: 7559"},
/* F9CE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9CE","	: 786B"},
/* F9CF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9CF","	: 7D10"},
/* F9D0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D0","	: 985E"},
/* F9D1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D1","	: 516D"},
/* F9D2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D2","	: 622E"},
/* F9D3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D3","	: 9678"},
/* F9D4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D4","	: 502B"},
/* F9D5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D5","	: 5D19"},
/* F9D6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D6","	: 6DEA"},
/* F9D7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D7","	: 8F2A"},
/* F9D8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D8","	: 5F8B"},
/* F9D9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9D9","	: 6144"},
/* F9DA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9DA","	: 6817"},
/* F9DB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9DB","	: 7387"},
/* F9DC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9DC","	: 9686"},
/* F9DD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9DD","	: 5229"},
/* F9DE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9DE","	: 540F"},
/* F9DF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9DF","	: 5C65"},
/* F9E0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E0","	: 6613"},
/* F9E1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E1","	: 674E"},
/* F9E2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E2","	: 68A8"},
/* F9E3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E3","	: 6CE5"},
/* F9E4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E4","	: 7406"},
/* F9E5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E5","	: 75E2"},
/* F9E6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E6","	: 7F79"},
/* F9E7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E7","	: 88CF"},
/* F9E8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E8","	: 88E1"},
/* F9E9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9E9","	: 91CC"},
/* F9EA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9EA","	: 96E2"},
/* F9EB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9EB","	: 533F"},
/* F9EC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9EC","	: 6EBA"},
/* F9ED */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9ED","	: 541D"},
/* F9EE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9EE","	: 71D0"},
/* F9EF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9EF","	: 7498"},
/* F9F0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F0","	: 85FA"},
/* F9F1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F1","	: 96A3"},
/* F9F2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F2","	: 9C57"},
/* F9F3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F3","	: 9E9F"},
/* F9F4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F4","	: 6797"},
/* F9F5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F5","	: 6DCB"},
/* F9F6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F6","	: 81E8"},
/* F9F7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F7","	: 7ACB"},
/* F9F8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F8","	: 7B20"},
/* F9F9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9F9","	: 7C92"},
/* F9FA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9FA","	: 72C0"},
/* F9FB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9FB","	: 7099"},
/* F9FC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9FC","	: 8B58"},
/* F9FD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9FD","	: 4EC0"},
/* F9FE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9FE","	: 8336"},
/* F9FF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-F9FF","	: 523A"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_FA[] = {
/* FA00 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA00","	: 5207"},
/* FA01 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA01","	: 5EA6"},
/* FA02 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA02","	: 62D3"},
/* FA03 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA03","	: 7CD6"},
/* FA04 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA04","	: 5B85"},
/* FA05 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA05","	: 6D1E"},
/* FA06 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA06","	: 66B4"},
/* FA07 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA07","	: 8F3B"},
/* FA08 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA08","	: 884C"},
/* FA09 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA09","	: 964D"},
/* FA0A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA0A","	: 898B"},
/* FA0B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA0B","	: 5ED3"},
/* FA0C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA0C","	: 5140"},
/* FA0D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA0D","	: 55C0"},
/* FA0E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA0E","	* fait partie du jeu des idéogrammes unifiés"},
/* FA0F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA0F","	* fait partie du jeu des idéogrammes unifiés"},
/* FA10 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA10","	: 585A"},
/* FA11 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA11","	* fait partie du jeu des idéogrammes unifiés"},
/* FA12 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA12","	: 6674"},
/* FA13 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA13","	* fait partie du jeu des idéogrammes unifiés"},
/* FA14 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA14","	* fait partie du jeu des idéogrammes unifiés"},
/* FA15 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA15","	: 51DE"},
/* FA16 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA16","	: 732A"},
/* FA17 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA17","	: 76CA"},
/* FA18 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA18","	: 793C"},
/* FA19 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA19","	: 795E"},
/* FA1A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA1A","	: 7965"},
/* FA1B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA1B","	: 798F"},
/* FA1C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA1C","	: 9756"},
/* FA1D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA1D","	: 7CBE"},
/* FA1E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA1E","	: 7FBD"},
/* FA1F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA1F","	* fait partie du jeu des idéogrammes unifiés"},
/* FA20 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA20","	: 8612"},
/* FA21 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA21","	* fait partie du jeu des idéogrammes unifiés"},
/* FA22 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA22","	: 8AF8"},
/* FA23 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA23","	* fait partie du jeu des idéogrammes unifiés"},
/* FA24 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA24","	* fait partie du jeu des idéogrammes unifiés"},
/* FA25 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA25","	: 9038"},
/* FA26 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA26","	: 90FD"},
/* FA27 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA27","	* fait partie du jeu des idéogrammes unifiés"},
/* FA28 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA28","	* fait partie du jeu des idéogrammes unifiés"},
/* FA29 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA29","	* fait partie du jeu des idéogrammes unifiés"},
/* FA2A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA2A","	: 98EF"},
/* FA2B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA2B","	: 98FC"},
/* FA2C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA2C","	: 9928"},
/* FA2D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA2D","	: 9DB4"},
/* FA2E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA2E","	: 90DE"},
/* FA2F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA2F","	: 96B7"},
/* FA30 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA30","	: 4FAE"},
/* FA31 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA31","	: 50E7"},
/* FA32 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA32","	: 514D"},
/* FA33 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA33","	: 52C9"},
/* FA34 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA34","	: 52E4"},
/* FA35 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA35","	: 5351"},
/* FA36 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA36","	: 559D"},
/* FA37 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA37","	: 5606"},
/* FA38 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA38","	: 5668"},
/* FA39 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA39","	: 5840"},
/* FA3A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA3A","	: 58A8"},
/* FA3B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA3B","	: 5C64"},
/* FA3C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA3C","	: 5C6E"},
/* FA3D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA3D","	: 6094"},
/* FA3E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA3E","	: 6168"},
/* FA3F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA3F","	: 618E"},
/* FA40 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA40","	: 61F2"},
/* FA41 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA41","	: 654F"},
/* FA42 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA42","	: 65E2"},
/* FA43 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA43","	: 6691"},
/* FA44 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA44","	: 6885"},
/* FA45 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA45","	: 6D77"},
/* FA46 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA46","	: 6E1A"},
/* FA47 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA47","	: 6F22"},
/* FA48 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA48","	: 716E"},
/* FA49 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA49","	: 722B"},
/* FA4A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA4A","	: 7422"},
/* FA4B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA4B","	: 7891"},
/* FA4C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA4C","	: 793E"},
/* FA4D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA4D","	: 7949"},
/* FA4E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA4E","	: 7948"},
/* FA4F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA4F","	: 7950"},
/* FA50 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA50","	: 7956"},
/* FA51 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA51","	: 795D"},
/* FA52 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA52","	: 798D"},
/* FA53 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA53","	: 798E"},
/* FA54 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA54","	: 7A40"},
/* FA55 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA55","	: 7A81"},
/* FA56 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA56","	: 7BC0"},
/* FA57 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA57","	: 7DF4"},
/* FA58 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA58","	: 7E09"},
/* FA59 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA59","	: 7E41"},
/* FA5A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA5A","	: 7F72"},
/* FA5B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA5B","	: 8005"},
/* FA5C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA5C","	: 81ED"},
/* FA5D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA5D","	: 8279"},
/* FA5E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA5E","	: 8279"},
/* FA5F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA5F","	: 8457"},
/* FA60 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA60","	: 8910"},
/* FA61 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA61","	: 8996"},
/* FA62 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA62","	: 8B01"},
/* FA63 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA63","	: 8B39"},
/* FA64 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA64","	: 8CD3"},
/* FA65 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA65","	: 8D08"},
/* FA66 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA66","	: 8FB6"},
/* FA67 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA67","	: 9038"},
/* FA68 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA68","	: 96E3"},
/* FA69 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA69","	: 97FF"},
/* FA6A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA6A","	: 983B"},
/* FA6B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA6B","	: 6075"},
/* FA6C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA6C","	: 242EE"},
/* FA6D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA6D","	: 8218"},
/* FA6E */ { NULL,NULL},
/* FA6F */ { NULL,NULL},
/* FA70 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA70","	: 4E26"},
/* FA71 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA71","	: 51B5"},
/* FA72 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA72","	: 5168"},
/* FA73 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA73","	: 4F80"},
/* FA74 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA74","	: 5145"},
/* FA75 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA75","	: 5180"},
/* FA76 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA76","	: 52C7"},
/* FA77 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA77","	: 52FA"},
/* FA78 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA78","	: 559D"},
/* FA79 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA79","	: 5555"},
/* FA7A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA7A","	: 5599"},
/* FA7B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA7B","	: 55E2"},
/* FA7C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA7C","	: 585A"},
/* FA7D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA7D","	: 58B3"},
/* FA7E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA7E","	: 5944"},
/* FA7F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA7F","	: 5954"},
/* FA80 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA80","	: 5A62"},
/* FA81 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA81","	: 5B28"},
/* FA82 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA82","	: 5ED2"},
/* FA83 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA83","	: 5ED9"},
/* FA84 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA84","	: 5F69"},
/* FA85 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA85","	: 5FAD"},
/* FA86 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA86","	: 60D8"},
/* FA87 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA87","	: 614E"},
/* FA88 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA88","	: 6108"},
/* FA89 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA89","	: 618E"},
/* FA8A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA8A","	: 6160"},
/* FA8B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA8B","	: 61F2"},
/* FA8C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA8C","	: 6234"},
/* FA8D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA8D","	: 63C4"},
/* FA8E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA8E","	: 641C"},
/* FA8F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA8F","	: 6452"},
/* FA90 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA90","	: 6556"},
/* FA91 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA91","	: 6674"},
/* FA92 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA92","	: 6717"},
/* FA93 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA93","	: 671B"},
/* FA94 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA94","	: 6756"},
/* FA95 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA95","	: 6B79"},
/* FA96 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA96","	: 6BBA"},
/* FA97 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA97","	: 6D41"},
/* FA98 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA98","	: 6EDB"},
/* FA99 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA99","	: 6ECB"},
/* FA9A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA9A","	: 6F22"},
/* FA9B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA9B","	: 701E"},
/* FA9C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA9C","	: 716E"},
/* FA9D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA9D","	: 77A7"},
/* FA9E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA9E","	: 7235"},
/* FA9F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FA9F","	: 72AF"},
/* FAA0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA0","	: 732A"},
/* FAA1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA1","	: 7471"},
/* FAA2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA2","	: 7506"},
/* FAA3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA3","	: 753B"},
/* FAA4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA4","	: 761D"},
/* FAA5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA5","	: 761F"},
/* FAA6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA6","	: 76CA"},
/* FAA7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA7","	: 76DB"},
/* FAA8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA8","	: 76F4"},
/* FAA9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAA9","	: 774A"},
/* FAAA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAAA","	: 7740"},
/* FAAB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAAB","	: 78CC"},
/* FAAC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAAC","	: 7AB1"},
/* FAAD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAAD","	: 7BC0"},
/* FAAE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAAE","	: 7C7B"},
/* FAAF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAAF","	: 7D5B"},
/* FAB0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB0","	: 7DF4"},
/* FAB1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB1","	: 7F3E"},
/* FAB2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB2","	: 8005"},
/* FAB3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB3","	: 8352"},
/* FAB4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB4","	: 83EF"},
/* FAB5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB5","	: 8779"},
/* FAB6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB6","	: 8941"},
/* FAB7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB7","	: 8986"},
/* FAB8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB8","	: 8996"},
/* FAB9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAB9","	: 8ABF"},
/* FABA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FABA","	: 8AF8"},
/* FABB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FABB","	: 8ACB"},
/* FABC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FABC","	: 8B01"},
/* FABD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FABD","	: 8AFE"},
/* FABE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FABE","	: 8AED"},
/* FABF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FABF","	: 8B39"},
/* FAC0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC0","	: 8B8A"},
/* FAC1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC1","	: 8D08"},
/* FAC2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC2","	: 8F38"},
/* FAC3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC3","	: 9072"},
/* FAC4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC4","	: 9199"},
/* FAC5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC5","	: 9276"},
/* FAC6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC6","	: 967C"},
/* FAC7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC7","	: 96E3"},
/* FAC8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC8","	: 9756"},
/* FAC9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAC9","	: 97DB"},
/* FACA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FACA","	: 97FF"},
/* FACB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FACB","	: 980B"},
/* FACC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FACC","	: 983B"},
/* FACD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FACD","	: 9B12"},
/* FACE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FACE","	: 9F9C"},
/* FACF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FACF","	: 2284A"},
/* FAD0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD0","	: 22844"},
/* FAD1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD1","	: 233D5"},
/* FAD2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD2","	: 3B9D"},
/* FAD3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD3","	: 4018"},
/* FAD4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD4","	* un changement de correspondance a supprimé la source originale\n"
	"	x (idéogramme de compatibilité cjc-2f949 - 2F949)\n"
	"	: 4039"},
/* FAD5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD5","	: 25249"},
/* FAD6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD6","	: 25CD0"},
/* FAD7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD7","	: 27ED3"},
/* FAD8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD8","	: 9F43"},
/* FAD9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-FAD9","	: 9F8E"},
/* FADA */ { NULL,NULL},
/* FADB */ { NULL,NULL},
/* FADC */ { NULL,NULL},
/* FADD */ { NULL,NULL},
/* FADE */ { NULL,NULL},
/* FADF */ { NULL,NULL},
/* FAE0 */ { NULL,NULL},
/* FAE1 */ { NULL,NULL},
/* FAE2 */ { NULL,NULL},
/* FAE3 */ { NULL,NULL},
/* FAE4 */ { NULL,NULL},
/* FAE5 */ { NULL,NULL},
/* FAE6 */ { NULL,NULL},
/* FAE7 */ { NULL,NULL},
/* FAE8 */ { NULL,NULL},
/* FAE9 */ { NULL,NULL},
/* FAEA */ { NULL,NULL},
/* FAEB */ { NULL,NULL},
/* FAEC */ { NULL,NULL},
/* FAED */ { NULL,NULL},
/* FAEE */ { NULL,NULL},
/* FAEF */ { NULL,NULL},
/* FAF0 */ { NULL,NULL},
/* FAF1 */ { NULL,NULL},
/* FAF2 */ { NULL,NULL},
/* FAF3 */ { NULL,NULL},
/* FAF4 */ { NULL,NULL},
/* FAF5 */ { NULL,NULL},
/* FAF6 */ { NULL,NULL},
/* FAF7 */ { NULL,NULL},
/* FAF8 */ { NULL,NULL},
/* FAF9 */ { NULL,NULL},
/* FAFA */ { NULL,NULL},
/* FAFB */ { NULL,NULL},
/* FAFC */ { NULL,NULL},
/* FAFD */ { NULL,NULL},
/* FAFE */ { NULL,NULL},
/* FAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_FB[] = {
/* FB00 */ { "LIGATURE MINUSCULE LATINE FF","	# 0066 0066"},
/* FB01 */ { "LIGATURE MINUSCULE LATINE FI","	# 0066 0069"},
/* FB02 */ { "LIGATURE MINUSCULE LATINE FL","	# 0066 006C"},
/* FB03 */ { "LIGATURE MINUSCULE LATINE FFI","	# 0066 0066 0069"},
/* FB04 */ { "LIGATURE MINUSCULE LATINE FFL","	# 0066 0066 006C"},
/* FB05 */ { "LIGATURE MINUSCULE LATINE S LONG T","	# 017F 0074"},
/* FB06 */ { "LIGATURE MINUSCULE LATINE ST","	# 0073 0074"},
/* FB07 */ { NULL,NULL},
/* FB08 */ { NULL,NULL},
/* FB09 */ { NULL,NULL},
/* FB0A */ { NULL,NULL},
/* FB0B */ { NULL,NULL},
/* FB0C */ { NULL,NULL},
/* FB0D */ { NULL,NULL},
/* FB0E */ { NULL,NULL},
/* FB0F */ { NULL,NULL},
/* FB10 */ { NULL,NULL},
/* FB11 */ { NULL,NULL},
/* FB12 */ { NULL,NULL},
/* FB13 */ { "LIGATURE MINUSCULE ARMÉNIENNE MÈN NOU","	# 0574 0576"},
/* FB14 */ { "LIGATURE MINUSCULE ARMÉNIENNE MÈN YÈTCH","	# 0574 0565"},
/* FB15 */ { "LIGATURE MINUSCULE ARMÉNIENNE MÈN INI","	# 0574 056B"},
/* FB16 */ { "LIGATURE MINUSCULE ARMÉNIENNE VÈV NOU","	# 057E 0576"},
/* FB17 */ { "LIGATURE MINUSCULE ARMÉNIENNE MÈN KHÉ","	# 0574 056D"},
/* FB18 */ { NULL,NULL},
/* FB19 */ { NULL,NULL},
/* FB1A */ { NULL,NULL},
/* FB1B */ { NULL,NULL},
/* FB1C */ { NULL,NULL},
/* FB1D */ { "LETTRE HÉBRAÏQUE YOD HIRIK","	: 05D9 05B4"},
/* FB1E */ { "POINT HÉBREU JUDÉO-ESPAGNOL VARIKA","	* une variante de glyphe de 05BF"},
/* FB1F */ { "LIGATURE HÉBRAÏQUE YIDICHE YOD YOD PATAH","	: 05F2 05B7"},
/* FB20 */ { "LETTRE HÉBRAÏQUE ALTERNATIVE 'AÏN","	* cette forme du ʿaïn n'a pas de hampe descendante, on l'utilise avec les signes souscrits\n"
	"	# <police> 05E2 lettre hébraïque 'aïn"},
/* FB21 */ { "LETTRE HÉBRAÏQUE LARGE ALEF","	# <police> 05D0 lettre hébraïque alef"},
/* FB22 */ { "LETTRE HÉBRAÏQUE LARGE DALÈT","	# <police> 05D3 lettre hébraïque dalèt"},
/* FB23 */ { "LETTRE HÉBRAÏQUE LARGE HÈ","	# <police> 05D4 lettre hébraïque hè"},
/* FB24 */ { "LETTRE HÉBRAÏQUE LARGE KAF","	# <police> 05DB lettre hébraïque kaf"},
/* FB25 */ { "LETTRE HÉBRAÏQUE LARGE LAMÈD","	# <police> 05DC lettre hébraïque lamèd"},
/* FB26 */ { "LETTRE HÉBRAÏQUE LARGE MÉM FINAL","	# <police> 05DD lettre hébraïque mém final"},
/* FB27 */ { "LETTRE HÉBRAÏQUE LARGE RÈCH","	# <police> 05E8 lettre hébraïque rèch"},
/* FB28 */ { "LETTRE HÉBRAÏQUE LARGE TAW","	# <police> 05EA lettre hébraïque taw"},
/* FB29 */ { "LETTRE HÉBRAÏQUE ALTERNATIVE SIGNE PLUS","	# <police> 002B signe plus"},
/* FB2A */ { "LETTRE HÉBRAÏQUE CHINE POINT CHINE","	: 05E9 05C1"},
/* FB2B */ { "LETTRE HÉBRAÏQUE CHINE POINT SINE","	: 05E9 05C2"},
/* FB2C */ { "LETTRE HÉBRAÏQUE CHINE DAGUÈCH ET POINT CHINE","	: FB49 05C1"},
/* FB2D */ { "LETTRE HÉBRAÏQUE CHINE DAGUÈCH ET POINT SINE","	: FB49 05C2"},
/* FB2E */ { "LETTRE HÉBRAÏQUE ALEF PATAH","	: 05D0 05B7"},
/* FB2F */ { "LETTRE HÉBRAÏQUE ALEF QAMATS","	: 05D0 05B8"},
/* FB30 */ { "LETTRE HÉBRAÏQUE ALEF MAPIQ","	: 05D0 05BC"},
/* FB31 */ { "LETTRE HÉBRAÏQUE BÈT DAGUÈCH","	: 05D1 05BC"},
/* FB32 */ { "LETTRE HÉBRAÏQUE GUIMEL DAGUÈCH","	: 05D2 05BC"},
/* FB33 */ { "LETTRE HÉBRAÏQUE DALÈT DAGUÈCH","	: 05D3 05BC"},
/* FB34 */ { "LETTRE HÉBRAÏQUE HÈ MAPIQ","	: 05D4 05BC"},
/* FB35 */ { "LETTRE HÉBRAÏQUE WAW DAGUÈCH","	: 05D5 05BC"},
/* FB36 */ { "LETTRE HÉBRAÏQUE ZAÏN DAGUÈCH","	: 05D6 05BC"},
/* FB37 */ { NULL,NULL},
/* FB38 */ { "LETTRE HÉBRAÏQUE TÈT DAGUÈCH","	: 05D8 05BC"},
/* FB39 */ { "LETTRE HÉBRAÏQUE YOD DAGUÈCH","	: 05D9 05BC"},
/* FB3A */ { "LETTRE HÉBRAÏQUE KAF FINAL DAGUÈCH","	: 05DA 05BC"},
/* FB3B */ { "LETTRE HÉBRAÏQUE KAF DAGUÈCH","	: 05DB 05BC"},
/* FB3C */ { "LETTRE HÉBRAÏQUE LAMÈD DAGUÈCH","	: 05DC 05BC"},
/* FB3D */ { NULL,NULL},
/* FB3E */ { "LETTRE HÉBRAÏQUE MÉM DAGUÈCH","	: 05DE 05BC"},
/* FB3F */ { NULL,NULL},
/* FB40 */ { "LETTRE HÉBRAÏQUE NOUN DAGUÈCH","	: 05E0 05BC"},
/* FB41 */ { "LETTRE HÉBRAÏQUE SAMÈKH DAGUÈCH","	: 05E1 05BC"},
/* FB42 */ { NULL,NULL},
/* FB43 */ { "LETTRE HÉBRAÏQUE PÉ FINAL DAGUÈCH","	: 05E3 05BC"},
/* FB44 */ { "LETTRE HÉBRAÏQUE PÉ DAGUÈCH","	: 05E4 05BC"},
/* FB45 */ { NULL,NULL},
/* FB46 */ { "LETTRE HÉBRAÏQUE TSADÉ DAGUÈCH","	: 05E6 05BC"},
/* FB47 */ { "LETTRE HÉBRAÏQUE QOUF DAGUÈCH","	: 05E7 05BC"},
/* FB48 */ { "LETTRE HÉBRAÏQUE RÈCH DAGUÈCH","	: 05E8 05BC"},
/* FB49 */ { "LETTRE HÉBRAÏQUE CHINE DAGUÈCH","	: 05E9 05BC"},
/* FB4A */ { "LETTRE HÉBRAÏQUE TAW DAGUÈCH","	: 05EA 05BC"},
/* FB4B */ { "LETTRE HÉBRAÏQUE WAW HOLAM","	: 05D5 05B9"},
/* FB4C */ { "LETTRE HÉBRAÏQUE BÈT RAFE","	: 05D1 05BF"},
/* FB4D */ { "LETTRE HÉBRAÏQUE KAF RAFE","	: 05DB 05BF"},
/* FB4E */ { "LETTRE HÉBRAÏQUE PÉ RAFE","	: 05E4 05BF"},
/* FB4F */ { "LIGATURE HÉBRAÏQUE ALEF LAMÈD","	# 05D0 05DC"},
/* FB50 */ { "LETTRE ARABE ALIF WASLA ISOLÉ","	= alif ouasl isolé\n"
	"	# <isolée> 0671"},
/* FB51 */ { "LETTRE ARABE ALIF WASLA FINAL","	= alif ouasl final\n"
	"	# <finale> 0671"},
/* FB52 */ { "LETTRE ARABE BEA' ISOLÉ","	# <isolée> 067B"},
/* FB53 */ { "LETTRE ARABE BEA' FINAL","	# <finale> 067B"},
/* FB54 */ { "LETTRE ARABE BEA' INITIAL","	# <initiale> 067B"},
/* FB55 */ { "LETTRE ARABE BEA' MÉDIAL","	# <médiale> 067B"},
/* FB56 */ { "LETTRE ARABE PA' ISOLÉ","	# <isolée> 067E"},
/* FB57 */ { "LETTRE ARABE PA' FINAL","	# <finale> 067E"},
/* FB58 */ { "LETTRE ARABE PA' INITIAL","	# <initiale> 067E"},
/* FB59 */ { "LETTRE ARABE PA' MÉDIAL","	# <médiale> 067E"},
/* FB5A */ { "LETTRE ARABE BEHA' ISOLÉ","	# <isolée> 0680"},
/* FB5B */ { "LETTRE ARABE BEHA' FINAL","	# <finale> 0680"},
/* FB5C */ { "LETTRE ARABE BEHA' INITIAL","	# <initiale> 0680"},
/* FB5D */ { "LETTRE ARABE BEHA' MÉDIAL","	# <médiale> 0680"},
/* FB5E */ { "LETTRE ARABE TTEHA' ISOLÉ","	# <isolée> 067A"},
/* FB5F */ { "LETTRE ARABE TTEHA' FINAL","	# <finale> 067A"},
/* FB60 */ { "LETTRE ARABE TTEHA' INITIAL","	# <initiale> 067A"},
/* FB61 */ { "LETTRE ARABE TTEHA' MÉDIAL","	# <médiale> 067A"},
/* FB62 */ { "LETTRE ARABE TEHA' ISOLÉ","	# <isolée> 067F"},
/* FB63 */ { "LETTRE ARABE TEHA' FINAL","	# <finale> 067F"},
/* FB64 */ { "LETTRE ARABE TEHA' INITIAL","	# <initiale> 067F"},
/* FB65 */ { "LETTRE ARABE TEHA' MÉDIAL","	# <médiale> 067F"},
/* FB66 */ { "LETTRE ARABE TTA' ISOLÉ","	# <isolée> 0679"},
/* FB67 */ { "LETTRE ARABE TTA' FINAL","	# <finale> 0679"},
/* FB68 */ { "LETTRE ARABE TTA' INITIAL","	# <initiale> 0679"},
/* FB69 */ { "LETTRE ARABE TTA' MÉDIAL","	# <médiale> 0679"},
/* FB6A */ { "LETTRE ARABE VA' ISOLÉ","	# <isolée> 06A4"},
/* FB6B */ { "LETTRE ARABE VA' FINAL","	# <finale> 06A4"},
/* FB6C */ { "LETTRE ARABE VA' INITIAL","	# <initiale> 06A4"},
/* FB6D */ { "LETTRE ARABE VA' MÉDIAL","	# <médiale> 06A4"},
/* FB6E */ { "LETTRE ARABE PEHA' ISOLÉ","	# <isolée> 06A6"},
/* FB6F */ { "LETTRE ARABE PEHA' FINAL","	# <finale> 06A6"},
/* FB70 */ { "LETTRE ARABE PEHA' INITIAL","	# <initiale> 06A6"},
/* FB71 */ { "LETTRE ARABE PEHA' MÉDIAL","	# <médiale> 06A6"},
/* FB72 */ { "LETTRE ARABE DYA' ISOLÉ","	# <isolée> 0684"},
/* FB73 */ { "LETTRE ARABE DYA' FINAL","	# <finale> 0684"},
/* FB74 */ { "LETTRE ARABE DYA' INITIAL","	# <initiale> 0684"},
/* FB75 */ { "LETTRE ARABE DYA' MÉDIAL","	# <médiale> 0684"},
/* FB76 */ { "LETTRE ARABE NYA' ISOLÉ","	# <isolée> 0683"},
/* FB77 */ { "LETTRE ARABE NYA' FINAL","	# <finale> 0683"},
/* FB78 */ { "LETTRE ARABE NYA' INITIAL","	# <initiale> 0683"},
/* FB79 */ { "LETTRE ARABE NYA' MÉDIAL","	# <médiale> 0683"},
/* FB7A */ { "LETTRE ARABE TCHIM' ISOLÉ","	# <isolée> 0686"},
/* FB7B */ { "LETTRE ARABE TCHIM' FINAL","	# <finale> 0686"},
/* FB7C */ { "LETTRE ARABE TCHIM' INITIAL","	# <initiale> 0686"},
/* FB7D */ { "LETTRE ARABE TCHIM' MÉDIAL","	# <médiale> 0686"},
/* FB7E */ { "LETTRE ARABE TCHEHA' ISOLÉ","	# <isolée> 0687"},
/* FB7F */ { "LETTRE ARABE TCHEHA' FINAL","	# <finale> 0687"},
/* FB80 */ { "LETTRE ARABE TCHEHA' INITIAL","	# <initiale> 0687"},
/* FB81 */ { "LETTRE ARABE TCHEHA' MÉDIAL","	# <médiale> 0687"},
/* FB82 */ { "LETTRE ARABE DDAHAL ISOLÉ","	# <isolée> 068D"},
/* FB83 */ { "LETTRE ARABE DDAHAL FINAL","	# <finale> 068D"},
/* FB84 */ { "LETTRE ARABE DAHAL ISOLÉ","	# <isolée> 068C"},
/* FB85 */ { "LETTRE ARABE DAHAL FINAL","	# <finale> 068C"},
/* FB86 */ { "LETTRE ARABE DOUL ISOLÉ","	# <isolée> 068E"},
/* FB87 */ { "LETTRE ARABE DOUL FINAL","	# <finale> 068E"},
/* FB88 */ { "LETTRE ARABE DDAL ISOLÉ","	# <isolée> 0688"},
/* FB89 */ { "LETTRE ARABE DDAL FINAL","	# <finale> 0688"},
/* FB8A */ { "LETTRE ARABE JA' ISOLÉ","	# <isolée> 0698"},
/* FB8B */ { "LETTRE ARABE JA' FINAL","	# <finale> 0698"},
/* FB8C */ { "LETTRE ARABE RRA' ISOLÉ","	# <isolée> 0691"},
/* FB8D */ { "LETTRE ARABE RRA' FINAL","	# <finale> 0691"},
/* FB8E */ { "LETTRE ARABE KEHA' ISOLÉ","	# <isolée> 06A9"},
/* FB8F */ { "LETTRE ARABE KEHA' FINAL","	# <finale> 06A9"},
/* FB90 */ { "LETTRE ARABE KEHA' INITIAL","	# <initiale> 06A9"},
/* FB91 */ { "LETTRE ARABE KEHA' MÉDIAL","	# <médiale> 06A9"},
/* FB92 */ { "LETTRE ARABE GAF ISOLÉ","	# <isolée> 06AF"},
/* FB93 */ { "LETTRE ARABE GAF FINAL","	# <finale> 06AF"},
/* FB94 */ { "LETTRE ARABE GAF INITIAL","	# <initiale> 06AF"},
/* FB95 */ { "LETTRE ARABE GAF MÉDIAL","	# <médiale> 06AF"},
/* FB96 */ { "LETTRE ARABE GOUA' ISOLÉ","	# <isolée> 06B3"},
/* FB97 */ { "LETTRE ARABE GOUA' FINAL","	# <finale> 06B3"},
/* FB98 */ { "LETTRE ARABE GOUA' INITIAL","	# <initiale> 06B3"},
/* FB99 */ { "LETTRE ARABE GOUA' MÉDIAL","	# <médiale> 06B3"},
/* FB9A */ { "LETTRE ARABE NGOA' ISOLÉ","	# <isolée> 06B1"},
/* FB9B */ { "LETTRE ARABE NGOA' FINAL","	# <finale> 06B1"},
/* FB9C */ { "LETTRE ARABE NGOA' INITIAL","	# <initiale> 06B1"},
/* FB9D */ { "LETTRE ARABE NGOA' MÉDIAL","	# <médiale> 06B1"},
/* FB9E */ { "LETTRE ARABE NOÛN GHOUNNA ISOLÉ","	# <isolée> 06BA"},
/* FB9F */ { "LETTRE ARABE NOÛN GHOUNNA FINAL","	# <finale> 06BA"},
/* FBA0 */ { "LETTRE ARABE NNOÛN ISOLÉ","	# <isolée> 06BB"},
/* FBA1 */ { "LETTRE ARABE NNOÛN FINAL","	# <finale> 06BB"},
/* FBA2 */ { "LETTRE ARABE NNOÛN INITIAL","	# <initiale> 06BB"},
/* FBA3 */ { "LETTRE ARABE NNOÛN MÉDIAL","	# <médiale> 06BB"},
/* FBA4 */ { "LETTRE ARABE HÉ' YA' EN CHEF ISOLÉ","	# <isolée> 06C0"},
/* FBA5 */ { "LETTRE ARABE HÉ' YA' EN CHEF FINAL","	# <finale> 06C0"},
/* FBA6 */ { "LETTRE ARABE HÉ' GÔL ISOLÉ","	# <isolée> 06C1"},
/* FBA7 */ { "LETTRE ARABE HÉ' GÔL FINAL","	# <finale> 06C1"},
/* FBA8 */ { "LETTRE ARABE HÉ' GÔL INITIAL","	# <initiale> 06C1"},
/* FBA9 */ { "LETTRE ARABE HÉ' GÔL MÉDIAL","	# <médiale> 06C1"},
/* FBAA */ { "LETTRE ARABE HÉ' DOATCHACHMI ISOLÉ","	# <isolée> 06BE"},
/* FBAB */ { "LETTRE ARABE HÉ' DOATCHACHMI FINAL","	# <finale> 06BE"},
/* FBAC */ { "LETTRE ARABE HÉ' DOATCHACHMI INITIAL","	# <initiale> 06BE"},
/* FBAD */ { "LETTRE ARABE HÉ' DOATCHACHMI MÉDIAL","	# <médiale> 06BE"},
/* FBAE */ { "LETTRE ARABE YA' BARRÉ ISOLÉ","	# <isolée> 06D2"},
/* FBAF */ { "LETTRE ARABE YA' BARRÉ FINAL","	# <finale> 06D2"},
/* FBB0 */ { "LETTRE ARABE YA' BARRÉ HAMZA EN CHEF ISOLÉ","	# <isolée> 06D3"},
/* FBB1 */ { "LETTRE ARABE YA' BARRÉ HAMZA EN CHEF FINAL","	# <finale> 06D3"},
/* FBB2 */ { "SYMBOLE ARABE POINT EN CHEF",NULL},
/* FBB3 */ { "SYMBOLE ARABE POINT SOUSCRIT",NULL},
/* FBB4 */ { "SYMBOLE ARABE DEUX POINTS EN CHEF",NULL},
/* FBB5 */ { "SYMBOLE ARABE DEUX POINTS SOUSCRITS",NULL},
/* FBB6 */ { "SYMBOLE ARABE TROIS POINTS EN CHEF",NULL},
/* FBB7 */ { "SYMBOLE ARABE TROIS POINTS SOUSCRITS",NULL},
/* FBB8 */ { "SYMBOLE ARABE TROIS POINTS EN CHEF POINTANT VERS LE BAS",NULL},
/* FBB9 */ { "SYMBOLE ARABE TROIS POINTS SOUSCRITS POINTANT VERS LE BAS",NULL},
/* FBBA */ { "SYMBOLE ARABE QUATRE POINTS EN CHEF","	* sindhi"},
/* FBBB */ { "SYMBOLE ARABE QUATRE POINTS SOUSCRITS","	* sindhi"},
/* FBBC */ { "SYMBOLE ARABE DOUBLE BARRE VERTICALE SOUSCRITE","	* sindhi"},
/* FBBD */ { "SYMBOLE ARABE DEUX POINTS VERTICAUX EN CHEF","	* sindhi"},
/* FBBE */ { "SYMBOLE ARABE DEUX POINTS VERTICAUX SOUSCRITS","	* sindhi"},
/* FBBF */ { "SYMBOLE ARABE ROND","	* pachto"},
/* FBC0 */ { "SYMBOLE ARABE PETIT TA' EN CHEF","	* ourdou"},
/* FBC1 */ { "SYMBOLE ARABE PETIT TA' SOUSCRIT","	* ourdou"},
/* FBC2 */ { "SYMBOLE ARABE WASLA EN CHEF","	x (lettre arabe alif wasla - 0671)"},
/* FBC3 */ { "LIGATURE ARABE DJALLA WA-ALÂ",NULL},
/* FBC4 */ { "LIGATURE ARABE DÂMAT BARAKÂTOUHOUM",NULL},
/* FBC5 */ { "LIGATURE ARABE RAHMATOU ALLÂHI TAÂLÂ ALAYH",NULL},
/* FBC6 */ { "LIGATURE ARABE RAHMATOU ALLÂHI ALAYHIM",NULL},
/* FBC7 */ { "LIGATURE ARABE RAHMATOU ALLÂHI ALAYHIMÂ",NULL},
/* FBC8 */ { "LIGATURE ARABE RAHIMAHOUM ALLÂHOU TAÂLÂ",NULL},
/* FBC9 */ { "LIGATURE ARABE RAHIMAHOUMÂ ALLÂH",NULL},
/* FBCA */ { "LIGATURE ARABE RAHIMAHOUMÂ ALLÂHOU TAÂLÂ",NULL},
/* FBCB */ { "LIGATURE ARABE RADI ALLÂHOU TAÂLÂ ANHOUM",NULL},
/* FBCC */ { "LIGATURE ARABE HAFIZAHOU ALLÂH",NULL},
/* FBCD */ { "LIGATURE ARABE HAFIZAHOU ALLÂHOU TAÂLÂ",NULL},
/* FBCE */ { "LIGATURE ARABE HAFIZAHOUM ALLÂHOU TAÂLÂ",NULL},
/* FBCF */ { "LIGATURE ARABE HAFIZAHOUMÂ ALLÂHOU TAÂLÂ",NULL},
/* FBD0 */ { "LIGATURE ARABE SALLALLÂHOU TAÂLÂ ALAYHI WA-SALLAM",NULL},
/* FBD1 */ { "LIGATURE ARABE ADJJAL ALLÂHOU FARADJAHOU ACH-CHARÎF",NULL},
/* FBD2 */ { "LIGATURE ARABE ALAYHI AR-RAHMAH",NULL},
/* FBD3 */ { "LETTRE ARABE NG ISOLÉ","	# <isolée> 06AD"},
/* FBD4 */ { "LETTRE ARABE NG FINAL","	# <finale> 06AD"},
/* FBD5 */ { "LETTRE ARABE NG INITIAL","	# <initiale> 06AD"},
/* FBD6 */ { "LETTRE ARABE NG MÉDIAL","	# <médiale> 06AD"},
/* FBD7 */ { "LETTRE ARABE OU ISOLÉ","	# <isolée> 06C7"},
/* FBD8 */ { "LETTRE ARABE OU FINAL","	# <finale> 06C7"},
/* FBD9 */ { "LETTRE ARABE EU ISOLÉ","	# <isolée> 06C6"},
/* FBDA */ { "LETTRE ARABE EU FINAL","	# <finale> 06C6"},
/* FBDB */ { "LETTRE ARABE YOU ISOLÉ","	# <isolée> 06C8"},
/* FBDC */ { "LETTRE ARABE YOU FINAL","	# <finale> 06C8"},
/* FBDD */ { "LETTRE ARABE OU HAMZA EN CHEF ISOLÉ","	# <isolée> 0677"},
/* FBDE */ { "LETTRE ARABE VÉ ISOLÉ","	# <isolée> 06CB"},
/* FBDF */ { "LETTRE ARABE VÉ FINAL","	# <finale> 06CB"},
/* FBE0 */ { "LETTRE ARABE KIRGHIZE EU ISOLÉ","	# <isolée> 06C5"},
/* FBE1 */ { "LETTRE ARABE KIRGHIZE EU FINAL","	# <finale> 06C5"},
/* FBE2 */ { "LETTRE ARABE KIRGHIZE YOU ISOLÉ","	# <isolée> 06C9"},
/* FBE3 */ { "LETTRE ARABE KIRGHIZE YOU FINAL","	# <finale> 06C9"},
/* FBE4 */ { "LETTRE ARABE É ISOLÉ","	# <isolée> 06D0"},
/* FBE5 */ { "LETTRE ARABE É FINAL","	# <finale> 06D0"},
/* FBE6 */ { "LETTRE ARABE É INITIAL","	# <initiale> 06D0"},
/* FBE7 */ { "LETTRE ARABE É MÉDIAL","	# <médiale> 06D0"},
/* FBE8 */ { "LETTRE ARABE OUÏGOURE KAZAKHE KIRGHIZE ALIF MAKSOURA INITIAL","	# <initiale> 0649"},
/* FBE9 */ { "LETTRE ARABE OUÏGOURE KAZAKHE KIRGHIZE ALIF MAKSOURA MÉDIAL","	# <médiale> 0649"},
/* FBEA */ { "LIGATURE ARABE YA' HAMZA EN CHEF ALIF ISOLÉ","	# <isolée> 0626 0627"},
/* FBEB */ { "LIGATURE ARABE YA' HAMZA EN CHEF ALIF FINAL","	# <finale> 0626 0627"},
/* FBEC */ { "LIGATURE ARABE YA' HAMZA EN CHEF E ISOLÉ","	# <isolée> 0626 06D5"},
/* FBED */ { "LIGATURE ARABE YA' HAMZA EN CHEF E FINAL","	# <finale> 0626 06D5"},
/* FBEE */ { "LIGATURE ARABE YA' HAMZA EN CHEF WAW ISOLÉ","	# <isolée> 0626 0648"},
/* FBEF */ { "LIGATURE ARABE YA' HAMZA EN CHEF WAW FINAL","	# <finale> 0626 0648"},
/* FBF0 */ { "LIGATURE ARABE YA' HAMZA EN CHEF OU ISOLÉ","	# <isolée> 0626 06C7"},
/* FBF1 */ { "LIGATURE ARABE YA' HAMZA EN CHEF OU FINAL","	# <finale> 0626 06C7"},
/* FBF2 */ { "LIGATURE ARABE YA' HAMZA EN CHEF EU ISOLÉ","	# <isolée> 0626 06C6"},
/* FBF3 */ { "LIGATURE ARABE YA' HAMZA EN CHEF EU FINAL","	# <finale> 0626 06C6"},
/* FBF4 */ { "LIGATURE ARABE YA' HAMZA EN CHEF YOU ISOLÉ","	# <isolée> 0626 06C8"},
/* FBF5 */ { "LIGATURE ARABE YA' HAMZA EN CHEF YOU FINAL","	# <finale> 0626 06C8"},
/* FBF6 */ { "LIGATURE ARABE YA' HAMZA EN CHEF É ISOLÉ","	# <isolée> 0626 06D0"},
/* FBF7 */ { "LIGATURE ARABE YA' HAMZA EN CHEF É FINAL","	# <finale> 0626 06D0"},
/* FBF8 */ { "LIGATURE ARABE YA' HAMZA EN CHEF É INITIAL","	# <initiale> 0626 06D0"},
/* FBF9 */ { "LIGATURE ARABE OUÏGOURE KIRGHIZE YA' HAMZA EN CHEF ALIF MAKSOURA ISOLÉ","	* FC03 possède la même décomposition de compatibilité, mais constitue une variante de présentation distincte\n"
	"	x (ligature arabe ya' hamza en chef alif maksoura isolé - FC03)\n"
	"	# <isolée> 0626 0649"},
/* FBFA */ { "LIGATURE ARABE OUÏGOURE KIRGHIZE YA' HAMZA EN CHEF ALIF MAKSOURA FINAL","	* FC68 possède la même décomposition de compatibilité, mais constitue une variante de présentation distincte\n"
	"	x (ligature arabe ya' hamza en chef alif maksoura final - FC68)\n"
	"	# <finale> 0626 0649"},
/* FBFB */ { "LIGATURE ARABE OUÏGOURE KIRGHIZE YA' HAMZA EN CHEF ALIF MAKSOURA INITIAL","	# <initiale> 0626 0649"},
/* FBFC */ { "LETTRE ARABE FARSI YA' ISOLÉ","	# <isolée> 06CC"},
/* FBFD */ { "LETTRE ARABE FARSI YA' FINAL","	# <finale> 06CC"},
/* FBFE */ { "LETTRE ARABE FARSI YA' INITIAL","	# <initiale> 06CC"},
/* FBFF */ { "LETTRE ARABE FARSI YA' MÉDIAL","	# <médiale> 06CC"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_FC[] = {
/* FC00 */ { "LIGATURE ARABE YA' HAMZA EN CHEF DJÎM ISOLÉ","	# <isolée> 0626 062C"},
/* FC01 */ { "LIGATURE ARABE YA' HAMZA EN CHEF HA' ISOLÉ","	# <isolée> 0626 062D"},
/* FC02 */ { "LIGATURE ARABE YA' HAMZA EN CHEF MÎM ISOLÉ","	# <isolée> 0626 0645"},
/* FC03 */ { "LIGATURE ARABE YA' HAMZA EN CHEF ALIF MAKSOURA ISOLÉ","	* FBF9 possède la même décomposition de compatibilité, mais constitue une variante de présentation distincte\n"
	"	x (ligature arabe ouïgoure kirghize ya' hamza en chef alif maksoura isolé - FBF9)\n"
	"	# <isolée> 0626 0649"},
/* FC04 */ { "LIGATURE ARABE YA' HAMZA EN CHEF YA' ISOLÉ","	# <isolée> 0626 064A"},
/* FC05 */ { "LIGATURE ARABE BA' DJÎM ISOLÉ","	# <isolée> 0628 062C"},
/* FC06 */ { "LIGATURE ARABE BA' HA' ISOLÉ","	# <isolée> 0628 062D"},
/* FC07 */ { "LIGATURE ARABE BA' KHA' ISOLÉ","	# <isolée> 0628 062E"},
/* FC08 */ { "LIGATURE ARABE BA' MÎM ISOLÉ","	# <isolée> 0628 0645"},
/* FC09 */ { "LIGATURE ARABE BA' ALIF MAKSOURA ISOLÉ","	# <isolée> 0628 0649"},
/* FC0A */ { "LIGATURE ARABE BA' YA' ISOLÉ","	# <isolée> 0628 064A"},
/* FC0B */ { "LIGATURE ARABE TÉ' DJÎM ISOLÉ","	# <isolée> 062A 062C"},
/* FC0C */ { "LIGATURE ARABE TÉ' HA' ISOLÉ","	# <isolée> 062A 062D"},
/* FC0D */ { "LIGATURE ARABE TÉ' KHA' ISOLÉ","	# <isolée> 062A 062E"},
/* FC0E */ { "LIGATURE ARABE TÉ' MÎM ISOLÉ","	# <isolée> 062A 0645"},
/* FC0F */ { "LIGATURE ARABE TÉ' ALIF MAKSOURA ISOLÉ","	# <isolée> 062A 0649"},
/* FC10 */ { "LIGATURE ARABE TÉ' YA' ISOLÉ","	# <isolée> 062A 064A"},
/* FC11 */ { "LIGATURE ARABE THÉ' DJÎM ISOLÉ","	# <isolée> 062B 062C"},
/* FC12 */ { "LIGATURE ARABE THÉ' MÎM ISOLÉ","	# <isolée> 062B 0645"},
/* FC13 */ { "LIGATURE ARABE THÉ' ALIF MAKSOURA ISOLÉ","	# <isolée> 062B 0649"},
/* FC14 */ { "LIGATURE ARABE THÉ' YA' ISOLÉ","	# <isolée> 062B 064A"},
/* FC15 */ { "LIGATURE ARABE DJÎM HA' ISOLÉ","	# <isolée> 062C 062D"},
/* FC16 */ { "LIGATURE ARABE DJÎM MÎM ISOLÉ","	# <isolée> 062C 0645"},
/* FC17 */ { "LIGATURE ARABE HA' DJÎM ISOLÉ","	# <isolée> 062D 062C"},
/* FC18 */ { "LIGATURE ARABE HA' MÎM ISOLÉ","	# <isolée> 062D 0645"},
/* FC19 */ { "LIGATURE ARABE KHA' DJÎM ISOLÉ","	# <isolée> 062E 062C"},
/* FC1A */ { "LIGATURE ARABE KHA' HA' ISOLÉ","	# <isolée> 062E 062D"},
/* FC1B */ { "LIGATURE ARABE KHA' MÎM ISOLÉ","	# <isolée> 062E 0645"},
/* FC1C */ { "LIGATURE ARABE SÎN DJÎM ISOLÉ","	# <isolée> 0633 062C"},
/* FC1D */ { "LIGATURE ARABE SÎN HA' ISOLÉ","	# <isolée> 0633 062D"},
/* FC1E */ { "LIGATURE ARABE SÎN KHA' ISOLÉ","	# <isolée> 0633 062E"},
/* FC1F */ { "LIGATURE ARABE SÎN MÎM ISOLÉ","	# <isolée> 0633 0645"},
/* FC20 */ { "LIGATURE ARABE ÇAD HA' ISOLÉ","	# <isolée> 0635 062D"},
/* FC21 */ { "LIGATURE ARABE ÇAD MÎM ISOLÉ","	# <isolée> 0635 0645"},
/* FC22 */ { "LIGATURE ARABE DAD DJÎM ISOLÉ","	# <isolée> 0636 062C"},
/* FC23 */ { "LIGATURE ARABE DAD HA' ISOLÉ","	# <isolée> 0636 062D"},
/* FC24 */ { "LIGATURE ARABE DAD KHA' ISOLÉ","	# <isolée> 0636 062E"},
/* FC25 */ { "LIGATURE ARABE DAD MÎM ISOLÉ","	# <isolée> 0636 0645"},
/* FC26 */ { "LIGATURE ARABE TA' HA' ISOLÉ","	# <isolée> 0637 062D"},
/* FC27 */ { "LIGATURE ARABE TA' MÎM ISOLÉ","	# <isolée> 0637 0645"},
/* FC28 */ { "LIGATURE ARABE ZZA' MÎM ISOLÉ","	# <isolée> 0638 0645"},
/* FC29 */ { "LIGATURE ARABE 'AÏN DJÎM ISOLÉ","	# <isolée> 0639 062C"},
/* FC2A */ { "LIGATURE ARABE 'AÏN MÎM ISOLÉ","	# <isolée> 0639 0645"},
/* FC2B */ { "LIGATURE ARABE GHAÏN DJÎM ISOLÉ","	# <isolée> 063A 062C"},
/* FC2C */ { "LIGATURE ARABE GHAÏN MÎM ISOLÉ","	# <isolée> 063A 0645"},
/* FC2D */ { "LIGATURE ARABE FA' DJÎM ISOLÉ","	# <isolée> 0641 062C"},
/* FC2E */ { "LIGATURE ARABE FA' HA' ISOLÉ","	# <isolée> 0641 062D"},
/* FC2F */ { "LIGATURE ARABE FA' KHA' ISOLÉ","	# <isolée> 0641 062E"},
/* FC30 */ { "LIGATURE ARABE FA' MÎM ISOLÉ","	# <isolée> 0641 0645"},
/* FC31 */ { "LIGATURE ARABE FA' ALIF MAKSOURA ISOLÉ","	# <isolée> 0641 0649"},
/* FC32 */ { "LIGATURE ARABE FA' YA' ISOLÉ","	# <isolée> 0641 064A"},
/* FC33 */ { "LIGATURE ARABE QAF HA' ISOLÉ","	# <isolée> 0642 062D"},
/* FC34 */ { "LIGATURE ARABE QAF MÎM ISOLÉ","	# <isolée> 0642 0645"},
/* FC35 */ { "LIGATURE ARABE QAF ALIF MAKSOURA ISOLÉ","	# <isolée> 0642 0649"},
/* FC36 */ { "LIGATURE ARABE QAF YA' ISOLÉ","	# <isolée> 0642 064A"},
/* FC37 */ { "LIGATURE ARABE KAF ALIF ISOLÉ","	# <isolée> 0643 0627"},
/* FC38 */ { "LIGATURE ARABE KAF DJÎM ISOLÉ","	# <isolée> 0643 062C"},
/* FC39 */ { "LIGATURE ARABE KAF HA' ISOLÉ","	# <isolée> 0643 062D"},
/* FC3A */ { "LIGATURE ARABE KAF KHA' ISOLÉ","	# <isolée> 0643 062E"},
/* FC3B */ { "LIGATURE ARABE KAF LAM ISOLÉ","	# <isolée> 0643 0644"},
/* FC3C */ { "LIGATURE ARABE KAF MÎM ISOLÉ","	# <isolée> 0643 0645"},
/* FC3D */ { "LIGATURE ARABE KAF ALIF MAKSOURA ISOLÉ","	# <isolée> 0643 0649"},
/* FC3E */ { "LIGATURE ARABE KAF YA' ISOLÉ","	# <isolée> 0643 064A"},
/* FC3F */ { "LIGATURE ARABE LAM DJÎM ISOLÉ","	# <isolée> 0644 062C"},
/* FC40 */ { "LIGATURE ARABE LAM HA' ISOLÉ","	# <isolée> 0644 062D"},
/* FC41 */ { "LIGATURE ARABE LAM KHA' ISOLÉ","	# <isolée> 0644 062E"},
/* FC42 */ { "LIGATURE ARABE LAM MÎM ISOLÉ","	# <isolée> 0644 0645"},
/* FC43 */ { "LIGATURE ARABE LAM ALIF MAKSOURA ISOLÉ","	# <isolée> 0644 0649"},
/* FC44 */ { "LIGATURE ARABE LAM YA' ISOLÉ","	# <isolée> 0644 064A"},
/* FC45 */ { "LIGATURE ARABE MÎM DJÎM ISOLÉ","	# <isolée> 0645 062C"},
/* FC46 */ { "LIGATURE ARABE MÎM HA' ISOLÉ","	# <isolée> 0645 062D"},
/* FC47 */ { "LIGATURE ARABE MÎM KHA' ISOLÉ","	# <isolée> 0645 062E"},
/* FC48 */ { "LIGATURE ARABE MÎM MÎM ISOLÉ","	# <isolée> 0645 0645"},
/* FC49 */ { "LIGATURE ARABE MÎM ALIF MAKSOURA ISOLÉ","	# <isolée> 0645 0649"},
/* FC4A */ { "LIGATURE ARABE MÎM YA' ISOLÉ","	# <isolée> 0645 064A"},
/* FC4B */ { "LIGATURE ARABE NOÛN DJÎM ISOLÉ","	# <isolée> 0646 062C"},
/* FC4C */ { "LIGATURE ARABE NOÛN HA' ISOLÉ","	# <isolée> 0646 062D"},
/* FC4D */ { "LIGATURE ARABE NOÛN KHA' ISOLÉ","	# <isolée> 0646 062E"},
/* FC4E */ { "LIGATURE ARABE NOÛN MÎM ISOLÉ","	# <isolée> 0646 0645"},
/* FC4F */ { "LIGATURE ARABE NOÛN ALIF MAKSOURA ISOLÉ","	# <isolée> 0646 0649"},
/* FC50 */ { "LIGATURE ARABE NOÛN YA' ISOLÉ","	# <isolée> 0646 064A"},
/* FC51 */ { "LIGATURE ARABE HÉ' DJÎM ISOLÉ","	# <isolée> 0647 062C"},
/* FC52 */ { "LIGATURE ARABE HÉ' MÎM ISOLÉ","	# <isolée> 0647 0645"},
/* FC53 */ { "LIGATURE ARABE HÉ' ALIF MAKSOURA ISOLÉ","	# <isolée> 0647 0649"},
/* FC54 */ { "LIGATURE ARABE HÉ' YA' ISOLÉ","	# <isolée> 0647 064A"},
/* FC55 */ { "LIGATURE ARABE YA' DJÎM ISOLÉ","	# <isolée> 064A 062C"},
/* FC56 */ { "LIGATURE ARABE YA' HA' ISOLÉ","	# <isolée> 064A 062D"},
/* FC57 */ { "LIGATURE ARABE YA' KHA' ISOLÉ","	# <isolée> 064A 062E"},
/* FC58 */ { "LIGATURE ARABE YA' MÎM ISOLÉ","	# <isolée> 064A 0645"},
/* FC59 */ { "LIGATURE ARABE YA' ALIF MAKSOURA ISOLÉ","	# <isolée> 064A 0649"},
/* FC5A */ { "LIGATURE ARABE YA' YA' ISOLÉ","	# <isolée> 064A 064A"},
/* FC5B */ { "LIGATURE ARABE DHAL ALIF EN CHEF ISOLÉ","	# <isolée> 0630 0670"},
/* FC5C */ { "LIGATURE ARABE RA' ALIF EN CHEF ISOLÉ","	# <isolée> 0631 0670"},
/* FC5D */ { "LIGATURE ARABE ALIF MAKSOURA ALIF EN CHEF ISOLÉ","	# <isolée> 0649 0670"},
/* FC5E */ { "LIGATURE ARABE CHADDA DAMMATAN ISOLÉ","	# <isolée> 0020 064C 0651"},
/* FC5F */ { "LIGATURE ARABE CHADDA KASRATAN ISOLÉ","	# <isolée> 0020 064D 0651"},
/* FC60 */ { "LIGATURE ARABE CHADDA FATHA ISOLÉ","	# <isolée> 0020 064E 0651"},
/* FC61 */ { "LIGATURE ARABE CHADDA DAMMA ISOLÉ","	# <isolée> 0020 064F 0651"},
/* FC62 */ { "LIGATURE ARABE CHADDA KASRA ISOLÉ","	# <isolée> 0020 0650 0651"},
/* FC63 */ { "LIGATURE ARABE CHADDA ALIF EN CHEF ISOLÉ","	# <isolée> 0020 0651 0670"},
/* FC64 */ { "LIGATURE ARABE YA' HAMZA EN CHEF RA' FINAL","	# <finale> 0626 0631"},
/* FC65 */ { "LIGATURE ARABE YA' HAMZA EN CHEF ZAÏN FINAL","	# <finale> 0626 0632"},
/* FC66 */ { "LIGATURE ARABE YA' HAMZA EN CHEF MÎM FINAL","	# <finale> 0626 0645"},
/* FC67 */ { "LIGATURE ARABE YA' HAMZA EN CHEF NOÛN FINAL","	# <finale> 0626 0646"},
/* FC68 */ { "LIGATURE ARABE YA' HAMZA EN CHEF ALIF MAKSOURA FINAL","	* FBFA possède la même décomposition de compatibilité, mais constitue une variante de présentation distincte\n"
	"	x (ligature arabe ouïgoure kirghize ya' hamza en chef alif maksoura final - FBFA)\n"
	"	# <finale> 0626 0649"},
/* FC69 */ { "LIGATURE ARABE YA' HAMZA EN CHEF YA' FINAL","	# <finale> 0626 064A"},
/* FC6A */ { "LIGATURE ARABE BA' RA' FINAL","	# <finale> 0628 0631"},
/* FC6B */ { "LIGATURE ARABE BA' ZAÏN FINAL","	# <finale> 0628 0632"},
/* FC6C */ { "LIGATURE ARABE BA' MÎM FINAL","	# <finale> 0628 0645"},
/* FC6D */ { "LIGATURE ARABE BA' NOÛN FINAL","	# <finale> 0628 0646"},
/* FC6E */ { "LIGATURE ARABE BA' ALIF MAKSOURA FINAL","	# <finale> 0628 0649"},
/* FC6F */ { "LIGATURE ARABE BA' YA' FINAL","	# <finale> 0628 064A"},
/* FC70 */ { "LIGATURE ARABE TÉ' RA' FINAL","	# <finale> 062A 0631"},
/* FC71 */ { "LIGATURE ARABE TÉ' ZAÏN FINAL","	# <finale> 062A 0632"},
/* FC72 */ { "LIGATURE ARABE TÉ' MÎM FINAL","	# <finale> 062A 0645"},
/* FC73 */ { "LIGATURE ARABE TÉ' NOÛN FINAL","	# <finale> 062A 0646"},
/* FC74 */ { "LIGATURE ARABE TÉ' ALIF MAKSOURA FINAL","	# <finale> 062A 0649"},
/* FC75 */ { "LIGATURE ARABE TÉ' YA' FINAL","	# <finale> 062A 064A"},
/* FC76 */ { "LIGATURE ARABE THÉ' RA' FINAL","	# <finale> 062B 0631"},
/* FC77 */ { "LIGATURE ARABE THÉ' ZAÏN FINAL","	# <finale> 062B 0632"},
/* FC78 */ { "LIGATURE ARABE THÉ' MÎM FINAL","	# <finale> 062B 0645"},
/* FC79 */ { "LIGATURE ARABE THÉ' NOÛN FINAL","	# <finale> 062B 0646"},
/* FC7A */ { "LIGATURE ARABE THÉ' ALIF MAKSOURA FINAL","	# <finale> 062B 0649"},
/* FC7B */ { "LIGATURE ARABE THÉ' YA' FINAL","	# <finale> 062B 064A"},
/* FC7C */ { "LIGATURE ARABE FA' ALIF MAKSOURA FINAL","	# <finale> 0641 0649"},
/* FC7D */ { "LIGATURE ARABE FA' YA' FINAL","	# <finale> 0641 064A"},
/* FC7E */ { "LIGATURE ARABE QAF ALIF MAKSOURA FINAL","	# <finale> 0642 0649"},
/* FC7F */ { "LIGATURE ARABE QAF YA' FINAL","	# <finale> 0642 064A"},
/* FC80 */ { "LIGATURE ARABE KAF ALIF FINAL","	# <finale> 0643 0627"},
/* FC81 */ { "LIGATURE ARABE KAF LAM FINAL","	# <finale> 0643 0644"},
/* FC82 */ { "LIGATURE ARABE KAF MÎM FINAL","	# <finale> 0643 0645"},
/* FC83 */ { "LIGATURE ARABE KAF ALIF MAKSOURA FINAL","	# <finale> 0643 0649"},
/* FC84 */ { "LIGATURE ARABE KAF YA' FINAL","	# <finale> 0643 064A"},
/* FC85 */ { "LIGATURE ARABE LAM MÎM FINAL","	# <finale> 0644 0645"},
/* FC86 */ { "LIGATURE ARABE LAM ALIF MAKSOURA FINAL","	# <finale> 0644 0649"},
/* FC87 */ { "LIGATURE ARABE LAM YA' FINAL","	# <finale> 0644 064A"},
/* FC88 */ { "LIGATURE ARABE MÎM ALIF FINAL","	# <finale> 0645 0627"},
/* FC89 */ { "LIGATURE ARABE MÎM MÎM FINAL","	# <finale> 0645 0645"},
/* FC8A */ { "LIGATURE ARABE NOÛN RA' FINAL","	# <finale> 0646 0631"},
/* FC8B */ { "LIGATURE ARABE NOÛN ZAÏN FINAL","	# <finale> 0646 0632"},
/* FC8C */ { "LIGATURE ARABE NOÛN MÎM FINAL","	# <finale> 0646 0645"},
/* FC8D */ { "LIGATURE ARABE NOÛN NOÛN FINAL","	# <finale> 0646 0646"},
/* FC8E */ { "LIGATURE ARABE NOÛN ALIF MAKSOURA FINAL","	# <finale> 0646 0649"},
/* FC8F */ { "LIGATURE ARABE NOÛN YA' FINAL","	# <finale> 0646 064A"},
/* FC90 */ { "LIGATURE ARABE ALIF MAKSOURA ALIF EN CHEF FINAL","	# <finale> 0649 0670"},
/* FC91 */ { "LIGATURE ARABE YA' RA' FINAL","	# <finale> 064A 0631"},
/* FC92 */ { "LIGATURE ARABE YA' ZAÏN FINAL","	# <finale> 064A 0632"},
/* FC93 */ { "LIGATURE ARABE YA' MÎM FINAL","	# <finale> 064A 0645"},
/* FC94 */ { "LIGATURE ARABE YA' NOÛN FINAL","	# <finale> 064A 0646"},
/* FC95 */ { "LIGATURE ARABE YA' ALIF MAKSOURA FINAL","	# <finale> 064A 0649"},
/* FC96 */ { "LIGATURE ARABE YA' YA' FINAL","	# <finale> 064A 064A"},
/* FC97 */ { "LIGATURE ARABE YA' HAMZA EN CHEF DJÎM INITIAL","	# <initiale> 0626 062C"},
/* FC98 */ { "LIGATURE ARABE YA' HAMZA EN CHEF HA' INITIAL","	# <initiale> 0626 062D"},
/* FC99 */ { "LIGATURE ARABE YA' HAMZA EN CHEF KHA' INITIAL","	# <initiale> 0626 062E"},
/* FC9A */ { "LIGATURE ARABE YA' HAMZA EN CHEF MÎM INITIAL","	# <initiale> 0626 0645"},
/* FC9B */ { "LIGATURE ARABE YA' HAMZA EN CHEF HÉ' INITIAL","	# <initiale> 0626 0647"},
/* FC9C */ { "LIGATURE ARABE BA' DJÎM INITIAL","	# <initiale> 0628 062C"},
/* FC9D */ { "LIGATURE ARABE BA' HA' INITIAL","	# <initiale> 0628 062D"},
/* FC9E */ { "LIGATURE ARABE BA' KHA' INITIAL","	# <initiale> 0628 062E"},
/* FC9F */ { "LIGATURE ARABE BA' MÎM INITIAL","	# <initiale> 0628 0645"},
/* FCA0 */ { "LIGATURE ARABE BA' HÉ' INITIAL","	# <initiale> 0628 0647"},
/* FCA1 */ { "LIGATURE ARABE TÉ' DJÎM INITIAL","	# <initiale> 062A 062C"},
/* FCA2 */ { "LIGATURE ARABE TÉ' HA' INITIAL","	# <initiale> 062A 062D"},
/* FCA3 */ { "LIGATURE ARABE TÉ' KHA' INITIAL","	# <initiale> 062A 062E"},
/* FCA4 */ { "LIGATURE ARABE TÉ' MÎM INITIAL","	# <initiale> 062A 0645"},
/* FCA5 */ { "LIGATURE ARABE TÉ' HÉ' INITIAL","	# <initiale> 062A 0647"},
/* FCA6 */ { "LIGATURE ARABE THÉ' MÎM INITIAL","	# <initiale> 062B 0645"},
/* FCA7 */ { "LIGATURE ARABE DJÎM HA' INITIAL","	# <initiale> 062C 062D"},
/* FCA8 */ { "LIGATURE ARABE DJÎM MÎM INITIAL","	# <initiale> 062C 0645"},
/* FCA9 */ { "LIGATURE ARABE HA' DJÎM INITIAL","	# <initiale> 062D 062C"},
/* FCAA */ { "LIGATURE ARABE HA' MÎM INITIAL","	# <initiale> 062D 0645"},
/* FCAB */ { "LIGATURE ARABE KHA' DJÎM INITIAL","	# <initiale> 062E 062C"},
/* FCAC */ { "LIGATURE ARABE KHA' MÎM INITIAL","	# <initiale> 062E 0645"},
/* FCAD */ { "LIGATURE ARABE SÎN DJÎM INITIAL","	# <initiale> 0633 062C"},
/* FCAE */ { "LIGATURE ARABE SÎN HA' INITIAL","	# <initiale> 0633 062D"},
/* FCAF */ { "LIGATURE ARABE SÎN KHA' INITIAL","	# <initiale> 0633 062E"},
/* FCB0 */ { "LIGATURE ARABE SÎN MÎM INITIAL","	# <initiale> 0633 0645"},
/* FCB1 */ { "LIGATURE ARABE ÇAD HA' INITIAL","	# <initiale> 0635 062D"},
/* FCB2 */ { "LIGATURE ARABE ÇAD KHA' INITIAL","	# <initiale> 0635 062E"},
/* FCB3 */ { "LIGATURE ARABE ÇAD MÎM INITIAL","	# <initiale> 0635 0645"},
/* FCB4 */ { "LIGATURE ARABE DAD DJÎM INITIAL","	# <initiale> 0636 062C"},
/* FCB5 */ { "LIGATURE ARABE DAD HA' INITIAL","	# <initiale> 0636 062D"},
/* FCB6 */ { "LIGATURE ARABE DAD KHA' INITIAL","	# <initiale> 0636 062E"},
/* FCB7 */ { "LIGATURE ARABE DAD MÎM INITIAL","	# <initiale> 0636 0645"},
/* FCB8 */ { "LIGATURE ARABE TA' HA' INITIAL","	# <initiale> 0637 062D"},
/* FCB9 */ { "LIGATURE ARABE ZZA' MÎM INITIAL","	# <initiale> 0638 0645"},
/* FCBA */ { "LIGATURE ARABE 'AÏN DJÎM INITIAL","	# <initiale> 0639 062C"},
/* FCBB */ { "LIGATURE ARABE 'AÏN MÎM INITIAL","	# <initiale> 0639 0645"},
/* FCBC */ { "LIGATURE ARABE GHAÏN DJÎM INITIAL","	# <initiale> 063A 062C"},
/* FCBD */ { "LIGATURE ARABE GHAÏN MÎM INITIAL","	# <initiale> 063A 0645"},
/* FCBE */ { "LIGATURE ARABE FA' DJÎM INITIAL","	# <initiale> 0641 062C"},
/* FCBF */ { "LIGATURE ARABE FA' HA' INITIAL","	# <initiale> 0641 062D"},
/* FCC0 */ { "LIGATURE ARABE FA' KHA' INITIAL","	# <initiale> 0641 062E"},
/* FCC1 */ { "LIGATURE ARABE FA' MÎM INITIAL","	# <initiale> 0641 0645"},
/* FCC2 */ { "LIGATURE ARABE QAF HA' INITIAL","	# <initiale> 0642 062D"},
/* FCC3 */ { "LIGATURE ARABE QAF MÎM INITIAL","	# <initiale> 0642 0645"},
/* FCC4 */ { "LIGATURE ARABE KAF DJÎM INITIAL","	# <initiale> 0643 062C"},
/* FCC5 */ { "LIGATURE ARABE KAF HA' INITIAL","	# <initiale> 0643 062D"},
/* FCC6 */ { "LIGATURE ARABE KAF KHA' INITIAL","	# <initiale> 0643 062E"},
/* FCC7 */ { "LIGATURE ARABE KAF LAM INITIAL","	# <initiale> 0643 0644"},
/* FCC8 */ { "LIGATURE ARABE KAF MÎM INITIAL","	# <initiale> 0643 0645"},
/* FCC9 */ { "LIGATURE ARABE LAM DJÎM INITIAL","	# <initiale> 0644 062C"},
/* FCCA */ { "LIGATURE ARABE LAM HA' INITIAL","	# <initiale> 0644 062D"},
/* FCCB */ { "LIGATURE ARABE LAM KHA' INITIAL","	# <initiale> 0644 062E"},
/* FCCC */ { "LIGATURE ARABE LAM MÎM INITIAL","	# <initiale> 0644 0645"},
/* FCCD */ { "LIGATURE ARABE LAM HÉ' INITIAL","	# <initiale> 0644 0647"},
/* FCCE */ { "LIGATURE ARABE MÎM DJÎM INITIAL","	# <initiale> 0645 062C"},
/* FCCF */ { "LIGATURE ARABE MÎM HA' INITIAL","	# <initiale> 0645 062D"},
/* FCD0 */ { "LIGATURE ARABE MÎM KHA' INITIAL","	# <initiale> 0645 062E"},
/* FCD1 */ { "LIGATURE ARABE MÎM MÎM INITIAL","	# <initiale> 0645 0645"},
/* FCD2 */ { "LIGATURE ARABE NOÛN DJÎM INITIAL","	# <initiale> 0646 062C"},
/* FCD3 */ { "LIGATURE ARABE NOÛN HA' INITIAL","	# <initiale> 0646 062D"},
/* FCD4 */ { "LIGATURE ARABE NOÛN KHA' INITIAL","	# <initiale> 0646 062E"},
/* FCD5 */ { "LIGATURE ARABE NOÛN MÎM INITIAL","	# <initiale> 0646 0645"},
/* FCD6 */ { "LIGATURE ARABE NOÛN HÉ' INITIAL","	# <initiale> 0646 0647"},
/* FCD7 */ { "LIGATURE ARABE HÉ' DJÎM INITIAL","	# <initiale> 0647 062C"},
/* FCD8 */ { "LIGATURE ARABE HÉ' MÎM INITIAL","	# <initiale> 0647 0645"},
/* FCD9 */ { "LIGATURE ARABE HÉ' ALIF EN CHEF INITIAL","	# <initiale> 0647 0670"},
/* FCDA */ { "LIGATURE ARABE YA' DJÎM INITIAL","	# <initiale> 064A 062C"},
/* FCDB */ { "LIGATURE ARABE YA' HA' INITIAL","	# <initiale> 064A 062D"},
/* FCDC */ { "LIGATURE ARABE YA' KHA' INITIAL","	# <initiale> 064A 062E"},
/* FCDD */ { "LIGATURE ARABE YA' MÎM INITIAL","	# <initiale> 064A 0645"},
/* FCDE */ { "LIGATURE ARABE YA' HÉ' INITIAL","	# <initiale> 064A 0647"},
/* FCDF */ { "LIGATURE ARABE YA' HAMZA EN CHEF MÎM MÉDIAL","	# <médiale> 0626 0645"},
/* FCE0 */ { "LIGATURE ARABE YA' HAMZA EN CHEF HÉ' MÉDIAL","	# <médiale> 0626 0647"},
/* FCE1 */ { "LIGATURE ARABE BA' MÎM MÉDIAL","	# <médiale> 0628 0645"},
/* FCE2 */ { "LIGATURE ARABE BA' HÉ' MÉDIAL","	# <médiale> 0628 0647"},
/* FCE3 */ { "LIGATURE ARABE TÉ' MÎM MÉDIAL","	# <médiale> 062A 0645"},
/* FCE4 */ { "LIGATURE ARABE TÉ' HÉ' MÉDIAL","	# <médiale> 062A 0647"},
/* FCE5 */ { "LIGATURE ARABE THÉ' MÎM MÉDIAL","	# <médiale> 062B 0645"},
/* FCE6 */ { "LIGATURE ARABE THÉ' HÉ' MÉDIAL","	# <médiale> 062B 0647"},
/* FCE7 */ { "LIGATURE ARABE SÎN MÎM MÉDIAL","	# <médiale> 0633 0645"},
/* FCE8 */ { "LIGATURE ARABE SÎN HÉ' MÉDIAL","	# <médiale> 0633 0647"},
/* FCE9 */ { "LIGATURE ARABE CHÎN MÎM MÉDIAL","	# <médiale> 0634 0645"},
/* FCEA */ { "LIGATURE ARABE CHÎN HÉ' MÉDIAL","	# <médiale> 0634 0647"},
/* FCEB */ { "LIGATURE ARABE KAF LAM MÉDIAL","	# <médiale> 0643 0644"},
/* FCEC */ { "LIGATURE ARABE KAF MÎM MÉDIAL","	# <médiale> 0643 0645"},
/* FCED */ { "LIGATURE ARABE LAM MÎM MÉDIAL","	# <médiale> 0644 0645"},
/* FCEE */ { "LIGATURE ARABE NOÛN MÎM MÉDIAL","	# <médiale> 0646 0645"},
/* FCEF */ { "LIGATURE ARABE NOÛN HÉ' MÉDIAL","	# <médiale> 0646 0647"},
/* FCF0 */ { "LIGATURE ARABE YA' MÎM MÉDIAL","	# <médiale> 064A 0645"},
/* FCF1 */ { "LIGATURE ARABE YA' HÉ' MÉDIAL","	# <médiale> 064A 0647"},
/* FCF2 */ { "LIGATURE ARABE CHADDA FATHA MÉDIAL","	# <médiale> 0640 064E 0651"},
/* FCF3 */ { "LIGATURE ARABE CHADDA DAMMA MÉDIAL","	# <médiale> 0640 064F 0651"},
/* FCF4 */ { "LIGATURE ARABE CHADDA KASRA MÉDIAL","	# <médiale> 0640 0650 0651"},
/* FCF5 */ { "LIGATURE ARABE TA' ALIF MAKSOURA ISOLÉ","	# <isolée> 0637 0649"},
/* FCF6 */ { "LIGATURE ARABE TA' YA' ISOLÉ","	# <isolée> 0637 064A"},
/* FCF7 */ { "LIGATURE ARABE 'AÏN ALIF MAKSOURA ISOLÉ","	# <isolée> 0639 0649"},
/* FCF8 */ { "LIGATURE ARABE 'AÏN YA' ISOLÉ","	# <isolée> 0639 064A"},
/* FCF9 */ { "LIGATURE ARABE GHAÏN ALIF MAKSOURA ISOLÉ","	# <isolée> 063A 0649"},
/* FCFA */ { "LIGATURE ARABE GHAÏN YA' ISOLÉ","	# <isolée> 063A 064A"},
/* FCFB */ { "LIGATURE ARABE SÎN ALIF MAKSOURA ISOLÉ","	# <isolée> 0633 0649"},
/* FCFC */ { "LIGATURE ARABE SÎN YA' ISOLÉ","	# <isolée> 0633 064A"},
/* FCFD */ { "LIGATURE ARABE CHÎN ALIF MAKSOURA ISOLÉ","	# <isolée> 0634 0649"},
/* FCFE */ { "LIGATURE ARABE CHÎN YA' ISOLÉ","	# <isolée> 0634 064A"},
/* FCFF */ { "LIGATURE ARABE HA' ALIF MAKSOURA ISOLÉ","	# <isolée> 062D 0649"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_FD[] = {
/* FD00 */ { "LIGATURE ARABE HA' YA' ISOLÉ","	# <isolée> 062D 064A"},
/* FD01 */ { "LIGATURE ARABE DJÎM ALIF MAKSOURA ISOLÉ","	# <isolée> 062C 0649"},
/* FD02 */ { "LIGATURE ARABE DJÎM YA' ISOLÉ","	# <isolée> 062C 064A"},
/* FD03 */ { "LIGATURE ARABE KHA' ALIF MAKSOURA ISOLÉ","	# <isolée> 062E 0649"},
/* FD04 */ { "LIGATURE ARABE KHA' YA' ISOLÉ","	# <isolée> 062E 064A"},
/* FD05 */ { "LIGATURE ARABE ÇAD ALIF MAKSOURA ISOLÉ","	# <isolée> 0635 0649"},
/* FD06 */ { "LIGATURE ARABE ÇAD YA' ISOLÉ","	# <isolée> 0635 064A"},
/* FD07 */ { "LIGATURE ARABE DAD ALIF MAKSOURA ISOLÉ","	# <isolée> 0636 0649"},
/* FD08 */ { "LIGATURE ARABE DAD YA' ISOLÉ","	# <isolée> 0636 064A"},
/* FD09 */ { "LIGATURE ARABE CHÎN DJÎM ISOLÉ","	# <isolée> 0634 062C"},
/* FD0A */ { "LIGATURE ARABE CHÎN HA' ISOLÉ","	# <isolée> 0634 062D"},
/* FD0B */ { "LIGATURE ARABE CHÎN KHA' ISOLÉ","	# <isolée> 0634 062E"},
/* FD0C */ { "LIGATURE ARABE CHÎN MÎM ISOLÉ","	# <isolée> 0634 0645"},
/* FD0D */ { "LIGATURE ARABE CHÎN RA' ISOLÉ","	# <isolée> 0634 0631"},
/* FD0E */ { "LIGATURE ARABE SÎN RA' ISOLÉ","	# <isolée> 0633 0631"},
/* FD0F */ { "LIGATURE ARABE ÇAD RA' ISOLÉ","	# <isolée> 0635 0631"},
/* FD10 */ { "LIGATURE ARABE DAD RA' ISOLÉ","	# <isolée> 0636 0631"},
/* FD11 */ { "LIGATURE ARABE TA' ALIF MAKSOURA FINAL","	# <finale> 0637 0649"},
/* FD12 */ { "LIGATURE ARABE TA' YA' FINAL","	# <finale> 0637 064A"},
/* FD13 */ { "LIGATURE ARABE 'AÏN ALIF MAKSOURA FINAL","	# <finale> 0639 0649"},
/* FD14 */ { "LIGATURE ARABE 'AÏN YA' FINAL","	# <finale> 0639 064A"},
/* FD15 */ { "LIGATURE ARABE GHAÏN ALIF MAKSOURA FINAL","	# <finale> 063A 0649"},
/* FD16 */ { "LIGATURE ARABE GHAÏN YA' FINAL","	# <finale> 063A 064A"},
/* FD17 */ { "LIGATURE ARABE SÎN ALIF MAKSOURA FINAL","	# <finale> 0633 0649"},
/* FD18 */ { "LIGATURE ARABE SÎN YA' FINAL","	# <finale> 0633 064A"},
/* FD19 */ { "LIGATURE ARABE CHÎN ALIF MAKSOURA FINAL","	# <finale> 0634 0649"},
/* FD1A */ { "LIGATURE ARABE CHÎN YA' FINAL","	# <finale> 0634 064A"},
/* FD1B */ { "LIGATURE ARABE HA' ALIF MAKSOURA FINAL","	# <finale> 062D 0649"},
/* FD1C */ { "LIGATURE ARABE HA' YA' FINAL","	# <finale> 062D 064A"},
/* FD1D */ { "LIGATURE ARABE DJÎM ALIF MAKSOURA FINAL","	# <finale> 062C 0649"},
/* FD1E */ { "LIGATURE ARABE DJÎM YA' FINAL","	# <finale> 062C 064A"},
/* FD1F */ { "LIGATURE ARABE KHA' ALIF MAKSOURA FINAL","	# <finale> 062E 0649"},
/* FD20 */ { "LIGATURE ARABE KHA' YA' FINAL","	# <finale> 062E 064A"},
/* FD21 */ { "LIGATURE ARABE ÇAD ALIF MAKSOURA FINAL","	# <finale> 0635 0649"},
/* FD22 */ { "LIGATURE ARABE ÇAD YA' FINAL","	# <finale> 0635 064A"},
/* FD23 */ { "LIGATURE ARABE DAD ALIF MAKSOURA FINAL","	# <finale> 0636 0649"},
/* FD24 */ { "LIGATURE ARABE DAD YA' FINAL","	# <finale> 0636 064A"},
/* FD25 */ { "LIGATURE ARABE CHÎN DJÎM FINAL","	# <finale> 0634 062C"},
/* FD26 */ { "LIGATURE ARABE CHÎN HA' FINAL","	# <finale> 0634 062D"},
/* FD27 */ { "LIGATURE ARABE CHÎN KHA' FINAL","	# <finale> 0634 062E"},
/* FD28 */ { "LIGATURE ARABE CHÎN MÎM FINAL","	# <finale> 0634 0645"},
/* FD29 */ { "LIGATURE ARABE CHÎN RA' FINAL","	# <finale> 0634 0631"},
/* FD2A */ { "LIGATURE ARABE SÎN RA' FINAL","	# <finale> 0633 0631"},
/* FD2B */ { "LIGATURE ARABE ÇAD RA' FINAL","	# <finale> 0635 0631"},
/* FD2C */ { "LIGATURE ARABE DAD RA' FINAL","	# <finale> 0636 0631"},
/* FD2D */ { "LIGATURE ARABE CHÎN DJÎM INITIAL","	# <initiale> 0634 062C"},
/* FD2E */ { "LIGATURE ARABE CHÎN HA' INITIAL","	# <initiale> 0634 062D"},
/* FD2F */ { "LIGATURE ARABE CHÎN KHA' INITIAL","	# <initiale> 0634 062E"},
/* FD30 */ { "LIGATURE ARABE CHÎN MÎM INITIAL","	# <initiale> 0634 0645"},
/* FD31 */ { "LIGATURE ARABE SÎN HÉ' INITIAL","	# <initiale> 0633 0647"},
/* FD32 */ { "LIGATURE ARABE CHÎN HÉ' INITIAL","	# <initiale> 0634 0647"},
/* FD33 */ { "LIGATURE ARABE TA' MÎM INITIAL","	# <initiale> 0637 0645"},
/* FD34 */ { "LIGATURE ARABE SÎN DJÎM MÉDIAL","	# <médiale> 0633 062C"},
/* FD35 */ { "LIGATURE ARABE SÎN HA' MÉDIAL","	# <médiale> 0633 062D"},
/* FD36 */ { "LIGATURE ARABE SÎN KHA' MÉDIAL","	# <médiale> 0633 062E"},
/* FD37 */ { "LIGATURE ARABE CHÎN DJÎM MÉDIAL","	# <médiale> 0634 062C"},
/* FD38 */ { "LIGATURE ARABE CHÎN HA' MÉDIAL","	# <médiale> 0634 062D"},
/* FD39 */ { "LIGATURE ARABE CHÎN KHA' MÉDIAL","	# <médiale> 0634 062E"},
/* FD3A */ { "LIGATURE ARABE TA' MÎM MÉDIAL","	# <médiale> 0637 0645"},
/* FD3B */ { "LIGATURE ARABE ZZA' MÎM MÉDIAL","	# <médiale> 0638 0645"},
/* FD3C */ { "LIGATURE ARABE ALIF FATHATAN FINAL","	# <finale> 0627 064B"},
/* FD3D */ { "LIGATURE ARABE ALIF FATHATAN ISOLÉ","	# <isolée> 0627 064B"},
/* FD3E */ { "PARENTHÈSE GAUCHE ORNÉE",NULL},
/* FD3F */ { "PARENTHÈSE DROITE ORNÉE",NULL},
/* FD40 */ { "LIGATURE ARABE RAHIMAHOU ALLÂH","	x (diacritique arabe rahmatoullah alayhi - 0612)"},
/* FD41 */ { "LIGATURE ARABE RADI ALLÂHOU ANH","	x (diacritique arabe radi allâhou anhou - 0613)"},
/* FD42 */ { "LIGATURE ARABE RADI ALLÂHOU ANHÂ",NULL},
/* FD43 */ { "LIGATURE ARABE RADI ALLÂHOU ANHOUM",NULL},
/* FD44 */ { "LIGATURE ARABE RADI ALLÂHOU ANHOUMÂ",NULL},
/* FD45 */ { "LIGATURE ARABE RADI ALLÂHOU ANHOUNNA",NULL},
/* FD46 */ { "LIGATURE ARABE SALLALLÂHOU ALAYHI WA-ÂLIH","	x (ligature arabe sallallâhou alayhi wa-sallam - FDFA)"},
/* FD47 */ { "LIGATURE ARABE ALAYHI AS-SALÂM","	x (diacritique arabe alayhi as-salâm - 0611)"},
/* FD48 */ { "LIGATURE ARABE ALAYHIM AS-SALÂM",NULL},
/* FD49 */ { "LIGATURE ARABE ALAYHIMÂ AS-SALÂM",NULL},
/* FD4A */ { "LIGATURE ARABE ALAYHI AS-SALÂTOU WAS-SALÂM",NULL},
/* FD4B */ { "LIGATURE ARABE QOUDDISA SIRRAH",NULL},
/* FD4C */ { "LIGATURE ARABE SALLALLÂHOU ALAYHI WAÂLIHÎ WA-SALLAM","	x (ligature arabe sallallâhou alayhi wa-sallam - FDFA)\n"
	"	x (ligature arabe sallallâhou alayhi wa-âlih - FD46)"},
/* FD4D */ { "LIGATURE ARABE ALAYHÂ AS-SALÂM",NULL},
/* FD4E */ { "LIGATURE ARABE TABÂRAKA WA-TAÂLÂ",NULL},
/* FD4F */ { "LIGATURE ARABE RAHIMAHOUM ALLÂH",NULL},
/* FD50 */ { "LIGATURE ARABE TÉ' DJÎM MÎM INITIAL","	# <initiale> 062A 062C 0645"},
/* FD51 */ { "LIGATURE ARABE TÉ' HA' DJÎM FINAL","	# <finale> 062A 062D 062C"},
/* FD52 */ { "LIGATURE ARABE TÉ' HA' DJÎM INITIAL","	# <initiale> 062A 062D 062C"},
/* FD53 */ { "LIGATURE ARABE TÉ' HA' MÎM INITIAL","	# <initiale> 062A 062D 0645"},
/* FD54 */ { "LIGATURE ARABE TÉ' KHA' MÎM INITIAL","	# <initiale> 062A 062E 0645"},
/* FD55 */ { "LIGATURE ARABE TÉ' MÎM DJÎM INITIAL","	# <initiale> 062A 0645 062C"},
/* FD56 */ { "LIGATURE ARABE TÉ' MÎM HA' INITIAL","	# <initiale> 062A 0645 062D"},
/* FD57 */ { "LIGATURE ARABE TÉ' MÎM KHA' INITIAL","	# <initiale> 062A 0645 062E"},
/* FD58 */ { "LIGATURE ARABE DJÎM MÎM HA' FINAL","	# <finale> 062C 0645 062D"},
/* FD59 */ { "LIGATURE ARABE DJÎM MÎM HA' INITIAL","	# <initiale> 062C 0645 062D"},
/* FD5A */ { "LIGATURE ARABE HA' MÎM YA' FINAL","	# <finale> 062D 0645 064A"},
/* FD5B */ { "LIGATURE ARABE HA' MÎM ALIF MAKSOURA FINAL","	# <finale> 062D 0645 0649"},
/* FD5C */ { "LIGATURE ARABE SÎN HA' DJÎM INITIAL","	# <initiale> 0633 062D 062C"},
/* FD5D */ { "LIGATURE ARABE SÎN DJÎM HA' INITIAL","	# <initiale> 0633 062C 062D"},
/* FD5E */ { "LIGATURE ARABE SÎN DJÎM ALIF MAKSOURA FINAL","	# <finale> 0633 062C 0649"},
/* FD5F */ { "LIGATURE ARABE SÎN MÎM HA' FINAL","	# <finale> 0633 0645 062D"},
/* FD60 */ { "LIGATURE ARABE SÎN MÎM HA' INITIAL","	# <initiale> 0633 0645 062D"},
/* FD61 */ { "LIGATURE ARABE SÎN MÎM DJÎM INITIAL","	# <initiale> 0633 0645 062C"},
/* FD62 */ { "LIGATURE ARABE SÎN MÎM MÎM FINAL","	# <finale> 0633 0645 0645"},
/* FD63 */ { "LIGATURE ARABE SÎN MÎM MÎM INITIAL","	# <initiale> 0633 0645 0645"},
/* FD64 */ { "LIGATURE ARABE ÇAD HA' HA' FINAL","	# <finale> 0635 062D 062D"},
/* FD65 */ { "LIGATURE ARABE ÇAD HA' HA' INITIAL","	# <initiale> 0635 062D 062D"},
/* FD66 */ { "LIGATURE ARABE ÇAD MÎM MÎM FINAL","	# <finale> 0635 0645 0645"},
/* FD67 */ { "LIGATURE ARABE CHÎN HA' MÎM FINAL","	# <finale> 0634 062D 0645"},
/* FD68 */ { "LIGATURE ARABE CHÎN HA' MÎM INITIAL","	# <initiale> 0634 062D 0645"},
/* FD69 */ { "LIGATURE ARABE CHÎN DJÎM YA' FINAL","	# <finale> 0634 062C 064A"},
/* FD6A */ { "LIGATURE ARABE CHÎN MÎM KHA' FINAL","	# <finale> 0634 0645 062E"},
/* FD6B */ { "LIGATURE ARABE CHÎN MÎM KHA' INITIAL","	# <initiale> 0634 0645 062E"},
/* FD6C */ { "LIGATURE ARABE CHÎN MÎM MÎM FINAL","	# <finale> 0634 0645 0645"},
/* FD6D */ { "LIGATURE ARABE CHÎN MÎM MÎM INITIAL","	# <initiale> 0634 0645 0645"},
/* FD6E */ { "LIGATURE ARABE DAD HA' ALIF MAKSOURA FINAL","	# <finale> 0636 062D 0649"},
/* FD6F */ { "LIGATURE ARABE DAD KHA' MÎM FINAL","	# <finale> 0636 062E 0645"},
/* FD70 */ { "LIGATURE ARABE DAD KHA' MÎM INITIAL","	# <initiale> 0636 062E 0645"},
/* FD71 */ { "LIGATURE ARABE TA' MÎM HA' FINAL","	# <finale> 0637 0645 062D"},
/* FD72 */ { "LIGATURE ARABE TA' MÎM HA' INITIAL","	# <initiale> 0637 0645 062D"},
/* FD73 */ { "LIGATURE ARABE TA' MÎM MÎM INITIAL","	# <initiale> 0637 0645 0645"},
/* FD74 */ { "LIGATURE ARABE TA' MÎM YA' FINAL","	# <finale> 0637 0645 064A"},
/* FD75 */ { "LIGATURE ARABE 'AÏN DJÎM MÎM FINAL","	# <finale> 0639 062C 0645"},
/* FD76 */ { "LIGATURE ARABE 'AÏN MÎM MÎM FINAL","	# <finale> 0639 0645 0645"},
/* FD77 */ { "LIGATURE ARABE 'AÏN MÎM MÎM INITIAL","	# <initiale> 0639 0645 0645"},
/* FD78 */ { "LIGATURE ARABE 'AÏN MÎM ALIF MAKSOURA FINAL","	# <finale> 0639 0645 0649"},
/* FD79 */ { "LIGATURE ARABE GHAÏN MÎM MÎM FINAL","	# <finale> 063A 0645 0645"},
/* FD7A */ { "LIGATURE ARABE GHAÏN MÎM YA' FINAL","	# <finale> 063A 0645 064A"},
/* FD7B */ { "LIGATURE ARABE GHAÏN MÎM ALIF MAKSOURA FINAL","	# <finale> 063A 0645 0649"},
/* FD7C */ { "LIGATURE ARABE FA' KHA' MÎM FINAL","	# <finale> 0641 062E 0645"},
/* FD7D */ { "LIGATURE ARABE FA' KHA' MÎM INITIAL","	# <initiale> 0641 062E 0645"},
/* FD7E */ { "LIGATURE ARABE QAF MÎM HA' FINAL","	# <finale> 0642 0645 062D"},
/* FD7F */ { "LIGATURE ARABE QAF MÎM MÎM FINAL","	# <finale> 0642 0645 0645"},
/* FD80 */ { "LIGATURE ARABE LAM HA' MÎM FINAL","	# <finale> 0644 062D 0645"},
/* FD81 */ { "LIGATURE ARABE LAM HA' YA' FINAL","	# <finale> 0644 062D 064A"},
/* FD82 */ { "LIGATURE ARABE LAM HA' ALIF MAKSOURA FINAL","	# <finale> 0644 062D 0649"},
/* FD83 */ { "LIGATURE ARABE LAM DJÎM DJÎM INITIAL","	# <initiale> 0644 062C 062C"},
/* FD84 */ { "LIGATURE ARABE LAM DJÎM DJÎM FINAL","	# <finale> 0644 062C 062C"},
/* FD85 */ { "LIGATURE ARABE LAM KHA' MÎM FINAL","	# <finale> 0644 062E 0645"},
/* FD86 */ { "LIGATURE ARABE LAM KHA' MÎM INITIAL","	# <initiale> 0644 062E 0645"},
/* FD87 */ { "LIGATURE ARABE LAM MÎM HA' FINAL","	# <finale> 0644 0645 062D"},
/* FD88 */ { "LIGATURE ARABE LAM MÎM HA' INITIAL","	# <initiale> 0644 0645 062D"},
/* FD89 */ { "LIGATURE ARABE MÎM HA' DJÎM INITIAL","	# <initiale> 0645 062D 062C"},
/* FD8A */ { "LIGATURE ARABE MÎM HA' MÎM INITIAL","	# <initiale> 0645 062D 0645"},
/* FD8B */ { "LIGATURE ARABE MÎM HA' YA' FINAL","	# <finale> 0645 062D 064A"},
/* FD8C */ { "LIGATURE ARABE MÎM DJÎM HA' INITIAL","	# <initiale> 0645 062C 062D"},
/* FD8D */ { "LIGATURE ARABE MÎM DJÎM MÎM INITIAL","	# <initiale> 0645 062C 0645"},
/* FD8E */ { "LIGATURE ARABE MÎM KHA' DJÎM INITIAL","	# <initiale> 0645 062E 062C"},
/* FD8F */ { "LIGATURE ARABE MÎM KHA' MÎM INITIAL","	# <initiale> 0645 062E 0645"},
/* FD90 */ { "LIGATURE ARABE RAHMATOU ALLÂHI ALAYH",NULL},
/* FD91 */ { "LIGATURE ARABE RAHMATOU ALLÂHI ALAYHÂ",NULL},
/* FD92 */ { "LIGATURE ARABE MÎM DJÎM KHA' INITIAL","	# <initiale> 0645 062C 062E"},
/* FD93 */ { "LIGATURE ARABE HÉ' MÎM DJÎM INITIAL","	# <initiale> 0647 0645 062C"},
/* FD94 */ { "LIGATURE ARABE HÉ' MÎM MÎM INITIAL","	# <initiale> 0647 0645 0645"},
/* FD95 */ { "LIGATURE ARABE NOÛN HA' MÎM INITIAL","	# <initiale> 0646 062D 0645"},
/* FD96 */ { "LIGATURE ARABE NOÛN HA' ALIF MAKSOURA FINAL","	# <finale> 0646 062D 0649"},
/* FD97 */ { "LIGATURE ARABE NOÛN DJÎM MÎM FINAL","	# <finale> 0646 062C 0645"},
/* FD98 */ { "LIGATURE ARABE NOÛN DJÎM MÎM INITIAL","	# <initiale> 0646 062C 0645"},
/* FD99 */ { "LIGATURE ARABE NOÛN DJÎM ALIF MAKSOURA FINAL","	# <finale> 0646 062C 0649"},
/* FD9A */ { "LIGATURE ARABE NOÛN MÎM YA' FINAL","	# <finale> 0646 0645 064A"},
/* FD9B */ { "LIGATURE ARABE NOÛN MÎM ALIF MAKSOURA FINAL","	# <finale> 0646 0645 0649"},
/* FD9C */ { "LIGATURE ARABE YA' MÎM MÎM FINAL","	# <finale> 064A 0645 0645"},
/* FD9D */ { "LIGATURE ARABE YA' MÎM MÎM INITIAL","	# <initiale> 064A 0645 0645"},
/* FD9E */ { "LIGATURE ARABE BA' KHA' YA' FINAL","	# <finale> 0628 062E 064A"},
/* FD9F */ { "LIGATURE ARABE TÉ' DJÎM YA' FINAL","	# <finale> 062A 062C 064A"},
/* FDA0 */ { "LIGATURE ARABE TÉ' DJÎM ALIF MAKSOURA FINAL","	# <finale> 062A 062C 0649"},
/* FDA1 */ { "LIGATURE ARABE TÉ' KHA' YA' FINAL","	# <finale> 062A 062E 064A"},
/* FDA2 */ { "LIGATURE ARABE TÉ' KHA' ALIF MAKSOURA FINAL","	# <finale> 062A 062E 0649"},
/* FDA3 */ { "LIGATURE ARABE TÉ' MÎM YA' FINAL","	# <finale> 062A 0645 064A"},
/* FDA4 */ { "LIGATURE ARABE TÉ' MÎM ALIF MAKSOURA FINAL","	# <finale> 062A 0645 0649"},
/* FDA5 */ { "LIGATURE ARABE DJÎM MÎM YA' FINAL","	# <finale> 062C 0645 064A"},
/* FDA6 */ { "LIGATURE ARABE DJÎM HA' ALIF MAKSOURA FINAL","	# <finale> 062C 062D 0649"},
/* FDA7 */ { "LIGATURE ARABE DJÎM MÎM ALIF MAKSOURA FINAL","	# <finale> 062C 0645 0649"},
/* FDA8 */ { "LIGATURE ARABE SÎN KHA' ALIF MAKSOURA FINAL","	# <finale> 0633 062E 0649"},
/* FDA9 */ { "LIGATURE ARABE ÇAD HA' YA' FINAL","	# <finale> 0635 062D 064A"},
/* FDAA */ { "LIGATURE ARABE CHÎN HA' YA' FINAL","	# <finale> 0634 062D 064A"},
/* FDAB */ { "LIGATURE ARABE DAD HA' YA' FINAL","	# <finale> 0636 062D 064A"},
/* FDAC */ { "LIGATURE ARABE LAM DJÎM YA' FINAL","	# <finale> 0644 062C 064A"},
/* FDAD */ { "LIGATURE ARABE LAM MÎM YA' FINAL","	# <finale> 0644 0645 064A"},
/* FDAE */ { "LIGATURE ARABE YA' HA' YA' FINAL","	# <finale> 064A 062D 064A"},
/* FDAF */ { "LIGATURE ARABE YA' DJÎM YA' FINAL","	# <finale> 064A 062C 064A"},
/* FDB0 */ { "LIGATURE ARABE YA' MÎM YA' FINAL","	# <finale> 064A 0645 064A"},
/* FDB1 */ { "LIGATURE ARABE MÎM MÎM YA' FINAL","	# <finale> 0645 0645 064A"},
/* FDB2 */ { "LIGATURE ARABE QAF MÎM YA' FINAL","	# <finale> 0642 0645 064A"},
/* FDB3 */ { "LIGATURE ARABE NOÛN HA' YA' FINAL","	# <finale> 0646 062D 064A"},
/* FDB4 */ { "LIGATURE ARABE QAF MÎM HA' INITIAL","	# <initiale> 0642 0645 062D"},
/* FDB5 */ { "LIGATURE ARABE LAM HA' MÎM INITIAL","	# <initiale> 0644 062D 0645"},
/* FDB6 */ { "LIGATURE ARABE 'AÏN MÎM YA' FINAL","	# <finale> 0639 0645 064A"},
/* FDB7 */ { "LIGATURE ARABE KAF MÎM YA' FINAL","	# <finale> 0643 0645 064A"},
/* FDB8 */ { "LIGATURE ARABE NOÛN DJÎM HA' INITIAL","	# <initiale> 0646 062C 062D"},
/* FDB9 */ { "LIGATURE ARABE MÎM KHA' YA' FINAL","	# <finale> 0645 062E 064A"},
/* FDBA */ { "LIGATURE ARABE LAM DJÎM MÎM INITIAL","	# <initiale> 0644 062C 0645"},
/* FDBB */ { "LIGATURE ARABE KAF MÎM MÎM FINAL","	# <finale> 0643 0645 0645"},
/* FDBC */ { "LIGATURE ARABE LAM DJÎM MÎM FINAL","	# <finale> 0644 062C 0645"},
/* FDBD */ { "LIGATURE ARABE NOÛN DJÎM HA' FINAL","	# <finale> 0646 062C 062D"},
/* FDBE */ { "LIGATURE ARABE DJÎM HA' YA' FINAL","	# <finale> 062C 062D 064A"},
/* FDBF */ { "LIGATURE ARABE HA' DJÎM YA' FINAL","	# <finale> 062D 062C 064A"},
/* FDC0 */ { "LIGATURE ARABE MÎM DJÎM YA' FINAL","	# <finale> 0645 062C 064A"},
/* FDC1 */ { "LIGATURE ARABE FA' MÎM YA' FINAL","	# <finale> 0641 0645 064A"},
/* FDC2 */ { "LIGATURE ARABE BA' HA' YA' FINAL","	# <finale> 0628 062D 064A"},
/* FDC3 */ { "LIGATURE ARABE KAF MÎM MÎM INITIAL","	# <initiale> 0643 0645 0645"},
/* FDC4 */ { "LIGATURE ARABE 'AÏN DJÎM MÎM INITIAL","	# <initiale> 0639 062C 0645"},
/* FDC5 */ { "LIGATURE ARABE ÇAD MÎM MÎM INITIAL","	# <initiale> 0635 0645 0645"},
/* FDC6 */ { "LIGATURE ARABE SÎN KHA' YA' FINAL","	# <finale> 0633 062E 064A"},
/* FDC7 */ { "LIGATURE ARABE NOÛN DJÎM YA' FINAL","	# <finale> 0646 062C 064A"},
/* FDC8 */ { "LIGATURE ARABE RAHIMAHOU ALLÂH TAÂLÂ",NULL},
/* FDC9 */ { "LIGATURE ARABE RADI ALLÂHOU TAÂLÂ ANH",NULL},
/* FDCA */ { "LIGATURE ARABE RADI ALLÂHOU TAÂLÂ ANHÂ",NULL},
/* FDCB */ { "LIGATURE ARABE RADI ALLÂHOU TAÂLÂ ANHOUMÂ",NULL},
/* FDCC */ { "LIGATURE ARABE SALLALLÂHOU ALAYHI WA-ALÂ ÂLIHÎ WA-SALLAM",NULL},
/* FDCD */ { "LIGATURE ARABE ADJJAL ALLÂHOU TAÂLÂ FARADJAHOU ACH-CHARÎF",NULL},
/* FDCE */ { "LIGATURE ARABE KARRAMA ALLÂHOU WADJHAH",NULL},
/* FDCF */ { "LIGATURE ARABE SALÂMOUHOU ALAYNÂ","	* la paix soit sur nous\n"
	"	* se rencontre dans des textes religieux chrétiens"},
/* FDD0 */ { NULL,NULL},
/* FDD1 */ { NULL,NULL},
/* FDD2 */ { NULL,NULL},
/* FDD3 */ { NULL,NULL},
/* FDD4 */ { NULL,NULL},
/* FDD5 */ { NULL,NULL},
/* FDD6 */ { NULL,NULL},
/* FDD7 */ { NULL,NULL},
/* FDD8 */ { NULL,NULL},
/* FDD9 */ { NULL,NULL},
/* FDDA */ { NULL,NULL},
/* FDDB */ { NULL,NULL},
/* FDDC */ { NULL,NULL},
/* FDDD */ { NULL,NULL},
/* FDDE */ { NULL,NULL},
/* FDDF */ { NULL,NULL},
/* FDE0 */ { NULL,NULL},
/* FDE1 */ { NULL,NULL},
/* FDE2 */ { NULL,NULL},
/* FDE3 */ { NULL,NULL},
/* FDE4 */ { NULL,NULL},
/* FDE5 */ { NULL,NULL},
/* FDE6 */ { NULL,NULL},
/* FDE7 */ { NULL,NULL},
/* FDE8 */ { NULL,NULL},
/* FDE9 */ { NULL,NULL},
/* FDEA */ { NULL,NULL},
/* FDEB */ { NULL,NULL},
/* FDEC */ { NULL,NULL},
/* FDED */ { NULL,NULL},
/* FDEE */ { NULL,NULL},
/* FDEF */ { NULL,NULL},
/* FDF0 */ { "LIGATURE ARABE SALLA ISOLÉ UTILISÉ COMME SIGNE D'ARRÊT CORANIQUE","	# <isolée> 0635 0644 06D2"},
/* FDF1 */ { "LIGATURE ARABE QALA ISOLÉ UTILISÉ COMME SIGNE D'ARRÊT CORANIQUE","	# <isolée> 0642 0644 06D2"},
/* FDF2 */ { "LIGATURE ARABE ALLAH ISOLÉ","	# <isolée> 0627 0644 0644 0647"},
/* FDF3 */ { "LIGATURE ARABE AKBAR ISOLÉ","	# <isolée> 0627 0643 0628 0631"},
/* FDF4 */ { "LIGATURE ARABE MOHAMMAD ISOLÉ","	# <isolée> 0645 062D 0645 062F"},
/* FDF5 */ { "LIGATURE ARABE SALAM ISOLÉ","	* abréviation courante de la phrase d'eulogie « sallā -llāhu ʿalayhī wa-sallam »\n"
	"	x (ligature arabe sallallâhou alayhi wa-sallam - FDFA)\n"
	"	# <isolée> 0635 0644 0639 0645"},
/* FDF6 */ { "LIGATURE ARABE RASOUL ISOLÉ","	# <isolée> 0631 0633 0648 0644"},
/* FDF7 */ { "LIGATURE ARABE ALAYHI ISOLÉ","	# <isolée> 0639 0644 064A 0647"},
/* FDF8 */ { "LIGATURE ARABE WA-SALLAM ISOLÉ","	# <isolée> 0648 0633 0644 0645"},
/* FDF9 */ { "LIGATURE ARABE SALLA ISOLÉ","	# <isolée> 0635 0644 0649"},
/* FDFA */ { "LIGATURE ARABE SALLALLÂHOU ALAYHI WA-SALLAM","	# <isolée> 0635 0644 0649 0020 0627 0644 0644 0647 0020 0639 0644 064A 0647 0020 0648 0633 0644 0645"},
/* FDFB */ { "LIGATURE ARABE DJALLADJALALOUHOU","	# <isolée> 062C 0644 0020 062C 0644 0627 0644 0647"},
/* FDFC */ { "SYMBOLE RIAL","	# <isolée> 0631 06CC 0627 0644"},
/* FDFD */ { "LIGATURE ARABE BISMILLAH AR-RAHMAN AR-RAHÎM",NULL},
/* FDFE */ { "LIGATURE ARABE SOUBHÂNAHOU WA TAÂLÂ",NULL},
/* FDFF */ { "LIGATURE ARABE AZZA WA DJALL",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_FE[] = {
/* FE00 */ { "SÉLECTEUR DE VARIANTE-1","	* ces caractères ont pour abréviation VS1, VS2, et ainsi de suite"},
/* FE01 */ { "SÉLECTEUR DE VARIANTE-2",NULL},
/* FE02 */ { "SÉLECTEUR DE VARIANTE-3",NULL},
/* FE03 */ { "SÉLECTEUR DE VARIANTE-4",NULL},
/* FE04 */ { "SÉLECTEUR DE VARIANTE-5",NULL},
/* FE05 */ { "SÉLECTEUR DE VARIANTE-6",NULL},
/* FE06 */ { "SÉLECTEUR DE VARIANTE-7",NULL},
/* FE07 */ { "SÉLECTEUR DE VARIANTE-8",NULL},
/* FE08 */ { "SÉLECTEUR DE VARIANTE-9",NULL},
/* FE09 */ { "SÉLECTEUR DE VARIANTE-10",NULL},
/* FE0A */ { "SÉLECTEUR DE VARIANTE-11",NULL},
/* FE0B */ { "SÉLECTEUR DE VARIANTE-12",NULL},
/* FE0C */ { "SÉLECTEUR DE VARIANTE-13",NULL},
/* FE0D */ { "SÉLECTEUR DE VARIANTE-14",NULL},
/* FE0E */ { "SÉLECTEUR DE VARIANTE-15","	= sélecteur de variante texte"},
/* FE0F */ { "SÉLECTEUR DE VARIANTE-16","	= sélecteur de variante émoji"},
/* FE10 */ { "FORME DE PRÉSENTATION DE VIRGULE VERTICALE","	x (virgule minuscule - FE50)\n"
	"	# <verticale> 002C"},
/* FE11 */ { "FORME DE PRÉSENTATION DE VIRGULE IDÉOGRAPHIQUE VERTICALE","	x (point sésame - FE45)\n"
	"	x (virgule idéographique minuscule - FE51)\n"
	"	# <verticale> 3001"},
/* FE12 */ { "FORME DE PRÉSENTATION DE POINT IDÉOGRAPHIQUE VERTICAL","	# <verticale> 3002"},
/* FE13 */ { "FORME DE PRÉSENTATION DE DEUX-POINTS VERTICAL","	x (deux-points minuscule - FE55)\n"
	"	# <verticale> 003A"},
/* FE14 */ { "FORME DE PRÉSENTATION DE POINT-VIRGULE VERTICAL","	x (point-virgule minuscule - FE54)\n"
	"	# <verticale> 003B"},
/* FE15 */ { "FORME DE PRÉSENTATION DE POINT D'EXCLAMATION VERTICAL","	x (point d'exclamation minuscule - FE57)\n"
	"	# <verticale> 0021"},
/* FE16 */ { "FORME DE PRÉSENTATION DE POINT D'INTERROGATION VERTICAL","	x (point d'interrogation minuscule - FE56)\n"
	"	# <verticale> 003F"},
/* FE17 */ { "FORME DE PRÉSENTATION DE CROCHET LENTICULAIRE BLANC GAUCHE VERTICAL","	# <verticale> 3016"},
/* FE18 */ { "FORME DE PRÉSENTATION DE CROCHET LENTICULAIRE BLANC DROIT VERTICAL","	# <verticale> 3017"},
/* FE19 */ { "FORME DE PRÉSENTATION DE POINTS DE SUSPENSION VERTICAUX","	x (trois points suspendus - 22EE)\n"
	"	# <verticale> 2026"},
/* FE1A */ { NULL,NULL},
/* FE1B */ { NULL,NULL},
/* FE1C */ { NULL,NULL},
/* FE1D */ { NULL,NULL},
/* FE1E */ { NULL,NULL},
/* FE1F */ { NULL,NULL},
/* FE20 */ { "DIACRITIQUE MOITIÉ GAUCHE DE LIGATURE",NULL},
/* FE21 */ { "DIACRITIQUE MOITIÉ DROITE DE LIGATURE","	x (diacritique double brève renversée - 0361)"},
/* FE22 */ { "DIACRITIQUE MOITIÉ GAUCHE DE TILDE DOUBLE",NULL},
/* FE23 */ { "DIACRITIQUE MOITIÉ DROITE DE TILDE DOUBLE","	x (diacritique double tilde - 0360)"},
/* FE24 */ { "DIACRITIQUE MOITIÉ GAUCHE DE MACRON",NULL},
/* FE25 */ { "DIACRITIQUE MOITIÉ DROITE DE MACRON",NULL},
/* FE26 */ { "DIACRITIQUE MACRON JOINTIF","	x (diacritique macron - 0304)\n"
	"	x (diacritique double macron - 035E)"},
/* FE27 */ { "DIACRITIQUE MOITIÉ GAUCHE DE LIGATURE SOUSCRITE",NULL},
/* FE28 */ { "DIACRITIQUE MOITIÉ DROITE DE LIGATURE SOUSCRITE","	x (diacritique double brève souscrite - 035C)"},
/* FE29 */ { "DIACRITIQUE MOITIÉ GAUCHE DE TILDE SOUSCRIT",NULL},
/* FE2A */ { "DIACRITIQUE MOITIÉ DROITE DE TILDE SOUSCRIT",NULL},
/* FE2B */ { "DIACRITIQUE MOITIÉ GAUCHE DE MACRON SOUSCRIT",NULL},
/* FE2C */ { "DIACRITIQUE MOITIÉ DROITE DE MACRON SOUSCRIT",NULL},
/* FE2D */ { "DIACRITIQUE MACRON SOUSCRIT JOINTIF","	x (diacritique macron souscrit - 0331)\n"
	"	x (diacritique double macron souscrit - 035F)"},
/* FE2E */ { "DIACRITIQUE CYRILLIQUE MOITIÉ GAUCHE DE TITLO",NULL},
/* FE2F */ { "DIACRITIQUE CYRILLIQUE MOITIÉ DROITE DE TITLO","	x (diacritique cyrillique titlo - 0483)"},
/* FE30 */ { "FORME DE PRÉSENTATION DE POINT DE CONDUITE DOUBLE VERTICAL","	# <verticale> 2025"},
/* FE31 */ { "FORME DE PRÉSENTATION DE TIRET CADRATIN VERTICAL","	# <verticale> 2014"},
/* FE32 */ { "FORME DE PRÉSENTATION DE TIRET DEMI-CADRATIN VERTICAL","	# <verticale> 2013"},
/* FE33 */ { "FORME DE PRÉSENTATION DE TIRET BAS VERTICAL","	# <verticale> 005F"},
/* FE34 */ { "FORME DE PRÉSENTATION DE TIRET BAS ONDULÉ VERTICAL","	# <verticale> 005F"},
/* FE35 */ { "FORME DE PRÉSENTATION DE PARENTHÈSE GAUCHE VERTICALE","	x (parenthèse supérieure - 23DC)\n"
	"	# <verticale> 0028"},
/* FE36 */ { "FORME DE PRÉSENTATION DE PARENTHÈSE DROITE VERTICALE","	x (parenthèse inférieure - 23DD)\n"
	"	# <verticale> 0029"},
/* FE37 */ { "FORME DE PRÉSENTATION D'ACCOLADE GAUCHE VERTICALE","	x (accolade supérieure - 23DE)\n"
	"	# <verticale> 007B"},
/* FE38 */ { "FORME DE PRÉSENTATION D'ACCOLADE DROITE VERTICALE","	x (accolade inférieure - 23DF)\n"
	"	# <verticale> 007D"},
/* FE39 */ { "FORME DE PRÉSENTATION DE CROCHET EN ÉCAILLE GAUCHE VERTICAL","	x (crochet en écaille supérieur - 23E0)\n"
	"	# <verticale> 3014"},
/* FE3A */ { "FORME DE PRÉSENTATION DE CROCHET EN ÉCAILLE DROIT VERTICAL","	x (crochet en écaille inférieur - 23E1)\n"
	"	# <verticale> 3015"},
/* FE3B */ { "FORME DE PRÉSENTATION DE CROCHET LENTICULAIRE NOIR GAUCHE VERTICAL","	# <verticale> 3010"},
/* FE3C */ { "FORME DE PRÉSENTATION DE CROCHET LENTICULAIRE NOIR DROIT VERTICAL","	# <verticale> 3011"},
/* FE3D */ { "FORME DE PRÉSENTATION DE CROCHET DOUBLE GAUCHE VERTICAL","	# <verticale> 300A"},
/* FE3E */ { "FORME DE PRÉSENTATION DE CROCHET DOUBLE DROIT VERTICAL","	# <verticale> 300B"},
/* FE3F */ { "FORME DE PRÉSENTATION DE CHEVRON GAUCHE VERTICAL","	# <verticale> 3008"},
/* FE40 */ { "FORME DE PRÉSENTATION DE CHEVRON DROIT VERTICAL","	# <verticale> 3009"},
/* FE41 */ { "FORME DE PRÉSENTATION D'ANGLET GAUCHE VERTICAL","	# <verticale> 300C"},
/* FE42 */ { "FORME DE PRÉSENTATION D'ANGLET DROIT VERTICAL","	# <verticale> 300D"},
/* FE43 */ { "FORME DE PRÉSENTATION D'ANGLET BLANC GAUCHE VERTICAL","	# <verticale> 300E"},
/* FE44 */ { "FORME DE PRÉSENTATION D'ANGLET BLANC DROIT VERTICAL","	# <verticale> 300F"},
/* FE45 */ { "POINT SÉSAME","	x (virgule idéographique minuscule - FE51)"},
/* FE46 */ { "POINT SÉSAME BLANC","	* on utilise les points sésame pour souligner un passage dans un texte vertical"},
/* FE47 */ { "FORME DE PRÉSENTATION DE CROCHET GAUCHE VERTICAL","	x (crochet supérieur - 23B4)\n"
	"	# <verticale> 005B"},
/* FE48 */ { "FORME DE PRÉSENTATION DE CROCHET DROIT VERTICAL","	x (crochet inférieur - 23B5)\n"
	"	# <verticale> 005D"},
/* FE49 */ { "TIRET HAUT À TRAITS DISCONTINUS","	# 203E tiret haut"},
/* FE4A */ { "TIRET HAUT À POINT CENTRAL","	# 203E tiret haut"},
/* FE4B */ { "TIRET HAUT ONDULÉ","	# 203E tiret haut"},
/* FE4C */ { "TIRET HAUT DOUBLE ONDULÉ","	# 203E tiret haut"},
/* FE4D */ { "TIRET BAS À TRAITS DISCONTINUS","	# 005F tiret bas"},
/* FE4E */ { "TIRET BAS À POINT CENTRAL","	# 005F tiret bas"},
/* FE4F */ { "TIRET BAS ONDULÉ","	# 005F tiret bas"},
/* FE50 */ { "VIRGULE MINUSCULE","	x (forme de présentation de virgule verticale - FE10)\n"
	"	# <petite> 002C"},
/* FE51 */ { "VIRGULE IDÉOGRAPHIQUE MINUSCULE","	x (forme de présentation de virgule idéographique verticale - FE11)\n"
	"	x (point sésame - FE45)\n"
	"	# <petite> 3001"},
/* FE52 */ { "POINT MINUSCULE","	# <petite> 002E"},
/* FE53 */ { NULL,NULL},
/* FE54 */ { "POINT-VIRGULE MINUSCULE","	x (forme de présentation de point-virgule vertical - FE14)\n"
	"	# <petite> 003B"},
/* FE55 */ { "DEUX-POINTS MINUSCULE","	x (forme de présentation de deux-points vertical - FE13)\n"
	"	# <petite> 003A"},
/* FE56 */ { "POINT D'INTERROGATION MINUSCULE","	# <petite> 003F"},
/* FE57 */ { "POINT D'EXCLAMATION MINUSCULE","	# <petite> 0021"},
/* FE58 */ { "TIRET CADRATIN MINUSCULE","	# <petite> 2014"},
/* FE59 */ { "PARENTHÈSE GAUCHE MINUSCULE","	# <petite> 0028"},
/* FE5A */ { "PARENTHÈSE DROITE MINUSCULE","	# <petite> 0029"},
/* FE5B */ { "ACCOLADE GAUCHE MINUSCULE","	# <petite> 007B"},
/* FE5C */ { "ACCOLADE DROITE MINUSCULE","	# <petite> 007D"},
/* FE5D */ { "CROCHET EN ÉCAILLE GAUCHE MINUSCULE","	# <petite> 3014"},
/* FE5E */ { "CROCHET EN ÉCAILLE DROIT MINUSCULE","	# <petite> 3015"},
/* FE5F */ { "CROISILLON MINUSCULE","	# <petite> 0023"},
/* FE60 */ { "PERLUÈTE MINUSCULE","	# <petite> 0026"},
/* FE61 */ { "ASTÉRISQUE MINUSCULE","	# <petite> 002A"},
/* FE62 */ { "SIGNE PLUS MINUSCULE","	# <petite> 002B"},
/* FE63 */ { "TIRET MINUSCULE","	# <petite> 002D"},
/* FE64 */ { "SIGNE INFÉRIEUR À MINUSCULE","	# <petite> 003C"},
/* FE65 */ { "SIGNE SUPÉRIEUR À MINUSCULE","	# <petite> 003E"},
/* FE66 */ { "SIGNE ÉGAL MINUSCULE","	# <petite> 003D"},
/* FE67 */ { NULL,NULL},
/* FE68 */ { "BARRE OBLIQUE INVERSÉE MINUSCULE","	= contre-oblique minuscule, contre-cotice minuscule\n"
	"	# <petite> 005C"},
/* FE69 */ { "SYMBOLE DOLLAR MINUSCULE","	# <petite> 0024"},
/* FE6A */ { "SYMBOLE POUR CENT MINUSCULE","	# <petite> 0025"},
/* FE6B */ { "ARROBE MINUSCULE","	= arobase, arobas/arrobas, à commercial\n"
	"	# <petite> 0040"},
/* FE6C */ { NULL,NULL},
/* FE6D */ { NULL,NULL},
/* FE6E */ { NULL,NULL},
/* FE6F */ { NULL,NULL},
/* FE70 */ { "FATHATAN ARABE ISOLÉ","	# <isolée> 0020 064B"},
/* FE71 */ { "TATOUÏL ARABE FATHATAN EN CHEF","	# <médiale> 0640 064B"},
/* FE72 */ { "DAMMATAN ARABE ISOLÉ","	# <isolée> 0020 064C"},
/* FE73 */ { "FRAGMENT DE QUEUE ARABE","	* à des fins de compatibilité avec des jeux de caractères préexistants"},
/* FE74 */ { "KASRATAN ARABE ISOLÉ","	# <isolée> 0020 064D"},
/* FE75 */ { NULL,NULL},
/* FE76 */ { "FATHA ARABE ISOLÉ","	# <isolée> 0020 064E"},
/* FE77 */ { "FATHA ARABE MÉDIAL","	# <médiale> 0640 064E"},
/* FE78 */ { "DAMMA ARABE ISOLÉ","	# <isolée> 0020 064F"},
/* FE79 */ { "DAMMA ARABE MÉDIAL","	# <médiale> 0640 064F"},
/* FE7A */ { "KASRA ARABE ISOLÉ","	# <isolée> 0020 0650"},
/* FE7B */ { "KASRA ARABE MÉDIAL","	# <médiale> 0640 0650"},
/* FE7C */ { "CHADDA ARABE ISOLÉ","	# <isolée> 0020 0651"},
/* FE7D */ { "CHADDA ARABE MÉDIAL","	# <médiale> 0640 0651"},
/* FE7E */ { "SOUKOUN ARABE ISOLÉ","	# <isolée> 0020 0652"},
/* FE7F */ { "SOUKOUN ARABE MÉDIAL","	# <médiale> 0640 0652"},
/* FE80 */ { "LETTRE ARABE HAMZA ISOLÉE","	# <isolée> 0621"},
/* FE81 */ { "LETTRE ARABE ALIF MADDA EN CHEF ISOLÉ","	# <isolée> 0622"},
/* FE82 */ { "LETTRE ARABE ALIF MADDA EN CHEF FINAL","	# <finale> 0622"},
/* FE83 */ { "LETTRE ARABE ALIF HAMZA EN CHEF ISOLÉ","	# <isolée> 0623"},
/* FE84 */ { "LETTRE ARABE ALIF HAMZA EN CHEF FINAL","	# <finale> 0623"},
/* FE85 */ { "LETTRE ARABE WAW HAMZA EN CHEF ISOLÉ","	# <isolée> 0624"},
/* FE86 */ { "LETTRE ARABE WAW HAMZA EN CHEF FINAL","	# <finale> 0624"},
/* FE87 */ { "LETTRE ARABE ALIF HAMZA SOUSCRITE ISOLÉ","	# <isolée> 0625"},
/* FE88 */ { "LETTRE ARABE ALIF HAMZA SOUSCRITE FINAL","	# <finale> 0625"},
/* FE89 */ { "LETTRE ARABE YA' HAMZA EN CHEF ISOLÉ","	# <isolée> 0626"},
/* FE8A */ { "LETTRE ARABE YA' HAMZA EN CHEF FINAL","	# <finale> 0626"},
/* FE8B */ { "LETTRE ARABE YA' HAMZA EN CHEF INITIAL","	# <initiale> 0626"},
/* FE8C */ { "LETTRE ARABE YA' HAMZA EN CHEF MÉDIAL","	# <médiale> 0626"},
/* FE8D */ { "LETTRE ARABE ALIF ISOLÉ","	# <isolée> 0627"},
/* FE8E */ { "LETTRE ARABE ALIF FINAL","	# <finale> 0627"},
/* FE8F */ { "LETTRE ARABE BA' ISOLÉ","	# <isolée> 0628"},
/* FE90 */ { "LETTRE ARABE BA' FINAL","	# <finale> 0628"},
/* FE91 */ { "LETTRE ARABE BA' INITIAL","	# <initiale> 0628"},
/* FE92 */ { "LETTRE ARABE BA' MÉDIAL","	# <médiale> 0628"},
/* FE93 */ { "LETTRE ARABE TÉ' MARBOUTA ISOLÉ","	# <isolée> 0629"},
/* FE94 */ { "LETTRE ARABE TÉ' MARBOUTA FINAL","	# <finale> 0629"},
/* FE95 */ { "LETTRE ARABE TÉ' ISOLÉ","	# <isolée> 062A"},
/* FE96 */ { "LETTRE ARABE TÉ' FINAL","	# <finale> 062A"},
/* FE97 */ { "LETTRE ARABE TÉ' INITIAL","	# <initiale> 062A"},
/* FE98 */ { "LETTRE ARABE TÉ' MÉDIAL","	# <médiale> 062A"},
/* FE99 */ { "LETTRE ARABE THÉ' ISOLÉ","	# <isolée> 062B"},
/* FE9A */ { "LETTRE ARABE THÉ' FINAL","	# <finale> 062B"},
/* FE9B */ { "LETTRE ARABE THÉ' INITIAL","	# <initiale> 062B"},
/* FE9C */ { "LETTRE ARABE THÉ' MÉDIAL","	# <médiale> 062B"},
/* FE9D */ { "LETTRE ARABE DJÎM ISOLÉ","	# <isolée> 062C"},
/* FE9E */ { "LETTRE ARABE DJÎM FINAL","	# <finale> 062C"},
/* FE9F */ { "LETTRE ARABE DJÎM INITIAL","	# <initiale> 062C"},
/* FEA0 */ { "LETTRE ARABE DJÎM MÉDIAL","	# <médiale> 062C"},
/* FEA1 */ { "LETTRE ARABE HA' ISOLÉ","	# <isolée> 062D"},
/* FEA2 */ { "LETTRE ARABE HA' FINAL","	# <finale> 062D"},
/* FEA3 */ { "LETTRE ARABE HA' INITIAL","	# <initiale> 062D"},
/* FEA4 */ { "LETTRE ARABE HA' MÉDIAL","	# <médiale> 062D"},
/* FEA5 */ { "LETTRE ARABE KHA' ISOLÉ","	# <isolée> 062E"},
/* FEA6 */ { "LETTRE ARABE KHA' FINAL","	# <finale> 062E"},
/* FEA7 */ { "LETTRE ARABE KHA' INITIAL","	# <initiale> 062E"},
/* FEA8 */ { "LETTRE ARABE KHA' MÉDIAL","	# <médiale> 062E"},
/* FEA9 */ { "LETTRE ARABE DAL ISOLÉ","	# <isolée> 062F"},
/* FEAA */ { "LETTRE ARABE DAL FINAL","	# <finale> 062F"},
/* FEAB */ { "LETTRE ARABE DHAL ISOLÉ","	# <isolée> 0630"},
/* FEAC */ { "LETTRE ARABE DHAL FINAL","	# <finale> 0630"},
/* FEAD */ { "LETTRE ARABE RA' ISOLÉ","	# <isolée> 0631"},
/* FEAE */ { "LETTRE ARABE RA' FINAL","	# <finale> 0631"},
/* FEAF */ { "LETTRE ARABE ZAÏN ISOLÉ","	# <isolée> 0632"},
/* FEB0 */ { "LETTRE ARABE ZAÏN FINAL","	# <finale> 0632"},
/* FEB1 */ { "LETTRE ARABE SÎN ISOLÉ","	# <isolée> 0633"},
/* FEB2 */ { "LETTRE ARABE SÎN FINAL","	# <finale> 0633"},
/* FEB3 */ { "LETTRE ARABE SÎN INITIAL","	# <initiale> 0633"},
/* FEB4 */ { "LETTRE ARABE SÎN MÉDIAL","	# <médiale> 0633"},
/* FEB5 */ { "LETTRE ARABE CHÎN ISOLÉ","	# <isolée> 0634"},
/* FEB6 */ { "LETTRE ARABE CHÎN FINAL","	# <finale> 0634"},
/* FEB7 */ { "LETTRE ARABE CHÎN INITIAL","	# <initiale> 0634"},
/* FEB8 */ { "LETTRE ARABE CHÎN MÉDIAL","	# <médiale> 0634"},
/* FEB9 */ { "LETTRE ARABE ÇAD ISOLÉ","	# <isolée> 0635"},
/* FEBA */ { "LETTRE ARABE ÇAD FINAL","	# <finale> 0635"},
/* FEBB */ { "LETTRE ARABE ÇAD INITIAL","	# <initiale> 0635"},
/* FEBC */ { "LETTRE ARABE ÇAD MÉDIAL","	# <médiale> 0635"},
/* FEBD */ { "LETTRE ARABE DAD ISOLÉ","	# <isolée> 0636"},
/* FEBE */ { "LETTRE ARABE DAD FINAL","	# <finale> 0636"},
/* FEBF */ { "LETTRE ARABE DAD INITIAL","	# <initiale> 0636"},
/* FEC0 */ { "LETTRE ARABE DAD MÉDIAL","	# <médiale> 0636"},
/* FEC1 */ { "LETTRE ARABE TA' ISOLÉ","	# <isolée> 0637"},
/* FEC2 */ { "LETTRE ARABE TA' FINAL","	# <finale> 0637"},
/* FEC3 */ { "LETTRE ARABE TA' INITIAL","	# <initiale> 0637"},
/* FEC4 */ { "LETTRE ARABE TA' MÉDIAL","	# <médiale> 0637"},
/* FEC5 */ { "LETTRE ARABE ZZA' ISOLÉ","	# <isolée> 0638"},
/* FEC6 */ { "LETTRE ARABE ZZA' FINAL","	# <finale> 0638"},
/* FEC7 */ { "LETTRE ARABE ZZA' INITIAL","	# <initiale> 0638"},
/* FEC8 */ { "LETTRE ARABE ZZA' MÉDIAL","	# <médiale> 0638"},
/* FEC9 */ { "LETTRE ARABE 'AÏN ISOLÉ","	# <isolée> 0639"},
/* FECA */ { "LETTRE ARABE 'AÏN FINAL","	# <finale> 0639"},
/* FECB */ { "LETTRE ARABE 'AÏN INITIAL","	# <initiale> 0639"},
/* FECC */ { "LETTRE ARABE 'AÏN MÉDIAL","	# <médiale> 0639"},
/* FECD */ { "LETTRE ARABE GHAÏN ISOLÉ","	# <isolée> 063A"},
/* FECE */ { "LETTRE ARABE GHAÏN FINAL","	# <finale> 063A"},
/* FECF */ { "LETTRE ARABE GHAÏN INITIAL","	# <initiale> 063A"},
/* FED0 */ { "LETTRE ARABE GHAÏN MÉDIAL","	# <médiale> 063A"},
/* FED1 */ { "LETTRE ARABE FA' ISOLÉ","	# <isolée> 0641"},
/* FED2 */ { "LETTRE ARABE FA' FINAL","	# <finale> 0641"},
/* FED3 */ { "LETTRE ARABE FA' INITIAL","	# <initiale> 0641"},
/* FED4 */ { "LETTRE ARABE FA' MÉDIAL","	# <médiale> 0641"},
/* FED5 */ { "LETTRE ARABE QAF ISOLÉ","	# <isolée> 0642"},
/* FED6 */ { "LETTRE ARABE QAF FINAL","	# <finale> 0642"},
/* FED7 */ { "LETTRE ARABE QAF INITIAL","	# <initiale> 0642"},
/* FED8 */ { "LETTRE ARABE QAF MÉDIAL","	# <médiale> 0642"},
/* FED9 */ { "LETTRE ARABE KAF ISOLÉ","	# <isolée> 0643"},
/* FEDA */ { "LETTRE ARABE KAF FINAL","	# <finale> 0643"},
/* FEDB */ { "LETTRE ARABE KAF INITIAL","	# <initiale> 0643"},
/* FEDC */ { "LETTRE ARABE KAF MÉDIAL","	# <médiale> 0643"},
/* FEDD */ { "LETTRE ARABE LAM ISOLÉ","	# <isolée> 0644"},
/* FEDE */ { "LETTRE ARABE LAM FINAL","	# <finale> 0644"},
/* FEDF */ { "LETTRE ARABE LAM INITIAL","	# <initiale> 0644"},
/* FEE0 */ { "LETTRE ARABE LAM MÉDIAL","	# <médiale> 0644"},
/* FEE1 */ { "LETTRE ARABE MÎM ISOLÉ","	# <isolée> 0645"},
/* FEE2 */ { "LETTRE ARABE MÎM FINAL","	# <finale> 0645"},
/* FEE3 */ { "LETTRE ARABE MÎM INITIAL","	# <initiale> 0645"},
/* FEE4 */ { "LETTRE ARABE MÎM MÉDIAL","	# <médiale> 0645"},
/* FEE5 */ { "LETTRE ARABE NOÛN ISOLÉ","	# <isolée> 0646"},
/* FEE6 */ { "LETTRE ARABE NOÛN FINAL","	# <finale> 0646"},
/* FEE7 */ { "LETTRE ARABE NOÛN INITIAL","	# <initiale> 0646"},
/* FEE8 */ { "LETTRE ARABE NOÛN MÉDIAL","	# <médiale> 0646"},
/* FEE9 */ { "LETTRE ARABE HÉ' ISOLÉ","	# <isolée> 0647"},
/* FEEA */ { "LETTRE ARABE HÉ' FINAL","	# <finale> 0647"},
/* FEEB */ { "LETTRE ARABE HÉ' INITIAL","	# <initiale> 0647"},
/* FEEC */ { "LETTRE ARABE HÉ' MÉDIAL","	# <médiale> 0647"},
/* FEED */ { "LETTRE ARABE WAW ISOLÉ","	# <isolée> 0648"},
/* FEEE */ { "LETTRE ARABE WAW FINAL","	# <finale> 0648"},
/* FEEF */ { "LETTRE ARABE ALIF MAKSOURA ISOLÉ","	# <isolée> 0649"},
/* FEF0 */ { "LETTRE ARABE ALIF MAKSOURA FINAL","	# <finale> 0649"},
/* FEF1 */ { "LETTRE ARABE YA' ISOLÉ","	# <isolée> 064A"},
/* FEF2 */ { "LETTRE ARABE YA' FINAL","	# <finale> 064A"},
/* FEF3 */ { "LETTRE ARABE YA' INITIAL","	# <initiale> 064A"},
/* FEF4 */ { "LETTRE ARABE YA' MÉDIAL","	# <médiale> 064A"},
/* FEF5 */ { "LIGATURE ARABE LAM ALIF MADDA EN CHEF ISOLÉ","	# <isolée> 0644 0622"},
/* FEF6 */ { "LIGATURE ARABE LAM ALIF MADDA EN CHEF FINAL","	# <finale> 0644 0622"},
/* FEF7 */ { "LIGATURE ARABE LAM ALIF HAMZA EN CHEF ISOLÉ","	# <isolée> 0644 0623"},
/* FEF8 */ { "LIGATURE ARABE LAM ALIF HAMZA EN CHEF FINAL","	# <finale> 0644 0623"},
/* FEF9 */ { "LIGATURE ARABE LAM ALIF HAMZA SOUSCRITE ISOLÉ","	# <isolée> 0644 0625"},
/* FEFA */ { "LIGATURE ARABE LAM ALIF HAMZA SOUSCRITE FINAL","	# <finale> 0644 0625"},
/* FEFB */ { "LIGATURE ARABE LAM ALIF ISOLÉ","	# <isolée> 0644 0627"},
/* FEFC */ { "LIGATURE ARABE LAM ALIF FINAL","	# <finale> 0644 0627"},
/* FEFD */ { NULL,NULL},
/* FEFE */ { NULL,NULL},
/* FEFF */ { "INDICATEUR D'ORDRE DES OCTETS","	= BOM (byte order mark)\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	* permet de détecter l'ordre des octets par opposition à FFFE, qui n'est associé à aucun caractère\n"
	"	* l'utilisation de ce caractère comme une espace insécable sans chasse (« zero width no-break space », communément abrégé en ZWNBSP) est obsolète ; la solution pour cet emploi est fournie par 2060\n"
	"	x (espace sans chasse - 200B)\n"
	"	x (gluon de mots - 2060)\n"
	"	x (<pas un caractère> - FFFE)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_00_FF[] = {
/* FF00 */ { NULL,NULL},
/* FF01 */ { "POINT D'EXCLAMATION PLEINE CHASSE","	~ FF01 FE00 forme alignée dans le coin\n"
	"	~ FF01 FE01 forme centrée\n"
	"	# <large> 0021"},
/* FF02 */ { "GUILLEMET PLEINE CHASSE","	# <large> 0022"},
/* FF03 */ { "CROISILLON PLEINE CHASSE","	# <large> 0023"},
/* FF04 */ { "SYMBOLE DOLLAR PLEINE CHASSE","	# <large> 0024"},
/* FF05 */ { "SYMBOLE POUR CENT PLEINE CHASSE","	# <large> 0025"},
/* FF06 */ { "PERLUÈTE PLEINE CHASSE","	# <large> 0026"},
/* FF07 */ { "APOSTROPHE PLEINE CHASSE","	# <large> 0027"},
/* FF08 */ { "PARENTHÈSE GAUCHE PLEINE CHASSE","	# <large> 0028"},
/* FF09 */ { "PARENTHÈSE DROITE PLEINE CHASSE","	# <large> 0029"},
/* FF0A */ { "ASTÉRISQUE PLEINE CHASSE","	# <large> 002A"},
/* FF0B */ { "SIGNE PLUS PLEINE CHASSE","	# <large> 002B"},
/* FF0C */ { "VIRGULE PLEINE CHASSE","	* en chinois, indique une pause\n"
	"	x (virgule idéographique - 3001)\n"
	"	~ FF0C FE00 forme alignée dans le coin\n"
	"	~ FF0C FE01 forme centrée\n"
	"	# <large> 002C"},
/* FF0D */ { "TIRET PLEINE CHASSE","	# <large> 002D"},
/* FF0E */ { "POINT PLEINE CHASSE","	~ FF0E FE00 forme alignée dans le coin\n"
	"	~ FF0E FE01 forme centrée\n"
	"	# <large> 002E"},
/* FF0F */ { "BARRE OBLIQUE PLEINE CHASSE","	= oblique pleine chasse, cotice pleine chasse\n"
	"	# <large> 002F"},
/* FF10 */ { "CHIFFRE ZÉRO PLEINE CHASSE","	~ FF10 FE00 forme à barre diagonale courte\n"
	"	# <large> 0030"},
/* FF11 */ { "CHIFFRE UN PLEINE CHASSE","	# <large> 0031"},
/* FF12 */ { "CHIFFRE DEUX PLEINE CHASSE","	# <large> 0032"},
/* FF13 */ { "CHIFFRE TROIS PLEINE CHASSE","	# <large> 0033"},
/* FF14 */ { "CHIFFRE QUATRE PLEINE CHASSE","	# <large> 0034"},
/* FF15 */ { "CHIFFRE CINQ PLEINE CHASSE","	# <large> 0035"},
/* FF16 */ { "CHIFFRE SIX PLEINE CHASSE","	# <large> 0036"},
/* FF17 */ { "CHIFFRE SEPT PLEINE CHASSE","	# <large> 0037"},
/* FF18 */ { "CHIFFRE HUIT PLEINE CHASSE","	# <large> 0038"},
/* FF19 */ { "CHIFFRE NEUF PLEINE CHASSE","	# <large> 0039"},
/* FF1A */ { "DEUX-POINTS PLEINE CHASSE","	~ FF1A FE00 forme alignée dans le coin\n"
	"	~ FF1A FE01 forme centrée\n"
	"	# <large> 003A"},
/* FF1B */ { "POINT-VIRGULE PLEINE CHASSE","	~ FF1B FE00 forme alignée dans le coin\n"
	"	~ FF1B FE01 forme centrée\n"
	"	# <large> 003B"},
/* FF1C */ { "SIGNE INFÉRIEUR À PLEINE CHASSE","	# <large> 003C"},
/* FF1D */ { "SIGNE ÉGAL PLEINE CHASSE","	# <large> 003D"},
/* FF1E */ { "SIGNE SUPÉRIEUR À PLEINE CHASSE","	# <large> 003E"},
/* FF1F */ { "POINT D'INTERROGATION PLEINE CHASSE","	~ FF1F FE00 forme alignée dans le coin\n"
	"	~ FF1F FE01 forme centrée\n"
	"	# <large> 003F"},
/* FF20 */ { "ARROBE PLEINE CHASSE","	= arobase, arobas/arrobas, à commercial\n"
	"	# <large> 0040"},
/* FF21 */ { "LETTRE MAJUSCULE LATINE A PLEINE CHASSE","	# <large> 0041"},
/* FF22 */ { "LETTRE MAJUSCULE LATINE B PLEINE CHASSE","	# <large> 0042"},
/* FF23 */ { "LETTRE MAJUSCULE LATINE C PLEINE CHASSE","	# <large> 0043"},
/* FF24 */ { "LETTRE MAJUSCULE LATINE D PLEINE CHASSE","	# <large> 0044"},
/* FF25 */ { "LETTRE MAJUSCULE LATINE E PLEINE CHASSE","	# <large> 0045"},
/* FF26 */ { "LETTRE MAJUSCULE LATINE F PLEINE CHASSE","	# <large> 0046"},
/* FF27 */ { "LETTRE MAJUSCULE LATINE G PLEINE CHASSE","	# <large> 0047"},
/* FF28 */ { "LETTRE MAJUSCULE LATINE H PLEINE CHASSE","	# <large> 0048"},
/* FF29 */ { "LETTRE MAJUSCULE LATINE I PLEINE CHASSE","	# <large> 0049"},
/* FF2A */ { "LETTRE MAJUSCULE LATINE J PLEINE CHASSE","	# <large> 004A"},
/* FF2B */ { "LETTRE MAJUSCULE LATINE K PLEINE CHASSE","	# <large> 004B"},
/* FF2C */ { "LETTRE MAJUSCULE LATINE L PLEINE CHASSE","	# <large> 004C"},
/* FF2D */ { "LETTRE MAJUSCULE LATINE M PLEINE CHASSE","	# <large> 004D"},
/* FF2E */ { "LETTRE MAJUSCULE LATINE N PLEINE CHASSE","	# <large> 004E"},
/* FF2F */ { "LETTRE MAJUSCULE LATINE O PLEINE CHASSE","	# <large> 004F"},
/* FF30 */ { "LETTRE MAJUSCULE LATINE P PLEINE CHASSE","	# <large> 0050"},
/* FF31 */ { "LETTRE MAJUSCULE LATINE Q PLEINE CHASSE","	# <large> 0051"},
/* FF32 */ { "LETTRE MAJUSCULE LATINE R PLEINE CHASSE","	# <large> 0052"},
/* FF33 */ { "LETTRE MAJUSCULE LATINE S PLEINE CHASSE","	# <large> 0053"},
/* FF34 */ { "LETTRE MAJUSCULE LATINE T PLEINE CHASSE","	# <large> 0054"},
/* FF35 */ { "LETTRE MAJUSCULE LATINE U PLEINE CHASSE","	# <large> 0055"},
/* FF36 */ { "LETTRE MAJUSCULE LATINE V PLEINE CHASSE","	# <large> 0056"},
/* FF37 */ { "LETTRE MAJUSCULE LATINE W PLEINE CHASSE","	# <large> 0057"},
/* FF38 */ { "LETTRE MAJUSCULE LATINE X PLEINE CHASSE","	# <large> 0058"},
/* FF39 */ { "LETTRE MAJUSCULE LATINE Y PLEINE CHASSE","	# <large> 0059"},
/* FF3A */ { "LETTRE MAJUSCULE LATINE Z PLEINE CHASSE","	# <large> 005A"},
/* FF3B */ { "CROCHET GAUCHE PLEINE CHASSE","	# <large> 005B"},
/* FF3C */ { "BARRE OBLIQUE INVERSÉE PLEINE CHASSE","	= contre-oblique pleine chasse, contre-cotice pleine chasse\n"
	"	# <large> 005C"},
/* FF3D */ { "CROCHET DROIT PLEINE CHASSE","	# <large> 005D"},
/* FF3E */ { "ACCENT CIRCONFLEXE PLEINE CHASSE","	# <large> 005E"},
/* FF3F */ { "TIRET BAS PLEINE CHASSE","	# <large> 005F"},
/* FF40 */ { "ACCENT GRAVE PLEINE CHASSE","	# <large> 0060"},
/* FF41 */ { "LETTRE MINUSCULE LATINE A PLEINE CHASSE","	# <large> 0061"},
/* FF42 */ { "LETTRE MINUSCULE LATINE B PLEINE CHASSE","	# <large> 0062"},
/* FF43 */ { "LETTRE MINUSCULE LATINE C PLEINE CHASSE","	# <large> 0063"},
/* FF44 */ { "LETTRE MINUSCULE LATINE D PLEINE CHASSE","	# <large> 0064"},
/* FF45 */ { "LETTRE MINUSCULE LATINE E PLEINE CHASSE","	# <large> 0065"},
/* FF46 */ { "LETTRE MINUSCULE LATINE F PLEINE CHASSE","	# <large> 0066"},
/* FF47 */ { "LETTRE MINUSCULE LATINE G PLEINE CHASSE","	# <large> 0067"},
/* FF48 */ { "LETTRE MINUSCULE LATINE H PLEINE CHASSE","	# <large> 0068"},
/* FF49 */ { "LETTRE MINUSCULE LATINE I PLEINE CHASSE","	# <large> 0069"},
/* FF4A */ { "LETTRE MINUSCULE LATINE J PLEINE CHASSE","	# <large> 006A"},
/* FF4B */ { "LETTRE MINUSCULE LATINE K PLEINE CHASSE","	# <large> 006B"},
/* FF4C */ { "LETTRE MINUSCULE LATINE L PLEINE CHASSE","	# <large> 006C"},
/* FF4D */ { "LETTRE MINUSCULE LATINE M PLEINE CHASSE","	# <large> 006D"},
/* FF4E */ { "LETTRE MINUSCULE LATINE N PLEINE CHASSE","	# <large> 006E"},
/* FF4F */ { "LETTRE MINUSCULE LATINE O PLEINE CHASSE","	# <large> 006F"},
/* FF50 */ { "LETTRE MINUSCULE LATINE P PLEINE CHASSE","	# <large> 0070"},
/* FF51 */ { "LETTRE MINUSCULE LATINE Q PLEINE CHASSE","	# <large> 0071"},
/* FF52 */ { "LETTRE MINUSCULE LATINE R PLEINE CHASSE","	# <large> 0072"},
/* FF53 */ { "LETTRE MINUSCULE LATINE S PLEINE CHASSE","	# <large> 0073"},
/* FF54 */ { "LETTRE MINUSCULE LATINE T PLEINE CHASSE","	# <large> 0074"},
/* FF55 */ { "LETTRE MINUSCULE LATINE U PLEINE CHASSE","	# <large> 0075"},
/* FF56 */ { "LETTRE MINUSCULE LATINE V PLEINE CHASSE","	# <large> 0076"},
/* FF57 */ { "LETTRE MINUSCULE LATINE W PLEINE CHASSE","	# <large> 0077"},
/* FF58 */ { "LETTRE MINUSCULE LATINE X PLEINE CHASSE","	# <large> 0078"},
/* FF59 */ { "LETTRE MINUSCULE LATINE Y PLEINE CHASSE","	# <large> 0079"},
/* FF5A */ { "LETTRE MINUSCULE LATINE Z PLEINE CHASSE","	# <large> 007A"},
/* FF5B */ { "ACCOLADE GAUCHE PLEINE CHASSE","	# <large> 007B"},
/* FF5C */ { "BARRE VERTICALE PLEINE CHASSE","	# <large> 007C"},
/* FF5D */ { "ACCOLADE DROITE PLEINE CHASSE","	# <large> 007D"},
/* FF5E */ { "TILDE PLEINE CHASSE","	x (tiret en esse - 301C)\n"
	"	# <large> 007E"},
/* FF5F */ { "PARENTHÈSE BLANCHE GAUCHE PLEINE CHASSE","	* la variante de glyphe la plus courante ressemble à une parenthèse dédoublée\n"
	"	x (double parenthèse gauche - 2E28)\n"
	"	# <large> 2985"},
/* FF60 */ { "PARENTHÈSE BLANCHE DROITE PLEINE CHASSE","	# <large> 2986"},
/* FF61 */ { "POINT IDÉOGRAPHIQUE DEMI-CHASSE","	# <étroite> 3002"},
/* FF62 */ { "ANGLET GAUCHE DEMI-CHASSE","	# <étroite> 300C"},
/* FF63 */ { "ANGLET DROIT DEMI-CHASSE","	# <étroite> 300D"},
/* FF64 */ { "VIRGULE IDÉOGRAPHIQUE DEMI-CHASSE","	# <étroite> 3001"},
/* FF65 */ { "POINT MÉDIAN KATAKANA DEMI-CHASSE","	# <étroite> 30FB"},
/* FF66 */ { "CARACTÈRE KATAKANA WO DEMI-CHASSE","	# <étroite> 30F2"},
/* FF67 */ { "CARACTÈRE KATAKANA PETIT A DEMI-CHASSE","	# <étroite> 30A1"},
/* FF68 */ { "CARACTÈRE KATAKANA PETIT I DEMI-CHASSE","	# <étroite> 30A3"},
/* FF69 */ { "CARACTÈRE KATAKANA PETIT U DEMI-CHASSE","	# <étroite> 30A5"},
/* FF6A */ { "CARACTÈRE KATAKANA PETIT E DEMI-CHASSE","	# <étroite> 30A7"},
/* FF6B */ { "CARACTÈRE KATAKANA PETIT O DEMI-CHASSE","	# <étroite> 30A9"},
/* FF6C */ { "CARACTÈRE KATAKANA PETIT YA DEMI-CHASSE","	# <étroite> 30E3"},
/* FF6D */ { "CARACTÈRE KATAKANA PETIT YU DEMI-CHASSE","	# <étroite> 30E5"},
/* FF6E */ { "CARACTÈRE KATAKANA PETIT YO DEMI-CHASSE","	# <étroite> 30E7"},
/* FF6F */ { "CARACTÈRE KATAKANA PETIT TU DEMI-CHASSE","	# <étroite> 30C3"},
/* FF70 */ { "MARQUE KATAKANA-HIRAGANA DE SON PROLONGÉ DEMI-CHASSE","	# <étroite> 30FC"},
/* FF71 */ { "CARACTÈRE KATAKANA A DEMI-CHASSE","	# <étroite> 30A2"},
/* FF72 */ { "CARACTÈRE KATAKANA I DEMI-CHASSE","	# <étroite> 30A4"},
/* FF73 */ { "CARACTÈRE KATAKANA U DEMI-CHASSE","	# <étroite> 30A6"},
/* FF74 */ { "CARACTÈRE KATAKANA E DEMI-CHASSE","	# <étroite> 30A8"},
/* FF75 */ { "CARACTÈRE KATAKANA O DEMI-CHASSE","	# <étroite> 30AA"},
/* FF76 */ { "CARACTÈRE KATAKANA KA DEMI-CHASSE","	# <étroite> 30AB"},
/* FF77 */ { "CARACTÈRE KATAKANA KI DEMI-CHASSE","	# <étroite> 30AD"},
/* FF78 */ { "CARACTÈRE KATAKANA KU DEMI-CHASSE","	# <étroite> 30AF"},
/* FF79 */ { "CARACTÈRE KATAKANA KE DEMI-CHASSE","	# <étroite> 30B1"},
/* FF7A */ { "CARACTÈRE KATAKANA KO DEMI-CHASSE","	# <étroite> 30B3"},
/* FF7B */ { "CARACTÈRE KATAKANA SA DEMI-CHASSE","	# <étroite> 30B5"},
/* FF7C */ { "CARACTÈRE KATAKANA SI DEMI-CHASSE","	# <étroite> 30B7"},
/* FF7D */ { "CARACTÈRE KATAKANA SU DEMI-CHASSE","	# <étroite> 30B9"},
/* FF7E */ { "CARACTÈRE KATAKANA SE DEMI-CHASSE","	# <étroite> 30BB"},
/* FF7F */ { "CARACTÈRE KATAKANA SO DEMI-CHASSE","	# <étroite> 30BD"},
/* FF80 */ { "CARACTÈRE KATAKANA TA DEMI-CHASSE","	# <étroite> 30BF"},
/* FF81 */ { "CARACTÈRE KATAKANA TI DEMI-CHASSE","	# <étroite> 30C1"},
/* FF82 */ { "CARACTÈRE KATAKANA TU DEMI-CHASSE","	# <étroite> 30C4"},
/* FF83 */ { "CARACTÈRE KATAKANA TE DEMI-CHASSE","	# <étroite> 30C6"},
/* FF84 */ { "CARACTÈRE KATAKANA TO DEMI-CHASSE","	# <étroite> 30C8"},
/* FF85 */ { "CARACTÈRE KATAKANA NA DEMI-CHASSE","	# <étroite> 30CA"},
/* FF86 */ { "CARACTÈRE KATAKANA NI DEMI-CHASSE","	# <étroite> 30CB"},
/* FF87 */ { "CARACTÈRE KATAKANA NU DEMI-CHASSE","	# <étroite> 30CC"},
/* FF88 */ { "CARACTÈRE KATAKANA NE DEMI-CHASSE","	# <étroite> 30CD"},
/* FF89 */ { "CARACTÈRE KATAKANA NO DEMI-CHASSE","	# <étroite> 30CE"},
/* FF8A */ { "CARACTÈRE KATAKANA HA DEMI-CHASSE","	# <étroite> 30CF"},
/* FF8B */ { "CARACTÈRE KATAKANA HI DEMI-CHASSE","	# <étroite> 30D2"},
/* FF8C */ { "CARACTÈRE KATAKANA HU DEMI-CHASSE","	# <étroite> 30D5"},
/* FF8D */ { "CARACTÈRE KATAKANA HE DEMI-CHASSE","	# <étroite> 30D8"},
/* FF8E */ { "CARACTÈRE KATAKANA HO DEMI-CHASSE","	# <étroite> 30DB"},
/* FF8F */ { "CARACTÈRE KATAKANA MA DEMI-CHASSE","	# <étroite> 30DE"},
/* FF90 */ { "CARACTÈRE KATAKANA MI DEMI-CHASSE","	# <étroite> 30DF"},
/* FF91 */ { "CARACTÈRE KATAKANA MU DEMI-CHASSE","	# <étroite> 30E0"},
/* FF92 */ { "CARACTÈRE KATAKANA ME DEMI-CHASSE","	# <étroite> 30E1"},
/* FF93 */ { "CARACTÈRE KATAKANA MO DEMI-CHASSE","	# <étroite> 30E2"},
/* FF94 */ { "CARACTÈRE KATAKANA YA DEMI-CHASSE","	# <étroite> 30E4"},
/* FF95 */ { "CARACTÈRE KATAKANA YU DEMI-CHASSE","	# <étroite> 30E6"},
/* FF96 */ { "CARACTÈRE KATAKANA YO DEMI-CHASSE","	# <étroite> 30E8"},
/* FF97 */ { "CARACTÈRE KATAKANA RA DEMI-CHASSE","	# <étroite> 30E9"},
/* FF98 */ { "CARACTÈRE KATAKANA RI DEMI-CHASSE","	# <étroite> 30EA"},
/* FF99 */ { "CARACTÈRE KATAKANA RU DEMI-CHASSE","	# <étroite> 30EB"},
/* FF9A */ { "CARACTÈRE KATAKANA RE DEMI-CHASSE","	# <étroite> 30EC"},
/* FF9B */ { "CARACTÈRE KATAKANA RO DEMI-CHASSE","	# <étroite> 30ED"},
/* FF9C */ { "CARACTÈRE KATAKANA WA DEMI-CHASSE","	# <étroite> 30EF"},
/* FF9D */ { "CARACTÈRE KATAKANA N DEMI-CHASSE","	# <étroite> 30F3"},
/* FF9E */ { "MARQUE KATAKANA DE SON VOISÉ DEMI-CHASSE","	# <étroite> 3099"},
/* FF9F */ { "MARQUE KATAKANA DE SON SEMI-VOISÉ DEMI-CHASSE","	# <étroite> 309A"},
/* FFA0 */ { "BOURRE HANGÛL DEMI-CHASSE","	# <étroite> 3164"},
/* FFA1 */ { "LETTRE HANGÛL KIYOK DEMI-CHASSE","	# <étroite> 3131"},
/* FFA2 */ { "LETTRE HANGÛL SSANGKIYOK DEMI-CHASSE","	# <étroite> 3132"},
/* FFA3 */ { "LETTRE HANGÛL KIYOK-SIÔS DEMI-CHASSE","	# <étroite> 3133"},
/* FFA4 */ { "LETTRE HANGÛL NIÛN DEMI-CHASSE","	# <étroite> 3134"},
/* FFA5 */ { "LETTRE HANGÛL NIÛN-TCHIÛTCH DEMI-CHASSE","	# <étroite> 3135"},
/* FFA6 */ { "LETTRE HANGÛL NIÛN-HIÛH DEMI-CHASSE","	# <étroite> 3136"},
/* FFA7 */ { "LETTRE HANGÛL TIKÛT DEMI-CHASSE","	# <étroite> 3137"},
/* FFA8 */ { "LETTRE HANGÛL SSANGTIKÛT DEMI-CHASSE","	# <étroite> 3138"},
/* FFA9 */ { "LETTRE HANGÛL RIÛL DEMI-CHASSE","	# <étroite> 3139"},
/* FFAA */ { "LETTRE HANGÛL RIÛL-KIYOK DEMI-CHASSE","	# <étroite> 313A"},
/* FFAB */ { "LETTRE HANGÛL RIÛL-MIÛM DEMI-CHASSE","	# <étroite> 313B"},
/* FFAC */ { "LETTRE HANGÛL RIÛL-PIÛP DEMI-CHASSE","	# <étroite> 313C"},
/* FFAD */ { "LETTRE HANGÛL RIÛL-SIÔS DEMI-CHASSE","	# <étroite> 313D"},
/* FFAE */ { "LETTRE HANGÛL RIÛL-T'IÛT' DEMI-CHASSE","	# <étroite> 313E"},
/* FFAF */ { "LETTRE HANGÛL RIÛL-P'IÛP' DEMI-CHASSE","	# <étroite> 313F"},
/* FFB0 */ { "LETTRE HANGÛL RIÛL-HIÛH DEMI-CHASSE","	# <étroite> 3140"},
/* FFB1 */ { "LETTRE HANGÛL MIÛM DEMI-CHASSE","	# <étroite> 3141"},
/* FFB2 */ { "LETTRE HANGÛL PIÛP DEMI-CHASSE","	# <étroite> 3142"},
/* FFB3 */ { "LETTRE HANGÛL SSANGPIÛP DEMI-CHASSE","	# <étroite> 3143"},
/* FFB4 */ { "LETTRE HANGÛL PIÛP-SIÔS DEMI-CHASSE","	# <étroite> 3144"},
/* FFB5 */ { "LETTRE HANGÛL SIÔS DEMI-CHASSE","	# <étroite> 3145"},
/* FFB6 */ { "LETTRE HANGÛL SSANGSIÔS DEMI-CHASSE","	# <étroite> 3146"},
/* FFB7 */ { "LETTRE HANGÛL IÛNG DEMI-CHASSE","	# <étroite> 3147"},
/* FFB8 */ { "LETTRE HANGÛL TCHIÛTCH DEMI-CHASSE","	# <étroite> 3148"},
/* FFB9 */ { "LETTRE HANGÛL SSANGTCHIÛTCH DEMI-CHASSE","	# <étroite> 3149"},
/* FFBA */ { "LETTRE HANGÛL TCH'IÛTCH' DEMI-CHASSE","	# <étroite> 314A"},
/* FFBB */ { "LETTRE HANGÛL K'IÛK' DEMI-CHASSE","	# <étroite> 314B"},
/* FFBC */ { "LETTRE HANGÛL T'IÛT' DEMI-CHASSE","	# <étroite> 314C"},
/* FFBD */ { "LETTRE HANGÛL P'IÛP' DEMI-CHASSE","	# <étroite> 314D"},
/* FFBE */ { "LETTRE HANGÛL HIÛH DEMI-CHASSE","	# <étroite> 314E"},
/* FFBF */ { NULL,NULL},
/* FFC0 */ { NULL,NULL},
/* FFC1 */ { NULL,NULL},
/* FFC2 */ { "LETTRE HANGÛL A DEMI-CHASSE","	# <étroite> 314F"},
/* FFC3 */ { "LETTRE HANGÛL È DEMI-CHASSE","	# <étroite> 3150"},
/* FFC4 */ { "LETTRE HANGÛL YA DEMI-CHASSE","	# <étroite> 3151"},
/* FFC5 */ { "LETTRE HANGÛL YÈ DEMI-CHASSE","	# <étroite> 3152"},
/* FFC6 */ { "LETTRE HANGÛL O DEMI-CHASSE","	# <étroite> 3153"},
/* FFC7 */ { "LETTRE HANGÛL É DEMI-CHASSE","	# <étroite> 3154"},
/* FFC8 */ { NULL,NULL},
/* FFC9 */ { NULL,NULL},
/* FFCA */ { "LETTRE HANGÛL YO DEMI-CHASSE","	# <étroite> 3155"},
/* FFCB */ { "LETTRE HANGÛL YÉ DEMI-CHASSE","	# <étroite> 3156"},
/* FFCC */ { "LETTRE HANGÛL Ô DEMI-CHASSE","	# <étroite> 3157"},
/* FFCD */ { "LETTRE HANGÛL WA DEMI-CHASSE","	# <étroite> 3158"},
/* FFCE */ { "LETTRE HANGÛL WÈ DEMI-CHASSE","	# <étroite> 3159"},
/* FFCF */ { "LETTRE HANGÛL EU DEMI-CHASSE","	# <étroite> 315A"},
/* FFD0 */ { NULL,NULL},
/* FFD1 */ { NULL,NULL},
/* FFD2 */ { "LETTRE HANGÛL YÔ DEMI-CHASSE","	# <étroite> 315B"},
/* FFD3 */ { "LETTRE HANGÛL OU DEMI-CHASSE","	# <étroite> 315C"},
/* FFD4 */ { "LETTRE HANGÛL WO DEMI-CHASSE","	# <étroite> 315D"},
/* FFD5 */ { "LETTRE HANGÛL WÉ DEMI-CHASSE","	# <étroite> 315E"},
/* FFD6 */ { "LETTRE HANGÛL WI DEMI-CHASSE","	# <étroite> 315F"},
/* FFD7 */ { "LETTRE HANGÛL YOU DEMI-CHASSE","	# <étroite> 3160"},
/* FFD8 */ { NULL,NULL},
/* FFD9 */ { NULL,NULL},
/* FFDA */ { "LETTRE HANGÛL Û DEMI-CHASSE","	# <étroite> 3161"},
/* FFDB */ { "LETTRE HANGÛL ÛI DEMI-CHASSE","	# <étroite> 3162"},
/* FFDC */ { "LETTRE HANGÛL I DEMI-CHASSE","	# <étroite> 3163"},
/* FFDD */ { NULL,NULL},
/* FFDE */ { NULL,NULL},
/* FFDF */ { NULL,NULL},
/* FFE0 */ { "SYMBOLE CENTIME PLEINE CHASSE","	# <large> 00A2"},
/* FFE1 */ { "SYMBOLE LIVRE PLEINE CHASSE","	# <large> 00A3"},
/* FFE2 */ { "SIGNE NÉGATION PLEINE CHASSE","	# <large> 00AC"},
/* FFE3 */ { "MACRON PLEINE CHASSE","	* parfois traité comme un tiret en chef pleine chasse\n"
	"	x (tiret haut - 203E)\n"
	"	# <large> 00AF"},
/* FFE4 */ { "BARRE BRISÉE PLEINE CHASSE","	# <large> 00A6"},
/* FFE5 */ { "SYMBOLE YEN PLEINE CHASSE","	# <large> 00A5"},
/* FFE6 */ { "SYMBOLE WON PLEINE CHASSE","	# <large> 20A9"},
/* FFE7 */ { NULL,NULL},
/* FFE8 */ { "LIGNE VERTICALE MINCE DEMI-CHASSE","	# <étroite> 2502"},
/* FFE9 */ { "FLÈCHE VERS LA GAUCHE DEMI-CHASSE","	# <étroite> 2190"},
/* FFEA */ { "FLÈCHE VERS LE HAUT DEMI-CHASSE","	# <étroite> 2191"},
/* FFEB */ { "FLÈCHE VERS LA DROITE DEMI-CHASSE","	# <étroite> 2192"},
/* FFEC */ { "FLÈCHE VERS LE BAS DEMI-CHASSE","	# <étroite> 2193"},
/* FFED */ { "CARRÉ NOIR DEMI-CHASSE","	# <étroite> 25A0"},
/* FFEE */ { "CERCLE BLANC DEMI-CHASSE","	# <étroite> 25CB"},
/* FFEF */ { NULL,NULL},
/* FFF0 */ { NULL,NULL},
/* FFF1 */ { NULL,NULL},
/* FFF2 */ { NULL,NULL},
/* FFF3 */ { NULL,NULL},
/* FFF4 */ { NULL,NULL},
/* FFF5 */ { NULL,NULL},
/* FFF6 */ { NULL,NULL},
/* FFF7 */ { NULL,NULL},
/* FFF8 */ { NULL,NULL},
/* FFF9 */ { "ANCRE D'ANNOTATION INTERLINÉAIRE","	* indique le début d'un texte annoté"},
/* FFFA */ { "SÉPARATEUR D'ANNOTATION INTERLINÉAIRE","	* indique le début des caractères d'annotation"},
/* FFFB */ { "TERMINATEUR D'ANNOTATION INTERLINÉAIRE","	* indique la fin du bloc d'annotation"},
/* FFFC */ { "CARACTÈRE DE REMPLACEMENT D'OBJET","	* utilisé dans un texte comme substitut d'un objet qui n'est pas spécifié par ailleurs"},
/* FFFD */ { "CARACTÈRE DE REMPLACEMENT","	* s'emploie pour remplacer un caractère entrant dont la valeur est inconnue ou qui ne peut pas être représenté en Unicode\n"
	"	* comparez l'utilisation de 001A en tant que caractère de commande indiquant la fonction de substitution\n"
	"	x (signe d'incertitude - 2BD1)\n"
	"	x (point d'interrogation encadré noir au blanc - 1FBC4)"},
/* FFFE */ { NULL,"	* peut servir à détecter l'ordre des octets (grand-boutien, petit-boutien), par contraste avec FEFF\n"
	"	x (indicateur d'ordre des octets - FEFF)"},
/* FFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_00[] = {
/* 10000 */ { "SYLLABE LINÉAIRE B B008 A",NULL},
/* 10001 */ { "SYLLABE LINÉAIRE B B038 E",NULL},
/* 10002 */ { "SYLLABE LINÉAIRE B B028 I",NULL},
/* 10003 */ { "SYLLABE LINÉAIRE B B061 O",NULL},
/* 10004 */ { "SYLLABE LINÉAIRE B B010 U",NULL},
/* 10005 */ { "SYLLABE LINÉAIRE B B001 DA",NULL},
/* 10006 */ { "SYLLABE LINÉAIRE B B045 DE",NULL},
/* 10007 */ { "SYLLABE LINÉAIRE B B007 DI",NULL},
/* 10008 */ { "SYLLABE LINÉAIRE B B014 DO",NULL},
/* 10009 */ { "SYLLABE LINÉAIRE B B051 DU",NULL},
/* 1000A */ { "SYLLABE LINÉAIRE B B057 JA",NULL},
/* 1000B */ { "SYLLABE LINÉAIRE B B046 JE",NULL},
/* 1000C */ { NULL,NULL},
/* 1000D */ { "SYLLABE LINÉAIRE B B036 JO",NULL},
/* 1000E */ { "SYLLABE LINÉAIRE B B065 JU","	= idéogramme B129 farine"},
/* 1000F */ { "SYLLABE LINÉAIRE B B077 KA",NULL},
/* 10010 */ { "SYLLABE LINÉAIRE B B044 KE",NULL},
/* 10011 */ { "SYLLABE LINÉAIRE B B067 KI",NULL},
/* 10012 */ { "SYLLABE LINÉAIRE B B070 KO",NULL},
/* 10013 */ { "SYLLABE LINÉAIRE B B081 KU",NULL},
/* 10014 */ { "SYLLABE LINÉAIRE B B080 MA",NULL},
/* 10015 */ { "SYLLABE LINÉAIRE B B013 ME",NULL},
/* 10016 */ { "SYLLABE LINÉAIRE B B073 MI",NULL},
/* 10017 */ { "SYLLABE LINÉAIRE B B015 MO",NULL},
/* 10018 */ { "SYLLABE LINÉAIRE B B023 MU","	= idéogramme B109 bœuf"},
/* 10019 */ { "SYLLABE LINÉAIRE B B006 NA",NULL},
/* 1001A */ { "SYLLABE LINÉAIRE B B024 NE",NULL},
/* 1001B */ { "SYLLABE LINÉAIRE B B030 NI","	= idéogramme B030 figues"},
/* 1001C */ { "SYLLABE LINÉAIRE B B052 NO",NULL},
/* 1001D */ { "SYLLABE LINÉAIRE B B055 NU",NULL},
/* 1001E */ { "SYLLABE LINÉAIRE B B003 PA",NULL},
/* 1001F */ { "SYLLABE LINÉAIRE B B072 PE",NULL},
/* 10020 */ { "SYLLABE LINÉAIRE B B039 PI",NULL},
/* 10021 */ { "SYLLABE LINÉAIRE B B011 PO",NULL},
/* 10022 */ { "SYLLABE LINÉAIRE B B050 PU",NULL},
/* 10023 */ { "SYLLABE LINÉAIRE B B016 QA",NULL},
/* 10024 */ { "SYLLABE LINÉAIRE B B078 QE",NULL},
/* 10025 */ { "SYLLABE LINÉAIRE B B021 QI","	= idéogramme B106 mouton"},
/* 10026 */ { "SYLLABE LINÉAIRE B B032 QO",NULL},
/* 10027 */ { NULL,NULL},
/* 10028 */ { "SYLLABE LINÉAIRE B B060 RA",NULL},
/* 10029 */ { "SYLLABE LINÉAIRE B B027 RE",NULL},
/* 1002A */ { "SYLLABE LINÉAIRE B B053 RI",NULL},
/* 1002B */ { "SYLLABE LINÉAIRE B B002 RO",NULL},
/* 1002C */ { "SYLLABE LINÉAIRE B B026 RU",NULL},
/* 1002D */ { "SYLLABE LINÉAIRE B B031 SA","	= idéogramme B031 lin"},
/* 1002E */ { "SYLLABE LINÉAIRE B B009 SE",NULL},
/* 1002F */ { "SYLLABE LINÉAIRE B B041 SI",NULL},
/* 10030 */ { "SYLLABE LINÉAIRE B B012 SO",NULL},
/* 10031 */ { "SYLLABE LINÉAIRE B B058 SU",NULL},
/* 10032 */ { "SYLLABE LINÉAIRE B B059 TA",NULL},
/* 10033 */ { "SYLLABE LINÉAIRE B B004 TE",NULL},
/* 10034 */ { "SYLLABE LINÉAIRE B B037 TI",NULL},
/* 10035 */ { "SYLLABE LINÉAIRE B B005 TO",NULL},
/* 10036 */ { "SYLLABE LINÉAIRE B B069 TU",NULL},
/* 10037 */ { "SYLLABE LINÉAIRE B B054 WA",NULL},
/* 10038 */ { "SYLLABE LINÉAIRE B B075 WE",NULL},
/* 10039 */ { "SYLLABE LINÉAIRE B B040 WI",NULL},
/* 1003A */ { "SYLLABE LINÉAIRE B B042 WO",NULL},
/* 1003B */ { NULL,NULL},
/* 1003C */ { "SYLLABE LINÉAIRE B B017 ZA",NULL},
/* 1003D */ { "SYLLABE LINÉAIRE B B074 ZE",NULL},
/* 1003E */ { NULL,NULL},
/* 1003F */ { "SYLLABE LINÉAIRE B B020 ZO",NULL},
/* 10040 */ { "SYLLABE LINÉAIRE B B025 A2",NULL},
/* 10041 */ { "SYLLABE LINÉAIRE B B043 A3",NULL},
/* 10042 */ { "SYLLABE LINÉAIRE B B085 AU","	= idéogramme B108 porc"},
/* 10043 */ { "SYLLABE LINÉAIRE B B071 DWE",NULL},
/* 10044 */ { "SYLLABE LINÉAIRE B B090 DWO",NULL},
/* 10045 */ { "SYLLABE LINÉAIRE B B048 NWA",NULL},
/* 10046 */ { "SYLLABE LINÉAIRE B B029 PU2",NULL},
/* 10047 */ { "SYLLABE LINÉAIRE B B062 PTE",NULL},
/* 10048 */ { "SYLLABE LINÉAIRE B B076 RA2",NULL},
/* 10049 */ { "SYLLABE LINÉAIRE B B033 RA3","	= idéogramme B144 safran"},
/* 1004A */ { "SYLLABE LINÉAIRE B B068 RO2",NULL},
/* 1004B */ { "SYLLABE LINÉAIRE B B066 TA2",NULL},
/* 1004C */ { "SYLLABE LINÉAIRE B B087 TWE",NULL},
/* 1004D */ { "SYLLABE LINÉAIRE B B091 TWO",NULL},
/* 1004E */ { NULL,NULL},
/* 1004F */ { NULL,NULL},
/* 10050 */ { "SYMBOLE LINÉAIRE B B018",NULL},
/* 10051 */ { "SYMBOLE LINÉAIRE B B019",NULL},
/* 10052 */ { "SYMBOLE LINÉAIRE B B022","	= idéogramme B107 chèvre"},
/* 10053 */ { "SYMBOLE LINÉAIRE B B034",NULL},
/* 10054 */ { "SYMBOLE LINÉAIRE B B047",NULL},
/* 10055 */ { "SYMBOLE LINÉAIRE B B049",NULL},
/* 10056 */ { "SYMBOLE LINÉAIRE B B056",NULL},
/* 10057 */ { "SYMBOLE LINÉAIRE B B063",NULL},
/* 10058 */ { "SYMBOLE LINÉAIRE B B064",NULL},
/* 10059 */ { "SYMBOLE LINÉAIRE B B079",NULL},
/* 1005A */ { "SYMBOLE LINÉAIRE B B082",NULL},
/* 1005B */ { "SYMBOLE LINÉAIRE B B083",NULL},
/* 1005C */ { "SYMBOLE LINÉAIRE B B086",NULL},
/* 1005D */ { "SYMBOLE LINÉAIRE B B089",NULL},
/* 1005E */ { NULL,NULL},
/* 1005F */ { NULL,NULL},
/* 10060 */ { NULL,NULL},
/* 10061 */ { NULL,NULL},
/* 10062 */ { NULL,NULL},
/* 10063 */ { NULL,NULL},
/* 10064 */ { NULL,NULL},
/* 10065 */ { NULL,NULL},
/* 10066 */ { NULL,NULL},
/* 10067 */ { NULL,NULL},
/* 10068 */ { NULL,NULL},
/* 10069 */ { NULL,NULL},
/* 1006A */ { NULL,NULL},
/* 1006B */ { NULL,NULL},
/* 1006C */ { NULL,NULL},
/* 1006D */ { NULL,NULL},
/* 1006E */ { NULL,NULL},
/* 1006F */ { NULL,NULL},
/* 10070 */ { NULL,NULL},
/* 10071 */ { NULL,NULL},
/* 10072 */ { NULL,NULL},
/* 10073 */ { NULL,NULL},
/* 10074 */ { NULL,NULL},
/* 10075 */ { NULL,NULL},
/* 10076 */ { NULL,NULL},
/* 10077 */ { NULL,NULL},
/* 10078 */ { NULL,NULL},
/* 10079 */ { NULL,NULL},
/* 1007A */ { NULL,NULL},
/* 1007B */ { NULL,NULL},
/* 1007C */ { NULL,NULL},
/* 1007D */ { NULL,NULL},
/* 1007E */ { NULL,NULL},
/* 1007F */ { NULL,NULL},
/* 10080 */ { "IDÉOGRAMME LINÉAIRE B B100 HOMME",NULL},
/* 10081 */ { "IDÉOGRAMME LINÉAIRE B B102 FEMME",NULL},
/* 10082 */ { "IDÉOGRAMME LINÉAIRE B B104 CERF",NULL},
/* 10083 */ { "IDÉOGRAMME LINÉAIRE B B105 CHEVAL",NULL},
/* 10084 */ { "IDÉOGRAMME LINÉAIRE B B105F JUMENT",NULL},
/* 10085 */ { "IDÉOGRAMME LINÉAIRE B B105M ÉTALON",NULL},
/* 10086 */ { "IDÉOGRAMME LINÉAIRE B B106F BREBIS",NULL},
/* 10087 */ { "IDÉOGRAMME LINÉAIRE B B106M BÉLIER",NULL},
/* 10088 */ { "IDÉOGRAMME LINÉAIRE B B107F BIQUE",NULL},
/* 10089 */ { "IDÉOGRAMME LINÉAIRE B B10FM BOUC",NULL},
/* 1008A */ { "IDÉOGRAMME LINÉAIRE B B108F TRUIE",NULL},
/* 1008B */ { "IDÉOGRAMME LINÉAIRE B B108M VERRAT",NULL},
/* 1008C */ { "IDÉOGRAMME LINÉAIRE B B109F VACHE",NULL},
/* 1008D */ { "IDÉOGRAMME LINÉAIRE B B109M TAUREAU",NULL},
/* 1008E */ { "IDÉOGRAMME LINÉAIRE B B120 BLÉ",NULL},
/* 1008F */ { "IDÉOGRAMME LINÉAIRE B B121 ORGE",NULL},
/* 10090 */ { "IDÉOGRAMME LINÉAIRE B B122 OLIVE",NULL},
/* 10091 */ { "IDÉOGRAMME LINÉAIRE B B123 ÉPICE",NULL},
/* 10092 */ { "IDÉOGRAMME LINÉAIRE B B125 CYPERUS","	* cypéracées (laîches ou carex)"},
/* 10093 */ { "MONOGRAMME LINÉAIRE B B127 KAPO","	= fruit"},
/* 10094 */ { "MONOGRAMME LINÉAIRE B B128 KANAKO","	= safran"},
/* 10095 */ { "IDÉOGRAMME LINÉAIRE B B130 HUILE D'OLIVE",NULL},
/* 10096 */ { "IDÉOGRAMME LINÉAIRE B B131 VIN",NULL},
/* 10097 */ { "IDÉOGRAMME LINÉAIRE B B132",NULL},
/* 10098 */ { "MONOGRAMME LINÉAIRE B B133 AREPA","	= onguent"},
/* 10099 */ { "MONOGRAMME LINÉAIRE B B135 MERI","	= miel"},
/* 1009A */ { "IDÉOGRAMME LINÉAIRE B B140 BRONZE",NULL},
/* 1009B */ { "IDÉOGRAMME LINÉAIRE B B141 OR",NULL},
/* 1009C */ { "IDÉOGRAMME LINÉAIRE B B142",NULL},
/* 1009D */ { "IDÉOGRAMME LINÉAIRE B B145 LAINE",NULL},
/* 1009E */ { "IDÉOGRAMME LINÉAIRE B B146",NULL},
/* 1009F */ { "IDÉOGRAMME LINÉAIRE B B150",NULL},
/* 100A0 */ { "IDÉOGRAMME LINÉAIRE B B151 CORNE",NULL},
/* 100A1 */ { "IDÉOGRAMME LINÉAIRE B B152",NULL},
/* 100A2 */ { "IDÉOGRAMME LINÉAIRE B B153",NULL},
/* 100A3 */ { "IDÉOGRAMME LINÉAIRE B B154",NULL},
/* 100A4 */ { "MONOGRAMME LINÉAIRE B B156 TURO2","	= fromage"},
/* 100A5 */ { "IDÉOGRAMME LINÉAIRE B B157",NULL},
/* 100A6 */ { "IDÉOGRAMME LINÉAIRE B B158",NULL},
/* 100A7 */ { "IDÉOGRAMME LINÉAIRE B B159 TISSU",NULL},
/* 100A8 */ { "IDÉOGRAMME LINÉAIRE B B160",NULL},
/* 100A9 */ { "IDÉOGRAMME LINÉAIRE B B161",NULL},
/* 100AA */ { "IDÉOGRAMME LINÉAIRE B B162 TUNIQUE",NULL},
/* 100AB */ { "IDÉOGRAMME LINÉAIRE B B163 ARMURE",NULL},
/* 100AC */ { "IDÉOGRAMME LINÉAIRE B B164",NULL},
/* 100AD */ { "IDÉOGRAMME LINÉAIRE B B165",NULL},
/* 100AE */ { "IDÉOGRAMME LINÉAIRE B B166",NULL},
/* 100AF */ { "IDÉOGRAMME LINÉAIRE B B167",NULL},
/* 100B0 */ { "IDÉOGRAMME LINÉAIRE B B168",NULL},
/* 100B1 */ { "IDÉOGRAMME LINÉAIRE B B169",NULL},
/* 100B2 */ { "IDÉOGRAMME LINÉAIRE B B170",NULL},
/* 100B3 */ { "IDÉOGRAMME LINÉAIRE B B171",NULL},
/* 100B4 */ { "IDÉOGRAMME LINÉAIRE B B172",NULL},
/* 100B5 */ { "IDÉOGRAMME LINÉAIRE B B173 MOIS",NULL},
/* 100B6 */ { "IDÉOGRAMME LINÉAIRE B B174",NULL},
/* 100B7 */ { "IDÉOGRAMME LINÉAIRE B B176 ARBRE",NULL},
/* 100B8 */ { "IDÉOGRAMME LINÉAIRE B B177",NULL},
/* 100B9 */ { "IDÉOGRAMME LINÉAIRE B B178",NULL},
/* 100BA */ { "IDÉOGRAMME LINÉAIRE B B179",NULL},
/* 100BB */ { "IDÉOGRAMME LINÉAIRE B B180",NULL},
/* 100BC */ { "IDÉOGRAMME LINÉAIRE B B181",NULL},
/* 100BD */ { "IDÉOGRAMME LINÉAIRE B B182",NULL},
/* 100BE */ { "IDÉOGRAMME LINÉAIRE B B183",NULL},
/* 100BF */ { "IDÉOGRAMME LINÉAIRE B B184","	* la forme de cet idéogramme n'est connue que partiellement"},
/* 100C0 */ { "IDÉOGRAMME LINÉAIRE B B185",NULL},
/* 100C1 */ { "IDÉOGRAMME LINÉAIRE B B189",NULL},
/* 100C2 */ { "IDÉOGRAMME LINÉAIRE B B190",NULL},
/* 100C3 */ { "IDÉOGRAMME LINÉAIRE B B191 CASQUE",NULL},
/* 100C4 */ { "IDÉOGRAMME LINÉAIRE B B220 TABOURET",NULL},
/* 100C5 */ { "IDÉOGRAMME LINÉAIRE B B225 BAIGNOIRE",NULL},
/* 100C6 */ { "IDÉOGRAMME LINÉAIRE B B230 LANCE",NULL},
/* 100C7 */ { "IDÉOGRAMME LINÉAIRE B B231 FLÈCHE",NULL},
/* 100C8 */ { "IDÉOGRAMME LINÉAIRE B B232",NULL},
/* 100C9 */ { "IDÉOGRAMME LINÉAIRE B B233 POIGNARD","	= pugio"},
/* 100CA */ { "IDÉOGRAMME LINÉAIRE B B234",NULL},
/* 100CB */ { "IDÉOGRAMME LINÉAIRE B B236","	= « gupio », poignard inversé"},
/* 100CC */ { "IDÉOGRAMME LINÉAIRE B B240 CHAR AVEC ROUES",NULL},
/* 100CD */ { "IDÉOGRAMME LINÉAIRE B B241 CHAR SANS ROUES",NULL},
/* 100CE */ { "IDÉOGRAMME LINÉAIRE B B242 BÂTI DE CHAR",NULL},
/* 100CF */ { "IDÉOGRAMME LINÉAIRE B B243 ROUE",NULL},
/* 100D0 */ { "IDÉOGRAMME LINÉAIRE B B245",NULL},
/* 100D1 */ { "IDÉOGRAMME LINÉAIRE B B246",NULL},
/* 100D2 */ { "MONOGRAMME LINÉAIRE B B247 DIPTE",NULL},
/* 100D3 */ { "IDÉOGRAMME LINÉAIRE B B248",NULL},
/* 100D4 */ { "IDÉOGRAMME LINÉAIRE B B249",NULL},
/* 100D5 */ { "IDÉOGRAMME LINÉAIRE B B251","	* la forme de cet idéogramme n'est connue que partiellement"},
/* 100D6 */ { "IDÉOGRAMME LINÉAIRE B B252","	* la forme de cet idéogramme n'est connue que partiellement"},
/* 100D7 */ { "IDÉOGRAMME LINÉAIRE B B253",NULL},
/* 100D8 */ { "IDÉOGRAMME LINÉAIRE B B254 DARD",NULL},
/* 100D9 */ { "IDÉOGRAMME LINÉAIRE B B255",NULL},
/* 100DA */ { "IDÉOGRAMME LINÉAIRE B B256",NULL},
/* 100DB */ { "IDÉOGRAMME LINÉAIRE B B257",NULL},
/* 100DC */ { "IDÉOGRAMME LINÉAIRE B B258",NULL},
/* 100DD */ { "IDÉOGRAMME LINÉAIRE B B259",NULL},
/* 100DE */ { "IDÉOGRAMME LINÉAIRE B VASE B155",NULL},
/* 100DF */ { "IDÉOGRAMME LINÉAIRE B VASE B200",NULL},
/* 100E0 */ { "IDÉOGRAMME LINÉAIRE B VASE B201",NULL},
/* 100E1 */ { "IDÉOGRAMME LINÉAIRE B VASE B202",NULL},
/* 100E2 */ { "IDÉOGRAMME LINÉAIRE B VASE B203",NULL},
/* 100E3 */ { "IDÉOGRAMME LINÉAIRE B VASE B204",NULL},
/* 100E4 */ { "IDÉOGRAMME LINÉAIRE B VASE B205",NULL},
/* 100E5 */ { "IDÉOGRAMME LINÉAIRE B VASE B206",NULL},
/* 100E6 */ { "IDÉOGRAMME LINÉAIRE B VASE B207",NULL},
/* 100E7 */ { "IDÉOGRAMME LINÉAIRE B VASE B208",NULL},
/* 100E8 */ { "IDÉOGRAMME LINÉAIRE B VASE B209","	x (amphore - 1F3FA)"},
/* 100E9 */ { "IDÉOGRAMME LINÉAIRE B VASE B210",NULL},
/* 100EA */ { "IDÉOGRAMME LINÉAIRE B VASE B211",NULL},
/* 100EB */ { "IDÉOGRAMME LINÉAIRE B VASE B212",NULL},
/* 100EC */ { "IDÉOGRAMME LINÉAIRE B VASE B213",NULL},
/* 100ED */ { "IDÉOGRAMME LINÉAIRE B VASE B214",NULL},
/* 100EE */ { "IDÉOGRAMME LINÉAIRE B VASE B215",NULL},
/* 100EF */ { "IDÉOGRAMME LINÉAIRE B VASE B216",NULL},
/* 100F0 */ { "IDÉOGRAMME LINÉAIRE B VASE B217",NULL},
/* 100F1 */ { "IDÉOGRAMME LINÉAIRE B VASE B218",NULL},
/* 100F2 */ { "IDÉOGRAMME LINÉAIRE B VASE B219",NULL},
/* 100F3 */ { "IDÉOGRAMME LINÉAIRE B VASE B221",NULL},
/* 100F4 */ { "IDÉOGRAMME LINÉAIRE B VASE B222",NULL},
/* 100F5 */ { "IDÉOGRAMME LINÉAIRE B VASE B226",NULL},
/* 100F6 */ { "IDÉOGRAMME LINÉAIRE B VASE B227",NULL},
/* 100F7 */ { "IDÉOGRAMME LINÉAIRE B VASE B228",NULL},
/* 100F8 */ { "IDÉOGRAMME LINÉAIRE B VASE B229",NULL},
/* 100F9 */ { "IDÉOGRAMME LINÉAIRE B VASE B250",NULL},
/* 100FA */ { "IDÉOGRAMME LINÉAIRE B VASE B305","	* la forme de cet idéogramme n'est connue que partiellement"},
/* 100FB */ { NULL,NULL},
/* 100FC */ { NULL,NULL},
/* 100FD */ { NULL,NULL},
/* 100FE */ { NULL,NULL},
/* 100FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_01[] = {
/* 10100 */ { "TRAIT ÉGÉEN SÉPARATEUR DE MOTS",NULL},
/* 10101 */ { "POINT ÉGÉEN SÉPARATEUR DE MOTS",NULL},
/* 10102 */ { "COCHE ÉGÉENNE",NULL},
/* 10103 */ { NULL,NULL},
/* 10104 */ { NULL,NULL},
/* 10105 */ { NULL,NULL},
/* 10106 */ { NULL,NULL},
/* 10107 */ { "NOMBRE ÉGÉEN UN",NULL},
/* 10108 */ { "NOMBRE ÉGÉEN DEUX",NULL},
/* 10109 */ { "NOMBRE ÉGÉEN TROIS",NULL},
/* 1010A */ { "NOMBRE ÉGÉEN QUATRE",NULL},
/* 1010B */ { "NOMBRE ÉGÉEN CINQ",NULL},
/* 1010C */ { "NOMBRE ÉGÉEN SIX",NULL},
/* 1010D */ { "NOMBRE ÉGÉEN SEPT",NULL},
/* 1010E */ { "NOMBRE ÉGÉEN HUIT",NULL},
/* 1010F */ { "NOMBRE ÉGÉEN NEUF",NULL},
/* 10110 */ { "NOMBRE ÉGÉEN DIX",NULL},
/* 10111 */ { "NOMBRE ÉGÉEN VINGT",NULL},
/* 10112 */ { "NOMBRE ÉGÉEN TRENTE",NULL},
/* 10113 */ { "NOMBRE ÉGÉEN QUARANTE",NULL},
/* 10114 */ { "NOMBRE ÉGÉEN CINQUANTE",NULL},
/* 10115 */ { "NOMBRE ÉGÉEN SOIXANTE",NULL},
/* 10116 */ { "NOMBRE ÉGÉEN SOIXANTE-DIX","	= nombre égéen septante"},
/* 10117 */ { "NOMBRE ÉGÉEN QUATRE-VINGTS","	= nombre égéen huitante"},
/* 10118 */ { "NOMBRE ÉGÉEN QUATRE-VINGT-DIX","	= nombre égéen nonante"},
/* 10119 */ { "NOMBRE ÉGÉEN CENT",NULL},
/* 1011A */ { "NOMBRE ÉGÉEN DEUX CENTS",NULL},
/* 1011B */ { "NOMBRE ÉGÉEN TROIS CENTS",NULL},
/* 1011C */ { "NOMBRE ÉGÉEN QUATRE CENTS",NULL},
/* 1011D */ { "NOMBRE ÉGÉEN CINQ CENTS",NULL},
/* 1011E */ { "NOMBRE ÉGÉEN SIX CENTS",NULL},
/* 1011F */ { "NOMBRE ÉGÉEN SEPT CENTS",NULL},
/* 10120 */ { "NOMBRE ÉGÉEN HUIT CENTS",NULL},
/* 10121 */ { "NOMBRE ÉGÉEN NEUF CENTS",NULL},
/* 10122 */ { "NOMBRE ÉGÉEN MILLE",NULL},
/* 10123 */ { "NOMBRE ÉGÉEN DEUX MILLE",NULL},
/* 10124 */ { "NOMBRE ÉGÉEN TROIS MILLE",NULL},
/* 10125 */ { "NOMBRE ÉGÉEN QUATRE MILLE",NULL},
/* 10126 */ { "NOMBRE ÉGÉEN CINQ MILLE",NULL},
/* 10127 */ { "NOMBRE ÉGÉEN SIX MILLE",NULL},
/* 10128 */ { "NOMBRE ÉGÉEN SEPT MILLE",NULL},
/* 10129 */ { "NOMBRE ÉGÉEN HUIT MILLE",NULL},
/* 1012A */ { "NOMBRE ÉGÉEN NEUF MILLE",NULL},
/* 1012B */ { "NOMBRE ÉGÉEN DIX MILLE",NULL},
/* 1012C */ { "NOMBRE ÉGÉEN VINGT MILLE",NULL},
/* 1012D */ { "NOMBRE ÉGÉEN TRENTE MILLE",NULL},
/* 1012E */ { "NOMBRE ÉGÉEN QUARANTE MILLE",NULL},
/* 1012F */ { "NOMBRE ÉGÉEN CINQUANTE MILLE",NULL},
/* 10130 */ { "NOMBRE ÉGÉEN SOIXANTE MILLE",NULL},
/* 10131 */ { "NOMBRE ÉGÉEN SOIXANTE-DIX MILLE","	= nombre égéen septante mille"},
/* 10132 */ { "NOMBRE ÉGÉEN QUATRE-VINGT MILLE","	= nombre égéen huitante mille"},
/* 10133 */ { "NOMBRE ÉGÉEN QUATRE-VINGT-DIX MILLE","	= nombre égéen nonante mille"},
/* 10134 */ { NULL,NULL},
/* 10135 */ { NULL,NULL},
/* 10136 */ { NULL,NULL},
/* 10137 */ { "UNITÉ ÉGÉENNE DE POIDS DE BASE",NULL},
/* 10138 */ { "PREMIÈRE SOUS-UNITÉ ÉGÉENNE DE POIDS",NULL},
/* 10139 */ { "DEUXIÈME SOUS-UNITÉ ÉGÉENNE DE POIDS",NULL},
/* 1013A */ { "TROISIÈME SOUS-UNITÉ ÉGÉENNE DE POIDS",NULL},
/* 1013B */ { "QUATRIÈME SOUS-UNITÉ ÉGÉENNE DE POIDS",NULL},
/* 1013C */ { "PREMIÈRE SOUS-UNITÉ ÉGÉENNE DE MESURE SOLIDE",NULL},
/* 1013D */ { "PREMIÈRE SOUS-UNITÉ ÉGÉENNE DE MESURE LIQUIDE",NULL},
/* 1013E */ { "DEUXIÈME SOUS-UNITÉ ÉGÉENNE DE MESURE",NULL},
/* 1013F */ { "TROISIÈME SOUS-UNITÉ ÉGÉENNE DE MESURE",NULL},
/* 10140 */ { "UN QUART ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10141 */ { "UNE MOITIÉ ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10142 */ { "UN DRACHME ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10143 */ { "CINQ ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10144 */ { "CINQUANTE ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10145 */ { "CINQ CENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10146 */ { "CINQ MILLE ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10147 */ { "CINQUANTE MILLE ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10148 */ { "CINQ TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10149 */ { "DIX TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 1014A */ { "CINQUANTE TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 1014B */ { "CENT TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 1014C */ { "CINQ CENTS TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 1014D */ { "MILLE TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 1014E */ { "CINQ MILLE TALENTS ACROPHONIQUE GREC ATTIQUE",NULL},
/* 1014F */ { "CINQ STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10150 */ { "DIX STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10151 */ { "CINQUANTE STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10152 */ { "CENT STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10153 */ { "CINQ CENTS STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10154 */ { "MILLE STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10155 */ { "DIX MILLE STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10156 */ { "CINQUANTE MILLE STATÈRES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10157 */ { "DIX MINES ACROPHONIQUE GREC ATTIQUE",NULL},
/* 10158 */ { "UN PLÈTHRE ACROPHONIQUE GREC HÉRÉEN",NULL},
/* 10159 */ { "UN ACROPHONIQUE GREC THESPIEN",NULL},
/* 1015A */ { "UN ACROPHONIQUE GREC HERMIONIEN",NULL},
/* 1015B */ { "DEUX ACROPHONIQUE GREC ÉPIDAURIEN","	x (deux-points en capitale - 205A)"},
/* 1015C */ { "DEUX ACROPHONIQUE GREC THESPIEN",NULL},
/* 1015D */ { "DEUX DRACHMES ACROPHONIQUE GREC CYRÉNAÏQUE",NULL},
/* 1015E */ { "DEUX DRACHMES ACROPHONIQUE GREC ÉPIDAURIEN","	* s'étend jusqu'à la ligne de hauteur des capitales, contrairement à 10111\n"
	"	x (nombre égéen vingt - 10111)"},
/* 1015F */ { "CINQ ACROPHONIQUE GREC TRÉZÉNIEN",NULL},
/* 10160 */ { "DIX ACROPHONIQUE GREC TRÉZÉNIEN",NULL},
/* 10161 */ { "DIX ACROPHONIQUE GREC TRÉZÉNIEN VARIANTE",NULL},
/* 10162 */ { "DIX ACROPHONIQUE GREC HERMIONIEN",NULL},
/* 10163 */ { "DIX ACROPHONIQUE GREC MESSÉNIEN",NULL},
/* 10164 */ { "DIX ACROPHONIQUE GREC THESPIEN",NULL},
/* 10165 */ { "TRENTE ACROPHONIQUE GREC THESPIEN",NULL},
/* 10166 */ { "CINQUANTE ACROPHONIQUE GREC TRÉZÉNIEN",NULL},
/* 10167 */ { "CINQUANTE ACROPHONIQUE GREC TRÉZÉNIEN VARIANTE",NULL},
/* 10168 */ { "CINQUANTE ACROPHONIQUE GREC HERMIONIEN",NULL},
/* 10169 */ { "CINQUANTE ACROPHONIQUE GREC THESPIEN",NULL},
/* 1016A */ { "CENT ACROPHONIQUE GREC THESPIEN",NULL},
/* 1016B */ { "TROIS CENTS ACROPHONIQUE GREC THESPIEN",NULL},
/* 1016C */ { "CINQ CENTS ACROPHONIQUE GREC ÉPIDAURIEN",NULL},
/* 1016D */ { "CINQ CENTS ACROPHONIQUE GREC TRÉZÉNIEN",NULL},
/* 1016E */ { "CINQ CENTS ACROPHONIQUE GREC THESPIEN",NULL},
/* 1016F */ { "CINQ CENTS ACROPHONIQUE GREC CARYSTIEN",NULL},
/* 10170 */ { "CINQ CENTS ACROPHONIQUE GREC NAXIEN",NULL},
/* 10171 */ { "MILLE ACROPHONIQUE GREC THESPIEN",NULL},
/* 10172 */ { "CINQ MILLE ACROPHONIQUE GREC THESPIEN",NULL},
/* 10173 */ { "CINQ MINES ACROPHONIQUE GREC DELPHIEN",NULL},
/* 10174 */ { "CINQUANTE MINES ACROPHONIQUE GREC STRATIEN",NULL},
/* 10175 */ { "SYMBOLE GREC UN DEMI",NULL},
/* 10176 */ { "SYMBOLE GREC VARIANTE UN DEMI",NULL},
/* 10177 */ { "SYMBOLE GREC DEUX TIERS",NULL},
/* 10178 */ { "SYMBOLE GREC TROIS QUARTS",NULL},
/* 10179 */ { "SYMBOLE GREC ANNÉE",NULL},
/* 1017A */ { "SYMBOLE GREC TALENT",NULL},
/* 1017B */ { "SYMBOLE GREC DRACHME",NULL},
/* 1017C */ { "SYMBOLE GREC OBOLE",NULL},
/* 1017D */ { "SYMBOLE GREC DEUX OBOLES",NULL},
/* 1017E */ { "SYMBOLE GREC TROIS OBOLES",NULL},
/* 1017F */ { "SYMBOLE GREC QUATRE OBOLES",NULL},
/* 10180 */ { "SYMBOLE GREC CINQ OBOLES",NULL},
/* 10181 */ { "SYMBOLE GREC MÉTRÈTE",NULL},
/* 10182 */ { "SYMBOLE GREC DE BASE KYATHOS",NULL},
/* 10183 */ { "SYMBOLE GREC LITRE","	= litra"},
/* 10184 */ { "SYMBOLE GREC ONCE","	= ounkia"},
/* 10185 */ { "SYMBOLE GREC SETIER","	= xestes"},
/* 10186 */ { "SYMBOLE GREC ARTABE",NULL},
/* 10187 */ { "SYMBOLE GREC AROURE",NULL},
/* 10188 */ { "SYMBOLE GREC SCRUPULE","	= gramma"},
/* 10189 */ { "SYMBOLE GREC DE BASE TRYBLION",NULL},
/* 1018A */ { "SYMBOLE GREC ZÉRO",NULL},
/* 1018B */ { "SYMBOLE GREC UN QUART",NULL},
/* 1018C */ { "SYMBOLE GREC SINUSOÏDE","	* désigne l'année"},
/* 1018D */ { "SYMBOLE GREC D'INDICTION","	* mesure du temps"},
/* 1018E */ { "SYMBOLE NOMISMA","	* symbole monétaire et marqueur de poids"},
/* 1018F */ { NULL,NULL},
/* 10190 */ { "SYMBOLE ROMAIN SEXTANT","	x (signe égal - 003D)"},
/* 10191 */ { "SYMBOLE ROMAIN ONCE","	x (trait d'union-signe moins - 002D)"},
/* 10192 */ { "SYMBOLE ROMAIN DEMI-ONCE","	x (symbole livre - 00A3)"},
/* 10193 */ { "SYMBOLE ROMAIN SEXTULE","	x (lettre majuscule cyrillique dzé réfléchi - A644)"},
/* 10194 */ { "SYMBOLE ROMAIN MOITIÉ DE SEXTULE",NULL},
/* 10195 */ { "SYMBOLE ROMAIN SILIQUE",NULL},
/* 10196 */ { "SYMBOLE ROMAIN DENIER",NULL},
/* 10197 */ { "SYMBOLE ROMAIN QUINAIRE",NULL},
/* 10198 */ { "SYMBOLE ROMAIN SESTERCE",NULL},
/* 10199 */ { "SYMBOLE ROMAIN DUPONDIUS",NULL},
/* 1019A */ { "SYMBOLE ROMAIN AS","	x (symbole de fonction apl cotice barrée - 233F)"},
/* 1019B */ { "SYMBOLE ROMAIN DE CENTURIE",NULL},
/* 1019C */ { "SYMBOLE ASCIA",NULL},
/* 1019D */ { NULL,NULL},
/* 1019E */ { NULL,NULL},
/* 1019F */ { NULL,NULL},
/* 101A0 */ { "SYMBOLE GREC TAU RHÔ","	= rhô croix, staurogramme\n"
	"	x (chrisme - 2627)\n"
	"	x (symbole copte tau rhô - 2CE8)"},
/* 101A1 */ { NULL,NULL},
/* 101A2 */ { NULL,NULL},
/* 101A3 */ { NULL,NULL},
/* 101A4 */ { NULL,NULL},
/* 101A5 */ { NULL,NULL},
/* 101A6 */ { NULL,NULL},
/* 101A7 */ { NULL,NULL},
/* 101A8 */ { NULL,NULL},
/* 101A9 */ { NULL,NULL},
/* 101AA */ { NULL,NULL},
/* 101AB */ { NULL,NULL},
/* 101AC */ { NULL,NULL},
/* 101AD */ { NULL,NULL},
/* 101AE */ { NULL,NULL},
/* 101AF */ { NULL,NULL},
/* 101B0 */ { NULL,NULL},
/* 101B1 */ { NULL,NULL},
/* 101B2 */ { NULL,NULL},
/* 101B3 */ { NULL,NULL},
/* 101B4 */ { NULL,NULL},
/* 101B5 */ { NULL,NULL},
/* 101B6 */ { NULL,NULL},
/* 101B7 */ { NULL,NULL},
/* 101B8 */ { NULL,NULL},
/* 101B9 */ { NULL,NULL},
/* 101BA */ { NULL,NULL},
/* 101BB */ { NULL,NULL},
/* 101BC */ { NULL,NULL},
/* 101BD */ { NULL,NULL},
/* 101BE */ { NULL,NULL},
/* 101BF */ { NULL,NULL},
/* 101C0 */ { NULL,NULL},
/* 101C1 */ { NULL,NULL},
/* 101C2 */ { NULL,NULL},
/* 101C3 */ { NULL,NULL},
/* 101C4 */ { NULL,NULL},
/* 101C5 */ { NULL,NULL},
/* 101C6 */ { NULL,NULL},
/* 101C7 */ { NULL,NULL},
/* 101C8 */ { NULL,NULL},
/* 101C9 */ { NULL,NULL},
/* 101CA */ { NULL,NULL},
/* 101CB */ { NULL,NULL},
/* 101CC */ { NULL,NULL},
/* 101CD */ { NULL,NULL},
/* 101CE */ { NULL,NULL},
/* 101CF */ { NULL,NULL},
/* 101D0 */ { "SIGNE DU DISQUE DE PHAÏSTOS PIÉTON",NULL},
/* 101D1 */ { "SIGNE DU DISQUE DE PHAÏSTOS TÊTE EMPLUMÉE",NULL},
/* 101D2 */ { "SIGNE DU DISQUE DE PHAÏSTOS TÊTE TATOUÉE",NULL},
/* 101D3 */ { "SIGNE DU DISQUE DE PHAÏSTOS PRISONNIER",NULL},
/* 101D4 */ { "SIGNE DU DISQUE DE PHAÏSTOS ENFANT",NULL},
/* 101D5 */ { "SIGNE DU DISQUE DE PHAÏSTOS FEMME",NULL},
/* 101D6 */ { "SIGNE DU DISQUE DE PHAÏSTOS CASQUE",NULL},
/* 101D7 */ { "SIGNE DU DISQUE DE PHAÏSTOS GANT",NULL},
/* 101D8 */ { "SIGNE DU DISQUE DE PHAÏSTOS TIARE",NULL},
/* 101D9 */ { "SIGNE DU DISQUE DE PHAÏSTOS FLÈCHE",NULL},
/* 101DA */ { "SIGNE DU DISQUE DE PHAÏSTOS ARC",NULL},
/* 101DB */ { "SIGNE DU DISQUE DE PHAÏSTOS BOUCLIER",NULL},
/* 101DC */ { "SIGNE DU DISQUE DE PHAÏSTOS MASSUE",NULL},
/* 101DD */ { "SIGNE DU DISQUE DE PHAÏSTOS MENOTTES",NULL},
/* 101DE */ { "SIGNE DU DISQUE DE PHAÏSTOS PIOLET",NULL},
/* 101DF */ { "SIGNE DU DISQUE DE PHAÏSTOS SCIE",NULL},
/* 101E0 */ { "SIGNE DU DISQUE DE PHAÏSTOS COUVERCLE",NULL},
/* 101E1 */ { "SIGNE DU DISQUE DE PHAÏSTOS ÉQUERRE",NULL},
/* 101E2 */ { "SIGNE DU DISQUE DE PHAÏSTOS RABOT",NULL},
/* 101E3 */ { "SIGNE DU DISQUE DE PHAÏSTOS TRITON",NULL},
/* 101E4 */ { "SIGNE DU DISQUE DE PHAÏSTOS PEIGNE",NULL},
/* 101E5 */ { "SIGNE DU DISQUE DE PHAÏSTOS FRONDE",NULL},
/* 101E6 */ { "SIGNE DU DISQUE DE PHAÏSTOS COLONNE À CHAPITEAU",NULL},
/* 101E7 */ { "SIGNE DU DISQUE DE PHAÏSTOS RUCHE",NULL},
/* 101E8 */ { "SIGNE DU DISQUE DE PHAÏSTOS NEF",NULL},
/* 101E9 */ { "SIGNE DU DISQUE DE PHAÏSTOS CORNE",NULL},
/* 101EA */ { "SIGNE DU DISQUE DE PHAÏSTOS PEAU D'ANIMAL",NULL},
/* 101EB */ { "SIGNE DU DISQUE DE PHAÏSTOS PATTE DE TAUREAU",NULL},
/* 101EC */ { "SIGNE DU DISQUE DE PHAÏSTOS CHATTE",NULL},
/* 101ED */ { "SIGNE DU DISQUE DE PHAÏSTOS BÉLIER",NULL},
/* 101EE */ { "SIGNE DU DISQUE DE PHAÏSTOS RAPACE",NULL},
/* 101EF */ { "SIGNE DU DISQUE DE PHAÏSTOS PIGEON",NULL},
/* 101F0 */ { "SIGNE DU DISQUE DE PHAÏSTOS POISSON",NULL},
/* 101F1 */ { "SIGNE DU DISQUE DE PHAÏSTOS ABEILLE",NULL},
/* 101F2 */ { "SIGNE DU DISQUE DE PHAÏSTOS PLATANE",NULL},
/* 101F3 */ { "SIGNE DU DISQUE DE PHAÏSTOS PIED DE VIGNE",NULL},
/* 101F4 */ { "SIGNE DU DISQUE DE PHAÏSTOS PAPYRUS",NULL},
/* 101F5 */ { "SIGNE DU DISQUE DE PHAÏSTOS ROSETTE",NULL},
/* 101F6 */ { "SIGNE DU DISQUE DE PHAÏSTOS LYS",NULL},
/* 101F7 */ { "SIGNE DU DISQUE DE PHAÏSTOS CUL DE BŒUF",NULL},
/* 101F8 */ { "SIGNE DU DISQUE DE PHAÏSTOS FLÛTE",NULL},
/* 101F9 */ { "SIGNE DU DISQUE DE PHAÏSTOS RÂPE",NULL},
/* 101FA */ { "SIGNE DU DISQUE DE PHAÏSTOS PASSOIRE",NULL},
/* 101FB */ { "SIGNE DU DISQUE DE PHAÏSTOS TRANCHET",NULL},
/* 101FC */ { "SIGNE DU DISQUE DE PHAÏSTOS EAU QUI COULE",NULL},
/* 101FD */ { "DIACRITIQUE DU DISQUE DE PHAÏSTOS TRAIT OBLIQUE SOUSCRIT",NULL},
/* 101FE */ { NULL,NULL},
/* 101FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_02[] = {
/* 10200 */ { NULL,NULL},
/* 10201 */ { NULL,NULL},
/* 10202 */ { NULL,NULL},
/* 10203 */ { NULL,NULL},
/* 10204 */ { NULL,NULL},
/* 10205 */ { NULL,NULL},
/* 10206 */ { NULL,NULL},
/* 10207 */ { NULL,NULL},
/* 10208 */ { NULL,NULL},
/* 10209 */ { NULL,NULL},
/* 1020A */ { NULL,NULL},
/* 1020B */ { NULL,NULL},
/* 1020C */ { NULL,NULL},
/* 1020D */ { NULL,NULL},
/* 1020E */ { NULL,NULL},
/* 1020F */ { NULL,NULL},
/* 10210 */ { NULL,NULL},
/* 10211 */ { NULL,NULL},
/* 10212 */ { NULL,NULL},
/* 10213 */ { NULL,NULL},
/* 10214 */ { NULL,NULL},
/* 10215 */ { NULL,NULL},
/* 10216 */ { NULL,NULL},
/* 10217 */ { NULL,NULL},
/* 10218 */ { NULL,NULL},
/* 10219 */ { NULL,NULL},
/* 1021A */ { NULL,NULL},
/* 1021B */ { NULL,NULL},
/* 1021C */ { NULL,NULL},
/* 1021D */ { NULL,NULL},
/* 1021E */ { NULL,NULL},
/* 1021F */ { NULL,NULL},
/* 10220 */ { NULL,NULL},
/* 10221 */ { NULL,NULL},
/* 10222 */ { NULL,NULL},
/* 10223 */ { NULL,NULL},
/* 10224 */ { NULL,NULL},
/* 10225 */ { NULL,NULL},
/* 10226 */ { NULL,NULL},
/* 10227 */ { NULL,NULL},
/* 10228 */ { NULL,NULL},
/* 10229 */ { NULL,NULL},
/* 1022A */ { NULL,NULL},
/* 1022B */ { NULL,NULL},
/* 1022C */ { NULL,NULL},
/* 1022D */ { NULL,NULL},
/* 1022E */ { NULL,NULL},
/* 1022F */ { NULL,NULL},
/* 10230 */ { NULL,NULL},
/* 10231 */ { NULL,NULL},
/* 10232 */ { NULL,NULL},
/* 10233 */ { NULL,NULL},
/* 10234 */ { NULL,NULL},
/* 10235 */ { NULL,NULL},
/* 10236 */ { NULL,NULL},
/* 10237 */ { NULL,NULL},
/* 10238 */ { NULL,NULL},
/* 10239 */ { NULL,NULL},
/* 1023A */ { NULL,NULL},
/* 1023B */ { NULL,NULL},
/* 1023C */ { NULL,NULL},
/* 1023D */ { NULL,NULL},
/* 1023E */ { NULL,NULL},
/* 1023F */ { NULL,NULL},
/* 10240 */ { NULL,NULL},
/* 10241 */ { NULL,NULL},
/* 10242 */ { NULL,NULL},
/* 10243 */ { NULL,NULL},
/* 10244 */ { NULL,NULL},
/* 10245 */ { NULL,NULL},
/* 10246 */ { NULL,NULL},
/* 10247 */ { NULL,NULL},
/* 10248 */ { NULL,NULL},
/* 10249 */ { NULL,NULL},
/* 1024A */ { NULL,NULL},
/* 1024B */ { NULL,NULL},
/* 1024C */ { NULL,NULL},
/* 1024D */ { NULL,NULL},
/* 1024E */ { NULL,NULL},
/* 1024F */ { NULL,NULL},
/* 10250 */ { NULL,NULL},
/* 10251 */ { NULL,NULL},
/* 10252 */ { NULL,NULL},
/* 10253 */ { NULL,NULL},
/* 10254 */ { NULL,NULL},
/* 10255 */ { NULL,NULL},
/* 10256 */ { NULL,NULL},
/* 10257 */ { NULL,NULL},
/* 10258 */ { NULL,NULL},
/* 10259 */ { NULL,NULL},
/* 1025A */ { NULL,NULL},
/* 1025B */ { NULL,NULL},
/* 1025C */ { NULL,NULL},
/* 1025D */ { NULL,NULL},
/* 1025E */ { NULL,NULL},
/* 1025F */ { NULL,NULL},
/* 10260 */ { NULL,NULL},
/* 10261 */ { NULL,NULL},
/* 10262 */ { NULL,NULL},
/* 10263 */ { NULL,NULL},
/* 10264 */ { NULL,NULL},
/* 10265 */ { NULL,NULL},
/* 10266 */ { NULL,NULL},
/* 10267 */ { NULL,NULL},
/* 10268 */ { NULL,NULL},
/* 10269 */ { NULL,NULL},
/* 1026A */ { NULL,NULL},
/* 1026B */ { NULL,NULL},
/* 1026C */ { NULL,NULL},
/* 1026D */ { NULL,NULL},
/* 1026E */ { NULL,NULL},
/* 1026F */ { NULL,NULL},
/* 10270 */ { NULL,NULL},
/* 10271 */ { NULL,NULL},
/* 10272 */ { NULL,NULL},
/* 10273 */ { NULL,NULL},
/* 10274 */ { NULL,NULL},
/* 10275 */ { NULL,NULL},
/* 10276 */ { NULL,NULL},
/* 10277 */ { NULL,NULL},
/* 10278 */ { NULL,NULL},
/* 10279 */ { NULL,NULL},
/* 1027A */ { NULL,NULL},
/* 1027B */ { NULL,NULL},
/* 1027C */ { NULL,NULL},
/* 1027D */ { NULL,NULL},
/* 1027E */ { NULL,NULL},
/* 1027F */ { NULL,NULL},
/* 10280 */ { "LETTRE LYCIENNE A",NULL},
/* 10281 */ { "LETTRE LYCIENNE E",NULL},
/* 10282 */ { "LETTRE LYCIENNE B",NULL},
/* 10283 */ { "LETTRE LYCIENNE BH",NULL},
/* 10284 */ { "LETTRE LYCIENNE G",NULL},
/* 10285 */ { "LETTRE LYCIENNE D",NULL},
/* 10286 */ { "LETTRE LYCIENNE I",NULL},
/* 10287 */ { "LETTRE LYCIENNE W",NULL},
/* 10288 */ { "LETTRE LYCIENNE Z",NULL},
/* 10289 */ { "LETTRE LYCIENNE TH",NULL},
/* 1028A */ { "LETTRE LYCIENNE Y",NULL},
/* 1028B */ { "LETTRE LYCIENNE K",NULL},
/* 1028C */ { "LETTRE LYCIENNE Q",NULL},
/* 1028D */ { "LETTRE LYCIENNE L",NULL},
/* 1028E */ { "LETTRE LYCIENNE M",NULL},
/* 1028F */ { "LETTRE LYCIENNE N",NULL},
/* 10290 */ { "LETTRE LYCIENNE MM",NULL},
/* 10291 */ { "LETTRE LYCIENNE NN",NULL},
/* 10292 */ { "LETTRE LYCIENNE U",NULL},
/* 10293 */ { "LETTRE LYCIENNE P",NULL},
/* 10294 */ { "LETTRE LYCIENNE KK",NULL},
/* 10295 */ { "LETTRE LYCIENNE R",NULL},
/* 10296 */ { "LETTRE LYCIENNE S",NULL},
/* 10297 */ { "LETTRE LYCIENNE T",NULL},
/* 10298 */ { "LETTRE LYCIENNE TT",NULL},
/* 10299 */ { "LETTRE LYCIENNE AN",NULL},
/* 1029A */ { "LETTRE LYCIENNE EN",NULL},
/* 1029B */ { "LETTRE LYCIENNE H",NULL},
/* 1029C */ { "LETTRE LYCIENNE KH",NULL},
/* 1029D */ { NULL,NULL},
/* 1029E */ { NULL,NULL},
/* 1029F */ { NULL,NULL},
/* 102A0 */ { "LETTRE CARIENNE A",NULL},
/* 102A1 */ { "LETTRE CARIENNE P2",NULL},
/* 102A2 */ { "LETTRE CARIENNE D",NULL},
/* 102A3 */ { "LETTRE CARIENNE L",NULL},
/* 102A4 */ { "LETTRE CARIENNE UUU",NULL},
/* 102A5 */ { "LETTRE CARIENNE R",NULL},
/* 102A6 */ { "LETTRE CARIENNE LD",NULL},
/* 102A7 */ { "LETTRE CARIENNE A2",NULL},
/* 102A8 */ { "LETTRE CARIENNE Q",NULL},
/* 102A9 */ { "LETTRE CARIENNE B",NULL},
/* 102AA */ { "LETTRE CARIENNE M",NULL},
/* 102AB */ { "LETTRE CARIENNE O",NULL},
/* 102AC */ { "LETTRE CARIENNE D2",NULL},
/* 102AD */ { "LETTRE CARIENNE T",NULL},
/* 102AE */ { "LETTRE CARIENNE CH",NULL},
/* 102AF */ { "LETTRE CARIENNE CH2",NULL},
/* 102B0 */ { "LETTRE CARIENNE S",NULL},
/* 102B1 */ { "LETTRE CARIENNE C-18",NULL},
/* 102B2 */ { "LETTRE CARIENNE U",NULL},
/* 102B3 */ { "LETTRE CARIENNE Ñ",NULL},
/* 102B4 */ { "LETTRE CARIENNE KH",NULL},
/* 102B5 */ { "LETTRE CARIENNE N",NULL},
/* 102B6 */ { "LETTRE CARIENNE TT2",NULL},
/* 102B7 */ { "LETTRE CARIENNE P",NULL},
/* 102B8 */ { "LETTRE CARIENNE SS",NULL},
/* 102B9 */ { "LETTRE CARIENNE I",NULL},
/* 102BA */ { "LETTRE CARIENNE E",NULL},
/* 102BB */ { "LETTRE CARIENNE UUUU",NULL},
/* 102BC */ { "LETTRE CARIENNE K",NULL},
/* 102BD */ { "LETTRE CARIENNE K2",NULL},
/* 102BE */ { "LETTRE CARIENNE ND",NULL},
/* 102BF */ { "LETTRE CARIENNE UU",NULL},
/* 102C0 */ { "LETTRE CARIENNE G",NULL},
/* 102C1 */ { "LETTRE CARIENNE G2",NULL},
/* 102C2 */ { "LETTRE CARIENNE ST",NULL},
/* 102C3 */ { "LETTRE CARIENNE ST2",NULL},
/* 102C4 */ { "LETTRE CARIENNE NG",NULL},
/* 102C5 */ { "LETTRE CARIENNE II",NULL},
/* 102C6 */ { "LETTRE CARIENNE C-39",NULL},
/* 102C7 */ { "LETTRE CARIENNE TT",NULL},
/* 102C8 */ { "LETTRE CARIENNE UUU2",NULL},
/* 102C9 */ { "LETTRE CARIENNE RR",NULL},
/* 102CA */ { "LETTRE CARIENNE MB",NULL},
/* 102CB */ { "LETTRE CARIENNE MB2",NULL},
/* 102CC */ { "LETTRE CARIENNE MB3",NULL},
/* 102CD */ { "LETTRE CARIENNE MB4",NULL},
/* 102CE */ { "LETTRE CARIENNE LD2",NULL},
/* 102CF */ { "LETTRE CARIENNE E2",NULL},
/* 102D0 */ { "LETTRE CARIENNE UUU3",NULL},
/* 102D1 */ { NULL,NULL},
/* 102D2 */ { NULL,NULL},
/* 102D3 */ { NULL,NULL},
/* 102D4 */ { NULL,NULL},
/* 102D5 */ { NULL,NULL},
/* 102D6 */ { NULL,NULL},
/* 102D7 */ { NULL,NULL},
/* 102D8 */ { NULL,NULL},
/* 102D9 */ { NULL,NULL},
/* 102DA */ { NULL,NULL},
/* 102DB */ { NULL,NULL},
/* 102DC */ { NULL,NULL},
/* 102DD */ { NULL,NULL},
/* 102DE */ { NULL,NULL},
/* 102DF */ { NULL,NULL},
/* 102E0 */ { "SIGNE ÉPACTE COPTE MILLIERS",NULL},
/* 102E1 */ { "CHIFFRE ÉPACTE COPTE UN",NULL},
/* 102E2 */ { "CHIFFRE ÉPACTE COPTE DEUX",NULL},
/* 102E3 */ { "CHIFFRE ÉPACTE COPTE TROIS",NULL},
/* 102E4 */ { "CHIFFRE ÉPACTE COPTE QUATRE",NULL},
/* 102E5 */ { "CHIFFRE ÉPACTE COPTE CINQ",NULL},
/* 102E6 */ { "CHIFFRE ÉPACTE COPTE SIX",NULL},
/* 102E7 */ { "CHIFFRE ÉPACTE COPTE SEPT",NULL},
/* 102E8 */ { "CHIFFRE ÉPACTE COPTE HUIT",NULL},
/* 102E9 */ { "CHIFFRE ÉPACTE COPTE NEUF",NULL},
/* 102EA */ { "NOMBRE ÉPACTE COPTE DIX",NULL},
/* 102EB */ { "NOMBRE ÉPACTE COPTE VINGT",NULL},
/* 102EC */ { "NOMBRE ÉPACTE COPTE TRENTE",NULL},
/* 102ED */ { "NOMBRE ÉPACTE COPTE QUARANTE",NULL},
/* 102EE */ { "NOMBRE ÉPACTE COPTE CINQUANTE",NULL},
/* 102EF */ { "NOMBRE ÉPACTE COPTE SOIXANTE",NULL},
/* 102F0 */ { "NOMBRE ÉPACTE COPTE SOIXANTE-DIX","	= nombre épacte copte septante"},
/* 102F1 */ { "NOMBRE ÉPACTE COPTE QUATRE-VINGTS","	= nombre épacte copte huitante"},
/* 102F2 */ { "NOMBRE ÉPACTE COPTE QUATRE-VINGT-DIX","	= nombre épacte copte nonante"},
/* 102F3 */ { "NOMBRE ÉPACTE COPTE CENT",NULL},
/* 102F4 */ { "NOMBRE ÉPACTE COPTE DEUX CENTS",NULL},
/* 102F5 */ { "NOMBRE ÉPACTE COPTE TROIS CENTS",NULL},
/* 102F6 */ { "NOMBRE ÉPACTE COPTE QUATRE CENTS",NULL},
/* 102F7 */ { "NOMBRE ÉPACTE COPTE CINQ CENTS",NULL},
/* 102F8 */ { "NOMBRE ÉPACTE COPTE SIX CENTS",NULL},
/* 102F9 */ { "NOMBRE ÉPACTE COPTE SEPT CENTS",NULL},
/* 102FA */ { "NOMBRE ÉPACTE COPTE HUIT CENTS",NULL},
/* 102FB */ { "NOMBRE ÉPACTE COPTE NEUF CENTS",NULL},
/* 102FC */ { NULL,NULL},
/* 102FD */ { NULL,NULL},
/* 102FE */ { NULL,NULL},
/* 102FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_03[] = {
/* 10300 */ { "LETTRE VIEIL ITALIQUE A",NULL},
/* 10301 */ { "LETTRE VIEIL ITALIQUE BÉ",NULL},
/* 10302 */ { "LETTRE VIEIL ITALIQUE KÉ",NULL},
/* 10303 */ { "LETTRE VIEIL ITALIQUE DÉ",NULL},
/* 10304 */ { "LETTRE VIEIL ITALIQUE É",NULL},
/* 10305 */ { "LETTRE VIEIL ITALIQUE VÉ",NULL},
/* 10306 */ { "LETTRE VIEIL ITALIQUE ZÉ",NULL},
/* 10307 */ { "LETTRE VIEIL ITALIQUE HÉ",NULL},
/* 10308 */ { "LETTRE VIEIL ITALIQUE THÉ",NULL},
/* 10309 */ { "LETTRE VIEIL ITALIQUE I",NULL},
/* 1030A */ { "LETTRE VIEIL ITALIQUE KA",NULL},
/* 1030B */ { "LETTRE VIEIL ITALIQUE ELLE",NULL},
/* 1030C */ { "LETTRE VIEIL ITALIQUE EMME",NULL},
/* 1030D */ { "LETTRE VIEIL ITALIQUE ENNE",NULL},
/* 1030E */ { "LETTRE VIEIL ITALIQUE ECH",NULL},
/* 1030F */ { "LETTRE VIEIL ITALIQUE O","	* falisque"},
/* 10310 */ { "LETTRE VIEIL ITALIQUE PÉ",NULL},
/* 10311 */ { "LETTRE VIEIL ITALIQUE CHÉ",NULL},
/* 10312 */ { "LETTRE VIEIL ITALIQUE KU",NULL},
/* 10313 */ { "LETTRE VIEIL ITALIQUE ERRE",NULL},
/* 10314 */ { "LETTRE VIEIL ITALIQUE ESSE",NULL},
/* 10315 */ { "LETTRE VIEIL ITALIQUE TÉ",NULL},
/* 10316 */ { "LETTRE VIEIL ITALIQUE U",NULL},
/* 10317 */ { "LETTRE VIEIL ITALIQUE IKS","	* falisque"},
/* 10318 */ { "LETTRE VIEIL ITALIQUE PHÉ",NULL},
/* 10319 */ { "LETTRE VIEIL ITALIQUE KHÉ",NULL},
/* 1031A */ { "LETTRE VIEIL ITALIQUE EFFE",NULL},
/* 1031B */ { "LETTRE VIEIL ITALIQUE ERSE",NULL},
/* 1031C */ { "LETTRE VIEIL ITALIQUE ÇÉ",NULL},
/* 1031D */ { "LETTRE VIEIL ITALIQUE Í",NULL},
/* 1031E */ { "LETTRE VIEIL ITALIQUE Ú",NULL},
/* 1031F */ { "LETTRE VIEIL ITALIQUE ESSE DUR",NULL},
/* 10320 */ { "NOMBRE VIEIL ITALIQUE UN",NULL},
/* 10321 */ { "NOMBRE VIEIL ITALIQUE CINQ",NULL},
/* 10322 */ { "NOMBRE VIEIL ITALIQUE DIX",NULL},
/* 10323 */ { "NOMBRE VIEIL ITALIQUE CINQUANTE",NULL},
/* 10324 */ { NULL,NULL},
/* 10325 */ { NULL,NULL},
/* 10326 */ { NULL,NULL},
/* 10327 */ { NULL,NULL},
/* 10328 */ { NULL,NULL},
/* 10329 */ { NULL,NULL},
/* 1032A */ { NULL,NULL},
/* 1032B */ { NULL,NULL},
/* 1032C */ { NULL,NULL},
/* 1032D */ { "LETTRE VIEIL ITALIQUE YÉ",NULL},
/* 1032E */ { "LETTRE VIEIL ITALIQUE TSÉ DU NORD",NULL},
/* 1032F */ { "LETTRE VIEIL ITALIQUE TSÉ DU SUD",NULL},
/* 10330 */ { "LETTRE GOTIQUE A","	= ahsa"},
/* 10331 */ { "LETTRE GOTIQUE B","	= bairkan"},
/* 10332 */ { "LETTRE GOTIQUE G","	= giba"},
/* 10333 */ { "LETTRE GOTIQUE D","	= dags"},
/* 10334 */ { "LETTRE GOTIQUE É","	= aihvus"},
/* 10335 */ { "LETTRE GOTIQUE Q","	= qairthra"},
/* 10336 */ { "LETTRE GOTIQUE Z","	= iuja"},
/* 10337 */ { "LETTRE GOTIQUE H","	= hagl"},
/* 10338 */ { "LETTRE GOTIQUE TH","	= thiuth"},
/* 10339 */ { "LETTRE GOTIQUE I","	= eis"},
/* 1033A */ { "LETTRE GOTIQUE K","	= kusma"},
/* 1033B */ { "LETTRE GOTIQUE L","	= lagus"},
/* 1033C */ { "LETTRE GOTIQUE M","	= manna"},
/* 1033D */ { "LETTRE GOTIQUE N","	= nauths"},
/* 1033E */ { "LETTRE GOTIQUE Y","	= jer"},
/* 1033F */ { "LETTRE GOTIQUE OU","	= urus"},
/* 10340 */ { "LETTRE GOTIQUE P","	= pairthra"},
/* 10341 */ { "LETTRE GOTIQUE NONANTE","	= quatre-vingt-dix gotique"},
/* 10342 */ { "LETTRE GOTIQUE R","	= raida"},
/* 10343 */ { "LETTRE GOTIQUE S","	= sauil"},
/* 10344 */ { "LETTRE GOTIQUE T","	= teiws"},
/* 10345 */ { "LETTRE GOTIQUE U","	= winja"},
/* 10346 */ { "LETTRE GOTIQUE F","	= faihu"},
/* 10347 */ { "LETTRE GOTIQUE KH","	= iggws"},
/* 10348 */ { "LETTRE GOTIQUE HW","	= hwair"},
/* 10349 */ { "LETTRE GOTIQUE O","	= othal"},
/* 1034A */ { "LETTRE GOTIQUE NEUF CENTS",NULL},
/* 1034B */ { NULL,NULL},
/* 1034C */ { NULL,NULL},
/* 1034D */ { NULL,NULL},
/* 1034E */ { NULL,NULL},
/* 1034F */ { NULL,NULL},
/* 10350 */ { "LETTRE PERMIENNE AN",NULL},
/* 10351 */ { "LETTRE PERMIENNE BOUR",NULL},
/* 10352 */ { "LETTRE PERMIENNE GAÏ",NULL},
/* 10353 */ { "LETTRE PERMIENNE DOÏ",NULL},
/* 10354 */ { "LETTRE PERMIENNE E",NULL},
/* 10355 */ { "LETTRE PERMIENNE JOÏ",NULL},
/* 10356 */ { "LETTRE PERMIENNE DJOÏ",NULL},
/* 10357 */ { "LETTRE PERMIENNE ZATA",NULL},
/* 10358 */ { "LETTRE PERMIENNE DZITA",NULL},
/* 10359 */ { "LETTRE PERMIENNE I",NULL},
/* 1035A */ { "LETTRE PERMIENNE KOKE",NULL},
/* 1035B */ { "LETTRE PERMIENNE LEÏ",NULL},
/* 1035C */ { "LETTRE PERMIENNE MENOE",NULL},
/* 1035D */ { "LETTRE PERMIENNE NENOE",NULL},
/* 1035E */ { "LETTRE PERMIENNE VÔÏ",NULL},
/* 1035F */ { "LETTRE PERMIENNE PEÏ",NULL},
/* 10360 */ { "LETTRE PERMIENNE REÏ",NULL},
/* 10361 */ { "LETTRE PERMIENNE SIÏ",NULL},
/* 10362 */ { "LETTRE PERMIENNE TAÏ",NULL},
/* 10363 */ { "LETTRE PERMIENNE OU",NULL},
/* 10364 */ { "LETTRE PERMIENNE TCHERY",NULL},
/* 10365 */ { "LETTRE PERMIENNE CHÔÏ",NULL},
/* 10366 */ { "LETTRE PERMIENNE CHTCHÔÏ",NULL},
/* 10367 */ { "LETTRE PERMIENNE YRY",NULL},
/* 10368 */ { "LETTRE PERMIENNE YÉROU",NULL},
/* 10369 */ { "LETTRE PERMIENNE O",NULL},
/* 1036A */ { "LETTRE PERMIENNE Ô",NULL},
/* 1036B */ { "LETTRE PERMIENNE EF",NULL},
/* 1036C */ { "LETTRE PERMIENNE KHA",NULL},
/* 1036D */ { "LETTRE PERMIENNE TSIOU",NULL},
/* 1036E */ { "LETTRE PERMIENNE VER",NULL},
/* 1036F */ { "LETTRE PERMIENNE YER",NULL},
/* 10370 */ { "LETTRE PERMIENNE YÉRI",NULL},
/* 10371 */ { "LETTRE PERMIENNE IAT",NULL},
/* 10372 */ { "LETTRE PERMIENNE IE",NULL},
/* 10373 */ { "LETTRE PERMIENNE YOU",NULL},
/* 10374 */ { "LETTRE PERMIENNE YA",NULL},
/* 10375 */ { "LETTRE PERMIENNE IA",NULL},
/* 10376 */ { "DIACRITIQUE LETTRE PERMIENNE AN",NULL},
/* 10377 */ { "DIACRITIQUE LETTRE PERMIENNE DOÏ",NULL},
/* 10378 */ { "DIACRITIQUE LETTRE PERMIENNE ZATA",NULL},
/* 10379 */ { "DIACRITIQUE LETTRE PERMIENNE NENOE",NULL},
/* 1037A */ { "DIACRITIQUE LETTRE PERMIENNE SIÏ",NULL},
/* 1037B */ { NULL,NULL},
/* 1037C */ { NULL,NULL},
/* 1037D */ { NULL,NULL},
/* 1037E */ { NULL,NULL},
/* 1037F */ { NULL,NULL},
/* 10380 */ { "LETTRE OUGARITIQUE ALPA",NULL},
/* 10381 */ { "LETTRE OUGARITIQUE BÊTA",NULL},
/* 10382 */ { "LETTRE OUGARITIQUE GAMLA",NULL},
/* 10383 */ { "LETTRE OUGARITIQUE KHA",NULL},
/* 10384 */ { "LETTRE OUGARITIQUE DELTA",NULL},
/* 10385 */ { "LETTRE OUGARITIQUE HO",NULL},
/* 10386 */ { "LETTRE OUGARITIQUE WO",NULL},
/* 10387 */ { "LETTRE OUGARITIQUE DZÊTA",NULL},
/* 10388 */ { "LETTRE OUGARITIQUE HOTA",NULL},
/* 10389 */ { "LETTRE OUGARITIQUE TÈT",NULL},
/* 1038A */ { "LETTRE OUGARITIQUE YOD",NULL},
/* 1038B */ { "LETTRE OUGARITIQUE KAF",NULL},
/* 1038C */ { "LETTRE OUGARITIQUE CHINE",NULL},
/* 1038D */ { "LETTRE OUGARITIQUE LAMBDA",NULL},
/* 1038E */ { "LETTRE OUGARITIQUE MÉM",NULL},
/* 1038F */ { "LETTRE OUGARITIQUE DHAL",NULL},
/* 10390 */ { "LETTRE OUGARITIQUE NOUN",NULL},
/* 10391 */ { "LETTRE OUGARITIQUE ZOU",NULL},
/* 10392 */ { "LETTRE OUGARITIQUE SAMKA",NULL},
/* 10393 */ { "LETTRE OUGARITIQUE 'AÏN",NULL},
/* 10394 */ { "LETTRE OUGARITIQUE POU",NULL},
/* 10395 */ { "LETTRE OUGARITIQUE TSADÉ",NULL},
/* 10396 */ { "LETTRE OUGARITIQUE QOPA",NULL},
/* 10397 */ { "LETTRE OUGARITIQUE RACHA",NULL},
/* 10398 */ { "LETTRE OUGARITIQUE THANNA",NULL},
/* 10399 */ { "LETTRE OUGARITIQUE GHAÏN",NULL},
/* 1039A */ { "LETTRE OUGARITIQUE TO",NULL},
/* 1039B */ { "LETTRE OUGARITIQUE I",NULL},
/* 1039C */ { "LETTRE OUGARITIQUE OU",NULL},
/* 1039D */ { "LETTRE OUGARITIQUE SSOU",NULL},
/* 1039E */ { NULL,NULL},
/* 1039F */ { "SÉPARATEUR DE MOTS OUGARITIQUE",NULL},
/* 103A0 */ { "SIGNE VIEUX PERSE A",NULL},
/* 103A1 */ { "SIGNE VIEUX PERSE I",NULL},
/* 103A2 */ { "SIGNE VIEUX PERSE U",NULL},
/* 103A3 */ { "SIGNE VIEUX PERSE KA",NULL},
/* 103A4 */ { "SIGNE VIEUX PERSE KU",NULL},
/* 103A5 */ { "SIGNE VIEUX PERSE GA",NULL},
/* 103A6 */ { "SIGNE VIEUX PERSE GU",NULL},
/* 103A7 */ { "SIGNE VIEUX PERSE XA",NULL},
/* 103A8 */ { "SIGNE VIEUX PERSE TCHA",NULL},
/* 103A9 */ { "SIGNE VIEUX PERSE JA",NULL},
/* 103AA */ { "SIGNE VIEUX PERSE JI",NULL},
/* 103AB */ { "SIGNE VIEUX PERSE TA",NULL},
/* 103AC */ { "SIGNE VIEUX PERSE TU",NULL},
/* 103AD */ { "SIGNE VIEUX PERSE DA",NULL},
/* 103AE */ { "SIGNE VIEUX PERSE DI",NULL},
/* 103AF */ { "SIGNE VIEUX PERSE DU",NULL},
/* 103B0 */ { "SIGNE VIEUX PERSE THA",NULL},
/* 103B1 */ { "SIGNE VIEUX PERSE PA",NULL},
/* 103B2 */ { "SIGNE VIEUX PERSE BA",NULL},
/* 103B3 */ { "SIGNE VIEUX PERSE FA",NULL},
/* 103B4 */ { "SIGNE VIEUX PERSE NA",NULL},
/* 103B5 */ { "SIGNE VIEUX PERSE NU",NULL},
/* 103B6 */ { "SIGNE VIEUX PERSE MA",NULL},
/* 103B7 */ { "SIGNE VIEUX PERSE MI",NULL},
/* 103B8 */ { "SIGNE VIEUX PERSE MU",NULL},
/* 103B9 */ { "SIGNE VIEUX PERSE YA",NULL},
/* 103BA */ { "SIGNE VIEUX PERSE VA",NULL},
/* 103BB */ { "SIGNE VIEUX PERSE VI",NULL},
/* 103BC */ { "SIGNE VIEUX PERSE RA",NULL},
/* 103BD */ { "SIGNE VIEUX PERSE RU",NULL},
/* 103BE */ { "SIGNE VIEUX PERSE LA",NULL},
/* 103BF */ { "SIGNE VIEUX PERSE SA",NULL},
/* 103C0 */ { "SIGNE VIEUX PERSE ZA",NULL},
/* 103C1 */ { "SIGNE VIEUX PERSE ÇA",NULL},
/* 103C2 */ { "SIGNE VIEUX PERSE CHA",NULL},
/* 103C3 */ { "SIGNE VIEUX PERSE HA",NULL},
/* 103C4 */ { NULL,NULL},
/* 103C5 */ { NULL,NULL},
/* 103C6 */ { NULL,NULL},
/* 103C7 */ { NULL,NULL},
/* 103C8 */ { "SIGNE VIEUX PERSE AURAMAZDÂ",NULL},
/* 103C9 */ { "SIGNE VIEUX PERSE AURAMAZDÂ-2",NULL},
/* 103CA */ { "SIGNE VIEUX PERSE AURAMAZDÂHA",NULL},
/* 103CB */ { "SIGNE VIEUX PERSE XCHÂYATHIYA",NULL},
/* 103CC */ { "SIGNE VIEUX PERSE DAHYÂUCH",NULL},
/* 103CD */ { "SIGNE VIEUX PERSE DAHYÂUCH-2",NULL},
/* 103CE */ { "SIGNE VIEUX PERSE BAGA",NULL},
/* 103CF */ { "SIGNE VIEUX PERSE BÛMICH",NULL},
/* 103D0 */ { "SÉPARATEUR DE MOTS VIEUX PERSE",NULL},
/* 103D1 */ { "NOMBRE VIEUX PERSE UN",NULL},
/* 103D2 */ { "NOMBRE VIEUX PERSE DEUX",NULL},
/* 103D3 */ { "NOMBRE VIEUX PERSE DIX",NULL},
/* 103D4 */ { "NOMBRE VIEUX PERSE VINGT",NULL},
/* 103D5 */ { "NOMBRE VIEUX PERSE CENT",NULL},
/* 103D6 */ { NULL,NULL},
/* 103D7 */ { NULL,NULL},
/* 103D8 */ { NULL,NULL},
/* 103D9 */ { NULL,NULL},
/* 103DA */ { NULL,NULL},
/* 103DB */ { NULL,NULL},
/* 103DC */ { NULL,NULL},
/* 103DD */ { NULL,NULL},
/* 103DE */ { NULL,NULL},
/* 103DF */ { NULL,NULL},
/* 103E0 */ { NULL,NULL},
/* 103E1 */ { NULL,NULL},
/* 103E2 */ { NULL,NULL},
/* 103E3 */ { NULL,NULL},
/* 103E4 */ { NULL,NULL},
/* 103E5 */ { NULL,NULL},
/* 103E6 */ { NULL,NULL},
/* 103E7 */ { NULL,NULL},
/* 103E8 */ { NULL,NULL},
/* 103E9 */ { NULL,NULL},
/* 103EA */ { NULL,NULL},
/* 103EB */ { NULL,NULL},
/* 103EC */ { NULL,NULL},
/* 103ED */ { NULL,NULL},
/* 103EE */ { NULL,NULL},
/* 103EF */ { NULL,NULL},
/* 103F0 */ { NULL,NULL},
/* 103F1 */ { NULL,NULL},
/* 103F2 */ { NULL,NULL},
/* 103F3 */ { NULL,NULL},
/* 103F4 */ { NULL,NULL},
/* 103F5 */ { NULL,NULL},
/* 103F6 */ { NULL,NULL},
/* 103F7 */ { NULL,NULL},
/* 103F8 */ { NULL,NULL},
/* 103F9 */ { NULL,NULL},
/* 103FA */ { NULL,NULL},
/* 103FB */ { NULL,NULL},
/* 103FC */ { NULL,NULL},
/* 103FD */ { NULL,NULL},
/* 103FE */ { NULL,NULL},
/* 103FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_04[] = {
/* 10400 */ { "LETTRE MAJUSCULE DÉSÉRET I LONG",NULL},
/* 10401 */ { "LETTRE MAJUSCULE DÉSÉRET E LONG",NULL},
/* 10402 */ { "LETTRE MAJUSCULE DÉSÉRET A LONG",NULL},
/* 10403 */ { "LETTRE MAJUSCULE DÉSÉRET AH LONG",NULL},
/* 10404 */ { "LETTRE MAJUSCULE DÉSÉRET O LONG",NULL},
/* 10405 */ { "LETTRE MAJUSCULE DÉSÉRET OO LONG",NULL},
/* 10406 */ { "LETTRE MAJUSCULE DÉSÉRET I BREF",NULL},
/* 10407 */ { "LETTRE MAJUSCULE DÉSÉRET E BREF",NULL},
/* 10408 */ { "LETTRE MAJUSCULE DÉSÉRET A BREF",NULL},
/* 10409 */ { "LETTRE MAJUSCULE DÉSÉRET AH BREF",NULL},
/* 1040A */ { "LETTRE MAJUSCULE DÉSÉRET O BREF",NULL},
/* 1040B */ { "LETTRE MAJUSCULE DÉSÉRET OO BREF",NULL},
/* 1040C */ { "LETTRE MAJUSCULE DÉSÉRET AY",NULL},
/* 1040D */ { "LETTRE MAJUSCULE DÉSÉRET OW",NULL},
/* 1040E */ { "LETTRE MAJUSCULE DÉSÉRET WU",NULL},
/* 1040F */ { "LETTRE MAJUSCULE DÉSÉRET YEE",NULL},
/* 10410 */ { "LETTRE MAJUSCULE DÉSÉRET H",NULL},
/* 10411 */ { "LETTRE MAJUSCULE DÉSÉRET PEE",NULL},
/* 10412 */ { "LETTRE MAJUSCULE DÉSÉRET BEE",NULL},
/* 10413 */ { "LETTRE MAJUSCULE DÉSÉRET TEE",NULL},
/* 10414 */ { "LETTRE MAJUSCULE DÉSÉRET DEE",NULL},
/* 10415 */ { "LETTRE MAJUSCULE DÉSÉRET CHEE",NULL},
/* 10416 */ { "LETTRE MAJUSCULE DÉSÉRET JEE",NULL},
/* 10417 */ { "LETTRE MAJUSCULE DÉSÉRET KAY",NULL},
/* 10418 */ { "LETTRE MAJUSCULE DÉSÉRET GAY",NULL},
/* 10419 */ { "LETTRE MAJUSCULE DÉSÉRET EFFE",NULL},
/* 1041A */ { "LETTRE MAJUSCULE DÉSÉRET VEE",NULL},
/* 1041B */ { "LETTRE MAJUSCULE DÉSÉRET ETH",NULL},
/* 1041C */ { "LETTRE MAJUSCULE DÉSÉRET THEE",NULL},
/* 1041D */ { "LETTRE MAJUSCULE DÉSÉRET ES",NULL},
/* 1041E */ { "LETTRE MAJUSCULE DÉSÉRET ZEE",NULL},
/* 1041F */ { "LETTRE MAJUSCULE DÉSÉRET ESH",NULL},
/* 10420 */ { "LETTRE MAJUSCULE DÉSÉRET ZHEE",NULL},
/* 10421 */ { "LETTRE MAJUSCULE DÉSÉRET ER",NULL},
/* 10422 */ { "LETTRE MAJUSCULE DÉSÉRET ELLE",NULL},
/* 10423 */ { "LETTRE MAJUSCULE DÉSÉRET EMME",NULL},
/* 10424 */ { "LETTRE MAJUSCULE DÉSÉRET ENNE",NULL},
/* 10425 */ { "LETTRE MAJUSCULE DÉSÉRET ENG",NULL},
/* 10426 */ { "LETTRE MAJUSCULE DÉSÉRET OI",NULL},
/* 10427 */ { "LETTRE MAJUSCULE DÉSÉRET EW",NULL},
/* 10428 */ { "LETTRE MINUSCULE DÉSÉRET I LONG",NULL},
/* 10429 */ { "LETTRE MINUSCULE DÉSÉRET E LONG",NULL},
/* 1042A */ { "LETTRE MINUSCULE DÉSÉRET A LONG",NULL},
/* 1042B */ { "LETTRE MINUSCULE DÉSÉRET AH LONG",NULL},
/* 1042C */ { "LETTRE MINUSCULE DÉSÉRET O LONG",NULL},
/* 1042D */ { "LETTRE MINUSCULE DÉSÉRET OO LONG",NULL},
/* 1042E */ { "LETTRE MINUSCULE DÉSÉRET I BREF",NULL},
/* 1042F */ { "LETTRE MINUSCULE DÉSÉRET E BREF",NULL},
/* 10430 */ { "LETTRE MINUSCULE DÉSÉRET A BREF",NULL},
/* 10431 */ { "LETTRE MINUSCULE DÉSÉRET AH BREF",NULL},
/* 10432 */ { "LETTRE MINUSCULE DÉSÉRET O BREF",NULL},
/* 10433 */ { "LETTRE MINUSCULE DÉSÉRET OO BREF",NULL},
/* 10434 */ { "LETTRE MINUSCULE DÉSÉRET AY",NULL},
/* 10435 */ { "LETTRE MINUSCULE DÉSÉRET OW",NULL},
/* 10436 */ { "LETTRE MINUSCULE DÉSÉRET WU",NULL},
/* 10437 */ { "LETTRE MINUSCULE DÉSÉRET YEE",NULL},
/* 10438 */ { "LETTRE MINUSCULE DÉSÉRET H",NULL},
/* 10439 */ { "LETTRE MINUSCULE DÉSÉRET PEE",NULL},
/* 1043A */ { "LETTRE MINUSCULE DÉSÉRET BEE",NULL},
/* 1043B */ { "LETTRE MINUSCULE DÉSÉRET TEE",NULL},
/* 1043C */ { "LETTRE MINUSCULE DÉSÉRET DEE",NULL},
/* 1043D */ { "LETTRE MINUSCULE DÉSÉRET CHEE",NULL},
/* 1043E */ { "LETTRE MINUSCULE DÉSÉRET JEE",NULL},
/* 1043F */ { "LETTRE MINUSCULE DÉSÉRET KAY",NULL},
/* 10440 */ { "LETTRE MINUSCULE DÉSÉRET GAY",NULL},
/* 10441 */ { "LETTRE MINUSCULE DÉSÉRET EFFE",NULL},
/* 10442 */ { "LETTRE MINUSCULE DÉSÉRET VEE",NULL},
/* 10443 */ { "LETTRE MINUSCULE DÉSÉRET ETH",NULL},
/* 10444 */ { "LETTRE MINUSCULE DÉSÉRET THEE",NULL},
/* 10445 */ { "LETTRE MINUSCULE DÉSÉRET ES",NULL},
/* 10446 */ { "LETTRE MINUSCULE DÉSÉRET ZEE",NULL},
/* 10447 */ { "LETTRE MINUSCULE DÉSÉRET ESH",NULL},
/* 10448 */ { "LETTRE MINUSCULE DÉSÉRET ZHEE",NULL},
/* 10449 */ { "LETTRE MINUSCULE DÉSÉRET ER",NULL},
/* 1044A */ { "LETTRE MINUSCULE DÉSÉRET EL",NULL},
/* 1044B */ { "LETTRE MINUSCULE DÉSÉRET EMME",NULL},
/* 1044C */ { "LETTRE MINUSCULE DÉSÉRET ENNE",NULL},
/* 1044D */ { "LETTRE MINUSCULE DÉSÉRET ENG",NULL},
/* 1044E */ { "LETTRE MINUSCULE DÉSÉRET OI",NULL},
/* 1044F */ { "LETTRE MINUSCULE DÉSÉRET EW",NULL},
/* 10450 */ { "LETTRE SHAVIENNE PEEP",NULL},
/* 10451 */ { "LETTRE SHAVIENNE TOT",NULL},
/* 10452 */ { "LETTRE SHAVIENNE KICK",NULL},
/* 10453 */ { "LETTRE SHAVIENNE FEE",NULL},
/* 10454 */ { "LETTRE SHAVIENNE THIGH",NULL},
/* 10455 */ { "LETTRE SHAVIENNE SO",NULL},
/* 10456 */ { "LETTRE SHAVIENNE SURE",NULL},
/* 10457 */ { "LETTRE SHAVIENNE CHURCH",NULL},
/* 10458 */ { "LETTRE SHAVIENNE YEA","	* spirante palatale sonore"},
/* 10459 */ { "LETTRE SHAVIENNE HUNG","	* nasale vélaire sonore"},
/* 1045A */ { "LETTRE SHAVIENNE BIB",NULL},
/* 1045B */ { "LETTRE SHAVIENNE DEAD",NULL},
/* 1045C */ { "LETTRE SHAVIENNE GAG",NULL},
/* 1045D */ { "LETTRE SHAVIENNE VOW",NULL},
/* 1045E */ { "LETTRE SHAVIENNE THEY",NULL},
/* 1045F */ { "LETTRE SHAVIENNE ZOO",NULL},
/* 10460 */ { "LETTRE SHAVIENNE MEASURE",NULL},
/* 10461 */ { "LETTRE SHAVIENNE JUDGE",NULL},
/* 10462 */ { "LETTRE SHAVIENNE WOE","	* spirante labiovélaire sonore"},
/* 10463 */ { "LETTRE SHAVIENNE HA-HA","	* fricative glottale sourde"},
/* 10464 */ { "LETTRE SHAVIENNE LOLL",NULL},
/* 10465 */ { "LETTRE SHAVIENNE MIME",NULL},
/* 10466 */ { "LETTRE SHAVIENNE IF",NULL},
/* 10467 */ { "LETTRE SHAVIENNE EGG",NULL},
/* 10468 */ { "LETTRE SHAVIENNE ASH",NULL},
/* 10469 */ { "LETTRE SHAVIENNE ADO",NULL},
/* 1046A */ { "LETTRE SHAVIENNE ON",NULL},
/* 1046B */ { "LETTRE SHAVIENNE WOOL",NULL},
/* 1046C */ { "LETTRE SHAVIENNE OUT",NULL},
/* 1046D */ { "LETTRE SHAVIENNE AH",NULL},
/* 1046E */ { "LETTRE SHAVIENNE ROAR",NULL},
/* 1046F */ { "LETTRE SHAVIENNE NUN",NULL},
/* 10470 */ { "LETTRE SHAVIENNE EAT",NULL},
/* 10471 */ { "LETTRE SHAVIENNE AGE",NULL},
/* 10472 */ { "LETTRE SHAVIENNE ICE",NULL},
/* 10473 */ { "LETTRE SHAVIENNE UP",NULL},
/* 10474 */ { "LETTRE SHAVIENNE OAK",NULL},
/* 10475 */ { "LETTRE SHAVIENNE OOZE",NULL},
/* 10476 */ { "LETTRE SHAVIENNE OIL",NULL},
/* 10477 */ { "LETTRE SHAVIENNE AWE",NULL},
/* 10478 */ { "LETTRE SHAVIENNE ARE",NULL},
/* 10479 */ { "LETTRE SHAVIENNE OR",NULL},
/* 1047A */ { "LETTRE SHAVIENNE AIR",NULL},
/* 1047B */ { "LETTRE SHAVIENNE ERR",NULL},
/* 1047C */ { "LETTRE SHAVIENNE ARRAY",NULL},
/* 1047D */ { "LETTRE SHAVIENNE EAR",NULL},
/* 1047E */ { "LETTRE SHAVIENNE IAN",NULL},
/* 1047F */ { "LETTRE SHAVIENNE YEW",NULL},
/* 10480 */ { "LETTRE OSMANYA ALIF",NULL},
/* 10481 */ { "LETTRE OSMANYA BA",NULL},
/* 10482 */ { "LETTRE OSMANYA TA",NULL},
/* 10483 */ { "LETTRE OSMANYA DJA",NULL},
/* 10484 */ { "LETTRE OSMANYA XA",NULL},
/* 10485 */ { "LETTRE OSMANYA KHA",NULL},
/* 10486 */ { "LETTRE OSMANYA DÊL",NULL},
/* 10487 */ { "LETTRE OSMANYA RA",NULL},
/* 10488 */ { "LETTRE OSMANYA SA",NULL},
/* 10489 */ { "LETTRE OSMANYA CHÎN",NULL},
/* 1048A */ { "LETTRE OSMANYA DHA",NULL},
/* 1048B */ { "LETTRE OSMANYA CAÏN",NULL},
/* 1048C */ { "LETTRE OSMANYA GA",NULL},
/* 1048D */ { "LETTRE OSMANYA FA",NULL},
/* 1048E */ { "LETTRE OSMANYA QÂF",NULL},
/* 1048F */ { "LETTRE OSMANYA KÂF",NULL},
/* 10490 */ { "LETTRE OSMANYA LÂN",NULL},
/* 10491 */ { "LETTRE OSMANYA MÎN",NULL},
/* 10492 */ { "LETTRE OSMANYA NOÛN",NULL},
/* 10493 */ { "LETTRE OSMANYA WAW",NULL},
/* 10494 */ { "LETTRE OSMANYA HA",NULL},
/* 10495 */ { "LETTRE OSMANYA YA",NULL},
/* 10496 */ { "LETTRE OSMANYA A",NULL},
/* 10497 */ { "LETTRE OSMANYA É",NULL},
/* 10498 */ { "LETTRE OSMANYA I",NULL},
/* 10499 */ { "LETTRE OSMANYA O",NULL},
/* 1049A */ { "LETTRE OSMANYA OU",NULL},
/* 1049B */ { "LETTRE OSMANYA Â",NULL},
/* 1049C */ { "LETTRE OSMANYA Ê",NULL},
/* 1049D */ { "LETTRE OSMANYA Ô",NULL},
/* 1049E */ { NULL,NULL},
/* 1049F */ { NULL,NULL},
/* 104A0 */ { "CHIFFRE OSMANYA ZÉRO",NULL},
/* 104A1 */ { "CHIFFRE OSMANYA UN",NULL},
/* 104A2 */ { "CHIFFRE OSMANYA DEUX",NULL},
/* 104A3 */ { "CHIFFRE OSMANYA TROIS",NULL},
/* 104A4 */ { "CHIFFRE OSMANYA QUATRE",NULL},
/* 104A5 */ { "CHIFFRE OSMANYA CINQ",NULL},
/* 104A6 */ { "CHIFFRE OSMANYA SIX",NULL},
/* 104A7 */ { "CHIFFRE OSMANYA SEPT",NULL},
/* 104A8 */ { "CHIFFRE OSMANYA HUIT",NULL},
/* 104A9 */ { "CHIFFRE OSMANYA NEUF",NULL},
/* 104AA */ { NULL,NULL},
/* 104AB */ { NULL,NULL},
/* 104AC */ { NULL,NULL},
/* 104AD */ { NULL,NULL},
/* 104AE */ { NULL,NULL},
/* 104AF */ { NULL,NULL},
/* 104B0 */ { "LETTRE MAJUSCULE OSAGE A",NULL},
/* 104B1 */ { "LETTRE MAJUSCULE OSAGE AI",NULL},
/* 104B2 */ { "LETTRE MAJUSCULE OSAGE AIN",NULL},
/* 104B3 */ { "LETTRE MAJUSCULE OSAGE AH",NULL},
/* 104B4 */ { "LETTRE MAJUSCULE OSAGE BRA",NULL},
/* 104B5 */ { "LETTRE MAJUSCULE OSAGE CHA",NULL},
/* 104B6 */ { "LETTRE MAJUSCULE OSAGE EHCHA",NULL},
/* 104B7 */ { "LETTRE MAJUSCULE OSAGE E",NULL},
/* 104B8 */ { "LETTRE MAJUSCULE OSAGE EIN",NULL},
/* 104B9 */ { "LETTRE MAJUSCULE OSAGE HA",NULL},
/* 104BA */ { "LETTRE MAJUSCULE OSAGE HYA",NULL},
/* 104BB */ { "LETTRE MAJUSCULE OSAGE I",NULL},
/* 104BC */ { "LETTRE MAJUSCULE OSAGE KA",NULL},
/* 104BD */ { "LETTRE MAJUSCULE OSAGE EHKA",NULL},
/* 104BE */ { "LETTRE MAJUSCULE OSAGE KYA",NULL},
/* 104BF */ { "LETTRE MAJUSCULE OSAGE LA",NULL},
/* 104C0 */ { "LETTRE MAJUSCULE OSAGE MA",NULL},
/* 104C1 */ { "LETTRE MAJUSCULE OSAGE NA",NULL},
/* 104C2 */ { "LETTRE MAJUSCULE OSAGE O",NULL},
/* 104C3 */ { "LETTRE MAJUSCULE OSAGE OIN",NULL},
/* 104C4 */ { "LETTRE MAJUSCULE OSAGE PA",NULL},
/* 104C5 */ { "LETTRE MAJUSCULE OSAGE EHPA",NULL},
/* 104C6 */ { "LETTRE MAJUSCULE OSAGE SA",NULL},
/* 104C7 */ { "LETTRE MAJUSCULE OSAGE SHA",NULL},
/* 104C8 */ { "LETTRE MAJUSCULE OSAGE TA",NULL},
/* 104C9 */ { "LETTRE MAJUSCULE OSAGE EHTA",NULL},
/* 104CA */ { "LETTRE MAJUSCULE OSAGE TSA",NULL},
/* 104CB */ { "LETTRE MAJUSCULE OSAGE EHTSA",NULL},
/* 104CC */ { "LETTRE MAJUSCULE OSAGE TSHA",NULL},
/* 104CD */ { "LETTRE MAJUSCULE OSAGE DHA",NULL},
/* 104CE */ { "LETTRE MAJUSCULE OSAGE U",NULL},
/* 104CF */ { "LETTRE MAJUSCULE OSAGE WA",NULL},
/* 104D0 */ { "LETTRE MAJUSCULE OSAGE KHA",NULL},
/* 104D1 */ { "LETTRE MAJUSCULE OSAGE GHA",NULL},
/* 104D2 */ { "LETTRE MAJUSCULE OSAGE ZA",NULL},
/* 104D3 */ { "LETTRE MAJUSCULE OSAGE ZHA",NULL},
/* 104D4 */ { NULL,NULL},
/* 104D5 */ { NULL,NULL},
/* 104D6 */ { NULL,NULL},
/* 104D7 */ { NULL,NULL},
/* 104D8 */ { "LETTRE MINUSCULE OSAGE A",NULL},
/* 104D9 */ { "LETTRE MINUSCULE OSAGE AI",NULL},
/* 104DA */ { "LETTRE MINUSCULE OSAGE AIN",NULL},
/* 104DB */ { "LETTRE MINUSCULE OSAGE AH",NULL},
/* 104DC */ { "LETTRE MINUSCULE OSAGE BRA",NULL},
/* 104DD */ { "LETTRE MINUSCULE OSAGE CHA",NULL},
/* 104DE */ { "LETTRE MINUSCULE OSAGE EHCHA",NULL},
/* 104DF */ { "LETTRE MINUSCULE OSAGE E",NULL},
/* 104E0 */ { "LETTRE MINUSCULE OSAGE EIN",NULL},
/* 104E1 */ { "LETTRE MINUSCULE OSAGE HA",NULL},
/* 104E2 */ { "LETTRE MINUSCULE OSAGE HYA",NULL},
/* 104E3 */ { "LETTRE MINUSCULE OSAGE I",NULL},
/* 104E4 */ { "LETTRE MINUSCULE OSAGE KA",NULL},
/* 104E5 */ { "LETTRE MINUSCULE OSAGE EHKA",NULL},
/* 104E6 */ { "LETTRE MINUSCULE OSAGE KYA",NULL},
/* 104E7 */ { "LETTRE MINUSCULE OSAGE LA",NULL},
/* 104E8 */ { "LETTRE MINUSCULE OSAGE MA",NULL},
/* 104E9 */ { "LETTRE MINUSCULE OSAGE NA",NULL},
/* 104EA */ { "LETTRE MINUSCULE OSAGE O",NULL},
/* 104EB */ { "LETTRE MINUSCULE OSAGE OIN",NULL},
/* 104EC */ { "LETTRE MINUSCULE OSAGE PA",NULL},
/* 104ED */ { "LETTRE MINUSCULE OSAGE EHPA",NULL},
/* 104EE */ { "LETTRE MINUSCULE OSAGE SA",NULL},
/* 104EF */ { "LETTRE MINUSCULE OSAGE SHA",NULL},
/* 104F0 */ { "LETTRE MINUSCULE OSAGE TA",NULL},
/* 104F1 */ { "LETTRE MINUSCULE OSAGE EHTA",NULL},
/* 104F2 */ { "LETTRE MINUSCULE OSAGE TSA",NULL},
/* 104F3 */ { "LETTRE MINUSCULE OSAGE EHTSA",NULL},
/* 104F4 */ { "LETTRE MINUSCULE OSAGE TSHA",NULL},
/* 104F5 */ { "LETTRE MINUSCULE OSAGE DHA",NULL},
/* 104F6 */ { "LETTRE MINUSCULE OSAGE U",NULL},
/* 104F7 */ { "LETTRE MINUSCULE OSAGE WA",NULL},
/* 104F8 */ { "LETTRE MINUSCULE OSAGE KHA",NULL},
/* 104F9 */ { "LETTRE MINUSCULE OSAGE GHA",NULL},
/* 104FA */ { "LETTRE MINUSCULE OSAGE ZA",NULL},
/* 104FB */ { "LETTRE MINUSCULE OSAGE ZHA",NULL},
/* 104FC */ { NULL,NULL},
/* 104FD */ { NULL,NULL},
/* 104FE */ { NULL,NULL},
/* 104FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_05[] = {
/* 10500 */ { "LETTRE ELBASAN A",NULL},
/* 10501 */ { "LETTRE ELBASAN B",NULL},
/* 10502 */ { "LETTRE ELBASAN C",NULL},
/* 10503 */ { "LETTRE ELBASAN Ç",NULL},
/* 10504 */ { "LETTRE ELBASAN D",NULL},
/* 10505 */ { "LETTRE ELBASAN ND",NULL},
/* 10506 */ { "LETTRE ELBASAN DH",NULL},
/* 10507 */ { "LETTRE ELBASAN E",NULL},
/* 10508 */ { "LETTRE ELBASAN Ë",NULL},
/* 10509 */ { "LETTRE ELBASAN F",NULL},
/* 1050A */ { "LETTRE ELBASAN G",NULL},
/* 1050B */ { "LETTRE ELBASAN GJ",NULL},
/* 1050C */ { "LETTRE ELBASAN H",NULL},
/* 1050D */ { "LETTRE ELBASAN I",NULL},
/* 1050E */ { "LETTRE ELBASAN J",NULL},
/* 1050F */ { "LETTRE ELBASAN K",NULL},
/* 10510 */ { "LETTRE ELBASAN L",NULL},
/* 10511 */ { "LETTRE ELBASAN LL",NULL},
/* 10512 */ { "LETTRE ELBASAN M",NULL},
/* 10513 */ { "LETTRE ELBASAN N",NULL},
/* 10514 */ { "LETTRE ELBASAN NA",NULL},
/* 10515 */ { "LETTRE ELBASAN NJ",NULL},
/* 10516 */ { "LETTRE ELBASAN O",NULL},
/* 10517 */ { "LETTRE ELBASAN P",NULL},
/* 10518 */ { "LETTRE ELBASAN Q",NULL},
/* 10519 */ { "LETTRE ELBASAN R",NULL},
/* 1051A */ { "LETTRE ELBASAN RR",NULL},
/* 1051B */ { "LETTRE ELBASAN S",NULL},
/* 1051C */ { "LETTRE ELBASAN SH",NULL},
/* 1051D */ { "LETTRE ELBASAN T",NULL},
/* 1051E */ { "LETTRE ELBASAN TH",NULL},
/* 1051F */ { "LETTRE ELBASAN U",NULL},
/* 10520 */ { "LETTRE ELBASAN V",NULL},
/* 10521 */ { "LETTRE ELBASAN X",NULL},
/* 10522 */ { "LETTRE ELBASAN Y",NULL},
/* 10523 */ { "LETTRE ELBASAN Z",NULL},
/* 10524 */ { "LETTRE ELBASAN ZH",NULL},
/* 10525 */ { "LETTRE ELBASAN GH",NULL},
/* 10526 */ { "LETTRE ELBASAN GHAMMA",NULL},
/* 10527 */ { "LETTRE ELBASAN KH",NULL},
/* 10528 */ { NULL,NULL},
/* 10529 */ { NULL,NULL},
/* 1052A */ { NULL,NULL},
/* 1052B */ { NULL,NULL},
/* 1052C */ { NULL,NULL},
/* 1052D */ { NULL,NULL},
/* 1052E */ { NULL,NULL},
/* 1052F */ { NULL,NULL},
/* 10530 */ { "LETTRE ALBANIENNE ALT",NULL},
/* 10531 */ { "LETTRE ALBANIENNE BET",NULL},
/* 10532 */ { "LETTRE ALBANIENNE GIM",NULL},
/* 10533 */ { "LETTRE ALBANIENNE DAT",NULL},
/* 10534 */ { "LETTRE ALBANIENNE EB",NULL},
/* 10535 */ { "LETTRE ALBANIENNE ZARL",NULL},
/* 10536 */ { "LETTRE ALBANIENNE EYN",NULL},
/* 10537 */ { "LETTRE ALBANIENNE ZHIL",NULL},
/* 10538 */ { "LETTRE ALBANIENNE TAS",NULL},
/* 10539 */ { "LETTRE ALBANIENNE CHA",NULL},
/* 1053A */ { "LETTRE ALBANIENNE YOWD",NULL},
/* 1053B */ { "LETTRE ALBANIENNE ZHA",NULL},
/* 1053C */ { "LETTRE ALBANIENNE IRB",NULL},
/* 1053D */ { "LETTRE ALBANIENNE SHA",NULL},
/* 1053E */ { "LETTRE ALBANIENNE LAN",NULL},
/* 1053F */ { "LETTRE ALBANIENNE INYA",NULL},
/* 10540 */ { "LETTRE ALBANIENNE XEYN",NULL},
/* 10541 */ { "LETTRE ALBANIENNE DYAN",NULL},
/* 10542 */ { "LETTRE ALBANIENNE CAR",NULL},
/* 10543 */ { "LETTRE ALBANIENNE JHOX",NULL},
/* 10544 */ { "LETTRE ALBANIENNE KAR",NULL},
/* 10545 */ { "LETTRE ALBANIENNE LYIT",NULL},
/* 10546 */ { "LETTRE ALBANIENNE HEYT",NULL},
/* 10547 */ { "LETTRE ALBANIENNE QAY",NULL},
/* 10548 */ { "LETTRE ALBANIENNE AOR",NULL},
/* 10549 */ { "LETTRE ALBANIENNE CHOY",NULL},
/* 1054A */ { "LETTRE ALBANIENNE CHI",NULL},
/* 1054B */ { "LETTRE ALBANIENNE CYAY",NULL},
/* 1054C */ { "LETTRE ALBANIENNE MAQ",NULL},
/* 1054D */ { "LETTRE ALBANIENNE QAR",NULL},
/* 1054E */ { "LETTRE ALBANIENNE NOWC",NULL},
/* 1054F */ { "LETTRE ALBANIENNE DZYAY",NULL},
/* 10550 */ { "LETTRE ALBANIENNE SHAK",NULL},
/* 10551 */ { "LETTRE ALBANIENNE JAYN",NULL},
/* 10552 */ { "LETTRE ALBANIENNE ON",NULL},
/* 10553 */ { "LETTRE ALBANIENNE TYAY",NULL},
/* 10554 */ { "LETTRE ALBANIENNE FAM",NULL},
/* 10555 */ { "LETTRE ALBANIENNE DZAY",NULL},
/* 10556 */ { "LETTRE ALBANIENNE CHAT",NULL},
/* 10557 */ { "LETTRE ALBANIENNE PEN",NULL},
/* 10558 */ { "LETTRE ALBANIENNE GHEYS",NULL},
/* 10559 */ { "LETTRE ALBANIENNE RAT",NULL},
/* 1055A */ { "LETTRE ALBANIENNE SEYK",NULL},
/* 1055B */ { "LETTRE ALBANIENNE VEYZ",NULL},
/* 1055C */ { "LETTRE ALBANIENNE TIWR",NULL},
/* 1055D */ { "LETTRE ALBANIENNE SHOY",NULL},
/* 1055E */ { "LETTRE ALBANIENNE IWN",NULL},
/* 1055F */ { "LETTRE ALBANIENNE CYAW",NULL},
/* 10560 */ { "LETTRE ALBANIENNE CAYN",NULL},
/* 10561 */ { "LETTRE ALBANIENNE YAYD",NULL},
/* 10562 */ { "LETTRE ALBANIENNE PIWR",NULL},
/* 10563 */ { "LETTRE ALBANIENNE KIW",NULL},
/* 10564 */ { NULL,NULL},
/* 10565 */ { NULL,NULL},
/* 10566 */ { NULL,NULL},
/* 10567 */ { NULL,NULL},
/* 10568 */ { NULL,NULL},
/* 10569 */ { NULL,NULL},
/* 1056A */ { NULL,NULL},
/* 1056B */ { NULL,NULL},
/* 1056C */ { NULL,NULL},
/* 1056D */ { NULL,NULL},
/* 1056E */ { NULL,NULL},
/* 1056F */ { "MARQUE DE CITATION ALBANIENNE",NULL},
/* 10570 */ { "LETTRE MAJUSCULE VITHKUQI A",NULL},
/* 10571 */ { "LETTRE MAJUSCULE VITHKUQI BB",NULL},
/* 10572 */ { "LETTRE MAJUSCULE VITHKUQI B",NULL},
/* 10573 */ { "LETTRE MAJUSCULE VITHKUQI C",NULL},
/* 10574 */ { "LETTRE MAJUSCULE VITHKUQI Ç",NULL},
/* 10575 */ { "LETTRE MAJUSCULE VITHKUQI D",NULL},
/* 10576 */ { "LETTRE MAJUSCULE VITHKUQI DH",NULL},
/* 10577 */ { "LETTRE MAJUSCULE VITHKUQI E",NULL},
/* 10578 */ { "LETTRE MAJUSCULE VITHKUQI Ë",NULL},
/* 10579 */ { "LETTRE MAJUSCULE VITHKUQI F",NULL},
/* 1057A */ { "LETTRE MAJUSCULE VITHKUQI G",NULL},
/* 1057B */ { NULL,NULL},
/* 1057C */ { "LETTRE MAJUSCULE VITHKUQI H",NULL},
/* 1057D */ { "LETTRE MAJUSCULE VITHKUQI HH","	* utilisée dans l'orthographe du XIXe siècle"},
/* 1057E */ { "LETTRE MAJUSCULE VITHKUQI I",NULL},
/* 1057F */ { "LETTRE MAJUSCULE VITHKUQI IJ","	* utilisée dans l'orthographe du XIXe siècle"},
/* 10580 */ { "LETTRE MAJUSCULE VITHKUQI J",NULL},
/* 10581 */ { "LETTRE MAJUSCULE VITHKUQI K",NULL},
/* 10582 */ { "LETTRE MAJUSCULE VITHKUQI L",NULL},
/* 10583 */ { "LETTRE MAJUSCULE VITHKUQI LL",NULL},
/* 10584 */ { "LETTRE MAJUSCULE VITHKUQI M",NULL},
/* 10585 */ { "LETTRE MAJUSCULE VITHKUQI N",NULL},
/* 10586 */ { "LETTRE MAJUSCULE VITHKUQI NJ",NULL},
/* 10587 */ { "LETTRE MAJUSCULE VITHKUQI O",NULL},
/* 10588 */ { "LETTRE MAJUSCULE VITHKUQI P",NULL},
/* 10589 */ { "LETTRE MAJUSCULE VITHKUQI Q",NULL},
/* 1058A */ { "LETTRE MAJUSCULE VITHKUQI R",NULL},
/* 1058B */ { NULL,NULL},
/* 1058C */ { "LETTRE MAJUSCULE VITHKUQI S",NULL},
/* 1058D */ { "LETTRE MAJUSCULE VITHKUQI SH",NULL},
/* 1058E */ { "LETTRE MAJUSCULE VITHKUQI T",NULL},
/* 1058F */ { "LETTRE MAJUSCULE VITHKUQI TH",NULL},
/* 10590 */ { "LETTRE MAJUSCULE VITHKUQI U",NULL},
/* 10591 */ { "LETTRE MAJUSCULE VITHKUQI V",NULL},
/* 10592 */ { "LETTRE MAJUSCULE VITHKUQI X",NULL},
/* 10593 */ { NULL,NULL},
/* 10594 */ { "LETTRE MAJUSCULE VITHKUQI Y",NULL},
/* 10595 */ { "LETTRE MAJUSCULE VITHKUQI Z",NULL},
/* 10596 */ { NULL,NULL},
/* 10597 */ { "LETTRE MINUSCULE VITHKUQI A",NULL},
/* 10598 */ { "LETTRE MINUSCULE VITHKUQI BB",NULL},
/* 10599 */ { "LETTRE MINUSCULE VITHKUQI B",NULL},
/* 1059A */ { "LETTRE MINUSCULE VITHKUQI C",NULL},
/* 1059B */ { "LETTRE MINUSCULE VITHKUQI Ç",NULL},
/* 1059C */ { "LETTRE MINUSCULE VITHKUQI D",NULL},
/* 1059D */ { "LETTRE MINUSCULE VITHKUQI DH",NULL},
/* 1059E */ { "LETTRE MINUSCULE VITHKUQI E",NULL},
/* 1059F */ { "LETTRE MINUSCULE VITHKUQI Ë",NULL},
/* 105A0 */ { "LETTRE MINUSCULE VITHKUQI F",NULL},
/* 105A1 */ { "LETTRE MINUSCULE VITHKUQI G",NULL},
/* 105A2 */ { NULL,NULL},
/* 105A3 */ { "LETTRE MINUSCULE VITHKUQI H",NULL},
/* 105A4 */ { "LETTRE MINUSCULE VITHKUQI HH","	* utilisée dans l'orthographe du XIXe siècle"},
/* 105A5 */ { "LETTRE MINUSCULE VITHKUQI I",NULL},
/* 105A6 */ { "LETTRE MINUSCULE VITHKUQI IJ","	* utilisée dans l'orthographe du XIXe siècle"},
/* 105A7 */ { "LETTRE MINUSCULE VITHKUQI J",NULL},
/* 105A8 */ { "LETTRE MINUSCULE VITHKUQI K",NULL},
/* 105A9 */ { "LETTRE MINUSCULE VITHKUQI L",NULL},
/* 105AA */ { "LETTRE MINUSCULE VITHKUQI LL",NULL},
/* 105AB */ { "LETTRE MINUSCULE VITHKUQI M",NULL},
/* 105AC */ { "LETTRE MINUSCULE VITHKUQI N",NULL},
/* 105AD */ { "LETTRE MINUSCULE VITHKUQI NJ",NULL},
/* 105AE */ { "LETTRE MINUSCULE VITHKUQI O",NULL},
/* 105AF */ { "LETTRE MINUSCULE VITHKUQI P",NULL},
/* 105B0 */ { "LETTRE MINUSCULE VITHKUQI Q",NULL},
/* 105B1 */ { "LETTRE MINUSCULE VITHKUQI R",NULL},
/* 105B2 */ { NULL,NULL},
/* 105B3 */ { "LETTRE MINUSCULE VITHKUQI S",NULL},
/* 105B4 */ { "LETTRE MINUSCULE VITHKUQI SH",NULL},
/* 105B5 */ { "LETTRE MINUSCULE VITHKUQI T",NULL},
/* 105B6 */ { "LETTRE MINUSCULE VITHKUQI TH",NULL},
/* 105B7 */ { "LETTRE MINUSCULE VITHKUQI U",NULL},
/* 105B8 */ { "LETTRE MINUSCULE VITHKUQI V",NULL},
/* 105B9 */ { "LETTRE MINUSCULE VITHKUQI X",NULL},
/* 105BA */ { NULL,NULL},
/* 105BB */ { "LETTRE MINUSCULE VITHKUQI Y",NULL},
/* 105BC */ { "LETTRE MINUSCULE VITHKUQI Z",NULL},
/* 105BD */ { NULL,NULL},
/* 105BE */ { NULL,NULL},
/* 105BF */ { NULL,NULL},
/* 105C0 */ { "LETTRE TODHRI A",NULL},
/* 105C1 */ { "LETTRE TODHRI AS",NULL},
/* 105C2 */ { "LETTRE TODHRI BA",NULL},
/* 105C3 */ { "LETTRE TODHRI MBA",NULL},
/* 105C4 */ { "LETTRE TODHRI TSA",NULL},
/* 105C5 */ { "LETTRE TODHRI TCHA",NULL},
/* 105C6 */ { "LETTRE TODHRI DA",NULL},
/* 105C7 */ { "LETTRE TODHRI NDA",NULL},
/* 105C8 */ { "LETTRE TODHRI DHA",NULL},
/* 105C9 */ { "LETTRE TODHRI É","	: 105D2 0307"},
/* 105CA */ { "LETTRE TODHRI E",NULL},
/* 105CB */ { "LETTRE TODHRI FA",NULL},
/* 105CC */ { "LETTRE TODHRI GA",NULL},
/* 105CD */ { "LETTRE TODHRI NGA",NULL},
/* 105CE */ { "LETTRE TODHRI GIA",NULL},
/* 105CF */ { "LETTRE TODHRI NGIA",NULL},
/* 105D0 */ { "LETTRE TODHRI HA",NULL},
/* 105D1 */ { "LETTRE TODHRI HIA",NULL},
/* 105D2 */ { "LETTRE TODHRI I",NULL},
/* 105D3 */ { "LETTRE TODHRI IA",NULL},
/* 105D4 */ { "LETTRE TODHRI KA",NULL},
/* 105D5 */ { "LETTRE TODHRI LA",NULL},
/* 105D6 */ { "LETTRE TODHRI LLA",NULL},
/* 105D7 */ { "LETTRE TODHRI MA",NULL},
/* 105D8 */ { "LETTRE TODHRI NA",NULL},
/* 105D9 */ { "LETTRE TODHRI NIAN",NULL},
/* 105DA */ { "LETTRE TODHRI O",NULL},
/* 105DB */ { "LETTRE TODHRI PA",NULL},
/* 105DC */ { "LETTRE TODHRI QA",NULL},
/* 105DD */ { "LETTRE TODHRI RA",NULL},
/* 105DE */ { "LETTRE TODHRI RRA",NULL},
/* 105DF */ { "LETTRE TODHRI SA",NULL},
/* 105E0 */ { "LETTRE TODHRI CHA",NULL},
/* 105E1 */ { "LETTRE TODHRI CHTA",NULL},
/* 105E2 */ { "LETTRE TODHRI TA",NULL},
/* 105E3 */ { "LETTRE TODHRI THA",NULL},
/* 105E4 */ { "LETTRE TODHRI OU","	: 105DA 0307"},
/* 105E5 */ { "LETTRE TODHRI VA",NULL},
/* 105E6 */ { "LETTRE TODHRI XA",NULL},
/* 105E7 */ { "LETTRE TODHRI NXA",NULL},
/* 105E8 */ { "LETTRE TODHRI XHA",NULL},
/* 105E9 */ { "LETTRE TODHRI NXHA",NULL},
/* 105EA */ { "LETTRE TODHRI U",NULL},
/* 105EB */ { "LETTRE TODHRI IU",NULL},
/* 105EC */ { "LETTRE TODHRI ZA",NULL},
/* 105ED */ { "LETTRE TODHRI JA",NULL},
/* 105EE */ { "LETTRE TODHRI GHA",NULL},
/* 105EF */ { "LETTRE TODHRI STA",NULL},
/* 105F0 */ { "LETTRE TODHRI SKAN",NULL},
/* 105F1 */ { "LETTRE TODHRI KHA",NULL},
/* 105F2 */ { "LETTRE TODHRI PSA",NULL},
/* 105F3 */ { "LETTRE TODHRI Ô",NULL},
/* 105F4 */ { NULL,NULL},
/* 105F5 */ { NULL,NULL},
/* 105F6 */ { NULL,NULL},
/* 105F7 */ { NULL,NULL},
/* 105F8 */ { NULL,NULL},
/* 105F9 */ { NULL,NULL},
/* 105FA */ { NULL,NULL},
/* 105FB */ { NULL,NULL},
/* 105FC */ { NULL,NULL},
/* 105FD */ { NULL,NULL},
/* 105FE */ { NULL,NULL},
/* 105FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_06[] = {
/* 10600 */ { "SIGNE LINÉAIRE A AB001",NULL},
/* 10601 */ { "SIGNE LINÉAIRE A AB002",NULL},
/* 10602 */ { "SIGNE LINÉAIRE A AB003",NULL},
/* 10603 */ { "SIGNE LINÉAIRE A AB004",NULL},
/* 10604 */ { "SIGNE LINÉAIRE A AB005",NULL},
/* 10605 */ { "SIGNE LINÉAIRE A AB006",NULL},
/* 10606 */ { "SIGNE LINÉAIRE A AB007",NULL},
/* 10607 */ { "SIGNE LINÉAIRE A AB008",NULL},
/* 10608 */ { "SIGNE LINÉAIRE A AB009",NULL},
/* 10609 */ { "SIGNE LINÉAIRE A AB010",NULL},
/* 1060A */ { "SIGNE LINÉAIRE A AB011",NULL},
/* 1060B */ { "SIGNE LINÉAIRE A AB013",NULL},
/* 1060C */ { "SIGNE LINÉAIRE A AB016",NULL},
/* 1060D */ { "SIGNE LINÉAIRE A AB017",NULL},
/* 1060E */ { "SIGNE LINÉAIRE A AB020",NULL},
/* 1060F */ { "SIGNE LINÉAIRE A AB021","	* mouton\n"
	"	x (syllabe linéaire b b021 qi - 10025)"},
/* 10610 */ { "SIGNE LINÉAIRE A AB021F","	* brebis\n"
	"	x (idéogramme linéaire b b106f brebis - 10086)"},
/* 10611 */ { "SIGNE LINÉAIRE A AB021M","	* bélier\n"
	"	x (idéogramme linéaire b b106m bélier - 10087)"},
/* 10612 */ { "SIGNE LINÉAIRE A AB022","	* chèvre\n"
	"	x (symbole linéaire b b022 - 10052)"},
/* 10613 */ { "SIGNE LINÉAIRE A AB022F","	* bique\n"
	"	x (idéogramme linéaire b b107f bique - 10088)"},
/* 10614 */ { "SIGNE LINÉAIRE A AB022M","	* bouc\n"
	"	x (idéogramme linéaire b b10fm bouc - 10089)"},
/* 10615 */ { "SIGNE LINÉAIRE A AB023","	* bovin\n"
	"	x (syllabe linéaire b b023 mu - 10018)"},
/* 10616 */ { "SIGNE LINÉAIRE A AB023M","	* taureau\n"
	"	x (idéogramme linéaire b b109m taureau - 1008D)"},
/* 10617 */ { "SIGNE LINÉAIRE A AB024",NULL},
/* 10618 */ { "SIGNE LINÉAIRE A AB026",NULL},
/* 10619 */ { "SIGNE LINÉAIRE A AB027",NULL},
/* 1061A */ { "SIGNE LINÉAIRE A AB028",NULL},
/* 1061B */ { "SIGNE LINÉAIRE A A028B",NULL},
/* 1061C */ { "SIGNE LINÉAIRE A AB029",NULL},
/* 1061D */ { "SIGNE LINÉAIRE A AB030","	* figues\n"
	"	x (syllabe linéaire b b030 ni - 1001B)"},
/* 1061E */ { "SIGNE LINÉAIRE A AB031",NULL},
/* 1061F */ { "SIGNE LINÉAIRE A AB034",NULL},
/* 10620 */ { "SIGNE LINÉAIRE A AB037",NULL},
/* 10621 */ { "SIGNE LINÉAIRE A AB038",NULL},
/* 10622 */ { "SIGNE LINÉAIRE A AB039",NULL},
/* 10623 */ { "SIGNE LINÉAIRE A AB040",NULL},
/* 10624 */ { "SIGNE LINÉAIRE A AB041",NULL},
/* 10625 */ { "SIGNE LINÉAIRE A AB044",NULL},
/* 10626 */ { "SIGNE LINÉAIRE A AB045",NULL},
/* 10627 */ { "SIGNE LINÉAIRE A AB046",NULL},
/* 10628 */ { "SIGNE LINÉAIRE A AB047",NULL},
/* 10629 */ { "SIGNE LINÉAIRE A AB048","	x (syllabe linéaire b b048 nwa - 10045)"},
/* 1062A */ { "SIGNE LINÉAIRE A AB049",NULL},
/* 1062B */ { "SIGNE LINÉAIRE A AB050",NULL},
/* 1062C */ { "SIGNE LINÉAIRE A AB051",NULL},
/* 1062D */ { "SIGNE LINÉAIRE A AB053",NULL},
/* 1062E */ { "SIGNE LINÉAIRE A AB054","	* tissu\n"
	"	x (idéogramme linéaire b b159 tissu - 100A7)"},
/* 1062F */ { "SIGNE LINÉAIRE A AB055",NULL},
/* 10630 */ { "SIGNE LINÉAIRE A AB056",NULL},
/* 10631 */ { "SIGNE LINÉAIRE A AB057",NULL},
/* 10632 */ { "SIGNE LINÉAIRE A AB058",NULL},
/* 10633 */ { "SIGNE LINÉAIRE A AB059",NULL},
/* 10634 */ { "SIGNE LINÉAIRE A AB060",NULL},
/* 10635 */ { "SIGNE LINÉAIRE A AB061",NULL},
/* 10636 */ { "SIGNE LINÉAIRE A AB065",NULL},
/* 10637 */ { "SIGNE LINÉAIRE A AB066",NULL},
/* 10638 */ { "SIGNE LINÉAIRE A AB067",NULL},
/* 10639 */ { "SIGNE LINÉAIRE A AB069",NULL},
/* 1063A */ { "SIGNE LINÉAIRE A AB070",NULL},
/* 1063B */ { "SIGNE LINÉAIRE A AB073",NULL},
/* 1063C */ { "SIGNE LINÉAIRE A AB074",NULL},
/* 1063D */ { "SIGNE LINÉAIRE A AB076",NULL},
/* 1063E */ { "SIGNE LINÉAIRE A AB077",NULL},
/* 1063F */ { "SIGNE LINÉAIRE A AB078",NULL},
/* 10640 */ { "SIGNE LINÉAIRE A AB079",NULL},
/* 10641 */ { "SIGNE LINÉAIRE A AB080",NULL},
/* 10642 */ { "SIGNE LINÉAIRE A AB081",NULL},
/* 10643 */ { "SIGNE LINÉAIRE A AB082",NULL},
/* 10644 */ { "SIGNE LINÉAIRE A AB085","	* cochon\n"
	"	x (syllabe linéaire b b085 au - 10042)"},
/* 10645 */ { "SIGNE LINÉAIRE A AB086",NULL},
/* 10646 */ { "SIGNE LINÉAIRE A AB087",NULL},
/* 10647 */ { "SIGNE LINÉAIRE A A100-102","	* homme ou femme\n"
	"	x (idéogramme linéaire b b100 homme - 10080)\n"
	"	x (idéogramme linéaire b b102 femme - 10081)"},
/* 10648 */ { "SIGNE LINÉAIRE A AB118",NULL},
/* 10649 */ { "SIGNE LINÉAIRE A AB120","	* grain\n"
	"	x (idéogramme linéaire b b120 blé - 1008E)"},
/* 1064A */ { "SIGNE LINÉAIRE A A120B","	* grain"},
/* 1064B */ { "SIGNE LINÉAIRE A AB122","	* olives\n"
	"	x (idéogramme linéaire b b122 olive - 10090)"},
/* 1064C */ { "SIGNE LINÉAIRE A AB123",NULL},
/* 1064D */ { "SIGNE LINÉAIRE A AB131A","	* vin\n"
	"	x (idéogramme linéaire b b131 vin - 10096)"},
/* 1064E */ { "SIGNE LINÉAIRE A AB131B","	* vin"},
/* 1064F */ { "SIGNE LINÉAIRE A A131C","	* vin"},
/* 10650 */ { "SIGNE LINÉAIRE A AB164",NULL},
/* 10651 */ { "SIGNE LINÉAIRE A AB171",NULL},
/* 10652 */ { "SIGNE LINÉAIRE A AB180",NULL},
/* 10653 */ { "SIGNE LINÉAIRE A AB188",NULL},
/* 10654 */ { "SIGNE LINÉAIRE A AB191",NULL},
/* 10655 */ { "SIGNE LINÉAIRE A A301",NULL},
/* 10656 */ { "SIGNE LINÉAIRE A A302","	* huile d'olive\n"
	"	x (idéogramme linéaire b b130 huile d'olive - 10095)"},
/* 10657 */ { "SIGNE LINÉAIRE A A303","	* cyperus\n"
	"	x (idéogramme linéaire b b125 cyperus - 10092)"},
/* 10658 */ { "SIGNE LINÉAIRE A A304",NULL},
/* 10659 */ { "SIGNE LINÉAIRE A A305",NULL},
/* 1065A */ { "SIGNE LINÉAIRE A A306",NULL},
/* 1065B */ { "SIGNE LINÉAIRE A A307",NULL},
/* 1065C */ { "SIGNE LINÉAIRE A A308",NULL},
/* 1065D */ { "SIGNE LINÉAIRE A A309A",NULL},
/* 1065E */ { "SIGNE LINÉAIRE A A309B",NULL},
/* 1065F */ { "SIGNE LINÉAIRE A A309C",NULL},
/* 10660 */ { "SIGNE LINÉAIRE A A310",NULL},
/* 10661 */ { "SIGNE LINÉAIRE A A311","	* s'utilise avec 10655 signe linéaire a a301"},
/* 10662 */ { "SIGNE LINÉAIRE A A312",NULL},
/* 10663 */ { "SIGNE LINÉAIRE A A313A","	* s'utilise avec 10647 signe linéaire a a100-102"},
/* 10664 */ { "SIGNE LINÉAIRE A A313B","	* s'utilise avec 10647 signe linéaire a a100-102"},
/* 10665 */ { "SIGNE LINÉAIRE A A313C","	* s'utilise avec 10647 signe linéaire a a100-102"},
/* 10666 */ { "SIGNE LINÉAIRE A A314",NULL},
/* 10667 */ { "SIGNE LINÉAIRE A A315",NULL},
/* 10668 */ { "SIGNE LINÉAIRE A A316",NULL},
/* 10669 */ { "SIGNE LINÉAIRE A A317",NULL},
/* 1066A */ { "SIGNE LINÉAIRE A A318",NULL},
/* 1066B */ { "SIGNE LINÉAIRE A A319",NULL},
/* 1066C */ { "SIGNE LINÉAIRE A A320",NULL},
/* 1066D */ { "SIGNE LINÉAIRE A A321",NULL},
/* 1066E */ { "SIGNE LINÉAIRE A A322",NULL},
/* 1066F */ { "SIGNE LINÉAIRE A A323",NULL},
/* 10670 */ { "SIGNE LINÉAIRE A A324",NULL},
/* 10671 */ { "SIGNE LINÉAIRE A A325",NULL},
/* 10672 */ { "SIGNE LINÉAIRE A A326",NULL},
/* 10673 */ { "SIGNE LINÉAIRE A A327",NULL},
/* 10674 */ { "SIGNE LINÉAIRE A A328",NULL},
/* 10675 */ { "SIGNE LINÉAIRE A A329",NULL},
/* 10676 */ { "SIGNE LINÉAIRE A A330","	* s'utilise avec 10600 signe linéaire ab001 et 1061E signe linéaire ab031"},
/* 10677 */ { "SIGNE LINÉAIRE A A331",NULL},
/* 10678 */ { "SIGNE LINÉAIRE A A332",NULL},
/* 10679 */ { "SIGNE LINÉAIRE A A333",NULL},
/* 1067A */ { "SIGNE LINÉAIRE A A334",NULL},
/* 1067B */ { "SIGNE LINÉAIRE A A335",NULL},
/* 1067C */ { "SIGNE LINÉAIRE A A336",NULL},
/* 1067D */ { "SIGNE LINÉAIRE A A337","	* s'utilise avec 10653 signe linéaire ab188"},
/* 1067E */ { "SIGNE LINÉAIRE A A338",NULL},
/* 1067F */ { "SIGNE LINÉAIRE A A339",NULL},
/* 10680 */ { "SIGNE LINÉAIRE A A340",NULL},
/* 10681 */ { "SIGNE LINÉAIRE A A341","	* s'utilise avec 10622 signe linéaire ab039"},
/* 10682 */ { "SIGNE LINÉAIRE A A342",NULL},
/* 10683 */ { "SIGNE LINÉAIRE A A343",NULL},
/* 10684 */ { "SIGNE LINÉAIRE A A344",NULL},
/* 10685 */ { "SIGNE LINÉAIRE A A345",NULL},
/* 10686 */ { "SIGNE LINÉAIRE A A346",NULL},
/* 10687 */ { "SIGNE LINÉAIRE A A347",NULL},
/* 10688 */ { "SIGNE LINÉAIRE A A348","	* s'utilise avec 10657 signe linéaire a303"},
/* 10689 */ { "SIGNE LINÉAIRE A A349",NULL},
/* 1068A */ { "SIGNE LINÉAIRE A A350",NULL},
/* 1068B */ { "SIGNE LINÉAIRE A A351","	* s'utilise avec 10655 signe linéaire a a301"},
/* 1068C */ { "SIGNE LINÉAIRE A A352",NULL},
/* 1068D */ { "SIGNE LINÉAIRE A A353",NULL},
/* 1068E */ { "SIGNE LINÉAIRE A A354",NULL},
/* 1068F */ { "SIGNE LINÉAIRE A A355",NULL},
/* 10690 */ { "SIGNE LINÉAIRE A A356",NULL},
/* 10691 */ { "SIGNE LINÉAIRE A A357",NULL},
/* 10692 */ { "SIGNE LINÉAIRE A A358",NULL},
/* 10693 */ { "SIGNE LINÉAIRE A A359",NULL},
/* 10694 */ { "SIGNE LINÉAIRE A A360",NULL},
/* 10695 */ { "SIGNE LINÉAIRE A A361",NULL},
/* 10696 */ { "SIGNE LINÉAIRE A A362",NULL},
/* 10697 */ { "SIGNE LINÉAIRE A A363",NULL},
/* 10698 */ { "SIGNE LINÉAIRE A A364",NULL},
/* 10699 */ { "SIGNE LINÉAIRE A A365",NULL},
/* 1069A */ { "SIGNE LINÉAIRE A A366",NULL},
/* 1069B */ { "SIGNE LINÉAIRE A A367",NULL},
/* 1069C */ { "SIGNE LINÉAIRE A A368",NULL},
/* 1069D */ { "SIGNE LINÉAIRE A A369",NULL},
/* 1069E */ { "SIGNE LINÉAIRE A A370",NULL},
/* 1069F */ { "SIGNE LINÉAIRE A A371",NULL},
/* 106A0 */ { "SIGNE LINÉAIRE A A400-VAS",NULL},
/* 106A1 */ { "SIGNE LINÉAIRE A A401-VAS",NULL},
/* 106A2 */ { "SIGNE LINÉAIRE A A402-VAS",NULL},
/* 106A3 */ { "SIGNE LINÉAIRE A A403-VAS",NULL},
/* 106A4 */ { "SIGNE LINÉAIRE A A404-VAS",NULL},
/* 106A5 */ { "SIGNE LINÉAIRE A A405-VAS",NULL},
/* 106A6 */ { "SIGNE LINÉAIRE A A406-VAS",NULL},
/* 106A7 */ { "SIGNE LINÉAIRE A A407-VAS",NULL},
/* 106A8 */ { "SIGNE LINÉAIRE A A408-VAS",NULL},
/* 106A9 */ { "SIGNE LINÉAIRE A A409-VAS",NULL},
/* 106AA */ { "SIGNE LINÉAIRE A A410-VAS",NULL},
/* 106AB */ { "SIGNE LINÉAIRE A A411-VAS",NULL},
/* 106AC */ { "SIGNE LINÉAIRE A A412-VAS",NULL},
/* 106AD */ { "SIGNE LINÉAIRE A A413-VAS",NULL},
/* 106AE */ { "SIGNE LINÉAIRE A A414-VAS",NULL},
/* 106AF */ { "SIGNE LINÉAIRE A A415-VAS",NULL},
/* 106B0 */ { "SIGNE LINÉAIRE A A416-VAS",NULL},
/* 106B1 */ { "SIGNE LINÉAIRE A A417-VAS",NULL},
/* 106B2 */ { "SIGNE LINÉAIRE A A418-VAS",NULL},
/* 106B3 */ { "SIGNE LINÉAIRE A A501","	* 10600 ab001, 10601 ab002"},
/* 106B4 */ { "SIGNE LINÉAIRE A A502","	* 10600 ab001, 10619 ab027, 10608 ab009"},
/* 106B5 */ { "SIGNE LINÉAIRE A A503","	* 10600 ab001, 10655 a301"},
/* 106B6 */ { "SIGNE LINÉAIRE A A504","	* 10601 ab002, 10601 ab002"},
/* 106B7 */ { "SIGNE LINÉAIRE A A505","	* 10603 ab004, 10601 ab002"},
/* 106B8 */ { "SIGNE LINÉAIRE A A506","	* 10606 ab007, 1063F ab078"},
/* 106B9 */ { "SIGNE LINÉAIRE A A508","	* 1060C ab016, 10619 ab027"},
/* 106BA */ { "SIGNE LINÉAIRE A A509","	* 1060C ab016, 10619 ab027, 1062B ab050"},
/* 106BB */ { "SIGNE LINÉAIRE A A510","	* 1060C ab016, 1062B ab050"},
/* 106BC */ { "SIGNE LINÉAIRE A A511","	* 1060C ab016, 1062B ab050, 10619 ab027"},
/* 106BD */ { "SIGNE LINÉAIRE A A512","	* 1060F ab021, 10624 ab041"},
/* 106BE */ { "SIGNE LINÉAIRE A A513","	* 10614 ab022m, 10642 ab081"},
/* 106BF */ { "SIGNE LINÉAIRE A A515","	* 10619 ab027, 10608 ab009"},
/* 106C0 */ { "SIGNE LINÉAIRE A A516","	x (signe linéaire a ab028 - 1061A)"},
/* 106C1 */ { "SIGNE LINÉAIRE A A520","	* 1061A ab028, 10655 a301"},
/* 106C2 */ { "SIGNE LINÉAIRE A A521","	* 1061E ab031, 10615 ab023, 10642 ab081"},
/* 106C3 */ { "SIGNE LINÉAIRE A A523","	* 10620 ab037, 10607 ab008"},
/* 106C4 */ { "SIGNE LINÉAIRE A A524","	* 10620 ab037, 106AC a412-vas"},
/* 106C5 */ { "SIGNE LINÉAIRE A A525","	x (signe linéaire a ab038 - 10621)"},
/* 106C6 */ { "SIGNE LINÉAIRE A A526","	* 10621 ab038, 1063E ab077"},
/* 106C7 */ { "SIGNE LINÉAIRE A A527","	* 10623 ab040, 1063C ab074"},
/* 106C8 */ { "SIGNE LINÉAIRE A A528","	* 10624 ab041, 10606 ab007"},
/* 106C9 */ { "SIGNE LINÉAIRE A A529","	* 10624 ab041, 10608 ab009"},
/* 106CA */ { "SIGNE LINÉAIRE A A530","	* 10624 ab041, 1060B ab013"},
/* 106CB */ { "SIGNE LINÉAIRE A A531","	* 10624 ab041, 1060B ab013, 10638 ab067"},
/* 106CC */ { "SIGNE LINÉAIRE A A532","	* 10624 ab041, 10637 ab066"},
/* 106CD */ { "SIGNE LINÉAIRE A A534","	x (signe linéaire a ab051 - 1062C)"},
/* 106CE */ { "SIGNE LINÉAIRE A A535","	* 1062E ab054, 10642 ab081"},
/* 106CF */ { "SIGNE LINÉAIRE A A536","	* 1062E ab054, 10662 a312"},
/* 106D0 */ { "SIGNE LINÉAIRE A A537","	* 10630 ab056, 1063F ab078"},
/* 106D1 */ { "SIGNE LINÉAIRE A A538","	* 10631 ab057, 10618 ab026"},
/* 106D2 */ { "SIGNE LINÉAIRE A A539","	* 10631 ab057, 1063E ab077"},
/* 106D3 */ { "SIGNE LINÉAIRE A A540","	* 10632 ab058, 1063B ab073"},
/* 106D4 */ { "SIGNE LINÉAIRE A A541","	* 10634 ab060, 1063E ab077"},
/* 106D5 */ { "SIGNE LINÉAIRE A A542","	* 10636 ab065, 10669 a317, 1063F ab078"},
/* 106D6 */ { "SIGNE LINÉAIRE A A545","	* 10638 ab067, 10615 ab023"},
/* 106D7 */ { "SIGNE LINÉAIRE A A547","	* 10639 ab069, 10601 ab002"},
/* 106D8 */ { "SIGNE LINÉAIRE A A548","	* 1063B ab073, 10631 ab057"},
/* 106D9 */ { "SIGNE LINÉAIRE A A549","	x (signe linéaire a a548 - 106D8)"},
/* 106DA */ { "SIGNE LINÉAIRE A A550","	* 1063B ab073, 10631 ab057, 10618 ab026"},
/* 106DB */ { "SIGNE LINÉAIRE A A551","	* 1063B ab073, 10631 ab057, 1061A ab028"},
/* 106DC */ { "SIGNE LINÉAIRE A A552","	* 1063B ab073, 10631 ab057, 1063E ab077"},
/* 106DD */ { "SIGNE LINÉAIRE A A553","	* 1063B ab073, 10655 a301"},
/* 106DE */ { "SIGNE LINÉAIRE A A554","	* 1063E ab077, 10607 ab008"},
/* 106DF */ { "SIGNE LINÉAIRE A A555","	* 1063F ab078, 10649 ab120, 10602 ab003"},
/* 106E0 */ { "SIGNE LINÉAIRE A A556","	x (signe linéaire a ab080 - 10641)"},
/* 106E1 */ { "SIGNE LINÉAIRE A A557","	* 10641 ab080, 10607 ab008"},
/* 106E2 */ { "SIGNE LINÉAIRE A A559","	* 10641 ab080, 10618 ab026"},
/* 106E3 */ { "SIGNE LINÉAIRE A A563","	* 10641 ab080, 10641 ab080"},
/* 106E4 */ { "SIGNE LINÉAIRE A A564","	x (signe linéaire a ab081 - 10642)"},
/* 106E5 */ { "SIGNE LINÉAIRE A A565","	* 10645 ab086, 10653 ab188"},
/* 106E6 */ { "SIGNE LINÉAIRE A A566","	* 10645 ab086, 10653 ab188"},
/* 106E7 */ { "SIGNE LINÉAIRE A A568","	* 10647 a100-102, 1063E ab077"},
/* 106E8 */ { "SIGNE LINÉAIRE A A569","	* 10647 a100-102, 1065B a307"},
/* 106E9 */ { "SIGNE LINÉAIRE A A570","	* 10647 a100-102, 10663 a313a"},
/* 106EA */ { "SIGNE LINÉAIRE A A571","	* 10647 a100-102, 10664 a313b"},
/* 106EB */ { "SIGNE LINÉAIRE A A572","	* 10647 a100-102, 10665 a313c"},
/* 106EC */ { "SIGNE LINÉAIRE A A573","	* 10649 ab120, 10600 ab001"},
/* 106ED */ { "SIGNE LINÉAIRE A A574","	* 10649 ab120, 10602 ab003"},
/* 106EE */ { "SIGNE LINÉAIRE A A575","	* 10649 ab120, 10610 ab021f"},
/* 106EF */ { "SIGNE LINÉAIRE A A576","	* 10649 ab120, 10614 ab022m"},
/* 106F0 */ { "SIGNE LINÉAIRE A A577","	* 10649 ab120, 1062F ab056"},
/* 106F1 */ { "SIGNE LINÉAIRE A A578","	* 10649 ab120, 1063F ab078"},
/* 106F2 */ { "SIGNE LINÉAIRE A A579","	* 10649 ab120, 10642 ab081"},
/* 106F3 */ { "SIGNE LINÉAIRE A A580","	* 10649 ab120, 10741 a702 b"},
/* 106F4 */ { "SIGNE LINÉAIRE A A581","	* 10649 ab120, 10743 a704 e"},
/* 106F5 */ { "SIGNE LINÉAIRE A A582","	* 10649 ab120, 10744 a705 f"},
/* 106F6 */ { "SIGNE LINÉAIRE A A583","	* 10649 ab120, 10745 a706 h"},
/* 106F7 */ { "SIGNE LINÉAIRE A A584","	* 10649 ab120, 10747 a708 k, 10749 a709-2 l2"},
/* 106F8 */ { "SIGNE LINÉAIRE A A585","	* 10649 ab120, 10749 a709-2 l2"},
/* 106F9 */ { "SIGNE LINÉAIRE A A586","	* 10649 ab120, 1074A a709-3 l3, 1074A a709-3 l3"},
/* 106FA */ { "SIGNE LINÉAIRE A A587","	* 1064B ab122, 10639 ab069"},
/* 106FB */ { "SIGNE LINÉAIRE A A588","	* 1064D ab131a, 10603 ab004"},
/* 106FC */ { "SIGNE LINÉAIRE A A589","	* 1064D ab131a, 1061E ab031"},
/* 106FD */ { "SIGNE LINÉAIRE A A591","	* 1064D ab131a, 1062E ab054"},
/* 106FE */ { "SIGNE LINÉAIRE A A592","	* 1064D ab131a, 1062E ab054"},
/* 106FF */ { "SIGNE LINÉAIRE A A594","	* 1064D ab131a, 10634 ab060"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_07[] = {
/* 10700 */ { "SIGNE LINÉAIRE A A595","	* 1064D ab131a, 10634 ab060"},
/* 10701 */ { "SIGNE LINÉAIRE A A596","	* 1064D ab131a, 1063E ab077"},
/* 10702 */ { "SIGNE LINÉAIRE A A598","	* 1064D ab131b, 10623 ab040"},
/* 10703 */ { "SIGNE LINÉAIRE A A600","	* 10764 a804, 10741 a702 b"},
/* 10704 */ { "SIGNE LINÉAIRE A A601","	* 10764 a804, 10748 a709 l"},
/* 10705 */ { "SIGNE LINÉAIRE A A602","	* 10652 ab180, 10741 a702 b"},
/* 10706 */ { "SIGNE LINÉAIRE A A603","	* 10652 ab180, 10748 a709 l"},
/* 10707 */ { "SIGNE LINÉAIRE A A604","	* 10653 ab188, 10642 ab081"},
/* 10708 */ { "SIGNE LINÉAIRE A A606","	* 10655 a301, 10661 a311"},
/* 10709 */ { "SIGNE LINÉAIRE A A608","	* 10656 a302, 10606 ab007"},
/* 1070A */ { "SIGNE LINÉAIRE A A609","	* 10656 a302, 10607 ab008"},
/* 1070B */ { "SIGNE LINÉAIRE A A610","	* 10656 a302, 10609 ab010"},
/* 1070C */ { "SIGNE LINÉAIRE A A611","	* 10656 a302, 10610 ab021f"},
/* 1070D */ { "SIGNE LINÉAIRE A A612","	* 10656 a302, 10617 ab024"},
/* 1070E */ { "SIGNE LINÉAIRE A A613","	* 10656 a302, 10621 ab038"},
/* 1070F */ { "SIGNE LINÉAIRE A A614","	* 10656 a302, 1062D ab053"},
/* 10710 */ { "SIGNE LINÉAIRE A A615","	* 10656 a302, 10633 ab059"},
/* 10711 */ { "SIGNE LINÉAIRE A A616","	* 10656 a302, 10634 ab060"},
/* 10712 */ { "SIGNE LINÉAIRE A A617","	* 10656 a302, 10638 ab067"},
/* 10713 */ { "SIGNE LINÉAIRE A A618","	* 10656 a302, 10638 ab067"},
/* 10714 */ { "SIGNE LINÉAIRE A A619","	* 10656 a302, 10638 ab067, 10609 ab010"},
/* 10715 */ { "SIGNE LINÉAIRE A A620","	* 10656 a302, 10638 ab067, 1060B ab013"},
/* 10716 */ { "SIGNE LINÉAIRE A A621","	* 10656 a302, 10639 ab069"},
/* 10717 */ { "SIGNE LINÉAIRE A A622","	* 10656 a302, 1063B ab073"},
/* 10718 */ { "SIGNE LINÉAIRE A A623","	* 10656 a302, 1063F ab078, 10606 ab007"},
/* 10719 */ { "SIGNE LINÉAIRE A A624","	* 10657 a303, 10742 a703 d"},
/* 1071A */ { "SIGNE LINÉAIRE A A626","	* 10657 a303, 10743 a704 e"},
/* 1071B */ { "SIGNE LINÉAIRE A A627","	* 10657 a303, 10747 a708 k"},
/* 1071C */ { "SIGNE LINÉAIRE A A628","	x (signe linéaire a a304 - 10658)"},
/* 1071D */ { "SIGNE LINÉAIRE A A629","	* 10658 a304, 10602 ab003"},
/* 1071E */ { "SIGNE LINÉAIRE A A634","	* 1065A a306, 1063B ab073"},
/* 1071F */ { "SIGNE LINÉAIRE A A637","	* 1065B a307, 10655 a301"},
/* 10720 */ { "SIGNE LINÉAIRE A A638","	* 1065B a307, 1065B a307"},
/* 10721 */ { "SIGNE LINÉAIRE A A640","	* 10668 a316, 10638 ab067"},
/* 10722 */ { "SIGNE LINÉAIRE A A642","	x (signe linéaire a a318 - 1066A)"},
/* 10723 */ { "SIGNE LINÉAIRE A A643","	* 10676 a330, 10600 ab001"},
/* 10724 */ { "SIGNE LINÉAIRE A A644","	* 10676 a330, 1061E ab031"},
/* 10725 */ { "SIGNE LINÉAIRE A A645","	* 1067D a337, 10653 ab188"},
/* 10726 */ { "SIGNE LINÉAIRE A A646","	* 10681 a341, 10622 ab039"},
/* 10727 */ { "SIGNE LINÉAIRE A A648","	* 106A0 a400-vas, 1062D ab053"},
/* 10728 */ { "SIGNE LINÉAIRE A A649","	x (signe linéaire a a401-vas - 106A1)"},
/* 10729 */ { "SIGNE LINÉAIRE A A651","	* 106A1 a401-vas, 10618 ab026"},
/* 1072A */ { "SIGNE LINÉAIRE A A652","	* 106A1 a401-vas, 10634 ab060"},
/* 1072B */ { "SIGNE LINÉAIRE A A653","	* 106A1 a401-vas, 10658 a304"},
/* 1072C */ { "SIGNE LINÉAIRE A A654","	* 106A4 a404-vas, 10607 ab008"},
/* 1072D */ { "SIGNE LINÉAIRE A A655","	* 106A5 a405-vas, 10750 a713 oméga"},
/* 1072E */ { "SIGNE LINÉAIRE A A656","	* 106A6 a406-vas, 10625 ab044"},
/* 1072F */ { "SIGNE LINÉAIRE A A657","	* 106A7 a407-vas, 10607 ab008"},
/* 10730 */ { "SIGNE LINÉAIRE A A658","	* 106AC a412-vas, 10743 a704 e"},
/* 10731 */ { "SIGNE LINÉAIRE A A659","	* 106AC a412-vas, 10744 a705 f"},
/* 10732 */ { "SIGNE LINÉAIRE A A660","	* 106AD a413-vas, 10632 ab058"},
/* 10733 */ { "SIGNE LINÉAIRE A A661","	x (signe linéaire a a414-vas - 106AE)"},
/* 10734 */ { "SIGNE LINÉAIRE A A662","	* 106AE a414-vas, 10744 a705 f"},
/* 10735 */ { "SIGNE LINÉAIRE A A663","	* 106B1 a417-vas, 10749 a709-2 l2"},
/* 10736 */ { "SIGNE LINÉAIRE A A664","	* 106B2 a418-vas, 10749 a709-2 l2"},
/* 10737 */ { NULL,NULL},
/* 10738 */ { NULL,NULL},
/* 10739 */ { NULL,NULL},
/* 1073A */ { NULL,NULL},
/* 1073B */ { NULL,NULL},
/* 1073C */ { NULL,NULL},
/* 1073D */ { NULL,NULL},
/* 1073E */ { NULL,NULL},
/* 1073F */ { NULL,NULL},
/* 10740 */ { "SIGNE LINÉAIRE A A701 A","	* peut-être un sixième (valeur incertaine)\n"
	"	x (thermodynamique - 29E7)"},
/* 10741 */ { "SIGNE LINÉAIRE A A702 B","	* un tiers"},
/* 10742 */ { "SIGNE LINÉAIRE A A703 D","	* un cinquième"},
/* 10743 */ { "SIGNE LINÉAIRE A A704 E","	* un quart"},
/* 10744 */ { "SIGNE LINÉAIRE A A705 F","	* un huitième"},
/* 10745 */ { "SIGNE LINÉAIRE A A706 H","	* peut-être un sixième (valeur incertaine)"},
/* 10746 */ { "SIGNE LINÉAIRE A A707 J","	* un demi"},
/* 10747 */ { "SIGNE LINÉAIRE A A708 K","	* un seizième\n"
	"	x (première sous-unité égéenne de mesure solide - 1013C)"},
/* 10748 */ { "SIGNE LINÉAIRE A A709 L",NULL},
/* 10749 */ { "SIGNE LINÉAIRE A A709-2 L2",NULL},
/* 1074A */ { "SIGNE LINÉAIRE A A709-3 L3",NULL},
/* 1074B */ { "SIGNE LINÉAIRE A A709-4 L4",NULL},
/* 1074C */ { "SIGNE LINÉAIRE A A709-6 L6","	* s'utilise avec 10655 signe linéaire a a301"},
/* 1074D */ { "SIGNE LINÉAIRE A A710 W",NULL},
/* 1074E */ { "SIGNE LINÉAIRE A A711 X","	x (deuxième sous-unité égéenne de poids - 10139)"},
/* 1074F */ { "SIGNE LINÉAIRE A A712 Y","	x (lettre runique wunjo wynn w - 16B9)"},
/* 10750 */ { "SIGNE LINÉAIRE A A713 OMÉGA","	* s'utilise avec 106A5 signe linéaire a a405-vas"},
/* 10751 */ { "SIGNE LINÉAIRE A A714 ABB",NULL},
/* 10752 */ { "SIGNE LINÉAIRE A A715 BB",NULL},
/* 10753 */ { "SIGNE LINÉAIRE A A717 DD",NULL},
/* 10754 */ { "SIGNE LINÉAIRE A A726 EYYY",NULL},
/* 10755 */ { "SIGNE LINÉAIRE A A732 JE","	* trois quarts"},
/* 10756 */ { NULL,NULL},
/* 10757 */ { NULL,NULL},
/* 10758 */ { NULL,NULL},
/* 10759 */ { NULL,NULL},
/* 1075A */ { NULL,NULL},
/* 1075B */ { NULL,NULL},
/* 1075C */ { NULL,NULL},
/* 1075D */ { NULL,NULL},
/* 1075E */ { NULL,NULL},
/* 1075F */ { NULL,NULL},
/* 10760 */ { "SIGNE LINÉAIRE A A800","	* 10603 ab004, 10607 ab008"},
/* 10761 */ { "SIGNE LINÉAIRE A A801","	* 1062E ab054, 10608 ab009"},
/* 10762 */ { "SIGNE LINÉAIRE A A802","	x (signe linéaire a ab060 - 10634)"},
/* 10763 */ { "SIGNE LINÉAIRE A A803","	* 1064D ab131a, 10762 a802"},
/* 10764 */ { "SIGNE LINÉAIRE A A804","	* 10652 ab180, 1061E ab031"},
/* 10765 */ { "SIGNE LINÉAIRE A A805","	x (signe linéaire a a301 - 10655)"},
/* 10766 */ { "SIGNE LINÉAIRE A A806","	* 10668 a316, 10601 ab002"},
/* 10767 */ { "SIGNE LINÉAIRE A A807","	* 10668 a316, 10742 a703 d"},
/* 10768 */ { NULL,NULL},
/* 10769 */ { NULL,NULL},
/* 1076A */ { NULL,NULL},
/* 1076B */ { NULL,NULL},
/* 1076C */ { NULL,NULL},
/* 1076D */ { NULL,NULL},
/* 1076E */ { NULL,NULL},
/* 1076F */ { NULL,NULL},
/* 10770 */ { NULL,NULL},
/* 10771 */ { NULL,NULL},
/* 10772 */ { NULL,NULL},
/* 10773 */ { NULL,NULL},
/* 10774 */ { NULL,NULL},
/* 10775 */ { NULL,NULL},
/* 10776 */ { NULL,NULL},
/* 10777 */ { NULL,NULL},
/* 10778 */ { NULL,NULL},
/* 10779 */ { NULL,NULL},
/* 1077A */ { NULL,NULL},
/* 1077B */ { NULL,NULL},
/* 1077C */ { NULL,NULL},
/* 1077D */ { NULL,NULL},
/* 1077E */ { NULL,NULL},
/* 1077F */ { NULL,NULL},
/* 10780 */ { "LETTRE MODIFICATIVE PETITE CAPITALE AA","	* en fait une petite capitale dans son emploi comme symbole de qualité vocale, sans distinction sémantique par rapport à une grande capitale\n"
	"	x (lettre majuscule latine aa - A732)"},
/* 10781 */ { "LETTRE MODIFICATIVE DEUX POINTS TRIANGULAIRES EN CHEF","	# <exp> 02D0"},
/* 10782 */ { "LETTRE MODIFICATIVE POINT TRIANGULAIRE EN CHEF","	# <exp> 02D1"},
/* 10783 */ { "LETTRE MODIFICATIVE MINUSCULE AE","	# <exp> 00E6"},
/* 10784 */ { "LETTRE MODIFICATIVE PETITE CAPITALE B","	# <exp> 0299"},
/* 10785 */ { "LETTRE MODIFICATIVE MINUSCULE B CROSSE","	# <exp> 0253"},
/* 10786 */ { NULL,NULL},
/* 10787 */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME DZ","	# <exp> 02A3"},
/* 10788 */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME DZ HAMEÇON RÉTROFLEXE","	# <exp> AB66"},
/* 10789 */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME DZ BOUCLÉ","	# <exp> 02A5"},
/* 1078A */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME DEJ","	# <exp> 02A4"},
/* 1078B */ { "LETTRE MODIFICATIVE MINUSCULE D HAMEÇON RÉTROFLEXE","	# <exp> 0256"},
/* 1078C */ { "LETTRE MODIFICATIVE MINUSCULE D CROSSE","	# <exp> 0257"},
/* 1078D */ { "LETTRE MODIFICATIVE MINUSCULE D CROSSE ET HAMEÇON RÉTROFLEXE","	# <exp> 1D91"},
/* 1078E */ { "LETTRE MODIFICATIVE MINUSCULE E RÉFLÉCHI","	# <exp> 0258"},
/* 1078F */ { "LETTRE MODIFICATIVE MINUSCULE E OUVERT RÉFLÉCHI FERMÉ","	# <exp> 025E"},
/* 10790 */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME FENG","	# <exp> 02A9"},
/* 10791 */ { "LETTRE MODIFICATIVE MINUSCULE CORNES DE BÉLIER","	# <exp> 0264"},
/* 10792 */ { "LETTRE MODIFICATIVE PETITE CAPITALE G","	# <exp> 0262"},
/* 10793 */ { "LETTRE MODIFICATIVE MINUSCULE G CROSSE","	# <exp> 0260"},
/* 10794 */ { "LETTRE MODIFICATIVE PETITE CAPITALE G CROSSE","	# <exp> 029B"},
/* 10795 */ { "LETTRE MODIFICATIVE MINUSCULE H BARRÉ","	# <exp> 0127"},
/* 10796 */ { "LETTRE MODIFICATIVE PETITE CAPITALE H","	# <exp> 029C"},
/* 10797 */ { "LETTRE MODIFICATIVE MINUSCULE HENG CROSSE","	# <exp> 0267"},
/* 10798 */ { "LETTRE MODIFICATIVE MINUSCULE J SANS POINT BARRÉ CROSSE","	# <exp> 0284"},
/* 10799 */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME LS","	# <exp> 02AA"},
/* 1079A */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME LZ","	# <exp> 02AB"},
/* 1079B */ { "LETTRE MODIFICATIVE MINUSCULE L SANGLÉ","	# <exp> 026C"},
/* 1079C */ { "LETTRE MODIFICATIVE PETITE CAPITALE L SANGLÉ","	# <exp> 1DF04"},
/* 1079D */ { "LETTRE MODIFICATIVE MINUSCULE L SANGLÉ HAMEÇON RÉTROFLEXE","	# <exp> A78E"},
/* 1079E */ { "LETTRE MODIFICATIVE MINUSCULE LEJ","	# <exp> 026E"},
/* 1079F */ { "LETTRE MODIFICATIVE MINUSCULE LEJ HAMEÇON RÉTROFLEXE","	# <exp> 1DF05"},
/* 107A0 */ { "LETTRE MODIFICATIVE MINUSCULE Y CULBUTÉ","	# <exp> 028E"},
/* 107A1 */ { "LETTRE MODIFICATIVE MINUSCULE Y SANGLÉ CULBUTÉ","	# <exp> 1DF06"},
/* 107A2 */ { "LETTRE MODIFICATIVE MINUSCULE O BARRÉ OBLIQUEMENT","	# <exp> 00F8"},
/* 107A3 */ { "LETTRE MODIFICATIVE PETITE CAPITALE OE","	# <exp> 0276"},
/* 107A4 */ { "LETTRE MODIFICATIVE MINUSCULE OMÉGA FERMÉ","	# <exp> 0277"},
/* 107A5 */ { "LETTRE MODIFICATIVE MINUSCULE Q","	# <exp> 0071"},
/* 107A6 */ { "LETTRE MODIFICATIVE MINUSCULE R CULBUTÉ À LONG FÛT","	# <exp> 027A"},
/* 107A7 */ { "LETTRE MODIFICATIVE MINUSCULE R CULBUTÉ À LONG FÛT HAMEÇON RÉTROFLEXE","	# <exp> 1DF08"},
/* 107A8 */ { "LETTRE MODIFICATIVE MINUSCULE R HAMEÇON RÉTROFLEXE","	# <exp> 027D"},
/* 107A9 */ { "LETTRE MODIFICATIVE MINUSCULE R SANS OBIT","	# <exp> 027E"},
/* 107AA */ { "LETTRE MODIFICATIVE PETITE CAPITALE R","	# <exp> 0280"},
/* 107AB */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME TC BOUCLÉ","	# <exp> 02A8"},
/* 107AC */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME TS","	# <exp> 02A6"},
/* 107AD */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME TS HAMEÇON RÉTROFLEXE","	# <exp> AB67"},
/* 107AE */ { "LETTRE MODIFICATIVE MINUSCULE DIGRAMME TECH","	# <exp> 02A7"},
/* 107AF */ { "LETTRE MODIFICATIVE MINUSCULE T HAMEÇON RÉTROFLEXE","	# <exp> 0288"},
/* 107B0 */ { "LETTRE MODIFICATIVE MINUSCULE V CROSSE À DROITE","	# <exp> 2C71"},
/* 107B1 */ { NULL,NULL},
/* 107B2 */ { "LETTRE MODIFICATIVE PETITE CAPITALE Y","	# <exp> 028F"},
/* 107B3 */ { "LETTRE MODIFICATIVE COUP DE GLOTTE BARRÉ","	# <exp> 02A1"},
/* 107B4 */ { "LETTRE MODIFICATIVE COUP DE GLOTTE BARRÉ RENVERSÉ","	# <exp> 02A2"},
/* 107B5 */ { "LETTRE MODIFICATIVE CLIC BILABIAL","	# <exp> 0298"},
/* 107B6 */ { "LETTRE MODIFICATIVE CLIC DENTAL","	# <exp> 01C0"},
/* 107B7 */ { "LETTRE MODIFICATIVE CLIC LATÉRAL","	# <exp> 01C1"},
/* 107B8 */ { "LETTRE MODIFICATIVE CLIC ALVÉOLAIRE","	# <exp> 01C2"},
/* 107B9 */ { "LETTRE MODIFICATIVE CLIC RÉTROFLEXE AVEC HAMEÇON RÉTROFLEXE","	x (lettre modificative point d'exclamation haut - A71D)\n"
	"	# <exp> 1DF0A"},
/* 107BA */ { "LETTRE MODIFICATIVE MINUSCULE S BOUCLÉ","	# <exp> 1DF1E"},
/* 107BB */ { NULL,NULL},
/* 107BC */ { NULL,NULL},
/* 107BD */ { NULL,NULL},
/* 107BE */ { NULL,NULL},
/* 107BF */ { NULL,NULL},
/* 107C0 */ { NULL,NULL},
/* 107C1 */ { NULL,NULL},
/* 107C2 */ { NULL,NULL},
/* 107C3 */ { NULL,NULL},
/* 107C4 */ { NULL,NULL},
/* 107C5 */ { NULL,NULL},
/* 107C6 */ { NULL,NULL},
/* 107C7 */ { NULL,NULL},
/* 107C8 */ { NULL,NULL},
/* 107C9 */ { NULL,NULL},
/* 107CA */ { NULL,NULL},
/* 107CB */ { NULL,NULL},
/* 107CC */ { NULL,NULL},
/* 107CD */ { NULL,NULL},
/* 107CE */ { NULL,NULL},
/* 107CF */ { NULL,NULL},
/* 107D0 */ { NULL,NULL},
/* 107D1 */ { NULL,NULL},
/* 107D2 */ { NULL,NULL},
/* 107D3 */ { NULL,NULL},
/* 107D4 */ { NULL,NULL},
/* 107D5 */ { NULL,NULL},
/* 107D6 */ { NULL,NULL},
/* 107D7 */ { NULL,NULL},
/* 107D8 */ { NULL,NULL},
/* 107D9 */ { NULL,NULL},
/* 107DA */ { NULL,NULL},
/* 107DB */ { NULL,NULL},
/* 107DC */ { NULL,NULL},
/* 107DD */ { NULL,NULL},
/* 107DE */ { NULL,NULL},
/* 107DF */ { NULL,NULL},
/* 107E0 */ { NULL,NULL},
/* 107E1 */ { NULL,NULL},
/* 107E2 */ { NULL,NULL},
/* 107E3 */ { NULL,NULL},
/* 107E4 */ { NULL,NULL},
/* 107E5 */ { NULL,NULL},
/* 107E6 */ { NULL,NULL},
/* 107E7 */ { NULL,NULL},
/* 107E8 */ { NULL,NULL},
/* 107E9 */ { NULL,NULL},
/* 107EA */ { NULL,NULL},
/* 107EB */ { NULL,NULL},
/* 107EC */ { NULL,NULL},
/* 107ED */ { NULL,NULL},
/* 107EE */ { NULL,NULL},
/* 107EF */ { NULL,NULL},
/* 107F0 */ { NULL,NULL},
/* 107F1 */ { NULL,NULL},
/* 107F2 */ { NULL,NULL},
/* 107F3 */ { NULL,NULL},
/* 107F4 */ { NULL,NULL},
/* 107F5 */ { NULL,NULL},
/* 107F6 */ { NULL,NULL},
/* 107F7 */ { NULL,NULL},
/* 107F8 */ { NULL,NULL},
/* 107F9 */ { NULL,NULL},
/* 107FA */ { NULL,NULL},
/* 107FB */ { NULL,NULL},
/* 107FC */ { NULL,NULL},
/* 107FD */ { NULL,NULL},
/* 107FE */ { NULL,NULL},
/* 107FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_08[] = {
/* 10800 */ { "SYLLABE CHYPRIOTE A",NULL},
/* 10801 */ { "SYLLABE CHYPRIOTE E",NULL},
/* 10802 */ { "SYLLABE CHYPRIOTE I",NULL},
/* 10803 */ { "SYLLABE CHYPRIOTE O",NULL},
/* 10804 */ { "SYLLABE CHYPRIOTE U",NULL},
/* 10805 */ { "SYLLABE CHYPRIOTE JA",NULL},
/* 10806 */ { NULL,NULL},
/* 10807 */ { NULL,NULL},
/* 10808 */ { "SYLLABE CHYPRIOTE JO",NULL},
/* 10809 */ { NULL,NULL},
/* 1080A */ { "SYLLABE CHYPRIOTE KA",NULL},
/* 1080B */ { "SYLLABE CHYPRIOTE KE",NULL},
/* 1080C */ { "SYLLABE CHYPRIOTE KI",NULL},
/* 1080D */ { "SYLLABE CHYPRIOTE KO",NULL},
/* 1080E */ { "SYLLABE CHYPRIOTE KU",NULL},
/* 1080F */ { "SYLLABE CHYPRIOTE LA",NULL},
/* 10810 */ { "SYLLABE CHYPRIOTE LE",NULL},
/* 10811 */ { "SYLLABE CHYPRIOTE LI",NULL},
/* 10812 */ { "SYLLABE CHYPRIOTE LO",NULL},
/* 10813 */ { "SYLLABE CHYPRIOTE LU",NULL},
/* 10814 */ { "SYLLABE CHYPRIOTE MA",NULL},
/* 10815 */ { "SYLLABE CHYPRIOTE ME",NULL},
/* 10816 */ { "SYLLABE CHYPRIOTE MI",NULL},
/* 10817 */ { "SYLLABE CHYPRIOTE MO",NULL},
/* 10818 */ { "SYLLABE CHYPRIOTE MU",NULL},
/* 10819 */ { "SYLLABE CHYPRIOTE NA",NULL},
/* 1081A */ { "SYLLABE CHYPRIOTE NE",NULL},
/* 1081B */ { "SYLLABE CHYPRIOTE NI",NULL},
/* 1081C */ { "SYLLABE CHYPRIOTE NO",NULL},
/* 1081D */ { "SYLLABE CHYPRIOTE NU",NULL},
/* 1081E */ { "SYLLABE CHYPRIOTE PA",NULL},
/* 1081F */ { "SYLLABE CHYPRIOTE PE",NULL},
/* 10820 */ { "SYLLABE CHYPRIOTE PI",NULL},
/* 10821 */ { "SYLLABE CHYPRIOTE PO",NULL},
/* 10822 */ { "SYLLABE CHYPRIOTE PU",NULL},
/* 10823 */ { "SYLLABE CHYPRIOTE RA",NULL},
/* 10824 */ { "SYLLABE CHYPRIOTE RE",NULL},
/* 10825 */ { "SYLLABE CHYPRIOTE RI",NULL},
/* 10826 */ { "SYLLABE CHYPRIOTE RO",NULL},
/* 10827 */ { "SYLLABE CHYPRIOTE RU",NULL},
/* 10828 */ { "SYLLABE CHYPRIOTE SA",NULL},
/* 10829 */ { "SYLLABE CHYPRIOTE SE",NULL},
/* 1082A */ { "SYLLABE CHYPRIOTE SI",NULL},
/* 1082B */ { "SYLLABE CHYPRIOTE SO",NULL},
/* 1082C */ { "SYLLABE CHYPRIOTE SU",NULL},
/* 1082D */ { "SYLLABE CHYPRIOTE TA",NULL},
/* 1082E */ { "SYLLABE CHYPRIOTE TE",NULL},
/* 1082F */ { "SYLLABE CHYPRIOTE TI",NULL},
/* 10830 */ { "SYLLABE CHYPRIOTE TO",NULL},
/* 10831 */ { "SYLLABE CHYPRIOTE TU",NULL},
/* 10832 */ { "SYLLABE CHYPRIOTE WA",NULL},
/* 10833 */ { "SYLLABE CHYPRIOTE WE",NULL},
/* 10834 */ { "SYLLABE CHYPRIOTE WI",NULL},
/* 10835 */ { "SYLLABE CHYPRIOTE WO",NULL},
/* 10836 */ { NULL,NULL},
/* 10837 */ { "SYLLABE CHYPRIOTE XA",NULL},
/* 10838 */ { "SYLLABE CHYPRIOTE XE",NULL},
/* 10839 */ { NULL,NULL},
/* 1083A */ { NULL,NULL},
/* 1083B */ { NULL,NULL},
/* 1083C */ { "SYLLABE CHYPRIOTE ZA",NULL},
/* 1083D */ { NULL,NULL},
/* 1083E */ { NULL,NULL},
/* 1083F */ { "SYLLABE CHYPRIOTE ZO",NULL},
/* 10840 */ { "LETTRE ARAMÉENNE IMPÉRIALE ALEF",NULL},
/* 10841 */ { "LETTRE ARAMÉENNE IMPÉRIALE BÈT",NULL},
/* 10842 */ { "LETTRE ARAMÉENNE IMPÉRIALE GUIMEL",NULL},
/* 10843 */ { "LETTRE ARAMÉENNE IMPÉRIALE DALÈT",NULL},
/* 10844 */ { "LETTRE ARAMÉENNE IMPÉRIALE HÈ",NULL},
/* 10845 */ { "LETTRE ARAMÉENNE IMPÉRIALE WAW",NULL},
/* 10846 */ { "LETTRE ARAMÉENNE IMPÉRIALE ZAÏN",NULL},
/* 10847 */ { "LETTRE ARAMÉENNE IMPÉRIALE HÈT",NULL},
/* 10848 */ { "LETTRE ARAMÉENNE IMPÉRIALE TÈT",NULL},
/* 10849 */ { "LETTRE ARAMÉENNE IMPÉRIALE YOD",NULL},
/* 1084A */ { "LETTRE ARAMÉENNE IMPÉRIALE KAF",NULL},
/* 1084B */ { "LETTRE ARAMÉENNE IMPÉRIALE LAMÈD",NULL},
/* 1084C */ { "LETTRE ARAMÉENNE IMPÉRIALE MÉM",NULL},
/* 1084D */ { "LETTRE ARAMÉENNE IMPÉRIALE NOUN",NULL},
/* 1084E */ { "LETTRE ARAMÉENNE IMPÉRIALE SAMÈKH",NULL},
/* 1084F */ { "LETTRE ARAMÉENNE IMPÉRIALE 'AÏN",NULL},
/* 10850 */ { "LETTRE ARAMÉENNE IMPÉRIALE PÉ",NULL},
/* 10851 */ { "LETTRE ARAMÉENNE IMPÉRIALE TSADÉ",NULL},
/* 10852 */ { "LETTRE ARAMÉENNE IMPÉRIALE QOUF",NULL},
/* 10853 */ { "LETTRE ARAMÉENNE IMPÉRIALE RÈCH",NULL},
/* 10854 */ { "LETTRE ARAMÉENNE IMPÉRIALE CHINE",NULL},
/* 10855 */ { "LETTRE ARAMÉENNE IMPÉRIALE TAW",NULL},
/* 10856 */ { NULL,NULL},
/* 10857 */ { "PARAGRAPHE ARAMÉEN IMPÉRIAL",NULL},
/* 10858 */ { "NOMBRE ARAMÉEN IMPÉRIAL UN",NULL},
/* 10859 */ { "NOMBRE ARAMÉEN IMPÉRIAL DEUX",NULL},
/* 1085A */ { "NOMBRE ARAMÉEN IMPÉRIAL TROIS",NULL},
/* 1085B */ { "NOMBRE ARAMÉEN IMPÉRIAL DIX",NULL},
/* 1085C */ { "NOMBRE ARAMÉEN IMPÉRIAL VINGT",NULL},
/* 1085D */ { "NOMBRE ARAMÉEN IMPÉRIAL CENT",NULL},
/* 1085E */ { "NOMBRE ARAMÉEN IMPÉRIAL MILLE",NULL},
/* 1085F */ { "NOMBRE ARAMÉEN IMPÉRIAL DIX MILLE",NULL},
/* 10860 */ { "LETTRE PALMYRÉENNE ALEF",NULL},
/* 10861 */ { "LETTRE PALMYRÉENNE BÈT",NULL},
/* 10862 */ { "LETTRE PALMYRÉENNE GUIMEL",NULL},
/* 10863 */ { "LETTRE PALMYRÉENNE DALÈT",NULL},
/* 10864 */ { "LETTRE PALMYRÉENNE HÈ",NULL},
/* 10865 */ { "LETTRE PALMYRÉENNE WAW",NULL},
/* 10866 */ { "LETTRE PALMYRÉENNE ZAÏN",NULL},
/* 10867 */ { "LETTRE PALMYRÉENNE HÈT",NULL},
/* 10868 */ { "LETTRE PALMYRÉENNE TÈT",NULL},
/* 10869 */ { "LETTRE PALMYRÉENNE YOD",NULL},
/* 1086A */ { "LETTRE PALMYRÉENNE KAF",NULL},
/* 1086B */ { "LETTRE PALMYRÉENNE LAMÈD",NULL},
/* 1086C */ { "LETTRE PALMYRÉENNE MÉM",NULL},
/* 1086D */ { "LETTRE PALMYRÉENNE NOUN FINAL",NULL},
/* 1086E */ { "LETTRE PALMYRÉENNE NOUN",NULL},
/* 1086F */ { "LETTRE PALMYRÉENNE SAMÈKH",NULL},
/* 10870 */ { "LETTRE PALMYRÉENNE 'AÏN",NULL},
/* 10871 */ { "LETTRE PALMYRÉENNE PÉ",NULL},
/* 10872 */ { "LETTRE PALMYRÉENNE TSADÉ",NULL},
/* 10873 */ { "LETTRE PALMYRÉENNE QOUF",NULL},
/* 10874 */ { "LETTRE PALMYRÉENNE RÈCH",NULL},
/* 10875 */ { "LETTRE PALMYRÉENNE CHINE",NULL},
/* 10876 */ { "LETTRE PALMYRÉENNE TAW",NULL},
/* 10877 */ { "FLEURON PALMYRÉEN POINTANT VERS LA GAUCHE",NULL},
/* 10878 */ { "FLEURON PALMYRÉEN POINTANT VERS LA DROITE",NULL},
/* 10879 */ { "NOMBRE PALMYRÉEN UN",NULL},
/* 1087A */ { "NOMBRE PALMYRÉEN DEUX",NULL},
/* 1087B */ { "NOMBRE PALMYRÉEN TROIS",NULL},
/* 1087C */ { "NOMBRE PALMYRÉEN QUATRE",NULL},
/* 1087D */ { "NOMBRE PALMYRÉEN CINQ",NULL},
/* 1087E */ { "NOMBRE PALMYRÉEN DIX","	* utilisé aussi pour les centaines"},
/* 1087F */ { "NOMBRE PALMYRÉEN VINGT",NULL},
/* 10880 */ { "LETTRE NABATÉENNE ALEF FINAL",NULL},
/* 10881 */ { "LETTRE NABATÉENNE ALEF",NULL},
/* 10882 */ { "LETTRE NABATÉENNE BÈT FINAL",NULL},
/* 10883 */ { "LETTRE NABATÉENNE BÈT",NULL},
/* 10884 */ { "LETTRE NABATÉENNE GUIMEL",NULL},
/* 10885 */ { "LETTRE NABATÉENNE DALÈT",NULL},
/* 10886 */ { "LETTRE NABATÉENNE HÈ FINAL",NULL},
/* 10887 */ { "LETTRE NABATÉENNE HÈ",NULL},
/* 10888 */ { "LETTRE NABATÉENNE WAW",NULL},
/* 10889 */ { "LETTRE NABATÉENNE ZAÏN",NULL},
/* 1088A */ { "LETTRE NABATÉENNE HÈT",NULL},
/* 1088B */ { "LETTRE NABATÉENNE TÈT",NULL},
/* 1088C */ { "LETTRE NABATÉENNE YOD FINAL",NULL},
/* 1088D */ { "LETTRE NABATÉENNE YOD",NULL},
/* 1088E */ { "LETTRE NABATÉENNE KAF FINAL",NULL},
/* 1088F */ { "LETTRE NABATÉENNE KAF",NULL},
/* 10890 */ { "LETTRE NABATÉENNE LAMÈD FINAL",NULL},
/* 10891 */ { "LETTRE NABATÉENNE LAMÈD",NULL},
/* 10892 */ { "LETTRE NABATÉENNE MÉM FINAL",NULL},
/* 10893 */ { "LETTRE NABATÉENNE MÉM",NULL},
/* 10894 */ { "LETTRE NABATÉENNE NOUN FINAL",NULL},
/* 10895 */ { "LETTRE NABATÉENNE NOUN",NULL},
/* 10896 */ { "LETTRE NABATÉENNE SAMÈKH",NULL},
/* 10897 */ { "LETTRE NABATÉENNE 'AÏN",NULL},
/* 10898 */ { "LETTRE NABATÉENNE PÉ",NULL},
/* 10899 */ { "LETTRE NABATÉENNE TSADÉ",NULL},
/* 1089A */ { "LETTRE NABATÉENNE QOUF",NULL},
/* 1089B */ { "LETTRE NABATÉENNE RÈCH",NULL},
/* 1089C */ { "LETTRE NABATÉENNE CHINE FINAL",NULL},
/* 1089D */ { "LETTRE NABATÉENNE CHINE",NULL},
/* 1089E */ { "LETTRE NABATÉENNE TAW",NULL},
/* 1089F */ { NULL,NULL},
/* 108A0 */ { NULL,NULL},
/* 108A1 */ { NULL,NULL},
/* 108A2 */ { NULL,NULL},
/* 108A3 */ { NULL,NULL},
/* 108A4 */ { NULL,NULL},
/* 108A5 */ { NULL,NULL},
/* 108A6 */ { NULL,NULL},
/* 108A7 */ { "NOMBRE NABATÉEN UN",NULL},
/* 108A8 */ { "NOMBRE NABATÉEN DEUX",NULL},
/* 108A9 */ { "NOMBRE NABATÉEN TROIS",NULL},
/* 108AA */ { "NOMBRE NABATÉEN QUATRE",NULL},
/* 108AB */ { "NOMBRE NABATÉEN CRUCIFORME QUATRE",NULL},
/* 108AC */ { "NOMBRE NABATÉEN CINQ",NULL},
/* 108AD */ { "NOMBRE NABATÉEN DIX",NULL},
/* 108AE */ { "NOMBRE NABATÉEN VINGT",NULL},
/* 108AF */ { "NOMBRE NABATÉEN CENT",NULL},
/* 108B0 */ { NULL,NULL},
/* 108B1 */ { NULL,NULL},
/* 108B2 */ { NULL,NULL},
/* 108B3 */ { NULL,NULL},
/* 108B4 */ { NULL,NULL},
/* 108B5 */ { NULL,NULL},
/* 108B6 */ { NULL,NULL},
/* 108B7 */ { NULL,NULL},
/* 108B8 */ { NULL,NULL},
/* 108B9 */ { NULL,NULL},
/* 108BA */ { NULL,NULL},
/* 108BB */ { NULL,NULL},
/* 108BC */ { NULL,NULL},
/* 108BD */ { NULL,NULL},
/* 108BE */ { NULL,NULL},
/* 108BF */ { NULL,NULL},
/* 108C0 */ { NULL,NULL},
/* 108C1 */ { NULL,NULL},
/* 108C2 */ { NULL,NULL},
/* 108C3 */ { NULL,NULL},
/* 108C4 */ { NULL,NULL},
/* 108C5 */ { NULL,NULL},
/* 108C6 */ { NULL,NULL},
/* 108C7 */ { NULL,NULL},
/* 108C8 */ { NULL,NULL},
/* 108C9 */ { NULL,NULL},
/* 108CA */ { NULL,NULL},
/* 108CB */ { NULL,NULL},
/* 108CC */ { NULL,NULL},
/* 108CD */ { NULL,NULL},
/* 108CE */ { NULL,NULL},
/* 108CF */ { NULL,NULL},
/* 108D0 */ { NULL,NULL},
/* 108D1 */ { NULL,NULL},
/* 108D2 */ { NULL,NULL},
/* 108D3 */ { NULL,NULL},
/* 108D4 */ { NULL,NULL},
/* 108D5 */ { NULL,NULL},
/* 108D6 */ { NULL,NULL},
/* 108D7 */ { NULL,NULL},
/* 108D8 */ { NULL,NULL},
/* 108D9 */ { NULL,NULL},
/* 108DA */ { NULL,NULL},
/* 108DB */ { NULL,NULL},
/* 108DC */ { NULL,NULL},
/* 108DD */ { NULL,NULL},
/* 108DE */ { NULL,NULL},
/* 108DF */ { NULL,NULL},
/* 108E0 */ { "LETTRE HATRÉENNE ALEF",NULL},
/* 108E1 */ { "LETTRE HATRÉENNE BÈT",NULL},
/* 108E2 */ { "LETTRE HATRÉENNE GUIMEL",NULL},
/* 108E3 */ { "LETTRE HATRÉENNE DALÈT-RÈCH",NULL},
/* 108E4 */ { "LETTRE HATRÉENNE HÈ",NULL},
/* 108E5 */ { "LETTRE HATRÉENNE WAW",NULL},
/* 108E6 */ { "LETTRE HATRÉENNE ZAÏN",NULL},
/* 108E7 */ { "LETTRE HATRÉENNE HÈT",NULL},
/* 108E8 */ { "LETTRE HATRÉENNE TÈT",NULL},
/* 108E9 */ { "LETTRE HATRÉENNE YOD",NULL},
/* 108EA */ { "LETTRE HATRÉENNE KAF",NULL},
/* 108EB */ { "LETTRE HATRÉENNE LAMÈD",NULL},
/* 108EC */ { "LETTRE HATRÉENNE MÉM",NULL},
/* 108ED */ { "LETTRE HATRÉENNE NOUN",NULL},
/* 108EE */ { "LETTRE HATRÉENNE SAMÈKH",NULL},
/* 108EF */ { "LETTRE HATRÉENNE 'AÏN",NULL},
/* 108F0 */ { "LETTRE HATRÉENNE PÉ",NULL},
/* 108F1 */ { "LETTRE HATRÉENNE TSADÉ",NULL},
/* 108F2 */ { "LETTRE HATRÉENNE QOUF",NULL},
/* 108F3 */ { NULL,NULL},
/* 108F4 */ { "LETTRE HATRÉENNE CHINE",NULL},
/* 108F5 */ { "LETTRE HATRÉENNE TAW",NULL},
/* 108F6 */ { NULL,NULL},
/* 108F7 */ { NULL,NULL},
/* 108F8 */ { NULL,NULL},
/* 108F9 */ { NULL,NULL},
/* 108FA */ { NULL,NULL},
/* 108FB */ { "NOMBRE HATRÉEN UN",NULL},
/* 108FC */ { "NOMBRE HATRÉEN CINQ",NULL},
/* 108FD */ { "NOMBRE HATRÉEN DIX",NULL},
/* 108FE */ { "NOMBRE HATRÉEN VINGT",NULL},
/* 108FF */ { "NOMBRE HATRÉEN CENT",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_09[] = {
/* 10900 */ { "LETTRE PHÉNICIENNE ALF","	x (lettre hébraïque alef - 05D0)"},
/* 10901 */ { "LETTRE PHÉNICIENNE BÈT","	x (lettre hébraïque bèt - 05D1)"},
/* 10902 */ { "LETTRE PHÉNICIENNE GAML","	x (lettre hébraïque guimel - 05D2)"},
/* 10903 */ { "LETTRE PHÉNICIENNE DELT","	x (lettre hébraïque dalèt - 05D3)"},
/* 10904 */ { "LETTRE PHÉNICIENNE HÈ","	x (lettre hébraïque hè - 05D4)"},
/* 10905 */ { "LETTRE PHÉNICIENNE WAW","	x (lettre hébraïque waw - 05D5)"},
/* 10906 */ { "LETTRE PHÉNICIENNE ZAÏ","	x (lettre hébraïque zaïn - 05D6)"},
/* 10907 */ { "LETTRE PHÉNICIENNE HÈT","	x (lettre hébraïque hèt - 05D7)"},
/* 10908 */ { "LETTRE PHÉNICIENNE TÈT","	x (lettre hébraïque tèt - 05D8)"},
/* 10909 */ { "LETTRE PHÉNICIENNE YOD","	x (lettre hébraïque yod - 05D9)"},
/* 1090A */ { "LETTRE PHÉNICIENNE KAF","	x (lettre hébraïque kaf - 05DB)"},
/* 1090B */ { "LETTRE PHÉNICIENNE LAMD","	x (lettre hébraïque lamèd - 05DC)"},
/* 1090C */ { "LETTRE PHÉNICIENNE MÉM","	x (lettre hébraïque mém - 05DE)"},
/* 1090D */ { "LETTRE PHÉNICIENNE NOUN","	x (lettre hébraïque noun - 05E0)"},
/* 1090E */ { "LETTRE PHÉNICIENNE SEMK","	x (lettre hébraïque samèkh - 05E1)"},
/* 1090F */ { "LETTRE PHÉNICIENNE 'AÏN","	x (lettre hébraïque 'aïn - 05E2)"},
/* 10910 */ { "LETTRE PHÉNICIENNE PÉ","	x (lettre hébraïque pé - 05E4)"},
/* 10911 */ { "LETTRE PHÉNICIENNE TSADÉ","	x (lettre hébraïque tsadé - 05E6)"},
/* 10912 */ { "LETTRE PHÉNICIENNE QOUF","	x (lettre hébraïque qouf - 05E7)"},
/* 10913 */ { "LETTRE PHÉNICIENNE ROCH","	x (lettre hébraïque rèch - 05E8)"},
/* 10914 */ { "LETTRE PHÉNICIENNE CHINE","	x (lettre hébraïque chine - 05E9)"},
/* 10915 */ { "LETTRE PHÉNICIENNE TAW","	x (lettre hébraïque taw - 05EA)"},
/* 10916 */ { "NOMBRE PHÉNICIEN UN",NULL},
/* 10917 */ { "NOMBRE PHÉNICIEN DIX",NULL},
/* 10918 */ { "NOMBRE PHÉNICIEN VINGT",NULL},
/* 10919 */ { "NOMBRE PHÉNICIEN CENT",NULL},
/* 1091A */ { "NOMBRE PHÉNICIEN DEUX",NULL},
/* 1091B */ { "NOMBRE PHÉNICIEN TROIS",NULL},
/* 1091C */ { NULL,NULL},
/* 1091D */ { NULL,NULL},
/* 1091E */ { NULL,NULL},
/* 1091F */ { "SÉPARATEUR DE MOTS PHÉNICIEN","	* le glyphe peut prendre l'aspect d'une courte barre verticale\n"
	"	x (point - 002E)\n"
	"	x (point médian - 00B7)\n"
	"	x (point médian séparateur de mots - 2E31)"},
/* 10920 */ { "LETTRE LYDIENNE A",NULL},
/* 10921 */ { "LETTRE LYDIENNE B",NULL},
/* 10922 */ { "LETTRE LYDIENNE G",NULL},
/* 10923 */ { "LETTRE LYDIENNE D",NULL},
/* 10924 */ { "LETTRE LYDIENNE E",NULL},
/* 10925 */ { "LETTRE LYDIENNE V",NULL},
/* 10926 */ { "LETTRE LYDIENNE I",NULL},
/* 10927 */ { "LETTRE LYDIENNE Y",NULL},
/* 10928 */ { "LETTRE LYDIENNE K",NULL},
/* 10929 */ { "LETTRE LYDIENNE L",NULL},
/* 1092A */ { "LETTRE LYDIENNE M",NULL},
/* 1092B */ { "LETTRE LYDIENNE N",NULL},
/* 1092C */ { "LETTRE LYDIENNE O",NULL},
/* 1092D */ { "LETTRE LYDIENNE R",NULL},
/* 1092E */ { "LETTRE LYDIENNE SS",NULL},
/* 1092F */ { "LETTRE LYDIENNE T",NULL},
/* 10930 */ { "LETTRE LYDIENNE U",NULL},
/* 10931 */ { "LETTRE LYDIENNE F",NULL},
/* 10932 */ { "LETTRE LYDIENNE Q",NULL},
/* 10933 */ { "LETTRE LYDIENNE S",NULL},
/* 10934 */ { "LETTRE LYDIENNE TT",NULL},
/* 10935 */ { "LETTRE LYDIENNE AN",NULL},
/* 10936 */ { "LETTRE LYDIENNE EN",NULL},
/* 10937 */ { "LETTRE LYDIENNE LL",NULL},
/* 10938 */ { "LETTRE LYDIENNE NN",NULL},
/* 10939 */ { "LETTRE LYDIENNE C",NULL},
/* 1093A */ { NULL,NULL},
/* 1093B */ { NULL,NULL},
/* 1093C */ { NULL,NULL},
/* 1093D */ { NULL,NULL},
/* 1093E */ { NULL,NULL},
/* 1093F */ { "SIGNE TRIANGULAIRE LYDIEN",NULL},
/* 10940 */ { "LETTRE SIDÉTIQUE N01","	* voyelle a"},
/* 10941 */ { "LETTRE SIDÉTIQUE N02","	* voyelle e"},
/* 10942 */ { "LETTRE SIDÉTIQUE N03","	* voyelle i"},
/* 10943 */ { "LETTRE SIDÉTIQUE N04","	* voyelle o"},
/* 10944 */ { "LETTRE SIDÉTIQUE N05","	* voyelle u"},
/* 10945 */ { "LETTRE SIDÉTIQUE N06","	* semi-voyelle w"},
/* 10946 */ { "LETTRE SIDÉTIQUE N07","	* semi-voyelle y"},
/* 10947 */ { "LETTRE SIDÉTIQUE N08","	* consonne p"},
/* 10948 */ { "LETTRE SIDÉTIQUE N09","	* consonne d2"},
/* 10949 */ { "LETTRE SIDÉTIQUE N10","	* consonne m"},
/* 1094A */ { "LETTRE SIDÉTIQUE N11","	* consonne t"},
/* 1094B */ { "LETTRE SIDÉTIQUE N12","	* consonne d"},
/* 1094C */ { "LETTRE SIDÉTIQUE N13","	* consonne θ"},
/* 1094D */ { "LETTRE SIDÉTIQUE N14","	* consonne fricative s"},
/* 1094E */ { "LETTRE SIDÉTIQUE N15","	* consonne fricative s2"},
/* 1094F */ { "LETTRE SIDÉTIQUE N16","	* consonne n"},
/* 10950 */ { "LETTRE SIDÉTIQUE N17","	* consonne l"},
/* 10951 */ { "LETTRE SIDÉTIQUE N18","	* consonne"},
/* 10952 */ { "LETTRE SIDÉTIQUE N19","	* consonne g"},
/* 10953 */ { "LETTRE SIDÉTIQUE N20","	* khi grec"},
/* 10954 */ { "LETTRE SIDÉTIQUE N21","	* consonne r"},
/* 10955 */ { "LETTRE SIDÉTIQUE N22","	* voyelle"},
/* 10956 */ { "LETTRE SIDÉTIQUE N23","	* consonne k"},
/* 10957 */ { "LETTRE SIDÉTIQUE N24","	* consonne b"},
/* 10958 */ { "LETTRE SIDÉTIQUE N25","	* consonne n2"},
/* 10959 */ { "LETTRE SIDÉTIQUE N26","	* consonne z"},
/* 1095A */ { NULL,NULL},
/* 1095B */ { NULL,NULL},
/* 1095C */ { NULL,NULL},
/* 1095D */ { NULL,NULL},
/* 1095E */ { NULL,NULL},
/* 1095F */ { NULL,NULL},
/* 10960 */ { NULL,NULL},
/* 10961 */ { NULL,NULL},
/* 10962 */ { NULL,NULL},
/* 10963 */ { NULL,NULL},
/* 10964 */ { NULL,NULL},
/* 10965 */ { NULL,NULL},
/* 10966 */ { NULL,NULL},
/* 10967 */ { NULL,NULL},
/* 10968 */ { NULL,NULL},
/* 10969 */ { NULL,NULL},
/* 1096A */ { NULL,NULL},
/* 1096B */ { NULL,NULL},
/* 1096C */ { NULL,NULL},
/* 1096D */ { NULL,NULL},
/* 1096E */ { NULL,NULL},
/* 1096F */ { NULL,NULL},
/* 10970 */ { NULL,NULL},
/* 10971 */ { NULL,NULL},
/* 10972 */ { NULL,NULL},
/* 10973 */ { NULL,NULL},
/* 10974 */ { NULL,NULL},
/* 10975 */ { NULL,NULL},
/* 10976 */ { NULL,NULL},
/* 10977 */ { NULL,NULL},
/* 10978 */ { NULL,NULL},
/* 10979 */ { NULL,NULL},
/* 1097A */ { NULL,NULL},
/* 1097B */ { NULL,NULL},
/* 1097C */ { NULL,NULL},
/* 1097D */ { NULL,NULL},
/* 1097E */ { NULL,NULL},
/* 1097F */ { NULL,NULL},
/* 10980 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE A","	x (hiéroglyphe égyptien a001 - 13000)"},
/* 10981 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE E","	x (hiéroglyphe égyptien h006 - 13184)"},
/* 10982 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE I","	x (hiéroglyphe égyptien a026 - 1301E)"},
/* 10983 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE O","	x (hiéroglyphe égyptien f001 - 130FE)"},
/* 10984 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE YA","	x (hiéroglyphe égyptien m017a - 131CC)"},
/* 10985 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE WA","	x (hiéroglyphe égyptien v004 - 1336F)"},
/* 10986 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE BA","	x (hiéroglyphe égyptien e011 - 130DE)"},
/* 10987 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE BA-2","	x (hiéroglyphe égyptien d058 - 130C0)"},
/* 10988 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE PA","	x (hiéroglyphe égyptien q003 - 132AA)"},
/* 10989 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE MA","	x (hiéroglyphe égyptien g017 - 13153)"},
/* 1098A */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE NA","	x (hiéroglyphe égyptien n035 - 13216)"},
/* 1098B */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE NA-2",NULL},
/* 1098C */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE NE","	x (hiéroglyphe égyptien m022a - 131D2)"},
/* 1098D */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE NE-2",NULL},
/* 1098E */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE RA","	x (hiéroglyphe égyptien d021 - 1308B)"},
/* 1098F */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE RA-2",NULL},
/* 10990 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE LA","	x (hiéroglyphe égyptien e023 - 130ED)"},
/* 10991 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE KHA","	x (hiéroglyphe égyptien aa001 - 1340D)"},
/* 10992 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE HHA","	x (hiéroglyphe égyptien w011 - 133BC)"},
/* 10993 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE SA","	x (hiéroglyphe égyptien m008 - 131B7)"},
/* 10994 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE SA-2","	x (hiéroglyphe égyptien o034 - 13283)"},
/* 10995 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE SE","	x (hiéroglyphe égyptien o034 - 13283)"},
/* 10996 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE KA","	x (hiéroglyphe égyptien g038 - 1316C)"},
/* 10997 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE QA","	x (hiéroglyphe égyptien n029 - 1320E)"},
/* 10998 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE TA","	x (hiéroglyphe égyptien v013 - 1337F)"},
/* 10999 */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE TA-2","	x (hiéroglyphe égyptien n016 - 131FE)"},
/* 1099A */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE TE","	x (hiéroglyphe égyptien n016 - 131FE)\n"
	"	x (hiéroglyphe égyptien o004 - 13254)"},
/* 1099B */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE TE-2","	x (hiéroglyphe égyptien o004 - 13254)"},
/* 1099C */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE TO","	x (hiéroglyphe égyptien n021 - 13205)"},
/* 1099D */ { "LETTRE HIÉROGLYPHIQUE MÉROÏTIQUE DA","	x (hiéroglyphe égyptien d006 - 1307B)"},
/* 1099E */ { "SYMBOLE HIÉROGLYPHIQUE MÉROÏTIQUE VIDJ","	x (ankh - 2625)\n"
	"	x (hiéroglyphe égyptien s034 - 132F9)"},
/* 1099F */ { "SYMBOLE HIÉROGLYPHIQUE MÉROÏTIQUE VIDJ-2",NULL},
/* 109A0 */ { "LETTRE CURSIVE MÉROÏTIQUE A",NULL},
/* 109A1 */ { "LETTRE CURSIVE MÉROÏTIQUE E",NULL},
/* 109A2 */ { "LETTRE CURSIVE MÉROÏTIQUE I",NULL},
/* 109A3 */ { "LETTRE CURSIVE MÉROÏTIQUE O",NULL},
/* 109A4 */ { "LETTRE CURSIVE MÉROÏTIQUE YA",NULL},
/* 109A5 */ { "LETTRE CURSIVE MÉROÏTIQUE WA",NULL},
/* 109A6 */ { "LETTRE CURSIVE MÉROÏTIQUE BA",NULL},
/* 109A7 */ { "LETTRE CURSIVE MÉROÏTIQUE PA",NULL},
/* 109A8 */ { "LETTRE CURSIVE MÉROÏTIQUE MA",NULL},
/* 109A9 */ { "LETTRE CURSIVE MÉROÏTIQUE NA",NULL},
/* 109AA */ { "LETTRE CURSIVE MÉROÏTIQUE NE",NULL},
/* 109AB */ { "LETTRE CURSIVE MÉROÏTIQUE RA",NULL},
/* 109AC */ { "LETTRE CURSIVE MÉROÏTIQUE LA",NULL},
/* 109AD */ { "LETTRE CURSIVE MÉROÏTIQUE KHA",NULL},
/* 109AE */ { "LETTRE CURSIVE MÉROÏTIQUE HHA",NULL},
/* 109AF */ { "LETTRE CURSIVE MÉROÏTIQUE SA",NULL},
/* 109B0 */ { "LETTRE CURSIVE MÉROÏTIQUE SA ARCHAÏQUE",NULL},
/* 109B1 */ { "LETTRE CURSIVE MÉROÏTIQUE SE",NULL},
/* 109B2 */ { "LETTRE CURSIVE MÉROÏTIQUE KA",NULL},
/* 109B3 */ { "LETTRE CURSIVE MÉROÏTIQUE QA",NULL},
/* 109B4 */ { "LETTRE CURSIVE MÉROÏTIQUE TA",NULL},
/* 109B5 */ { "LETTRE CURSIVE MÉROÏTIQUE TE",NULL},
/* 109B6 */ { "LETTRE CURSIVE MÉROÏTIQUE TO",NULL},
/* 109B7 */ { "LETTRE CURSIVE MÉROÏTIQUE DA",NULL},
/* 109B8 */ { NULL,NULL},
/* 109B9 */ { NULL,NULL},
/* 109BA */ { NULL,NULL},
/* 109BB */ { NULL,NULL},
/* 109BC */ { "FRACTION CURSIVE MÉROÏTIQUE ONZE DOUZIÈMES",NULL},
/* 109BD */ { "FRACTION CURSIVE MÉROÏTIQUE UN DEMI",NULL},
/* 109BE */ { "LOGOGRAMME CURSIF MÉROÏTIQUE RMT",NULL},
/* 109BF */ { "LOGOGRAMME CURSIF MÉROÏTIQUE IMN",NULL},
/* 109C0 */ { "NOMBRE CURSIF MÉROÏTIQUE UN",NULL},
/* 109C1 */ { "NOMBRE CURSIF MÉROÏTIQUE DEUX",NULL},
/* 109C2 */ { "NOMBRE CURSIF MÉROÏTIQUE TROIS",NULL},
/* 109C3 */ { "NOMBRE CURSIF MÉROÏTIQUE QUATRE",NULL},
/* 109C4 */ { "NOMBRE CURSIF MÉROÏTIQUE CINQ",NULL},
/* 109C5 */ { "NOMBRE CURSIF MÉROÏTIQUE SIX",NULL},
/* 109C6 */ { "NOMBRE CURSIF MÉROÏTIQUE SEPT",NULL},
/* 109C7 */ { "NOMBRE CURSIF MÉROÏTIQUE HUIT",NULL},
/* 109C8 */ { "NOMBRE CURSIF MÉROÏTIQUE NEUF",NULL},
/* 109C9 */ { "NOMBRE CURSIF MÉROÏTIQUE DIX",NULL},
/* 109CA */ { "NOMBRE CURSIF MÉROÏTIQUE VINGT",NULL},
/* 109CB */ { "NOMBRE CURSIF MÉROÏTIQUE TRENTE",NULL},
/* 109CC */ { "NOMBRE CURSIF MÉROÏTIQUE QUARANTE",NULL},
/* 109CD */ { "NOMBRE CURSIF MÉROÏTIQUE CINQUANTE",NULL},
/* 109CE */ { "NOMBRE CURSIF MÉROÏTIQUE SOIXANTE",NULL},
/* 109CF */ { "NOMBRE CURSIF MÉROÏTIQUE SOIXANTE-DIX","	= nombre méroïtique cursif septante"},
/* 109D0 */ { NULL,NULL},
/* 109D1 */ { NULL,NULL},
/* 109D2 */ { "NOMBRE CURSIF MÉROÏTIQUE CENT",NULL},
/* 109D3 */ { "NOMBRE CURSIF MÉROÏTIQUE DEUX CENTS",NULL},
/* 109D4 */ { "NOMBRE CURSIF MÉROÏTIQUE TROIS CENTS",NULL},
/* 109D5 */ { "NOMBRE CURSIF MÉROÏTIQUE QUATRE CENTS",NULL},
/* 109D6 */ { "NOMBRE CURSIF MÉROÏTIQUE CINQ CENTS",NULL},
/* 109D7 */ { "NOMBRE CURSIF MÉROÏTIQUE SIX CENTS",NULL},
/* 109D8 */ { "NOMBRE CURSIF MÉROÏTIQUE SEPT CENTS",NULL},
/* 109D9 */ { "NOMBRE CURSIF MÉROÏTIQUE HUIT CENTS",NULL},
/* 109DA */ { "NOMBRE CURSIF MÉROÏTIQUE NEUF CENTS",NULL},
/* 109DB */ { "NOMBRE CURSIF MÉROÏTIQUE MILLE",NULL},
/* 109DC */ { "NOMBRE CURSIF MÉROÏTIQUE DEUX MILLE",NULL},
/* 109DD */ { "NOMBRE CURSIF MÉROÏTIQUE TROIS MILLE",NULL},
/* 109DE */ { "NOMBRE CURSIF MÉROÏTIQUE QUATRE MILLE",NULL},
/* 109DF */ { "NOMBRE CURSIF MÉROÏTIQUE CINQ MILLE",NULL},
/* 109E0 */ { "NOMBRE CURSIF MÉROÏTIQUE SIX MILLE",NULL},
/* 109E1 */ { "NOMBRE CURSIF MÉROÏTIQUE SEPT MILLE",NULL},
/* 109E2 */ { "NOMBRE CURSIF MÉROÏTIQUE HUIT MILLE",NULL},
/* 109E3 */ { "NOMBRE CURSIF MÉROÏTIQUE NEUF MILLE",NULL},
/* 109E4 */ { "NOMBRE CURSIF MÉROÏTIQUE DIX MILLE",NULL},
/* 109E5 */ { "NOMBRE CURSIF MÉROÏTIQUE VINGT MILLE",NULL},
/* 109E6 */ { "NOMBRE CURSIF MÉROÏTIQUE TRENTE MILLE",NULL},
/* 109E7 */ { "NOMBRE CURSIF MÉROÏTIQUE QUARANTE MILLE",NULL},
/* 109E8 */ { "NOMBRE CURSIF MÉROÏTIQUE CINQUANTE MILLE",NULL},
/* 109E9 */ { "NOMBRE CURSIF MÉROÏTIQUE SOIXANTE MILLE",NULL},
/* 109EA */ { "NOMBRE CURSIF MÉROÏTIQUE SOIXANTE-DIX MILLE","	= nombre méroïtique cursif septante mille"},
/* 109EB */ { "NOMBRE CURSIF MÉROÏTIQUE QUATRE-VINGT MILLE","	= nombre méroïtique cursif huitante mille"},
/* 109EC */ { "NOMBRE CURSIF MÉROÏTIQUE QUATRE-VINGT-DIX MILLE","	= nombre méroïtique cursif nonante mille"},
/* 109ED */ { "NOMBRE CURSIF MÉROÏTIQUE CENT MILLE",NULL},
/* 109EE */ { "NOMBRE CURSIF MÉROÏTIQUE DEUX CENT MILLE",NULL},
/* 109EF */ { "NOMBRE CURSIF MÉROÏTIQUE TROIS CENT MILLE",NULL},
/* 109F0 */ { "NOMBRE CURSIF MÉROÏTIQUE QUATRE CENT MILLE",NULL},
/* 109F1 */ { "NOMBRE CURSIF MÉROÏTIQUE CINQ CENT MILLE",NULL},
/* 109F2 */ { "NOMBRE CURSIF MÉROÏTIQUE SIX CENT MILLE",NULL},
/* 109F3 */ { "NOMBRE CURSIF MÉROÏTIQUE SEPT CENT MILLE",NULL},
/* 109F4 */ { "NOMBRE CURSIF MÉROÏTIQUE HUIT CENT MILLE",NULL},
/* 109F5 */ { "NOMBRE CURSIF MÉROÏTIQUE NEUF CENT MILLE",NULL},
/* 109F6 */ { "FRACTION CURSIVE MÉROÏTIQUE UN DOUZIÈME",NULL},
/* 109F7 */ { "FRACTION CURSIVE MÉROÏTIQUE DEUX DOUZIÈMES",NULL},
/* 109F8 */ { "FRACTION CURSIVE MÉROÏTIQUE TROIS DOUZIÈMES",NULL},
/* 109F9 */ { "FRACTION CURSIVE MÉROÏTIQUE QUATRE DOUZIÈMES",NULL},
/* 109FA */ { "FRACTION CURSIVE MÉROÏTIQUE CINQ DOUZIÈMES",NULL},
/* 109FB */ { "FRACTION CURSIVE MÉROÏTIQUE SIX DOUZIÈMES",NULL},
/* 109FC */ { "FRACTION CURSIVE MÉROÏTIQUE SEPT DOUZIÈMES",NULL},
/* 109FD */ { "FRACTION CURSIVE MÉROÏTIQUE HUIT DOUZIÈMES",NULL},
/* 109FE */ { "FRACTION CURSIVE MÉROÏTIQUE NEUF DOUZIÈMES",NULL},
/* 109FF */ { "FRACTION CURSIVE MÉROÏTIQUE DIX DOUZIÈMES",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_0A[] = {
/* 10A00 */ { "LETTRE KHAROCHTHÎ A",NULL},
/* 10A01 */ { "DIACRITIQUE VOYELLE KHAROCHTHÎ I",NULL},
/* 10A02 */ { "DIACRITIQUE VOYELLE KHAROCHTHÎ OU",NULL},
/* 10A03 */ { "DIACRITIQUE VOYELLE KHAROCHTHÎ R VOCALIQUE",NULL},
/* 10A04 */ { NULL,NULL},
/* 10A05 */ { "DIACRITIQUE VOYELLE KHAROCHTHÎ É",NULL},
/* 10A06 */ { "DIACRITIQUE VOYELLE KHAROCHTHÎ O",NULL},
/* 10A07 */ { NULL,NULL},
/* 10A08 */ { NULL,NULL},
/* 10A09 */ { NULL,NULL},
/* 10A0A */ { NULL,NULL},
/* 10A0B */ { NULL,NULL},
/* 10A0C */ { "SIGNE KHAROCHTHÎ DE LONGUEUR",NULL},
/* 10A0D */ { "DIACRITIQUE KHAROCHTHÎ DOUBLE ROND SOUSCRIT",NULL},
/* 10A0E */ { "DIACRITIQUE KHAROCHTHÎ ANOUSVÂRA",NULL},
/* 10A0F */ { "DIACRITIQUE KHAROCHTHÎ VISARGA",NULL},
/* 10A10 */ { "LETTRE KHAROCHTHÎ KA",NULL},
/* 10A11 */ { "LETTRE KHAROCHTHÎ KHA",NULL},
/* 10A12 */ { "LETTRE KHAROCHTHÎ GA",NULL},
/* 10A13 */ { "LETTRE KHAROCHTHÎ GHA",NULL},
/* 10A14 */ { NULL,NULL},
/* 10A15 */ { "LETTRE KHAROCHTHÎ TCHA",NULL},
/* 10A16 */ { "LETTRE KHAROCHTHÎ TCHHA",NULL},
/* 10A17 */ { "LETTRE KHAROCHTHÎ DJA",NULL},
/* 10A18 */ { NULL,NULL},
/* 10A19 */ { "LETTRE KHAROCHTHÎ ÑA",NULL},
/* 10A1A */ { "LETTRE KHAROCHTHÎ TTA",NULL},
/* 10A1B */ { "LETTRE KHAROCHTHÎ TTHA",NULL},
/* 10A1C */ { "LETTRE KHAROCHTHÎ DDA",NULL},
/* 10A1D */ { "LETTRE KHAROCHTHÎ DDHA",NULL},
/* 10A1E */ { "LETTRE KHAROCHTHÎ NNA",NULL},
/* 10A1F */ { "LETTRE KHAROCHTHÎ TA",NULL},
/* 10A20 */ { "LETTRE KHAROCHTHÎ THA",NULL},
/* 10A21 */ { "LETTRE KHAROCHTHÎ DA",NULL},
/* 10A22 */ { "LETTRE KHAROCHTHÎ DHA",NULL},
/* 10A23 */ { "LETTRE KHAROCHTHÎ NA",NULL},
/* 10A24 */ { "LETTRE KHAROCHTHÎ PA",NULL},
/* 10A25 */ { "LETTRE KHAROCHTHÎ PHA","	= lettre kharochthî p'a"},
/* 10A26 */ { "LETTRE KHAROCHTHÎ BA",NULL},
/* 10A27 */ { "LETTRE KHAROCHTHÎ BHA",NULL},
/* 10A28 */ { "LETTRE KHAROCHTHÎ MA",NULL},
/* 10A29 */ { "LETTRE KHAROCHTHÎ YA",NULL},
/* 10A2A */ { "LETTRE KHAROCHTHÎ RA",NULL},
/* 10A2B */ { "LETTRE KHAROCHTHÎ LA",NULL},
/* 10A2C */ { "LETTRE KHAROCHTHÎ VA",NULL},
/* 10A2D */ { "LETTRE KHAROCHTHÎ ÇA",NULL},
/* 10A2E */ { "LETTRE KHAROCHTHÎ CHA",NULL},
/* 10A2F */ { "LETTRE KHAROCHTHÎ SA",NULL},
/* 10A30 */ { "LETTRE KHAROCHTHÎ ZA",NULL},
/* 10A31 */ { "LETTRE KHAROCHTHÎ HA",NULL},
/* 10A32 */ { "LETTRE KHAROCHTHÎ KKA",NULL},
/* 10A33 */ { "LETTRE KHAROCHTHÎ TTTHA",NULL},
/* 10A34 */ { "LETTRE KHAROCHTHÎ TTTA",NULL},
/* 10A35 */ { "LETTRE KHAROCHTHÎ VHA",NULL},
/* 10A36 */ { NULL,NULL},
/* 10A37 */ { NULL,NULL},
/* 10A38 */ { "DIACRITIQUE KHAROCHTHÎ TRAIT EN CHEF",NULL},
/* 10A39 */ { "DIACRITIQUE KHAROCHTHÎ TCHAOUDA",NULL},
/* 10A3A */ { "DIACRITIQUE KHAROCHTHÎ POINT SOUSCRIT",NULL},
/* 10A3B */ { NULL,NULL},
/* 10A3C */ { NULL,NULL},
/* 10A3D */ { NULL,NULL},
/* 10A3E */ { NULL,NULL},
/* 10A3F */ { "DIACRITIQUE KHAROCHTHÎ VIRÂMA","	= halant\n"
	"	* supprime la voyelle inhérente\n"
	"	* la forme choisie est arbitraire, invisible"},
/* 10A40 */ { "CHIFFRE KHAROCHTHÎ UN",NULL},
/* 10A41 */ { "CHIFFRE KHAROCHTHÎ DEUX",NULL},
/* 10A42 */ { "CHIFFRE KHAROCHTHÎ TROIS",NULL},
/* 10A43 */ { "CHIFFRE KHAROCHTHÎ QUATRE",NULL},
/* 10A44 */ { "NOMBRE KHAROCHTHÎ DIX",NULL},
/* 10A45 */ { "NOMBRE KHAROCHTHÎ VINGT",NULL},
/* 10A46 */ { "NOMBRE KHAROCHTHÎ CENT",NULL},
/* 10A47 */ { "NOMBRE KHAROCHTHÎ MILLE",NULL},
/* 10A48 */ { "FRACTION KHAROCHTHÎ UN DEMI",NULL},
/* 10A49 */ { NULL,NULL},
/* 10A4A */ { NULL,NULL},
/* 10A4B */ { NULL,NULL},
/* 10A4C */ { NULL,NULL},
/* 10A4D */ { NULL,NULL},
/* 10A4E */ { NULL,NULL},
/* 10A4F */ { NULL,NULL},
/* 10A50 */ { "PONCTUATION KHAROCHTHÎ POINT",NULL},
/* 10A51 */ { "PONCTUATION KHAROCHTHÎ PETIT CERCLE",NULL},
/* 10A52 */ { "PONCTUATION KHAROCHTHÎ CERCLE",NULL},
/* 10A53 */ { "PONCTUATION KHAROCHTHÎ CROISSANT BARRE",NULL},
/* 10A54 */ { "PONCTUATION KHAROCHTHÎ MANGALAM",NULL},
/* 10A55 */ { "PONCTUATION KHAROCHTHÎ LOTUS",NULL},
/* 10A56 */ { "PONCTUATION KHAROCHTHÎ DANDA",NULL},
/* 10A57 */ { "PONCTUATION KHAROCHTHÎ DOUBLE DANDA",NULL},
/* 10A58 */ { "PONCTUATION KHAROCHTHÎ LIGNES",NULL},
/* 10A59 */ { NULL,NULL},
/* 10A5A */ { NULL,NULL},
/* 10A5B */ { NULL,NULL},
/* 10A5C */ { NULL,NULL},
/* 10A5D */ { NULL,NULL},
/* 10A5E */ { NULL,NULL},
/* 10A5F */ { NULL,NULL},
/* 10A60 */ { "LETTRE SUD-ARABIQUE HÈ","	= hé'\n"
	"	* translittération en h\n"
	"	x (syllabe éthiopienne hä - 1200)"},
/* 10A61 */ { "LETTRE SUD-ARABIQUE LAMÈD","	= lam\n"
	"	* translittération en l\n"
	"	x (syllabe éthiopienne lä - 1208)"},
/* 10A62 */ { "LETTRE SUD-ARABIQUE HÈT","	= ha'\n"
	"	* translittération en 1E25\n"
	"	x (syllabe éthiopienne hhä - 1210)"},
/* 10A63 */ { "LETTRE SUD-ARABIQUE MÉM","	= mîm\n"
	"	* translittération en m\n"
	"	x (syllabe éthiopienne mä - 1218)"},
/* 10A64 */ { "LETTRE SUD-ARABIQUE QOUF","	= qaf\n"
	"	* translittération en q\n"
	"	x (syllabe éthiopienne qä - 1240)"},
/* 10A65 */ { "LETTRE SUD-ARABIQUE WAW","	= waw\n"
	"	* translittération en w\n"
	"	x (syllabe éthiopienne wä - 12C8)"},
/* 10A66 */ { "LETTRE SUD-ARABIQUE CHINE","	= chîn\n"
	"	* translittération en 0161 ou en s2\n"
	"	x (syllabe éthiopienne çä - 1220)"},
/* 10A67 */ { "LETTRE SUD-ARABIQUE RÈCH","	= re', ra'\n"
	"	* translittération en r\n"
	"	x (syllabe éthiopienne rä - 1228)"},
/* 10A68 */ { "LETTRE SUD-ARABIQUE BÈT","	= be', ba'\n"
	"	* translittération en b\n"
	"	x (syllabe éthiopienne bä - 1260)"},
/* 10A69 */ { "LETTRE SUD-ARABIQUE TAW","	= té'\n"
	"	* translittération en t\n"
	"	x (syllabe éthiopienne tä - 1270)"},
/* 10A6A */ { "LETTRE SUD-ARABIQUE SAT","	* translittération en s ou en s1\n"
	"	x (syllabe éthiopienne sä - 1230)"},
/* 10A6B */ { "LETTRE SUD-ARABIQUE KAF","	* translittération en k\n"
	"	x (syllabe éthiopienne kä - 12A8)"},
/* 10A6C */ { "LETTRE SUD-ARABIQUE NOUN","	= noûn\n"
	"	* translittération en n\n"
	"	x (syllabe éthiopienne nä - 1290)"},
/* 10A6D */ { "LETTRE SUD-ARABIQUE KÈT","	= kha'\n"
	"	* translittération en 1E2B\n"
	"	x (syllabe éthiopienne xä - 1280)"},
/* 10A6E */ { "LETTRE SUD-ARABIQUE TSADÉ","	= çad\n"
	"	* translittération en 1E63\n"
	"	x (syllabe éthiopienne tsä - 1338)"},
/* 10A6F */ { "LETTRE SUD-ARABIQUE SAMÈKH","	* translittération en 015B ou en s3"},
/* 10A70 */ { "LETTRE SUD-ARABIQUE FÉ","	= fa'\n"
	"	* translittération en f\n"
	"	x (syllabe éthiopienne fä - 1348)"},
/* 10A71 */ { "LETTRE SUD-ARABIQUE ALIF","	= alef\n"
	"	* translittération en 02BC\n"
	"	x (syllabe éthiopienne ä glottal - 12A0)"},
/* 10A72 */ { "LETTRE SUD-ARABIQUE 'AÏN","	= 'ain\n"
	"	* translittération en 02BD\n"
	"	x (syllabe éthiopienne ä pharyngal - 12D0)"},
/* 10A73 */ { "LETTRE SUD-ARABIQUE DADÉ","	= dad\n"
	"	* translittération en 1E0D\n"
	"	x (syllabe éthiopienne tzä - 1340)"},
/* 10A74 */ { "LETTRE SUD-ARABIQUE GUIMEL","	= djîm\n"
	"	* translittération en g\n"
	"	x (syllabe éthiopienne gä - 1308)"},
/* 10A75 */ { "LETTRE SUD-ARABIQUE DALÈT","	= dal\n"
	"	* translittération en d\n"
	"	x (syllabe éthiopienne dä - 12F0)"},
/* 10A76 */ { "LETTRE SUD-ARABIQUE GAÏN","	= ghaïn\n"
	"	* translittération en 0121"},
/* 10A77 */ { "LETTRE SUD-ARABIQUE TÈT","	= ta'\n"
	"	* translittération en 1E6D\n"
	"	x (syllabe éthiopienne thä - 1320)"},
/* 10A78 */ { "LETTRE SUD-ARABIQUE ZAÏN","	= zaïn\n"
	"	* translittération en z\n"
	"	x (syllabe éthiopienne zä - 12D8)"},
/* 10A79 */ { "LETTRE SUD-ARABIQUE DHALÈT","	= dhal\n"
	"	* translittération en 1E0F"},
/* 10A7A */ { "LETTRE SUD-ARABIQUE YOD","	= ya'\n"
	"	* translittération en y\n"
	"	x (syllabe éthiopienne yä - 12E8)"},
/* 10A7B */ { "LETTRE SUD-ARABIQUE THAW","	= thé'\n"
	"	* translittération en 1E6F"},
/* 10A7C */ { "LETTRE SUD-ARABIQUE THÈT","	= zza'\n"
	"	* translittération en 1E93"},
/* 10A7D */ { "NOMBRE SUD-ARABIQUE UN",NULL},
/* 10A7E */ { "NOMBRE SUD-ARABIQUE CINQUANTE",NULL},
/* 10A7F */ { "INDICATEUR NUMÉRIQUE SUD-ARABIQUE",NULL},
/* 10A80 */ { "LETTRE VIEIL ARABE DU NORD HÉ'","	* translittération en h\n"
	"	x (syllabe éthiopienne hä - 1200)\n"
	"	x (lettre sud-arabique hè - 10A60)"},
/* 10A81 */ { "LETTRE VIEIL ARABE DU NORD LAM","	* translittération en l\n"
	"	x (syllabe éthiopienne lä - 1208)\n"
	"	x (lettre sud-arabique lamèd - 10A61)"},
/* 10A82 */ { "LETTRE VIEIL ARABE DU NORD HA'","	* translittération en 1E25\n"
	"	x (syllabe éthiopienne hhä - 1210)\n"
	"	x (lettre sud-arabique hèt - 10A62)"},
/* 10A83 */ { "LETTRE VIEIL ARABE DU NORD MÎM","	* translittération en m\n"
	"	x (syllabe éthiopienne mä - 1218)\n"
	"	x (lettre sud-arabique mém - 10A63)"},
/* 10A84 */ { "LETTRE VIEIL ARABE DU NORD QAF","	* translittération en q\n"
	"	x (syllabe éthiopienne qä - 1240)\n"
	"	x (lettre sud-arabique qouf - 10A64)"},
/* 10A85 */ { "LETTRE VIEIL ARABE DU NORD WAW","	* translittération en w\n"
	"	x (syllabe éthiopienne wä - 12C8)\n"
	"	x (lettre sud-arabique waw - 10A65)"},
/* 10A86 */ { "LETTRE VIEIL ARABE DU NORD ESSE-2","	* translittération en s2\n"
	"	x (syllabe éthiopienne çä - 1220)\n"
	"	x (lettre sud-arabique chine - 10A66)"},
/* 10A87 */ { "LETTRE VIEIL ARABE DU NORD RE'","	* translittération en r\n"
	"	x (syllabe éthiopienne rä - 1228)\n"
	"	x (lettre sud-arabique rèch - 10A67)"},
/* 10A88 */ { "LETTRE VIEIL ARABE DU NORD BA'","	* translittération en b\n"
	"	x (syllabe éthiopienne bä - 1260)\n"
	"	x (lettre sud-arabique bèt - 10A68)"},
/* 10A89 */ { "LETTRE VIEIL ARABE DU NORD TÉ'","	* translittération en t\n"
	"	x (syllabe éthiopienne tä - 1270)\n"
	"	x (lettre sud-arabique taw - 10A69)"},
/* 10A8A */ { "LETTRE VIEIL ARABE DU NORD ESSE-1","	* translittération en s1\n"
	"	x (syllabe éthiopienne sä - 1230)\n"
	"	x (lettre sud-arabique sat - 10A6A)"},
/* 10A8B */ { "LETTRE VIEIL ARABE DU NORD KAF","	* translittération en k\n"
	"	x (syllabe éthiopienne kä - 12A8)\n"
	"	x (lettre sud-arabique kaf - 10A6B)"},
/* 10A8C */ { "LETTRE VIEIL ARABE DU NORD NOÛN","	* translittération en n\n"
	"	x (syllabe éthiopienne nä - 1290)\n"
	"	x (lettre sud-arabique noun - 10A6C)"},
/* 10A8D */ { "LETTRE VIEIL ARABE DU NORD KHA'","	* translittération en 1E2B\n"
	"	x (syllabe éthiopienne xä - 1280)\n"
	"	x (lettre sud-arabique kèt - 10A6D)"},
/* 10A8E */ { "LETTRE VIEIL ARABE DU NORD ÇAD","	* translittération en 1E63\n"
	"	x (syllabe éthiopienne tsä - 1338)\n"
	"	x (lettre sud-arabique tsadé - 10A6E)"},
/* 10A8F */ { "LETTRE VIEIL ARABE DU NORD ESSE-3","	* translittération en s3\n"
	"	x (lettre sud-arabique samèkh - 10A6F)"},
/* 10A90 */ { "LETTRE VIEIL ARABE DU NORD FA'","	* translittération en f\n"
	"	x (syllabe éthiopienne fä - 1348)\n"
	"	x (lettre sud-arabique fé - 10A70)"},
/* 10A91 */ { "LETTRE VIEIL ARABE DU NORD ALIF","	* translittération en 02BC\n"
	"	x (syllabe éthiopienne ä glottal - 12A0)\n"
	"	x (lettre sud-arabique alif - 10A71)"},
/* 10A92 */ { "LETTRE VIEIL ARABE DU NORD 'AÏN","	* translittération en 02BD\n"
	"	x (syllabe éthiopienne ä pharyngal - 12D0)\n"
	"	x (lettre sud-arabique 'aïn - 10A72)"},
/* 10A93 */ { "LETTRE VIEIL ARABE DU NORD DAD","	* translittération en 1E0D\n"
	"	x (syllabe éthiopienne tzä - 1340)\n"
	"	x (lettre sud-arabique dadé - 10A73)"},
/* 10A94 */ { "LETTRE VIEIL ARABE DU NORD GUÏM","	* translittération en g\n"
	"	x (syllabe éthiopienne gä - 1308)\n"
	"	x (lettre sud-arabique guimel - 10A74)"},
/* 10A95 */ { "LETTRE VIEIL ARABE DU NORD DAL","	* translittération en d\n"
	"	x (syllabe éthiopienne dä - 12F0)\n"
	"	x (lettre sud-arabique dalèt - 10A75)"},
/* 10A96 */ { "LETTRE VIEIL ARABE DU NORD GHAÏN","	* translittération en 0121\n"
	"	x (lettre sud-arabique gaïn - 10A76)"},
/* 10A97 */ { "LETTRE VIEIL ARABE DU NORD TA'","	* translittération en 1E6D\n"
	"	x (syllabe éthiopienne thä - 1320)\n"
	"	x (lettre sud-arabique tèt - 10A77)"},
/* 10A98 */ { "LETTRE VIEIL ARABE DU NORD ZAÏN","	* translittération en z\n"
	"	x (syllabe éthiopienne zä - 12D8)\n"
	"	x (lettre sud-arabique zaïn - 10A78)"},
/* 10A99 */ { "LETTRE VIEIL ARABE DU NORD DHAL","	* translittération en 1E0F\n"
	"	x (lettre sud-arabique dhalèt - 10A79)"},
/* 10A9A */ { "LETTRE VIEIL ARABE DU NORD YA'","	* translittération en y\n"
	"	x (syllabe éthiopienne yä - 12E8)\n"
	"	x (lettre sud-arabique yod - 10A7A)"},
/* 10A9B */ { "LETTRE VIEIL ARABE DU NORD THÉ'","	* translittération en 1E6F\n"
	"	x (lettre sud-arabique thaw - 10A7B)"},
/* 10A9C */ { "LETTRE VIEIL ARABE DU NORD ZZA'","	* translittération en 1E93\n"
	"	x (lettre sud-arabique thèt - 10A7C)"},
/* 10A9D */ { "NOMBRE VIEIL ARABE DU NORD UN",NULL},
/* 10A9E */ { "NOMBRE VIEIL ARABE DU NORD DIX",NULL},
/* 10A9F */ { "NOMBRE VIEIL ARABE DU NORD VINGT",NULL},
/* 10AA0 */ { NULL,NULL},
/* 10AA1 */ { NULL,NULL},
/* 10AA2 */ { NULL,NULL},
/* 10AA3 */ { NULL,NULL},
/* 10AA4 */ { NULL,NULL},
/* 10AA5 */ { NULL,NULL},
/* 10AA6 */ { NULL,NULL},
/* 10AA7 */ { NULL,NULL},
/* 10AA8 */ { NULL,NULL},
/* 10AA9 */ { NULL,NULL},
/* 10AAA */ { NULL,NULL},
/* 10AAB */ { NULL,NULL},
/* 10AAC */ { NULL,NULL},
/* 10AAD */ { NULL,NULL},
/* 10AAE */ { NULL,NULL},
/* 10AAF */ { NULL,NULL},
/* 10AB0 */ { NULL,NULL},
/* 10AB1 */ { NULL,NULL},
/* 10AB2 */ { NULL,NULL},
/* 10AB3 */ { NULL,NULL},
/* 10AB4 */ { NULL,NULL},
/* 10AB5 */ { NULL,NULL},
/* 10AB6 */ { NULL,NULL},
/* 10AB7 */ { NULL,NULL},
/* 10AB8 */ { NULL,NULL},
/* 10AB9 */ { NULL,NULL},
/* 10ABA */ { NULL,NULL},
/* 10ABB */ { NULL,NULL},
/* 10ABC */ { NULL,NULL},
/* 10ABD */ { NULL,NULL},
/* 10ABE */ { NULL,NULL},
/* 10ABF */ { NULL,NULL},
/* 10AC0 */ { "LETTRE MANICHÉENNE ALEF",NULL},
/* 10AC1 */ { "LETTRE MANICHÉENNE BÈT",NULL},
/* 10AC2 */ { "LETTRE MANICHÉENNE BHÈT",NULL},
/* 10AC3 */ { "LETTRE MANICHÉENNE GUIMEL",NULL},
/* 10AC4 */ { "LETTRE MANICHÉENNE GHIMEL",NULL},
/* 10AC5 */ { "LETTRE MANICHÉENNE DALÈT","	~ 10AC5 FE00 forme concurrente (isolate)"},
/* 10AC6 */ { "LETTRE MANICHÉENNE HÈ","	~ 10AC6 FE00 forme concurrente (isolate)"},
/* 10AC7 */ { "LETTRE MANICHÉENNE WAW",NULL},
/* 10AC8 */ { "SIGNE MANICHÉEN OUD","	* représente la conjonction « et »"},
/* 10AC9 */ { "LETTRE MANICHÉENNE ZAÏN",NULL},
/* 10ACA */ { "LETTRE MANICHÉENNE ZHAÏN",NULL},
/* 10ACB */ { "LETTRE MANICHÉENNE JAÏN",NULL},
/* 10ACC */ { "LETTRE MANICHÉENNE JHAÏN",NULL},
/* 10ACD */ { "LETTRE MANICHÉENNE HÈT",NULL},
/* 10ACE */ { "LETTRE MANICHÉENNE TÈT",NULL},
/* 10ACF */ { "LETTRE MANICHÉENNE YOD",NULL},
/* 10AD0 */ { "LETTRE MANICHÉENNE KAF",NULL},
/* 10AD1 */ { "LETTRE MANICHÉENNE XAF",NULL},
/* 10AD2 */ { "LETTRE MANICHÉENNE KHAF",NULL},
/* 10AD3 */ { "LETTRE MANICHÉENNE LAMÈD",NULL},
/* 10AD4 */ { "LETTRE MANICHÉENNE DHAMÈD",NULL},
/* 10AD5 */ { "LETTRE MANICHÉENNE THAMÈD",NULL},
/* 10AD6 */ { "LETTRE MANICHÉENNE MÉM","	~ 10AD6 FE00 forme concurrente (isolate)\n"
	"	~ 10AD6 FE00 forme concurrente (final)"},
/* 10AD7 */ { "LETTRE MANICHÉENNE NOUN","	~ 10AD7 FE00 forme concurrente (isolate)"},
/* 10AD8 */ { "LETTRE MANICHÉENNE SAMÈKH",NULL},
/* 10AD9 */ { "LETTRE MANICHÉENNE 'AÏN",NULL},
/* 10ADA */ { "LETTRE MANICHÉENNE 'AAÏN",NULL},
/* 10ADB */ { "LETTRE MANICHÉENNE PÉ",NULL},
/* 10ADC */ { "LETTRE MANICHÉENNE FÉ",NULL},
/* 10ADD */ { "LETTRE MANICHÉENNE TSADÉ",NULL},
/* 10ADE */ { "LETTRE MANICHÉENNE QOUF",NULL},
/* 10ADF */ { "LETTRE MANICHÉENNE XOUF",NULL},
/* 10AE0 */ { "LETTRE MANICHÉENNE QHOUF",NULL},
/* 10AE1 */ { "LETTRE MANICHÉENNE RÈCH","	~ 10AE1 FE00 forme concurrente (isolate)"},
/* 10AE2 */ { "LETTRE MANICHÉENNE CHINE",NULL},
/* 10AE3 */ { "LETTRE MANICHÉENNE CCHINE",NULL},
/* 10AE4 */ { "LETTRE MANICHÉENNE TAW",NULL},
/* 10AE5 */ { "DIACRITIQUE D'ABRÉVIATION MANICHÉEN SUSCRIT",NULL},
/* 10AE6 */ { "DIACRITIQUE D'ABRÉVIATION MANICHÉEN SOUSCRIT",NULL},
/* 10AE7 */ { NULL,NULL},
/* 10AE8 */ { NULL,NULL},
/* 10AE9 */ { NULL,NULL},
/* 10AEA */ { NULL,NULL},
/* 10AEB */ { "NOMBRE MANICHÉEN UN",NULL},
/* 10AEC */ { "NOMBRE MANICHÉEN CINQ",NULL},
/* 10AED */ { "NOMBRE MANICHÉEN DIX",NULL},
/* 10AEE */ { "NOMBRE MANICHÉEN VINGT",NULL},
/* 10AEF */ { "NOMBRE MANICHÉEN CENT",NULL},
/* 10AF0 */ { "PONCTUATION MANICHÉENNE ÉTOILE",NULL},
/* 10AF1 */ { "PONCTUATION MANICHÉENNE FLEURON",NULL},
/* 10AF2 */ { "PONCTUATION MANICHÉENNE DOUBLE POINT INSCRIT DANS LE POINT",NULL},
/* 10AF3 */ { "PONCTUATION MANICHÉENNE POINT INSCRIT DANS LE POINT",NULL},
/* 10AF4 */ { "PONCTUATION MANICHÉENNE POINT",NULL},
/* 10AF5 */ { "PONCTUATION MANICHÉENNE DEUX-POINTS",NULL},
/* 10AF6 */ { "PONCTUATION MANICHÉENNE BOURRE DE LIGNE",NULL},
/* 10AF7 */ { NULL,NULL},
/* 10AF8 */ { NULL,NULL},
/* 10AF9 */ { NULL,NULL},
/* 10AFA */ { NULL,NULL},
/* 10AFB */ { NULL,NULL},
/* 10AFC */ { NULL,NULL},
/* 10AFD */ { NULL,NULL},
/* 10AFE */ { NULL,NULL},
/* 10AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_0B[] = {
/* 10B00 */ { "LETTRE AVESTIQUE A",NULL},
/* 10B01 */ { "LETTRE AVESTIQUE AA",NULL},
/* 10B02 */ { "LETTRE AVESTIQUE AO",NULL},
/* 10B03 */ { "LETTRE AVESTIQUE AAO",NULL},
/* 10B04 */ { "LETTRE AVESTIQUE AN",NULL},
/* 10B05 */ { "LETTRE AVESTIQUE AAN",NULL},
/* 10B06 */ { "LETTRE AVESTIQUE AE",NULL},
/* 10B07 */ { "LETTRE AVESTIQUE AEE",NULL},
/* 10B08 */ { "LETTRE AVESTIQUE E",NULL},
/* 10B09 */ { "LETTRE AVESTIQUE EE",NULL},
/* 10B0A */ { "LETTRE AVESTIQUE O",NULL},
/* 10B0B */ { "LETTRE AVESTIQUE OO",NULL},
/* 10B0C */ { "LETTRE AVESTIQUE I",NULL},
/* 10B0D */ { "LETTRE AVESTIQUE II",NULL},
/* 10B0E */ { "LETTRE AVESTIQUE U",NULL},
/* 10B0F */ { "LETTRE AVESTIQUE UU",NULL},
/* 10B10 */ { "LETTRE AVESTIQUE KE",NULL},
/* 10B11 */ { "LETTRE AVESTIQUE XE",NULL},
/* 10B12 */ { "LETTRE AVESTIQUE XYE",NULL},
/* 10B13 */ { "LETTRE AVESTIQUE XVE",NULL},
/* 10B14 */ { "LETTRE AVESTIQUE GE",NULL},
/* 10B15 */ { "LETTRE AVESTIQUE GGE",NULL},
/* 10B16 */ { "LETTRE AVESTIQUE GHE",NULL},
/* 10B17 */ { "LETTRE AVESTIQUE CE",NULL},
/* 10B18 */ { "LETTRE AVESTIQUE JE",NULL},
/* 10B19 */ { "LETTRE AVESTIQUE TE",NULL},
/* 10B1A */ { "LETTRE AVESTIQUE THE",NULL},
/* 10B1B */ { "LETTRE AVESTIQUE DE",NULL},
/* 10B1C */ { "LETTRE AVESTIQUE DHE",NULL},
/* 10B1D */ { "LETTRE AVESTIQUE TTE",NULL},
/* 10B1E */ { "LETTRE AVESTIQUE PE",NULL},
/* 10B1F */ { "LETTRE AVESTIQUE FE",NULL},
/* 10B20 */ { "LETTRE AVESTIQUE BE",NULL},
/* 10B21 */ { "LETTRE AVESTIQUE BHE",NULL},
/* 10B22 */ { "LETTRE AVESTIQUE NGE",NULL},
/* 10B23 */ { "LETTRE AVESTIQUE NGYE",NULL},
/* 10B24 */ { "LETTRE AVESTIQUE NGVE",NULL},
/* 10B25 */ { "LETTRE AVESTIQUE NE",NULL},
/* 10B26 */ { "LETTRE AVESTIQUE NYE",NULL},
/* 10B27 */ { "LETTRE AVESTIQUE NNE",NULL},
/* 10B28 */ { "LETTRE AVESTIQUE ME",NULL},
/* 10B29 */ { "LETTRE AVESTIQUE HME",NULL},
/* 10B2A */ { "LETTRE AVESTIQUE YYE",NULL},
/* 10B2B */ { "LETTRE AVESTIQUE YE",NULL},
/* 10B2C */ { "LETTRE AVESTIQUE VE",NULL},
/* 10B2D */ { "LETTRE AVESTIQUE RE",NULL},
/* 10B2E */ { "LETTRE AVESTIQUE LE",NULL},
/* 10B2F */ { "LETTRE AVESTIQUE SE",NULL},
/* 10B30 */ { "LETTRE AVESTIQUE ZE",NULL},
/* 10B31 */ { "LETTRE AVESTIQUE SHE",NULL},
/* 10B32 */ { "LETTRE AVESTIQUE ZHE",NULL},
/* 10B33 */ { "LETTRE AVESTIQUE SHYE",NULL},
/* 10B34 */ { "LETTRE AVESTIQUE SSHE",NULL},
/* 10B35 */ { "LETTRE AVESTIQUE HE",NULL},
/* 10B36 */ { NULL,NULL},
/* 10B37 */ { NULL,NULL},
/* 10B38 */ { NULL,NULL},
/* 10B39 */ { "SIGNE D'ABRÉVIATION AVESTIQUE","	x (opérateur rond - 2218)\n"
	"	x (point évidé - 2E30)\n"
	"	x (point médian séparateur de mots - 2E31)"},
/* 10B3A */ { "PONCTUATION DEUX TRÈS PETITS POINTS AU-DESSUS D'UN AUTRE",NULL},
/* 10B3B */ { "PONCTUATION DEUX PETITS POINTS AU-DESSUS D'UN AUTRE",NULL},
/* 10B3C */ { "PONCTUATION DEUX GROS POINTS AU-DESSUS D'UN AUTRE",NULL},
/* 10B3D */ { "PONCTUATION DEUX GROS POINTS EN DESSOUS D'UN AUTRE",NULL},
/* 10B3E */ { "PONCTUATION DEUX RONDS AU-DESSUS D'UN AUTRE",NULL},
/* 10B3F */ { "PONCTUATION DEUX RONDS EN DESSOUS D'UN AUTRE",NULL},
/* 10B40 */ { "LETTRE PARTHE DES INSCRIPTIONS ALEF",NULL},
/* 10B41 */ { "LETTRE PARTHE DES INSCRIPTIONS BÈT",NULL},
/* 10B42 */ { "LETTRE PARTHE DES INSCRIPTIONS GUIMEL",NULL},
/* 10B43 */ { "LETTRE PARTHE DES INSCRIPTIONS DALÈT",NULL},
/* 10B44 */ { "LETTRE PARTHE DES INSCRIPTIONS HÈ",NULL},
/* 10B45 */ { "LETTRE PARTHE DES INSCRIPTIONS WAW",NULL},
/* 10B46 */ { "LETTRE PARTHE DES INSCRIPTIONS ZAÏN",NULL},
/* 10B47 */ { "LETTRE PARTHE DES INSCRIPTIONS HÈT",NULL},
/* 10B48 */ { "LETTRE PARTHE DES INSCRIPTIONS TÈT",NULL},
/* 10B49 */ { "LETTRE PARTHE DES INSCRIPTIONS YOD",NULL},
/* 10B4A */ { "LETTRE PARTHE DES INSCRIPTIONS KAF",NULL},
/* 10B4B */ { "LETTRE PARTHE DES INSCRIPTIONS LAMÈD",NULL},
/* 10B4C */ { "LETTRE PARTHE DES INSCRIPTIONS MÉM",NULL},
/* 10B4D */ { "LETTRE PARTHE DES INSCRIPTIONS NOUN",NULL},
/* 10B4E */ { "LETTRE PARTHE DES INSCRIPTIONS SAMÈKH",NULL},
/* 10B4F */ { "LETTRE PARTHE DES INSCRIPTIONS 'AÏN",NULL},
/* 10B50 */ { "LETTRE PARTHE DES INSCRIPTIONS PÉ",NULL},
/* 10B51 */ { "LETTRE PARTHE DES INSCRIPTIONS TSADÉ",NULL},
/* 10B52 */ { "LETTRE PARTHE DES INSCRIPTIONS QOUF",NULL},
/* 10B53 */ { "LETTRE PARTHE DES INSCRIPTIONS RÈCH",NULL},
/* 10B54 */ { "LETTRE PARTHE DES INSCRIPTIONS CHINE",NULL},
/* 10B55 */ { "LETTRE PARTHE DES INSCRIPTIONS TAW",NULL},
/* 10B56 */ { NULL,NULL},
/* 10B57 */ { NULL,NULL},
/* 10B58 */ { "NOMBRE PARTHE DES INSCRIPTIONS UN",NULL},
/* 10B59 */ { "NOMBRE PARTHE DES INSCRIPTIONS DEUX",NULL},
/* 10B5A */ { "NOMBRE PARTHE DES INSCRIPTIONS TROIS",NULL},
/* 10B5B */ { "NOMBRE PARTHE DES INSCRIPTIONS QUATRE",NULL},
/* 10B5C */ { "NOMBRE PARTHE DES INSCRIPTIONS DIX",NULL},
/* 10B5D */ { "NOMBRE PARTHE DES INSCRIPTIONS VINGT",NULL},
/* 10B5E */ { "NOMBRE PARTHE DES INSCRIPTIONS CENT",NULL},
/* 10B5F */ { "NOMBRE PARTHE DES INSCRIPTIONS MILLE",NULL},
/* 10B60 */ { "LETTRE PEHLVIE DES INSCRIPTIONS ALEF",NULL},
/* 10B61 */ { "LETTRE PEHLVIE DES INSCRIPTIONS BÈT",NULL},
/* 10B62 */ { "LETTRE PEHLVIE DES INSCRIPTIONS GUIMEL",NULL},
/* 10B63 */ { "LETTRE PEHLVIE DES INSCRIPTIONS DALÈT",NULL},
/* 10B64 */ { "LETTRE PEHLVIE DES INSCRIPTIONS HÈ",NULL},
/* 10B65 */ { "LETTRE PEHLVIE DES INSCRIPTIONS WAW-'AÏN-RÈCH",NULL},
/* 10B66 */ { "LETTRE PEHLVIE DES INSCRIPTIONS ZAÏN",NULL},
/* 10B67 */ { "LETTRE PEHLVIE DES INSCRIPTIONS HÈT",NULL},
/* 10B68 */ { "LETTRE PEHLVIE DES INSCRIPTIONS TÈT",NULL},
/* 10B69 */ { "LETTRE PEHLVIE DES INSCRIPTIONS YOD",NULL},
/* 10B6A */ { "LETTRE PEHLVIE DES INSCRIPTIONS KAF",NULL},
/* 10B6B */ { "LETTRE PEHLVIE DES INSCRIPTIONS LAMÈD",NULL},
/* 10B6C */ { "LETTRE PEHLVIE DES INSCRIPTIONS MÉM-QOUF",NULL},
/* 10B6D */ { "LETTRE PEHLVIE DES INSCRIPTIONS NOUN",NULL},
/* 10B6E */ { "LETTRE PEHLVIE DES INSCRIPTIONS SAMÈKH",NULL},
/* 10B6F */ { "LETTRE PEHLVIE DES INSCRIPTIONS PÉ",NULL},
/* 10B70 */ { "LETTRE PEHLVIE DES INSCRIPTIONS TSADÉ",NULL},
/* 10B71 */ { "LETTRE PEHLVIE DES INSCRIPTIONS CHINE",NULL},
/* 10B72 */ { "LETTRE PEHLVIE DES INSCRIPTIONS TAW",NULL},
/* 10B73 */ { NULL,NULL},
/* 10B74 */ { NULL,NULL},
/* 10B75 */ { NULL,NULL},
/* 10B76 */ { NULL,NULL},
/* 10B77 */ { NULL,NULL},
/* 10B78 */ { "NOMBRE PEHLVI DES INSCRIPTIONS UN",NULL},
/* 10B79 */ { "NOMBRE PEHLVI DES INSCRIPTIONS DEUX",NULL},
/* 10B7A */ { "NOMBRE PEHLVI DES INSCRIPTIONS TROIS",NULL},
/* 10B7B */ { "NOMBRE PEHLVI DES INSCRIPTIONS QUATRE",NULL},
/* 10B7C */ { "NOMBRE PEHLVI DES INSCRIPTIONS DIX",NULL},
/* 10B7D */ { "NOMBRE PEHLVI DES INSCRIPTIONS VINGT",NULL},
/* 10B7E */ { "NOMBRE PEHLVI DES INSCRIPTIONS CENT",NULL},
/* 10B7F */ { "NOMBRE PEHLVI DES INSCRIPTIONS MILLE",NULL},
/* 10B80 */ { "LETTRE PEHLVIE DES PSAUTIERS ALEF",NULL},
/* 10B81 */ { "LETTRE PEHLVIE DES PSAUTIERS BÈT",NULL},
/* 10B82 */ { "LETTRE PEHLVIE DES PSAUTIERS GUIMEL",NULL},
/* 10B83 */ { "LETTRE PEHLVIE DES PSAUTIERS DALÈT",NULL},
/* 10B84 */ { "LETTRE PEHLVIE DES PSAUTIERS HÈ",NULL},
/* 10B85 */ { "LETTRE PEHLVIE DES PSAUTIERS WAW-'AÏN-RÈCH",NULL},
/* 10B86 */ { "LETTRE PEHLVIE DES PSAUTIERS ZAÏN",NULL},
/* 10B87 */ { "LETTRE PEHLVIE DES PSAUTIERS HÈT",NULL},
/* 10B88 */ { "LETTRE PEHLVIE DES PSAUTIERS YOD",NULL},
/* 10B89 */ { "LETTRE PEHLVIE DES PSAUTIERS KAF",NULL},
/* 10B8A */ { "LETTRE PEHLVIE DES PSAUTIERS LAMÈD",NULL},
/* 10B8B */ { "LETTRE PEHLVIE DES PSAUTIERS MÉM-QOUF",NULL},
/* 10B8C */ { "LETTRE PEHLVIE DES PSAUTIERS NOUN",NULL},
/* 10B8D */ { "LETTRE PEHLVIE DES PSAUTIERS SAMÈKH",NULL},
/* 10B8E */ { "LETTRE PEHLVIE DES PSAUTIERS PÉ",NULL},
/* 10B8F */ { "LETTRE PEHLVIE DES PSAUTIERS TSADÉ",NULL},
/* 10B90 */ { "LETTRE PEHLVIE DES PSAUTIERS CHINE",NULL},
/* 10B91 */ { "LETTRE PEHLVIE DES PSAUTIERS TAW",NULL},
/* 10B92 */ { NULL,NULL},
/* 10B93 */ { NULL,NULL},
/* 10B94 */ { NULL,NULL},
/* 10B95 */ { NULL,NULL},
/* 10B96 */ { NULL,NULL},
/* 10B97 */ { NULL,NULL},
/* 10B98 */ { NULL,NULL},
/* 10B99 */ { "FIN DE PHRASE PEHLVIE DES PSAUTIERS",NULL},
/* 10B9A */ { "FIN DE PHRASE CULBUTÉE PEHLVIE DES PSAUTIERS",NULL},
/* 10B9B */ { "QUATRE ANNEAUX AUTOUR D'UNE CROIX PEHLVIE DES PSAUTIERS",NULL},
/* 10B9C */ { "QUATRE ANNEAUX AUTOUR D'UN POINT PEHLVI DES PSAUTIERS",NULL},
/* 10B9D */ { NULL,NULL},
/* 10B9E */ { NULL,NULL},
/* 10B9F */ { NULL,NULL},
/* 10BA0 */ { NULL,NULL},
/* 10BA1 */ { NULL,NULL},
/* 10BA2 */ { NULL,NULL},
/* 10BA3 */ { NULL,NULL},
/* 10BA4 */ { NULL,NULL},
/* 10BA5 */ { NULL,NULL},
/* 10BA6 */ { NULL,NULL},
/* 10BA7 */ { NULL,NULL},
/* 10BA8 */ { NULL,NULL},
/* 10BA9 */ { "NOMBRE PEHLVI DES PSAUTIERS UN",NULL},
/* 10BAA */ { "NOMBRE PEHLVI DES PSAUTIERS DEUX",NULL},
/* 10BAB */ { "NOMBRE PEHLVI DES PSAUTIERS TROIS",NULL},
/* 10BAC */ { "NOMBRE PEHLVI DES PSAUTIERS QUATRE",NULL},
/* 10BAD */ { "NOMBRE PEHLVI DES PSAUTIERS DIX",NULL},
/* 10BAE */ { "NOMBRE PEHLVI DES PSAUTIERS VINGT",NULL},
/* 10BAF */ { "NOMBRE PEHLVI DES PSAUTIERS CENT",NULL},
/* 10BB0 */ { NULL,NULL},
/* 10BB1 */ { NULL,NULL},
/* 10BB2 */ { NULL,NULL},
/* 10BB3 */ { NULL,NULL},
/* 10BB4 */ { NULL,NULL},
/* 10BB5 */ { NULL,NULL},
/* 10BB6 */ { NULL,NULL},
/* 10BB7 */ { NULL,NULL},
/* 10BB8 */ { NULL,NULL},
/* 10BB9 */ { NULL,NULL},
/* 10BBA */ { NULL,NULL},
/* 10BBB */ { NULL,NULL},
/* 10BBC */ { NULL,NULL},
/* 10BBD */ { NULL,NULL},
/* 10BBE */ { NULL,NULL},
/* 10BBF */ { NULL,NULL},
/* 10BC0 */ { NULL,NULL},
/* 10BC1 */ { NULL,NULL},
/* 10BC2 */ { NULL,NULL},
/* 10BC3 */ { NULL,NULL},
/* 10BC4 */ { NULL,NULL},
/* 10BC5 */ { NULL,NULL},
/* 10BC6 */ { NULL,NULL},
/* 10BC7 */ { NULL,NULL},
/* 10BC8 */ { NULL,NULL},
/* 10BC9 */ { NULL,NULL},
/* 10BCA */ { NULL,NULL},
/* 10BCB */ { NULL,NULL},
/* 10BCC */ { NULL,NULL},
/* 10BCD */ { NULL,NULL},
/* 10BCE */ { NULL,NULL},
/* 10BCF */ { NULL,NULL},
/* 10BD0 */ { NULL,NULL},
/* 10BD1 */ { NULL,NULL},
/* 10BD2 */ { NULL,NULL},
/* 10BD3 */ { NULL,NULL},
/* 10BD4 */ { NULL,NULL},
/* 10BD5 */ { NULL,NULL},
/* 10BD6 */ { NULL,NULL},
/* 10BD7 */ { NULL,NULL},
/* 10BD8 */ { NULL,NULL},
/* 10BD9 */ { NULL,NULL},
/* 10BDA */ { NULL,NULL},
/* 10BDB */ { NULL,NULL},
/* 10BDC */ { NULL,NULL},
/* 10BDD */ { NULL,NULL},
/* 10BDE */ { NULL,NULL},
/* 10BDF */ { NULL,NULL},
/* 10BE0 */ { NULL,NULL},
/* 10BE1 */ { NULL,NULL},
/* 10BE2 */ { NULL,NULL},
/* 10BE3 */ { NULL,NULL},
/* 10BE4 */ { NULL,NULL},
/* 10BE5 */ { NULL,NULL},
/* 10BE6 */ { NULL,NULL},
/* 10BE7 */ { NULL,NULL},
/* 10BE8 */ { NULL,NULL},
/* 10BE9 */ { NULL,NULL},
/* 10BEA */ { NULL,NULL},
/* 10BEB */ { NULL,NULL},
/* 10BEC */ { NULL,NULL},
/* 10BED */ { NULL,NULL},
/* 10BEE */ { NULL,NULL},
/* 10BEF */ { NULL,NULL},
/* 10BF0 */ { NULL,NULL},
/* 10BF1 */ { NULL,NULL},
/* 10BF2 */ { NULL,NULL},
/* 10BF3 */ { NULL,NULL},
/* 10BF4 */ { NULL,NULL},
/* 10BF5 */ { NULL,NULL},
/* 10BF6 */ { NULL,NULL},
/* 10BF7 */ { NULL,NULL},
/* 10BF8 */ { NULL,NULL},
/* 10BF9 */ { NULL,NULL},
/* 10BFA */ { NULL,NULL},
/* 10BFB */ { NULL,NULL},
/* 10BFC */ { NULL,NULL},
/* 10BFD */ { NULL,NULL},
/* 10BFE */ { NULL,NULL},
/* 10BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_0C[] = {
/* 10C00 */ { "LETTRE VIEUX-TURQUE A ORKHON",NULL},
/* 10C01 */ { "LETTRE VIEUX-TURQUE A IENISSEÏ",NULL},
/* 10C02 */ { "LETTRE VIEUX-TURQUE AE IENISSEÏ",NULL},
/* 10C03 */ { "LETTRE VIEUX-TURQUE I ORKHON",NULL},
/* 10C04 */ { "LETTRE VIEUX-TURQUE I IENISSEÏ",NULL},
/* 10C05 */ { "LETTRE VIEUX-TURQUE E IENISSEÏ",NULL},
/* 10C06 */ { "LETTRE VIEUX-TURQUE O ORKHON",NULL},
/* 10C07 */ { "LETTRE VIEUX-TURQUE OE ORKHON",NULL},
/* 10C08 */ { "LETTRE VIEUX-TURQUE OE IENISSEÏ",NULL},
/* 10C09 */ { "LETTRE VIEUX-TURQUE AB ORKHON",NULL},
/* 10C0A */ { "LETTRE VIEUX-TURQUE AB IENISSEÏ",NULL},
/* 10C0B */ { "LETTRE VIEUX-TURQUE AEB ORKHON",NULL},
/* 10C0C */ { "LETTRE VIEUX-TURQUE AEB IENISSEÏ",NULL},
/* 10C0D */ { "LETTRE VIEUX-TURQUE AG ORKHON",NULL},
/* 10C0E */ { "LETTRE VIEUX-TURQUE AG IENISSEÏ",NULL},
/* 10C0F */ { "LETTRE VIEUX-TURQUE AEG ORKHON",NULL},
/* 10C10 */ { "LETTRE VIEUX-TURQUE AEG IENISSEÏ",NULL},
/* 10C11 */ { "LETTRE VIEUX-TURQUE AD ORKHON",NULL},
/* 10C12 */ { "LETTRE VIEUX-TURQUE AD IENISSEÏ",NULL},
/* 10C13 */ { "LETTRE VIEUX-TURQUE AED ORKHON",NULL},
/* 10C14 */ { "LETTRE VIEUX-TURQUE EZ ORKHON",NULL},
/* 10C15 */ { "LETTRE VIEUX-TURQUE EZ IENISSEÏ",NULL},
/* 10C16 */ { "LETTRE VIEUX-TURQUE AY ORKHON",NULL},
/* 10C17 */ { "LETTRE VIEUX-TURQUE AY IENISSEÏ",NULL},
/* 10C18 */ { "LETTRE VIEUX-TURQUE AEY ORKHON",NULL},
/* 10C19 */ { "LETTRE VIEUX-TURQUE AEY IENISSEÏ",NULL},
/* 10C1A */ { "LETTRE VIEUX-TURQUE AEK ORKHON",NULL},
/* 10C1B */ { "LETTRE VIEUX-TURQUE AEK IENISSEÏ",NULL},
/* 10C1C */ { "LETTRE VIEUX-TURQUE OEK ORKHON",NULL},
/* 10C1D */ { "LETTRE VIEUX-TURQUE OEK IENISSEÏ",NULL},
/* 10C1E */ { "LETTRE VIEUX-TURQUE AL ORKHON",NULL},
/* 10C1F */ { "LETTRE VIEUX-TURQUE AL IENISSEÏ",NULL},
/* 10C20 */ { "LETTRE VIEUX-TURQUE AEL ORKHON",NULL},
/* 10C21 */ { "LETTRE VIEUX-TURQUE ELT ORKHON",NULL},
/* 10C22 */ { "LETTRE VIEUX-TURQUE EM ORKHON",NULL},
/* 10C23 */ { "LETTRE VIEUX-TURQUE AN ORKHON",NULL},
/* 10C24 */ { "LETTRE VIEUX-TURQUE AEN ORKHON",NULL},
/* 10C25 */ { "LETTRE VIEUX-TURQUE AEN IENISSEÏ",NULL},
/* 10C26 */ { "LETTRE VIEUX-TURQUE ENT ORKHON",NULL},
/* 10C27 */ { "LETTRE VIEUX-TURQUE ENT IENISSEÏ",NULL},
/* 10C28 */ { "LETTRE VIEUX-TURQUE ENC ORKHON",NULL},
/* 10C29 */ { "LETTRE VIEUX-TURQUE ENC IENISSEÏ",NULL},
/* 10C2A */ { "LETTRE VIEUX-TURQUE ENY ORKHON",NULL},
/* 10C2B */ { "LETTRE VIEUX-TURQUE ENY IENISSEÏ",NULL},
/* 10C2C */ { "LETTRE VIEUX-TURQUE ANG IENISSEÏ",NULL},
/* 10C2D */ { "LETTRE VIEUX-TURQUE ENG ORKHON",NULL},
/* 10C2E */ { "LETTRE VIEUX-TURQUE AENG IENISSEÏ",NULL},
/* 10C2F */ { "LETTRE VIEUX-TURQUE EP ORKHON",NULL},
/* 10C30 */ { "LETTRE VIEUX-TURQUE OP ORKHON",NULL},
/* 10C31 */ { "LETTRE VIEUX-TURQUE IC ORKHON",NULL},
/* 10C32 */ { "LETTRE VIEUX-TURQUE EC ORKHON",NULL},
/* 10C33 */ { "LETTRE VIEUX-TURQUE EC IENISSEÏ",NULL},
/* 10C34 */ { "LETTRE VIEUX-TURQUE AQ ORKHON",NULL},
/* 10C35 */ { "LETTRE VIEUX-TURQUE AQ IENISSEÏ",NULL},
/* 10C36 */ { "LETTRE VIEUX-TURQUE IQ ORKHON",NULL},
/* 10C37 */ { "LETTRE VIEUX-TURQUE IQ IENISSEÏ",NULL},
/* 10C38 */ { "LETTRE VIEUX-TURQUE OQ ORKHON",NULL},
/* 10C39 */ { "LETTRE VIEUX-TURQUE OQ IENISSEÏ",NULL},
/* 10C3A */ { "LETTRE VIEUX-TURQUE AR ORKHON",NULL},
/* 10C3B */ { "LETTRE VIEUX-TURQUE AR IENISSEÏ",NULL},
/* 10C3C */ { "LETTRE VIEUX-TURQUE AER ORKHON",NULL},
/* 10C3D */ { "LETTRE VIEUX-TURQUE AS ORKHON",NULL},
/* 10C3E */ { "LETTRE VIEUX-TURQUE AES ORKHON",NULL},
/* 10C3F */ { "LETTRE VIEUX-TURQUE ACH ORKHON",NULL},
/* 10C40 */ { "LETTRE VIEUX-TURQUE ACH IENISSEÏ",NULL},
/* 10C41 */ { "LETTRE VIEUX-TURQUE ECH ORKHON",NULL},
/* 10C42 */ { "LETTRE VIEUX-TURQUE ECH IENISSEÏ",NULL},
/* 10C43 */ { "LETTRE VIEUX-TURQUE AT ORKHON",NULL},
/* 10C44 */ { "LETTRE VIEUX-TURQUE AT IENISSEÏ",NULL},
/* 10C45 */ { "LETTRE VIEUX-TURQUE AET ORKHON",NULL},
/* 10C46 */ { "LETTRE VIEUX-TURQUE AET IENISSEÏ",NULL},
/* 10C47 */ { "LETTRE VIEUX-TURQUE OT ORKHON",NULL},
/* 10C48 */ { "LETTRE VIEUX-TURQUE BACH ORKHON",NULL},
/* 10C49 */ { NULL,NULL},
/* 10C4A */ { NULL,NULL},
/* 10C4B */ { NULL,NULL},
/* 10C4C */ { NULL,NULL},
/* 10C4D */ { NULL,NULL},
/* 10C4E */ { NULL,NULL},
/* 10C4F */ { NULL,NULL},
/* 10C50 */ { NULL,NULL},
/* 10C51 */ { NULL,NULL},
/* 10C52 */ { NULL,NULL},
/* 10C53 */ { NULL,NULL},
/* 10C54 */ { NULL,NULL},
/* 10C55 */ { NULL,NULL},
/* 10C56 */ { NULL,NULL},
/* 10C57 */ { NULL,NULL},
/* 10C58 */ { NULL,NULL},
/* 10C59 */ { NULL,NULL},
/* 10C5A */ { NULL,NULL},
/* 10C5B */ { NULL,NULL},
/* 10C5C */ { NULL,NULL},
/* 10C5D */ { NULL,NULL},
/* 10C5E */ { NULL,NULL},
/* 10C5F */ { NULL,NULL},
/* 10C60 */ { NULL,NULL},
/* 10C61 */ { NULL,NULL},
/* 10C62 */ { NULL,NULL},
/* 10C63 */ { NULL,NULL},
/* 10C64 */ { NULL,NULL},
/* 10C65 */ { NULL,NULL},
/* 10C66 */ { NULL,NULL},
/* 10C67 */ { NULL,NULL},
/* 10C68 */ { NULL,NULL},
/* 10C69 */ { NULL,NULL},
/* 10C6A */ { NULL,NULL},
/* 10C6B */ { NULL,NULL},
/* 10C6C */ { NULL,NULL},
/* 10C6D */ { NULL,NULL},
/* 10C6E */ { NULL,NULL},
/* 10C6F */ { NULL,NULL},
/* 10C70 */ { NULL,NULL},
/* 10C71 */ { NULL,NULL},
/* 10C72 */ { NULL,NULL},
/* 10C73 */ { NULL,NULL},
/* 10C74 */ { NULL,NULL},
/* 10C75 */ { NULL,NULL},
/* 10C76 */ { NULL,NULL},
/* 10C77 */ { NULL,NULL},
/* 10C78 */ { NULL,NULL},
/* 10C79 */ { NULL,NULL},
/* 10C7A */ { NULL,NULL},
/* 10C7B */ { NULL,NULL},
/* 10C7C */ { NULL,NULL},
/* 10C7D */ { NULL,NULL},
/* 10C7E */ { NULL,NULL},
/* 10C7F */ { NULL,NULL},
/* 10C80 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE A",NULL},
/* 10C81 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE Â","	= Á"},
/* 10C82 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EB","	= B"},
/* 10C83 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE AMB",NULL},
/* 10C84 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EC","	= C"},
/* 10C85 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ENC",NULL},
/* 10C86 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ECS","	= Cs"},
/* 10C87 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ED","	= D"},
/* 10C88 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE AND",NULL},
/* 10C89 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE È",NULL},
/* 10C8A */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE H","	= Ë"},
/* 10C8B */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE É",NULL},
/* 10C8C */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EF","	= F"},
/* 10C8D */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EG","	= G"},
/* 10C8E */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈGUY","	= Gy"},
/* 10C8F */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈH","	= H"},
/* 10C90 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE I",NULL},
/* 10C91 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE Î","	= Í"},
/* 10C92 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EJ","	= J"},
/* 10C93 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EK","	= K"},
/* 10C94 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE AK",NULL},
/* 10C95 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE OUNK",NULL},
/* 10C96 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EL","	= L"},
/* 10C97 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈLY","	= Ly"},
/* 10C98 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈM","	= M"},
/* 10C99 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈN","	= N"},
/* 10C9A */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈNY","	= Ny"},
/* 10C9B */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE O",NULL},
/* 10C9C */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE OÛ","	= Ó"},
/* 10C9D */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE DE NICOLSBOURG EU","	= Ö"},
/* 10C9E */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE RUDIMENTA EU","	= Ö"},
/* 10C9F */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EUÈ","	= Ő"},
/* 10CA0 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EP","	= P"},
/* 10CA1 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EMP",NULL},
/* 10CA2 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ER","	= R"},
/* 10CA3 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ER COURT",NULL},
/* 10CA4 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ES","	= S"},
/* 10CA5 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ESZ","	= Sz"},
/* 10CA6 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈT","	= T"},
/* 10CA7 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈNT","	* utilisée aussi pour Ant et Int"},
/* 10CA8 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈTY","	= Ty"},
/* 10CA9 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE ÈCH",NULL},
/* 10CAA */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE OU",NULL},
/* 10CAB */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE OUÛ","	= Ú"},
/* 10CAC */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE DE NICOLSBOURG U","	= Ü\n"
	"	* utilisée aussi pour Ö\n"
	"	* utilisée pour Ű dans l'orthographe de Sándor Forrai"},
/* 10CAD */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE RUDIMENTA U","	= Ü, Ű\n"
	"	* utilisée pour Ü dans l'orthographe de Sándor Forrai"},
/* 10CAE */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EV","	= V"},
/* 10CAF */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EZ","	= Z"},
/* 10CB0 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE EZS","	= Zs"},
/* 10CB1 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE TPRUS",NULL},
/* 10CB2 */ { "LETTRE MAJUSCULE RUNIQUE HONGROISE OUS",NULL},
/* 10CB3 */ { NULL,NULL},
/* 10CB4 */ { NULL,NULL},
/* 10CB5 */ { NULL,NULL},
/* 10CB6 */ { NULL,NULL},
/* 10CB7 */ { NULL,NULL},
/* 10CB8 */ { NULL,NULL},
/* 10CB9 */ { NULL,NULL},
/* 10CBA */ { NULL,NULL},
/* 10CBB */ { NULL,NULL},
/* 10CBC */ { NULL,NULL},
/* 10CBD */ { NULL,NULL},
/* 10CBE */ { NULL,NULL},
/* 10CBF */ { NULL,NULL},
/* 10CC0 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE A",NULL},
/* 10CC1 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE Â","	= á"},
/* 10CC2 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EB","	= b"},
/* 10CC3 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE AMB",NULL},
/* 10CC4 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EC","	= c"},
/* 10CC5 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ENC",NULL},
/* 10CC6 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ECS","	= cs"},
/* 10CC7 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ED","	= d"},
/* 10CC8 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE AND",NULL},
/* 10CC9 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE È",NULL},
/* 10CCA */ { "LETTRE MINUSCULE RUNIQUE HONGROISE H","	= ë"},
/* 10CCB */ { "LETTRE MINUSCULE RUNIQUE HONGROISE É",NULL},
/* 10CCC */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EF","	= f"},
/* 10CCD */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EG","	= g"},
/* 10CCE */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈGUY","	= gy"},
/* 10CCF */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈH","	= h"},
/* 10CD0 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE I",NULL},
/* 10CD1 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE Î","	= í"},
/* 10CD2 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EJ","	= j"},
/* 10CD3 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EK","	= k"},
/* 10CD4 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE AK",NULL},
/* 10CD5 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE OUNK",NULL},
/* 10CD6 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EL","	= l"},
/* 10CD7 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈLY","	= ly"},
/* 10CD8 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈM","	= m"},
/* 10CD9 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈN","	= n"},
/* 10CDA */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈNY","	= ny"},
/* 10CDB */ { "LETTRE MINUSCULE RUNIQUE HONGROISE O",NULL},
/* 10CDC */ { "LETTRE MINUSCULE RUNIQUE HONGROISE OÛ","	= ó"},
/* 10CDD */ { "LETTRE MINUSCULE RUNIQUE HONGROISE DE NICOLSBOURG EU","	= ö\n"
	"	* utilisée aussi pour ü"},
/* 10CDE */ { "LETTRE MINUSCULE RUNIQUE HONGROISE RUDIMENTA EU","	= ö"},
/* 10CDF */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EUÈ","	= ő"},
/* 10CE0 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EP","	= p"},
/* 10CE1 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EMP",NULL},
/* 10CE2 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ER","	= r"},
/* 10CE3 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ER COURT",NULL},
/* 10CE4 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ES","	= s"},
/* 10CE5 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ESZ","	= sz"},
/* 10CE6 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈT","	= t"},
/* 10CE7 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈNT","	* utilisée aussi pour ant et int"},
/* 10CE8 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈTY","	= ty"},
/* 10CE9 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE ÈCH",NULL},
/* 10CEA */ { "LETTRE MINUSCULE RUNIQUE HONGROISE OU",NULL},
/* 10CEB */ { "LETTRE MINUSCULE RUNIQUE HONGROISE OUÛ","	= ú"},
/* 10CEC */ { "LETTRE MINUSCULE RUNIQUE HONGROISE DE NICOLSBOURG U","	= ü\n"
	"	* utilisée aussi pour ö\n"
	"	* utilisée pour ű dans l'orthographe de Sándor Forrai"},
/* 10CED */ { "LETTRE MINUSCULE RUNIQUE HONGROISE RUDIMENTA U","	= ü, u double accent aigu\n"
	"	= ü, ű\n"
	"	* utilisée pour ü dans l'orthographe de Sándor Forrai"},
/* 10CEE */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EV","	= v"},
/* 10CEF */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EZ","	= z"},
/* 10CF0 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE EZS","	= zs"},
/* 10CF1 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE TPRUS","	* appelée « tprus » dans la littérature ancienne (reconnue plus tard comme une abréviation de « temperius »)"},
/* 10CF2 */ { "LETTRE MINUSCULE RUNIQUE HONGROISE OUS",NULL},
/* 10CF3 */ { NULL,NULL},
/* 10CF4 */ { NULL,NULL},
/* 10CF5 */ { NULL,NULL},
/* 10CF6 */ { NULL,NULL},
/* 10CF7 */ { NULL,NULL},
/* 10CF8 */ { NULL,NULL},
/* 10CF9 */ { NULL,NULL},
/* 10CFA */ { "NOMBRE RUNIQUE HONGROIS UN",NULL},
/* 10CFB */ { "NOMBRE RUNIQUE HONGROIS CINQ",NULL},
/* 10CFC */ { "NOMBRE RUNIQUE HONGROIS DIX",NULL},
/* 10CFD */ { "NOMBRE RUNIQUE HONGROIS CINQUANTE",NULL},
/* 10CFE */ { "NOMBRE RUNIQUE HONGROIS CENT",NULL},
/* 10CFF */ { "NOMBRE RUNIQUE HONGROIS MILLE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_0D[] = {
/* 10D00 */ { "LETTRE ROHINGYA HANIFI A",NULL},
/* 10D01 */ { "LETTRE ROHINGYA HANIFI BA",NULL},
/* 10D02 */ { "LETTRE ROHINGYA HANIFI PA",NULL},
/* 10D03 */ { "LETTRE ROHINGYA HANIFI TA",NULL},
/* 10D04 */ { "LETTRE ROHINGYA HANIFI TTA",NULL},
/* 10D05 */ { "LETTRE ROHINGYA HANIFI DJA",NULL},
/* 10D06 */ { "LETTRE ROHINGYA HANIFI TCHA",NULL},
/* 10D07 */ { "LETTRE ROHINGYA HANIFI HA",NULL},
/* 10D08 */ { "LETTRE ROHINGYA HANIFI KHA",NULL},
/* 10D09 */ { "LETTRE ROHINGYA HANIFI FA",NULL},
/* 10D0A */ { "LETTRE ROHINGYA HANIFI DA",NULL},
/* 10D0B */ { "LETTRE ROHINGYA HANIFI DDA",NULL},
/* 10D0C */ { "LETTRE ROHINGYA HANIFI RA",NULL},
/* 10D0D */ { "LETTRE ROHINGYA HANIFI RRA",NULL},
/* 10D0E */ { "LETTRE ROHINGYA HANIFI ZA",NULL},
/* 10D0F */ { "LETTRE ROHINGYA HANIFI SA",NULL},
/* 10D10 */ { "LETTRE ROHINGYA HANIFI ÇA",NULL},
/* 10D11 */ { "LETTRE ROHINGYA HANIFI KA",NULL},
/* 10D12 */ { "LETTRE ROHINGYA HANIFI GA",NULL},
/* 10D13 */ { "LETTRE ROHINGYA HANIFI LA",NULL},
/* 10D14 */ { "LETTRE ROHINGYA HANIFI MA",NULL},
/* 10D15 */ { "LETTRE ROHINGYA HANIFI NA",NULL},
/* 10D16 */ { "LETTRE ROHINGYA HANIFI WA",NULL},
/* 10D17 */ { "LETTRE ROHINGYA HANIFI KINNA WA",NULL},
/* 10D18 */ { "LETTRE ROHINGYA HANIFI YA",NULL},
/* 10D19 */ { "LETTRE ROHINGYA HANIFI KINNA YA",NULL},
/* 10D1A */ { "LETTRE ROHINGYA HANIFI NGA","	= gan"},
/* 10D1B */ { "LETTRE ROHINGYA HANIFI ÑA","	= nayya"},
/* 10D1C */ { "LETTRE ROHINGYA HANIFI VA","	* n'était pas employée largement ; son usage a été abandonné"},
/* 10D1D */ { "VOYELLE ROHINGYA HANIFI A","	= aa-for"},
/* 10D1E */ { "VOYELLE ROHINGYA HANIFI I","	= i-for"},
/* 10D1F */ { "VOYELLE ROHINGYA HANIFI OU","	= u-for"},
/* 10D20 */ { "VOYELLE ROHINGYA HANIFI É","	= e-for"},
/* 10D21 */ { "VOYELLE ROHINGYA HANIFI O","	= o-for"},
/* 10D22 */ { "DIACRITIQUE ROHINGYA HANIFI SAKIN",NULL},
/* 10D23 */ { "DIACRITIQUE ROHINGYA HANIFI NA KHONNA",NULL},
/* 10D24 */ { "DIACRITIQUE ROHINGYA HANIFI HARBAHAY","	* ton haut bref"},
/* 10D25 */ { "DIACRITIQUE ROHINGYA HANIFI TAHALA","	* ton descendant long"},
/* 10D26 */ { "DIACRITIQUE ROHINGYA HANIFI TANA","	* ton montant long"},
/* 10D27 */ { "DIACRITIQUE ROHINGYA HANIFI TASSI",NULL},
/* 10D28 */ { NULL,NULL},
/* 10D29 */ { NULL,NULL},
/* 10D2A */ { NULL,NULL},
/* 10D2B */ { NULL,NULL},
/* 10D2C */ { NULL,NULL},
/* 10D2D */ { NULL,NULL},
/* 10D2E */ { NULL,NULL},
/* 10D2F */ { NULL,NULL},
/* 10D30 */ { "CHIFFRE ROHINGYA HANIFI ZÉRO",NULL},
/* 10D31 */ { "CHIFFRE ROHINGYA HANIFI UN",NULL},
/* 10D32 */ { "CHIFFRE ROHINGYA HANIFI DEUX",NULL},
/* 10D33 */ { "CHIFFRE ROHINGYA HANIFI TROIS",NULL},
/* 10D34 */ { "CHIFFRE ROHINGYA HANIFI QUATRE",NULL},
/* 10D35 */ { "CHIFFRE ROHINGYA HANIFI CINQ",NULL},
/* 10D36 */ { "CHIFFRE ROHINGYA HANIFI SIX",NULL},
/* 10D37 */ { "CHIFFRE ROHINGYA HANIFI SEPT",NULL},
/* 10D38 */ { "CHIFFRE ROHINGYA HANIFI HUIT",NULL},
/* 10D39 */ { "CHIFFRE ROHINGYA HANIFI NEUF",NULL},
/* 10D3A */ { NULL,NULL},
/* 10D3B */ { NULL,NULL},
/* 10D3C */ { NULL,NULL},
/* 10D3D */ { NULL,NULL},
/* 10D3E */ { NULL,NULL},
/* 10D3F */ { NULL,NULL},
/* 10D40 */ { "CHIFFRE GARAY ZÉRO",NULL},
/* 10D41 */ { "CHIFFRE GARAY UN",NULL},
/* 10D42 */ { "CHIFFRE GARAY DEUX",NULL},
/* 10D43 */ { "CHIFFRE GARAY TROIS",NULL},
/* 10D44 */ { "CHIFFRE GARAY QUATRE",NULL},
/* 10D45 */ { "CHIFFRE GARAY CINQ",NULL},
/* 10D46 */ { "CHIFFRE GARAY SIX",NULL},
/* 10D47 */ { "CHIFFRE GARAY SEPT",NULL},
/* 10D48 */ { "CHIFFRE GARAY HUIT",NULL},
/* 10D49 */ { "CHIFFRE GARAY NEUF",NULL},
/* 10D4A */ { "DIACRITIQUE VOYELLE GARAY A",NULL},
/* 10D4B */ { "DIACRITIQUE VOYELLE GARAY I",NULL},
/* 10D4C */ { "DIACRITIQUE VOYELLE GARAY O",NULL},
/* 10D4D */ { "DIACRITIQUE VOYELLE GARAY E",NULL},
/* 10D4E */ { "SIGNE GARAY DE LONGUEUR DE VOYELLE",NULL},
/* 10D4F */ { "SOUKOUN GARAY",NULL},
/* 10D50 */ { "LETTRE MAJUSCULE GARAY A",NULL},
/* 10D51 */ { "LETTRE MAJUSCULE GARAY CA",NULL},
/* 10D52 */ { "LETTRE MAJUSCULE GARAY MA",NULL},
/* 10D53 */ { "LETTRE MAJUSCULE GARAY KA",NULL},
/* 10D54 */ { "LETTRE MAJUSCULE GARAY BA",NULL},
/* 10D55 */ { "LETTRE MAJUSCULE GARAY DJA",NULL},
/* 10D56 */ { "LETTRE MAJUSCULE GARAY SA",NULL},
/* 10D57 */ { "LETTRE MAJUSCULE GARAY WA",NULL},
/* 10D58 */ { "LETTRE MAJUSCULE GARAY LA",NULL},
/* 10D59 */ { "LETTRE MAJUSCULE GARAY GA",NULL},
/* 10D5A */ { "LETTRE MAJUSCULE GARAY DA",NULL},
/* 10D5B */ { "LETTRE MAJUSCULE GARAY XA",NULL},
/* 10D5C */ { "LETTRE MAJUSCULE GARAY YA",NULL},
/* 10D5D */ { "LETTRE MAJUSCULE GARAY TA",NULL},
/* 10D5E */ { "LETTRE MAJUSCULE GARAY RA",NULL},
/* 10D5F */ { "LETTRE MAJUSCULE GARAY ÑA",NULL},
/* 10D60 */ { "LETTRE MAJUSCULE GARAY FA",NULL},
/* 10D61 */ { "LETTRE MAJUSCULE GARAY NA",NULL},
/* 10D62 */ { "LETTRE MAJUSCULE GARAY PA",NULL},
/* 10D63 */ { "LETTRE MAJUSCULE GARAY HA",NULL},
/* 10D64 */ { "LETTRE MAJUSCULE GARAY VIEUX KA",NULL},
/* 10D65 */ { "LETTRE MAJUSCULE GARAY VIEUX NA",NULL},
/* 10D66 */ { NULL,NULL},
/* 10D67 */ { NULL,NULL},
/* 10D68 */ { NULL,NULL},
/* 10D69 */ { "DIACRITIQUE VOYELLE GARAY È",NULL},
/* 10D6A */ { "DIACRITIQUE GARAY DE GÉMINATION DE CONSONNE",NULL},
/* 10D6B */ { "DIACRITIQUE GARAY POINT EN CHEF",NULL},
/* 10D6C */ { "DIACRITIQUE GARAY TRÉMA EXTENSEUR",NULL},
/* 10D6D */ { "DIACRITIQUE GARAY DE NASALISATION DE CONSONNE",NULL},
/* 10D6E */ { "TRAIT D'UNION GARAY",NULL},
/* 10D6F */ { "SIGNE GARAY DE RÉDUPLICATION",NULL},
/* 10D70 */ { "LETTRE MINUSCULE GARAY A",NULL},
/* 10D71 */ { "LETTRE MINUSCULE GARAY CA",NULL},
/* 10D72 */ { "LETTRE MINUSCULE GARAY MA",NULL},
/* 10D73 */ { "LETTRE MINUSCULE GARAY KA",NULL},
/* 10D74 */ { "LETTRE MINUSCULE GARAY BA",NULL},
/* 10D75 */ { "LETTRE MINUSCULE GARAY DJA",NULL},
/* 10D76 */ { "LETTRE MINUSCULE GARAY SA",NULL},
/* 10D77 */ { "LETTRE MINUSCULE GARAY WA",NULL},
/* 10D78 */ { "LETTRE MINUSCULE GARAY LA",NULL},
/* 10D79 */ { "LETTRE MINUSCULE GARAY GA",NULL},
/* 10D7A */ { "LETTRE MINUSCULE GARAY DA",NULL},
/* 10D7B */ { "LETTRE MINUSCULE GARAY XA",NULL},
/* 10D7C */ { "LETTRE MINUSCULE GARAY YA",NULL},
/* 10D7D */ { "LETTRE MINUSCULE GARAY TA",NULL},
/* 10D7E */ { "LETTRE MINUSCULE GARAY RA",NULL},
/* 10D7F */ { "LETTRE MINUSCULE GARAY ÑA",NULL},
/* 10D80 */ { "LETTRE MINUSCULE GARAY FA",NULL},
/* 10D81 */ { "LETTRE MINUSCULE GARAY NA",NULL},
/* 10D82 */ { "LETTRE MINUSCULE GARAY PA",NULL},
/* 10D83 */ { "LETTRE MINUSCULE GARAY HA",NULL},
/* 10D84 */ { "LETTRE MINUSCULE GARAY VIEUX KA",NULL},
/* 10D85 */ { "LETTRE MINUSCULE GARAY VIEUX NA",NULL},
/* 10D86 */ { NULL,NULL},
/* 10D87 */ { NULL,NULL},
/* 10D88 */ { NULL,NULL},
/* 10D89 */ { NULL,NULL},
/* 10D8A */ { NULL,NULL},
/* 10D8B */ { NULL,NULL},
/* 10D8C */ { NULL,NULL},
/* 10D8D */ { NULL,NULL},
/* 10D8E */ { "SIGNE PLUS GARAY",NULL},
/* 10D8F */ { "SIGNE MOINS GARAY",NULL},
/* 10D90 */ { NULL,NULL},
/* 10D91 */ { NULL,NULL},
/* 10D92 */ { NULL,NULL},
/* 10D93 */ { NULL,NULL},
/* 10D94 */ { NULL,NULL},
/* 10D95 */ { NULL,NULL},
/* 10D96 */ { NULL,NULL},
/* 10D97 */ { NULL,NULL},
/* 10D98 */ { NULL,NULL},
/* 10D99 */ { NULL,NULL},
/* 10D9A */ { NULL,NULL},
/* 10D9B */ { NULL,NULL},
/* 10D9C */ { NULL,NULL},
/* 10D9D */ { NULL,NULL},
/* 10D9E */ { NULL,NULL},
/* 10D9F */ { NULL,NULL},
/* 10DA0 */ { NULL,NULL},
/* 10DA1 */ { NULL,NULL},
/* 10DA2 */ { NULL,NULL},
/* 10DA3 */ { NULL,NULL},
/* 10DA4 */ { NULL,NULL},
/* 10DA5 */ { NULL,NULL},
/* 10DA6 */ { NULL,NULL},
/* 10DA7 */ { NULL,NULL},
/* 10DA8 */ { NULL,NULL},
/* 10DA9 */ { NULL,NULL},
/* 10DAA */ { NULL,NULL},
/* 10DAB */ { NULL,NULL},
/* 10DAC */ { NULL,NULL},
/* 10DAD */ { NULL,NULL},
/* 10DAE */ { NULL,NULL},
/* 10DAF */ { NULL,NULL},
/* 10DB0 */ { NULL,NULL},
/* 10DB1 */ { NULL,NULL},
/* 10DB2 */ { NULL,NULL},
/* 10DB3 */ { NULL,NULL},
/* 10DB4 */ { NULL,NULL},
/* 10DB5 */ { NULL,NULL},
/* 10DB6 */ { NULL,NULL},
/* 10DB7 */ { NULL,NULL},
/* 10DB8 */ { NULL,NULL},
/* 10DB9 */ { NULL,NULL},
/* 10DBA */ { NULL,NULL},
/* 10DBB */ { NULL,NULL},
/* 10DBC */ { NULL,NULL},
/* 10DBD */ { NULL,NULL},
/* 10DBE */ { NULL,NULL},
/* 10DBF */ { NULL,NULL},
/* 10DC0 */ { NULL,NULL},
/* 10DC1 */ { NULL,NULL},
/* 10DC2 */ { NULL,NULL},
/* 10DC3 */ { NULL,NULL},
/* 10DC4 */ { NULL,NULL},
/* 10DC5 */ { NULL,NULL},
/* 10DC6 */ { NULL,NULL},
/* 10DC7 */ { NULL,NULL},
/* 10DC8 */ { NULL,NULL},
/* 10DC9 */ { NULL,NULL},
/* 10DCA */ { NULL,NULL},
/* 10DCB */ { NULL,NULL},
/* 10DCC */ { NULL,NULL},
/* 10DCD */ { NULL,NULL},
/* 10DCE */ { NULL,NULL},
/* 10DCF */ { NULL,NULL},
/* 10DD0 */ { NULL,NULL},
/* 10DD1 */ { NULL,NULL},
/* 10DD2 */ { NULL,NULL},
/* 10DD3 */ { NULL,NULL},
/* 10DD4 */ { NULL,NULL},
/* 10DD5 */ { NULL,NULL},
/* 10DD6 */ { NULL,NULL},
/* 10DD7 */ { NULL,NULL},
/* 10DD8 */ { NULL,NULL},
/* 10DD9 */ { NULL,NULL},
/* 10DDA */ { NULL,NULL},
/* 10DDB */ { NULL,NULL},
/* 10DDC */ { NULL,NULL},
/* 10DDD */ { NULL,NULL},
/* 10DDE */ { NULL,NULL},
/* 10DDF */ { NULL,NULL},
/* 10DE0 */ { NULL,NULL},
/* 10DE1 */ { NULL,NULL},
/* 10DE2 */ { NULL,NULL},
/* 10DE3 */ { NULL,NULL},
/* 10DE4 */ { NULL,NULL},
/* 10DE5 */ { NULL,NULL},
/* 10DE6 */ { NULL,NULL},
/* 10DE7 */ { NULL,NULL},
/* 10DE8 */ { NULL,NULL},
/* 10DE9 */ { NULL,NULL},
/* 10DEA */ { NULL,NULL},
/* 10DEB */ { NULL,NULL},
/* 10DEC */ { NULL,NULL},
/* 10DED */ { NULL,NULL},
/* 10DEE */ { NULL,NULL},
/* 10DEF */ { NULL,NULL},
/* 10DF0 */ { NULL,NULL},
/* 10DF1 */ { NULL,NULL},
/* 10DF2 */ { NULL,NULL},
/* 10DF3 */ { NULL,NULL},
/* 10DF4 */ { NULL,NULL},
/* 10DF5 */ { NULL,NULL},
/* 10DF6 */ { NULL,NULL},
/* 10DF7 */ { NULL,NULL},
/* 10DF8 */ { NULL,NULL},
/* 10DF9 */ { NULL,NULL},
/* 10DFA */ { NULL,NULL},
/* 10DFB */ { NULL,NULL},
/* 10DFC */ { NULL,NULL},
/* 10DFD */ { NULL,NULL},
/* 10DFE */ { NULL,NULL},
/* 10DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_0E[] = {
/* 10E00 */ { NULL,NULL},
/* 10E01 */ { NULL,NULL},
/* 10E02 */ { NULL,NULL},
/* 10E03 */ { NULL,NULL},
/* 10E04 */ { NULL,NULL},
/* 10E05 */ { NULL,NULL},
/* 10E06 */ { NULL,NULL},
/* 10E07 */ { NULL,NULL},
/* 10E08 */ { NULL,NULL},
/* 10E09 */ { NULL,NULL},
/* 10E0A */ { NULL,NULL},
/* 10E0B */ { NULL,NULL},
/* 10E0C */ { NULL,NULL},
/* 10E0D */ { NULL,NULL},
/* 10E0E */ { NULL,NULL},
/* 10E0F */ { NULL,NULL},
/* 10E10 */ { NULL,NULL},
/* 10E11 */ { NULL,NULL},
/* 10E12 */ { NULL,NULL},
/* 10E13 */ { NULL,NULL},
/* 10E14 */ { NULL,NULL},
/* 10E15 */ { NULL,NULL},
/* 10E16 */ { NULL,NULL},
/* 10E17 */ { NULL,NULL},
/* 10E18 */ { NULL,NULL},
/* 10E19 */ { NULL,NULL},
/* 10E1A */ { NULL,NULL},
/* 10E1B */ { NULL,NULL},
/* 10E1C */ { NULL,NULL},
/* 10E1D */ { NULL,NULL},
/* 10E1E */ { NULL,NULL},
/* 10E1F */ { NULL,NULL},
/* 10E20 */ { NULL,NULL},
/* 10E21 */ { NULL,NULL},
/* 10E22 */ { NULL,NULL},
/* 10E23 */ { NULL,NULL},
/* 10E24 */ { NULL,NULL},
/* 10E25 */ { NULL,NULL},
/* 10E26 */ { NULL,NULL},
/* 10E27 */ { NULL,NULL},
/* 10E28 */ { NULL,NULL},
/* 10E29 */ { NULL,NULL},
/* 10E2A */ { NULL,NULL},
/* 10E2B */ { NULL,NULL},
/* 10E2C */ { NULL,NULL},
/* 10E2D */ { NULL,NULL},
/* 10E2E */ { NULL,NULL},
/* 10E2F */ { NULL,NULL},
/* 10E30 */ { NULL,NULL},
/* 10E31 */ { NULL,NULL},
/* 10E32 */ { NULL,NULL},
/* 10E33 */ { NULL,NULL},
/* 10E34 */ { NULL,NULL},
/* 10E35 */ { NULL,NULL},
/* 10E36 */ { NULL,NULL},
/* 10E37 */ { NULL,NULL},
/* 10E38 */ { NULL,NULL},
/* 10E39 */ { NULL,NULL},
/* 10E3A */ { NULL,NULL},
/* 10E3B */ { NULL,NULL},
/* 10E3C */ { NULL,NULL},
/* 10E3D */ { NULL,NULL},
/* 10E3E */ { NULL,NULL},
/* 10E3F */ { NULL,NULL},
/* 10E40 */ { NULL,NULL},
/* 10E41 */ { NULL,NULL},
/* 10E42 */ { NULL,NULL},
/* 10E43 */ { NULL,NULL},
/* 10E44 */ { NULL,NULL},
/* 10E45 */ { NULL,NULL},
/* 10E46 */ { NULL,NULL},
/* 10E47 */ { NULL,NULL},
/* 10E48 */ { NULL,NULL},
/* 10E49 */ { NULL,NULL},
/* 10E4A */ { NULL,NULL},
/* 10E4B */ { NULL,NULL},
/* 10E4C */ { NULL,NULL},
/* 10E4D */ { NULL,NULL},
/* 10E4E */ { NULL,NULL},
/* 10E4F */ { NULL,NULL},
/* 10E50 */ { NULL,NULL},
/* 10E51 */ { NULL,NULL},
/* 10E52 */ { NULL,NULL},
/* 10E53 */ { NULL,NULL},
/* 10E54 */ { NULL,NULL},
/* 10E55 */ { NULL,NULL},
/* 10E56 */ { NULL,NULL},
/* 10E57 */ { NULL,NULL},
/* 10E58 */ { NULL,NULL},
/* 10E59 */ { NULL,NULL},
/* 10E5A */ { NULL,NULL},
/* 10E5B */ { NULL,NULL},
/* 10E5C */ { NULL,NULL},
/* 10E5D */ { NULL,NULL},
/* 10E5E */ { NULL,NULL},
/* 10E5F */ { NULL,NULL},
/* 10E60 */ { "CHIFFRE RÛMÎ UN",NULL},
/* 10E61 */ { "CHIFFRE RÛMÎ DEUX",NULL},
/* 10E62 */ { "CHIFFRE RÛMÎ TROIS",NULL},
/* 10E63 */ { "CHIFFRE RÛMÎ QUATRE",NULL},
/* 10E64 */ { "CHIFFRE RÛMÎ CINQ",NULL},
/* 10E65 */ { "CHIFFRE RÛMÎ SIX",NULL},
/* 10E66 */ { "CHIFFRE RÛMÎ SEPT",NULL},
/* 10E67 */ { "CHIFFRE RÛMÎ HUIT",NULL},
/* 10E68 */ { "CHIFFRE RÛMÎ NEUF",NULL},
/* 10E69 */ { "NOMBRE RÛMÎ DIX",NULL},
/* 10E6A */ { "NOMBRE RÛMÎ VINGT",NULL},
/* 10E6B */ { "NOMBRE RÛMÎ TRENTE",NULL},
/* 10E6C */ { "NOMBRE RÛMÎ QUARANTE",NULL},
/* 10E6D */ { "NOMBRE RÛMÎ CINQUANTE",NULL},
/* 10E6E */ { "NOMBRE RÛMÎ SOIXANTE",NULL},
/* 10E6F */ { "NOMBRE RÛMÎ SOIXANTE-DIX","	= nombre rûmî septante"},
/* 10E70 */ { "NOMBRE RÛMÎ QUATRE-VINGTS","	= nombre rûmî huitante"},
/* 10E71 */ { "NOMBRE RÛMÎ QUATRE-VINGT-DIX","	= nombre rûmî nonante"},
/* 10E72 */ { "NOMBRE RÛMÎ CENT",NULL},
/* 10E73 */ { "NOMBRE RÛMÎ DEUX CENTS",NULL},
/* 10E74 */ { "NOMBRE RÛMÎ TROIS CENTS",NULL},
/* 10E75 */ { "NOMBRE RÛMÎ QUATRE CENTS",NULL},
/* 10E76 */ { "NOMBRE RÛMÎ CINQ CENTS",NULL},
/* 10E77 */ { "NOMBRE RÛMÎ SIX CENTS",NULL},
/* 10E78 */ { "NOMBRE RÛMÎ SEPT CENTS",NULL},
/* 10E79 */ { "NOMBRE RÛMÎ HUIT CENTS",NULL},
/* 10E7A */ { "NOMBRE RÛMÎ NEUF CENTS",NULL},
/* 10E7B */ { "FRACTION RÛMÎ UN DEMI",NULL},
/* 10E7C */ { "FRACTION RÛMÎ UN QUART",NULL},
/* 10E7D */ { "FRACTION RÛMÎ UN TIERS",NULL},
/* 10E7E */ { "FRACTION RÛMÎ DEUX TIERS",NULL},
/* 10E7F */ { NULL,NULL},
/* 10E80 */ { "LETTRE YÉZIDIE ELIF",NULL},
/* 10E81 */ { "LETTRE YÉZIDIE BÉ",NULL},
/* 10E82 */ { "LETTRE YÉZIDIE PÉ",NULL},
/* 10E83 */ { "LETTRE YÉZIDIE PHÉ",NULL},
/* 10E84 */ { "LETTRE YÉZIDIE THÉ",NULL},
/* 10E85 */ { "LETTRE YÉZIDIE SÉ",NULL},
/* 10E86 */ { "LETTRE YÉZIDIE DJIM",NULL},
/* 10E87 */ { "LETTRE YÉZIDIE TCHIM",NULL},
/* 10E88 */ { "LETTRE YÉZIDIE TCHHIM",NULL},
/* 10E89 */ { "LETTRE YÉZIDIE HHA",NULL},
/* 10E8A */ { "LETTRE YÉZIDIE XA",NULL},
/* 10E8B */ { "LETTRE YÉZIDIE DAL",NULL},
/* 10E8C */ { "LETTRE YÉZIDIE ZAL",NULL},
/* 10E8D */ { "LETTRE YÉZIDIE RA",NULL},
/* 10E8E */ { "LETTRE YÉZIDIE RHA",NULL},
/* 10E8F */ { "LETTRE YÉZIDIE ZA",NULL},
/* 10E90 */ { "LETTRE YÉZIDIE DJA",NULL},
/* 10E91 */ { "LETTRE YÉZIDIE SINE",NULL},
/* 10E92 */ { "LETTRE YÉZIDIE CHINE",NULL},
/* 10E93 */ { "LETTRE YÉZIDIE ÇAD",NULL},
/* 10E94 */ { "LETTRE YÉZIDIE DAD",NULL},
/* 10E95 */ { "LETTRE YÉZIDIE TA",NULL},
/* 10E96 */ { "LETTRE YÉZIDIE ZÉ",NULL},
/* 10E97 */ { "LETTRE YÉZIDIE EYN",NULL},
/* 10E98 */ { "LETTRE YÉZIDIE XHEYN",NULL},
/* 10E99 */ { "LETTRE YÉZIDIE FA",NULL},
/* 10E9A */ { "LETTRE YÉZIDIE VA",NULL},
/* 10E9B */ { "LETTRE YÉZIDIE VARIANTE DE VA",NULL},
/* 10E9C */ { "LETTRE YÉZIDIE QAF",NULL},
/* 10E9D */ { "LETTRE YÉZIDIE KAF",NULL},
/* 10E9E */ { "LETTRE YÉZIDIE KHAF",NULL},
/* 10E9F */ { "LETTRE YÉZIDIE GAF",NULL},
/* 10EA0 */ { "LETTRE YÉZIDIE LAM",NULL},
/* 10EA1 */ { "LETTRE YÉZIDIE MIM",NULL},
/* 10EA2 */ { "LETTRE YÉZIDIE NOUN",NULL},
/* 10EA3 */ { "LETTRE YÉZIDIE OUM",NULL},
/* 10EA4 */ { "LETTRE YÉZIDIE WAW",NULL},
/* 10EA5 */ { "LETTRE YÉZIDIE OW",NULL},
/* 10EA6 */ { "LETTRE YÉZIDIE EW",NULL},
/* 10EA7 */ { "LETTRE YÉZIDIE HAY",NULL},
/* 10EA8 */ { "LETTRE YÉZIDIE YOT",NULL},
/* 10EA9 */ { "LETTRE YÉZIDIE ET",NULL},
/* 10EAA */ { NULL,NULL},
/* 10EAB */ { "DIACRITIQUE YÉZIDI HAMZA","	* représente un coup de glotte"},
/* 10EAC */ { "DIACRITIQUE YÉZIDI MADDA","	* indique un a long au début de certains mots"},
/* 10EAD */ { "SIGNE DE COUPURE DE MOT YÉZIDI",NULL},
/* 10EAE */ { NULL,NULL},
/* 10EAF */ { NULL,NULL},
/* 10EB0 */ { "LETTRE YÉZIDIE LAM POINT EN CHEF",NULL},
/* 10EB1 */ { "LETTRE YÉZIDIE LAM ACCENT CIRCONFLEXE",NULL},
/* 10EB2 */ { NULL,NULL},
/* 10EB3 */ { NULL,NULL},
/* 10EB4 */ { NULL,NULL},
/* 10EB5 */ { NULL,NULL},
/* 10EB6 */ { NULL,NULL},
/* 10EB7 */ { NULL,NULL},
/* 10EB8 */ { NULL,NULL},
/* 10EB9 */ { NULL,NULL},
/* 10EBA */ { NULL,NULL},
/* 10EBB */ { NULL,NULL},
/* 10EBC */ { NULL,NULL},
/* 10EBD */ { NULL,NULL},
/* 10EBE */ { NULL,NULL},
/* 10EBF */ { NULL,NULL},
/* 10EC0 */ { NULL,NULL},
/* 10EC1 */ { NULL,NULL},
/* 10EC2 */ { "LETTRE ARABE DAL DEUX POINTS VERTICAUX SOUSCRITS",NULL},
/* 10EC3 */ { "LETTRE ARABE TA' DEUX POINTS VERTICAUX SOUSCRITS",NULL},
/* 10EC4 */ { "LETTRE ARABE KAF DEUX POINTS VERTICAUX SOUSCRITS",NULL},
/* 10EC5 */ { "PETIT YA' BARRÉ ARABE DEUX POINTS SOUSCRITS","	* utilisé pour marquer un ya' implicite dans la graphie attribuée au calife Othman\n"
	"	x (petit ya' arabe - 06E6)\n"
	"	x (petit ya' barré arabe en chef deux points souscrits - 08CB)"},
/* 10EC6 */ { "LETTRE ARABE NOÛN MINCE","	* seule la forme en position médiale est attestée"},
/* 10EC7 */ { "LETTRE ARABE YA' QUATRE POINTS SOUSCRITS",NULL},
/* 10EC8 */ { NULL,NULL},
/* 10EC9 */ { NULL,NULL},
/* 10ECA */ { NULL,NULL},
/* 10ECB */ { NULL,NULL},
/* 10ECC */ { NULL,NULL},
/* 10ECD */ { NULL,NULL},
/* 10ECE */ { NULL,NULL},
/* 10ECF */ { NULL,NULL},
/* 10ED0 */ { "FIN DE VERSET BIBLIQUE ARABE","	* utilisée comme indicateur de fin de verset en ourdou"},
/* 10ED1 */ { "LIGATURE ARABE ALAYHÂ AS-SALÂTOU WAS-SALÂM",NULL},
/* 10ED2 */ { "LIGATURE ARABE ALAYHIM AS-SALÂTOU WAS-SALÂM",NULL},
/* 10ED3 */ { "LIGATURE ARABE ALAYHIMÂ AS-SALÂTOU WAS-SALÂM",NULL},
/* 10ED4 */ { "LIGATURE ARABE QADDASA ALLÂHOU SIRRAH",NULL},
/* 10ED5 */ { "LIGATURE ARABE QOUDDISA SIRROUHOUM",NULL},
/* 10ED6 */ { "LIGATURE ARABE QOUDDISA SIRROUHOUMÂ",NULL},
/* 10ED7 */ { "LIGATURE ARABE QOUDDISAT ASRÂROUHOUM",NULL},
/* 10ED8 */ { "LIGATURE ARABE NAWWARA ALLÂHOU MARQADAH",NULL},
/* 10ED9 */ { NULL,NULL},
/* 10EDA */ { NULL,NULL},
/* 10EDB */ { NULL,NULL},
/* 10EDC */ { NULL,NULL},
/* 10EDD */ { NULL,NULL},
/* 10EDE */ { NULL,NULL},
/* 10EDF */ { NULL,NULL},
/* 10EE0 */ { NULL,NULL},
/* 10EE1 */ { NULL,NULL},
/* 10EE2 */ { NULL,NULL},
/* 10EE3 */ { NULL,NULL},
/* 10EE4 */ { NULL,NULL},
/* 10EE5 */ { NULL,NULL},
/* 10EE6 */ { NULL,NULL},
/* 10EE7 */ { NULL,NULL},
/* 10EE8 */ { NULL,NULL},
/* 10EE9 */ { NULL,NULL},
/* 10EEA */ { NULL,NULL},
/* 10EEB */ { NULL,NULL},
/* 10EEC */ { NULL,NULL},
/* 10EED */ { NULL,NULL},
/* 10EEE */ { NULL,NULL},
/* 10EEF */ { NULL,NULL},
/* 10EF0 */ { NULL,NULL},
/* 10EF1 */ { NULL,NULL},
/* 10EF2 */ { NULL,NULL},
/* 10EF3 */ { NULL,NULL},
/* 10EF4 */ { NULL,NULL},
/* 10EF5 */ { NULL,NULL},
/* 10EF6 */ { NULL,NULL},
/* 10EF7 */ { NULL,NULL},
/* 10EF8 */ { NULL,NULL},
/* 10EF9 */ { NULL,NULL},
/* 10EFA */ { "DOUBLE BARRE VERTICALE SOUSCRITE ARABE","	x (kasratan arabe - 064D)"},
/* 10EFB */ { "PETIT NOÛN ARABE SOUSCRIT","	x (petit noûn arabe souscrit avec kasra - 08D9)"},
/* 10EFC */ { "DIACRITIQUE ALEF COUVRANT ARABE",NULL},
/* 10EFD */ { "PETIT MOT ARABE SOUSCRIT SAKTA","	x (petit mot arabe en chef sakta - 08DD)"},
/* 10EFE */ { "PETIT MOT ARABE SOUSCRIT QASR",NULL},
/* 10EFF */ { "PETIT MOT ARABE SOUSCRIT MADDA",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_0F[] = {
/* 10F00 */ { "LETTRE VIEUX-SOGDIENNE ALEF",NULL},
/* 10F01 */ { "LETTRE VIEUX-SOGDIENNE ALEF FINAL",NULL},
/* 10F02 */ { "LETTRE VIEUX-SOGDIENNE BÈT",NULL},
/* 10F03 */ { "LETTRE VIEUX-SOGDIENNE BÈT FINAL",NULL},
/* 10F04 */ { "LETTRE VIEUX-SOGDIENNE GUIMEL",NULL},
/* 10F05 */ { "LETTRE VIEUX-SOGDIENNE HÈ",NULL},
/* 10F06 */ { "LETTRE VIEUX-SOGDIENNE HÈ FINAL",NULL},
/* 10F07 */ { "LETTRE VIEUX-SOGDIENNE WAW",NULL},
/* 10F08 */ { "LETTRE VIEUX-SOGDIENNE ZAÏN",NULL},
/* 10F09 */ { "LETTRE VIEUX-SOGDIENNE HÈT",NULL},
/* 10F0A */ { "LETTRE VIEUX-SOGDIENNE YOD",NULL},
/* 10F0B */ { "LETTRE VIEUX-SOGDIENNE KAF",NULL},
/* 10F0C */ { "LETTRE VIEUX-SOGDIENNE LAMÈD",NULL},
/* 10F0D */ { "LETTRE VIEUX-SOGDIENNE MÉM",NULL},
/* 10F0E */ { "LETTRE VIEUX-SOGDIENNE NOUN",NULL},
/* 10F0F */ { "LETTRE VIEUX-SOGDIENNE NOUN FINAL",NULL},
/* 10F10 */ { "LETTRE VIEUX-SOGDIENNE NOUN FINAL À QUEUE VERTICALE",NULL},
/* 10F11 */ { "LETTRE VIEUX-SOGDIENNE SAMÈKH",NULL},
/* 10F12 */ { "LETTRE VIEUX-SOGDIENNE 'AÏN","	* utilisée uniquement dans l'hétérogramme araméen ʿD\n"
	"	* la lettre rèch-ʿaïn-dalèt est utilisée dans d'autres hétérogrammes"},
/* 10F13 */ { "LETTRE VIEUX-SOGDIENNE VARIANTE DE 'AÏN","	* utilisée uniquement dans l'hétérogramme araméen ʿD\n"
	"	* la lettre rèch-ʿaïn-dalèt est utilisée dans d'autres hétérogrammes"},
/* 10F14 */ { "LETTRE VIEUX-SOGDIENNE PÉ",NULL},
/* 10F15 */ { "LETTRE VIEUX-SOGDIENNE TSADÉ",NULL},
/* 10F16 */ { "LETTRE VIEUX-SOGDIENNE TSADÉ FINAL",NULL},
/* 10F17 */ { "LETTRE VIEUX-SOGDIENNE TSADÉ FINAL À QUEUE VERTICALE",NULL},
/* 10F18 */ { "LETTRE VIEUX-SOGDIENNE RÈCH-'AÏN-DALÈT",NULL},
/* 10F19 */ { "LETTRE VIEUX-SOGDIENNE CHINE",NULL},
/* 10F1A */ { "LETTRE VIEUX-SOGDIENNE TAW",NULL},
/* 10F1B */ { "LETTRE VIEUX-SOGDIENNE TAW FINAL",NULL},
/* 10F1C */ { "LETTRE VIEUX-SOGDIENNE TAW FINAL À QUEUE VERTICALE",NULL},
/* 10F1D */ { "NOMBRE VIEUX-SOGDIEN UN",NULL},
/* 10F1E */ { "NOMBRE VIEUX-SOGDIEN DEUX",NULL},
/* 10F1F */ { "NOMBRE VIEUX-SOGDIEN TROIS",NULL},
/* 10F20 */ { "NOMBRE VIEUX-SOGDIEN QUATRE",NULL},
/* 10F21 */ { "NOMBRE VIEUX-SOGDIEN CINQ",NULL},
/* 10F22 */ { "NOMBRE VIEUX-SOGDIEN DIX",NULL},
/* 10F23 */ { "NOMBRE VIEUX-SOGDIEN VINGT",NULL},
/* 10F24 */ { "NOMBRE VIEUX-SOGDIEN TRENTE",NULL},
/* 10F25 */ { "NOMBRE VIEUX-SOGDIEN CENT",NULL},
/* 10F26 */ { "FRACTION VIEUX-SOGDIENNE UN DEMI",NULL},
/* 10F27 */ { "LIGATURE VIEUX-SOGDIENNE 'AÏN-DALÈT","	* représente l'hétérogramme araméen ʿD"},
/* 10F28 */ { NULL,NULL},
/* 10F29 */ { NULL,NULL},
/* 10F2A */ { NULL,NULL},
/* 10F2B */ { NULL,NULL},
/* 10F2C */ { NULL,NULL},
/* 10F2D */ { NULL,NULL},
/* 10F2E */ { NULL,NULL},
/* 10F2F */ { NULL,NULL},
/* 10F30 */ { "LETTRE SOGDIENNE ALEF",NULL},
/* 10F31 */ { "LETTRE SOGDIENNE BÈT",NULL},
/* 10F32 */ { "LETTRE SOGDIENNE GUIMEL",NULL},
/* 10F33 */ { "LETTRE SOGDIENNE HÈ",NULL},
/* 10F34 */ { "LETTRE SOGDIENNE WAW",NULL},
/* 10F35 */ { "LETTRE SOGDIENNE ZAÏN",NULL},
/* 10F36 */ { "LETTRE SOGDIENNE HÈT",NULL},
/* 10F37 */ { "LETTRE SOGDIENNE YOD",NULL},
/* 10F38 */ { "LETTRE SOGDIENNE KAF",NULL},
/* 10F39 */ { "LETTRE SOGDIENNE LAMÈD",NULL},
/* 10F3A */ { "LETTRE SOGDIENNE MÉM",NULL},
/* 10F3B */ { "LETTRE SOGDIENNE NOUN",NULL},
/* 10F3C */ { "LETTRE SOGDIENNE SAMÈKH",NULL},
/* 10F3D */ { "LETTRE SOGDIENNE 'AÏN","	* utilisée uniquement dans des hétérogrammes araméens"},
/* 10F3E */ { "LETTRE SOGDIENNE PÉ",NULL},
/* 10F3F */ { "LETTRE SOGDIENNE TSADÉ",NULL},
/* 10F40 */ { "LETTRE SOGDIENNE RÈCH-'AÏN",NULL},
/* 10F41 */ { "LETTRE SOGDIENNE CHINE",NULL},
/* 10F42 */ { "LETTRE SOGDIENNE TAW",NULL},
/* 10F43 */ { "LETTRE SOGDIENNE FÈT",NULL},
/* 10F44 */ { "LETTRE SOGDIENNE LÈCH","	= rèch en crochet"},
/* 10F45 */ { "CHINE INDÉPENDANT SOGDIEN","	x 6240"},
/* 10F46 */ { "DIACRITIQUE SOGDIEN POINT SOUSCRIT",NULL},
/* 10F47 */ { "DIACRITIQUE SOGDIEN DEUX POINTS SOUSCRITS",NULL},
/* 10F48 */ { "DIACRITIQUE SOGDIEN POINT EN CHEF",NULL},
/* 10F49 */ { "DIACRITIQUE SOGDIEN DEUX POINTS EN CHEF",NULL},
/* 10F4A */ { "DIACRITIQUE SOGDIEN ARC EN CHEF",NULL},
/* 10F4B */ { "DIACRITIQUE SOGDIEN ARC SOUSCRIT",NULL},
/* 10F4C */ { "DIACRITIQUE SOGDIEN CROCHET EN CHEF",NULL},
/* 10F4D */ { "DIACRITIQUE SOGDIEN CROCHET SOUSCRIT",NULL},
/* 10F4E */ { "DIACRITIQUE SOGDIEN LONG CROCHET SOUSCRIT",NULL},
/* 10F4F */ { "DIACRITIQUE SOGDIEN RÈCH SOUSCRIT",NULL},
/* 10F50 */ { "DIACRITIQUE SOGDIEN TRAIT SOUSCRIT",NULL},
/* 10F51 */ { "NOMBRE SOGDIEN UN",NULL},
/* 10F52 */ { "NOMBRE SOGDIEN DIX",NULL},
/* 10F53 */ { "NOMBRE SOGDIEN VINGT",NULL},
/* 10F54 */ { "NOMBRE SOGDIEN CENT",NULL},
/* 10F55 */ { "PONCTUATION SOGDIENNE DEUX BARRES VERTICALES",NULL},
/* 10F56 */ { "PONCTUATION SOGDIENNE DEUX BARRES VERTICALES AVEC POINTS",NULL},
/* 10F57 */ { "PONCTUATION SOGDIENNE CERCLE AVEC POINT",NULL},
/* 10F58 */ { "PONCTUATION SOGDIENNE DEUX CERCLES AVEC POINTS",NULL},
/* 10F59 */ { "PONCTUATION SOGDIENNE DEMI-CERCLE AVEC POINT",NULL},
/* 10F5A */ { NULL,NULL},
/* 10F5B */ { NULL,NULL},
/* 10F5C */ { NULL,NULL},
/* 10F5D */ { NULL,NULL},
/* 10F5E */ { NULL,NULL},
/* 10F5F */ { NULL,NULL},
/* 10F60 */ { NULL,NULL},
/* 10F61 */ { NULL,NULL},
/* 10F62 */ { NULL,NULL},
/* 10F63 */ { NULL,NULL},
/* 10F64 */ { NULL,NULL},
/* 10F65 */ { NULL,NULL},
/* 10F66 */ { NULL,NULL},
/* 10F67 */ { NULL,NULL},
/* 10F68 */ { NULL,NULL},
/* 10F69 */ { NULL,NULL},
/* 10F6A */ { NULL,NULL},
/* 10F6B */ { NULL,NULL},
/* 10F6C */ { NULL,NULL},
/* 10F6D */ { NULL,NULL},
/* 10F6E */ { NULL,NULL},
/* 10F6F */ { NULL,NULL},
/* 10F70 */ { "LETTRE VIEIL-OUÏGOURE ALEF",NULL},
/* 10F71 */ { "LETTRE VIEIL-OUÏGOURE BÈT",NULL},
/* 10F72 */ { "LETTRE VIEIL-OUÏGOURE GUIMEL-HÈT",NULL},
/* 10F73 */ { "LETTRE VIEIL-OUÏGOURE WAW",NULL},
/* 10F74 */ { "LETTRE VIEIL-OUÏGOURE ZAÏN",NULL},
/* 10F75 */ { "LETTRE VIEIL-OUÏGOURE HÈT FINAL",NULL},
/* 10F76 */ { "LETTRE VIEIL-OUÏGOURE YOD",NULL},
/* 10F77 */ { "LETTRE VIEIL-OUÏGOURE KAF",NULL},
/* 10F78 */ { "LETTRE VIEIL-OUÏGOURE LAMÈD",NULL},
/* 10F79 */ { "LETTRE VIEIL-OUÏGOURE MÉM",NULL},
/* 10F7A */ { "LETTRE VIEIL-OUÏGOURE NOUN",NULL},
/* 10F7B */ { "LETTRE VIEIL-OUÏGOURE SAMÈKH",NULL},
/* 10F7C */ { "LETTRE VIEIL-OUÏGOURE PÉ",NULL},
/* 10F7D */ { "LETTRE VIEIL-OUÏGOURE TSADÉ",NULL},
/* 10F7E */ { "LETTRE VIEIL-OUÏGOURE RÈCH",NULL},
/* 10F7F */ { "LETTRE VIEIL-OUÏGOURE CHINE",NULL},
/* 10F80 */ { "LETTRE VIEIL-OUÏGOURE TAW",NULL},
/* 10F81 */ { "LETTRE VIEIL-OUÏGOURE LÈCH","	= rèch crochet"},
/* 10F82 */ { "DIACRITIQUE VIEIL-OUÏGOUR POINT EN CHEF",NULL},
/* 10F83 */ { "DIACRITIQUE VIEIL-OUÏGOUR POINT SOUSCRIT",NULL},
/* 10F84 */ { "DIACRITIQUE VIEIL-OUÏGOUR DEUX POINTS EN CHEF",NULL},
/* 10F85 */ { "DIACRITIQUE VIEIL-OUÏGOUR DEUX POINTS SOUSCRITS",NULL},
/* 10F86 */ { "PONCTUATION VIEIL-OUÏGOURE BARRE",NULL},
/* 10F87 */ { "PONCTUATION VIEIL-OUÏGOURE DEUX BARRES",NULL},
/* 10F88 */ { "PONCTUATION VIEIL-OUÏGOURE DEUX POINTS",NULL},
/* 10F89 */ { "PONCTUATION VIEIL-OUÏGOURE QUATRE POINTS",NULL},
/* 10F8A */ { NULL,NULL},
/* 10F8B */ { NULL,NULL},
/* 10F8C */ { NULL,NULL},
/* 10F8D */ { NULL,NULL},
/* 10F8E */ { NULL,NULL},
/* 10F8F */ { NULL,NULL},
/* 10F90 */ { NULL,NULL},
/* 10F91 */ { NULL,NULL},
/* 10F92 */ { NULL,NULL},
/* 10F93 */ { NULL,NULL},
/* 10F94 */ { NULL,NULL},
/* 10F95 */ { NULL,NULL},
/* 10F96 */ { NULL,NULL},
/* 10F97 */ { NULL,NULL},
/* 10F98 */ { NULL,NULL},
/* 10F99 */ { NULL,NULL},
/* 10F9A */ { NULL,NULL},
/* 10F9B */ { NULL,NULL},
/* 10F9C */ { NULL,NULL},
/* 10F9D */ { NULL,NULL},
/* 10F9E */ { NULL,NULL},
/* 10F9F */ { NULL,NULL},
/* 10FA0 */ { NULL,NULL},
/* 10FA1 */ { NULL,NULL},
/* 10FA2 */ { NULL,NULL},
/* 10FA3 */ { NULL,NULL},
/* 10FA4 */ { NULL,NULL},
/* 10FA5 */ { NULL,NULL},
/* 10FA6 */ { NULL,NULL},
/* 10FA7 */ { NULL,NULL},
/* 10FA8 */ { NULL,NULL},
/* 10FA9 */ { NULL,NULL},
/* 10FAA */ { NULL,NULL},
/* 10FAB */ { NULL,NULL},
/* 10FAC */ { NULL,NULL},
/* 10FAD */ { NULL,NULL},
/* 10FAE */ { NULL,NULL},
/* 10FAF */ { NULL,NULL},
/* 10FB0 */ { "LETTRE CHORASMIENNE ALEF",NULL},
/* 10FB1 */ { "LETTRE CHORASMIENNE PETIT ALEF",NULL},
/* 10FB2 */ { "LETTRE CHORASMIENNE BÈT",NULL},
/* 10FB3 */ { "LETTRE CHORASMIENNE GUIMEL",NULL},
/* 10FB4 */ { "LETTRE CHORASMIENNE DALÈT",NULL},
/* 10FB5 */ { "LETTRE CHORASMIENNE HÈ",NULL},
/* 10FB6 */ { "LETTRE CHORASMIENNE WAV",NULL},
/* 10FB7 */ { "LETTRE CHORASMIENNE WAV BOUCLÉ",NULL},
/* 10FB8 */ { "LETTRE CHORASMIENNE ZAÏN",NULL},
/* 10FB9 */ { "LETTRE CHORASMIENNE HÈT",NULL},
/* 10FBA */ { "LETTRE CHORASMIENNE YOD",NULL},
/* 10FBB */ { "LETTRE CHORASMIENNE KAF",NULL},
/* 10FBC */ { "LETTRE CHORASMIENNE LAMÈD",NULL},
/* 10FBD */ { "LETTRE CHORASMIENNE MÉM",NULL},
/* 10FBE */ { "LETTRE CHORASMIENNE NOUN",NULL},
/* 10FBF */ { "LETTRE CHORASMIENNE SAMÈKH",NULL},
/* 10FC0 */ { "LETTRE CHORASMIENNE 'AÏN",NULL},
/* 10FC1 */ { "LETTRE CHORASMIENNE PÉ",NULL},
/* 10FC2 */ { "LETTRE CHORASMIENNE RÈCH",NULL},
/* 10FC3 */ { "LETTRE CHORASMIENNE CHINE",NULL},
/* 10FC4 */ { "LETTRE CHORASMIENNE TAW",NULL},
/* 10FC5 */ { "NOMBRE CHORASMIEN UN",NULL},
/* 10FC6 */ { "NOMBRE CHORASMIEN DEUX",NULL},
/* 10FC7 */ { "NOMBRE CHORASMIEN TROIS",NULL},
/* 10FC8 */ { "NOMBRE CHORASMIEN QUATRE",NULL},
/* 10FC9 */ { "NOMBRE CHORASMIEN DIX",NULL},
/* 10FCA */ { "NOMBRE CHORASMIEN VINGT",NULL},
/* 10FCB */ { "NOMBRE CHORASMIEN CENT",NULL},
/* 10FCC */ { NULL,NULL},
/* 10FCD */ { NULL,NULL},
/* 10FCE */ { NULL,NULL},
/* 10FCF */ { NULL,NULL},
/* 10FD0 */ { NULL,NULL},
/* 10FD1 */ { NULL,NULL},
/* 10FD2 */ { NULL,NULL},
/* 10FD3 */ { NULL,NULL},
/* 10FD4 */ { NULL,NULL},
/* 10FD5 */ { NULL,NULL},
/* 10FD6 */ { NULL,NULL},
/* 10FD7 */ { NULL,NULL},
/* 10FD8 */ { NULL,NULL},
/* 10FD9 */ { NULL,NULL},
/* 10FDA */ { NULL,NULL},
/* 10FDB */ { NULL,NULL},
/* 10FDC */ { NULL,NULL},
/* 10FDD */ { NULL,NULL},
/* 10FDE */ { NULL,NULL},
/* 10FDF */ { NULL,NULL},
/* 10FE0 */ { "LETTRE ÉLYMÉENNE ALEF",NULL},
/* 10FE1 */ { "LETTRE ÉLYMÉENNE BÈT",NULL},
/* 10FE2 */ { "LETTRE ÉLYMÉENNE GUIMEL",NULL},
/* 10FE3 */ { "LETTRE ÉLYMÉENNE DALÈT",NULL},
/* 10FE4 */ { "LETTRE ÉLYMÉENNE HÈ",NULL},
/* 10FE5 */ { "LETTRE ÉLYMÉENNE WAW",NULL},
/* 10FE6 */ { "LETTRE ÉLYMÉENNE ZAÏN",NULL},
/* 10FE7 */ { "LETTRE ÉLYMÉENNE HÈH",NULL},
/* 10FE8 */ { "LETTRE ÉLYMÉENNE TÈT",NULL},
/* 10FE9 */ { "LETTRE ÉLYMÉENNE YOD",NULL},
/* 10FEA */ { "LETTRE ÉLYMÉENNE KAF",NULL},
/* 10FEB */ { "LETTRE ÉLYMÉENNE LAMÈD",NULL},
/* 10FEC */ { "LETTRE ÉLYMÉENNE MÉM",NULL},
/* 10FED */ { "LETTRE ÉLYMÉENNE NOUN",NULL},
/* 10FEE */ { "LETTRE ÉLYMÉENNE SAMÈKH",NULL},
/* 10FEF */ { "LETTRE ÉLYMÉENNE 'AÏN",NULL},
/* 10FF0 */ { "LETTRE ÉLYMÉENNE PÉ",NULL},
/* 10FF1 */ { "LETTRE ÉLYMÉENNE TSADÉ",NULL},
/* 10FF2 */ { "LETTRE ÉLYMÉENNE QOUF",NULL},
/* 10FF3 */ { "LETTRE ÉLYMÉENNE RÈCH",NULL},
/* 10FF4 */ { "LETTRE ÉLYMÉENNE CHINE",NULL},
/* 10FF5 */ { "LETTRE ÉLYMÉENNE TAW",NULL},
/* 10FF6 */ { "LIGATURE ÉLYMÉENNE ZAÏN-YOD","	* utilisée pour l'hétérogramme araméen zy"},
/* 10FF7 */ { NULL,NULL},
/* 10FF8 */ { NULL,NULL},
/* 10FF9 */ { NULL,NULL},
/* 10FFA */ { NULL,NULL},
/* 10FFB */ { NULL,NULL},
/* 10FFC */ { NULL,NULL},
/* 10FFD */ { NULL,NULL},
/* 10FFE */ { NULL,NULL},
/* 10FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_10[] = {
/* 11000 */ { "DIACRITIQUE BRAHMI TCHANDRABINDOU",NULL},
/* 11001 */ { "DIACRITIQUE BRAHMI ANOUSVÂRA",NULL},
/* 11002 */ { "DIACRITIQUE BRAHMI VISARGA",NULL},
/* 11003 */ { "SIGNE BRAHMI DJIHVAMOULIYA",NULL},
/* 11004 */ { "SIGNE BRAHMI OUPADHMANIYA",NULL},
/* 11005 */ { "LETTRE BRAHMI A",NULL},
/* 11006 */ { "LETTRE BRAHMI Â",NULL},
/* 11007 */ { "LETTRE BRAHMI I",NULL},
/* 11008 */ { "LETTRE BRAHMI Î",NULL},
/* 11009 */ { "LETTRE BRAHMI OU",NULL},
/* 1100A */ { "LETTRE BRAHMI OÛ",NULL},
/* 1100B */ { "LETTRE BRAHMI R VOCALIQUE",NULL},
/* 1100C */ { "LETTRE BRAHMI RR VOCALIQUE",NULL},
/* 1100D */ { "LETTRE BRAHMI L VOCALIQUE",NULL},
/* 1100E */ { "LETTRE BRAHMI LL VOCALIQUE",NULL},
/* 1100F */ { "LETTRE BRAHMI É",NULL},
/* 11010 */ { "LETTRE BRAHMI AI",NULL},
/* 11011 */ { "LETTRE BRAHMI O",NULL},
/* 11012 */ { "LETTRE BRAHMI AOU",NULL},
/* 11013 */ { "LETTRE BRAHMI KA",NULL},
/* 11014 */ { "LETTRE BRAHMI KHA",NULL},
/* 11015 */ { "LETTRE BRAHMI GA",NULL},
/* 11016 */ { "LETTRE BRAHMI GHA",NULL},
/* 11017 */ { "LETTRE BRAHMI NGA",NULL},
/* 11018 */ { "LETTRE BRAHMI TCHA",NULL},
/* 11019 */ { "LETTRE BRAHMI TCHHA",NULL},
/* 1101A */ { "LETTRE BRAHMI DJA",NULL},
/* 1101B */ { "LETTRE BRAHMI DJHA",NULL},
/* 1101C */ { "LETTRE BRAHMI ÑA",NULL},
/* 1101D */ { "LETTRE BRAHMI TTA",NULL},
/* 1101E */ { "LETTRE BRAHMI TTHA",NULL},
/* 1101F */ { "LETTRE BRAHMI DDA",NULL},
/* 11020 */ { "LETTRE BRAHMI DDHA",NULL},
/* 11021 */ { "LETTRE BRAHMI NNA",NULL},
/* 11022 */ { "LETTRE BRAHMI TA",NULL},
/* 11023 */ { "LETTRE BRAHMI THA",NULL},
/* 11024 */ { "LETTRE BRAHMI DA",NULL},
/* 11025 */ { "LETTRE BRAHMI DHA",NULL},
/* 11026 */ { "LETTRE BRAHMI NA",NULL},
/* 11027 */ { "LETTRE BRAHMI PA",NULL},
/* 11028 */ { "LETTRE BRAHMI PHA","	= lettre brahmi p'a"},
/* 11029 */ { "LETTRE BRAHMI BA",NULL},
/* 1102A */ { "LETTRE BRAHMI BHA",NULL},
/* 1102B */ { "LETTRE BRAHMI MA",NULL},
/* 1102C */ { "LETTRE BRAHMI YA",NULL},
/* 1102D */ { "LETTRE BRAHMI RA",NULL},
/* 1102E */ { "LETTRE BRAHMI LA",NULL},
/* 1102F */ { "LETTRE BRAHMI VA",NULL},
/* 11030 */ { "LETTRE BRAHMI ÇA",NULL},
/* 11031 */ { "LETTRE BRAHMI CHA",NULL},
/* 11032 */ { "LETTRE BRAHMI SA",NULL},
/* 11033 */ { "LETTRE BRAHMI HA",NULL},
/* 11034 */ { "LETTRE BRAHMI LLA",NULL},
/* 11035 */ { "LETTRE BRAHMI LLLA VIEUX TAMOUL",NULL},
/* 11036 */ { "LETTRE BRAHMI RRA VIEUX TAMOUL",NULL},
/* 11037 */ { "LETTRE BRAHMI NNNA VIEUX TAMOUL",NULL},
/* 11038 */ { "DIACRITIQUE VOYELLE BRAHMI AA",NULL},
/* 11039 */ { "DIACRITIQUE VOYELLE BRAHMI BHATTIPROLOU AA",NULL},
/* 1103A */ { "DIACRITIQUE VOYELLE BRAHMI I",NULL},
/* 1103B */ { "DIACRITIQUE VOYELLE BRAHMI Î",NULL},
/* 1103C */ { "DIACRITIQUE VOYELLE BRAHMI OU",NULL},
/* 1103D */ { "DIACRITIQUE VOYELLE BRAHMI OÛ",NULL},
/* 1103E */ { "DIACRITIQUE VOYELLE BRAHMI R VOCALIQUE",NULL},
/* 1103F */ { "DIACRITIQUE VOYELLE BRAHMI RR VOCALIQUE",NULL},
/* 11040 */ { "DIACRITIQUE VOYELLE BRAHMI L VOCALIQUE",NULL},
/* 11041 */ { "DIACRITIQUE VOYELLE BRAHMI LL VOCALIQUE",NULL},
/* 11042 */ { "DIACRITIQUE VOYELLE BRAHMI É",NULL},
/* 11043 */ { "DIACRITIQUE VOYELLE BRAHMI AI",NULL},
/* 11044 */ { "DIACRITIQUE VOYELLE BRAHMI O",NULL},
/* 11045 */ { "DIACRITIQUE VOYELLE BRAHMI AOU",NULL},
/* 11046 */ { "DIACRITIQUE BRAHMI VIRÂMA",NULL},
/* 11047 */ { "DANDA BRAHMI",NULL},
/* 11048 */ { "DOUBLE DANDA BRAHMI",NULL},
/* 11049 */ { "PONCTUATION BRAHMI POINT",NULL},
/* 1104A */ { "PONCTUATION BRAHMI DOUBLE POINT",NULL},
/* 1104B */ { "PONCTUATION BRAHMI LIGNE",NULL},
/* 1104C */ { "PONCTUATION BRAHMI CROISSANT BARRE",NULL},
/* 1104D */ { "PONCTUATION BRAHMI LOTUS",NULL},
/* 1104E */ { NULL,NULL},
/* 1104F */ { NULL,NULL},
/* 11050 */ { NULL,NULL},
/* 11051 */ { NULL,NULL},
/* 11052 */ { "NOMBRE BRAHMI UN",NULL},
/* 11053 */ { "NOMBRE BRAHMI DEUX",NULL},
/* 11054 */ { "NOMBRE BRAHMI TROIS",NULL},
/* 11055 */ { "NOMBRE BRAHMI QUATRE",NULL},
/* 11056 */ { "NOMBRE BRAHMI CINQ",NULL},
/* 11057 */ { "NOMBRE BRAHMI SIX",NULL},
/* 11058 */ { "NOMBRE BRAHMI SEPT",NULL},
/* 11059 */ { "NOMBRE BRAHMI HUIT",NULL},
/* 1105A */ { "NOMBRE BRAHMI NEUF",NULL},
/* 1105B */ { "NOMBRE BRAHMI DIX",NULL},
/* 1105C */ { "NOMBRE BRAHMI VINGT",NULL},
/* 1105D */ { "NOMBRE BRAHMI TRENTE",NULL},
/* 1105E */ { "NOMBRE BRAHMI QUARANTE",NULL},
/* 1105F */ { "NOMBRE BRAHMI CINQUANTE",NULL},
/* 11060 */ { "NOMBRE BRAHMI SOIXANTE",NULL},
/* 11061 */ { "NOMBRE BRAHMI SOIXANTE-DIX","	= nombre brahmi septante"},
/* 11062 */ { "NOMBRE BRAHMI QUATRE-VINGTS","	= nombre brahmi huitante"},
/* 11063 */ { "NOMBRE BRAHMI QUATRE-VINGT-DIX","	= nombre brahmi nonante"},
/* 11064 */ { "NOMBRE BRAHMI CENT",NULL},
/* 11065 */ { "NOMBRE BRAHMI MILLE",NULL},
/* 11066 */ { "CHIFFRE BRAHMI ZÉRO",NULL},
/* 11067 */ { "CHIFFRE BRAHMI UN",NULL},
/* 11068 */ { "CHIFFRE BRAHMI DEUX",NULL},
/* 11069 */ { "CHIFFRE BRAHMI TROIS",NULL},
/* 1106A */ { "CHIFFRE BRAHMI QUATRE",NULL},
/* 1106B */ { "CHIFFRE BRAHMI CINQ",NULL},
/* 1106C */ { "CHIFFRE BRAHMI SIX",NULL},
/* 1106D */ { "CHIFFRE BRAHMI SEPT",NULL},
/* 1106E */ { "CHIFFRE BRAHMI HUIT",NULL},
/* 1106F */ { "CHIFFRE BRAHMI NEUF",NULL},
/* 11070 */ { "DIACRITIQUE BRAHMI VIRÂMA VIEUX TAMOUL",NULL},
/* 11071 */ { "LETTRE BRAHMI E COURT VIEUX TAMOUL",NULL},
/* 11072 */ { "LETTRE BRAHMI O COURT VIEUX TAMOUL",NULL},
/* 11073 */ { "DIACRITIQUE VOYELLE BRAHMI E COURT VIEUX TAMOUL",NULL},
/* 11074 */ { "DIACRITIQUE VOYELLE BRAHMI O COURT VIEUX TAMOUL",NULL},
/* 11075 */ { "LETTRE BRAHMI LLA VIEUX TAMOUL",NULL},
/* 11076 */ { NULL,NULL},
/* 11077 */ { NULL,NULL},
/* 11078 */ { NULL,NULL},
/* 11079 */ { NULL,NULL},
/* 1107A */ { NULL,NULL},
/* 1107B */ { NULL,NULL},
/* 1107C */ { NULL,NULL},
/* 1107D */ { NULL,NULL},
/* 1107E */ { NULL,NULL},
/* 1107F */ { "GLUON DE NOMBRES BRAHMI","	* un virâma utilisé pour former des ligatures entre les nombres brahmi pour indiquer la multiplication"},
/* 11080 */ { "DIACRITIQUE KAYATHI TCHANDRABINDOU",NULL},
/* 11081 */ { "DIACRITIQUE KAYATHI ANOUSVÂRA",NULL},
/* 11082 */ { "DIACRITIQUE KAYATHI VISARGA",NULL},
/* 11083 */ { "LETTRE KAYATHI A",NULL},
/* 11084 */ { "LETTRE KAYATHI Â",NULL},
/* 11085 */ { "LETTRE KAYATHI I",NULL},
/* 11086 */ { "LETTRE KAYATHI Î",NULL},
/* 11087 */ { "LETTRE KAYATHI OU",NULL},
/* 11088 */ { "LETTRE KAYATHI OÛ",NULL},
/* 11089 */ { "LETTRE KAYATHI É",NULL},
/* 1108A */ { "LETTRE KAYATHI AI",NULL},
/* 1108B */ { "LETTRE KAYATHI O",NULL},
/* 1108C */ { "LETTRE KAYATHI AOU",NULL},
/* 1108D */ { "LETTRE KAYATHI KA",NULL},
/* 1108E */ { "LETTRE KAYATHI KHA",NULL},
/* 1108F */ { "LETTRE KAYATHI GA",NULL},
/* 11090 */ { "LETTRE KAYATHI GHA",NULL},
/* 11091 */ { "LETTRE KAYATHI NGA",NULL},
/* 11092 */ { "LETTRE KAYATHI TCHA",NULL},
/* 11093 */ { "LETTRE KAYATHI TCHHA",NULL},
/* 11094 */ { "LETTRE KAYATHI DJA",NULL},
/* 11095 */ { "LETTRE KAYATHI DJHA",NULL},
/* 11096 */ { "LETTRE KAYATHI ÑA",NULL},
/* 11097 */ { "LETTRE KAYATHI TTA",NULL},
/* 11098 */ { "LETTRE KAYATHI TTHA",NULL},
/* 11099 */ { "LETTRE KAYATHI DDA",NULL},
/* 1109A */ { "LETTRE KAYATHI DDDHA","	: 11099 110BA"},
/* 1109B */ { "LETTRE KAYATHI DDHA",NULL},
/* 1109C */ { "LETTRE KAYATHI RHA","	: 1109B 110BA"},
/* 1109D */ { "LETTRE KAYATHI NNA",NULL},
/* 1109E */ { "LETTRE KAYATHI TA",NULL},
/* 1109F */ { "LETTRE KAYATHI THA",NULL},
/* 110A0 */ { "LETTRE KAYATHI DA",NULL},
/* 110A1 */ { "LETTRE KAYATHI DHA",NULL},
/* 110A2 */ { "LETTRE KAYATHI NA",NULL},
/* 110A3 */ { "LETTRE KAYATHI PA",NULL},
/* 110A4 */ { "LETTRE KAYATHI PHA","	= lettre kayathi p'a"},
/* 110A5 */ { "LETTRE KAYATHI BA",NULL},
/* 110A6 */ { "LETTRE KAYATHI BHA",NULL},
/* 110A7 */ { "LETTRE KAYATHI MA",NULL},
/* 110A8 */ { "LETTRE KAYATHI YA","	* le glyphe peut présenter le point ou non"},
/* 110A9 */ { "LETTRE KAYATHI RA",NULL},
/* 110AA */ { "LETTRE KAYATHI LA",NULL},
/* 110AB */ { "LETTRE KAYATHI VA","	: 110A5 110BA"},
/* 110AC */ { "LETTRE KAYATHI ÇA",NULL},
/* 110AD */ { "LETTRE KAYATHI CHA",NULL},
/* 110AE */ { "LETTRE KAYATHI SA",NULL},
/* 110AF */ { "LETTRE KAYATHI HA",NULL},
/* 110B0 */ { "DIACRITIQUE VOYELLE KAYATHI Â",NULL},
/* 110B1 */ { "DIACRITIQUE VOYELLE KAYATHI I",NULL},
/* 110B2 */ { "DIACRITIQUE VOYELLE KAYATHI Î",NULL},
/* 110B3 */ { "DIACRITIQUE VOYELLE KAYATHI OU",NULL},
/* 110B4 */ { "DIACRITIQUE VOYELLE KAYATHI OÛ",NULL},
/* 110B5 */ { "DIACRITIQUE VOYELLE KAYATHI É",NULL},
/* 110B6 */ { "DIACRITIQUE VOYELLE KAYATHI AI",NULL},
/* 110B7 */ { "DIACRITIQUE VOYELLE KAYATHI O",NULL},
/* 110B8 */ { "DIACRITIQUE VOYELLE KAYATHI AOU",NULL},
/* 110B9 */ { "DIACRITIQUE KAYATHI VIRÂMA",NULL},
/* 110BA */ { "DIACRITIQUE KAYATHI NOUKTA",NULL},
/* 110BB */ { "SIGNE D'ABRÉVIATION KAYATHI",NULL},
/* 110BC */ { "SIGNE D'ÉNUMÉRATION KAYATHI",NULL},
/* 110BD */ { "SYMBOLE KAYATHI NUMÉRO","	* utilisé pour indiquer une référence numérique"},
/* 110BE */ { "REPÈRE DE SECTION KAYATHI","	* marque la fin d'une phrase\n"
	"	x (repère de section khojki - 1123B)"},
/* 110BF */ { "REPÈRE DE SECTION DOUBLE KAYATHI","	* délimite des parties plus larges d'un texte, comme les paragraphes\n"
	"	x (repère de section double khojki - 1123C)"},
/* 110C0 */ { "DANDA KAYATHI",NULL},
/* 110C1 */ { "DOUBLE DANDA KAYATHI",NULL},
/* 110C2 */ { "DIACRITIQUE VOYELLE KAYATHI R VOCALIQUE",NULL},
/* 110C3 */ { NULL,NULL},
/* 110C4 */ { NULL,NULL},
/* 110C5 */ { NULL,NULL},
/* 110C6 */ { NULL,NULL},
/* 110C7 */ { NULL,NULL},
/* 110C8 */ { NULL,NULL},
/* 110C9 */ { NULL,NULL},
/* 110CA */ { NULL,NULL},
/* 110CB */ { NULL,NULL},
/* 110CC */ { NULL,NULL},
/* 110CD */ { "SYMBOLE KAYATHI NUMÉRO EN CHEF","	* utilisé pour indiquer un numéro dans une liste détaillée"},
/* 110CE */ { NULL,NULL},
/* 110CF */ { NULL,NULL},
/* 110D0 */ { "LETTRE SORA SOMPENG SAH",NULL},
/* 110D1 */ { "LETTRE SORA SOMPENG TAH",NULL},
/* 110D2 */ { "LETTRE SORA SOMPENG BAH",NULL},
/* 110D3 */ { "LETTRE SORA SOMPENG TCHAH",NULL},
/* 110D4 */ { "LETTRE SORA SOMPENG DAH",NULL},
/* 110D5 */ { "LETTRE SORA SOMPENG GAH",NULL},
/* 110D6 */ { "LETTRE SORA SOMPENG MAH",NULL},
/* 110D7 */ { "LETTRE SORA SOMPENG NGAH",NULL},
/* 110D8 */ { "LETTRE SORA SOMPENG LAH",NULL},
/* 110D9 */ { "LETTRE SORA SOMPENG NAH",NULL},
/* 110DA */ { "LETTRE SORA SOMPENG VAH",NULL},
/* 110DB */ { "LETTRE SORA SOMPENG PAH",NULL},
/* 110DC */ { "LETTRE SORA SOMPENG YAH",NULL},
/* 110DD */ { "LETTRE SORA SOMPENG RAH",NULL},
/* 110DE */ { "LETTRE SORA SOMPENG HAH",NULL},
/* 110DF */ { "LETTRE SORA SOMPENG KAH",NULL},
/* 110E0 */ { "LETTRE SORA SOMPENG DJAH",NULL},
/* 110E1 */ { "LETTRE SORA SOMPENG ÑAH",NULL},
/* 110E2 */ { "LETTRE SORA SOMPENG AH",NULL},
/* 110E3 */ { "LETTRE SORA SOMPENG ÉÉH",NULL},
/* 110E4 */ { "LETTRE SORA SOMPENG IH",NULL},
/* 110E5 */ { "LETTRE SORA SOMPENG OUH",NULL},
/* 110E6 */ { "LETTRE SORA SOMPENG OH",NULL},
/* 110E7 */ { "LETTRE SORA SOMPENG ÈH",NULL},
/* 110E8 */ { "LETTRE SORA SOMPENG MAÈ",NULL},
/* 110E9 */ { NULL,NULL},
/* 110EA */ { NULL,NULL},
/* 110EB */ { NULL,NULL},
/* 110EC */ { NULL,NULL},
/* 110ED */ { NULL,NULL},
/* 110EE */ { NULL,NULL},
/* 110EF */ { NULL,NULL},
/* 110F0 */ { "CHIFFRE SORA SOMPENG ZÉRO",NULL},
/* 110F1 */ { "CHIFFRE SORA SOMPENG UN",NULL},
/* 110F2 */ { "CHIFFRE SORA SOMPENG DEUX",NULL},
/* 110F3 */ { "CHIFFRE SORA SOMPENG TROIS",NULL},
/* 110F4 */ { "CHIFFRE SORA SOMPENG QUATRE",NULL},
/* 110F5 */ { "CHIFFRE SORA SOMPENG CINQ",NULL},
/* 110F6 */ { "CHIFFRE SORA SOMPENG SIX",NULL},
/* 110F7 */ { "CHIFFRE SORA SOMPENG SEPT",NULL},
/* 110F8 */ { "CHIFFRE SORA SOMPENG HUIT",NULL},
/* 110F9 */ { "CHIFFRE SORA SOMPENG NEUF",NULL},
/* 110FA */ { NULL,NULL},
/* 110FB */ { NULL,NULL},
/* 110FC */ { NULL,NULL},
/* 110FD */ { NULL,NULL},
/* 110FE */ { NULL,NULL},
/* 110FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_11[] = {
/* 11100 */ { "DIACRITIQUE CHAKMA TCHANDRABINDOU",NULL},
/* 11101 */ { "DIACRITIQUE CHAKMA ANOUSVÂRA",NULL},
/* 11102 */ { "DIACRITIQUE CHAKMA VISARGA",NULL},
/* 11103 */ { "LETTRE CHAKMA Â",NULL},
/* 11104 */ { "LETTRE CHAKMA I",NULL},
/* 11105 */ { "LETTRE CHAKMA OU",NULL},
/* 11106 */ { "LETTRE CHAKMA É",NULL},
/* 11107 */ { "LETTRE CHAKMA KÂ",NULL},
/* 11108 */ { "LETTRE CHAKMA KHÂ",NULL},
/* 11109 */ { "LETTRE CHAKMA GÂ",NULL},
/* 1110A */ { "LETTRE CHAKMA GHÂ",NULL},
/* 1110B */ { "LETTRE CHAKMA NGÂ",NULL},
/* 1110C */ { "LETTRE CHAKMA TCHÂ",NULL},
/* 1110D */ { "LETTRE CHAKMA TCHHÂ",NULL},
/* 1110E */ { "LETTRE CHAKMA DJÂ",NULL},
/* 1110F */ { "LETTRE CHAKMA DJHÂ",NULL},
/* 11110 */ { "LETTRE CHAKMA ÑÂ",NULL},
/* 11111 */ { "LETTRE CHAKMA TTÂ",NULL},
/* 11112 */ { "LETTRE CHAKMA TTHÂ",NULL},
/* 11113 */ { "LETTRE CHAKMA DDÂ",NULL},
/* 11114 */ { "LETTRE CHAKMA DDHÂ",NULL},
/* 11115 */ { "LETTRE CHAKMA NNÂ",NULL},
/* 11116 */ { "LETTRE CHAKMA TÂ",NULL},
/* 11117 */ { "LETTRE CHAKMA THÂ",NULL},
/* 11118 */ { "LETTRE CHAKMA DÂ",NULL},
/* 11119 */ { "LETTRE CHAKMA DHÂ",NULL},
/* 1111A */ { "LETTRE CHAKMA NÂ",NULL},
/* 1111B */ { "LETTRE CHAKMA PÂ",NULL},
/* 1111C */ { "LETTRE CHAKMA PHÂ",NULL},
/* 1111D */ { "LETTRE CHAKMA BÂ",NULL},
/* 1111E */ { "LETTRE CHAKMA BHÂ",NULL},
/* 1111F */ { "LETTRE CHAKMA MÂ",NULL},
/* 11120 */ { "LETTRE CHAKMA YYÂ",NULL},
/* 11121 */ { "LETTRE CHAKMA YÂ",NULL},
/* 11122 */ { "LETTRE CHAKMA RÂ",NULL},
/* 11123 */ { "LETTRE CHAKMA LÂ",NULL},
/* 11124 */ { "LETTRE CHAKMA WÂ",NULL},
/* 11125 */ { "LETTRE CHAKMA SÂ",NULL},
/* 11126 */ { "LETTRE CHAKMA HÂ",NULL},
/* 11127 */ { "DIACRITIQUE VOYELLE CHAKMA A",NULL},
/* 11128 */ { "DIACRITIQUE VOYELLE CHAKMA I",NULL},
/* 11129 */ { "DIACRITIQUE VOYELLE CHAKMA Î",NULL},
/* 1112A */ { "DIACRITIQUE VOYELLE CHAKMA OU",NULL},
/* 1112B */ { "DIACRITIQUE VOYELLE CHAKMA OÛ",NULL},
/* 1112C */ { "DIACRITIQUE VOYELLE CHAKMA É",NULL},
/* 1112D */ { "DIACRITIQUE VOYELLE CHAKMA AI",NULL},
/* 1112E */ { "DIACRITIQUE VOYELLE CHAKMA O","	: 11131 11127"},
/* 1112F */ { "DIACRITIQUE VOYELLE CHAKMA AOU","	: 11132 11127"},
/* 11130 */ { "DIACRITIQUE VOYELLE CHAKMA OÏ",NULL},
/* 11131 */ { "DIACRITIQUE CHAKMA O",NULL},
/* 11132 */ { "DIACRITIQUE CHAKMA AOU",NULL},
/* 11133 */ { "DIACRITIQUE CHAKMA VIRÂMA","	* s'utilise pour former des ligatures\n"
	"	x (diacritique birman virâma - 1039)"},
/* 11134 */ { "DIACRITIQUE CHAKMA MÂYYÂ","	* signe « tueur »\n"
	"	* s'utilise aussi séparément comme une marque de gémination qui peut se présenter avec les voyelles\n"
	"	x (diacritique birman asat - 103A)"},
/* 11135 */ { NULL,NULL},
/* 11136 */ { "CHIFFRE CHAKMA ZÉRO",NULL},
/* 11137 */ { "CHIFFRE CHAKMA UN",NULL},
/* 11138 */ { "CHIFFRE CHAKMA DEUX",NULL},
/* 11139 */ { "CHIFFRE CHAKMA TROIS",NULL},
/* 1113A */ { "CHIFFRE CHAKMA QUATRE",NULL},
/* 1113B */ { "CHIFFRE CHAKMA CINQ",NULL},
/* 1113C */ { "CHIFFRE CHAKMA SIX",NULL},
/* 1113D */ { "CHIFFRE CHAKMA SEPT",NULL},
/* 1113E */ { "CHIFFRE CHAKMA HUIT",NULL},
/* 1113F */ { "CHIFFRE CHAKMA NEUF",NULL},
/* 11140 */ { "FIN DE PHRASE CHAKMA",NULL},
/* 11141 */ { "DANDA CHAKMA",NULL},
/* 11142 */ { "DOUBLE DANDA CHAKMA",NULL},
/* 11143 */ { "POINT D'INTERROGATION CHAKMA",NULL},
/* 11144 */ { "LETTRE CHAKMA LHÂ",NULL},
/* 11145 */ { "DIACRITIQUE VOYELLE CHAKMA Â",NULL},
/* 11146 */ { "DIACRITIQUE VOYELLE CHAKMA EI",NULL},
/* 11147 */ { "LETTRE CHAKMA VÂ","	= va\n"
	"	* utilisée dans des textes en pali"},
/* 11148 */ { NULL,NULL},
/* 11149 */ { NULL,NULL},
/* 1114A */ { NULL,NULL},
/* 1114B */ { NULL,NULL},
/* 1114C */ { NULL,NULL},
/* 1114D */ { NULL,NULL},
/* 1114E */ { NULL,NULL},
/* 1114F */ { NULL,NULL},
/* 11150 */ { "LETTRE MAHAJANI A",NULL},
/* 11151 */ { "LETTRE MAHAJANI I",NULL},
/* 11152 */ { "LETTRE MAHAJANI OU",NULL},
/* 11153 */ { "LETTRE MAHAJANI É",NULL},
/* 11154 */ { "LETTRE MAHAJANI O",NULL},
/* 11155 */ { "LETTRE MAHAJANI KA",NULL},
/* 11156 */ { "LETTRE MAHAJANI KHA",NULL},
/* 11157 */ { "LETTRE MAHAJANI GA",NULL},
/* 11158 */ { "LETTRE MAHAJANI GHA",NULL},
/* 11159 */ { "LETTRE MAHAJANI TCHA",NULL},
/* 1115A */ { "LETTRE MAHAJANI TCHHA",NULL},
/* 1115B */ { "LETTRE MAHAJANI DJA",NULL},
/* 1115C */ { "LETTRE MAHAJANI DJHA",NULL},
/* 1115D */ { "LETTRE MAHAJANI ÑA",NULL},
/* 1115E */ { "LETTRE MAHAJANI TTA",NULL},
/* 1115F */ { "LETTRE MAHAJANI TTHA",NULL},
/* 11160 */ { "LETTRE MAHAJANI DDA",NULL},
/* 11161 */ { "LETTRE MAHAJANI DDHA",NULL},
/* 11162 */ { "LETTRE MAHAJANI NNA",NULL},
/* 11163 */ { "LETTRE MAHAJANI TA",NULL},
/* 11164 */ { "LETTRE MAHAJANI THA",NULL},
/* 11165 */ { "LETTRE MAHAJANI DA",NULL},
/* 11166 */ { "LETTRE MAHAJANI DHA",NULL},
/* 11167 */ { "LETTRE MAHAJANI NA",NULL},
/* 11168 */ { "LETTRE MAHAJANI PA",NULL},
/* 11169 */ { "LETTRE MAHAJANI PHA","	= lettre mahajani p'a"},
/* 1116A */ { "LETTRE MAHAJANI BA",NULL},
/* 1116B */ { "LETTRE MAHAJANI BHA",NULL},
/* 1116C */ { "LETTRE MAHAJANI MA",NULL},
/* 1116D */ { "LETTRE MAHAJANI RA",NULL},
/* 1116E */ { "LETTRE MAHAJANI LA",NULL},
/* 1116F */ { "LETTRE MAHAJANI VA",NULL},
/* 11170 */ { "LETTRE MAHAJANI SA",NULL},
/* 11171 */ { "LETTRE MAHAJANI HA",NULL},
/* 11172 */ { "LETTRE MAHAJANI RRA",NULL},
/* 11173 */ { "DIACRITIQUE MAHAJANI NOUKTA",NULL},
/* 11174 */ { "SIGNE D'ABRÉVIATION MAHAJANI",NULL},
/* 11175 */ { "REPÈRE DE SECTION MAHAJANI",NULL},
/* 11176 */ { "LIGATURE MAHAJANI ÇRI",NULL},
/* 11177 */ { NULL,NULL},
/* 11178 */ { NULL,NULL},
/* 11179 */ { NULL,NULL},
/* 1117A */ { NULL,NULL},
/* 1117B */ { NULL,NULL},
/* 1117C */ { NULL,NULL},
/* 1117D */ { NULL,NULL},
/* 1117E */ { NULL,NULL},
/* 1117F */ { NULL,NULL},
/* 11180 */ { "DIACRITIQUE CHARADA TCHANDRABINDOU",NULL},
/* 11181 */ { "DIACRITIQUE CHARADA ANOUSVÂRA",NULL},
/* 11182 */ { "DIACRITIQUE CHARADA VISARGA",NULL},
/* 11183 */ { "LETTRE CHARADA A",NULL},
/* 11184 */ { "LETTRE CHARADA Â",NULL},
/* 11185 */ { "LETTRE CHARADA I",NULL},
/* 11186 */ { "LETTRE CHARADA Î",NULL},
/* 11187 */ { "LETTRE CHARADA OU",NULL},
/* 11188 */ { "LETTRE CHARADA OÛ",NULL},
/* 11189 */ { "LETTRE CHARADA R VOCALIQUE",NULL},
/* 1118A */ { "LETTRE CHARADA RR VOCALIQUE",NULL},
/* 1118B */ { "LETTRE CHARADA L VOCALIQUE",NULL},
/* 1118C */ { "LETTRE CHARADA LL VOCALIQUE",NULL},
/* 1118D */ { "LETTRE CHARADA É",NULL},
/* 1118E */ { "LETTRE CHARADA AI",NULL},
/* 1118F */ { "LETTRE CHARADA O",NULL},
/* 11190 */ { "LETTRE CHARADA AOU",NULL},
/* 11191 */ { "LETTRE CHARADA KA",NULL},
/* 11192 */ { "LETTRE CHARADA KHA",NULL},
/* 11193 */ { "LETTRE CHARADA GA",NULL},
/* 11194 */ { "LETTRE CHARADA GHA",NULL},
/* 11195 */ { "LETTRE CHARADA NGA",NULL},
/* 11196 */ { "LETTRE CHARADA TCHA",NULL},
/* 11197 */ { "LETTRE CHARADA TCHHA",NULL},
/* 11198 */ { "LETTRE CHARADA DJA",NULL},
/* 11199 */ { "LETTRE CHARADA DJHA",NULL},
/* 1119A */ { "LETTRE CHARADA ÑA",NULL},
/* 1119B */ { "LETTRE CHARADA TTA",NULL},
/* 1119C */ { "LETTRE CHARADA TTHA",NULL},
/* 1119D */ { "LETTRE CHARADA DDA",NULL},
/* 1119E */ { "LETTRE CHARADA DDHA",NULL},
/* 1119F */ { "LETTRE CHARADA NNA",NULL},
/* 111A0 */ { "LETTRE CHARADA TA",NULL},
/* 111A1 */ { "LETTRE CHARADA THA",NULL},
/* 111A2 */ { "LETTRE CHARADA DA",NULL},
/* 111A3 */ { "LETTRE CHARADA DHA",NULL},
/* 111A4 */ { "LETTRE CHARADA NA",NULL},
/* 111A5 */ { "LETTRE CHARADA PA",NULL},
/* 111A6 */ { "LETTRE CHARADA PHA","	= lettre charada p'a"},
/* 111A7 */ { "LETTRE CHARADA BA",NULL},
/* 111A8 */ { "LETTRE CHARADA BHA",NULL},
/* 111A9 */ { "LETTRE CHARADA MA",NULL},
/* 111AA */ { "LETTRE CHARADA YA",NULL},
/* 111AB */ { "LETTRE CHARADA RA",NULL},
/* 111AC */ { "LETTRE CHARADA LA",NULL},
/* 111AD */ { "LETTRE CHARADA LLA",NULL},
/* 111AE */ { "LETTRE CHARADA VA",NULL},
/* 111AF */ { "LETTRE CHARADA ÇA",NULL},
/* 111B0 */ { "LETTRE CHARADA CHA",NULL},
/* 111B1 */ { "LETTRE CHARADA SA",NULL},
/* 111B2 */ { "LETTRE CHARADA HA",NULL},
/* 111B3 */ { "DIACRITIQUE VOYELLE CHARADA Â",NULL},
/* 111B4 */ { "DIACRITIQUE VOYELLE CHARADA I",NULL},
/* 111B5 */ { "DIACRITIQUE VOYELLE CHARADA Î",NULL},
/* 111B6 */ { "DIACRITIQUE VOYELLE CHARADA OU",NULL},
/* 111B7 */ { "DIACRITIQUE VOYELLE CHARADA OÛ",NULL},
/* 111B8 */ { "DIACRITIQUE VOYELLE CHARADA R VOCALIQUE",NULL},
/* 111B9 */ { "DIACRITIQUE VOYELLE CHARADA RR VOCALIQUE",NULL},
/* 111BA */ { "DIACRITIQUE VOYELLE CHARADA L VOCALIQUE",NULL},
/* 111BB */ { "DIACRITIQUE VOYELLE CHARADA LL VOCALIQUE",NULL},
/* 111BC */ { "DIACRITIQUE VOYELLE CHARADA É",NULL},
/* 111BD */ { "DIACRITIQUE VOYELLE CHARADA AI",NULL},
/* 111BE */ { "DIACRITIQUE VOYELLE CHARADA O",NULL},
/* 111BF */ { "DIACRITIQUE VOYELLE CHARADA AOU",NULL},
/* 111C0 */ { "DIACRITIQUE CHARADA VIRÂMA",NULL},
/* 111C1 */ { "SIGNE CHARADA AVAGRAHA",NULL},
/* 111C2 */ { "SIGNE CHARADA DJIHVAMOULIYA",NULL},
/* 111C3 */ { "SIGNE CHARADA OUPADHMANIYA",NULL},
/* 111C4 */ { "OM CHARADA","	* l'utilisation de ce caractère est déconseillée\n"
	"	* la séquence recommandée est 1118F 11180"},
/* 111C5 */ { "DANDA CHARADA",NULL},
/* 111C6 */ { "DOUBLE DANDA CHARADA",NULL},
/* 111C7 */ { "SIGNE D'ABRÉVIATION CHARADA",NULL},
/* 111C8 */ { "SÉPARATEUR CHARADA",NULL},
/* 111C9 */ { "SIGNE CHARADA SANDHI","	* indique le sandhi externe dans les documents en sanskrit\n"
	"	x (signe bengali sandhi - 09FE)"},
/* 111CA */ { "DIACRITIQUE CHARADA NOUKTA","	* pour étendre l'alphabet et former de nouvelles lettres"},
/* 111CB */ { "DIACRITIQUE CHARADA MODIFICATEUR DE VOYELLE","	* représente la métaphonie régressive"},
/* 111CC */ { "DIACRITIQUE CHARADA DE VOYELLE TRÈS COURTE","	* s'utilise pour l'écriture des matras"},
/* 111CD */ { "SIGNE CHARADA SOUTRA","	* utilisé pour marquer la fin d'un soutra dans le manuscrit de Bakhshali"},
/* 111CE */ { "DIACRITIQUE VOYELLE CHARADA E PRISHTHAMATRA","	x (diacritique voyelle dévanâgarî é prishthamatra - 094E)"},
/* 111CF */ { "DIACRITIQUE CHARADA TCHANDRABINDOU RENVERSÉ",NULL},
/* 111D0 */ { "CHIFFRE CHARADA ZÉRO",NULL},
/* 111D1 */ { "CHIFFRE CHARADA UN",NULL},
/* 111D2 */ { "CHIFFRE CHARADA DEUX",NULL},
/* 111D3 */ { "CHIFFRE CHARADA TROIS",NULL},
/* 111D4 */ { "CHIFFRE CHARADA QUATRE",NULL},
/* 111D5 */ { "CHIFFRE CHARADA CINQ",NULL},
/* 111D6 */ { "CHIFFRE CHARADA SIX",NULL},
/* 111D7 */ { "CHIFFRE CHARADA SEPT",NULL},
/* 111D8 */ { "CHIFFRE CHARADA HUIT",NULL},
/* 111D9 */ { "CHIFFRE CHARADA NEUF",NULL},
/* 111DA */ { "ÉKAM CHARADA","	* symbole d'invocation utilisé au début ou à la fin des textes"},
/* 111DB */ { "SIGNE CHARADA SIDDHAM","	= siddhirastou\n"
	"	* placé au début d'un texte comme une invocation\n"
	"	x (signe kannara siddham - 0C84)\n"
	"	x (signe dévanâgarî siddham - A8FC)"},
/* 111DC */ { "BARRE DE TÊTE CHARADA","	* permet de joindre les mots tout en indiquant les lacunes (dans les transcriptions de manuscrits)\n"
	"	x (barre de tête dévanâgarî - A8FB)"},
/* 111DD */ { "SIGNE CHARADA DE CONTINUATION","	* indique une possibilité de coupure dans un mot"},
/* 111DE */ { "FIN DE SECTION-1 CHARADA",NULL},
/* 111DF */ { "FIN DE SECTION-2 CHARADA",NULL},
/* 111E0 */ { NULL,NULL},
/* 111E1 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS UN",NULL},
/* 111E2 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS DEUX",NULL},
/* 111E3 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS TROIS",NULL},
/* 111E4 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS QUATRE",NULL},
/* 111E5 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS CINQ",NULL},
/* 111E6 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS SIX",NULL},
/* 111E7 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS SEPT",NULL},
/* 111E8 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS HUIT",NULL},
/* 111E9 */ { "CHIFFRE ARCHAÏQUE SINGHALAIS NEUF",NULL},
/* 111EA */ { "NOMBRE ARCHAÏQUE SINGHALAIS DIX",NULL},
/* 111EB */ { "NOMBRE ARCHAÏQUE SINGHALAIS VINGT",NULL},
/* 111EC */ { "NOMBRE ARCHAÏQUE SINGHALAIS TRENTE",NULL},
/* 111ED */ { "NOMBRE ARCHAÏQUE SINGHALAIS QUARANTE",NULL},
/* 111EE */ { "NOMBRE ARCHAÏQUE SINGHALAIS CINQUANTE",NULL},
/* 111EF */ { "NOMBRE ARCHAÏQUE SINGHALAIS SOIXANTE",NULL},
/* 111F0 */ { "NOMBRE ARCHAÏQUE SINGHALAIS SOIXANTE-DIX","	= nombre archaïque singhalais septante"},
/* 111F1 */ { "NOMBRE ARCHAÏQUE SINGHALAIS QUATRE-VINGTS","	= nombre archaïque singhalais huitante"},
/* 111F2 */ { "NOMBRE ARCHAÏQUE SINGHALAIS QUATRE-VINGT-DIX","	= nombre archaïque singhalais nonante"},
/* 111F3 */ { "NOMBRE ARCHAÏQUE SINGHALAIS CENT",NULL},
/* 111F4 */ { "NOMBRE ARCHAÏQUE SINGHALAIS MILLE",NULL},
/* 111F5 */ { NULL,NULL},
/* 111F6 */ { NULL,NULL},
/* 111F7 */ { NULL,NULL},
/* 111F8 */ { NULL,NULL},
/* 111F9 */ { NULL,NULL},
/* 111FA */ { NULL,NULL},
/* 111FB */ { NULL,NULL},
/* 111FC */ { NULL,NULL},
/* 111FD */ { NULL,NULL},
/* 111FE */ { NULL,NULL},
/* 111FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_12[] = {
/* 11200 */ { "LETTRE KHOJKI A",NULL},
/* 11201 */ { "LETTRE KHOJKI Â",NULL},
/* 11202 */ { "LETTRE KHOJKI I",NULL},
/* 11203 */ { "LETTRE KHOJKI OU",NULL},
/* 11204 */ { "LETTRE KHOJKI É",NULL},
/* 11205 */ { "LETTRE KHOJKI AI",NULL},
/* 11206 */ { "LETTRE KHOJKI O",NULL},
/* 11207 */ { "LETTRE KHOJKI AOU",NULL},
/* 11208 */ { "LETTRE KHOJKI KA",NULL},
/* 11209 */ { "LETTRE KHOJKI KHA",NULL},
/* 1120A */ { "LETTRE KHOJKI GA",NULL},
/* 1120B */ { "LETTRE KHOJKI GGA",NULL},
/* 1120C */ { "LETTRE KHOJKI GHA",NULL},
/* 1120D */ { "LETTRE KHOJKI NGA",NULL},
/* 1120E */ { "LETTRE KHOJKI TCHA",NULL},
/* 1120F */ { "LETTRE KHOJKI TCHHA",NULL},
/* 11210 */ { "LETTRE KHOJKI DJA",NULL},
/* 11211 */ { "LETTRE KHOJKI DJJA",NULL},
/* 11212 */ { NULL,NULL},
/* 11213 */ { "LETTRE KHOJKI ÑA",NULL},
/* 11214 */ { "LETTRE KHOJKI TTA",NULL},
/* 11215 */ { "LETTRE KHOJKI TTHA",NULL},
/* 11216 */ { "LETTRE KHOJKI DDA",NULL},
/* 11217 */ { "LETTRE KHOJKI DDHA",NULL},
/* 11218 */ { "LETTRE KHOJKI NNA",NULL},
/* 11219 */ { "LETTRE KHOJKI TA",NULL},
/* 1121A */ { "LETTRE KHOJKI THA",NULL},
/* 1121B */ { "LETTRE KHOJKI DA",NULL},
/* 1121C */ { "LETTRE KHOJKI DDDA",NULL},
/* 1121D */ { "LETTRE KHOJKI DHA",NULL},
/* 1121E */ { "LETTRE KHOJKI NA",NULL},
/* 1121F */ { "LETTRE KHOJKI PA",NULL},
/* 11220 */ { "LETTRE KHOJKI PHA","	= lettre khojki p'a"},
/* 11221 */ { "LETTRE KHOJKI BA",NULL},
/* 11222 */ { "LETTRE KHOJKI BBA",NULL},
/* 11223 */ { "LETTRE KHOJKI BHA",NULL},
/* 11224 */ { "LETTRE KHOJKI MA",NULL},
/* 11225 */ { "LETTRE KHOJKI YA",NULL},
/* 11226 */ { "LETTRE KHOJKI RA",NULL},
/* 11227 */ { "LETTRE KHOJKI LA",NULL},
/* 11228 */ { "LETTRE KHOJKI VA",NULL},
/* 11229 */ { "LETTRE KHOJKI SA",NULL},
/* 1122A */ { "LETTRE KHOJKI HA",NULL},
/* 1122B */ { "LETTRE KHOJKI LLA",NULL},
/* 1122C */ { "DIACRITIQUE VOYELLE KHOJKI Â",NULL},
/* 1122D */ { "DIACRITIQUE VOYELLE KHOJKI I",NULL},
/* 1122E */ { "DIACRITIQUE VOYELLE KHOJKI Î",NULL},
/* 1122F */ { "DIACRITIQUE VOYELLE KHOJKI OU",NULL},
/* 11230 */ { "DIACRITIQUE VOYELLE KHOJKI É",NULL},
/* 11231 */ { "DIACRITIQUE VOYELLE KHOJKI AI",NULL},
/* 11232 */ { "DIACRITIQUE VOYELLE KHOJKI O",NULL},
/* 11233 */ { "DIACRITIQUE VOYELLE KHOJKI AOU",NULL},
/* 11234 */ { "DIACRITIQUE KHOJKI ANOUSVÂRA",NULL},
/* 11235 */ { "DIACRITIQUE KHOJKI VIRÂMA",NULL},
/* 11236 */ { "DIACRITIQUE KHOJKI NOUKTA",NULL},
/* 11237 */ { "DIACRITIQUE KHOJKI ÇADDA",NULL},
/* 11238 */ { "DANDA KHOJKI",NULL},
/* 11239 */ { "DOUBLE DANDA KHOJKI",NULL},
/* 1123A */ { "SÉPARATEUR DE MOTS KHOJKI",NULL},
/* 1123B */ { "REPÈRE DE SECTION KHOJKI","	* marque la fin d'une phrase\n"
	"	x (repère de section kayathi - 110BE)"},
/* 1123C */ { "REPÈRE DE SECTION DOUBLE KHOJKI","	* délimite des parties plus larges d'un texte, comme les paragraphes\n"
	"	x (repère de section double kayathi - 110BF)"},
/* 1123D */ { "SIGNE D'ABRÉVIATION KHOJKI",NULL},
/* 1123E */ { "DIACRITIQUE KHOJKI SOUKOUN","	* utilisé pour la translittération de l'arabe"},
/* 1123F */ { "LETTRE KHOJKI QA",NULL},
/* 11240 */ { "LETTRE KHOJKI I BREF",NULL},
/* 11241 */ { "DIACRITIQUE VOYELLE KHOJKI R VOCALIQUE",NULL},
/* 11242 */ { NULL,NULL},
/* 11243 */ { NULL,NULL},
/* 11244 */ { NULL,NULL},
/* 11245 */ { NULL,NULL},
/* 11246 */ { NULL,NULL},
/* 11247 */ { NULL,NULL},
/* 11248 */ { NULL,NULL},
/* 11249 */ { NULL,NULL},
/* 1124A */ { NULL,NULL},
/* 1124B */ { NULL,NULL},
/* 1124C */ { NULL,NULL},
/* 1124D */ { NULL,NULL},
/* 1124E */ { NULL,NULL},
/* 1124F */ { NULL,NULL},
/* 11250 */ { NULL,NULL},
/* 11251 */ { NULL,NULL},
/* 11252 */ { NULL,NULL},
/* 11253 */ { NULL,NULL},
/* 11254 */ { NULL,NULL},
/* 11255 */ { NULL,NULL},
/* 11256 */ { NULL,NULL},
/* 11257 */ { NULL,NULL},
/* 11258 */ { NULL,NULL},
/* 11259 */ { NULL,NULL},
/* 1125A */ { NULL,NULL},
/* 1125B */ { NULL,NULL},
/* 1125C */ { NULL,NULL},
/* 1125D */ { NULL,NULL},
/* 1125E */ { NULL,NULL},
/* 1125F */ { NULL,NULL},
/* 11260 */ { NULL,NULL},
/* 11261 */ { NULL,NULL},
/* 11262 */ { NULL,NULL},
/* 11263 */ { NULL,NULL},
/* 11264 */ { NULL,NULL},
/* 11265 */ { NULL,NULL},
/* 11266 */ { NULL,NULL},
/* 11267 */ { NULL,NULL},
/* 11268 */ { NULL,NULL},
/* 11269 */ { NULL,NULL},
/* 1126A */ { NULL,NULL},
/* 1126B */ { NULL,NULL},
/* 1126C */ { NULL,NULL},
/* 1126D */ { NULL,NULL},
/* 1126E */ { NULL,NULL},
/* 1126F */ { NULL,NULL},
/* 11270 */ { NULL,NULL},
/* 11271 */ { NULL,NULL},
/* 11272 */ { NULL,NULL},
/* 11273 */ { NULL,NULL},
/* 11274 */ { NULL,NULL},
/* 11275 */ { NULL,NULL},
/* 11276 */ { NULL,NULL},
/* 11277 */ { NULL,NULL},
/* 11278 */ { NULL,NULL},
/* 11279 */ { NULL,NULL},
/* 1127A */ { NULL,NULL},
/* 1127B */ { NULL,NULL},
/* 1127C */ { NULL,NULL},
/* 1127D */ { NULL,NULL},
/* 1127E */ { NULL,NULL},
/* 1127F */ { NULL,NULL},
/* 11280 */ { "LETTRE MULTANAISE A",NULL},
/* 11281 */ { "LETTRE MULTANAISE I",NULL},
/* 11282 */ { "LETTRE MULTANAISE OU",NULL},
/* 11283 */ { "LETTRE MULTANAISE É",NULL},
/* 11284 */ { "LETTRE MULTANAISE KA",NULL},
/* 11285 */ { "LETTRE MULTANAISE KHA",NULL},
/* 11286 */ { "LETTRE MULTANAISE GA",NULL},
/* 11287 */ { NULL,NULL},
/* 11288 */ { "LETTRE MULTANAISE GHA",NULL},
/* 11289 */ { NULL,NULL},
/* 1128A */ { "LETTRE MULTANAISE TCHA",NULL},
/* 1128B */ { "LETTRE MULTANAISE TCHHA",NULL},
/* 1128C */ { "LETTRE MULTANAISE DJA",NULL},
/* 1128D */ { "LETTRE MULTANAISE DJJA",NULL},
/* 1128E */ { NULL,NULL},
/* 1128F */ { "LETTRE MULTANAISE ÑA",NULL},
/* 11290 */ { "LETTRE MULTANAISE TTA",NULL},
/* 11291 */ { "LETTRE MULTANAISE TTHA",NULL},
/* 11292 */ { "LETTRE MULTANAISE DDA",NULL},
/* 11293 */ { "LETTRE MULTANAISE DDDA","	= tra"},
/* 11294 */ { "LETTRE MULTANAISE DDHA",NULL},
/* 11295 */ { "LETTRE MULTANAISE NNA",NULL},
/* 11296 */ { "LETTRE MULTANAISE TA",NULL},
/* 11297 */ { "LETTRE MULTANAISE THA",NULL},
/* 11298 */ { "LETTRE MULTANAISE DA",NULL},
/* 11299 */ { "LETTRE MULTANAISE DHA",NULL},
/* 1129A */ { "LETTRE MULTANAISE NA",NULL},
/* 1129B */ { "LETTRE MULTANAISE PA",NULL},
/* 1129C */ { "LETTRE MULTANAISE PHA","	= lettre multanaise p'a"},
/* 1129D */ { "LETTRE MULTANAISE BA",NULL},
/* 1129E */ { NULL,NULL},
/* 1129F */ { "LETTRE MULTANAISE BHA",NULL},
/* 112A0 */ { "LETTRE MULTANAISE MA",NULL},
/* 112A1 */ { "LETTRE MULTANAISE YA",NULL},
/* 112A2 */ { "LETTRE MULTANAISE RA",NULL},
/* 112A3 */ { "LETTRE MULTANAISE LA",NULL},
/* 112A4 */ { "LETTRE MULTANAISE VA",NULL},
/* 112A5 */ { "LETTRE MULTANAISE SA",NULL},
/* 112A6 */ { "LETTRE MULTANAISE HA",NULL},
/* 112A7 */ { "LETTRE MULTANAISE RRA",NULL},
/* 112A8 */ { "LETTRE MULTANAISE RHA",NULL},
/* 112A9 */ { "REPÈRE DE SECTION MULTANAIS",NULL},
/* 112AA */ { NULL,NULL},
/* 112AB */ { NULL,NULL},
/* 112AC */ { NULL,NULL},
/* 112AD */ { NULL,NULL},
/* 112AE */ { NULL,NULL},
/* 112AF */ { NULL,NULL},
/* 112B0 */ { "LETTRE KHUDAWADI A",NULL},
/* 112B1 */ { "LETTRE KHUDAWADI Â",NULL},
/* 112B2 */ { "LETTRE KHUDAWADI I",NULL},
/* 112B3 */ { "LETTRE KHUDAWADI Î",NULL},
/* 112B4 */ { "LETTRE KHUDAWADI OU",NULL},
/* 112B5 */ { "LETTRE KHUDAWADI OÛ",NULL},
/* 112B6 */ { "LETTRE KHUDAWADI É",NULL},
/* 112B7 */ { "LETTRE KHUDAWADI AI",NULL},
/* 112B8 */ { "LETTRE KHUDAWADI O",NULL},
/* 112B9 */ { "LETTRE KHUDAWADI AOU",NULL},
/* 112BA */ { "LETTRE KHUDAWADI KA",NULL},
/* 112BB */ { "LETTRE KHUDAWADI KHA",NULL},
/* 112BC */ { "LETTRE KHUDAWADI GA",NULL},
/* 112BD */ { "LETTRE KHUDAWADI GGA",NULL},
/* 112BE */ { "LETTRE KHUDAWADI GHA",NULL},
/* 112BF */ { "LETTRE KHUDAWADI NGA",NULL},
/* 112C0 */ { "LETTRE KHUDAWADI TCHA",NULL},
/* 112C1 */ { "LETTRE KHUDAWADI TCHHA",NULL},
/* 112C2 */ { "LETTRE KHUDAWADI DJA",NULL},
/* 112C3 */ { "LETTRE KHUDAWADI DJJA",NULL},
/* 112C4 */ { "LETTRE KHUDAWADI DJHA",NULL},
/* 112C5 */ { "LETTRE KHUDAWADI ÑA",NULL},
/* 112C6 */ { "LETTRE KHUDAWADI TTA",NULL},
/* 112C7 */ { "LETTRE KHUDAWADI TTHA",NULL},
/* 112C8 */ { "LETTRE KHUDAWADI DDA",NULL},
/* 112C9 */ { "LETTRE KHUDAWADI DDDA",NULL},
/* 112CA */ { "LETTRE KHUDAWADI RRA",NULL},
/* 112CB */ { "LETTRE KHUDAWADI DDHA",NULL},
/* 112CC */ { "LETTRE KHUDAWADI NNA",NULL},
/* 112CD */ { "LETTRE KHUDAWADI TA",NULL},
/* 112CE */ { "LETTRE KHUDAWADI THA",NULL},
/* 112CF */ { "LETTRE KHUDAWADI DA",NULL},
/* 112D0 */ { "LETTRE KHUDAWADI DHA",NULL},
/* 112D1 */ { "LETTRE KHUDAWADI NA",NULL},
/* 112D2 */ { "LETTRE KHUDAWADI PA",NULL},
/* 112D3 */ { "LETTRE KHUDAWADI PHA","	= lettre khudawadi p'a"},
/* 112D4 */ { "LETTRE KHUDAWADI BA",NULL},
/* 112D5 */ { "LETTRE KHUDAWADI BBA",NULL},
/* 112D6 */ { "LETTRE KHUDAWADI BHA",NULL},
/* 112D7 */ { "LETTRE KHUDAWADI MA",NULL},
/* 112D8 */ { "LETTRE KHUDAWADI YA",NULL},
/* 112D9 */ { "LETTRE KHUDAWADI RA",NULL},
/* 112DA */ { "LETTRE KHUDAWADI LA",NULL},
/* 112DB */ { "LETTRE KHUDAWADI VA",NULL},
/* 112DC */ { "LETTRE KHUDAWADI ÇA",NULL},
/* 112DD */ { "LETTRE KHUDAWADI SA",NULL},
/* 112DE */ { "LETTRE KHUDAWADI HA",NULL},
/* 112DF */ { "DIACRITIQUE KHUDAWADI ANOUSVÂRA",NULL},
/* 112E0 */ { "DIACRITIQUE VOYELLE KHUDAWADI Â",NULL},
/* 112E1 */ { "DIACRITIQUE VOYELLE KHUDAWADI I",NULL},
/* 112E2 */ { "DIACRITIQUE VOYELLE KHUDAWADI Î",NULL},
/* 112E3 */ { "DIACRITIQUE VOYELLE KHUDAWADI OU",NULL},
/* 112E4 */ { "DIACRITIQUE VOYELLE KHUDAWADI OÛ",NULL},
/* 112E5 */ { "DIACRITIQUE VOYELLE KHUDAWADI É",NULL},
/* 112E6 */ { "DIACRITIQUE VOYELLE KHUDAWADI AI",NULL},
/* 112E7 */ { "DIACRITIQUE VOYELLE KHUDAWADI O",NULL},
/* 112E8 */ { "DIACRITIQUE VOYELLE KHUDAWADI AOU",NULL},
/* 112E9 */ { "DIACRITIQUE KHUDAWADI NOUKTA",NULL},
/* 112EA */ { "DIACRITIQUE KHUDAWADI VIRÂMA",NULL},
/* 112EB */ { NULL,NULL},
/* 112EC */ { NULL,NULL},
/* 112ED */ { NULL,NULL},
/* 112EE */ { NULL,NULL},
/* 112EF */ { NULL,NULL},
/* 112F0 */ { "CHIFFRE KHUDAWADI ZÉRO",NULL},
/* 112F1 */ { "CHIFFRE KHUDAWADIUN",NULL},
/* 112F2 */ { "CHIFFRE KHUDAWADI DEUX",NULL},
/* 112F3 */ { "CHIFFRE KHUDAWADI TROIS",NULL},
/* 112F4 */ { "CHIFFRE KHUDAWADI QUATRE",NULL},
/* 112F5 */ { "CHIFFRE KHUDAWADI CINQ",NULL},
/* 112F6 */ { "CHIFFRE KHUDAWADI SIX",NULL},
/* 112F7 */ { "CHIFFRE KHUDAWADI SEPT",NULL},
/* 112F8 */ { "CHIFFRE KHUDAWADI HUIT",NULL},
/* 112F9 */ { "CHIFFRE KHUDAWADI NEUF",NULL},
/* 112FA */ { NULL,NULL},
/* 112FB */ { NULL,NULL},
/* 112FC */ { NULL,NULL},
/* 112FD */ { NULL,NULL},
/* 112FE */ { NULL,NULL},
/* 112FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_13[] = {
/* 11300 */ { "DIACRITIQUE GRANTHA ANOUSVÂRA SUSCRIT","	* utilisé dans des textes jaïniques en langue prâkrit pour l'anousvâra linguistique"},
/* 11301 */ { "DIACRITIQUE GRANTHA TCHANDRABINDOU",NULL},
/* 11302 */ { "DIACRITIQUE GRANTHA ANOUSVÂRA","	* utilisé dans des textes jaïniques en langue prâkrit pour indiquer la gémination de la consonne suivante"},
/* 11303 */ { "DIACRITIQUE GRANTHA VISARGA",NULL},
/* 11304 */ { NULL,NULL},
/* 11305 */ { "LETTRE GRANTHA A",NULL},
/* 11306 */ { "LETTRE GRANTHA Â",NULL},
/* 11307 */ { "LETTRE GRANTHA I",NULL},
/* 11308 */ { "LETTRE GRANTHA Î",NULL},
/* 11309 */ { "LETTRE GRANTHA OU",NULL},
/* 1130A */ { "LETTRE GRANTHA OÛ",NULL},
/* 1130B */ { "LETTRE GRANTHA R VOCALIQUE",NULL},
/* 1130C */ { "LETTRE GRANTHA L VOCALIQUE",NULL},
/* 1130D */ { NULL,NULL},
/* 1130E */ { NULL,NULL},
/* 1130F */ { "LETTRE GRANTHA ÉÉ",NULL},
/* 11310 */ { "LETTRE GRANTHA AI",NULL},
/* 11311 */ { NULL,NULL},
/* 11312 */ { NULL,NULL},
/* 11313 */ { "LETTRE GRANTHA Ô",NULL},
/* 11314 */ { "LETTRE GRANTHA AOU",NULL},
/* 11315 */ { "LETTRE GRANTHA KA",NULL},
/* 11316 */ { "LETTRE GRANTHA KHA",NULL},
/* 11317 */ { "LETTRE GRANTHA GA",NULL},
/* 11318 */ { "LETTRE GRANTHA GHA",NULL},
/* 11319 */ { "LETTRE GRANTHA NGA",NULL},
/* 1131A */ { "LETTRE GRANTHA TCHA",NULL},
/* 1131B */ { "LETTRE GRANTHA TCHHA",NULL},
/* 1131C */ { "LETTRE GRANTHA DJA",NULL},
/* 1131D */ { "LETTRE GRANTHA DJHA",NULL},
/* 1131E */ { "LETTRE GRANTHA ÑA",NULL},
/* 1131F */ { "LETTRE GRANTHA TTA",NULL},
/* 11320 */ { "LETTRE GRANTHA TTHA",NULL},
/* 11321 */ { "LETTRE GRANTHA DDA",NULL},
/* 11322 */ { "LETTRE GRANTHA DDHA",NULL},
/* 11323 */ { "LETTRE GRANTHA NNA",NULL},
/* 11324 */ { "LETTRE GRANTHA TA",NULL},
/* 11325 */ { "LETTRE GRANTHA THA",NULL},
/* 11326 */ { "LETTRE GRANTHA DA",NULL},
/* 11327 */ { "LETTRE GRANTHA DHA",NULL},
/* 11328 */ { "LETTRE GRANTHA NA",NULL},
/* 11329 */ { NULL,NULL},
/* 1132A */ { "LETTRE GRANTHA PA",NULL},
/* 1132B */ { "LETTRE GRANTHA PHA","	= lettre grantha p'a"},
/* 1132C */ { "LETTRE GRANTHA BA",NULL},
/* 1132D */ { "LETTRE GRANTHA BHA",NULL},
/* 1132E */ { "LETTRE GRANTHA MA",NULL},
/* 1132F */ { "LETTRE GRANTHA YA",NULL},
/* 11330 */ { "LETTRE GRANTHA RA",NULL},
/* 11331 */ { NULL,NULL},
/* 11332 */ { "LETTRE GRANTHA LA",NULL},
/* 11333 */ { "LETTRE GRANTHA LLA",NULL},
/* 11334 */ { NULL,NULL},
/* 11335 */ { "LETTRE GRANTHA VA",NULL},
/* 11336 */ { "LETTRE GRANTHA ÇA",NULL},
/* 11337 */ { "LETTRE GRANTHA CHA",NULL},
/* 11338 */ { "LETTRE GRANTHA SA",NULL},
/* 11339 */ { "LETTRE GRANTHA HA",NULL},
/* 1133A */ { NULL,NULL},
/* 1133B */ { "DIACRITIQUE BINDOU SOUSCRIT","	= vindou\n"
	"	* utilisé comme un noukta pour le betta kurumba et d'autres langues"},
/* 1133C */ { "DIACRITIQUE GRANTHA NOUKTA",NULL},
/* 1133D */ { "SIGNE GRANTHA AVAGRAHA",NULL},
/* 1133E */ { "DIACRITIQUE VOYELLE GRANTHA Â",NULL},
/* 1133F */ { "DIACRITIQUE VOYELLE GRANTHA I",NULL},
/* 11340 */ { "DIACRITIQUE VOYELLE GRANTHA Î",NULL},
/* 11341 */ { "DIACRITIQUE VOYELLE GRANTHA OU",NULL},
/* 11342 */ { "DIACRITIQUE VOYELLE GRANTHA OÛ",NULL},
/* 11343 */ { "DIACRITIQUE VOYELLE GRANTHA R VOCALIQUE",NULL},
/* 11344 */ { "DIACRITIQUE VOYELLE GRANTHA RR VOCALIQUE",NULL},
/* 11345 */ { NULL,NULL},
/* 11346 */ { NULL,NULL},
/* 11347 */ { "DIACRITIQUE VOYELLE GRANTHA ÉÉ",NULL},
/* 11348 */ { "DIACRITIQUE VOYELLE GRANTHA AI",NULL},
/* 11349 */ { NULL,NULL},
/* 1134A */ { NULL,NULL},
/* 1134B */ { "DIACRITIQUE VOYELLE GRANTHA Ô","	: 11347 1133E"},
/* 1134C */ { "DIACRITIQUE VOYELLE GRANTHA AOU","	: 11347 11357"},
/* 1134D */ { "DIACRITIQUE GRANTHA VIRÂMA",NULL},
/* 1134E */ { NULL,NULL},
/* 1134F */ { NULL,NULL},
/* 11350 */ { "OM GRANTHA",NULL},
/* 11351 */ { NULL,NULL},
/* 11352 */ { NULL,NULL},
/* 11353 */ { NULL,NULL},
/* 11354 */ { NULL,NULL},
/* 11355 */ { NULL,NULL},
/* 11356 */ { NULL,NULL},
/* 11357 */ { "SIGNE DE LONGUEUR GRANTHA AOU",NULL},
/* 11358 */ { NULL,NULL},
/* 11359 */ { NULL,NULL},
/* 1135A */ { NULL,NULL},
/* 1135B */ { NULL,NULL},
/* 1135C */ { NULL,NULL},
/* 1135D */ { "SIGNE GRANTHA PLOUTA","	* signe d'allongement de voyelle"},
/* 1135E */ { "LETTRE GRANTHA ANOUSVÂRA VÉDIQUE",NULL},
/* 1135F */ { "LETTRE GRANTHA DOUBLE ANOUSVÂRA VÉDIQUE",NULL},
/* 11360 */ { "LETTRE GRANTHA RR VOCALIQUE",NULL},
/* 11361 */ { "LETTRE GRANTHA LL VOCALIQUE",NULL},
/* 11362 */ { "DIACRITIQUE VOYELLE GRANTHA L VOCALIQUE",NULL},
/* 11363 */ { "DIACRITIQUE VOYELLE GRANTHA LL VOCALIQUE",NULL},
/* 11364 */ { NULL,NULL},
/* 11365 */ { NULL,NULL},
/* 11366 */ { "DIACRITIQUE CHIFFRE GRANTHA ZÉRO",NULL},
/* 11367 */ { "DIACRITIQUE CHIFFRE GRANTHA UN",NULL},
/* 11368 */ { "DIACRITIQUE CHIFFRE GRANTHA DEUX",NULL},
/* 11369 */ { "DIACRITIQUE CHIFFRE GRANTHA TROIS",NULL},
/* 1136A */ { "DIACRITIQUE CHIFFRE GRANTHA QUATRE",NULL},
/* 1136B */ { "DIACRITIQUE CHIFFRE GRANTHA CINQ",NULL},
/* 1136C */ { "DIACRITIQUE CHIFFRE GRANTHA SIX",NULL},
/* 1136D */ { NULL,NULL},
/* 1136E */ { NULL,NULL},
/* 1136F */ { NULL,NULL},
/* 11370 */ { "DIACRITIQUE LETTRE GRANTHA A",NULL},
/* 11371 */ { "DIACRITIQUE LETTRE GRANTHA KA",NULL},
/* 11372 */ { "DIACRITIQUE LETTRE GRANTHA NA",NULL},
/* 11373 */ { "DIACRITIQUE LETTRE GRANTHA VI",NULL},
/* 11374 */ { "DIACRITIQUE LETTRE GRANTHA PA",NULL},
/* 11375 */ { NULL,NULL},
/* 11376 */ { NULL,NULL},
/* 11377 */ { NULL,NULL},
/* 11378 */ { NULL,NULL},
/* 11379 */ { NULL,NULL},
/* 1137A */ { NULL,NULL},
/* 1137B */ { NULL,NULL},
/* 1137C */ { NULL,NULL},
/* 1137D */ { NULL,NULL},
/* 1137E */ { NULL,NULL},
/* 1137F */ { NULL,NULL},
/* 11380 */ { "LETTRE TOULOU-TIGALARI A",NULL},
/* 11381 */ { "LETTRE TOULOU-TIGALARI Â",NULL},
/* 11382 */ { "LETTRE TOULOU-TIGALARI I",NULL},
/* 11383 */ { "LETTRE TOULOU-TIGALARI Î","	: 11382 113C9"},
/* 11384 */ { "LETTRE TOULOU-TIGALARI OU",NULL},
/* 11385 */ { "LETTRE TOULOU-TIGALARI OÛ","	: 11384 113BB"},
/* 11386 */ { "LETTRE TOULOU-TIGALARI R VOCALIQUE",NULL},
/* 11387 */ { "LETTRE TOULOU-TIGALARI RR VOCALIQUE",NULL},
/* 11388 */ { "LETTRE TOULOU-TIGALARI L VOCALIQUE",NULL},
/* 11389 */ { "LETTRE TOULOU-TIGALARI LL VOCALIQUE",NULL},
/* 1138A */ { NULL,NULL},
/* 1138B */ { "LETTRE TOULOU-TIGALARI ÉÉ",NULL},
/* 1138C */ { NULL,NULL},
/* 1138D */ { NULL,NULL},
/* 1138E */ { "LETTRE TOULOU-TIGALARI AI","	: 1138B 113C2"},
/* 1138F */ { NULL,NULL},
/* 11390 */ { "LETTRE TOULOU-TIGALARI Ô",NULL},
/* 11391 */ { "LETTRE TOULOU-TIGALARI AOU","	: 11390 113C9"},
/* 11392 */ { "LETTRE TOULOU-TIGALARI KA",NULL},
/* 11393 */ { "LETTRE TOULOU-TIGALARI KHA",NULL},
/* 11394 */ { "LETTRE TOULOU-TIGALARI GA",NULL},
/* 11395 */ { "LETTRE TOULOU-TIGALARI GHA",NULL},
/* 11396 */ { "LETTRE TOULOU-TIGALARI NGA",NULL},
/* 11397 */ { "LETTRE TOULOU-TIGALARI TCHA",NULL},
/* 11398 */ { "LETTRE TOULOU-TIGALARI TCHHA",NULL},
/* 11399 */ { "LETTRE TOULOU-TIGALARI DJA",NULL},
/* 1139A */ { "LETTRE TOULOU-TIGALARI DJHA",NULL},
/* 1139B */ { "LETTRE TOULOU-TIGALARI ÑA",NULL},
/* 1139C */ { "LETTRE TOULOU-TIGALARI TTA",NULL},
/* 1139D */ { "LETTRE TOULOU-TIGALARI TTHA",NULL},
/* 1139E */ { "LETTRE TOULOU-TIGALARI DDA",NULL},
/* 1139F */ { "LETTRE TOULOU-TIGALARI DDHA",NULL},
/* 113A0 */ { "LETTRE TOULOU-TIGALARI NNA",NULL},
/* 113A1 */ { "LETTRE TOULOU-TIGALARI TA",NULL},
/* 113A2 */ { "LETTRE TOULOU-TIGALARI THA",NULL},
/* 113A3 */ { "LETTRE TOULOU-TIGALARI DA",NULL},
/* 113A4 */ { "LETTRE TOULOU-TIGALARI DHA",NULL},
/* 113A5 */ { "LETTRE TOULOU-TIGALARI NA",NULL},
/* 113A6 */ { "LETTRE TOULOU-TIGALARI PA",NULL},
/* 113A7 */ { "LETTRE TOULOU-TIGALARI PHA","	= lettre toulou-tigalari p'a"},
/* 113A8 */ { "LETTRE TOULOU-TIGALARI BA",NULL},
/* 113A9 */ { "LETTRE TOULOU-TIGALARI BHA",NULL},
/* 113AA */ { "LETTRE TOULOU-TIGALARI MA",NULL},
/* 113AB */ { "LETTRE TOULOU-TIGALARI YA",NULL},
/* 113AC */ { "LETTRE TOULOU-TIGALARI RA",NULL},
/* 113AD */ { "LETTRE TOULOU-TIGALARI LA",NULL},
/* 113AE */ { "LETTRE TOULOU-TIGALARI VA",NULL},
/* 113AF */ { "LETTRE TOULOU-TIGALARI ÇA",NULL},
/* 113B0 */ { "LETTRE TOULOU-TIGALARI CHA",NULL},
/* 113B1 */ { "LETTRE TOULOU-TIGALARI SA",NULL},
/* 113B2 */ { "LETTRE TOULOU-TIGALARI HA",NULL},
/* 113B3 */ { "LETTRE TOULOU-TIGALARI LLA",NULL},
/* 113B4 */ { "LETTRE TOULOU-TIGALARI RRA",NULL},
/* 113B5 */ { "LETTRE TOULOU-TIGALARI LLLA",NULL},
/* 113B6 */ { NULL,NULL},
/* 113B7 */ { "SIGNE TOULOU-TIGALARI AVAGRAHA",NULL},
/* 113B8 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI Â",NULL},
/* 113B9 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI I",NULL},
/* 113BA */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI Î",NULL},
/* 113BB */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI OU",NULL},
/* 113BC */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI OÛ",NULL},
/* 113BD */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI R VOCALIQUE",NULL},
/* 113BE */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI RR VOCALIQUE",NULL},
/* 113BF */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI L VOCALIQUE",NULL},
/* 113C0 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI LL VOCALIQUE",NULL},
/* 113C1 */ { NULL,NULL},
/* 113C2 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI ÉÉ",NULL},
/* 113C3 */ { NULL,NULL},
/* 113C4 */ { NULL,NULL},
/* 113C5 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI AI","	: 113C2 113C2"},
/* 113C6 */ { NULL,NULL},
/* 113C7 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI Ô","	: 113C2 113B8"},
/* 113C8 */ { "DIACRITIQUE VOYELLE TOULOU-TIGALARI AOU","	: 113C2 113C9"},
/* 113C9 */ { "SIGNE DE LONGUEUR TOULOU-TIGALARI AOU",NULL},
/* 113CA */ { "DIACRITIQUE TOULOU-TIGALARI CANDRA ANOUNASSIKA",NULL},
/* 113CB */ { NULL,NULL},
/* 113CC */ { "DIACRITIQUE TOULOU-TIGALARI ANOUSVÂRA",NULL},
/* 113CD */ { "DIACRITIQUE TOULOU-TIGALARI VISARGA",NULL},
/* 113CE */ { "DIACRITIQUE TOULOU-TIGALARI VIRÂMA",NULL},
/* 113CF */ { "DIACRITIQUE TOULOU-TIGALARI VIRÂMA BOUCLÉ",NULL},
/* 113D0 */ { "CONNECTEUR TOULOU-TIGALARI",NULL},
/* 113D1 */ { "REPHA TOULOU-TIGALARI",NULL},
/* 113D2 */ { "DIACRITIQUE TOULOU-TIGALARI DE GÉMINATION",NULL},
/* 113D3 */ { "SIGNE TOULOU-TIGALARI PLOUTA","	x (signe grantha plouta - 1135D)"},
/* 113D4 */ { "DANDA TOULOU-TIGALARI",NULL},
/* 113D5 */ { "DOUBLE DANDA TOULOU-TIGALARI",NULL},
/* 113D6 */ { NULL,NULL},
/* 113D7 */ { "SIGNE TOULOU-TIGALARI OM POUSHPIKA",NULL},
/* 113D8 */ { "SIGNE TOULOU-TIGALARI ÇRÎ POUSHPIKA",NULL},
/* 113D9 */ { NULL,NULL},
/* 113DA */ { NULL,NULL},
/* 113DB */ { NULL,NULL},
/* 113DC */ { NULL,NULL},
/* 113DD */ { NULL,NULL},
/* 113DE */ { NULL,NULL},
/* 113DF */ { NULL,NULL},
/* 113E0 */ { NULL,NULL},
/* 113E1 */ { "TON VÉDIQUE SVARITA TOULOU-TIGALARI",NULL},
/* 113E2 */ { "TON VÉDIQUE ANOUDATTA TOULOU-TIGALARI",NULL},
/* 113E3 */ { NULL,NULL},
/* 113E4 */ { NULL,NULL},
/* 113E5 */ { NULL,NULL},
/* 113E6 */ { NULL,NULL},
/* 113E7 */ { NULL,NULL},
/* 113E8 */ { NULL,NULL},
/* 113E9 */ { NULL,NULL},
/* 113EA */ { NULL,NULL},
/* 113EB */ { NULL,NULL},
/* 113EC */ { NULL,NULL},
/* 113ED */ { NULL,NULL},
/* 113EE */ { NULL,NULL},
/* 113EF */ { NULL,NULL},
/* 113F0 */ { NULL,NULL},
/* 113F1 */ { NULL,NULL},
/* 113F2 */ { NULL,NULL},
/* 113F3 */ { NULL,NULL},
/* 113F4 */ { NULL,NULL},
/* 113F5 */ { NULL,NULL},
/* 113F6 */ { NULL,NULL},
/* 113F7 */ { NULL,NULL},
/* 113F8 */ { NULL,NULL},
/* 113F9 */ { NULL,NULL},
/* 113FA */ { NULL,NULL},
/* 113FB */ { NULL,NULL},
/* 113FC */ { NULL,NULL},
/* 113FD */ { NULL,NULL},
/* 113FE */ { NULL,NULL},
/* 113FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_14[] = {
/* 11400 */ { "LETTRE NÉWAR A",NULL},
/* 11401 */ { "LETTRE NÉWAR Â",NULL},
/* 11402 */ { "LETTRE NÉWAR I",NULL},
/* 11403 */ { "LETTRE NÉWAR Î",NULL},
/* 11404 */ { "LETTRE NÉWAR OU",NULL},
/* 11405 */ { "LETTRE NÉWAR OÛ",NULL},
/* 11406 */ { "LETTRE NÉWAR R VOCALIQUE",NULL},
/* 11407 */ { "LETTRE NÉWAR RR VOCALIQUE",NULL},
/* 11408 */ { "LETTRE NÉWAR L VOCALIQUE",NULL},
/* 11409 */ { "LETTRE NÉWAR LL VOCALIQUE",NULL},
/* 1140A */ { "LETTRE NÉWAR É",NULL},
/* 1140B */ { "LETTRE NÉWAR AI",NULL},
/* 1140C */ { "LETTRE NÉWAR O",NULL},
/* 1140D */ { "LETTRE NÉWAR AOU",NULL},
/* 1140E */ { "LETTRE NÉWAR KA",NULL},
/* 1140F */ { "LETTRE NÉWAR KHA",NULL},
/* 11410 */ { "LETTRE NÉWAR GA",NULL},
/* 11411 */ { "LETTRE NÉWAR GHA",NULL},
/* 11412 */ { "LETTRE NÉWAR NGA",NULL},
/* 11413 */ { "LETTRE NÉWAR NGHA","	* nasale murmurée pour la langue nepalbhasha"},
/* 11414 */ { "LETTRE NÉWAR TCHA",NULL},
/* 11415 */ { "LETTRE NÉWAR TCHHA",NULL},
/* 11416 */ { "LETTRE NÉWAR DJA",NULL},
/* 11417 */ { "LETTRE NÉWAR DJHA",NULL},
/* 11418 */ { "LETTRE NÉWAR ÑA",NULL},
/* 11419 */ { "LETTRE NÉWAR ÑHA","	* nasale murmurée pour la langue nepalbhasha"},
/* 1141A */ { "LETTRE NÉWAR TTA",NULL},
/* 1141B */ { "LETTRE NÉWAR TTHA",NULL},
/* 1141C */ { "LETTRE NÉWAR DDA",NULL},
/* 1141D */ { "LETTRE NÉWAR DDHA",NULL},
/* 1141E */ { "LETTRE NÉWAR NNA",NULL},
/* 1141F */ { "LETTRE NÉWAR TA",NULL},
/* 11420 */ { "LETTRE NÉWAR THA",NULL},
/* 11421 */ { "LETTRE NÉWAR DA",NULL},
/* 11422 */ { "LETTRE NÉWAR DHA",NULL},
/* 11423 */ { "LETTRE NÉWAR NA",NULL},
/* 11424 */ { "LETTRE NÉWAR NHA","	* nasale murmurée pour la langue nepalbhasha"},
/* 11425 */ { "LETTRE NÉWAR PA",NULL},
/* 11426 */ { "LETTRE NÉWAR PHA","	= lettre néwar p'a"},
/* 11427 */ { "LETTRE NÉWAR BA",NULL},
/* 11428 */ { "LETTRE NÉWAR BHA",NULL},
/* 11429 */ { "LETTRE NÉWAR MA",NULL},
/* 1142A */ { "LETTRE NÉWAR MHA","	* nasale murmurée pour la langue nepalbhasha"},
/* 1142B */ { "LETTRE NÉWAR YA",NULL},
/* 1142C */ { "LETTRE NÉWAR RA",NULL},
/* 1142D */ { "LETTRE NÉWAR RHA","	* battue murmurée pour la langue nepalbhasha"},
/* 1142E */ { "LETTRE NÉWAR LA",NULL},
/* 1142F */ { "LETTRE NÉWAR LHA","	* latérale murmurée pour la langue nepalbhasha"},
/* 11430 */ { "LETTRE NÉWAR WA",NULL},
/* 11431 */ { "LETTRE NÉWAR ÇA",NULL},
/* 11432 */ { "LETTRE NÉWAR CHA",NULL},
/* 11433 */ { "LETTRE NÉWAR SA",NULL},
/* 11434 */ { "LETTRE NÉWAR HA",NULL},
/* 11435 */ { "DIACRITIQUE VOYELLE NÉWAR Â",NULL},
/* 11436 */ { "DIACRITIQUE VOYELLE NÉWAR I",NULL},
/* 11437 */ { "DIACRITIQUE VOYELLE NÉWAR Î",NULL},
/* 11438 */ { "DIACRITIQUE VOYELLE NÉWAR OU",NULL},
/* 11439 */ { "DIACRITIQUE VOYELLE NÉWAR OÛ",NULL},
/* 1143A */ { "DIACRITIQUE VOYELLE NÉWAR R VOCALIQUE",NULL},
/* 1143B */ { "DIACRITIQUE VOYELLE NÉWAR RR VOCALIQUE",NULL},
/* 1143C */ { "DIACRITIQUE VOYELLE NÉWAR L VOCALIQUE",NULL},
/* 1143D */ { "DIACRITIQUE VOYELLE NÉWAR LL VOCALIQUE",NULL},
/* 1143E */ { "DIACRITIQUE VOYELLE NÉWAR É",NULL},
/* 1143F */ { "DIACRITIQUE VOYELLE NÉWAR AI",NULL},
/* 11440 */ { "DIACRITIQUE VOYELLE NÉWAR O",NULL},
/* 11441 */ { "DIACRITIQUE VOYELLE NÉWAR AOU",NULL},
/* 11442 */ { "DIACRITIQUE NÉWAR VIRÂMA","	= toutisâlâ"},
/* 11443 */ { "DIACRITIQUE NÉWAR TCHANDRABINDOU","	= milâphouti"},
/* 11444 */ { "DIACRITIQUE NÉWAR ANOUSVÂRA","	= sinhaphouti"},
/* 11445 */ { "DIACRITIQUE NÉWAR VISARGA","	= liphouti"},
/* 11446 */ { "DIACRITIQUE NÉWAR NOUKTA",NULL},
/* 11447 */ { "SIGNE NÉWAR AVAGRAHA","	= soulâ"},
/* 11448 */ { "SIGNE NÉWAR ANOUSVÂRA FINAL","	= bâdipou"},
/* 11449 */ { "OM NÉWAR",NULL},
/* 1144A */ { "SIDDHI NÉWAR",NULL},
/* 1144B */ { "DANDA NÉWAR","	= dipou"},
/* 1144C */ { "DOUBLE DANDA NÉWAR",NULL},
/* 1144D */ { "VIRGULE NÉWAR","	= djhâsou"},
/* 1144E */ { "BOURRE D'ÉCART NÉWAR","	= thâydjâyekâ"},
/* 1144F */ { "SIGNE D'ABRÉVIATION NÉWAR",NULL},
/* 11450 */ { "CHIFFRE NÉWAR ZÉRO","	= gouli"},
/* 11451 */ { "CHIFFRE NÉWAR UN","	= tchi"},
/* 11452 */ { "CHIFFRE NÉWAR DEUX","	= nasi"},
/* 11453 */ { "CHIFFRE NÉWAR TROIS","	= swa"},
/* 11454 */ { "CHIFFRE NÉWAR QUATRE","	= pi"},
/* 11455 */ { "CHIFFRE NÉWAR CINQ","	= ndjâ"},
/* 11456 */ { "CHIFFRE NÉWAR SIX","	= khou"},
/* 11457 */ { "CHIFFRE NÉWAR SEPT","	= nhasa"},
/* 11458 */ { "CHIFFRE NÉWAR HUIT","	= cyâ"},
/* 11459 */ { "CHIFFRE NÉWAR NEUF","	= gou"},
/* 1145A */ { "DOUBLE VIRGULE NÉWAR",NULL},
/* 1145B */ { "SIGNE D'ABSENCE D'UNITÉ NÉWAR","	= djâvekâ"},
/* 1145C */ { NULL,NULL},
/* 1145D */ { "SIGNE D'INSERTION NÉWAR","	= tansâ"},
/* 1145E */ { "SIGNE NÉWAR SANDHI","	* indique le sandhi externe dans les documents en sanskrit\n"
	"	x (signe bengali sandhi - 09FE)"},
/* 1145F */ { "LETTRE NÉWAR ANOUSVÂRA VÉDIQUE",NULL},
/* 11460 */ { "SIGNE NÉWAR DJIHVAMOULIYA","	x (signe védique djihvamouliya - 1CF5)"},
/* 11461 */ { "SIGNE NÉWAR OUPADHMANIYA","	x (signe védique oupadhmaniya - 1CF6)"},
/* 11462 */ { NULL,NULL},
/* 11463 */ { NULL,NULL},
/* 11464 */ { NULL,NULL},
/* 11465 */ { NULL,NULL},
/* 11466 */ { NULL,NULL},
/* 11467 */ { NULL,NULL},
/* 11468 */ { NULL,NULL},
/* 11469 */ { NULL,NULL},
/* 1146A */ { NULL,NULL},
/* 1146B */ { NULL,NULL},
/* 1146C */ { NULL,NULL},
/* 1146D */ { NULL,NULL},
/* 1146E */ { NULL,NULL},
/* 1146F */ { NULL,NULL},
/* 11470 */ { NULL,NULL},
/* 11471 */ { NULL,NULL},
/* 11472 */ { NULL,NULL},
/* 11473 */ { NULL,NULL},
/* 11474 */ { NULL,NULL},
/* 11475 */ { NULL,NULL},
/* 11476 */ { NULL,NULL},
/* 11477 */ { NULL,NULL},
/* 11478 */ { NULL,NULL},
/* 11479 */ { NULL,NULL},
/* 1147A */ { NULL,NULL},
/* 1147B */ { NULL,NULL},
/* 1147C */ { NULL,NULL},
/* 1147D */ { NULL,NULL},
/* 1147E */ { NULL,NULL},
/* 1147F */ { NULL,NULL},
/* 11480 */ { "ANDJI TIRHUTA",NULL},
/* 11481 */ { "LETTRE TIRHUTA A",NULL},
/* 11482 */ { "LETTRE TIRHUTA Â",NULL},
/* 11483 */ { "LETTRE TIRHUTA I",NULL},
/* 11484 */ { "LETTRE TIRHUTA Î",NULL},
/* 11485 */ { "LETTRE TIRHUTA OU",NULL},
/* 11486 */ { "LETTRE TIRHUTA OÛ",NULL},
/* 11487 */ { "LETTRE TIRHUTA R VOCALIQUE",NULL},
/* 11488 */ { "LETTRE TIRHUTA RR VOCALIQUE",NULL},
/* 11489 */ { "LETTRE TIRHUTA L VOCALIQUE",NULL},
/* 1148A */ { "LETTRE TIRHUTA LL VOCALIQUE",NULL},
/* 1148B */ { "LETTRE TIRHUTA É",NULL},
/* 1148C */ { "LETTRE TIRHUTA AI",NULL},
/* 1148D */ { "LETTRE TIRHUTA O",NULL},
/* 1148E */ { "LETTRE TIRHUTA AOU",NULL},
/* 1148F */ { "LETTRE TIRHUTA KA",NULL},
/* 11490 */ { "LETTRE TIRHUTA KHA",NULL},
/* 11491 */ { "LETTRE TIRHUTA GA",NULL},
/* 11492 */ { "LETTRE TIRHUTA GHA",NULL},
/* 11493 */ { "LETTRE TIRHUTA NGA",NULL},
/* 11494 */ { "LETTRE TIRHUTA TCHA",NULL},
/* 11495 */ { "LETTRE TIRHUTA TCHHA",NULL},
/* 11496 */ { "LETTRE TIRHUTA DJA",NULL},
/* 11497 */ { "LETTRE TIRHUTA DJHA",NULL},
/* 11498 */ { "LETTRE TIRHUTA ÑA",NULL},
/* 11499 */ { "LETTRE TIRHUTA TTA",NULL},
/* 1149A */ { "LETTRE TIRHUTA TTHA",NULL},
/* 1149B */ { "LETTRE TIRHUTA DDA",NULL},
/* 1149C */ { "LETTRE TIRHUTA DDHA",NULL},
/* 1149D */ { "LETTRE TIRHUTA NNA",NULL},
/* 1149E */ { "LETTRE TIRHUTA TA",NULL},
/* 1149F */ { "LETTRE TIRHUTA THA",NULL},
/* 114A0 */ { "LETTRE TIRHUTA DA",NULL},
/* 114A1 */ { "LETTRE TIRHUTA DHA",NULL},
/* 114A2 */ { "LETTRE TIRHUTA NA",NULL},
/* 114A3 */ { "LETTRE TIRHUTA PA",NULL},
/* 114A4 */ { "LETTRE TIRHUTA PHA","	= lettre tirhuta p'a"},
/* 114A5 */ { "LETTRE TIRHUTA BA",NULL},
/* 114A6 */ { "LETTRE TIRHUTA BHA",NULL},
/* 114A7 */ { "LETTRE TIRHUTA MA",NULL},
/* 114A8 */ { "LETTRE TIRHUTA YA",NULL},
/* 114A9 */ { "LETTRE TIRHUTA RA",NULL},
/* 114AA */ { "LETTRE TIRHUTA LA",NULL},
/* 114AB */ { "LETTRE TIRHUTA VA",NULL},
/* 114AC */ { "LETTRE TIRHUTA ÇA",NULL},
/* 114AD */ { "LETTRE TIRHUTA CHA",NULL},
/* 114AE */ { "LETTRE TIRHUTA SA",NULL},
/* 114AF */ { "LETTRE TIRHUTA HA",NULL},
/* 114B0 */ { "DIACRITIQUE VOYELLE TIRHUTA Â",NULL},
/* 114B1 */ { "DIACRITIQUE VOYELLE TIRHUTA I",NULL},
/* 114B2 */ { "DIACRITIQUE VOYELLE TIRHUTA Î",NULL},
/* 114B3 */ { "DIACRITIQUE VOYELLE TIRHUTA OU",NULL},
/* 114B4 */ { "DIACRITIQUE VOYELLE TIRHUTA OÛ",NULL},
/* 114B5 */ { "DIACRITIQUE VOYELLE TIRHUTA R VOCALIQUE",NULL},
/* 114B6 */ { "DIACRITIQUE VOYELLE TIRHUTA RR VOCALIQUE",NULL},
/* 114B7 */ { "DIACRITIQUE VOYELLE TIRHUTA L VOCALIQUE",NULL},
/* 114B8 */ { "DIACRITIQUE VOYELLE TIRHUTA LL VOCALIQUE",NULL},
/* 114B9 */ { "DIACRITIQUE VOYELLE TIRHUTA É",NULL},
/* 114BA */ { "DIACRITIQUE VOYELLE TIRHUTA É COURT",NULL},
/* 114BB */ { "DIACRITIQUE VOYELLE TIRHUTA AI","	: 114B9 114BA"},
/* 114BC */ { "DIACRITIQUE VOYELLE TIRHUTA O","	: 114B9 114B0"},
/* 114BD */ { "DIACRITIQUE VOYELLE TIRHUTA O COURT",NULL},
/* 114BE */ { "DIACRITIQUE VOYELLE TIRHUTA AOU","	: 114B9 114BD"},
/* 114BF */ { "DIACRITIQUE TIRHUTA TCHANDRABINDOU",NULL},
/* 114C0 */ { "DIACRITIQUE TIRHUTA ANOUSVÂRA",NULL},
/* 114C1 */ { "DIACRITIQUE TIRHUTA VISARGA",NULL},
/* 114C2 */ { "DIACRITIQUE TIRHUTA VIRÂMA","	= halant"},
/* 114C3 */ { "DIACRITIQUE TIRHUTA NOUKTA",NULL},
/* 114C4 */ { "SIGNE TIRHUTA AVAGRAHA",NULL},
/* 114C5 */ { "GVANG TIRHUTA","	= anousvâra védique"},
/* 114C6 */ { "SIGNE D'ABRÉVIATION TIRHUTA",NULL},
/* 114C7 */ { "OM TIRHUTA",NULL},
/* 114C8 */ { NULL,NULL},
/* 114C9 */ { NULL,NULL},
/* 114CA */ { NULL,NULL},
/* 114CB */ { NULL,NULL},
/* 114CC */ { NULL,NULL},
/* 114CD */ { NULL,NULL},
/* 114CE */ { NULL,NULL},
/* 114CF */ { NULL,NULL},
/* 114D0 */ { "CHIFFRE TIRHUTA ZÉRO",NULL},
/* 114D1 */ { "CHIFFRE TIRHUTA UN",NULL},
/* 114D2 */ { "CHIFFRE TIRHUTA DEUX",NULL},
/* 114D3 */ { "CHIFFRE TIRHUTA TROIS",NULL},
/* 114D4 */ { "CHIFFRE TIRHUTA QUATRE",NULL},
/* 114D5 */ { "CHIFFRE TIRHUTA CINQ",NULL},
/* 114D6 */ { "CHIFFRE TIRHUTA SIX",NULL},
/* 114D7 */ { "CHIFFRE TIRHUTA SEPT",NULL},
/* 114D8 */ { "CHIFFRE TIRHUTA HUIT",NULL},
/* 114D9 */ { "CHIFFRE TIRHUTA NEUF",NULL},
/* 114DA */ { NULL,NULL},
/* 114DB */ { NULL,NULL},
/* 114DC */ { NULL,NULL},
/* 114DD */ { NULL,NULL},
/* 114DE */ { NULL,NULL},
/* 114DF */ { NULL,NULL},
/* 114E0 */ { NULL,NULL},
/* 114E1 */ { NULL,NULL},
/* 114E2 */ { NULL,NULL},
/* 114E3 */ { NULL,NULL},
/* 114E4 */ { NULL,NULL},
/* 114E5 */ { NULL,NULL},
/* 114E6 */ { NULL,NULL},
/* 114E7 */ { NULL,NULL},
/* 114E8 */ { NULL,NULL},
/* 114E9 */ { NULL,NULL},
/* 114EA */ { NULL,NULL},
/* 114EB */ { NULL,NULL},
/* 114EC */ { NULL,NULL},
/* 114ED */ { NULL,NULL},
/* 114EE */ { NULL,NULL},
/* 114EF */ { NULL,NULL},
/* 114F0 */ { NULL,NULL},
/* 114F1 */ { NULL,NULL},
/* 114F2 */ { NULL,NULL},
/* 114F3 */ { NULL,NULL},
/* 114F4 */ { NULL,NULL},
/* 114F5 */ { NULL,NULL},
/* 114F6 */ { NULL,NULL},
/* 114F7 */ { NULL,NULL},
/* 114F8 */ { NULL,NULL},
/* 114F9 */ { NULL,NULL},
/* 114FA */ { NULL,NULL},
/* 114FB */ { NULL,NULL},
/* 114FC */ { NULL,NULL},
/* 114FD */ { NULL,NULL},
/* 114FE */ { NULL,NULL},
/* 114FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_15[] = {
/* 11500 */ { NULL,NULL},
/* 11501 */ { NULL,NULL},
/* 11502 */ { NULL,NULL},
/* 11503 */ { NULL,NULL},
/* 11504 */ { NULL,NULL},
/* 11505 */ { NULL,NULL},
/* 11506 */ { NULL,NULL},
/* 11507 */ { NULL,NULL},
/* 11508 */ { NULL,NULL},
/* 11509 */ { NULL,NULL},
/* 1150A */ { NULL,NULL},
/* 1150B */ { NULL,NULL},
/* 1150C */ { NULL,NULL},
/* 1150D */ { NULL,NULL},
/* 1150E */ { NULL,NULL},
/* 1150F */ { NULL,NULL},
/* 11510 */ { NULL,NULL},
/* 11511 */ { NULL,NULL},
/* 11512 */ { NULL,NULL},
/* 11513 */ { NULL,NULL},
/* 11514 */ { NULL,NULL},
/* 11515 */ { NULL,NULL},
/* 11516 */ { NULL,NULL},
/* 11517 */ { NULL,NULL},
/* 11518 */ { NULL,NULL},
/* 11519 */ { NULL,NULL},
/* 1151A */ { NULL,NULL},
/* 1151B */ { NULL,NULL},
/* 1151C */ { NULL,NULL},
/* 1151D */ { NULL,NULL},
/* 1151E */ { NULL,NULL},
/* 1151F */ { NULL,NULL},
/* 11520 */ { NULL,NULL},
/* 11521 */ { NULL,NULL},
/* 11522 */ { NULL,NULL},
/* 11523 */ { NULL,NULL},
/* 11524 */ { NULL,NULL},
/* 11525 */ { NULL,NULL},
/* 11526 */ { NULL,NULL},
/* 11527 */ { NULL,NULL},
/* 11528 */ { NULL,NULL},
/* 11529 */ { NULL,NULL},
/* 1152A */ { NULL,NULL},
/* 1152B */ { NULL,NULL},
/* 1152C */ { NULL,NULL},
/* 1152D */ { NULL,NULL},
/* 1152E */ { NULL,NULL},
/* 1152F */ { NULL,NULL},
/* 11530 */ { NULL,NULL},
/* 11531 */ { NULL,NULL},
/* 11532 */ { NULL,NULL},
/* 11533 */ { NULL,NULL},
/* 11534 */ { NULL,NULL},
/* 11535 */ { NULL,NULL},
/* 11536 */ { NULL,NULL},
/* 11537 */ { NULL,NULL},
/* 11538 */ { NULL,NULL},
/* 11539 */ { NULL,NULL},
/* 1153A */ { NULL,NULL},
/* 1153B */ { NULL,NULL},
/* 1153C */ { NULL,NULL},
/* 1153D */ { NULL,NULL},
/* 1153E */ { NULL,NULL},
/* 1153F */ { NULL,NULL},
/* 11540 */ { NULL,NULL},
/* 11541 */ { NULL,NULL},
/* 11542 */ { NULL,NULL},
/* 11543 */ { NULL,NULL},
/* 11544 */ { NULL,NULL},
/* 11545 */ { NULL,NULL},
/* 11546 */ { NULL,NULL},
/* 11547 */ { NULL,NULL},
/* 11548 */ { NULL,NULL},
/* 11549 */ { NULL,NULL},
/* 1154A */ { NULL,NULL},
/* 1154B */ { NULL,NULL},
/* 1154C */ { NULL,NULL},
/* 1154D */ { NULL,NULL},
/* 1154E */ { NULL,NULL},
/* 1154F */ { NULL,NULL},
/* 11550 */ { NULL,NULL},
/* 11551 */ { NULL,NULL},
/* 11552 */ { NULL,NULL},
/* 11553 */ { NULL,NULL},
/* 11554 */ { NULL,NULL},
/* 11555 */ { NULL,NULL},
/* 11556 */ { NULL,NULL},
/* 11557 */ { NULL,NULL},
/* 11558 */ { NULL,NULL},
/* 11559 */ { NULL,NULL},
/* 1155A */ { NULL,NULL},
/* 1155B */ { NULL,NULL},
/* 1155C */ { NULL,NULL},
/* 1155D */ { NULL,NULL},
/* 1155E */ { NULL,NULL},
/* 1155F */ { NULL,NULL},
/* 11560 */ { NULL,NULL},
/* 11561 */ { NULL,NULL},
/* 11562 */ { NULL,NULL},
/* 11563 */ { NULL,NULL},
/* 11564 */ { NULL,NULL},
/* 11565 */ { NULL,NULL},
/* 11566 */ { NULL,NULL},
/* 11567 */ { NULL,NULL},
/* 11568 */ { NULL,NULL},
/* 11569 */ { NULL,NULL},
/* 1156A */ { NULL,NULL},
/* 1156B */ { NULL,NULL},
/* 1156C */ { NULL,NULL},
/* 1156D */ { NULL,NULL},
/* 1156E */ { NULL,NULL},
/* 1156F */ { NULL,NULL},
/* 11570 */ { NULL,NULL},
/* 11571 */ { NULL,NULL},
/* 11572 */ { NULL,NULL},
/* 11573 */ { NULL,NULL},
/* 11574 */ { NULL,NULL},
/* 11575 */ { NULL,NULL},
/* 11576 */ { NULL,NULL},
/* 11577 */ { NULL,NULL},
/* 11578 */ { NULL,NULL},
/* 11579 */ { NULL,NULL},
/* 1157A */ { NULL,NULL},
/* 1157B */ { NULL,NULL},
/* 1157C */ { NULL,NULL},
/* 1157D */ { NULL,NULL},
/* 1157E */ { NULL,NULL},
/* 1157F */ { NULL,NULL},
/* 11580 */ { "LETTRE SIDDHAM A",NULL},
/* 11581 */ { "LETTRE SIDDHAM Â",NULL},
/* 11582 */ { "LETTRE SIDDHAM I",NULL},
/* 11583 */ { "LETTRE SIDDHAM Î",NULL},
/* 11584 */ { "LETTRE SIDDHAM OU",NULL},
/* 11585 */ { "LETTRE SIDDHAM OÛ",NULL},
/* 11586 */ { "LETTRE SIDDHAM R VOCALIQUE",NULL},
/* 11587 */ { "LETTRE SIDDHAM RR VOCALIQUE",NULL},
/* 11588 */ { "LETTRE SIDDHAM L VOCALIQUE",NULL},
/* 11589 */ { "LETTRE SIDDHAM LL VOCALIQUE",NULL},
/* 1158A */ { "LETTRE SIDDHAM É",NULL},
/* 1158B */ { "LETTRE SIDDHAM AI",NULL},
/* 1158C */ { "LETTRE SIDDHAM O",NULL},
/* 1158D */ { "LETTRE SIDDHAM AOU",NULL},
/* 1158E */ { "LETTRE SIDDHAM KA",NULL},
/* 1158F */ { "LETTRE SIDDHAM KHA",NULL},
/* 11590 */ { "LETTRE SIDDHAM GA",NULL},
/* 11591 */ { "LETTRE SIDDHAM GHA",NULL},
/* 11592 */ { "LETTRE SIDDHAM NGA",NULL},
/* 11593 */ { "LETTRE SIDDHAM TCHA",NULL},
/* 11594 */ { "LETTRE SIDDHAM TCHHA",NULL},
/* 11595 */ { "LETTRE SIDDHAM DJA",NULL},
/* 11596 */ { "LETTRE SIDDHAM DJHA",NULL},
/* 11597 */ { "LETTRE SIDDHAM ÑA",NULL},
/* 11598 */ { "LETTRE SIDDHAM TTA",NULL},
/* 11599 */ { "LETTRE SIDDHAM TTHA",NULL},
/* 1159A */ { "LETTRE SIDDHAM DDA",NULL},
/* 1159B */ { "LETTRE SIDDHAM DDHA",NULL},
/* 1159C */ { "LETTRE SIDDHAM NNA",NULL},
/* 1159D */ { "LETTRE SIDDHAM TA",NULL},
/* 1159E */ { "LETTRE SIDDHAM THA",NULL},
/* 1159F */ { "LETTRE SIDDHAM DA",NULL},
/* 115A0 */ { "LETTRE SIDDHAM DHA",NULL},
/* 115A1 */ { "LETTRE SIDDHAM NA",NULL},
/* 115A2 */ { "LETTRE SIDDHAM PA",NULL},
/* 115A3 */ { "LETTRE SIDDHAM PHA","	= lettre siddham p'a"},
/* 115A4 */ { "LETTRE SIDDHAM BA",NULL},
/* 115A5 */ { "LETTRE SIDDHAM BHA",NULL},
/* 115A6 */ { "LETTRE SIDDHAM MA",NULL},
/* 115A7 */ { "LETTRE SIDDHAM YA",NULL},
/* 115A8 */ { "LETTRE SIDDHAM RA",NULL},
/* 115A9 */ { "LETTRE SIDDHAM LA",NULL},
/* 115AA */ { "LETTRE SIDDHAM VA",NULL},
/* 115AB */ { "LETTRE SIDDHAM ÇA",NULL},
/* 115AC */ { "LETTRE SIDDHAM CHA",NULL},
/* 115AD */ { "LETTRE SIDDHAM SA",NULL},
/* 115AE */ { "LETTRE SIDDHAM HA",NULL},
/* 115AF */ { "DIACRITIQUE VOYELLE SIDDHAM Â",NULL},
/* 115B0 */ { "DIACRITIQUE VOYELLE SIDDHAM I",NULL},
/* 115B1 */ { "DIACRITIQUE VOYELLE SIDDHAM Î",NULL},
/* 115B2 */ { "DIACRITIQUE VOYELLE SIDDHAM OU",NULL},
/* 115B3 */ { "DIACRITIQUE VOYELLE SIDDHAM OÛ",NULL},
/* 115B4 */ { "DIACRITIQUE VOYELLE SIDDHAM R VOCALIQUE",NULL},
/* 115B5 */ { "DIACRITIQUE VOYELLE SIDDHAM RR VOCALIQUE",NULL},
/* 115B6 */ { NULL,NULL},
/* 115B7 */ { NULL,NULL},
/* 115B8 */ { "DIACRITIQUE VOYELLE SIDDHAM É",NULL},
/* 115B9 */ { "DIACRITIQUE VOYELLE SIDDHAM AI",NULL},
/* 115BA */ { "DIACRITIQUE VOYELLE SIDDHAM O","	: 115B8 115AF"},
/* 115BB */ { "DIACRITIQUE VOYELLE SIDDHAM AOU","	: 115B9 115AF"},
/* 115BC */ { "DIACRITIQUE SIDDHAM TCHANDRABINDOU",NULL},
/* 115BD */ { "DIACRITIQUE SIDDHAM ANOUSVÂRA",NULL},
/* 115BE */ { "DIACRITIQUE SIDDHAM VISARGA",NULL},
/* 115BF */ { "DIACRITIQUE SIDDHAM VIRÂMA",NULL},
/* 115C0 */ { "DIACRITIQUE SIDDHAM NOUKTA","	* s'utilise pour l'écriture de sons étrangers"},
/* 115C1 */ { "SIGNE SIDDHAM SIDDHAM","	= siddhirastou\n"
	"	* se place au début d'un texte"},
/* 115C2 */ { "DANDA SIDDHAM",NULL},
/* 115C3 */ { "DOUBLE DANDA SIDDHAM",NULL},
/* 115C4 */ { "SÉPARATEUR SIDDHAM POINT","	* sépare les syllabes et les mots"},
/* 115C5 */ { "SÉPARATEUR SIDDHAM BARRE","	* sépare les syllabes et les mots"},
/* 115C6 */ { "SIGNE DE RÉPÉTITION SIDDHAM 1",NULL},
/* 115C7 */ { "SIGNE DE RÉPÉTITION SIDDHAM 2",NULL},
/* 115C8 */ { "SIGNE DE RÉPÉTITION SIDDHAM 3",NULL},
/* 115C9 */ { "SIGNE DE FIN DE TEXTE SIDDHAM","	* indique la fin d'un texte"},
/* 115CA */ { "REPÈRE DE SECTION SIDDHAM AVEC TRIDENTS ET FOURCHES",NULL},
/* 115CB */ { "REPÈRE DE SECTION SIDDHAM AVEC TRIDENTS ET CROISSANTS POINTÉS",NULL},
/* 115CC */ { "REPÈRE DE SECTION SIDDHAM AVEC RAYONS ET CROISSANTS POINTÉS",NULL},
/* 115CD */ { "REPÈRE DE SECTION SIDDHAM AVEC RAYONS ET CROISSANTS DOUBLES POINTÉS",NULL},
/* 115CE */ { "REPÈRE DE SECTION SIDDHAM AVEC RAYONS ET CROISSANTS TRIPLES POINTÉS",NULL},
/* 115CF */ { "REPÈRE DE SECTION SIDDHAM DOUBLE ANNEAU",NULL},
/* 115D0 */ { "REPÈRE DE SECTION SIDDHAM DOUBLE ANNEAU AVEC RAYONS",NULL},
/* 115D1 */ { "REPÈRE DE SECTION SIDDHAM AVEC CROISSANTS DOUBLES",NULL},
/* 115D2 */ { "REPÈRE DE SECTION SIDDHAM AVEC CROISSANTS TRIPLES",NULL},
/* 115D3 */ { "REPÈRE DE SECTION SIDDHAM AVEC CROISSANTS QUADRUPLES",NULL},
/* 115D4 */ { "REPÈRE DE SECTION SIDDHAM AVEC CROISSANTS SEPTUPLES",NULL},
/* 115D5 */ { "REPÈRE DE SECTION SIDDHAM AVEC CERCLES ET RAYONS",NULL},
/* 115D6 */ { "REPÈRE DE SECTION SIDDHAM AVEC CERCLES ET DEUX ENCLOS",NULL},
/* 115D7 */ { "REPÈRE DE SECTION SIDDHAM AVEC CERCLES ET QUATRE ENCLOS",NULL},
/* 115D8 */ { "LETTRE SIDDHAM VARIANTE DE I TROIS CERCLES","	x (lettre siddham i - 11582)"},
/* 115D9 */ { "LETTRE SIDDHAM VARIANTE DE I DEUX CERCLES",NULL},
/* 115DA */ { "LETTRE SIDDHAM VARIANTE DE Î DEUX CERCLES","	x (lettre siddham î - 11583)"},
/* 115DB */ { "LETTRE SIDDHAM VARIANTE DE OU","	x (lettre siddham ou - 11584)"},
/* 115DC */ { "DIACRITIQUE VOYELLE SIDDHAM VARIANTE DE OU",NULL},
/* 115DD */ { "DIACRITIQUE VOYELLE SIDDHAM VARIANTE DE OÛ",NULL},
/* 115DE */ { NULL,NULL},
/* 115DF */ { NULL,NULL},
/* 115E0 */ { NULL,NULL},
/* 115E1 */ { NULL,NULL},
/* 115E2 */ { NULL,NULL},
/* 115E3 */ { NULL,NULL},
/* 115E4 */ { NULL,NULL},
/* 115E5 */ { NULL,NULL},
/* 115E6 */ { NULL,NULL},
/* 115E7 */ { NULL,NULL},
/* 115E8 */ { NULL,NULL},
/* 115E9 */ { NULL,NULL},
/* 115EA */ { NULL,NULL},
/* 115EB */ { NULL,NULL},
/* 115EC */ { NULL,NULL},
/* 115ED */ { NULL,NULL},
/* 115EE */ { NULL,NULL},
/* 115EF */ { NULL,NULL},
/* 115F0 */ { NULL,NULL},
/* 115F1 */ { NULL,NULL},
/* 115F2 */ { NULL,NULL},
/* 115F3 */ { NULL,NULL},
/* 115F4 */ { NULL,NULL},
/* 115F5 */ { NULL,NULL},
/* 115F6 */ { NULL,NULL},
/* 115F7 */ { NULL,NULL},
/* 115F8 */ { NULL,NULL},
/* 115F9 */ { NULL,NULL},
/* 115FA */ { NULL,NULL},
/* 115FB */ { NULL,NULL},
/* 115FC */ { NULL,NULL},
/* 115FD */ { NULL,NULL},
/* 115FE */ { NULL,NULL},
/* 115FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_16[] = {
/* 11600 */ { "LETTRE MODI A",NULL},
/* 11601 */ { "LETTRE MODI Â",NULL},
/* 11602 */ { "LETTRE MODI I",NULL},
/* 11603 */ { "LETTRE MODI Î",NULL},
/* 11604 */ { "LETTRE MODI OU",NULL},
/* 11605 */ { "LETTRE MODI OÛ",NULL},
/* 11606 */ { "LETTRE MODI R VOCALIQUE",NULL},
/* 11607 */ { "LETTRE MODI RR VOCALIQUE",NULL},
/* 11608 */ { "LETTRE MODI L VOCALIQUE",NULL},
/* 11609 */ { "LETTRE MODI LL VOCALIQUE",NULL},
/* 1160A */ { "LETTRE MODI É",NULL},
/* 1160B */ { "LETTRE MODI AI",NULL},
/* 1160C */ { "LETTRE MODI O",NULL},
/* 1160D */ { "LETTRE MODI AOU",NULL},
/* 1160E */ { "LETTRE MODI KA",NULL},
/* 1160F */ { "LETTRE MODI KHA",NULL},
/* 11610 */ { "LETTRE MODI GA",NULL},
/* 11611 */ { "LETTRE MODI GHA",NULL},
/* 11612 */ { "LETTRE MODI NGA",NULL},
/* 11613 */ { "LETTRE MODI TCHA",NULL},
/* 11614 */ { "LETTRE MODI TCHHA",NULL},
/* 11615 */ { "LETTRE MODI DJA",NULL},
/* 11616 */ { "LETTRE MODI DJHA",NULL},
/* 11617 */ { "LETTRE MODI ÑA",NULL},
/* 11618 */ { "LETTRE MODI TTA",NULL},
/* 11619 */ { "LETTRE MODI TTHA",NULL},
/* 1161A */ { "LETTRE MODI DDA",NULL},
/* 1161B */ { "LETTRE MODI DDHA",NULL},
/* 1161C */ { "LETTRE MODI NNA",NULL},
/* 1161D */ { "LETTRE MODI TA",NULL},
/* 1161E */ { "LETTRE MODI THA",NULL},
/* 1161F */ { "LETTRE MODI DA",NULL},
/* 11620 */ { "LETTRE MODI DHA",NULL},
/* 11621 */ { "LETTRE MODI NA",NULL},
/* 11622 */ { "LETTRE MODI PA",NULL},
/* 11623 */ { "LETTRE MODI PHA","	= lettre modi p'a"},
/* 11624 */ { "LETTRE MODI BA",NULL},
/* 11625 */ { "LETTRE MODI BHA",NULL},
/* 11626 */ { "LETTRE MODI MA",NULL},
/* 11627 */ { "LETTRE MODI YA",NULL},
/* 11628 */ { "LETTRE MODI RA",NULL},
/* 11629 */ { "LETTRE MODI LA",NULL},
/* 1162A */ { "LETTRE MODI VA",NULL},
/* 1162B */ { "LETTRE MODI ÇA",NULL},
/* 1162C */ { "LETTRE MODI CHA",NULL},
/* 1162D */ { "LETTRE MODI SA",NULL},
/* 1162E */ { "LETTRE MODI HA",NULL},
/* 1162F */ { "LETTRE MODI LLA",NULL},
/* 11630 */ { "DIACRITIQUE VOYELLE MODI Â",NULL},
/* 11631 */ { "DIACRITIQUE VOYELLE MODI I",NULL},
/* 11632 */ { "DIACRITIQUE VOYELLE MODI Î",NULL},
/* 11633 */ { "DIACRITIQUE VOYELLE MODI OU",NULL},
/* 11634 */ { "DIACRITIQUE VOYELLE MODI OÛ",NULL},
/* 11635 */ { "DIACRITIQUE VOYELLE MODI R VOCALIQUE",NULL},
/* 11636 */ { "DIACRITIQUE VOYELLE MODI RR VOCALIQUE",NULL},
/* 11637 */ { "DIACRITIQUE VOYELLE MODI L VOCALIQUE",NULL},
/* 11638 */ { "DIACRITIQUE VOYELLE MODI LL VOCALIQUE",NULL},
/* 11639 */ { "DIACRITIQUE VOYELLE MODI É",NULL},
/* 1163A */ { "DIACRITIQUE VOYELLE MODI AI",NULL},
/* 1163B */ { "DIACRITIQUE VOYELLE MODI O",NULL},
/* 1163C */ { "DIACRITIQUE VOYELLE MODI AOU",NULL},
/* 1163D */ { "DIACRITIQUE MODI ANOUSVÂRA",NULL},
/* 1163E */ { "DIACRITIQUE MODI VISARGA",NULL},
/* 1163F */ { "DIACRITIQUE MODI VIRÂMA","	= halant"},
/* 11640 */ { "DIACRITIQUE MODI ARDHATCHANDRA","	* s'utilise pour transcrire l'anglais"},
/* 11641 */ { "DANDA MODI",NULL},
/* 11642 */ { "DOUBLE DANDA MODI",NULL},
/* 11643 */ { "SIGNE D'ABRÉVIATION MODI",NULL},
/* 11644 */ { "SIGNE MODI HOUVA","	* s'utilise comme une invocation"},
/* 11645 */ { NULL,NULL},
/* 11646 */ { NULL,NULL},
/* 11647 */ { NULL,NULL},
/* 11648 */ { NULL,NULL},
/* 11649 */ { NULL,NULL},
/* 1164A */ { NULL,NULL},
/* 1164B */ { NULL,NULL},
/* 1164C */ { NULL,NULL},
/* 1164D */ { NULL,NULL},
/* 1164E */ { NULL,NULL},
/* 1164F */ { NULL,NULL},
/* 11650 */ { "CHIFFRE MODI ZÉRO",NULL},
/* 11651 */ { "CHIFFRE MODI UN",NULL},
/* 11652 */ { "CHIFFRE MODI DEUX",NULL},
/* 11653 */ { "CHIFFRE MODI TROIS",NULL},
/* 11654 */ { "CHIFFRE MODI QUATRE",NULL},
/* 11655 */ { "CHIFFRE MODI CINQ",NULL},
/* 11656 */ { "CHIFFRE MODI SIX",NULL},
/* 11657 */ { "CHIFFRE MODI SEPT",NULL},
/* 11658 */ { "CHIFFRE MODI HUIT",NULL},
/* 11659 */ { "CHIFFRE MODI NEUF",NULL},
/* 1165A */ { NULL,NULL},
/* 1165B */ { NULL,NULL},
/* 1165C */ { NULL,NULL},
/* 1165D */ { NULL,NULL},
/* 1165E */ { NULL,NULL},
/* 1165F */ { NULL,NULL},
/* 11660 */ { "BIRGA MONGOL ORNÉ","	x (birga mongol - 1800)"},
/* 11661 */ { "BIRGA MONGOL COUCHÉ",NULL},
/* 11662 */ { "DOUBLE BIRGA MONGOL ORNÉ",NULL},
/* 11663 */ { "TRIPLE BIRGA MONGOL ORNÉ",NULL},
/* 11664 */ { "BIRGA MONGOL DOUBLEMENT ORNÉ",NULL},
/* 11665 */ { "BIRGA MONGOL COUCHÉ ET ORNÉ",NULL},
/* 11666 */ { "BIRGA MONGOL COUCHÉ ET DOUBLEMENT ORNÉ",NULL},
/* 11667 */ { "BIRGA MONGOL CULBUTÉ",NULL},
/* 11668 */ { "BIRGA MONGOL CULBUTÉ ET DOUBLEMENT ORNÉ",NULL},
/* 11669 */ { "BIRGA MONGOL EN SPIRALE",NULL},
/* 1166A */ { "BIRGA MONGOL EN SPIRALE ET ORNÉ",NULL},
/* 1166B */ { "BIRGA MONGOL EN SPIRALE ET DOUBLEMENT ORNÉ",NULL},
/* 1166C */ { "BIRGA MONGOL EN SPIRALE CULBUTÉ ET DOUBLEMENT ORNÉ",NULL},
/* 1166D */ { NULL,NULL},
/* 1166E */ { NULL,NULL},
/* 1166F */ { NULL,NULL},
/* 11670 */ { NULL,NULL},
/* 11671 */ { NULL,NULL},
/* 11672 */ { NULL,NULL},
/* 11673 */ { NULL,NULL},
/* 11674 */ { NULL,NULL},
/* 11675 */ { NULL,NULL},
/* 11676 */ { NULL,NULL},
/* 11677 */ { NULL,NULL},
/* 11678 */ { NULL,NULL},
/* 11679 */ { NULL,NULL},
/* 1167A */ { NULL,NULL},
/* 1167B */ { NULL,NULL},
/* 1167C */ { NULL,NULL},
/* 1167D */ { NULL,NULL},
/* 1167E */ { NULL,NULL},
/* 1167F */ { NULL,NULL},
/* 11680 */ { "LETTRE TAKRI A",NULL},
/* 11681 */ { "LETTRE TAKRI Â",NULL},
/* 11682 */ { "LETTRE TAKRI I",NULL},
/* 11683 */ { "LETTRE TAKRI Î",NULL},
/* 11684 */ { "LETTRE TAKRI OU",NULL},
/* 11685 */ { "LETTRE TAKRI OÛ",NULL},
/* 11686 */ { "LETTRE TAKRI É",NULL},
/* 11687 */ { "LETTRE TAKRI AI",NULL},
/* 11688 */ { "LETTRE TAKRI O",NULL},
/* 11689 */ { "LETTRE TAKRI AOU",NULL},
/* 1168A */ { "LETTRE TAKRI KA",NULL},
/* 1168B */ { "LETTRE TAKRI KHA","	* également utilisée pour noter ssa"},
/* 1168C */ { "LETTRE TAKRI GA",NULL},
/* 1168D */ { "LETTRE TAKRI GHA",NULL},
/* 1168E */ { "LETTRE TAKRI NGA",NULL},
/* 1168F */ { "LETTRE TAKRI TCHA",NULL},
/* 11690 */ { "LETTRE TAKRI TCHHA",NULL},
/* 11691 */ { "LETTRE TAKRI DJA",NULL},
/* 11692 */ { "LETTRE TAKRI DJHA",NULL},
/* 11693 */ { "LETTRE TAKRI ÑA",NULL},
/* 11694 */ { "LETTRE TAKRI TTA",NULL},
/* 11695 */ { "LETTRE TAKRI TTHA",NULL},
/* 11696 */ { "LETTRE TAKRI DDA",NULL},
/* 11697 */ { "LETTRE TAKRI DDHA",NULL},
/* 11698 */ { "LETTRE TAKRI NNA",NULL},
/* 11699 */ { "LETTRE TAKRI TA",NULL},
/* 1169A */ { "LETTRE TAKRI THA",NULL},
/* 1169B */ { "LETTRE TAKRI DA",NULL},
/* 1169C */ { "LETTRE TAKRI DHA",NULL},
/* 1169D */ { "LETTRE TAKRI NA",NULL},
/* 1169E */ { "LETTRE TAKRI PA",NULL},
/* 1169F */ { "LETTRE TAKRI PHA","	= lettre takri p'a"},
/* 116A0 */ { "LETTRE TAKRI BA",NULL},
/* 116A1 */ { "LETTRE TAKRI BHA",NULL},
/* 116A2 */ { "LETTRE TAKRI MA",NULL},
/* 116A3 */ { "LETTRE TAKRI YA",NULL},
/* 116A4 */ { "LETTRE TAKRI RA",NULL},
/* 116A5 */ { "LETTRE TAKRI LA",NULL},
/* 116A6 */ { "LETTRE TAKRI VA",NULL},
/* 116A7 */ { "LETTRE TAKRI ÇA",NULL},
/* 116A8 */ { "LETTRE TAKRI SA",NULL},
/* 116A9 */ { "LETTRE TAKRI HA",NULL},
/* 116AA */ { "LETTRE TAKRI RRA",NULL},
/* 116AB */ { "DIACRITIQUE TAKRI ANOUSVÂRA",NULL},
/* 116AC */ { "DIACRITIQUE TAKRI VISARGA",NULL},
/* 116AD */ { "DIACRITIQUE VOYELLE TAKRI Â",NULL},
/* 116AE */ { "DIACRITIQUE VOYELLE TAKRI I",NULL},
/* 116AF */ { "DIACRITIQUE VOYELLE TAKRI Î",NULL},
/* 116B0 */ { "DIACRITIQUE VOYELLE TAKRI OU",NULL},
/* 116B1 */ { "DIACRITIQUE VOYELLE TAKRI OÛ",NULL},
/* 116B2 */ { "DIACRITIQUE VOYELLE TAKRI É",NULL},
/* 116B3 */ { "DIACRITIQUE VOYELLE TAKRI AI",NULL},
/* 116B4 */ { "DIACRITIQUE VOYELLE TAKRI O",NULL},
/* 116B5 */ { "DIACRITIQUE VOYELLE TAKRI AOU",NULL},
/* 116B6 */ { "DIACRITIQUE TAKRI VIRÂMA",NULL},
/* 116B7 */ { "DIACRITIQUE TAKRI NOUKTA",NULL},
/* 116B8 */ { "LETTRE TAKRI KHA ARCHAÏQUE","	* utilisée dans des écrits anciens pour noter kha"},
/* 116B9 */ { "SIGNE D'ABRÉVIATION TAKRI","	x (signe d'abréviation gourmoukhî - 0A76)\n"
	"	x (signe d'abréviation charada - 111C7)"},
/* 116BA */ { NULL,NULL},
/* 116BB */ { NULL,NULL},
/* 116BC */ { NULL,NULL},
/* 116BD */ { NULL,NULL},
/* 116BE */ { NULL,NULL},
/* 116BF */ { NULL,NULL},
/* 116C0 */ { "CHIFFRE TAKRI ZÉRO",NULL},
/* 116C1 */ { "CHIFFRE TAKRI UN",NULL},
/* 116C2 */ { "CHIFFRE TAKRI DEUX",NULL},
/* 116C3 */ { "CHIFFRE TAKRI TROIS",NULL},
/* 116C4 */ { "CHIFFRE TAKRI QUATRE",NULL},
/* 116C5 */ { "CHIFFRE TAKRI CINQ",NULL},
/* 116C6 */ { "CHIFFRE TAKRI SIX",NULL},
/* 116C7 */ { "CHIFFRE TAKRI SEPT",NULL},
/* 116C8 */ { "CHIFFRE TAKRI HUIT",NULL},
/* 116C9 */ { "CHIFFRE TAKRI NEUF",NULL},
/* 116CA */ { NULL,NULL},
/* 116CB */ { NULL,NULL},
/* 116CC */ { NULL,NULL},
/* 116CD */ { NULL,NULL},
/* 116CE */ { NULL,NULL},
/* 116CF */ { NULL,NULL},
/* 116D0 */ { "CHIFFRE BIRMAN PAO ZÉRO",NULL},
/* 116D1 */ { "CHIFFRE BIRMAN PAO UN",NULL},
/* 116D2 */ { "CHIFFRE BIRMAN PAO DEUX",NULL},
/* 116D3 */ { "CHIFFRE BIRMAN PAO TROIS",NULL},
/* 116D4 */ { "CHIFFRE BIRMAN PAO QUATRE",NULL},
/* 116D5 */ { "CHIFFRE BIRMAN PAO CINQ",NULL},
/* 116D6 */ { "CHIFFRE BIRMAN PAO SIX",NULL},
/* 116D7 */ { "CHIFFRE BIRMAN PAO SEPT",NULL},
/* 116D8 */ { "CHIFFRE BIRMAN PAO HUIT",NULL},
/* 116D9 */ { "CHIFFRE BIRMAN PAO NEUF",NULL},
/* 116DA */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL ZÉRO",NULL},
/* 116DB */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL UN",NULL},
/* 116DC */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL DEUX",NULL},
/* 116DD */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL TROIS",NULL},
/* 116DE */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL QUATRE",NULL},
/* 116DF */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL CINQ",NULL},
/* 116E0 */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL SIX",NULL},
/* 116E1 */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL SEPT",NULL},
/* 116E2 */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL HUIT",NULL},
/* 116E3 */ { "CHIFFRE BIRMAN KAREN PWO ORIENTAL NEUF",NULL},
/* 116E4 */ { NULL,NULL},
/* 116E5 */ { NULL,NULL},
/* 116E6 */ { NULL,NULL},
/* 116E7 */ { NULL,NULL},
/* 116E8 */ { NULL,NULL},
/* 116E9 */ { NULL,NULL},
/* 116EA */ { NULL,NULL},
/* 116EB */ { NULL,NULL},
/* 116EC */ { NULL,NULL},
/* 116ED */ { NULL,NULL},
/* 116EE */ { NULL,NULL},
/* 116EF */ { NULL,NULL},
/* 116F0 */ { NULL,NULL},
/* 116F1 */ { NULL,NULL},
/* 116F2 */ { NULL,NULL},
/* 116F3 */ { NULL,NULL},
/* 116F4 */ { NULL,NULL},
/* 116F5 */ { NULL,NULL},
/* 116F6 */ { NULL,NULL},
/* 116F7 */ { NULL,NULL},
/* 116F8 */ { NULL,NULL},
/* 116F9 */ { NULL,NULL},
/* 116FA */ { NULL,NULL},
/* 116FB */ { NULL,NULL},
/* 116FC */ { NULL,NULL},
/* 116FD */ { NULL,NULL},
/* 116FE */ { NULL,NULL},
/* 116FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_17[] = {
/* 11700 */ { "LETTRE ÂHOM KA",NULL},
/* 11701 */ { "LETTRE ÂHOM KHA",NULL},
/* 11702 */ { "LETTRE ÂHOM NGA",NULL},
/* 11703 */ { "LETTRE ÂHOM NA",NULL},
/* 11704 */ { "LETTRE ÂHOM TA",NULL},
/* 11705 */ { "LETTRE ÂHOM VARIANTE DE TA",NULL},
/* 11706 */ { "LETTRE ÂHOM PA",NULL},
/* 11707 */ { "LETTRE ÂHOM PHA","	= lettre âhom p'a"},
/* 11708 */ { "LETTRE ÂHOM BA",NULL},
/* 11709 */ { "LETTRE ÂHOM MA",NULL},
/* 1170A */ { "LETTRE ÂHOM DJA",NULL},
/* 1170B */ { "LETTRE ÂHOM TCHHA",NULL},
/* 1170C */ { "LETTRE ÂHOM THA",NULL},
/* 1170D */ { "LETTRE ÂHOM RA",NULL},
/* 1170E */ { "LETTRE ÂHOM LA",NULL},
/* 1170F */ { "LETTRE ÂHOM SA",NULL},
/* 11710 */ { "LETTRE ÂHOM ÑA",NULL},
/* 11711 */ { "LETTRE ÂHOM HA",NULL},
/* 11712 */ { "LETTRE ÂHOM A",NULL},
/* 11713 */ { "LETTRE ÂHOM DA",NULL},
/* 11714 */ { "LETTRE ÂHOM DHA",NULL},
/* 11715 */ { "LETTRE ÂHOM GA",NULL},
/* 11716 */ { "LETTRE ÂHOM VARIANTE DE GA",NULL},
/* 11717 */ { "LETTRE ÂHOM GHA",NULL},
/* 11718 */ { "LETTRE ÂHOM BHA",NULL},
/* 11719 */ { "LETTRE ÂHOM DJHA",NULL},
/* 1171A */ { "LETTRE ÂHOM VARIANTE DE BA",NULL},
/* 1171B */ { NULL,NULL},
/* 1171C */ { NULL,NULL},
/* 1171D */ { "DIACRITIQUE CONSONNE ÂHOM LA MÉDIAL",NULL},
/* 1171E */ { "DIACRITIQUE CONSONNE ÂHOM RA MÉDIAL",NULL},
/* 1171F */ { "DIACRITIQUE CONSONNE ÂHOM RA LIANT MÉDIAL",NULL},
/* 11720 */ { "DIACRITIQUE VOYELLE ÂHOM A",NULL},
/* 11721 */ { "DIACRITIQUE VOYELLE ÂHOM Â",NULL},
/* 11722 */ { "DIACRITIQUE VOYELLE ÂHOM I",NULL},
/* 11723 */ { "DIACRITIQUE VOYELLE ÂHOM Î",NULL},
/* 11724 */ { "DIACRITIQUE VOYELLE ÂHOM OU",NULL},
/* 11725 */ { "DIACRITIQUE VOYELLE ÂHOM OÛ",NULL},
/* 11726 */ { "DIACRITIQUE VOYELLE ÂHOM É",NULL},
/* 11727 */ { "DIACRITIQUE VOYELLE ÂHOM AW",NULL},
/* 11728 */ { "DIACRITIQUE VOYELLE ÂHOM O",NULL},
/* 11729 */ { "DIACRITIQUE VOYELLE ÂHOM AI",NULL},
/* 1172A */ { "DIACRITIQUE VOYELLE ÂHOM AM",NULL},
/* 1172B */ { "DIACRITIQUE ÂHOM DE SUPPRESSION",NULL},
/* 1172C */ { NULL,NULL},
/* 1172D */ { NULL,NULL},
/* 1172E */ { NULL,NULL},
/* 1172F */ { NULL,NULL},
/* 11730 */ { "CHIFFRE ÂHOM ZÉRO",NULL},
/* 11731 */ { "CHIFFRE ÂHOM UN",NULL},
/* 11732 */ { "CHIFFRE ÂHOM DEUX",NULL},
/* 11733 */ { "CHIFFRE ÂHOM TROIS",NULL},
/* 11734 */ { "CHIFFRE ÂHOM QUATRE",NULL},
/* 11735 */ { "CHIFFRE ÂHOM CINQ",NULL},
/* 11736 */ { "CHIFFRE ÂHOM SIX",NULL},
/* 11737 */ { "CHIFFRE ÂHOM SEPT",NULL},
/* 11738 */ { "CHIFFRE ÂHOM HUIT",NULL},
/* 11739 */ { "CHIFFRE ÂHOM NEUF",NULL},
/* 1173A */ { "NOMBRE ÂHOM DIX",NULL},
/* 1173B */ { "NOMBRE ÂHOM VINGT",NULL},
/* 1173C */ { "SIGNE ÂHOM PETITE SECTION",NULL},
/* 1173D */ { "SIGNE ÂHOM SECTION",NULL},
/* 1173E */ { "SIGNE ÂHOM ROULAI",NULL},
/* 1173F */ { "SYMBOLE ÂHOM VI",NULL},
/* 11740 */ { "LETTRE ÂHOM TCHA",NULL},
/* 11741 */ { "LETTRE ÂHOM TTA",NULL},
/* 11742 */ { "LETTRE ÂHOM TTHA",NULL},
/* 11743 */ { "LETTRE ÂHOM DDA",NULL},
/* 11744 */ { "LETTRE ÂHOM DDHA",NULL},
/* 11745 */ { "LETTRE ÂHOM NNA",NULL},
/* 11746 */ { "LETTRE ÂHOM LLA",NULL},
/* 11747 */ { NULL,NULL},
/* 11748 */ { NULL,NULL},
/* 11749 */ { NULL,NULL},
/* 1174A */ { NULL,NULL},
/* 1174B */ { NULL,NULL},
/* 1174C */ { NULL,NULL},
/* 1174D */ { NULL,NULL},
/* 1174E */ { NULL,NULL},
/* 1174F */ { NULL,NULL},
/* 11750 */ { NULL,NULL},
/* 11751 */ { NULL,NULL},
/* 11752 */ { NULL,NULL},
/* 11753 */ { NULL,NULL},
/* 11754 */ { NULL,NULL},
/* 11755 */ { NULL,NULL},
/* 11756 */ { NULL,NULL},
/* 11757 */ { NULL,NULL},
/* 11758 */ { NULL,NULL},
/* 11759 */ { NULL,NULL},
/* 1175A */ { NULL,NULL},
/* 1175B */ { NULL,NULL},
/* 1175C */ { NULL,NULL},
/* 1175D */ { NULL,NULL},
/* 1175E */ { NULL,NULL},
/* 1175F */ { NULL,NULL},
/* 11760 */ { NULL,NULL},
/* 11761 */ { NULL,NULL},
/* 11762 */ { NULL,NULL},
/* 11763 */ { NULL,NULL},
/* 11764 */ { NULL,NULL},
/* 11765 */ { NULL,NULL},
/* 11766 */ { NULL,NULL},
/* 11767 */ { NULL,NULL},
/* 11768 */ { NULL,NULL},
/* 11769 */ { NULL,NULL},
/* 1176A */ { NULL,NULL},
/* 1176B */ { NULL,NULL},
/* 1176C */ { NULL,NULL},
/* 1176D */ { NULL,NULL},
/* 1176E */ { NULL,NULL},
/* 1176F */ { NULL,NULL},
/* 11770 */ { NULL,NULL},
/* 11771 */ { NULL,NULL},
/* 11772 */ { NULL,NULL},
/* 11773 */ { NULL,NULL},
/* 11774 */ { NULL,NULL},
/* 11775 */ { NULL,NULL},
/* 11776 */ { NULL,NULL},
/* 11777 */ { NULL,NULL},
/* 11778 */ { NULL,NULL},
/* 11779 */ { NULL,NULL},
/* 1177A */ { NULL,NULL},
/* 1177B */ { NULL,NULL},
/* 1177C */ { NULL,NULL},
/* 1177D */ { NULL,NULL},
/* 1177E */ { NULL,NULL},
/* 1177F */ { NULL,NULL},
/* 11780 */ { NULL,NULL},
/* 11781 */ { NULL,NULL},
/* 11782 */ { NULL,NULL},
/* 11783 */ { NULL,NULL},
/* 11784 */ { NULL,NULL},
/* 11785 */ { NULL,NULL},
/* 11786 */ { NULL,NULL},
/* 11787 */ { NULL,NULL},
/* 11788 */ { NULL,NULL},
/* 11789 */ { NULL,NULL},
/* 1178A */ { NULL,NULL},
/* 1178B */ { NULL,NULL},
/* 1178C */ { NULL,NULL},
/* 1178D */ { NULL,NULL},
/* 1178E */ { NULL,NULL},
/* 1178F */ { NULL,NULL},
/* 11790 */ { NULL,NULL},
/* 11791 */ { NULL,NULL},
/* 11792 */ { NULL,NULL},
/* 11793 */ { NULL,NULL},
/* 11794 */ { NULL,NULL},
/* 11795 */ { NULL,NULL},
/* 11796 */ { NULL,NULL},
/* 11797 */ { NULL,NULL},
/* 11798 */ { NULL,NULL},
/* 11799 */ { NULL,NULL},
/* 1179A */ { NULL,NULL},
/* 1179B */ { NULL,NULL},
/* 1179C */ { NULL,NULL},
/* 1179D */ { NULL,NULL},
/* 1179E */ { NULL,NULL},
/* 1179F */ { NULL,NULL},
/* 117A0 */ { NULL,NULL},
/* 117A1 */ { NULL,NULL},
/* 117A2 */ { NULL,NULL},
/* 117A3 */ { NULL,NULL},
/* 117A4 */ { NULL,NULL},
/* 117A5 */ { NULL,NULL},
/* 117A6 */ { NULL,NULL},
/* 117A7 */ { NULL,NULL},
/* 117A8 */ { NULL,NULL},
/* 117A9 */ { NULL,NULL},
/* 117AA */ { NULL,NULL},
/* 117AB */ { NULL,NULL},
/* 117AC */ { NULL,NULL},
/* 117AD */ { NULL,NULL},
/* 117AE */ { NULL,NULL},
/* 117AF */ { NULL,NULL},
/* 117B0 */ { NULL,NULL},
/* 117B1 */ { NULL,NULL},
/* 117B2 */ { NULL,NULL},
/* 117B3 */ { NULL,NULL},
/* 117B4 */ { NULL,NULL},
/* 117B5 */ { NULL,NULL},
/* 117B6 */ { NULL,NULL},
/* 117B7 */ { NULL,NULL},
/* 117B8 */ { NULL,NULL},
/* 117B9 */ { NULL,NULL},
/* 117BA */ { NULL,NULL},
/* 117BB */ { NULL,NULL},
/* 117BC */ { NULL,NULL},
/* 117BD */ { NULL,NULL},
/* 117BE */ { NULL,NULL},
/* 117BF */ { NULL,NULL},
/* 117C0 */ { NULL,NULL},
/* 117C1 */ { NULL,NULL},
/* 117C2 */ { NULL,NULL},
/* 117C3 */ { NULL,NULL},
/* 117C4 */ { NULL,NULL},
/* 117C5 */ { NULL,NULL},
/* 117C6 */ { NULL,NULL},
/* 117C7 */ { NULL,NULL},
/* 117C8 */ { NULL,NULL},
/* 117C9 */ { NULL,NULL},
/* 117CA */ { NULL,NULL},
/* 117CB */ { NULL,NULL},
/* 117CC */ { NULL,NULL},
/* 117CD */ { NULL,NULL},
/* 117CE */ { NULL,NULL},
/* 117CF */ { NULL,NULL},
/* 117D0 */ { NULL,NULL},
/* 117D1 */ { NULL,NULL},
/* 117D2 */ { NULL,NULL},
/* 117D3 */ { NULL,NULL},
/* 117D4 */ { NULL,NULL},
/* 117D5 */ { NULL,NULL},
/* 117D6 */ { NULL,NULL},
/* 117D7 */ { NULL,NULL},
/* 117D8 */ { NULL,NULL},
/* 117D9 */ { NULL,NULL},
/* 117DA */ { NULL,NULL},
/* 117DB */ { NULL,NULL},
/* 117DC */ { NULL,NULL},
/* 117DD */ { NULL,NULL},
/* 117DE */ { NULL,NULL},
/* 117DF */ { NULL,NULL},
/* 117E0 */ { NULL,NULL},
/* 117E1 */ { NULL,NULL},
/* 117E2 */ { NULL,NULL},
/* 117E3 */ { NULL,NULL},
/* 117E4 */ { NULL,NULL},
/* 117E5 */ { NULL,NULL},
/* 117E6 */ { NULL,NULL},
/* 117E7 */ { NULL,NULL},
/* 117E8 */ { NULL,NULL},
/* 117E9 */ { NULL,NULL},
/* 117EA */ { NULL,NULL},
/* 117EB */ { NULL,NULL},
/* 117EC */ { NULL,NULL},
/* 117ED */ { NULL,NULL},
/* 117EE */ { NULL,NULL},
/* 117EF */ { NULL,NULL},
/* 117F0 */ { NULL,NULL},
/* 117F1 */ { NULL,NULL},
/* 117F2 */ { NULL,NULL},
/* 117F3 */ { NULL,NULL},
/* 117F4 */ { NULL,NULL},
/* 117F5 */ { NULL,NULL},
/* 117F6 */ { NULL,NULL},
/* 117F7 */ { NULL,NULL},
/* 117F8 */ { NULL,NULL},
/* 117F9 */ { NULL,NULL},
/* 117FA */ { NULL,NULL},
/* 117FB */ { NULL,NULL},
/* 117FC */ { NULL,NULL},
/* 117FD */ { NULL,NULL},
/* 117FE */ { NULL,NULL},
/* 117FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_18[] = {
/* 11800 */ { "LETTRE DOGRA A",NULL},
/* 11801 */ { "LETTRE DOGRA Â",NULL},
/* 11802 */ { "LETTRE DOGRA I",NULL},
/* 11803 */ { "LETTRE DOGRA Î",NULL},
/* 11804 */ { "LETTRE DOGRA OU",NULL},
/* 11805 */ { "LETTRE DOGRA OÛ",NULL},
/* 11806 */ { "LETTRE DOGRA É",NULL},
/* 11807 */ { "LETTRE DOGRA AI",NULL},
/* 11808 */ { "LETTRE DOGRA O",NULL},
/* 11809 */ { "LETTRE DOGRA AOU",NULL},
/* 1180A */ { "LETTRE DOGRA KA",NULL},
/* 1180B */ { "LETTRE DOGRA KHA",NULL},
/* 1180C */ { "LETTRE DOGRA GA",NULL},
/* 1180D */ { "LETTRE DOGRA GHA",NULL},
/* 1180E */ { "LETTRE DOGRA NGA",NULL},
/* 1180F */ { "LETTRE DOGRA TCHA",NULL},
/* 11810 */ { "LETTRE DOGRA TCHHA",NULL},
/* 11811 */ { "LETTRE DOGRA DJA",NULL},
/* 11812 */ { "LETTRE DOGRA DJHA",NULL},
/* 11813 */ { "LETTRE DOGRA ÑA",NULL},
/* 11814 */ { "LETTRE DOGRA TTA",NULL},
/* 11815 */ { "LETTRE DOGRA TTHA",NULL},
/* 11816 */ { "LETTRE DOGRA DDA",NULL},
/* 11817 */ { "LETTRE DOGRA DDHA",NULL},
/* 11818 */ { "LETTRE DOGRA NNA",NULL},
/* 11819 */ { "LETTRE DOGRA TA",NULL},
/* 1181A */ { "LETTRE DOGRA THA",NULL},
/* 1181B */ { "LETTRE DOGRA DA",NULL},
/* 1181C */ { "LETTRE DOGRA DHA",NULL},
/* 1181D */ { "LETTRE DOGRA NA",NULL},
/* 1181E */ { "LETTRE DOGRA PA",NULL},
/* 1181F */ { "LETTRE DOGRA PHA","	= lettre dogra p'a"},
/* 11820 */ { "LETTRE DOGRA BA",NULL},
/* 11821 */ { "LETTRE DOGRA BHA",NULL},
/* 11822 */ { "LETTRE DOGRA MA",NULL},
/* 11823 */ { "LETTRE DOGRA YA",NULL},
/* 11824 */ { "LETTRE DOGRA RA",NULL},
/* 11825 */ { "LETTRE DOGRA LA",NULL},
/* 11826 */ { "LETTRE DOGRA VA",NULL},
/* 11827 */ { "LETTRE DOGRA ÇA",NULL},
/* 11828 */ { "LETTRE DOGRA CHA",NULL},
/* 11829 */ { "LETTRE DOGRA SA",NULL},
/* 1182A */ { "LETTRE DOGRA HA",NULL},
/* 1182B */ { "LETTRE DOGRA RRA",NULL},
/* 1182C */ { "DIACRITIQUE VOYELLE DOGRA Â",NULL},
/* 1182D */ { "DIACRITIQUE VOYELLE DOGRA I",NULL},
/* 1182E */ { "DIACRITIQUE VOYELLE DOGRA Î",NULL},
/* 1182F */ { "DIACRITIQUE VOYELLE DOGRA OU",NULL},
/* 11830 */ { "DIACRITIQUE VOYELLE DOGRA OÛ",NULL},
/* 11831 */ { "DIACRITIQUE VOYELLE DOGRA R VOCALIQUE",NULL},
/* 11832 */ { "DIACRITIQUE VOYELLE DOGRA RR VOCALIQUE",NULL},
/* 11833 */ { "DIACRITIQUE VOYELLE DOGRA É",NULL},
/* 11834 */ { "DIACRITIQUE VOYELLE DOGRA AI",NULL},
/* 11835 */ { "DIACRITIQUE VOYELLE DOGRA O",NULL},
/* 11836 */ { "DIACRITIQUE VOYELLE DOGRA AOU",NULL},
/* 11837 */ { "DIACRITIQUE DOGRA ANOUSVÂRA",NULL},
/* 11838 */ { "DIACRITIQUE DOGRA VISARGA",NULL},
/* 11839 */ { "DIACRITIQUE DOGRA VIRÂMA",NULL},
/* 1183A */ { "DIACRITIQUE DOGRA NOUKTA",NULL},
/* 1183B */ { "SIGNE D'ABRÉVIATION DOGRA",NULL},
/* 1183C */ { NULL,NULL},
/* 1183D */ { NULL,NULL},
/* 1183E */ { NULL,NULL},
/* 1183F */ { NULL,NULL},
/* 11840 */ { NULL,NULL},
/* 11841 */ { NULL,NULL},
/* 11842 */ { NULL,NULL},
/* 11843 */ { NULL,NULL},
/* 11844 */ { NULL,NULL},
/* 11845 */ { NULL,NULL},
/* 11846 */ { NULL,NULL},
/* 11847 */ { NULL,NULL},
/* 11848 */ { NULL,NULL},
/* 11849 */ { NULL,NULL},
/* 1184A */ { NULL,NULL},
/* 1184B */ { NULL,NULL},
/* 1184C */ { NULL,NULL},
/* 1184D */ { NULL,NULL},
/* 1184E */ { NULL,NULL},
/* 1184F */ { NULL,NULL},
/* 11850 */ { NULL,NULL},
/* 11851 */ { NULL,NULL},
/* 11852 */ { NULL,NULL},
/* 11853 */ { NULL,NULL},
/* 11854 */ { NULL,NULL},
/* 11855 */ { NULL,NULL},
/* 11856 */ { NULL,NULL},
/* 11857 */ { NULL,NULL},
/* 11858 */ { NULL,NULL},
/* 11859 */ { NULL,NULL},
/* 1185A */ { NULL,NULL},
/* 1185B */ { NULL,NULL},
/* 1185C */ { NULL,NULL},
/* 1185D */ { NULL,NULL},
/* 1185E */ { NULL,NULL},
/* 1185F */ { NULL,NULL},
/* 11860 */ { NULL,NULL},
/* 11861 */ { NULL,NULL},
/* 11862 */ { NULL,NULL},
/* 11863 */ { NULL,NULL},
/* 11864 */ { NULL,NULL},
/* 11865 */ { NULL,NULL},
/* 11866 */ { NULL,NULL},
/* 11867 */ { NULL,NULL},
/* 11868 */ { NULL,NULL},
/* 11869 */ { NULL,NULL},
/* 1186A */ { NULL,NULL},
/* 1186B */ { NULL,NULL},
/* 1186C */ { NULL,NULL},
/* 1186D */ { NULL,NULL},
/* 1186E */ { NULL,NULL},
/* 1186F */ { NULL,NULL},
/* 11870 */ { NULL,NULL},
/* 11871 */ { NULL,NULL},
/* 11872 */ { NULL,NULL},
/* 11873 */ { NULL,NULL},
/* 11874 */ { NULL,NULL},
/* 11875 */ { NULL,NULL},
/* 11876 */ { NULL,NULL},
/* 11877 */ { NULL,NULL},
/* 11878 */ { NULL,NULL},
/* 11879 */ { NULL,NULL},
/* 1187A */ { NULL,NULL},
/* 1187B */ { NULL,NULL},
/* 1187C */ { NULL,NULL},
/* 1187D */ { NULL,NULL},
/* 1187E */ { NULL,NULL},
/* 1187F */ { NULL,NULL},
/* 11880 */ { NULL,NULL},
/* 11881 */ { NULL,NULL},
/* 11882 */ { NULL,NULL},
/* 11883 */ { NULL,NULL},
/* 11884 */ { NULL,NULL},
/* 11885 */ { NULL,NULL},
/* 11886 */ { NULL,NULL},
/* 11887 */ { NULL,NULL},
/* 11888 */ { NULL,NULL},
/* 11889 */ { NULL,NULL},
/* 1188A */ { NULL,NULL},
/* 1188B */ { NULL,NULL},
/* 1188C */ { NULL,NULL},
/* 1188D */ { NULL,NULL},
/* 1188E */ { NULL,NULL},
/* 1188F */ { NULL,NULL},
/* 11890 */ { NULL,NULL},
/* 11891 */ { NULL,NULL},
/* 11892 */ { NULL,NULL},
/* 11893 */ { NULL,NULL},
/* 11894 */ { NULL,NULL},
/* 11895 */ { NULL,NULL},
/* 11896 */ { NULL,NULL},
/* 11897 */ { NULL,NULL},
/* 11898 */ { NULL,NULL},
/* 11899 */ { NULL,NULL},
/* 1189A */ { NULL,NULL},
/* 1189B */ { NULL,NULL},
/* 1189C */ { NULL,NULL},
/* 1189D */ { NULL,NULL},
/* 1189E */ { NULL,NULL},
/* 1189F */ { NULL,NULL},
/* 118A0 */ { "LETTRE MAJUSCULE VARANG KCHITI NGAA","	* fonctionne comme un anousvâra"},
/* 118A1 */ { "LETTRE MAJUSCULE VARANG KCHITI A",NULL},
/* 118A2 */ { "LETTRE MAJUSCULE VARANG KCHITI WI",NULL},
/* 118A3 */ { "LETTRE MAJUSCULE VARANG KCHITI YU",NULL},
/* 118A4 */ { "LETTRE MAJUSCULE VARANG KCHITI YA",NULL},
/* 118A5 */ { "LETTRE MAJUSCULE VARANG KCHITI YO",NULL},
/* 118A6 */ { "LETTRE MAJUSCULE VARANG KCHITI II",NULL},
/* 118A7 */ { "LETTRE MAJUSCULE VARANG KCHITI UU",NULL},
/* 118A8 */ { "LETTRE MAJUSCULE VARANG KCHITI E",NULL},
/* 118A9 */ { "LETTRE MAJUSCULE VARANG KCHITI O",NULL},
/* 118AA */ { "LETTRE MAJUSCULE VARANG KCHITI ANG",NULL},
/* 118AB */ { "LETTRE MAJUSCULE VARANG KCHITI GA",NULL},
/* 118AC */ { "LETTRE MAJUSCULE VARANG KCHITI KO",NULL},
/* 118AD */ { "LETTRE MAJUSCULE VARANG KCHITI ENY",NULL},
/* 118AE */ { "LETTRE MAJUSCULE VARANG KCHITI YUJ",NULL},
/* 118AF */ { "LETTRE MAJUSCULE VARANG KCHITI UC",NULL},
/* 118B0 */ { "LETTRE MAJUSCULE VARANG KCHITI ENN",NULL},
/* 118B1 */ { "LETTRE MAJUSCULE VARANG KCHITI ODD",NULL},
/* 118B2 */ { "LETTRE MAJUSCULE VARANG KCHITI TTE",NULL},
/* 118B3 */ { "LETTRE MAJUSCULE VARANG KCHITI NUNG",NULL},
/* 118B4 */ { "LETTRE MAJUSCULE VARANG KCHITI DA",NULL},
/* 118B5 */ { "LETTRE MAJUSCULE VARANG KCHITI AT",NULL},
/* 118B6 */ { "LETTRE MAJUSCULE VARANG KCHITI AM",NULL},
/* 118B7 */ { "LETTRE MAJUSCULE VARANG KCHITI BU",NULL},
/* 118B8 */ { "LETTRE MAJUSCULE VARANG KCHITI PU",NULL},
/* 118B9 */ { "LETTRE MAJUSCULE VARANG KCHITI HIYO",NULL},
/* 118BA */ { "LETTRE MAJUSCULE VARANG KCHITI HOLO",NULL},
/* 118BB */ { "LETTRE MAJUSCULE VARANG KCHITI HORR",NULL},
/* 118BC */ { "LETTRE MAJUSCULE VARANG KCHITI HAR",NULL},
/* 118BD */ { "LETTRE MAJUSCULE VARANG KCHITI SSUU",NULL},
/* 118BE */ { "LETTRE MAJUSCULE VARANG KCHITI SII",NULL},
/* 118BF */ { "LETTRE MAJUSCULE VARANG KCHITI VIYO",NULL},
/* 118C0 */ { "LETTRE MINUSCULE VARANG KCHITI NGAA",NULL},
/* 118C1 */ { "LETTRE MINUSCULE VARANG KCHITI A",NULL},
/* 118C2 */ { "LETTRE MINUSCULE VARANG KCHITI WI",NULL},
/* 118C3 */ { "LETTRE MINUSCULE VARANG KCHITI YU",NULL},
/* 118C4 */ { "LETTRE MINUSCULE VARANG KCHITI YA",NULL},
/* 118C5 */ { "LETTRE MINUSCULE VARANG KCHITI YO",NULL},
/* 118C6 */ { "LETTRE MINUSCULE VARANG KCHITI II",NULL},
/* 118C7 */ { "LETTRE MINUSCULE VARANG KCHITI UU",NULL},
/* 118C8 */ { "LETTRE MINUSCULE VARANG KCHITI E",NULL},
/* 118C9 */ { "LETTRE MINUSCULE VARANG KCHITI O",NULL},
/* 118CA */ { "LETTRE MINUSCULE VARANG KCHITI ANG",NULL},
/* 118CB */ { "LETTRE MINUSCULE VARANG KCHITI GA",NULL},
/* 118CC */ { "LETTRE MINUSCULE VARANG KCHITI KO",NULL},
/* 118CD */ { "LETTRE MINUSCULE VARANG KCHITI ENY",NULL},
/* 118CE */ { "LETTRE MINUSCULE VARANG KCHITI YUJ",NULL},
/* 118CF */ { "LETTRE MINUSCULE VARANG KCHITI UC",NULL},
/* 118D0 */ { "LETTRE MINUSCULE VARANG KCHITI ENN",NULL},
/* 118D1 */ { "LETTRE MINUSCULE VARANG KCHITI ODD",NULL},
/* 118D2 */ { "LETTRE MINUSCULE VARANG KCHITI TTE",NULL},
/* 118D3 */ { "LETTRE MINUSCULE VARANG KCHITI NUNG",NULL},
/* 118D4 */ { "LETTRE MINUSCULE VARANG KCHITI DA",NULL},
/* 118D5 */ { "LETTRE MINUSCULE VARANG KCHITI AT",NULL},
/* 118D6 */ { "LETTRE MINUSCULE VARANG KCHITI AM",NULL},
/* 118D7 */ { "LETTRE MINUSCULE VARANG KCHITI BU",NULL},
/* 118D8 */ { "LETTRE MINUSCULE VARANG KCHITI PU",NULL},
/* 118D9 */ { "LETTRE MINUSCULE VARANG KCHITI HIYO",NULL},
/* 118DA */ { "LETTRE MINUSCULE VARANG KCHITI HOLO",NULL},
/* 118DB */ { "LETTRE MINUSCULE VARANG KCHITI HORR",NULL},
/* 118DC */ { "LETTRE MINUSCULE VARANG KCHITI HAR",NULL},
/* 118DD */ { "LETTRE MINUSCULE VARANG KCHITI SSUU",NULL},
/* 118DE */ { "LETTRE MINUSCULE VARANG KCHITI SII",NULL},
/* 118DF */ { "LETTRE MINUSCULE VARANG KCHITI VIYO",NULL},
/* 118E0 */ { "CHIFFRE VARANG KCHITI ZÉRO",NULL},
/* 118E1 */ { "CHIFFRE VARANG KCHITI UN",NULL},
/* 118E2 */ { "CHIFFRE VARANG KCHITI DEUX",NULL},
/* 118E3 */ { "CHIFFRE VARANG KCHITI TROIS",NULL},
/* 118E4 */ { "CHIFFRE VARANG KCHITI QUATRE",NULL},
/* 118E5 */ { "CHIFFRE VARANG KCHITI CINQ",NULL},
/* 118E6 */ { "CHIFFRE VARANG KCHITI SIX",NULL},
/* 118E7 */ { "CHIFFRE VARANG KCHITI SEPT",NULL},
/* 118E8 */ { "CHIFFRE VARANG KCHITI HUIT",NULL},
/* 118E9 */ { "CHIFFRE VARANG KCHITI NEUF",NULL},
/* 118EA */ { "NOMBRE VARANG KCHITI DIX",NULL},
/* 118EB */ { "NOMBRE VARANG KCHITI VINGT",NULL},
/* 118EC */ { "NOMBRE VARANG KCHITI TRENTE",NULL},
/* 118ED */ { "NOMBRE VARANG KCHITI QUARANTE",NULL},
/* 118EE */ { "NOMBRE VARANG KCHITI CINQUANTE",NULL},
/* 118EF */ { "NOMBRE VARANG KCHITI SOIXANTE",NULL},
/* 118F0 */ { "NOMBRE VARANG KCHITI SOIXANTE-DIX","	= nombre varang kchiti septante"},
/* 118F1 */ { "NOMBRE VARANG KCHITI QUATRE-VINGTS","	= nombre varang kchiti huitante"},
/* 118F2 */ { "NOMBRE VARANG KCHITI QUATRE-VINGT-DIX","	= nombre varang kchiti nonante"},
/* 118F3 */ { NULL,NULL},
/* 118F4 */ { NULL,NULL},
/* 118F5 */ { NULL,NULL},
/* 118F6 */ { NULL,NULL},
/* 118F7 */ { NULL,NULL},
/* 118F8 */ { NULL,NULL},
/* 118F9 */ { NULL,NULL},
/* 118FA */ { NULL,NULL},
/* 118FB */ { NULL,NULL},
/* 118FC */ { NULL,NULL},
/* 118FD */ { NULL,NULL},
/* 118FE */ { NULL,NULL},
/* 118FF */ { "OM VARANG KCHITI",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_19[] = {
/* 11900 */ { "LETTRE DIVES AKURU A",NULL},
/* 11901 */ { "LETTRE DIVES AKURU Â",NULL},
/* 11902 */ { "LETTRE DIVES AKURU I",NULL},
/* 11903 */ { "LETTRE DIVES AKURU Î",NULL},
/* 11904 */ { "LETTRE DIVES AKURU OU",NULL},
/* 11905 */ { "LETTRE DIVES AKURU OÛ",NULL},
/* 11906 */ { "LETTRE DIVES AKURU É",NULL},
/* 11907 */ { NULL,NULL},
/* 11908 */ { NULL,NULL},
/* 11909 */ { "LETTRE DIVES AKURU O",NULL},
/* 1190A */ { NULL,NULL},
/* 1190B */ { NULL,NULL},
/* 1190C */ { "LETTRE DIVES AKURU KA",NULL},
/* 1190D */ { "LETTRE DIVES AKURU KHA",NULL},
/* 1190E */ { "LETTRE DIVES AKURU GA",NULL},
/* 1190F */ { "LETTRE DIVES AKURU GHA",NULL},
/* 11910 */ { "LETTRE DIVES AKURU NGA",NULL},
/* 11911 */ { "LETTRE DIVES AKURU TCHA",NULL},
/* 11912 */ { "LETTRE DIVES AKURU TCHHA",NULL},
/* 11913 */ { "LETTRE DIVES AKURU DJA",NULL},
/* 11914 */ { NULL,NULL},
/* 11915 */ { "LETTRE DIVES AKURU ÑA",NULL},
/* 11916 */ { "LETTRE DIVES AKURU TTA",NULL},
/* 11917 */ { NULL,NULL},
/* 11918 */ { "LETTRE DIVES AKURU DDA",NULL},
/* 11919 */ { "LETTRE DIVES AKURU DDHA",NULL},
/* 1191A */ { "LETTRE DIVES AKURU NNA",NULL},
/* 1191B */ { "LETTRE DIVES AKURU TA",NULL},
/* 1191C */ { "LETTRE DIVES AKURU THA",NULL},
/* 1191D */ { "LETTRE DIVES AKURU DA",NULL},
/* 1191E */ { "LETTRE DIVES AKURU DHA",NULL},
/* 1191F */ { "LETTRE DIVES AKURU NA",NULL},
/* 11920 */ { "LETTRE DIVES AKURU PA",NULL},
/* 11921 */ { "LETTRE DIVES AKURU PHA","	= lettre dives akuru p'a"},
/* 11922 */ { "LETTRE DIVES AKURU BA",NULL},
/* 11923 */ { "LETTRE DIVES AKURU BHA",NULL},
/* 11924 */ { "LETTRE DIVES AKURU MA",NULL},
/* 11925 */ { "LETTRE DIVES AKURU YA","	* également utilisée comme support de voyelle"},
/* 11926 */ { "LETTRE DIVES AKURU YYA",NULL},
/* 11927 */ { "LETTRE DIVES AKURU RA",NULL},
/* 11928 */ { "LETTRE DIVES AKURU LA",NULL},
/* 11929 */ { "LETTRE DIVES AKURU VA",NULL},
/* 1192A */ { "LETTRE DIVES AKURU ÇA",NULL},
/* 1192B */ { "LETTRE DIVES AKURU CHA",NULL},
/* 1192C */ { "LETTRE DIVES AKURU SA",NULL},
/* 1192D */ { "LETTRE DIVES AKURU HA",NULL},
/* 1192E */ { "LETTRE DIVES AKURU LLA",NULL},
/* 1192F */ { "LETTRE DIVES AKURU ZA",NULL},
/* 11930 */ { "DIACRITIQUE VOYELLE DIVES AKURU Â",NULL},
/* 11931 */ { "DIACRITIQUE VOYELLE DIVES AKURU I",NULL},
/* 11932 */ { "DIACRITIQUE VOYELLE DIVES AKURU Î",NULL},
/* 11933 */ { "DIACRITIQUE VOYELLE DIVES AKURU OU",NULL},
/* 11934 */ { "DIACRITIQUE VOYELLE DIVES AKURU OÛ",NULL},
/* 11935 */ { "DIACRITIQUE VOYELLE DIVES AKURU É",NULL},
/* 11936 */ { NULL,NULL},
/* 11937 */ { "DIACRITIQUE VOYELLE DIVES AKURU AÏ",NULL},
/* 11938 */ { "DIACRITIQUE VOYELLE DIVES AKURU O","	: 11935 11930"},
/* 11939 */ { NULL,NULL},
/* 1193A */ { NULL,NULL},
/* 1193B */ { "DIACRITIQUE DIVES AKURU ANOUSVÂRA",NULL},
/* 1193C */ { "DIACRITIQUE DIVES AKURU TCHANDRABINDOU",NULL},
/* 1193D */ { "DIACRITIQUE DIVES AKURU HALANTA","	= soukoun\n"
	"	* signe « tueur », qui indique qu'on ne lit pas la voyelle inhérente"},
/* 1193E */ { "DIACRITIQUE DIVES AKURU VIRÂMA","	* utilisé pour la production de ligatures\n"
	"	* utilisé aussi pour produire une ligature constituée d'une consonne dévoyellée et d'une voyelle indépendante"},
/* 1193F */ { "SIGNE NASAL PRÉFIXÉ DIVES AKURU","	* utilisé pour une nasale homorganique en position initiale d'un groupe"},
/* 11940 */ { "YA MÉDIAL DIVES AKURU","	* utilisé pour le ya non initial dans des ligatures"},
/* 11941 */ { "RA INITIAL DIVES AKURU","	= rép'a\n"
	"	* utilisé pour le ra initial dans des ligatures"},
/* 11942 */ { "RA MÉDIAL DIVES AKURU","	* utilisé pour le ra non initial dans des ligatures"},
/* 11943 */ { "DIACRITIQUE DIVES AKURU NOUKTA","	* diacritique moderne utilisé pour étendre l'alphabet"},
/* 11944 */ { "DOUBLE DANDA DIVES AKURU",NULL},
/* 11945 */ { "BOURRE D'ÉCART DIVES AKURU",NULL},
/* 11946 */ { "SIGNE DE FIN DE TEXTE DIVES AKURU",NULL},
/* 11947 */ { NULL,NULL},
/* 11948 */ { NULL,NULL},
/* 11949 */ { NULL,NULL},
/* 1194A */ { NULL,NULL},
/* 1194B */ { NULL,NULL},
/* 1194C */ { NULL,NULL},
/* 1194D */ { NULL,NULL},
/* 1194E */ { NULL,NULL},
/* 1194F */ { NULL,NULL},
/* 11950 */ { "CHIFFRE DIVES AKURU ZÉRO",NULL},
/* 11951 */ { "CHIFFRE DIVES AKURU UN",NULL},
/* 11952 */ { "CHIFFRE DIVES AKURU DEUX",NULL},
/* 11953 */ { "CHIFFRE DIVES AKURU TROIS",NULL},
/* 11954 */ { "CHIFFRE DIVES AKURU QUATRE",NULL},
/* 11955 */ { "CHIFFRE DIVES AKURU CINQ",NULL},
/* 11956 */ { "CHIFFRE DIVES AKURU SIX",NULL},
/* 11957 */ { "CHIFFRE DIVES AKURU SEPT",NULL},
/* 11958 */ { "CHIFFRE DIVES AKURU HUIT",NULL},
/* 11959 */ { "CHIFFRE DIVES AKURU NEUF",NULL},
/* 1195A */ { NULL,NULL},
/* 1195B */ { NULL,NULL},
/* 1195C */ { NULL,NULL},
/* 1195D */ { NULL,NULL},
/* 1195E */ { NULL,NULL},
/* 1195F */ { NULL,NULL},
/* 11960 */ { NULL,NULL},
/* 11961 */ { NULL,NULL},
/* 11962 */ { NULL,NULL},
/* 11963 */ { NULL,NULL},
/* 11964 */ { NULL,NULL},
/* 11965 */ { NULL,NULL},
/* 11966 */ { NULL,NULL},
/* 11967 */ { NULL,NULL},
/* 11968 */ { NULL,NULL},
/* 11969 */ { NULL,NULL},
/* 1196A */ { NULL,NULL},
/* 1196B */ { NULL,NULL},
/* 1196C */ { NULL,NULL},
/* 1196D */ { NULL,NULL},
/* 1196E */ { NULL,NULL},
/* 1196F */ { NULL,NULL},
/* 11970 */ { NULL,NULL},
/* 11971 */ { NULL,NULL},
/* 11972 */ { NULL,NULL},
/* 11973 */ { NULL,NULL},
/* 11974 */ { NULL,NULL},
/* 11975 */ { NULL,NULL},
/* 11976 */ { NULL,NULL},
/* 11977 */ { NULL,NULL},
/* 11978 */ { NULL,NULL},
/* 11979 */ { NULL,NULL},
/* 1197A */ { NULL,NULL},
/* 1197B */ { NULL,NULL},
/* 1197C */ { NULL,NULL},
/* 1197D */ { NULL,NULL},
/* 1197E */ { NULL,NULL},
/* 1197F */ { NULL,NULL},
/* 11980 */ { NULL,NULL},
/* 11981 */ { NULL,NULL},
/* 11982 */ { NULL,NULL},
/* 11983 */ { NULL,NULL},
/* 11984 */ { NULL,NULL},
/* 11985 */ { NULL,NULL},
/* 11986 */ { NULL,NULL},
/* 11987 */ { NULL,NULL},
/* 11988 */ { NULL,NULL},
/* 11989 */ { NULL,NULL},
/* 1198A */ { NULL,NULL},
/* 1198B */ { NULL,NULL},
/* 1198C */ { NULL,NULL},
/* 1198D */ { NULL,NULL},
/* 1198E */ { NULL,NULL},
/* 1198F */ { NULL,NULL},
/* 11990 */ { NULL,NULL},
/* 11991 */ { NULL,NULL},
/* 11992 */ { NULL,NULL},
/* 11993 */ { NULL,NULL},
/* 11994 */ { NULL,NULL},
/* 11995 */ { NULL,NULL},
/* 11996 */ { NULL,NULL},
/* 11997 */ { NULL,NULL},
/* 11998 */ { NULL,NULL},
/* 11999 */ { NULL,NULL},
/* 1199A */ { NULL,NULL},
/* 1199B */ { NULL,NULL},
/* 1199C */ { NULL,NULL},
/* 1199D */ { NULL,NULL},
/* 1199E */ { NULL,NULL},
/* 1199F */ { NULL,NULL},
/* 119A0 */ { "LETTRE NANDINÂGARÎ A",NULL},
/* 119A1 */ { "LETTRE NANDINÂGARÎ Â",NULL},
/* 119A2 */ { "LETTRE NANDINÂGARÎ I",NULL},
/* 119A3 */ { "LETTRE NANDINÂGARÎ Î",NULL},
/* 119A4 */ { "LETTRE NANDINÂGARÎ OU",NULL},
/* 119A5 */ { "LETTRE NANDINÂGARÎ OÛ",NULL},
/* 119A6 */ { "LETTRE NANDINÂGARÎ R VOCALIQUE",NULL},
/* 119A7 */ { "LETTRE NANDINÂGARÎ RR VOCALIQUE",NULL},
/* 119A8 */ { NULL,NULL},
/* 119A9 */ { NULL,NULL},
/* 119AA */ { "LETTRE NANDINÂGARÎ É",NULL},
/* 119AB */ { "LETTRE NANDINÂGARÎ AI",NULL},
/* 119AC */ { "LETTRE NANDINÂGARÎ O",NULL},
/* 119AD */ { "LETTRE NANDINÂGARÎ AOU",NULL},
/* 119AE */ { "LETTRE NANDINÂGARÎ KA",NULL},
/* 119AF */ { "LETTRE NANDINÂGARÎ KHA",NULL},
/* 119B0 */ { "LETTRE NANDINÂGARÎ GA",NULL},
/* 119B1 */ { "LETTRE NANDINÂGARÎ GHA",NULL},
/* 119B2 */ { "LETTRE NANDINÂGARÎ NGA",NULL},
/* 119B3 */ { "LETTRE NANDINÂGARÎ TCHA",NULL},
/* 119B4 */ { "LETTRE NANDINÂGARÎ TCHHA",NULL},
/* 119B5 */ { "LETTRE NANDINÂGARÎ DJA",NULL},
/* 119B6 */ { "LETTRE NANDINÂGARÎ DJHA",NULL},
/* 119B7 */ { "LETTRE NANDINÂGARÎ ÑA",NULL},
/* 119B8 */ { "LETTRE NANDINÂGARÎ TTA",NULL},
/* 119B9 */ { "LETTRE NANDINÂGARÎ TTHA",NULL},
/* 119BA */ { "LETTRE NANDINÂGARÎ DDA",NULL},
/* 119BB */ { "LETTRE NANDINÂGARÎ DDHA",NULL},
/* 119BC */ { "LETTRE NANDINÂGARÎ NNA",NULL},
/* 119BD */ { "LETTRE NANDINÂGARÎ TA",NULL},
/* 119BE */ { "LETTRE NANDINÂGARÎ THA",NULL},
/* 119BF */ { "LETTRE NANDINÂGARÎ DA",NULL},
/* 119C0 */ { "LETTRE NANDINÂGARÎ DHA",NULL},
/* 119C1 */ { "LETTRE NANDINÂGARÎ NA",NULL},
/* 119C2 */ { "LETTRE NANDINÂGARÎ PA",NULL},
/* 119C3 */ { "LETTRE NANDINÂGARÎ PHA","	= lettre nandinâgarî p'a"},
/* 119C4 */ { "LETTRE NANDINÂGARÎ BA",NULL},
/* 119C5 */ { "LETTRE NANDINÂGARÎ BHA",NULL},
/* 119C6 */ { "LETTRE NANDINÂGARÎ MA",NULL},
/* 119C7 */ { "LETTRE NANDINÂGARÎ YA",NULL},
/* 119C8 */ { "LETTRE NANDINÂGARÎ RA",NULL},
/* 119C9 */ { "LETTRE NANDINÂGARÎ LA",NULL},
/* 119CA */ { "LETTRE NANDINÂGARÎ VA",NULL},
/* 119CB */ { "LETTRE NANDINÂGARÎ ÇA",NULL},
/* 119CC */ { "LETTRE NANDINÂGARÎ CHA",NULL},
/* 119CD */ { "LETTRE NANDINÂGARÎ SA",NULL},
/* 119CE */ { "LETTRE NANDINÂGARÎ HA",NULL},
/* 119CF */ { "LETTRE NANDINÂGARÎ LLA",NULL},
/* 119D0 */ { "LETTRE NANDINÂGARÎ RRA",NULL},
/* 119D1 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ Â",NULL},
/* 119D2 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ I",NULL},
/* 119D3 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ Î",NULL},
/* 119D4 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ OU",NULL},
/* 119D5 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ OÛ",NULL},
/* 119D6 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ R VOCALIQUE",NULL},
/* 119D7 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ RR VOCALIQUE",NULL},
/* 119D8 */ { NULL,NULL},
/* 119D9 */ { NULL,NULL},
/* 119DA */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ É",NULL},
/* 119DB */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ AI",NULL},
/* 119DC */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ O",NULL},
/* 119DD */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ AOU",NULL},
/* 119DE */ { "DIACRITIQUE NANDINÂGARÎ ANOUSVÂRA",NULL},
/* 119DF */ { "DIACRITIQUE NANDINÂGARÎ VISARGA",NULL},
/* 119E0 */ { "DIACRITIQUE NANDINÂGARÎ VIRÂMA",NULL},
/* 119E1 */ { "SIGNE NANDINÂGARÎ AVAGRAHA",NULL},
/* 119E2 */ { "SIGNE NANDINÂGARÎ SIDDHAM",NULL},
/* 119E3 */ { "BARRE DE TÊTE NANDINÂGARÎ","	* utilisée comme marque d'espacement ou de remplissage"},
/* 119E4 */ { "DIACRITIQUE VOYELLE NANDINÂGARÎ E PRISHTHAMATRA",NULL},
/* 119E5 */ { NULL,NULL},
/* 119E6 */ { NULL,NULL},
/* 119E7 */ { NULL,NULL},
/* 119E8 */ { NULL,NULL},
/* 119E9 */ { NULL,NULL},
/* 119EA */ { NULL,NULL},
/* 119EB */ { NULL,NULL},
/* 119EC */ { NULL,NULL},
/* 119ED */ { NULL,NULL},
/* 119EE */ { NULL,NULL},
/* 119EF */ { NULL,NULL},
/* 119F0 */ { NULL,NULL},
/* 119F1 */ { NULL,NULL},
/* 119F2 */ { NULL,NULL},
/* 119F3 */ { NULL,NULL},
/* 119F4 */ { NULL,NULL},
/* 119F5 */ { NULL,NULL},
/* 119F6 */ { NULL,NULL},
/* 119F7 */ { NULL,NULL},
/* 119F8 */ { NULL,NULL},
/* 119F9 */ { NULL,NULL},
/* 119FA */ { NULL,NULL},
/* 119FB */ { NULL,NULL},
/* 119FC */ { NULL,NULL},
/* 119FD */ { NULL,NULL},
/* 119FE */ { NULL,NULL},
/* 119FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_1A[] = {
/* 11A00 */ { "LETTRE ZANABAZAR CARRÉ A","	* s'utilise pour représenter des voyelles indépendantes en combinaison avec des signes voyelles"},
/* 11A01 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ I",NULL},
/* 11A02 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ U",NULL},
/* 11A03 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ OU",NULL},
/* 11A04 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ É",NULL},
/* 11A05 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ E",NULL},
/* 11A06 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ O",NULL},
/* 11A07 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ AI","	* représente aussi la voyelle secondaire i"},
/* 11A08 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ AOU","	* représente aussi la voyelle secondaire ou"},
/* 11A09 */ { "DIACRITIQUE VOYELLE ZANABAZAR CARRÉ I RÉFLÉCHI","	* s'utilise pour les sons vocaliques sanskrits"},
/* 11A0A */ { "SIGNE ZANABAZAR CARRÉ DE LONGUEUR DE VOYELLE",NULL},
/* 11A0B */ { "LETTRE ZANABAZAR CARRÉ KA",NULL},
/* 11A0C */ { "LETTRE ZANABAZAR CARRÉ KHA",NULL},
/* 11A0D */ { "LETTRE ZANABAZAR CARRÉ GA",NULL},
/* 11A0E */ { "LETTRE ZANABAZAR CARRÉ GHA",NULL},
/* 11A0F */ { "LETTRE ZANABAZAR CARRÉ NGA",NULL},
/* 11A10 */ { "LETTRE ZANABAZAR CARRÉ TCHA",NULL},
/* 11A11 */ { "LETTRE ZANABAZAR CARRÉ TCHHA",NULL},
/* 11A12 */ { "LETTRE ZANABAZAR CARRÉ DJA",NULL},
/* 11A13 */ { "LETTRE ZANABAZAR CARRÉ ÑA",NULL},
/* 11A14 */ { "LETTRE ZANABAZAR CARRÉ TTA",NULL},
/* 11A15 */ { "LETTRE ZANABAZAR CARRÉ TTHA",NULL},
/* 11A16 */ { "LETTRE ZANABAZAR CARRÉ DDA",NULL},
/* 11A17 */ { "LETTRE ZANABAZAR CARRÉ DDHA",NULL},
/* 11A18 */ { "LETTRE ZANABAZAR CARRÉ NNA",NULL},
/* 11A19 */ { "LETTRE ZANABAZAR CARRÉ TA",NULL},
/* 11A1A */ { "LETTRE ZANABAZAR CARRÉ THA",NULL},
/* 11A1B */ { "LETTRE ZANABAZAR CARRÉ DA",NULL},
/* 11A1C */ { "LETTRE ZANABAZAR CARRÉ DHA",NULL},
/* 11A1D */ { "LETTRE ZANABAZAR CARRÉ NA",NULL},
/* 11A1E */ { "LETTRE ZANABAZAR CARRÉ PA",NULL},
/* 11A1F */ { "LETTRE ZANABAZAR CARRÉ PHA","	= lettre zanabazar carré p'a"},
/* 11A20 */ { "LETTRE ZANABAZAR CARRÉ BA","	* utilisée aussi à la place de 11A2D non initial dans des ligatures"},
/* 11A21 */ { "LETTRE ZANABAZAR CARRÉ BHA",NULL},
/* 11A22 */ { "LETTRE ZANABAZAR CARRÉ MA",NULL},
/* 11A23 */ { "LETTRE ZANABAZAR CARRÉ TSA",NULL},
/* 11A24 */ { "LETTRE ZANABAZAR CARRÉ TÇA",NULL},
/* 11A25 */ { "LETTRE ZANABAZAR CARRÉ DZA",NULL},
/* 11A26 */ { "LETTRE ZANABAZAR CARRÉ DZHA",NULL},
/* 11A27 */ { "LETTRE ZANABAZAR CARRÉ ZHA",NULL},
/* 11A28 */ { "LETTRE ZANABAZAR CARRÉ ZA",NULL},
/* 11A29 */ { "LETTRE ZANABAZAR CARRÉ 'A","	* aang mongol\n"
	"	* a-tchoung tibétain\n"
	"	x (lettre tibétaine 'a - 0F60)"},
/* 11A2A */ { "LETTRE ZANABAZAR CARRÉ YA",NULL},
/* 11A2B */ { "LETTRE ZANABAZAR CARRÉ RA",NULL},
/* 11A2C */ { "LETTRE ZANABAZAR CARRÉ LA",NULL},
/* 11A2D */ { "LETTRE ZANABAZAR CARRÉ VA",NULL},
/* 11A2E */ { "LETTRE ZANABAZAR CARRÉ ÇA",NULL},
/* 11A2F */ { "LETTRE ZANABAZAR CARRÉ CHA",NULL},
/* 11A30 */ { "LETTRE ZANABAZAR CARRÉ SA",NULL},
/* 11A31 */ { "LETTRE ZANABAZAR CARRÉ HA",NULL},
/* 11A32 */ { "LETTRE ZANABAZAR CARRÉ KCHA",NULL},
/* 11A33 */ { "DIACRITIQUE ZANABAZAR CARRÉ DE CONSONNE FINALE","	* s'utilise avec une consonne finale de syllabe en mongol\n"
	"	* indique une frontière syllabique en mongol"},
/* 11A34 */ { "DIACRITIQUE ZANABAZAR CARRÉ VIRÂMA","	* indique une consonne nue en sanskrit et en tibétain\n"
	"	* n'est pas utilisé pour la création de ligatures\n"
	"	x (diacritique tibétain halanta - 0F84)"},
/* 11A35 */ { "DIACRITIQUE ZANABAZAR CARRÉ TCHANDRABINDOU","	* indique la nasalisation\n"
	"	x (diacritique tibétain sna ldan - 0F83)\n"
	"	x (lettre mongole anousvâra un ali gali - 1880)"},
/* 11A36 */ { "DIACRITIQUE ZANABAZAR CARRÉ TCHANDRABINDOU ORNÉ","	* utilisé principalement avec 11A3F"},
/* 11A37 */ { "DIACRITIQUE ZANABAZAR CARRÉ TCHANDRA ORNÉ","	* utilisé principalement avec 11A3F\n"
	"	x (diacritique tibétain ñi zla nâ da - 0F82)"},
/* 11A38 */ { "DIACRITIQUE ZANABAZAR CARRÉ ANOUSVÂRA","	* indique la nasalisation\n"
	"	x (diacritique tibétain rdjes sou nga ro - 0F7E)"},
/* 11A39 */ { "DIACRITIQUE ZANABAZAR CARRÉ VISARGA","	* indique l'aspiration post-vocalique\n"
	"	x (diacritique tibétain rnam btchad - 0F7F)"},
/* 11A3A */ { "LETTRE INITIALE DE GROUPE ZANABAZAR CARRÉ RA","	* forme initiale de 11A2B dans les ligatures tibétaines"},
/* 11A3B */ { "LETTRE FINALE DE GROUPE ZANABAZAR CARRÉ YA","	* forme finale de 11A2A dans les ligatures tibétaines"},
/* 11A3C */ { "LETTRE FINALE DE GROUPE ZANABAZAR CARRÉ RA","	* forme finale de 11A2B dans les ligatures tibétaines"},
/* 11A3D */ { "LETTRE FINALE DE GROUPE ZANABAZAR CARRÉ LA","	* forme finale de 11A2C dans les ligatures tibétaines"},
/* 11A3E */ { "LETTRE FINALE DE GROUPE ZANABAZAR CARRÉ VA","	* forme finale de 11A2D dans les ligatures tibétaines"},
/* 11A3F */ { "REPÈRE DE DÉBUT ZANABAZAR CARRÉ INITIAL","	x (signe tibétain brda rñing yig mgo mdoun ma ouvrant - 0FD3)\n"
	"	x (birga mongol - 1800)"},
/* 11A40 */ { "REPÈRE DE DÉBUT ZANABAZAR CARRÉ FERMANT","	x (signe tibétain brda rñing yig mgo sgab ma fermant - 0FD4)"},
/* 11A41 */ { "SIGNE ZANABAZAR CARRÉ TÇEG","	x (signe tibétain tçeg - 0F0B)"},
/* 11A42 */ { "SIGNE ZANABAZAR CARRÉ ÇAD","	x (signe tibétain çad - 0F0D)"},
/* 11A43 */ { "SIGNE ZANABAZAR CARRÉ DOUBLE ÇAD","	x (signe tibétain ñis çad - 0F0E)"},
/* 11A44 */ { "SIGNE ZANABAZAR CARRÉ LONG TÇEG","	x (signe tibétain gter tçeg - 0F14)"},
/* 11A45 */ { "REPÈRE DE DÉBUT ZANABAZAR CARRÉ À DOUBLE TRAIT INITIAL","	x (signe tibétain yig mgo mdoun ma ouvrant - 0F04)"},
/* 11A46 */ { "REPÈRE DE DÉBUT ZANABAZAR CARRÉ À DOUBLE TRAIT FERMANT","	x (signe tibétain yig mgo sgab ma fermant - 0F05)"},
/* 11A47 */ { "DIACRITIQUE D'EMPILEMENT ZANABAZAR CARRÉ","	* sert à créer des ligatures de consonnes"},
/* 11A48 */ { NULL,NULL},
/* 11A49 */ { NULL,NULL},
/* 11A4A */ { NULL,NULL},
/* 11A4B */ { NULL,NULL},
/* 11A4C */ { NULL,NULL},
/* 11A4D */ { NULL,NULL},
/* 11A4E */ { NULL,NULL},
/* 11A4F */ { NULL,NULL},
/* 11A50 */ { "LETTRE SOYOMBO A","	* s'utilise pour représenter des voyelles indépendantes en combinaison avec des signes voyelles"},
/* 11A51 */ { "DIACRITIQUE VOYELLE SOYOMBO I",NULL},
/* 11A52 */ { "DIACRITIQUE VOYELLE SOYOMBO U",NULL},
/* 11A53 */ { "DIACRITIQUE VOYELLE SOYOMBO OU",NULL},
/* 11A54 */ { "DIACRITIQUE VOYELLE SOYOMBO É",NULL},
/* 11A55 */ { "DIACRITIQUE VOYELLE SOYOMBO O",NULL},
/* 11A56 */ { "DIACRITIQUE VOYELLE SOYOMBO E",NULL},
/* 11A57 */ { "DIACRITIQUE VOYELLE SOYOMBO AI",NULL},
/* 11A58 */ { "DIACRITIQUE VOYELLE SOYOMBO AOU",NULL},
/* 11A59 */ { "DIACRITIQUE VOYELLE SOYOMBO R VOCALIQUE",NULL},
/* 11A5A */ { "DIACRITIQUE VOYELLE SOYOMBO L VOCALIQUE",NULL},
/* 11A5B */ { "SIGNE SOYOMBO DE LONGUEUR DE VOYELLE",NULL},
/* 11A5C */ { "LETTRE SOYOMBO KA",NULL},
/* 11A5D */ { "LETTRE SOYOMBO KHA",NULL},
/* 11A5E */ { "LETTRE SOYOMBO GA",NULL},
/* 11A5F */ { "LETTRE SOYOMBO GHA",NULL},
/* 11A60 */ { "LETTRE SOYOMBO NGA",NULL},
/* 11A61 */ { "LETTRE SOYOMBO TCHA",NULL},
/* 11A62 */ { "LETTRE SOYOMBO TCHHA",NULL},
/* 11A63 */ { "LETTRE SOYOMBO DJA",NULL},
/* 11A64 */ { "LETTRE SOYOMBO DJHA",NULL},
/* 11A65 */ { "LETTRE SOYOMBO ÑA",NULL},
/* 11A66 */ { "LETTRE SOYOMBO TTA",NULL},
/* 11A67 */ { "LETTRE SOYOMBO TTHA",NULL},
/* 11A68 */ { "LETTRE SOYOMBO DDA",NULL},
/* 11A69 */ { "LETTRE SOYOMBO DDHA",NULL},
/* 11A6A */ { "LETTRE SOYOMBO NNA",NULL},
/* 11A6B */ { "LETTRE SOYOMBO TA",NULL},
/* 11A6C */ { "LETTRE SOYOMBO THA",NULL},
/* 11A6D */ { "LETTRE SOYOMBO DA",NULL},
/* 11A6E */ { "LETTRE SOYOMBO DHA",NULL},
/* 11A6F */ { "LETTRE SOYOMBO NA",NULL},
/* 11A70 */ { "LETTRE SOYOMBO PA",NULL},
/* 11A71 */ { "LETTRE SOYOMBO PHA","	= lettre soyombo p'a"},
/* 11A72 */ { "LETTRE SOYOMBO BA",NULL},
/* 11A73 */ { "LETTRE SOYOMBO BHA",NULL},
/* 11A74 */ { "LETTRE SOYOMBO MA",NULL},
/* 11A75 */ { "LETTRE SOYOMBO TSA",NULL},
/* 11A76 */ { "LETTRE SOYOMBO TÇA",NULL},
/* 11A77 */ { "LETTRE SOYOMBO DZA",NULL},
/* 11A78 */ { "LETTRE SOYOMBO ZHA",NULL},
/* 11A79 */ { "LETTRE SOYOMBO ZA",NULL},
/* 11A7A */ { "LETTRE SOYOMBO 'A",NULL},
/* 11A7B */ { "LETTRE SOYOMBO YA",NULL},
/* 11A7C */ { "LETTRE SOYOMBO RA",NULL},
/* 11A7D */ { "LETTRE SOYOMBO LA",NULL},
/* 11A7E */ { "LETTRE SOYOMBO VA",NULL},
/* 11A7F */ { "LETTRE SOYOMBO ÇA",NULL},
/* 11A80 */ { "LETTRE SOYOMBO CHA",NULL},
/* 11A81 */ { "LETTRE SOYOMBO SA",NULL},
/* 11A82 */ { "LETTRE SOYOMBO HA",NULL},
/* 11A83 */ { "LETTRE SOYOMBO KCHA",NULL},
/* 11A84 */ { "SIGNE SOYOMBO DJIHVAMOULIYA","	x (signe védique djihvamouliya - 1CF5)"},
/* 11A85 */ { "SIGNE SOYOMBO OUPADHMANIYA","	x (signe védique oupadhmaniya - 1CF6)"},
/* 11A86 */ { "LETTRE INITIALE DE GROUPE SOYOMBO RA",NULL},
/* 11A87 */ { "LETTRE INITIALE DE GROUPE SOYOMBO LA",NULL},
/* 11A88 */ { "LETTRE INITIALE DE GROUPE SOYOMBO ÇA",NULL},
/* 11A89 */ { "LETTRE INITIALE DE GROUPE SOYOMBO SA",NULL},
/* 11A8A */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO G",NULL},
/* 11A8B */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO K",NULL},
/* 11A8C */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO NG",NULL},
/* 11A8D */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO D",NULL},
/* 11A8E */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO N",NULL},
/* 11A8F */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO B",NULL},
/* 11A90 */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO M",NULL},
/* 11A91 */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO R",NULL},
/* 11A92 */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO L",NULL},
/* 11A93 */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO CH",NULL},
/* 11A94 */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO S",NULL},
/* 11A95 */ { "DIACRITIQUE CONSONNE FINALE SOYOMBO 'A","	* aang mongol\n"
	"	* a-tchoung tibétain\n"
	"	x (lettre tibétaine 'a - 0F60)"},
/* 11A96 */ { "DIACRITIQUE SOYOMBO ANOUSVÂRA",NULL},
/* 11A97 */ { "DIACRITIQUE SOYOMBO VISARGA",NULL},
/* 11A98 */ { "DIACRITIQUE SOYOMBO DE GÉMINATION",NULL},
/* 11A99 */ { "DIACRITIQUE D'EMPILEMENT SOYOMBO","	* sert à créer des ligatures de consonnes"},
/* 11A9A */ { "SIGNE SOYOMBO TÇEG",NULL},
/* 11A9B */ { "SIGNE SOYOMBO ÇAD",NULL},
/* 11A9C */ { "SIGNE SOYOMBO DOUBLE ÇAD",NULL},
/* 11A9D */ { "SIGNE SOYOMBO PLOUTA","	* marque un allongement vocalique"},
/* 11A9E */ { "REPÈRE DE DÉBUT SOYOMBO AVEC LUNE ET SOLEIL ET TRIPLE FLAMME","	* emblème national de la Mongolie"},
/* 11A9F */ { "REPÈRE DE DÉBUT SOYOMBO AVEC LUNE ET SOLEIL ET FLAMME",NULL},
/* 11AA0 */ { "REPÈRE DE DÉBUT SOYOMBO AVEC LUNE ET SOLEIL",NULL},
/* 11AA1 */ { "REPÈRE DE FIN SOYOMBO 1",NULL},
/* 11AA2 */ { "REPÈRE DE FIN SOYOMBO 2","	= cintamani, candamani"},
/* 11AA3 */ { NULL,NULL},
/* 11AA4 */ { NULL,NULL},
/* 11AA5 */ { NULL,NULL},
/* 11AA6 */ { NULL,NULL},
/* 11AA7 */ { NULL,NULL},
/* 11AA8 */ { NULL,NULL},
/* 11AA9 */ { NULL,NULL},
/* 11AAA */ { NULL,NULL},
/* 11AAB */ { NULL,NULL},
/* 11AAC */ { NULL,NULL},
/* 11AAD */ { NULL,NULL},
/* 11AAE */ { NULL,NULL},
/* 11AAF */ { NULL,NULL},
/* 11AB0 */ { "SYLLABE CANADIENNE HI NATTILIK",NULL},
/* 11AB1 */ { "SYLLABE CANADIENNE HÎ NATTILIK",NULL},
/* 11AB2 */ { "SYLLABE CANADIENNE HO NATTILIK","	* Nattilik (HOU)"},
/* 11AB3 */ { "SYLLABE CANADIENNE HÔ NATTILIK","	* Nattilik (HOÛ)"},
/* 11AB4 */ { "SYLLABE CANADIENNE HA NATTILIK",NULL},
/* 11AB5 */ { "SYLLABE CANADIENNE HÂ NATTILIK",NULL},
/* 11AB6 */ { "SYLLABE CANADIENNE CHRI NATTILIK",NULL},
/* 11AB7 */ { "SYLLABE CANADIENNE CHRÎ NATTILIK",NULL},
/* 11AB8 */ { "SYLLABE CANADIENNE CHRO NATTILIK","	* Nattilik (CHROU)"},
/* 11AB9 */ { "SYLLABE CANADIENNE CHRÔ NATTILIK","	* Nattilik (CHROÛ)"},
/* 11ABA */ { "SYLLABE CANADIENNE CHRA NATTILIK",NULL},
/* 11ABB */ { "SYLLABE CANADIENNE CHRÂ NATTILIK",NULL},
/* 11ABC */ { "SYLLABE CANADIENNE SPÉ",NULL},
/* 11ABD */ { "SYLLABE CANADIENNE SPI",NULL},
/* 11ABE */ { "SYLLABE CANADIENNE SPO",NULL},
/* 11ABF */ { "SYLLABE CANADIENNE SPA",NULL},
/* 11AC0 */ { "LETTRE PAU CIN HAU PA",NULL},
/* 11AC1 */ { "LETTRE PAU CIN HAU KA",NULL},
/* 11AC2 */ { "LETTRE PAU CIN HAU LA",NULL},
/* 11AC3 */ { "LETTRE PAU CIN HAU MA",NULL},
/* 11AC4 */ { "LETTRE PAU CIN HAU DA",NULL},
/* 11AC5 */ { "LETTRE PAU CIN HAU ZA",NULL},
/* 11AC6 */ { "LETTRE PAU CIN HAU VA",NULL},
/* 11AC7 */ { "LETTRE PAU CIN HAU NGA",NULL},
/* 11AC8 */ { "LETTRE PAU CIN HAU HA",NULL},
/* 11AC9 */ { "LETTRE PAU CIN HAU GA",NULL},
/* 11ACA */ { "LETTRE PAU CIN HAU KHA",NULL},
/* 11ACB */ { "LETTRE PAU CIN HAU SA",NULL},
/* 11ACC */ { "LETTRE PAU CIN HAU BA",NULL},
/* 11ACD */ { "LETTRE PAU CIN HAU CA",NULL},
/* 11ACE */ { "LETTRE PAU CIN HAU TA",NULL},
/* 11ACF */ { "LETTRE PAU CIN HAU THA",NULL},
/* 11AD0 */ { "LETTRE PAU CIN HAU NA",NULL},
/* 11AD1 */ { "LETTRE PAU CIN HAU PHA","	= lettre pau cin hau p'a"},
/* 11AD2 */ { "LETTRE PAU CIN HAU RA",NULL},
/* 11AD3 */ { "LETTRE PAU CIN HAU FA",NULL},
/* 11AD4 */ { "LETTRE PAU CIN HAU TCHHA",NULL},
/* 11AD5 */ { "LETTRE PAU CIN HAU A",NULL},
/* 11AD6 */ { "LETTRE PAU CIN HAU É",NULL},
/* 11AD7 */ { "LETTRE PAU CIN HAU I",NULL},
/* 11AD8 */ { "LETTRE PAU CIN HAU O",NULL},
/* 11AD9 */ { "LETTRE PAU CIN HAU OU",NULL},
/* 11ADA */ { "LETTRE PAU CIN HAU OUA",NULL},
/* 11ADB */ { "LETTRE PAU CIN HAU IA",NULL},
/* 11ADC */ { "LETTRE PAU CIN HAU P FINAL",NULL},
/* 11ADD */ { "LETTRE PAU CIN HAU K FINAL",NULL},
/* 11ADE */ { "LETTRE PAU CIN HAU T FINAL",NULL},
/* 11ADF */ { "LETTRE PAU CIN HAU M FINAL",NULL},
/* 11AE0 */ { "LETTRE PAU CIN HAU N FINAL",NULL},
/* 11AE1 */ { "LETTRE PAU CIN HAU L FINAL",NULL},
/* 11AE2 */ { "LETTRE PAU CIN HAU W FINAL",NULL},
/* 11AE3 */ { "LETTRE PAU CIN HAU NG FINAL",NULL},
/* 11AE4 */ { "LETTRE PAU CIN HAU Y FINAL",NULL},
/* 11AE5 */ { "TON ASCENDANT LONG PAU CIN HAU",NULL},
/* 11AE6 */ { "TON ASCENDANT PAU CIN HAU",NULL},
/* 11AE7 */ { "SANDHI DE COUP DE GLOTTE PAU CIN HAU",NULL},
/* 11AE8 */ { "TON ASCENDANT FINAL LONG PAU CIN HAU",NULL},
/* 11AE9 */ { "TON ASCENDANT FINAL PAU CIN HAU",NULL},
/* 11AEA */ { "SANDHI DE COUP DE GLOTTE FINAL PAU CIN HAU",NULL},
/* 11AEB */ { "SANDHI TONAL LONG PAU CIN HAU",NULL},
/* 11AEC */ { "SANDHI TONAL PAU CIN HAU",NULL},
/* 11AED */ { "SANDHI TONAL FINAL LONG PAU CIN HAU",NULL},
/* 11AEE */ { "SANDHI TONAL FINAL PAU CIN HAU",NULL},
/* 11AEF */ { "TON MOYEN PAU CIN HAU",NULL},
/* 11AF0 */ { "VARIANTE DE COUP DE GLOTTE PAU CIN HAU",NULL},
/* 11AF1 */ { "TON MOYEN FINAL LONG PAU CIN HAU",NULL},
/* 11AF2 */ { "TON MOYEN FINAL PAU CIN HAU",NULL},
/* 11AF3 */ { "TON BAS DESCENDANT LONG PAU CIN HAU",NULL},
/* 11AF4 */ { "TON BAS DESCENDANT PAU CIN HAU",NULL},
/* 11AF5 */ { "COUP DE GLOTTE PAU CIN HAU",NULL},
/* 11AF6 */ { "TON BAS DESCENDANT FINAL LONG PAU CIN HAU",NULL},
/* 11AF7 */ { "TON BAS DESCENDANT FINAL PAU CIN HAU",NULL},
/* 11AF8 */ { "COUP DE GLOTTE FINAL PAU CIN HAU",NULL},
/* 11AF9 */ { NULL,NULL},
/* 11AFA */ { NULL,NULL},
/* 11AFB */ { NULL,NULL},
/* 11AFC */ { NULL,NULL},
/* 11AFD */ { NULL,NULL},
/* 11AFE */ { NULL,NULL},
/* 11AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_1B[] = {
/* 11B00 */ { "REPÈRE DE DÉBUT DÉVANÂGARÎ","	x (double danda dévanâgarî - 0965)"},
/* 11B01 */ { "REPÈRE DE DÉBUT DÉVANÂGARÎ AVEC BARRE DE TÊTE",NULL},
/* 11B02 */ { "SIGNE DÉVANÂGARÎ BHALÉ",NULL},
/* 11B03 */ { "SIGNE DÉVANÂGARÎ BHALÉ CROSSE",NULL},
/* 11B04 */ { "SIGNE DÉVANÂGARÎ BHALÉ ÉTENDU",NULL},
/* 11B05 */ { "SIGNE DÉVANÂGARÎ BHALÉ ÉTENDU CROSSE",NULL},
/* 11B06 */ { "SIGNE DÉVANÂGARÎ BHALÉ OCCIDENTAL EN FORME DE CINQ",NULL},
/* 11B07 */ { "SIGNE DÉVANÂGARÎ BHALÉ OCCIDENTAL EN FORME DE NEUF",NULL},
/* 11B08 */ { "SIGNE DÉVANÂGARÎ BHALÉ EN FORME DE NEUF RÉFLÉCHI",NULL},
/* 11B09 */ { "SIGNE DÉVANÂGARÎ MINDOU","	x (chiffre dévanâgarî zéro - 0966)"},
/* 11B0A */ { NULL,NULL},
/* 11B0B */ { NULL,NULL},
/* 11B0C */ { NULL,NULL},
/* 11B0D */ { NULL,NULL},
/* 11B0E */ { NULL,NULL},
/* 11B0F */ { NULL,NULL},
/* 11B10 */ { NULL,NULL},
/* 11B11 */ { NULL,NULL},
/* 11B12 */ { NULL,NULL},
/* 11B13 */ { NULL,NULL},
/* 11B14 */ { NULL,NULL},
/* 11B15 */ { NULL,NULL},
/* 11B16 */ { NULL,NULL},
/* 11B17 */ { NULL,NULL},
/* 11B18 */ { NULL,NULL},
/* 11B19 */ { NULL,NULL},
/* 11B1A */ { NULL,NULL},
/* 11B1B */ { NULL,NULL},
/* 11B1C */ { NULL,NULL},
/* 11B1D */ { NULL,NULL},
/* 11B1E */ { NULL,NULL},
/* 11B1F */ { NULL,NULL},
/* 11B20 */ { NULL,NULL},
/* 11B21 */ { NULL,NULL},
/* 11B22 */ { NULL,NULL},
/* 11B23 */ { NULL,NULL},
/* 11B24 */ { NULL,NULL},
/* 11B25 */ { NULL,NULL},
/* 11B26 */ { NULL,NULL},
/* 11B27 */ { NULL,NULL},
/* 11B28 */ { NULL,NULL},
/* 11B29 */ { NULL,NULL},
/* 11B2A */ { NULL,NULL},
/* 11B2B */ { NULL,NULL},
/* 11B2C */ { NULL,NULL},
/* 11B2D */ { NULL,NULL},
/* 11B2E */ { NULL,NULL},
/* 11B2F */ { NULL,NULL},
/* 11B30 */ { NULL,NULL},
/* 11B31 */ { NULL,NULL},
/* 11B32 */ { NULL,NULL},
/* 11B33 */ { NULL,NULL},
/* 11B34 */ { NULL,NULL},
/* 11B35 */ { NULL,NULL},
/* 11B36 */ { NULL,NULL},
/* 11B37 */ { NULL,NULL},
/* 11B38 */ { NULL,NULL},
/* 11B39 */ { NULL,NULL},
/* 11B3A */ { NULL,NULL},
/* 11B3B */ { NULL,NULL},
/* 11B3C */ { NULL,NULL},
/* 11B3D */ { NULL,NULL},
/* 11B3E */ { NULL,NULL},
/* 11B3F */ { NULL,NULL},
/* 11B40 */ { NULL,NULL},
/* 11B41 */ { NULL,NULL},
/* 11B42 */ { NULL,NULL},
/* 11B43 */ { NULL,NULL},
/* 11B44 */ { NULL,NULL},
/* 11B45 */ { NULL,NULL},
/* 11B46 */ { NULL,NULL},
/* 11B47 */ { NULL,NULL},
/* 11B48 */ { NULL,NULL},
/* 11B49 */ { NULL,NULL},
/* 11B4A */ { NULL,NULL},
/* 11B4B */ { NULL,NULL},
/* 11B4C */ { NULL,NULL},
/* 11B4D */ { NULL,NULL},
/* 11B4E */ { NULL,NULL},
/* 11B4F */ { NULL,NULL},
/* 11B50 */ { NULL,NULL},
/* 11B51 */ { NULL,NULL},
/* 11B52 */ { NULL,NULL},
/* 11B53 */ { NULL,NULL},
/* 11B54 */ { NULL,NULL},
/* 11B55 */ { NULL,NULL},
/* 11B56 */ { NULL,NULL},
/* 11B57 */ { NULL,NULL},
/* 11B58 */ { NULL,NULL},
/* 11B59 */ { NULL,NULL},
/* 11B5A */ { NULL,NULL},
/* 11B5B */ { NULL,NULL},
/* 11B5C */ { NULL,NULL},
/* 11B5D */ { NULL,NULL},
/* 11B5E */ { NULL,NULL},
/* 11B5F */ { NULL,NULL},
/* 11B60 */ { "DIACRITIQUE VOYELLE CHARADA E","	x (diacritique voyelle dévanâgarî e - 093A)"},
/* 11B61 */ { "DIACRITIQUE VOYELLE CHARADA EE","	x (diacritique voyelle dévanâgarî ee - 093B)"},
/* 11B62 */ { "DIACRITIQUE VOYELLE CHARADA U","	x (diacritique voyelle dévanâgarî u - 0956)"},
/* 11B63 */ { "DIACRITIQUE VOYELLE CHARADA Û","	x (diacritique voyelle dévanâgarî û - 0957)"},
/* 11B64 */ { "DIACRITIQUE VOYELLE CHARADA É BREF","	x (diacritique voyelle dévanâgarî é bref - 0946)"},
/* 11B65 */ { "DIACRITIQUE VOYELLE CHARADA O BREF","	x (diacritique voyelle dévanâgarî o bref - 094A)"},
/* 11B66 */ { "DIACRITIQUE VOYELLE CHARADA É TCHANDRA","	x (diacritique voyelle dévanâgarî é tchandra - 0945)"},
/* 11B67 */ { "DIACRITIQUE VOYELLE CHARADA O TCHANDRA","	x (diacritique voyelle dévanâgarî o tchandra - 0949)"},
/* 11B68 */ { NULL,NULL},
/* 11B69 */ { NULL,NULL},
/* 11B6A */ { NULL,NULL},
/* 11B6B */ { NULL,NULL},
/* 11B6C */ { NULL,NULL},
/* 11B6D */ { NULL,NULL},
/* 11B6E */ { NULL,NULL},
/* 11B6F */ { NULL,NULL},
/* 11B70 */ { NULL,NULL},
/* 11B71 */ { NULL,NULL},
/* 11B72 */ { NULL,NULL},
/* 11B73 */ { NULL,NULL},
/* 11B74 */ { NULL,NULL},
/* 11B75 */ { NULL,NULL},
/* 11B76 */ { NULL,NULL},
/* 11B77 */ { NULL,NULL},
/* 11B78 */ { NULL,NULL},
/* 11B79 */ { NULL,NULL},
/* 11B7A */ { NULL,NULL},
/* 11B7B */ { NULL,NULL},
/* 11B7C */ { NULL,NULL},
/* 11B7D */ { NULL,NULL},
/* 11B7E */ { NULL,NULL},
/* 11B7F */ { NULL,NULL},
/* 11B80 */ { NULL,NULL},
/* 11B81 */ { NULL,NULL},
/* 11B82 */ { NULL,NULL},
/* 11B83 */ { NULL,NULL},
/* 11B84 */ { NULL,NULL},
/* 11B85 */ { NULL,NULL},
/* 11B86 */ { NULL,NULL},
/* 11B87 */ { NULL,NULL},
/* 11B88 */ { NULL,NULL},
/* 11B89 */ { NULL,NULL},
/* 11B8A */ { NULL,NULL},
/* 11B8B */ { NULL,NULL},
/* 11B8C */ { NULL,NULL},
/* 11B8D */ { NULL,NULL},
/* 11B8E */ { NULL,NULL},
/* 11B8F */ { NULL,NULL},
/* 11B90 */ { NULL,NULL},
/* 11B91 */ { NULL,NULL},
/* 11B92 */ { NULL,NULL},
/* 11B93 */ { NULL,NULL},
/* 11B94 */ { NULL,NULL},
/* 11B95 */ { NULL,NULL},
/* 11B96 */ { NULL,NULL},
/* 11B97 */ { NULL,NULL},
/* 11B98 */ { NULL,NULL},
/* 11B99 */ { NULL,NULL},
/* 11B9A */ { NULL,NULL},
/* 11B9B */ { NULL,NULL},
/* 11B9C */ { NULL,NULL},
/* 11B9D */ { NULL,NULL},
/* 11B9E */ { NULL,NULL},
/* 11B9F */ { NULL,NULL},
/* 11BA0 */ { NULL,NULL},
/* 11BA1 */ { NULL,NULL},
/* 11BA2 */ { NULL,NULL},
/* 11BA3 */ { NULL,NULL},
/* 11BA4 */ { NULL,NULL},
/* 11BA5 */ { NULL,NULL},
/* 11BA6 */ { NULL,NULL},
/* 11BA7 */ { NULL,NULL},
/* 11BA8 */ { NULL,NULL},
/* 11BA9 */ { NULL,NULL},
/* 11BAA */ { NULL,NULL},
/* 11BAB */ { NULL,NULL},
/* 11BAC */ { NULL,NULL},
/* 11BAD */ { NULL,NULL},
/* 11BAE */ { NULL,NULL},
/* 11BAF */ { NULL,NULL},
/* 11BB0 */ { NULL,NULL},
/* 11BB1 */ { NULL,NULL},
/* 11BB2 */ { NULL,NULL},
/* 11BB3 */ { NULL,NULL},
/* 11BB4 */ { NULL,NULL},
/* 11BB5 */ { NULL,NULL},
/* 11BB6 */ { NULL,NULL},
/* 11BB7 */ { NULL,NULL},
/* 11BB8 */ { NULL,NULL},
/* 11BB9 */ { NULL,NULL},
/* 11BBA */ { NULL,NULL},
/* 11BBB */ { NULL,NULL},
/* 11BBC */ { NULL,NULL},
/* 11BBD */ { NULL,NULL},
/* 11BBE */ { NULL,NULL},
/* 11BBF */ { NULL,NULL},
/* 11BC0 */ { "LETTRE SOUNWAR DEVI",NULL},
/* 11BC1 */ { "LETTRE SOUNWAR TASLA",NULL},
/* 11BC2 */ { "LETTRE SOUNWAR EKO",NULL},
/* 11BC3 */ { "LETTRE SOUNWAR IMAR",NULL},
/* 11BC4 */ { "LETTRE SOUNWAR REU",NULL},
/* 11BC5 */ { "LETTRE SOUNWAR UTTHI",NULL},
/* 11BC6 */ { "LETTRE SOUNWAR KIK",NULL},
/* 11BC7 */ { "LETTRE SOUNWAR MA",NULL},
/* 11BC8 */ { "LETTRE SOUNWAR APPHO",NULL},
/* 11BC9 */ { "LETTRE SOUNWAR PIP",NULL},
/* 11BCA */ { "LETTRE SOUNWAR GIL",NULL},
/* 11BCB */ { "LETTRE SOUNWAR HAMSO",NULL},
/* 11BCC */ { "LETTRE SOUNWAR CARMI",NULL},
/* 11BCD */ { "LETTRE SOUNWAR NAH",NULL},
/* 11BCE */ { "LETTRE SOUNWAR BUR",NULL},
/* 11BCF */ { "LETTRE SOUNWAR JYAH",NULL},
/* 11BD0 */ { "LETTRE SOUNWAR LOACHA",NULL},
/* 11BD1 */ { "LETTRE SOUNWAR OTTHI",NULL},
/* 11BD2 */ { "LETTRE SOUNWAR SHYELE",NULL},
/* 11BD3 */ { "LETTRE SOUNWAR VARCA",NULL},
/* 11BD4 */ { "LETTRE SOUNWAR YAT",NULL},
/* 11BD5 */ { "LETTRE SOUNWAR AVA",NULL},
/* 11BD6 */ { "LETTRE SOUNWAR AAL",NULL},
/* 11BD7 */ { "LETTRE SOUNWAR DONGA",NULL},
/* 11BD8 */ { "LETTRE SOUNWAR THARI",NULL},
/* 11BD9 */ { "LETTRE SOUNWAR PHAR",NULL},
/* 11BDA */ { "LETTRE SOUNWAR NGAR",NULL},
/* 11BDB */ { "LETTRE SOUNWAR KHA",NULL},
/* 11BDC */ { "LETTRE SOUNWAR SHYER",NULL},
/* 11BDD */ { "LETTRE SOUNWAR CHELAP",NULL},
/* 11BDE */ { "LETTRE SOUNWAR TENTU",NULL},
/* 11BDF */ { "LETTRE SOUNWAR THELE",NULL},
/* 11BE0 */ { "LETTRE SOUNWAR KLOKO",NULL},
/* 11BE1 */ { "SIGNE SOUNWAR PVO",NULL},
/* 11BE2 */ { NULL,NULL},
/* 11BE3 */ { NULL,NULL},
/* 11BE4 */ { NULL,NULL},
/* 11BE5 */ { NULL,NULL},
/* 11BE6 */ { NULL,NULL},
/* 11BE7 */ { NULL,NULL},
/* 11BE8 */ { NULL,NULL},
/* 11BE9 */ { NULL,NULL},
/* 11BEA */ { NULL,NULL},
/* 11BEB */ { NULL,NULL},
/* 11BEC */ { NULL,NULL},
/* 11BED */ { NULL,NULL},
/* 11BEE */ { NULL,NULL},
/* 11BEF */ { NULL,NULL},
/* 11BF0 */ { "CHIFFRE SOUNWAR ZÉRO",NULL},
/* 11BF1 */ { "CHIFFRE SOUNWAR UN",NULL},
/* 11BF2 */ { "CHIFFRE SOUNWAR DEUX",NULL},
/* 11BF3 */ { "CHIFFRE SOUNWAR TROIS",NULL},
/* 11BF4 */ { "CHIFFRE SOUNWAR QUATRE",NULL},
/* 11BF5 */ { "CHIFFRE SOUNWAR CINQ",NULL},
/* 11BF6 */ { "CHIFFRE SOUNWAR SIX",NULL},
/* 11BF7 */ { "CHIFFRE SOUNWAR SEPT",NULL},
/* 11BF8 */ { "CHIFFRE SOUNWAR HUIT",NULL},
/* 11BF9 */ { "CHIFFRE SOUNWAR NEUF",NULL},
/* 11BFA */ { NULL,NULL},
/* 11BFB */ { NULL,NULL},
/* 11BFC */ { NULL,NULL},
/* 11BFD */ { NULL,NULL},
/* 11BFE */ { NULL,NULL},
/* 11BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_1C[] = {
/* 11C00 */ { "LETTRE BHAIKSUKI A",NULL},
/* 11C01 */ { "LETTRE BHAIKSUKI Â",NULL},
/* 11C02 */ { "LETTRE BHAIKSUKI I",NULL},
/* 11C03 */ { "LETTRE BHAIKSUKI Î",NULL},
/* 11C04 */ { "LETTRE BHAIKSUKI OU",NULL},
/* 11C05 */ { "LETTRE BHAIKSUKI OÛ",NULL},
/* 11C06 */ { "LETTRE BHAIKSUKI R VOCALIQUE",NULL},
/* 11C07 */ { "LETTRE BHAIKSUKI RR VOCALIQUE",NULL},
/* 11C08 */ { "LETTRE BHAIKSUKI L VOCALIQUE",NULL},
/* 11C09 */ { NULL,NULL},
/* 11C0A */ { "LETTRE BHAIKSUKI É",NULL},
/* 11C0B */ { "LETTRE BHAIKSUKI AI",NULL},
/* 11C0C */ { "LETTRE BHAIKSUKI O",NULL},
/* 11C0D */ { "LETTRE BHAIKSUKI AOU",NULL},
/* 11C0E */ { "LETTRE BHAIKSUKI KA",NULL},
/* 11C0F */ { "LETTRE BHAIKSUKI KHA",NULL},
/* 11C10 */ { "LETTRE BHAIKSUKI GA",NULL},
/* 11C11 */ { "LETTRE BHAIKSUKI GHA",NULL},
/* 11C12 */ { "LETTRE BHAIKSUKI NGA",NULL},
/* 11C13 */ { "LETTRE BHAIKSUKI TCHA",NULL},
/* 11C14 */ { "LETTRE BHAIKSUKI TCHHA",NULL},
/* 11C15 */ { "LETTRE BHAIKSUKI DJA",NULL},
/* 11C16 */ { "LETTRE BHAIKSUKI DJHA",NULL},
/* 11C17 */ { "LETTRE BHAIKSUKI ÑA",NULL},
/* 11C18 */ { "LETTRE BHAIKSUKI TTA",NULL},
/* 11C19 */ { "LETTRE BHAIKSUKI TTHA",NULL},
/* 11C1A */ { "LETTRE BHAIKSUKI DDA",NULL},
/* 11C1B */ { "LETTRE BHAIKSUKI DDHA",NULL},
/* 11C1C */ { "LETTRE BHAIKSUKI NNA",NULL},
/* 11C1D */ { "LETTRE BHAIKSUKI TA",NULL},
/* 11C1E */ { "LETTRE BHAIKSUKI THA",NULL},
/* 11C1F */ { "LETTRE BHAIKSUKI DA",NULL},
/* 11C20 */ { "LETTRE BHAIKSUKI DHA",NULL},
/* 11C21 */ { "LETTRE BHAIKSUKI NA",NULL},
/* 11C22 */ { "LETTRE BHAIKSUKI PA",NULL},
/* 11C23 */ { "LETTRE BHAIKSUKI PHA","	= lettre bhaiksuki p'a"},
/* 11C24 */ { "LETTRE BHAIKSUKI BA",NULL},
/* 11C25 */ { "LETTRE BHAIKSUKI BHA",NULL},
/* 11C26 */ { "LETTRE BHAIKSUKI MA",NULL},
/* 11C27 */ { "LETTRE BHAIKSUKI YA",NULL},
/* 11C28 */ { "LETTRE BHAIKSUKI RA",NULL},
/* 11C29 */ { "LETTRE BHAIKSUKI LA",NULL},
/* 11C2A */ { "LETTRE BHAIKSUKI VA",NULL},
/* 11C2B */ { "LETTRE BHAIKSUKI ÇA",NULL},
/* 11C2C */ { "LETTRE BHAIKSUKI CHA",NULL},
/* 11C2D */ { "LETTRE BHAIKSUKI SA",NULL},
/* 11C2E */ { "LETTRE BHAIKSUKI HA",NULL},
/* 11C2F */ { "DIACRITIQUE VOYELLE BHAIKSUKI Â",NULL},
/* 11C30 */ { "DIACRITIQUE VOYELLE BHAIKSUKI I",NULL},
/* 11C31 */ { "DIACRITIQUE VOYELLE BHAIKSUKI Î",NULL},
/* 11C32 */ { "DIACRITIQUE VOYELLE BHAIKSUKI OU",NULL},
/* 11C33 */ { "DIACRITIQUE VOYELLE BHAIKSUKI OÛ",NULL},
/* 11C34 */ { "DIACRITIQUE VOYELLE BHAIKSUKI R VOCALIQUE",NULL},
/* 11C35 */ { "DIACRITIQUE VOYELLE BHAIKSUKI RR VOCALIQUE",NULL},
/* 11C36 */ { "DIACRITIQUE VOYELLE BHAIKSUKI L VOCALIQUE",NULL},
/* 11C37 */ { NULL,NULL},
/* 11C38 */ { "DIACRITIQUE VOYELLE BHAIKSUKI É",NULL},
/* 11C39 */ { "DIACRITIQUE VOYELLE BHAIKSUKI AI",NULL},
/* 11C3A */ { "DIACRITIQUE VOYELLE BHAIKSUKI O",NULL},
/* 11C3B */ { "DIACRITIQUE VOYELLE BHAIKSUKI AOU",NULL},
/* 11C3C */ { "DIACRITIQUE BHAIKSUKI TCHANDRABINDOU",NULL},
/* 11C3D */ { "DIACRITIQUE BHAIKSUKI ANOUSVÂRA",NULL},
/* 11C3E */ { "DIACRITIQUE BHAIKSUKI VISARGA",NULL},
/* 11C3F */ { "DIACRITIQUE BHAIKSUKI VIRÂMA",NULL},
/* 11C40 */ { "SIGNE BHAIKSUKI AVAGRAHA",NULL},
/* 11C41 */ { "DANDA BHAIKSUKI",NULL},
/* 11C42 */ { "DOUBLE DANDA BHAIKSUKI",NULL},
/* 11C43 */ { "SÉPARATEUR DE MOTS BHAIKSUKI",NULL},
/* 11C44 */ { "BOURRE D'ÉCART-1 BHAIKSUKI",NULL},
/* 11C45 */ { "BOURRE D'ÉCART-2 BHAIKSUKI",NULL},
/* 11C46 */ { NULL,NULL},
/* 11C47 */ { NULL,NULL},
/* 11C48 */ { NULL,NULL},
/* 11C49 */ { NULL,NULL},
/* 11C4A */ { NULL,NULL},
/* 11C4B */ { NULL,NULL},
/* 11C4C */ { NULL,NULL},
/* 11C4D */ { NULL,NULL},
/* 11C4E */ { NULL,NULL},
/* 11C4F */ { NULL,NULL},
/* 11C50 */ { "CHIFFRE BHAIKSUKI ZÉRO",NULL},
/* 11C51 */ { "CHIFFRE BHAIKSUKI UN",NULL},
/* 11C52 */ { "CHIFFRE BHAIKSUKI DEUX",NULL},
/* 11C53 */ { "CHIFFRE BHAIKSUKI TROIS",NULL},
/* 11C54 */ { "CHIFFRE BHAIKSUKI QUATRE",NULL},
/* 11C55 */ { "CHIFFRE BHAIKSUKI CINQ",NULL},
/* 11C56 */ { "CHIFFRE BHAIKSUKI SIX",NULL},
/* 11C57 */ { "CHIFFRE BHAIKSUKI SEPT",NULL},
/* 11C58 */ { "CHIFFRE BHAIKSUKI HUIT",NULL},
/* 11C59 */ { "CHIFFRE BHAIKSUKI NEUF",NULL},
/* 11C5A */ { "NOMBRE BHAIKSUKI UN",NULL},
/* 11C5B */ { "NOMBRE BHAIKSUKI DEUX",NULL},
/* 11C5C */ { "NOMBRE BHAIKSUKI TROIS",NULL},
/* 11C5D */ { "NOMBRE BHAIKSUKI QUATRE",NULL},
/* 11C5E */ { "NOMBRE BHAIKSUKI CINQ",NULL},
/* 11C5F */ { "NOMBRE BHAIKSUKI SIX",NULL},
/* 11C60 */ { "NOMBRE BHAIKSUKI SEPT",NULL},
/* 11C61 */ { "NOMBRE BHAIKSUKI HUIT",NULL},
/* 11C62 */ { "NOMBRE BHAIKSUKI NEUF",NULL},
/* 11C63 */ { "NOMBRE BHAIKSUKI DIX",NULL},
/* 11C64 */ { "NOMBRE BHAIKSUKI VINGT",NULL},
/* 11C65 */ { "NOMBRE BHAIKSUKI TRENTE",NULL},
/* 11C66 */ { "NOMBRE BHAIKSUKI QUARANTE",NULL},
/* 11C67 */ { "NOMBRE BHAIKSUKI CINQUANTE",NULL},
/* 11C68 */ { "NOMBRE BHAIKSUKI SOIXANTE",NULL},
/* 11C69 */ { "NOMBRE BHAIKSUKI SOIXANTE-DIX","	= nombre bhaiksuki septante"},
/* 11C6A */ { "NOMBRE BHAIKSUKI QUATRE-VINGTS","	= nombre bhaiksuki huitante"},
/* 11C6B */ { "NOMBRE BHAIKSUKI QUATRE-VINGT-DIX","	= nombre bhaiksuki nonante"},
/* 11C6C */ { "INDICATEUR DE CENTAINES BHAIKSUKI",NULL},
/* 11C6D */ { NULL,NULL},
/* 11C6E */ { NULL,NULL},
/* 11C6F */ { NULL,NULL},
/* 11C70 */ { "REPÈRE DE DÉBUT MARCHEN","	x (svastika lévogyre - 0FD6)"},
/* 11C71 */ { "SIGNE MARCHEN ÇAD",NULL},
/* 11C72 */ { "LETTRE MARCHEN KA",NULL},
/* 11C73 */ { "LETTRE MARCHEN KHA",NULL},
/* 11C74 */ { "LETTRE MARCHEN GA",NULL},
/* 11C75 */ { "LETTRE MARCHEN NGA",NULL},
/* 11C76 */ { "LETTRE MARCHEN TCHA",NULL},
/* 11C77 */ { "LETTRE MARCHEN TCHHA",NULL},
/* 11C78 */ { "LETTRE MARCHEN DJA",NULL},
/* 11C79 */ { "LETTRE MARCHEN ÑA",NULL},
/* 11C7A */ { "LETTRE MARCHEN TA",NULL},
/* 11C7B */ { "LETTRE MARCHEN THA",NULL},
/* 11C7C */ { "LETTRE MARCHEN DA",NULL},
/* 11C7D */ { "LETTRE MARCHEN NA",NULL},
/* 11C7E */ { "LETTRE MARCHEN PA",NULL},
/* 11C7F */ { "LETTRE MARCHEN PHA","	= lettre marchen p'a"},
/* 11C80 */ { "LETTRE MARCHEN BA",NULL},
/* 11C81 */ { "LETTRE MARCHEN MA",NULL},
/* 11C82 */ { "LETTRE MARCHEN TSA",NULL},
/* 11C83 */ { "LETTRE MARCHEN TÇA",NULL},
/* 11C84 */ { "LETTRE MARCHEN DZA",NULL},
/* 11C85 */ { "LETTRE MARCHEN WA",NULL},
/* 11C86 */ { "LETTRE MARCHEN ZHA",NULL},
/* 11C87 */ { "LETTRE MARCHEN ZA",NULL},
/* 11C88 */ { "LETTRE MARCHEN 'A",NULL},
/* 11C89 */ { "LETTRE MARCHEN YA",NULL},
/* 11C8A */ { "LETTRE MARCHEN RA",NULL},
/* 11C8B */ { "LETTRE MARCHEN LA",NULL},
/* 11C8C */ { "LETTRE MARCHEN ÇA",NULL},
/* 11C8D */ { "LETTRE MARCHEN SA",NULL},
/* 11C8E */ { "LETTRE MARCHEN HA",NULL},
/* 11C8F */ { "LETTRE MARCHEN A",NULL},
/* 11C90 */ { NULL,NULL},
/* 11C91 */ { NULL,NULL},
/* 11C92 */ { "LETTRE SUBJOINTE MARCHEN KA",NULL},
/* 11C93 */ { "LETTRE SUBJOINTE MARCHEN KHA",NULL},
/* 11C94 */ { "LETTRE SUBJOINTE MARCHEN GA",NULL},
/* 11C95 */ { "LETTRE SUBJOINTE MARCHEN NGA",NULL},
/* 11C96 */ { "LETTRE SUBJOINTE MARCHEN TCHA",NULL},
/* 11C97 */ { "LETTRE SUBJOINTE MARCHEN TCHHA",NULL},
/* 11C98 */ { "LETTRE SUBJOINTE MARCHEN DJA",NULL},
/* 11C99 */ { "LETTRE SUBJOINTE MARCHEN ÑA",NULL},
/* 11C9A */ { "LETTRE SUBJOINTE MARCHEN TA",NULL},
/* 11C9B */ { "LETTRE SUBJOINTE MARCHEN THA",NULL},
/* 11C9C */ { "LETTRE SUBJOINTE MARCHEN DA",NULL},
/* 11C9D */ { "LETTRE SUBJOINTE MARCHEN NA",NULL},
/* 11C9E */ { "LETTRE SUBJOINTE MARCHEN PA",NULL},
/* 11C9F */ { "LETTRE SUBJOINTE MARCHEN PHA","	= lettre subjointe marchen p'a"},
/* 11CA0 */ { "LETTRE SUBJOINTE MARCHEN BA",NULL},
/* 11CA1 */ { "LETTRE SUBJOINTE MARCHEN MA",NULL},
/* 11CA2 */ { "LETTRE SUBJOINTE MARCHEN TSA",NULL},
/* 11CA3 */ { "LETTRE SUBJOINTE MARCHEN TÇA",NULL},
/* 11CA4 */ { "LETTRE SUBJOINTE MARCHEN DZA",NULL},
/* 11CA5 */ { "LETTRE SUBJOINTE MARCHEN WA",NULL},
/* 11CA6 */ { "LETTRE SUBJOINTE MARCHEN ZHA",NULL},
/* 11CA7 */ { "LETTRE SUBJOINTE MARCHEN ZA",NULL},
/* 11CA8 */ { NULL,NULL},
/* 11CA9 */ { "LETTRE SUBJOINTE MARCHEN YA",NULL},
/* 11CAA */ { "LETTRE SUBJOINTE MARCHEN RA",NULL},
/* 11CAB */ { "LETTRE SUBJOINTE MARCHEN LA",NULL},
/* 11CAC */ { "LETTRE SUBJOINTE MARCHEN ÇA",NULL},
/* 11CAD */ { "LETTRE SUBJOINTE MARCHEN SA",NULL},
/* 11CAE */ { "LETTRE SUBJOINTE MARCHEN HA",NULL},
/* 11CAF */ { "LETTRE SUBJOINTE MARCHEN A",NULL},
/* 11CB0 */ { "DIACRITIQUE VOYELLE MARCHEN Â",NULL},
/* 11CB1 */ { "DIACRITIQUE VOYELLE MARCHEN I",NULL},
/* 11CB2 */ { "DIACRITIQUE VOYELLE MARCHEN OU",NULL},
/* 11CB3 */ { "DIACRITIQUE VOYELLE MARCHEN É",NULL},
/* 11CB4 */ { "DIACRITIQUE VOYELLE MARCHEN O",NULL},
/* 11CB5 */ { "DIACRITIQUE MARCHEN ANOUSVÂRA",NULL},
/* 11CB6 */ { "DIACRITIQUE MARCHEN TCHANDRABINDOU",NULL},
/* 11CB7 */ { NULL,NULL},
/* 11CB8 */ { NULL,NULL},
/* 11CB9 */ { NULL,NULL},
/* 11CBA */ { NULL,NULL},
/* 11CBB */ { NULL,NULL},
/* 11CBC */ { NULL,NULL},
/* 11CBD */ { NULL,NULL},
/* 11CBE */ { NULL,NULL},
/* 11CBF */ { NULL,NULL},
/* 11CC0 */ { NULL,NULL},
/* 11CC1 */ { NULL,NULL},
/* 11CC2 */ { NULL,NULL},
/* 11CC3 */ { NULL,NULL},
/* 11CC4 */ { NULL,NULL},
/* 11CC5 */ { NULL,NULL},
/* 11CC6 */ { NULL,NULL},
/* 11CC7 */ { NULL,NULL},
/* 11CC8 */ { NULL,NULL},
/* 11CC9 */ { NULL,NULL},
/* 11CCA */ { NULL,NULL},
/* 11CCB */ { NULL,NULL},
/* 11CCC */ { NULL,NULL},
/* 11CCD */ { NULL,NULL},
/* 11CCE */ { NULL,NULL},
/* 11CCF */ { NULL,NULL},
/* 11CD0 */ { NULL,NULL},
/* 11CD1 */ { NULL,NULL},
/* 11CD2 */ { NULL,NULL},
/* 11CD3 */ { NULL,NULL},
/* 11CD4 */ { NULL,NULL},
/* 11CD5 */ { NULL,NULL},
/* 11CD6 */ { NULL,NULL},
/* 11CD7 */ { NULL,NULL},
/* 11CD8 */ { NULL,NULL},
/* 11CD9 */ { NULL,NULL},
/* 11CDA */ { NULL,NULL},
/* 11CDB */ { NULL,NULL},
/* 11CDC */ { NULL,NULL},
/* 11CDD */ { NULL,NULL},
/* 11CDE */ { NULL,NULL},
/* 11CDF */ { NULL,NULL},
/* 11CE0 */ { NULL,NULL},
/* 11CE1 */ { NULL,NULL},
/* 11CE2 */ { NULL,NULL},
/* 11CE3 */ { NULL,NULL},
/* 11CE4 */ { NULL,NULL},
/* 11CE5 */ { NULL,NULL},
/* 11CE6 */ { NULL,NULL},
/* 11CE7 */ { NULL,NULL},
/* 11CE8 */ { NULL,NULL},
/* 11CE9 */ { NULL,NULL},
/* 11CEA */ { NULL,NULL},
/* 11CEB */ { NULL,NULL},
/* 11CEC */ { NULL,NULL},
/* 11CED */ { NULL,NULL},
/* 11CEE */ { NULL,NULL},
/* 11CEF */ { NULL,NULL},
/* 11CF0 */ { NULL,NULL},
/* 11CF1 */ { NULL,NULL},
/* 11CF2 */ { NULL,NULL},
/* 11CF3 */ { NULL,NULL},
/* 11CF4 */ { NULL,NULL},
/* 11CF5 */ { NULL,NULL},
/* 11CF6 */ { NULL,NULL},
/* 11CF7 */ { NULL,NULL},
/* 11CF8 */ { NULL,NULL},
/* 11CF9 */ { NULL,NULL},
/* 11CFA */ { NULL,NULL},
/* 11CFB */ { NULL,NULL},
/* 11CFC */ { NULL,NULL},
/* 11CFD */ { NULL,NULL},
/* 11CFE */ { NULL,NULL},
/* 11CFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_1D[] = {
/* 11D00 */ { "LETTRE GONDI DE MASARAM A",NULL},
/* 11D01 */ { "LETTRE GONDI DE MASARAM Â",NULL},
/* 11D02 */ { "LETTRE GONDI DE MASARAM I",NULL},
/* 11D03 */ { "LETTRE GONDI DE MASARAM Î",NULL},
/* 11D04 */ { "LETTRE GONDI DE MASARAM OU",NULL},
/* 11D05 */ { "LETTRE GONDI DE MASARAM OÛ",NULL},
/* 11D06 */ { "LETTRE GONDI DE MASARAM É",NULL},
/* 11D07 */ { NULL,NULL},
/* 11D08 */ { "LETTRE GONDI DE MASARAM AI",NULL},
/* 11D09 */ { "LETTRE GONDI DE MASARAM O",NULL},
/* 11D0A */ { NULL,NULL},
/* 11D0B */ { "LETTRE GONDI DE MASARAM AOU",NULL},
/* 11D0C */ { "LETTRE GONDI DE MASARAM KA",NULL},
/* 11D0D */ { "LETTRE GONDI DE MASARAM KHA",NULL},
/* 11D0E */ { "LETTRE GONDI DE MASARAM GA",NULL},
/* 11D0F */ { "LETTRE GONDI DE MASARAM GHA",NULL},
/* 11D10 */ { "LETTRE GONDI DE MASARAM NGA",NULL},
/* 11D11 */ { "LETTRE GONDI DE MASARAM TCHA",NULL},
/* 11D12 */ { "LETTRE GONDI DE MASARAM TCHHA",NULL},
/* 11D13 */ { "LETTRE GONDI DE MASARAM DJA",NULL},
/* 11D14 */ { "LETTRE GONDI DE MASARAM DJHA",NULL},
/* 11D15 */ { "LETTRE GONDI DE MASARAM ÑA",NULL},
/* 11D16 */ { "LETTRE GONDI DE MASARAM TTA",NULL},
/* 11D17 */ { "LETTRE GONDI DE MASARAM TTHA",NULL},
/* 11D18 */ { "LETTRE GONDI DE MASARAM DDA",NULL},
/* 11D19 */ { "LETTRE GONDI DE MASARAM DDHA",NULL},
/* 11D1A */ { "LETTRE GONDI DE MASARAM NNA",NULL},
/* 11D1B */ { "LETTRE GONDI DE MASARAM TA",NULL},
/* 11D1C */ { "LETTRE GONDI DE MASARAM THA",NULL},
/* 11D1D */ { "LETTRE GONDI DE MASARAM DA",NULL},
/* 11D1E */ { "LETTRE GONDI DE MASARAM DHA",NULL},
/* 11D1F */ { "LETTRE GONDI DE MASARAM NA",NULL},
/* 11D20 */ { "LETTRE GONDI DE MASARAM PA",NULL},
/* 11D21 */ { "LETTRE GONDI DE MASARAM PHA","	= lettre gondi de Masaram p'a"},
/* 11D22 */ { "LETTRE GONDI DE MASARAM BA",NULL},
/* 11D23 */ { "LETTRE GONDI DE MASARAM BHA",NULL},
/* 11D24 */ { "LETTRE GONDI DE MASARAM MA",NULL},
/* 11D25 */ { "LETTRE GONDI DE MASARAM YA",NULL},
/* 11D26 */ { "LETTRE GONDI DE MASARAM RA",NULL},
/* 11D27 */ { "LETTRE GONDI DE MASARAM LA",NULL},
/* 11D28 */ { "LETTRE GONDI DE MASARAM VA",NULL},
/* 11D29 */ { "LETTRE GONDI DE MASARAM ÇA",NULL},
/* 11D2A */ { "LETTRE GONDI DE MASARAM CHA",NULL},
/* 11D2B */ { "LETTRE GONDI DE MASARAM SA",NULL},
/* 11D2C */ { "LETTRE GONDI DE MASARAM HA",NULL},
/* 11D2D */ { "LETTRE GONDI DE MASARAM LLA",NULL},
/* 11D2E */ { "LETTRE GONDI DE MASARAM KCHA",NULL},
/* 11D2F */ { "LETTRE GONDI DE MASARAM DJÑA",NULL},
/* 11D30 */ { "LETTRE GONDI DE MASARAM TRA",NULL},
/* 11D31 */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM Â",NULL},
/* 11D32 */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM I",NULL},
/* 11D33 */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM Î",NULL},
/* 11D34 */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM OU",NULL},
/* 11D35 */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM OÛ",NULL},
/* 11D36 */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM R VOCALIQUE",NULL},
/* 11D37 */ { NULL,NULL},
/* 11D38 */ { NULL,NULL},
/* 11D39 */ { NULL,NULL},
/* 11D3A */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM É",NULL},
/* 11D3B */ { NULL,NULL},
/* 11D3C */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM AI",NULL},
/* 11D3D */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM O",NULL},
/* 11D3E */ { NULL,NULL},
/* 11D3F */ { "DIACRITIQUE VOYELLE GONDI DE MASARAM AOU",NULL},
/* 11D40 */ { "DIACRITIQUE GONDI DE MASARAM ANOUSVÂRA",NULL},
/* 11D41 */ { "DIACRITIQUE GONDI DE MASARAM VISARGA",NULL},
/* 11D42 */ { "DIACRITIQUE GONDI DE MASARAM NOUKTA",NULL},
/* 11D43 */ { "DIACRITIQUE GONDI DE MASARAM TCHANDRA","	* utilisé pour transcrire des voyelles non natives"},
/* 11D44 */ { "DIACRITIQUE GONDI DE MASARAM HALANTA","	* utilisé pour amuïr la voyelle inhérente"},
/* 11D45 */ { "DIACRITIQUE GONDI DE MASARAM VIRÂMA","	* s'utilise pour former des ligatures"},
/* 11D46 */ { "REPHA GONDI DE MASARAM","	* forme de 11D26 en position initiale d'un groupe"},
/* 11D47 */ { "RA-KARA GONDI DE MASARAM","	* forme de 11D26 en position finale d'un groupe"},
/* 11D48 */ { NULL,NULL},
/* 11D49 */ { NULL,NULL},
/* 11D4A */ { NULL,NULL},
/* 11D4B */ { NULL,NULL},
/* 11D4C */ { NULL,NULL},
/* 11D4D */ { NULL,NULL},
/* 11D4E */ { NULL,NULL},
/* 11D4F */ { NULL,NULL},
/* 11D50 */ { "CHIFFRE GONDI DE MASARAM ZÉRO",NULL},
/* 11D51 */ { "CHIFFRE GONDI DE MASARAM UN",NULL},
/* 11D52 */ { "CHIFFRE GONDI DE MASARAM DEUX",NULL},
/* 11D53 */ { "CHIFFRE GONDI DE MASARAM TROIS",NULL},
/* 11D54 */ { "CHIFFRE GONDI DE MASARAM QUATRE",NULL},
/* 11D55 */ { "CHIFFRE GONDI DE MASARAM CINQ",NULL},
/* 11D56 */ { "CHIFFRE GONDI DE MASARAM SIX",NULL},
/* 11D57 */ { "CHIFFRE GONDI DE MASARAM SEPT",NULL},
/* 11D58 */ { "CHIFFRE GONDI DE MASARAM HUIT",NULL},
/* 11D59 */ { "CHIFFRE GONDI DE MASARAM NEUF",NULL},
/* 11D5A */ { NULL,NULL},
/* 11D5B */ { NULL,NULL},
/* 11D5C */ { NULL,NULL},
/* 11D5D */ { NULL,NULL},
/* 11D5E */ { NULL,NULL},
/* 11D5F */ { NULL,NULL},
/* 11D60 */ { "LETTRE GONDI DE GUNJALA A",NULL},
/* 11D61 */ { "LETTRE GONDI DE GUNJALA Â",NULL},
/* 11D62 */ { "LETTRE GONDI DE GUNJALA I",NULL},
/* 11D63 */ { "LETTRE GONDI DE GUNJALA Î",NULL},
/* 11D64 */ { "LETTRE GONDI DE GUNJALA OU",NULL},
/* 11D65 */ { "LETTRE GONDI DE GUNJALA OÛ",NULL},
/* 11D66 */ { NULL,NULL},
/* 11D67 */ { "LETTRE GONDI DE GUNJALA ÉÉ",NULL},
/* 11D68 */ { "LETTRE GONDI DE GUNJALA AI",NULL},
/* 11D69 */ { NULL,NULL},
/* 11D6A */ { "LETTRE GONDI DE GUNJALA Ô",NULL},
/* 11D6B */ { "LETTRE GONDI DE GUNJALA AOU",NULL},
/* 11D6C */ { "LETTRE GONDI DE GUNJALA YA",NULL},
/* 11D6D */ { "LETTRE GONDI DE GUNJALA VA",NULL},
/* 11D6E */ { "LETTRE GONDI DE GUNJALA BA",NULL},
/* 11D6F */ { "LETTRE GONDI DE GUNJALA BHA",NULL},
/* 11D70 */ { "LETTRE GONDI DE GUNJALA MA",NULL},
/* 11D71 */ { "LETTRE GONDI DE GUNJALA KA",NULL},
/* 11D72 */ { "LETTRE GONDI DE GUNJALA KHA",NULL},
/* 11D73 */ { "LETTRE GONDI DE GUNJALA TA",NULL},
/* 11D74 */ { "LETTRE GONDI DE GUNJALA THA",NULL},
/* 11D75 */ { "LETTRE GONDI DE GUNJALA LA",NULL},
/* 11D76 */ { "LETTRE GONDI DE GUNJALA GA",NULL},
/* 11D77 */ { "LETTRE GONDI DE GUNJALA GHA",NULL},
/* 11D78 */ { "LETTRE GONDI DE GUNJALA DA",NULL},
/* 11D79 */ { "LETTRE GONDI DE GUNJALA DHA",NULL},
/* 11D7A */ { "LETTRE GONDI DE GUNJALA NA",NULL},
/* 11D7B */ { "LETTRE GONDI DE GUNJALA TCHA",NULL},
/* 11D7C */ { "LETTRE GONDI DE GUNJALA TCHHA",NULL},
/* 11D7D */ { "LETTRE GONDI DE GUNJALA TTA",NULL},
/* 11D7E */ { "LETTRE GONDI DE GUNJALA TTHA",NULL},
/* 11D7F */ { "LETTRE GONDI DE GUNJALA LLA",NULL},
/* 11D80 */ { "LETTRE GONDI DE GUNJALA DJA",NULL},
/* 11D81 */ { "LETTRE GONDI DE GUNJALA DJHA",NULL},
/* 11D82 */ { "LETTRE GONDI DE GUNJALA DDA",NULL},
/* 11D83 */ { "LETTRE GONDI DE GUNJALA DDHA",NULL},
/* 11D84 */ { "LETTRE GONDI DE GUNJALA NGA",NULL},
/* 11D85 */ { "LETTRE GONDI DE GUNJALA PA",NULL},
/* 11D86 */ { "LETTRE GONDI DE GUNJALA PHA","	= lettre gondi de Gunjala p'a"},
/* 11D87 */ { "LETTRE GONDI DE GUNJALA HA",NULL},
/* 11D88 */ { "LETTRE GONDI DE GUNJALA RA",NULL},
/* 11D89 */ { "LETTRE GONDI DE GUNJALA SA",NULL},
/* 11D8A */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA Â",NULL},
/* 11D8B */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA I",NULL},
/* 11D8C */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA Î",NULL},
/* 11D8D */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA OU",NULL},
/* 11D8E */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA OÛ",NULL},
/* 11D8F */ { NULL,NULL},
/* 11D90 */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA ÉÉ",NULL},
/* 11D91 */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA AI",NULL},
/* 11D92 */ { NULL,NULL},
/* 11D93 */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA Ô",NULL},
/* 11D94 */ { "DIACRITIQUE VOYELLE GONDI DE GUNJALA AOU",NULL},
/* 11D95 */ { "DIACRITIQUE GONDI DE GUNJALA ANOUSVÂRA",NULL},
/* 11D96 */ { "DIACRITIQUE GONDI DE GUNJALA VISARGA",NULL},
/* 11D97 */ { "DIACRITIQUE GONDI DE GUNJALA VIRÂMA","	* s'utilise pour former des ligatures"},
/* 11D98 */ { "OM GONDI DE GUNJALA",NULL},
/* 11D99 */ { NULL,NULL},
/* 11D9A */ { NULL,NULL},
/* 11D9B */ { NULL,NULL},
/* 11D9C */ { NULL,NULL},
/* 11D9D */ { NULL,NULL},
/* 11D9E */ { NULL,NULL},
/* 11D9F */ { NULL,NULL},
/* 11DA0 */ { "CHIFFRE GONDI DE GUNJALA ZÉRO",NULL},
/* 11DA1 */ { "CHIFFRE GONDI DE GUNJALA UN",NULL},
/* 11DA2 */ { "CHIFFRE GONDI DE GUNJALA DEUX",NULL},
/* 11DA3 */ { "CHIFFRE GONDI DE GUNJALA TROIS",NULL},
/* 11DA4 */ { "CHIFFRE GONDI DE GUNJALA QUATRE",NULL},
/* 11DA5 */ { "CHIFFRE GONDI DE GUNJALA CINQ",NULL},
/* 11DA6 */ { "CHIFFRE GONDI DE GUNJALA SIX",NULL},
/* 11DA7 */ { "CHIFFRE GONDI DE GUNJALA SEPT",NULL},
/* 11DA8 */ { "CHIFFRE GONDI DE GUNJALA HUIT",NULL},
/* 11DA9 */ { "CHIFFRE GONDI DE GUNJALA NEUF",NULL},
/* 11DAA */ { NULL,NULL},
/* 11DAB */ { NULL,NULL},
/* 11DAC */ { NULL,NULL},
/* 11DAD */ { NULL,NULL},
/* 11DAE */ { NULL,NULL},
/* 11DAF */ { NULL,NULL},
/* 11DB0 */ { "LETTRE TOLONG SIKI I",NULL},
/* 11DB1 */ { "LETTRE TOLONG SIKI É",NULL},
/* 11DB2 */ { "LETTRE TOLONG SIKI OU",NULL},
/* 11DB3 */ { "LETTRE TOLONG SIKI O",NULL},
/* 11DB4 */ { "LETTRE TOLONG SIKI A",NULL},
/* 11DB5 */ { "LETTRE TOLONG SIKI Â",NULL},
/* 11DB6 */ { "LETTRE TOLONG SIKI P",NULL},
/* 11DB7 */ { "LETTRE TOLONG SIKI PH","	= p'"},
/* 11DB8 */ { "LETTRE TOLONG SIKI B",NULL},
/* 11DB9 */ { "LETTRE TOLONG SIKI BH",NULL},
/* 11DBA */ { "LETTRE TOLONG SIKI M",NULL},
/* 11DBB */ { "LETTRE TOLONG SIKI T",NULL},
/* 11DBC */ { "LETTRE TOLONG SIKI TH",NULL},
/* 11DBD */ { "LETTRE TOLONG SIKI D",NULL},
/* 11DBE */ { "LETTRE TOLONG SIKI DH",NULL},
/* 11DBF */ { "LETTRE TOLONG SIKI N",NULL},
/* 11DC0 */ { "LETTRE TOLONG SIKI TT",NULL},
/* 11DC1 */ { "LETTRE TOLONG SIKI TTH",NULL},
/* 11DC2 */ { "LETTRE TOLONG SIKI DD",NULL},
/* 11DC3 */ { "LETTRE TOLONG SIKI DDH",NULL},
/* 11DC4 */ { "LETTRE TOLONG SIKI NN",NULL},
/* 11DC5 */ { "LETTRE TOLONG SIKI TCH",NULL},
/* 11DC6 */ { "LETTRE TOLONG SIKI TCHH",NULL},
/* 11DC7 */ { "LETTRE TOLONG SIKI DJ",NULL},
/* 11DC8 */ { "LETTRE TOLONG SIKI DJH",NULL},
/* 11DC9 */ { "LETTRE TOLONG SIKI Ñ",NULL},
/* 11DCA */ { "LETTRE TOLONG SIKI K",NULL},
/* 11DCB */ { "LETTRE TOLONG SIKI KH",NULL},
/* 11DCC */ { "LETTRE TOLONG SIKI G",NULL},
/* 11DCD */ { "LETTRE TOLONG SIKI GH",NULL},
/* 11DCE */ { "LETTRE TOLONG SIKI NG",NULL},
/* 11DCF */ { "LETTRE TOLONG SIKI Y",NULL},
/* 11DD0 */ { "LETTRE TOLONG SIKI R",NULL},
/* 11DD1 */ { "LETTRE TOLONG SIKI L",NULL},
/* 11DD2 */ { "LETTRE TOLONG SIKI V",NULL},
/* 11DD3 */ { "LETTRE TOLONG SIKI ÑÑ",NULL},
/* 11DD4 */ { "LETTRE TOLONG SIKI S",NULL},
/* 11DD5 */ { "LETTRE TOLONG SIKI H",NULL},
/* 11DD6 */ { "LETTRE TOLONG SIKI X",NULL},
/* 11DD7 */ { "LETTRE TOLONG SIKI RR",NULL},
/* 11DD8 */ { "LETTRE TOLONG SIKI RRH",NULL},
/* 11DD9 */ { "SIGNE TOLONG SIKI SÉLA","	= signe de longueur de voyelle"},
/* 11DDA */ { "SIGNE TOLONG SIKI HÉTCHAKA","	= tala\n"
	"	* représente un coup de glotte"},
/* 11DDB */ { "OUNGGA TOLONG SIKI",NULL},
/* 11DDC */ { NULL,NULL},
/* 11DDD */ { NULL,NULL},
/* 11DDE */ { NULL,NULL},
/* 11DDF */ { NULL,NULL},
/* 11DE0 */ { "CHIFFRE TOLONG SIKI ZÉRO",NULL},
/* 11DE1 */ { "CHIFFRE TOLONG SIKI UN",NULL},
/* 11DE2 */ { "CHIFFRE TOLONG SIKI DEUX",NULL},
/* 11DE3 */ { "CHIFFRE TOLONG SIKI TROIS",NULL},
/* 11DE4 */ { "CHIFFRE TOLONG SIKI QUATRE",NULL},
/* 11DE5 */ { "CHIFFRE TOLONG SIKI CINQ",NULL},
/* 11DE6 */ { "CHIFFRE TOLONG SIKI SIX",NULL},
/* 11DE7 */ { "CHIFFRE TOLONG SIKI SEPT",NULL},
/* 11DE8 */ { "CHIFFRE TOLONG SIKI HUIT",NULL},
/* 11DE9 */ { "CHIFFRE TOLONG SIKI NEUF",NULL},
/* 11DEA */ { NULL,NULL},
/* 11DEB */ { NULL,NULL},
/* 11DEC */ { NULL,NULL},
/* 11DED */ { NULL,NULL},
/* 11DEE */ { NULL,NULL},
/* 11DEF */ { NULL,NULL},
/* 11DF0 */ { NULL,NULL},
/* 11DF1 */ { NULL,NULL},
/* 11DF2 */ { NULL,NULL},
/* 11DF3 */ { NULL,NULL},
/* 11DF4 */ { NULL,NULL},
/* 11DF5 */ { NULL,NULL},
/* 11DF6 */ { NULL,NULL},
/* 11DF7 */ { NULL,NULL},
/* 11DF8 */ { NULL,NULL},
/* 11DF9 */ { NULL,NULL},
/* 11DFA */ { NULL,NULL},
/* 11DFB */ { NULL,NULL},
/* 11DFC */ { NULL,NULL},
/* 11DFD */ { NULL,NULL},
/* 11DFE */ { NULL,NULL},
/* 11DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_1E[] = {
/* 11E00 */ { NULL,NULL},
/* 11E01 */ { NULL,NULL},
/* 11E02 */ { NULL,NULL},
/* 11E03 */ { NULL,NULL},
/* 11E04 */ { NULL,NULL},
/* 11E05 */ { NULL,NULL},
/* 11E06 */ { NULL,NULL},
/* 11E07 */ { NULL,NULL},
/* 11E08 */ { NULL,NULL},
/* 11E09 */ { NULL,NULL},
/* 11E0A */ { NULL,NULL},
/* 11E0B */ { NULL,NULL},
/* 11E0C */ { NULL,NULL},
/* 11E0D */ { NULL,NULL},
/* 11E0E */ { NULL,NULL},
/* 11E0F */ { NULL,NULL},
/* 11E10 */ { NULL,NULL},
/* 11E11 */ { NULL,NULL},
/* 11E12 */ { NULL,NULL},
/* 11E13 */ { NULL,NULL},
/* 11E14 */ { NULL,NULL},
/* 11E15 */ { NULL,NULL},
/* 11E16 */ { NULL,NULL},
/* 11E17 */ { NULL,NULL},
/* 11E18 */ { NULL,NULL},
/* 11E19 */ { NULL,NULL},
/* 11E1A */ { NULL,NULL},
/* 11E1B */ { NULL,NULL},
/* 11E1C */ { NULL,NULL},
/* 11E1D */ { NULL,NULL},
/* 11E1E */ { NULL,NULL},
/* 11E1F */ { NULL,NULL},
/* 11E20 */ { NULL,NULL},
/* 11E21 */ { NULL,NULL},
/* 11E22 */ { NULL,NULL},
/* 11E23 */ { NULL,NULL},
/* 11E24 */ { NULL,NULL},
/* 11E25 */ { NULL,NULL},
/* 11E26 */ { NULL,NULL},
/* 11E27 */ { NULL,NULL},
/* 11E28 */ { NULL,NULL},
/* 11E29 */ { NULL,NULL},
/* 11E2A */ { NULL,NULL},
/* 11E2B */ { NULL,NULL},
/* 11E2C */ { NULL,NULL},
/* 11E2D */ { NULL,NULL},
/* 11E2E */ { NULL,NULL},
/* 11E2F */ { NULL,NULL},
/* 11E30 */ { NULL,NULL},
/* 11E31 */ { NULL,NULL},
/* 11E32 */ { NULL,NULL},
/* 11E33 */ { NULL,NULL},
/* 11E34 */ { NULL,NULL},
/* 11E35 */ { NULL,NULL},
/* 11E36 */ { NULL,NULL},
/* 11E37 */ { NULL,NULL},
/* 11E38 */ { NULL,NULL},
/* 11E39 */ { NULL,NULL},
/* 11E3A */ { NULL,NULL},
/* 11E3B */ { NULL,NULL},
/* 11E3C */ { NULL,NULL},
/* 11E3D */ { NULL,NULL},
/* 11E3E */ { NULL,NULL},
/* 11E3F */ { NULL,NULL},
/* 11E40 */ { NULL,NULL},
/* 11E41 */ { NULL,NULL},
/* 11E42 */ { NULL,NULL},
/* 11E43 */ { NULL,NULL},
/* 11E44 */ { NULL,NULL},
/* 11E45 */ { NULL,NULL},
/* 11E46 */ { NULL,NULL},
/* 11E47 */ { NULL,NULL},
/* 11E48 */ { NULL,NULL},
/* 11E49 */ { NULL,NULL},
/* 11E4A */ { NULL,NULL},
/* 11E4B */ { NULL,NULL},
/* 11E4C */ { NULL,NULL},
/* 11E4D */ { NULL,NULL},
/* 11E4E */ { NULL,NULL},
/* 11E4F */ { NULL,NULL},
/* 11E50 */ { NULL,NULL},
/* 11E51 */ { NULL,NULL},
/* 11E52 */ { NULL,NULL},
/* 11E53 */ { NULL,NULL},
/* 11E54 */ { NULL,NULL},
/* 11E55 */ { NULL,NULL},
/* 11E56 */ { NULL,NULL},
/* 11E57 */ { NULL,NULL},
/* 11E58 */ { NULL,NULL},
/* 11E59 */ { NULL,NULL},
/* 11E5A */ { NULL,NULL},
/* 11E5B */ { NULL,NULL},
/* 11E5C */ { NULL,NULL},
/* 11E5D */ { NULL,NULL},
/* 11E5E */ { NULL,NULL},
/* 11E5F */ { NULL,NULL},
/* 11E60 */ { NULL,NULL},
/* 11E61 */ { NULL,NULL},
/* 11E62 */ { NULL,NULL},
/* 11E63 */ { NULL,NULL},
/* 11E64 */ { NULL,NULL},
/* 11E65 */ { NULL,NULL},
/* 11E66 */ { NULL,NULL},
/* 11E67 */ { NULL,NULL},
/* 11E68 */ { NULL,NULL},
/* 11E69 */ { NULL,NULL},
/* 11E6A */ { NULL,NULL},
/* 11E6B */ { NULL,NULL},
/* 11E6C */ { NULL,NULL},
/* 11E6D */ { NULL,NULL},
/* 11E6E */ { NULL,NULL},
/* 11E6F */ { NULL,NULL},
/* 11E70 */ { NULL,NULL},
/* 11E71 */ { NULL,NULL},
/* 11E72 */ { NULL,NULL},
/* 11E73 */ { NULL,NULL},
/* 11E74 */ { NULL,NULL},
/* 11E75 */ { NULL,NULL},
/* 11E76 */ { NULL,NULL},
/* 11E77 */ { NULL,NULL},
/* 11E78 */ { NULL,NULL},
/* 11E79 */ { NULL,NULL},
/* 11E7A */ { NULL,NULL},
/* 11E7B */ { NULL,NULL},
/* 11E7C */ { NULL,NULL},
/* 11E7D */ { NULL,NULL},
/* 11E7E */ { NULL,NULL},
/* 11E7F */ { NULL,NULL},
/* 11E80 */ { NULL,NULL},
/* 11E81 */ { NULL,NULL},
/* 11E82 */ { NULL,NULL},
/* 11E83 */ { NULL,NULL},
/* 11E84 */ { NULL,NULL},
/* 11E85 */ { NULL,NULL},
/* 11E86 */ { NULL,NULL},
/* 11E87 */ { NULL,NULL},
/* 11E88 */ { NULL,NULL},
/* 11E89 */ { NULL,NULL},
/* 11E8A */ { NULL,NULL},
/* 11E8B */ { NULL,NULL},
/* 11E8C */ { NULL,NULL},
/* 11E8D */ { NULL,NULL},
/* 11E8E */ { NULL,NULL},
/* 11E8F */ { NULL,NULL},
/* 11E90 */ { NULL,NULL},
/* 11E91 */ { NULL,NULL},
/* 11E92 */ { NULL,NULL},
/* 11E93 */ { NULL,NULL},
/* 11E94 */ { NULL,NULL},
/* 11E95 */ { NULL,NULL},
/* 11E96 */ { NULL,NULL},
/* 11E97 */ { NULL,NULL},
/* 11E98 */ { NULL,NULL},
/* 11E99 */ { NULL,NULL},
/* 11E9A */ { NULL,NULL},
/* 11E9B */ { NULL,NULL},
/* 11E9C */ { NULL,NULL},
/* 11E9D */ { NULL,NULL},
/* 11E9E */ { NULL,NULL},
/* 11E9F */ { NULL,NULL},
/* 11EA0 */ { NULL,NULL},
/* 11EA1 */ { NULL,NULL},
/* 11EA2 */ { NULL,NULL},
/* 11EA3 */ { NULL,NULL},
/* 11EA4 */ { NULL,NULL},
/* 11EA5 */ { NULL,NULL},
/* 11EA6 */ { NULL,NULL},
/* 11EA7 */ { NULL,NULL},
/* 11EA8 */ { NULL,NULL},
/* 11EA9 */ { NULL,NULL},
/* 11EAA */ { NULL,NULL},
/* 11EAB */ { NULL,NULL},
/* 11EAC */ { NULL,NULL},
/* 11EAD */ { NULL,NULL},
/* 11EAE */ { NULL,NULL},
/* 11EAF */ { NULL,NULL},
/* 11EB0 */ { NULL,NULL},
/* 11EB1 */ { NULL,NULL},
/* 11EB2 */ { NULL,NULL},
/* 11EB3 */ { NULL,NULL},
/* 11EB4 */ { NULL,NULL},
/* 11EB5 */ { NULL,NULL},
/* 11EB6 */ { NULL,NULL},
/* 11EB7 */ { NULL,NULL},
/* 11EB8 */ { NULL,NULL},
/* 11EB9 */ { NULL,NULL},
/* 11EBA */ { NULL,NULL},
/* 11EBB */ { NULL,NULL},
/* 11EBC */ { NULL,NULL},
/* 11EBD */ { NULL,NULL},
/* 11EBE */ { NULL,NULL},
/* 11EBF */ { NULL,NULL},
/* 11EC0 */ { NULL,NULL},
/* 11EC1 */ { NULL,NULL},
/* 11EC2 */ { NULL,NULL},
/* 11EC3 */ { NULL,NULL},
/* 11EC4 */ { NULL,NULL},
/* 11EC5 */ { NULL,NULL},
/* 11EC6 */ { NULL,NULL},
/* 11EC7 */ { NULL,NULL},
/* 11EC8 */ { NULL,NULL},
/* 11EC9 */ { NULL,NULL},
/* 11ECA */ { NULL,NULL},
/* 11ECB */ { NULL,NULL},
/* 11ECC */ { NULL,NULL},
/* 11ECD */ { NULL,NULL},
/* 11ECE */ { NULL,NULL},
/* 11ECF */ { NULL,NULL},
/* 11ED0 */ { NULL,NULL},
/* 11ED1 */ { NULL,NULL},
/* 11ED2 */ { NULL,NULL},
/* 11ED3 */ { NULL,NULL},
/* 11ED4 */ { NULL,NULL},
/* 11ED5 */ { NULL,NULL},
/* 11ED6 */ { NULL,NULL},
/* 11ED7 */ { NULL,NULL},
/* 11ED8 */ { NULL,NULL},
/* 11ED9 */ { NULL,NULL},
/* 11EDA */ { NULL,NULL},
/* 11EDB */ { NULL,NULL},
/* 11EDC */ { NULL,NULL},
/* 11EDD */ { NULL,NULL},
/* 11EDE */ { NULL,NULL},
/* 11EDF */ { NULL,NULL},
/* 11EE0 */ { "LETTRE MACASSAR KA",NULL},
/* 11EE1 */ { "LETTRE MACASSAR GA",NULL},
/* 11EE2 */ { "LETTRE MACASSAR NGA",NULL},
/* 11EE3 */ { "LETTRE MACASSAR PA",NULL},
/* 11EE4 */ { "LETTRE MACASSAR BA",NULL},
/* 11EE5 */ { "LETTRE MACASSAR MA",NULL},
/* 11EE6 */ { "LETTRE MACASSAR TA",NULL},
/* 11EE7 */ { "LETTRE MACASSAR DA",NULL},
/* 11EE8 */ { "LETTRE MACASSAR NA",NULL},
/* 11EE9 */ { "LETTRE MACASSAR TCHA",NULL},
/* 11EEA */ { "LETTRE MACASSAR DJA",NULL},
/* 11EEB */ { "LETTRE MACASSAR ÑA",NULL},
/* 11EEC */ { "LETTRE MACASSAR YA",NULL},
/* 11EED */ { "LETTRE MACASSAR RA",NULL},
/* 11EEE */ { "LETTRE MACASSAR LA",NULL},
/* 11EEF */ { "LETTRE MACASSAR VA",NULL},
/* 11EF0 */ { "LETTRE MACASSAR SA",NULL},
/* 11EF1 */ { "LETTRE MACASSAR A",NULL},
/* 11EF2 */ { "ANGKA MACASSAR",NULL},
/* 11EF3 */ { "DIACRITIQUE VOYELLE MACASSAR I",NULL},
/* 11EF4 */ { "DIACRITIQUE VOYELLE MACASSAR OU",NULL},
/* 11EF5 */ { "DIACRITIQUE VOYELLE MACASSAR É",NULL},
/* 11EF6 */ { "DIACRITIQUE VOYELLE MACASSAR O",NULL},
/* 11EF7 */ { "PASSIMBANG MACASSAR",NULL},
/* 11EF8 */ { "FIN DE SECTION MACASSAR",NULL},
/* 11EF9 */ { NULL,NULL},
/* 11EFA */ { NULL,NULL},
/* 11EFB */ { NULL,NULL},
/* 11EFC */ { NULL,NULL},
/* 11EFD */ { NULL,NULL},
/* 11EFE */ { NULL,NULL},
/* 11EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_1F[] = {
/* 11F00 */ { "DIACRITIQUE KAWI TCHANDRABINDOU",NULL},
/* 11F01 */ { "DIACRITIQUE KAWI ANOUSVÂRA",NULL},
/* 11F02 */ { "SYMBOLE KAWI REPHA","	* forme de 11F2C en position initiale d'un groupe\n"
	"	* également utilisé comme un r final"},
/* 11F03 */ { "DIACRITIQUE KAWI VISARGA",NULL},
/* 11F04 */ { "LETTRE KAWI A",NULL},
/* 11F05 */ { "LETTRE KAWI Â",NULL},
/* 11F06 */ { "LETTRE KAWI I",NULL},
/* 11F07 */ { "LETTRE KAWI Î",NULL},
/* 11F08 */ { "LETTRE KAWI OU",NULL},
/* 11F09 */ { "LETTRE KAWI OÛ",NULL},
/* 11F0A */ { "LETTRE KAWI R VOCALIQUE",NULL},
/* 11F0B */ { "LETTRE KAWI RR VOCALIQUE",NULL},
/* 11F0C */ { "LETTRE KAWI L VOCALIQUE",NULL},
/* 11F0D */ { "LETTRE KAWI LL VOCALIQUE",NULL},
/* 11F0E */ { "LETTRE KAWI É",NULL},
/* 11F0F */ { "LETTRE KAWI AI",NULL},
/* 11F10 */ { "LETTRE KAWI O",NULL},
/* 11F11 */ { NULL,NULL},
/* 11F12 */ { "LETTRE KAWI KA",NULL},
/* 11F13 */ { "LETTRE KAWI KHA",NULL},
/* 11F14 */ { "LETTRE KAWI GA",NULL},
/* 11F15 */ { "LETTRE KAWI GHA",NULL},
/* 11F16 */ { "LETTRE KAWI NGA",NULL},
/* 11F17 */ { "LETTRE KAWI TCHA",NULL},
/* 11F18 */ { "LETTRE KAWI TCHHA",NULL},
/* 11F19 */ { "LETTRE KAWI DJA",NULL},
/* 11F1A */ { "LETTRE KAWI DJHA",NULL},
/* 11F1B */ { "LETTRE KAWI ÑA",NULL},
/* 11F1C */ { "LETTRE KAWI TTA",NULL},
/* 11F1D */ { "LETTRE KAWI TTHA",NULL},
/* 11F1E */ { "LETTRE KAWI DDA",NULL},
/* 11F1F */ { "LETTRE KAWI DDHA",NULL},
/* 11F20 */ { "LETTRE KAWI NNA",NULL},
/* 11F21 */ { "LETTRE KAWI TA",NULL},
/* 11F22 */ { "LETTRE KAWI THA",NULL},
/* 11F23 */ { "LETTRE KAWI DA",NULL},
/* 11F24 */ { "LETTRE KAWI DHA",NULL},
/* 11F25 */ { "LETTRE KAWI NA",NULL},
/* 11F26 */ { "LETTRE KAWI PA",NULL},
/* 11F27 */ { "LETTRE KAWI PHA","	= lettre kawi p'a"},
/* 11F28 */ { "LETTRE KAWI BA",NULL},
/* 11F29 */ { "LETTRE KAWI BHA",NULL},
/* 11F2A */ { "LETTRE KAWI MA",NULL},
/* 11F2B */ { "LETTRE KAWI YA",NULL},
/* 11F2C */ { "LETTRE KAWI RA",NULL},
/* 11F2D */ { "LETTRE KAWI LA",NULL},
/* 11F2E */ { "LETTRE KAWI WA",NULL},
/* 11F2F */ { "LETTRE KAWI ÇA",NULL},
/* 11F30 */ { "LETTRE KAWI CHA",NULL},
/* 11F31 */ { "LETTRE KAWI SA",NULL},
/* 11F32 */ { "LETTRE KAWI HA",NULL},
/* 11F33 */ { "LETTRE KAWI DJÑA",NULL},
/* 11F34 */ { "DIACRITIQUE VOYELLE KAWI Â",NULL},
/* 11F35 */ { "DIACRITIQUE VOYELLE KAWI VARIANTE DE Â",NULL},
/* 11F36 */ { "DIACRITIQUE VOYELLE KAWI I",NULL},
/* 11F37 */ { "DIACRITIQUE VOYELLE KAWI Î",NULL},
/* 11F38 */ { "DIACRITIQUE VOYELLE KAWI OU",NULL},
/* 11F39 */ { "DIACRITIQUE VOYELLE KAWI OÛ",NULL},
/* 11F3A */ { "DIACRITIQUE VOYELLE KAWI R VOCALIQUE",NULL},
/* 11F3B */ { NULL,NULL},
/* 11F3C */ { NULL,NULL},
/* 11F3D */ { NULL,NULL},
/* 11F3E */ { "DIACRITIQUE VOYELLE KAWI É",NULL},
/* 11F3F */ { "DIACRITIQUE VOYELLE KAWI AI",NULL},
/* 11F40 */ { "DIACRITIQUE VOYELLE KAWI EU","	* correspond au schwa [ə]"},
/* 11F41 */ { "DIACRITIQUE KAWI DE SUPPRESSION","	* halant (toujours visible)"},
/* 11F42 */ { "CONNECTEUR KAWI","	* utilisé pour la formation de ligatures"},
/* 11F43 */ { "DANDA KAWI",NULL},
/* 11F44 */ { "DOUBLE DANDA KAWI",NULL},
/* 11F45 */ { "PONCTUATION KAWI REPÈRE DE SECTION",NULL},
/* 11F46 */ { "PONCTUATION KAWI VARIANTE DE REPÈRE DE SECTION",NULL},
/* 11F47 */ { "PONCTUATION KAWI FLEUR",NULL},
/* 11F48 */ { "PONCTUATION KAWI BOURRE D'ÉCART",NULL},
/* 11F49 */ { "PONCTUATION KAWI POINT",NULL},
/* 11F4A */ { "PONCTUATION KAWI DOUBLE POINT",NULL},
/* 11F4B */ { "PONCTUATION KAWI TRIPLE POINT",NULL},
/* 11F4C */ { "PONCTUATION KAWI CERCLE",NULL},
/* 11F4D */ { "PONCTUATION KAWI CERCLE GARNI",NULL},
/* 11F4E */ { "PONCTUATION KAWI SPIRALE",NULL},
/* 11F4F */ { "PONCTUATION KAWI SPIRALE DE FERMETURE",NULL},
/* 11F50 */ { "CHIFFRE KAWI ZÉRO",NULL},
/* 11F51 */ { "CHIFFRE KAWI UN",NULL},
/* 11F52 */ { "CHIFFRE KAWI DEUX","	* également utilisé pour la lettre ro"},
/* 11F53 */ { "CHIFFRE KAWI TROIS",NULL},
/* 11F54 */ { "CHIFFRE KAWI QUATRE",NULL},
/* 11F55 */ { "CHIFFRE KAWI CINQ",NULL},
/* 11F56 */ { "CHIFFRE KAWI SIX",NULL},
/* 11F57 */ { "CHIFFRE KAWI SEPT",NULL},
/* 11F58 */ { "CHIFFRE KAWI HUIT",NULL},
/* 11F59 */ { "CHIFFRE KAWI NEUF",NULL},
/* 11F5A */ { "DIACRITIQUE KAWI NOUKTA",NULL},
/* 11F5B */ { NULL,NULL},
/* 11F5C */ { NULL,NULL},
/* 11F5D */ { NULL,NULL},
/* 11F5E */ { NULL,NULL},
/* 11F5F */ { NULL,NULL},
/* 11F60 */ { NULL,NULL},
/* 11F61 */ { NULL,NULL},
/* 11F62 */ { NULL,NULL},
/* 11F63 */ { NULL,NULL},
/* 11F64 */ { NULL,NULL},
/* 11F65 */ { NULL,NULL},
/* 11F66 */ { NULL,NULL},
/* 11F67 */ { NULL,NULL},
/* 11F68 */ { NULL,NULL},
/* 11F69 */ { NULL,NULL},
/* 11F6A */ { NULL,NULL},
/* 11F6B */ { NULL,NULL},
/* 11F6C */ { NULL,NULL},
/* 11F6D */ { NULL,NULL},
/* 11F6E */ { NULL,NULL},
/* 11F6F */ { NULL,NULL},
/* 11F70 */ { NULL,NULL},
/* 11F71 */ { NULL,NULL},
/* 11F72 */ { NULL,NULL},
/* 11F73 */ { NULL,NULL},
/* 11F74 */ { NULL,NULL},
/* 11F75 */ { NULL,NULL},
/* 11F76 */ { NULL,NULL},
/* 11F77 */ { NULL,NULL},
/* 11F78 */ { NULL,NULL},
/* 11F79 */ { NULL,NULL},
/* 11F7A */ { NULL,NULL},
/* 11F7B */ { NULL,NULL},
/* 11F7C */ { NULL,NULL},
/* 11F7D */ { NULL,NULL},
/* 11F7E */ { NULL,NULL},
/* 11F7F */ { NULL,NULL},
/* 11F80 */ { NULL,NULL},
/* 11F81 */ { NULL,NULL},
/* 11F82 */ { NULL,NULL},
/* 11F83 */ { NULL,NULL},
/* 11F84 */ { NULL,NULL},
/* 11F85 */ { NULL,NULL},
/* 11F86 */ { NULL,NULL},
/* 11F87 */ { NULL,NULL},
/* 11F88 */ { NULL,NULL},
/* 11F89 */ { NULL,NULL},
/* 11F8A */ { NULL,NULL},
/* 11F8B */ { NULL,NULL},
/* 11F8C */ { NULL,NULL},
/* 11F8D */ { NULL,NULL},
/* 11F8E */ { NULL,NULL},
/* 11F8F */ { NULL,NULL},
/* 11F90 */ { NULL,NULL},
/* 11F91 */ { NULL,NULL},
/* 11F92 */ { NULL,NULL},
/* 11F93 */ { NULL,NULL},
/* 11F94 */ { NULL,NULL},
/* 11F95 */ { NULL,NULL},
/* 11F96 */ { NULL,NULL},
/* 11F97 */ { NULL,NULL},
/* 11F98 */ { NULL,NULL},
/* 11F99 */ { NULL,NULL},
/* 11F9A */ { NULL,NULL},
/* 11F9B */ { NULL,NULL},
/* 11F9C */ { NULL,NULL},
/* 11F9D */ { NULL,NULL},
/* 11F9E */ { NULL,NULL},
/* 11F9F */ { NULL,NULL},
/* 11FA0 */ { NULL,NULL},
/* 11FA1 */ { NULL,NULL},
/* 11FA2 */ { NULL,NULL},
/* 11FA3 */ { NULL,NULL},
/* 11FA4 */ { NULL,NULL},
/* 11FA5 */ { NULL,NULL},
/* 11FA6 */ { NULL,NULL},
/* 11FA7 */ { NULL,NULL},
/* 11FA8 */ { NULL,NULL},
/* 11FA9 */ { NULL,NULL},
/* 11FAA */ { NULL,NULL},
/* 11FAB */ { NULL,NULL},
/* 11FAC */ { NULL,NULL},
/* 11FAD */ { NULL,NULL},
/* 11FAE */ { NULL,NULL},
/* 11FAF */ { NULL,NULL},
/* 11FB0 */ { "LETTRE LISSOU YHA","	* utilisée pour la langue naxi\n"
	"	x (majuscule y culbuté sans empattement - 2144)\n"
	"	x (lettre lissou ya - A4EC)"},
/* 11FB1 */ { NULL,NULL},
/* 11FB2 */ { NULL,NULL},
/* 11FB3 */ { NULL,NULL},
/* 11FB4 */ { NULL,NULL},
/* 11FB5 */ { NULL,NULL},
/* 11FB6 */ { NULL,NULL},
/* 11FB7 */ { NULL,NULL},
/* 11FB8 */ { NULL,NULL},
/* 11FB9 */ { NULL,NULL},
/* 11FBA */ { NULL,NULL},
/* 11FBB */ { NULL,NULL},
/* 11FBC */ { NULL,NULL},
/* 11FBD */ { NULL,NULL},
/* 11FBE */ { NULL,NULL},
/* 11FBF */ { NULL,NULL},
/* 11FC0 */ { "FRACTION TAMOULE UN TROIS-CENT-VINGTIÈME","	= mounthiri"},
/* 11FC1 */ { "FRACTION TAMOULE UN TROIS-CENT-SOIXANTIÈME","	= araïkkâni"},
/* 11FC2 */ { "FRACTION TAMOULE UN QUATRE-VINGTIÈME","	= fraction tamoule un huitantième\n"
	"	= kâni"},
/* 11FC3 */ { "FRACTION TAMOULE UN SOIXANTE-QUATRIÈME","	= kâl vîsam"},
/* 11FC4 */ { "FRACTION TAMOULE UN QUARANTIÈME","	= araï mâ"},
/* 11FC5 */ { "FRACTION TAMOULE UN TRENTE-DEUXIÈME","	= araï vîsam"},
/* 11FC6 */ { "FRACTION TAMOULE TROIS QUATRE-VINGTIÈMES","	= fraction tamoule trois huitantièmes\n"
	"	= moukkâni"},
/* 11FC7 */ { "FRACTION TAMOULE TROIS SOIXANTE-QUATRIÈMES","	= moukkâl vîsam"},
/* 11FC8 */ { "FRACTION TAMOULE UN VINGTIÈME","	= mâ\n"
	"	x (lettre tamoule pa - 0BAA)"},
/* 11FC9 */ { "FRACTION TAMOULE UN SEIZIÈME 1","	= vîsam/mâkâni"},
/* 11FCA */ { "FRACTION TAMOULE UN SEIZIÈME 2","	= vîsam/mâkâni\n"
	"	* autre représentation"},
/* 11FCB */ { "FRACTION TAMOULE UN DIXIÈME","	= iroumâ"},
/* 11FCC */ { "FRACTION TAMOULE UN HUITIÈME","	= araïkkâl"},
/* 11FCD */ { "FRACTION TAMOULE TROIS VINGTIÈMES","	= moummâ"},
/* 11FCE */ { "FRACTION TAMOULE TROIS SEIZIÈMES","	= moûvîsam/moummâmoukkâni"},
/* 11FCF */ { "FRACTION TAMOULE UN CINQUIÈME","	= nângou mâ"},
/* 11FD0 */ { "FRACTION TAMOULE UN QUART","	= kâl\n"
	"	x (lettre tamoule va - 0BB5)"},
/* 11FD1 */ { "FRACTION TAMOULE UN DEMI 1","	= araï"},
/* 11FD2 */ { "FRACTION TAMOULE UN DEMI 2","	= araï\n"
	"	* autre représentation"},
/* 11FD3 */ { "FRACTION TAMOULE TROIS QUARTS","	= moukkâl"},
/* 11FD4 */ { "FACTEUR DE RÉDUCTION DE FRACTION TAMOUL KÎZH","	* lorsqu'il est placé devant une fraction, il en réduit la valeur d'un facteur de 1/320"},
/* 11FD5 */ { "SYMBOLE TAMOUL NEL","	* un grain de paddy"},
/* 11FD6 */ { "SYMBOLE TAMOUL TCHÉVITOU","	* équivaut à 360 nel"},
/* 11FD7 */ { "SYMBOLE TAMOUL ÂZHÂKKOU","	* équivaut à 5 tchévitou"},
/* 11FD8 */ { "SYMBOLE TAMOUL OUZHAKKOU","	* équivaut à 2 âzhâkkou\n"
	"	* pour la mesure ouri, qui équivaut à 2 ouzhakkou, on utilise la séquence 0B89 0BB0 0BBF"},
/* 11FD9 */ { "SYMBOLE TAMOUL MOUVOUZHAKKOU","	* équivaut à 3 ouzhakkou\n"
	"	* pour la mesure nâzhi/padi, qui équivaut à 2 ouri, on utilise 0BF3\n"
	"	x (symbole tamoul du jour - 0BF3)"},
/* 11FDA */ { "SYMBOLE TAMOUL KOUROUNI","	= marakkâl\n"
	"	* équivaut à 8 nâzhi/padi\n"
	"	x (lettre tamoule nga - 0B99)"},
/* 11FDB */ { "SYMBOLE TAMOUL PATHAKKOU","	* équivaut à 2 kourouni/marakkâl"},
/* 11FDC */ { "SYMBOLE TAMOUL MOUKKOUROUNI","	* équivaut à 3 kourouni/marakkâl\n"
	"	* pour la mesure thoûni, qui équivaut à 2 pathakkou, on utilise 0BA4\n"
	"	x (lettre tamoule ta - 0BA4)\n"
	"	* pour la mesure kalam, qui équivaut à 3 thoûni, on utilise 0BB3\n"
	"	x (lettre tamoule lla - 0BB3)"},
/* 11FDD */ { "SYMBOLE TAMOUL KÂSOU","	* petite unité monétaire"},
/* 11FDE */ { "SYMBOLE TAMOUL PANAM",NULL},
/* 11FDF */ { "SYMBOLE TAMOUL PON","	* pièce d'or"},
/* 11FE0 */ { "SYMBOLE TAMOUL VARÂKAN","	* pièce d'or portant une figure de sanglier"},
/* 11FE1 */ { "SYMBOLE TAMOUL PÂRAM","	* équivaut approximativement à 500 livres (227 kg)"},
/* 11FE2 */ { "SYMBOLE TAMOUL KOUZHI","	* équivaut à 1 kol carré, où 1 kol équivaut à environ 11 pieds (3,35 m)"},
/* 11FE3 */ { "SYMBOLE TAMOUL VÉLI","	= vêli\n"
	"	* équivaut à 2.000 kouzhi"},
/* 11FE4 */ { "SYMBOLE TAMOUL CULTURE HUMIDE","	= nansey"},
/* 11FE5 */ { "SYMBOLE TAMOUL CULTURE SÈCHE","	= pounsey"},
/* 11FE6 */ { "SYMBOLE TAMOUL TERRAIN","	= nilam\n"
	"	* distinct du symbole de la roupie\n"
	"	x (symbole tamoul roupie - 0BF9)"},
/* 11FE7 */ { "SYMBOLE TAMOUL SALINE","	= ouppalam"},
/* 11FE8 */ { "SYMBOLE TAMOUL TRADITIONNEL DE CRÉDIT","	= varavou\n"
	"	x (symbole tamoul de crédit - 0BF7)"},
/* 11FE9 */ { "SYMBOLE TAMOUL TRADITIONNEL NUMÉRO","	= enn\n"
	"	x (symbole tamoul numéro - 0BFA)"},
/* 11FEA */ { "SYMBOLE TAMOUL EN COURS","	= nâlathou"},
/* 11FEB */ { "SYMBOLE TAMOUL ET IMPAIR","	= silvânam/sillaraï"},
/* 11FEC */ { "SYMBOLE TAMOUL DÉPENSÉ","	= poga (poka)"},
/* 11FED */ { "SYMBOLE TAMOUL TOTAL","	= âga (âka)"},
/* 11FEE */ { "SYMBOLE TAMOUL EN POSSESSION","	= vasam"},
/* 11FEF */ { "SYMBOLE TAMOUL À COMPTER DE","	= mouthal"},
/* 11FF0 */ { "SYMBOLE TAMOUL MOUTHALIYA","	= et cetera\n"
	"	* indique les éléments d'une série"},
/* 11FF1 */ { "SYMBOLE TAMOUL VAKAÏYARÂ","	= et cetera\n"
	"	* indique les éléments d'une famille ou d'une espèce"},
/* 11FF2 */ { NULL,NULL},
/* 11FF3 */ { NULL,NULL},
/* 11FF4 */ { NULL,NULL},
/* 11FF5 */ { NULL,NULL},
/* 11FF6 */ { NULL,NULL},
/* 11FF7 */ { NULL,NULL},
/* 11FF8 */ { NULL,NULL},
/* 11FF9 */ { NULL,NULL},
/* 11FFA */ { NULL,NULL},
/* 11FFB */ { NULL,NULL},
/* 11FFC */ { NULL,NULL},
/* 11FFD */ { NULL,NULL},
/* 11FFE */ { NULL,NULL},
/* 11FFF */ { "PONCTUATION TAMOULE FIN DE TEXTE","	x (ponctuation singhalaise kounddaliya - 0DF4)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_20[] = {
/* 12000 */ { "SIGNE CUNÉIFORME A",NULL},
/* 12001 */ { "SIGNE CUNÉIFORME A FOIS A",NULL},
/* 12002 */ { "SIGNE CUNÉIFORME A FOIS BAD",NULL},
/* 12003 */ { "SIGNE CUNÉIFORME A FOIS GAN2 TENOU",NULL},
/* 12004 */ { "SIGNE CUNÉIFORME A FOIS HA",NULL},
/* 12005 */ { "SIGNE CUNÉIFORME A FOIS IGI",NULL},
/* 12006 */ { "SIGNE CUNÉIFORME A FOIS LAGAR GOUNOU",NULL},
/* 12007 */ { "SIGNE CUNÉIFORME A FOIS MOUCH",NULL},
/* 12008 */ { "SIGNE CUNÉIFORME A FOIS SAG",NULL},
/* 12009 */ { "SIGNE CUNÉIFORME A2",NULL},
/* 1200A */ { "SIGNE CUNÉIFORME AB",NULL},
/* 1200B */ { "SIGNE CUNÉIFORME AB FOIS ACH2",NULL},
/* 1200C */ { "SIGNE CUNÉIFORME AB FOIS DOUN3 GOUNOU",NULL},
/* 1200D */ { "SIGNE CUNÉIFORME AB FOIS GAL",NULL},
/* 1200E */ { "SIGNE CUNÉIFORME AB FOIS GAN2 TENOU",NULL},
/* 1200F */ { "SIGNE CUNÉIFORME AB FOIS HA",NULL},
/* 12010 */ { "SIGNE CUNÉIFORME AB FOIS IGI GOUNOU",NULL},
/* 12011 */ { "SIGNE CUNÉIFORME AB FOIS IMIN",NULL},
/* 12012 */ { "SIGNE CUNÉIFORME AB FOIS LAGAB",NULL},
/* 12013 */ { "SIGNE CUNÉIFORME AB FOIS CHECH",NULL},
/* 12014 */ { "SIGNE CUNÉIFORME AB FOIS OU PLUS OU PLUS OU",NULL},
/* 12015 */ { "SIGNE CUNÉIFORME AB GOUNOU",NULL},
/* 12016 */ { "SIGNE CUNÉIFORME AB2",NULL},
/* 12017 */ { "SIGNE CUNÉIFORME AB2 FOIS BALAG",NULL},
/* 12018 */ { "SIGNE CUNÉIFORME AB2 FOIS GAN2 TENOU",NULL},
/* 12019 */ { "SIGNE CUNÉIFORME AB2 FOIS ME PLUS EN",NULL},
/* 1201A */ { "SIGNE CUNÉIFORME AB2 FOIS CHA3",NULL},
/* 1201B */ { "SIGNE CUNÉIFORME AB2 FOIS TAK4",NULL},
/* 1201C */ { "SIGNE CUNÉIFORME AD",NULL},
/* 1201D */ { "SIGNE CUNÉIFORME AK",NULL},
/* 1201E */ { "SIGNE CUNÉIFORME AK FOIS ERIN2",NULL},
/* 1201F */ { "SIGNE CUNÉIFORME AK FOIS CHITA PLUS GICH",NULL},
/* 12020 */ { "SIGNE CUNÉIFORME AL",NULL},
/* 12021 */ { "SIGNE CUNÉIFORME AL FOIS AL",NULL},
/* 12022 */ { "SIGNE CUNÉIFORME AL FOIS DIM2",NULL},
/* 12023 */ { "SIGNE CUNÉIFORME AL FOIS GICH",NULL},
/* 12024 */ { "SIGNE CUNÉIFORME AL FOIS HA",NULL},
/* 12025 */ { "SIGNE CUNÉIFORME AL FOIS KAD3",NULL},
/* 12026 */ { "SIGNE CUNÉIFORME AL FOIS KI",NULL},
/* 12027 */ { "SIGNE CUNÉIFORME AL FOIS CHE",NULL},
/* 12028 */ { "SIGNE CUNÉIFORME AL FOIS OUCH",NULL},
/* 12029 */ { "SIGNE CUNÉIFORME ALAN",NULL},
/* 1202A */ { "SIGNE CUNÉIFORME ALEPH",NULL},
/* 1202B */ { "SIGNE CUNÉIFORME AMAR",NULL},
/* 1202C */ { "SIGNE CUNÉIFORME AMAR FOIS CHE",NULL},
/* 1202D */ { "SIGNE CUNÉIFORME AN",NULL},
/* 1202E */ { "SIGNE CUNÉIFORME AN SUR AN",NULL},
/* 1202F */ { "SIGNE CUNÉIFORME AN TROIS FOIS",NULL},
/* 12030 */ { "SIGNE CUNÉIFORME AN PLUS NAGA ADOSSÉ À AN PLUS NAGA",NULL},
/* 12031 */ { "SIGNE CUNÉIFORME QUATRE AN PLUS NAGA EN CROIX",NULL},
/* 12032 */ { "SIGNE CUNÉIFORME ANCHE",NULL},
/* 12033 */ { "SIGNE CUNÉIFORME APIN",NULL},
/* 12034 */ { "SIGNE CUNÉIFORME ARAD",NULL},
/* 12035 */ { "SIGNE CUNÉIFORME ARAD FOIS KOUR",NULL},
/* 12036 */ { "SIGNE CUNÉIFORME ARKAB",NULL},
/* 12037 */ { "SIGNE CUNÉIFORME ASAL2",NULL},
/* 12038 */ { "SIGNE CUNÉIFORME ACH","	= 1 aš\n"
	"	x (signe numéral cunéiforme deux ach - 12400)"},
/* 12039 */ { "SIGNE CUNÉIFORME ACH ZIDA TENOU","	= 1 aš tenû\n"
	"	= 1 diš tenû\n"
	"	= 1/2 iku\n"
	"	x (signe numéral cunéiforme deux ach tenou - 1244A)"},
/* 1203A */ { "SIGNE CUNÉIFORME ACH KABA TENOU",NULL},
/* 1203B */ { "SIGNE CUNÉIFORME ACH SUR ACH TOUG2 SUR TOUG2 TOUG2 SUR TOUG2 PAP",NULL},
/* 1203C */ { "SIGNE CUNÉIFORME ACH SUR ACH SUR ACH",NULL},
/* 1203D */ { "SIGNE CUNÉIFORME DEUX ACH SUR ACH SUR ACH CROISÉS",NULL},
/* 1203E */ { "SIGNE CUNÉIFORME ACH2","	x (signe numéral cunéiforme quatre ban2 variante - 12453)"},
/* 1203F */ { "SIGNE CUNÉIFORME ACHGAB",NULL},
/* 12040 */ { "SIGNE CUNÉIFORME BA",NULL},
/* 12041 */ { "SIGNE CUNÉIFORME BAD",NULL},
/* 12042 */ { "SIGNE CUNÉIFORME BAG3",NULL},
/* 12043 */ { "SIGNE CUNÉIFORME BAHAR2",NULL},
/* 12044 */ { "SIGNE CUNÉIFORME BAL",NULL},
/* 12045 */ { "SIGNE CUNÉIFORME BAL SUR BAL",NULL},
/* 12046 */ { "SIGNE CUNÉIFORME BALAG",NULL},
/* 12047 */ { "SIGNE CUNÉIFORME BAR",NULL},
/* 12048 */ { "SIGNE CUNÉIFORME BARA2",NULL},
/* 12049 */ { "SIGNE CUNÉIFORME BI",NULL},
/* 1204A */ { "SIGNE CUNÉIFORME BI FOIS A",NULL},
/* 1204B */ { "SIGNE CUNÉIFORME BI FOIS GAR",NULL},
/* 1204C */ { "SIGNE CUNÉIFORME BI FOIS IGI GOUNOU",NULL},
/* 1204D */ { "SIGNE CUNÉIFORME BOU",NULL},
/* 1204E */ { "SIGNE CUNÉIFORME BOU SUR BOU AB",NULL},
/* 1204F */ { "SIGNE CUNÉIFORME BOU SUR BOU OUN",NULL},
/* 12050 */ { "SIGNE CUNÉIFORME DEUX BOU CROISÉS",NULL},
/* 12051 */ { "SIGNE CUNÉIFORME BOULOUG",NULL},
/* 12052 */ { "SIGNE CUNÉIFORME BOULOUG SUR BOULOUG",NULL},
/* 12053 */ { "SIGNE CUNÉIFORME BOUR",NULL},
/* 12054 */ { "SIGNE CUNÉIFORME BOUR2",NULL},
/* 12055 */ { "SIGNE CUNÉIFORME DA",NULL},
/* 12056 */ { "SIGNE CUNÉIFORME DAG",NULL},
/* 12057 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS A PLUS MACH",NULL},
/* 12058 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS AMAR",NULL},
/* 12059 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS BALAG",NULL},
/* 1205A */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS BI",NULL},
/* 1205B */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS GA",NULL},
/* 1205C */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS GA PLUS MACH",NULL},
/* 1205D */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS GI",NULL},
/* 1205E */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS GIR2",NULL},
/* 1205F */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS GOUD",NULL},
/* 12060 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS HA",NULL},
/* 12061 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS IR",NULL},
/* 12062 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS IR PLUS LOU",NULL},
/* 12063 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS KAK",NULL},
/* 12064 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS LA",NULL},
/* 12065 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS LOU",NULL},
/* 12066 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS LOU PLUS MACH2",NULL},
/* 12067 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS LOUM",NULL},
/* 12068 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS NE",NULL},
/* 12069 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS PAP PLUS PAP",NULL},
/* 1206A */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS SI",NULL},
/* 1206B */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS TAK4",NULL},
/* 1206C */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS OU2 PLUS GIR2",NULL},
/* 1206D */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS OUCH",NULL},
/* 1206E */ { "SIGNE CUNÉIFORME DAM",NULL},
/* 1206F */ { "SIGNE CUNÉIFORME DAR",NULL},
/* 12070 */ { "SIGNE CUNÉIFORME DARA3",NULL},
/* 12071 */ { "SIGNE CUNÉIFORME DARA4",NULL},
/* 12072 */ { "SIGNE CUNÉIFORME DI",NULL},
/* 12073 */ { "SIGNE CUNÉIFORME DIB",NULL},
/* 12074 */ { "SIGNE CUNÉIFORME DIM",NULL},
/* 12075 */ { "SIGNE CUNÉIFORME DIM FOIS CHE",NULL},
/* 12076 */ { "SIGNE CUNÉIFORME DIM2",NULL},
/* 12077 */ { "SIGNE CUNÉIFORME DIN",NULL},
/* 12078 */ { "SIGNE CUNÉIFORME DIN KASKAL OU GOUNOU DICH",NULL},
/* 12079 */ { "SIGNE CUNÉIFORME DICH","	= 1 diš\n"
	"	= 1 bariga\n"
	"	x (signe numéral cunéiforme trois dich - 12408)\n"
	"	x (signe numéral cunéiforme nigidamin - 12456)\n"
	"	x (signe numéral cunéiforme nigidaech - 12457)"},
/* 1207A */ { "SIGNE CUNÉIFORME DOU",NULL},
/* 1207B */ { "SIGNE CUNÉIFORME DOU SUR DOU",NULL},
/* 1207C */ { "SIGNE CUNÉIFORME DOU GOUNOU",NULL},
/* 1207D */ { "SIGNE CUNÉIFORME DOU CHECHIG",NULL},
/* 1207E */ { "SIGNE CUNÉIFORME DOUB",NULL},
/* 1207F */ { "SIGNE CUNÉIFORME DOUB FOIS ECH2",NULL},
/* 12080 */ { "SIGNE CUNÉIFORME DOUB2",NULL},
/* 12081 */ { "SIGNE CUNÉIFORME DOUG",NULL},
/* 12082 */ { "SIGNE CUNÉIFORME DOUGOUD",NULL},
/* 12083 */ { "SIGNE CUNÉIFORME DOUH",NULL},
/* 12084 */ { "SIGNE CUNÉIFORME DOUN",NULL},
/* 12085 */ { "SIGNE CUNÉIFORME DOUN3",NULL},
/* 12086 */ { "SIGNE CUNÉIFORME DOUN3 GOUNOU",NULL},
/* 12087 */ { "SIGNE CUNÉIFORME DOUN3 GOUNOU GOUNOU",NULL},
/* 12088 */ { "SIGNE CUNÉIFORME DOUN4",NULL},
/* 12089 */ { "SIGNE CUNÉIFORME DOUR2",NULL},
/* 1208A */ { "SIGNE CUNÉIFORME E",NULL},
/* 1208B */ { "SIGNE CUNÉIFORME E FOIS PAP",NULL},
/* 1208C */ { "SIGNE CUNÉIFORME E SUR E NOUN SUR NOUN",NULL},
/* 1208D */ { "SIGNE CUNÉIFORME E2",NULL},
/* 1208E */ { "SIGNE CUNÉIFORME E2 FOIS A PLUS HA PLUS DA",NULL},
/* 1208F */ { "SIGNE CUNÉIFORME E2 FOIS GAR",NULL},
/* 12090 */ { "SIGNE CUNÉIFORME E2 FOIS MI",NULL},
/* 12091 */ { "SIGNE CUNÉIFORME E2 FOIS SAL",NULL},
/* 12092 */ { "SIGNE CUNÉIFORME E2 FOIS CHE",NULL},
/* 12093 */ { "SIGNE CUNÉIFORME E2 FOIS OU",NULL},
/* 12094 */ { "SIGNE CUNÉIFORME EDIN",NULL},
/* 12095 */ { "SIGNE CUNÉIFORME EGIR",NULL},
/* 12096 */ { "SIGNE CUNÉIFORME EL",NULL},
/* 12097 */ { "SIGNE CUNÉIFORME EN",NULL},
/* 12098 */ { "SIGNE CUNÉIFORME EN FOIS GAN2",NULL},
/* 12099 */ { "SIGNE CUNÉIFORME EN FOIS GAN2 TENOU",NULL},
/* 1209A */ { "SIGNE CUNÉIFORME EN FOIS ME",NULL},
/* 1209B */ { "SIGNE CUNÉIFORME DEUX EN CROISÉS",NULL},
/* 1209C */ { "SIGNE CUNÉIFORME EN ADOSSÉ À EN",NULL},
/* 1209D */ { "SIGNE CUNÉIFORME QUATRE EN DISPOSÉS EN CARRÉ",NULL},
/* 1209E */ { "SIGNE CUNÉIFORME EREN",NULL},
/* 1209F */ { "SIGNE CUNÉIFORME ERIN2",NULL},
/* 120A0 */ { "SIGNE CUNÉIFORME ECH2",NULL},
/* 120A1 */ { "SIGNE CUNÉIFORME EZEN",NULL},
/* 120A2 */ { "SIGNE CUNÉIFORME EZEN FOIS A",NULL},
/* 120A3 */ { "SIGNE CUNÉIFORME EZEN FOIS A PLUS LAL",NULL},
/* 120A4 */ { "SIGNE CUNÉIFORME EZEN FOIS A PLUS LAL FOIS LAL",NULL},
/* 120A5 */ { "SIGNE CUNÉIFORME EZEN FOIS AN",NULL},
/* 120A6 */ { "SIGNE CUNÉIFORME EZEN FOIS BAD",NULL},
/* 120A7 */ { "SIGNE CUNÉIFORME EZEN FOIS DOUN3 GOUNOU",NULL},
/* 120A8 */ { "SIGNE CUNÉIFORME EZEN FOIS DOUN3 GOUNOU GOUNOU",NULL},
/* 120A9 */ { "SIGNE CUNÉIFORME EZEN FOIS HA",NULL},
/* 120AA */ { "SIGNE CUNÉIFORME EZEN FOIS HA GOUNOU",NULL},
/* 120AB */ { "SIGNE CUNÉIFORME EZEN FOIS IGI GOUNOU",NULL},
/* 120AC */ { "SIGNE CUNÉIFORME EZEN FOIS KASKAL",NULL},
/* 120AD */ { "SIGNE CUNÉIFORME QUATRE EZEN FOIS KASKAL EN CROIX",NULL},
/* 120AE */ { "SIGNE CUNÉIFORME EZEN FOIS KOU3",NULL},
/* 120AF */ { "SIGNE CUNÉIFORME EZEN FOIS LA",NULL},
/* 120B0 */ { "SIGNE CUNÉIFORME EZEN FOIS LAL FOIS LAL",NULL},
/* 120B1 */ { "SIGNE CUNÉIFORME EZEN FOIS LI",NULL},
/* 120B2 */ { "SIGNE CUNÉIFORME EZEN FOIS LOU",NULL},
/* 120B3 */ { "SIGNE CUNÉIFORME EZEN FOIS OU2",NULL},
/* 120B4 */ { "SIGNE CUNÉIFORME EZEN FOIS OUD",NULL},
/* 120B5 */ { "SIGNE CUNÉIFORME GA",NULL},
/* 120B6 */ { "SIGNE CUNÉIFORME GA GOUNOU",NULL},
/* 120B7 */ { "SIGNE CUNÉIFORME GA2",NULL},
/* 120B8 */ { "SIGNE CUNÉIFORME GA2 FOIS A PLUS DA PLUS HA",NULL},
/* 120B9 */ { "SIGNE CUNÉIFORME GA2 FOIS A PLUS HA",NULL},
/* 120BA */ { "SIGNE CUNÉIFORME GA2 FOIS A PLUS IGI",NULL},
/* 120BB */ { "SIGNE CUNÉIFORME GA2 FOIS AB2 TENOU PLUS TAB",NULL},
/* 120BC */ { "SIGNE CUNÉIFORME GA2 FOIS AN",NULL},
/* 120BD */ { "SIGNE CUNÉIFORME GA2 FOIS ACH",NULL},
/* 120BE */ { "SIGNE CUNÉIFORME GA2 FOIS ACH2 PLUS GAL",NULL},
/* 120BF */ { "SIGNE CUNÉIFORME GA2 FOIS BAD",NULL},
/* 120C0 */ { "SIGNE CUNÉIFORME GA2 FOIS BAR PLUS RA",NULL},
/* 120C1 */ { "SIGNE CUNÉIFORME GA2 FOIS BOUR",NULL},
/* 120C2 */ { "SIGNE CUNÉIFORME GA2 FOIS BOUR PLUS RA",NULL},
/* 120C3 */ { "SIGNE CUNÉIFORME GA2 FOIS DA",NULL},
/* 120C4 */ { "SIGNE CUNÉIFORME GA2 FOIS DI",NULL},
/* 120C5 */ { "SIGNE CUNÉIFORME GA2 FOIS DIM FOIS CHE",NULL},
/* 120C6 */ { "SIGNE CUNÉIFORME GA2 FOIS DOUB",NULL},
/* 120C7 */ { "SIGNE CUNÉIFORME GA2 FOIS EL",NULL},
/* 120C8 */ { "SIGNE CUNÉIFORME GA2 FOIS EL PLUS LA",NULL},
/* 120C9 */ { "SIGNE CUNÉIFORME GA2 FOIS EN",NULL},
/* 120CA */ { "SIGNE CUNÉIFORME GA2 FOIS EN FOIS GAN2 TENOU",NULL},
/* 120CB */ { "SIGNE CUNÉIFORME GA2 FOIS GAN2 TENOU",NULL},
/* 120CC */ { "SIGNE CUNÉIFORME GA2 FOIS GAR",NULL},
/* 120CD */ { "SIGNE CUNÉIFORME GA2 FOIS GI",NULL},
/* 120CE */ { "SIGNE CUNÉIFORME GA2 FOIS GI4",NULL},
/* 120CF */ { "SIGNE CUNÉIFORME GA2 FOIS GI4 PLUS A",NULL},
/* 120D0 */ { "SIGNE CUNÉIFORME GA2 FOIS GIR2 PLUS SOU",NULL},
/* 120D1 */ { "SIGNE CUNÉIFORME GA2 FOIS HA PLUS LOU PLUS ECH2",NULL},
/* 120D2 */ { "SIGNE CUNÉIFORME GA2 FOIS HAL",NULL},
/* 120D3 */ { "SIGNE CUNÉIFORME GA2 FOIS HAL PLUS LA",NULL},
/* 120D4 */ { "SIGNE CUNÉIFORME GA2 FOIS HI PLUS LI",NULL},
/* 120D5 */ { "SIGNE CUNÉIFORME GA2 FOIS HOUB2",NULL},
/* 120D6 */ { "SIGNE CUNÉIFORME GA2 FOIS IGI GOUNOU",NULL},
/* 120D7 */ { "SIGNE CUNÉIFORME GA2 FOIS ICH PLUS HOU PLUS ACH",NULL},
/* 120D8 */ { "SIGNE CUNÉIFORME GA2 FOIS KAK",NULL},
/* 120D9 */ { "SIGNE CUNÉIFORME GA2 FOIS KASKAL",NULL},
/* 120DA */ { "SIGNE CUNÉIFORME GA2 FOIS KID",NULL},
/* 120DB */ { "SIGNE CUNÉIFORME GA2 FOIS KID PLUS LAL",NULL},
/* 120DC */ { "SIGNE CUNÉIFORME GA2 FOIS KOU3 PLUS AN",NULL},
/* 120DD */ { "SIGNE CUNÉIFORME GA2 FOIS LA",NULL},
/* 120DE */ { "SIGNE CUNÉIFORME GA2 FOIS ME PLUS EN",NULL},
/* 120DF */ { "SIGNE CUNÉIFORME GA2 FOIS MI",NULL},
/* 120E0 */ { "SIGNE CUNÉIFORME GA2 FOIS NOUN",NULL},
/* 120E1 */ { "SIGNE CUNÉIFORME GA2 FOIS NOUN SUR NOUN",NULL},
/* 120E2 */ { "SIGNE CUNÉIFORME GA2 FOIS PA",NULL},
/* 120E3 */ { "SIGNE CUNÉIFORME GA2 FOIS SAL",NULL},
/* 120E4 */ { "SIGNE CUNÉIFORME GA2 FOIS SAR",NULL},
/* 120E5 */ { "SIGNE CUNÉIFORME GA2 FOIS CHE",NULL},
/* 120E6 */ { "SIGNE CUNÉIFORME GA2 FOIS CHE PLUS TOUR",NULL},
/* 120E7 */ { "SIGNE CUNÉIFORME GA2 FOIS CHID",NULL},
/* 120E8 */ { "SIGNE CUNÉIFORME GA2 FOIS SOUM",NULL},
/* 120E9 */ { "SIGNE CUNÉIFORME GA2 FOIS TAK4",NULL},
/* 120EA */ { "SIGNE CUNÉIFORME GA2 FOIS OU",NULL},
/* 120EB */ { "SIGNE CUNÉIFORME GA2 FOIS OUD",NULL},
/* 120EC */ { "SIGNE CUNÉIFORME GA2 FOIS OUD PLUS DOU",NULL},
/* 120ED */ { "SIGNE CUNÉIFORME GA2 SUR GA2",NULL},
/* 120EE */ { "SIGNE CUNÉIFORME GABA",NULL},
/* 120EF */ { "SIGNE CUNÉIFORME DEUX GABA CROISÉS",NULL},
/* 120F0 */ { "SIGNE CUNÉIFORME GAD",NULL},
/* 120F1 */ { "SIGNE CUNÉIFORME GAD SUR GAD GAR SUR GAR",NULL},
/* 120F2 */ { "SIGNE CUNÉIFORME GAL",NULL},
/* 120F3 */ { "SIGNE CUNÉIFORME GAL GAD SUR GAD GAR SUR GAR",NULL},
/* 120F4 */ { "SIGNE CUNÉIFORME GALAM",NULL},
/* 120F5 */ { "SIGNE CUNÉIFORME GAM",NULL},
/* 120F6 */ { "SIGNE CUNÉIFORME GAN",NULL},
/* 120F7 */ { "SIGNE CUNÉIFORME GAN2",NULL},
/* 120F8 */ { "SIGNE CUNÉIFORME GAN2 TENOU",NULL},
/* 120F9 */ { "SIGNE CUNÉIFORME GAN2 SUR GAN2",NULL},
/* 120FA */ { "SIGNE CUNÉIFORME DEUX GAN2 CROISÉS",NULL},
/* 120FB */ { "SIGNE CUNÉIFORME GAR",NULL},
/* 120FC */ { "SIGNE CUNÉIFORME GAR3",NULL},
/* 120FD */ { "SIGNE CUNÉIFORME GACHAN",NULL},
/* 120FE */ { "SIGNE CUNÉIFORME GECHTIN",NULL},
/* 120FF */ { "SIGNE CUNÉIFORME GECHTIN FOIS KOUR",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_21[] = {
/* 12100 */ { "SIGNE CUNÉIFORME GI",NULL},
/* 12101 */ { "SIGNE CUNÉIFORME GI FOIS E",NULL},
/* 12102 */ { "SIGNE CUNÉIFORME GI FOIS OU",NULL},
/* 12103 */ { "SIGNE CUNÉIFORME DEUX GI CROISÉS",NULL},
/* 12104 */ { "SIGNE CUNÉIFORME GI4",NULL},
/* 12105 */ { "SIGNE CUNÉIFORME GI4 SUR GI4",NULL},
/* 12106 */ { "SIGNE CUNÉIFORME DEUX GI4 CROISÉS",NULL},
/* 12107 */ { "SIGNE CUNÉIFORME GIDIM",NULL},
/* 12108 */ { "SIGNE CUNÉIFORME GIR2",NULL},
/* 12109 */ { "SIGNE CUNÉIFORME GIR2 GOUNOU",NULL},
/* 1210A */ { "SIGNE CUNÉIFORME GIR3",NULL},
/* 1210B */ { "SIGNE CUNÉIFORME GIR3 FOIS A PLUS IGI",NULL},
/* 1210C */ { "SIGNE CUNÉIFORME GIR3 FOIS GAN2 TENOU",NULL},
/* 1210D */ { "SIGNE CUNÉIFORME GIR3 FOIS IGI",NULL},
/* 1210E */ { "SIGNE CUNÉIFORME GIR3 FOIS LOU PLUS IGI",NULL},
/* 1210F */ { "SIGNE CUNÉIFORME GIR3 FOIS PA",NULL},
/* 12110 */ { "SIGNE CUNÉIFORME GISAL",NULL},
/* 12111 */ { "SIGNE CUNÉIFORME GICH",NULL},
/* 12112 */ { "SIGNE CUNÉIFORME DEUX GICH CROISÉS",NULL},
/* 12113 */ { "SIGNE CUNÉIFORME GICH FOIS BAD",NULL},
/* 12114 */ { "SIGNE CUNÉIFORME GICH FOIS TAK4",NULL},
/* 12115 */ { "SIGNE CUNÉIFORME GICH TENOU",NULL},
/* 12116 */ { "SIGNE CUNÉIFORME GOU",NULL},
/* 12117 */ { "SIGNE CUNÉIFORME DEUX GOU CROISÉS",NULL},
/* 12118 */ { "SIGNE CUNÉIFORME GOU2",NULL},
/* 12119 */ { "SIGNE CUNÉIFORME GOU2 FOIS KAK",NULL},
/* 1211A */ { "SIGNE CUNÉIFORME GOU2 FOIS KAK FOIS IGI GOUNOU",NULL},
/* 1211B */ { "SIGNE CUNÉIFORME GOU2 FOIS NOUN",NULL},
/* 1211C */ { "SIGNE CUNÉIFORME GOU2 FOIS SAL PLUS TOUG2",NULL},
/* 1211D */ { "SIGNE CUNÉIFORME GOU2 GOUNOU",NULL},
/* 1211E */ { "SIGNE CUNÉIFORME GOUD",NULL},
/* 1211F */ { "SIGNE CUNÉIFORME GOUD FOIS A PLUS KOUR",NULL},
/* 12120 */ { "SIGNE CUNÉIFORME GOUD FOIS KOUR",NULL},
/* 12121 */ { "SIGNE CUNÉIFORME GOUD SUR GOUD LOUGAL",NULL},
/* 12122 */ { "SIGNE CUNÉIFORME GOUL",NULL},
/* 12123 */ { "SIGNE CUNÉIFORME GOUM",NULL},
/* 12124 */ { "SIGNE CUNÉIFORME GOUM FOIS CHE",NULL},
/* 12125 */ { "SIGNE CUNÉIFORME GOUR",NULL},
/* 12126 */ { "SIGNE CUNÉIFORME GOUR7",NULL},
/* 12127 */ { "SIGNE CUNÉIFORME GOUROUN",NULL},
/* 12128 */ { "SIGNE CUNÉIFORME GOUROUCH",NULL},
/* 12129 */ { "SIGNE CUNÉIFORME HA",NULL},
/* 1212A */ { "SIGNE CUNÉIFORME HA TENOU",NULL},
/* 1212B */ { "SIGNE CUNÉIFORME HA GOUNOU",NULL},
/* 1212C */ { "SIGNE CUNÉIFORME HAL",NULL},
/* 1212D */ { "SIGNE CUNÉIFORME HI",NULL},
/* 1212E */ { "SIGNE CUNÉIFORME HI FOIS ACH",NULL},
/* 1212F */ { "SIGNE CUNÉIFORME HI FOIS ACH2",NULL},
/* 12130 */ { "SIGNE CUNÉIFORME HI FOIS BAD",NULL},
/* 12131 */ { "SIGNE CUNÉIFORME HI FOIS DICH",NULL},
/* 12132 */ { "SIGNE CUNÉIFORME HI FOIS GAD",NULL},
/* 12133 */ { "SIGNE CUNÉIFORME HI FOIS KIN",NULL},
/* 12134 */ { "SIGNE CUNÉIFORME HI FOIS NOUN",NULL},
/* 12135 */ { "SIGNE CUNÉIFORME HI FOIS CHE",NULL},
/* 12136 */ { "SIGNE CUNÉIFORME HI FOIS OU",NULL},
/* 12137 */ { "SIGNE CUNÉIFORME HOU",NULL},
/* 12138 */ { "SIGNE CUNÉIFORME HOUB2",NULL},
/* 12139 */ { "SIGNE CUNÉIFORME HOUB2 FOIS AN",NULL},
/* 1213A */ { "SIGNE CUNÉIFORME HOUB2 FOIS HAL",NULL},
/* 1213B */ { "SIGNE CUNÉIFORME HOUB2 FOIS KASKAL",NULL},
/* 1213C */ { "SIGNE CUNÉIFORME HOUB2 FOIS LICH",NULL},
/* 1213D */ { "SIGNE CUNÉIFORME HOUB2 FOIS OUD",NULL},
/* 1213E */ { "SIGNE CUNÉIFORME HOUL2",NULL},
/* 1213F */ { "SIGNE CUNÉIFORME I",NULL},
/* 12140 */ { "SIGNE CUNÉIFORME I A",NULL},
/* 12141 */ { "SIGNE CUNÉIFORME IB",NULL},
/* 12142 */ { "SIGNE CUNÉIFORME IDIM",NULL},
/* 12143 */ { "SIGNE CUNÉIFORME IDIM SUR IDIM BOUR",NULL},
/* 12144 */ { "SIGNE CUNÉIFORME QUATRE IDIM SUR IDIM EN CROIX",NULL},
/* 12145 */ { "SIGNE CUNÉIFORME IG",NULL},
/* 12146 */ { "SIGNE CUNÉIFORME IGI",NULL},
/* 12147 */ { "SIGNE CUNÉIFORME IGI DIB",NULL},
/* 12148 */ { "SIGNE CUNÉIFORME IGI RI",NULL},
/* 12149 */ { "SIGNE CUNÉIFORME IGI SUR IGI CHIR SUR CHIR OUD SUR OUD",NULL},
/* 1214A */ { "SIGNE CUNÉIFORME IGI GOUNOU",NULL},
/* 1214B */ { "SIGNE CUNÉIFORME IL",NULL},
/* 1214C */ { "SIGNE CUNÉIFORME IL FOIS GAN2 TENOU",NULL},
/* 1214D */ { "SIGNE CUNÉIFORME IL2",NULL},
/* 1214E */ { "SIGNE CUNÉIFORME IM",NULL},
/* 1214F */ { "SIGNE CUNÉIFORME IM FOIS TAK4",NULL},
/* 12150 */ { "SIGNE CUNÉIFORME DEUX IM CROISÉS",NULL},
/* 12151 */ { "SIGNE CUNÉIFORME IM ADOSSÉ À IM",NULL},
/* 12152 */ { "SIGNE CUNÉIFORME QUATRE IM EN CROIX",NULL},
/* 12153 */ { "SIGNE CUNÉIFORME IMIN",NULL},
/* 12154 */ { "SIGNE CUNÉIFORME IN",NULL},
/* 12155 */ { "SIGNE CUNÉIFORME IR",NULL},
/* 12156 */ { "SIGNE CUNÉIFORME ICH",NULL},
/* 12157 */ { "SIGNE CUNÉIFORME KA",NULL},
/* 12158 */ { "SIGNE CUNÉIFORME KA FOIS A",NULL},
/* 12159 */ { "SIGNE CUNÉIFORME KA FOIS AD",NULL},
/* 1215A */ { "SIGNE CUNÉIFORME KA FOIS AD PLUS KOU3",NULL},
/* 1215B */ { "SIGNE CUNÉIFORME KA FOIS ACH2",NULL},
/* 1215C */ { "SIGNE CUNÉIFORME KA FOIS BAD",NULL},
/* 1215D */ { "SIGNE CUNÉIFORME KA FOIS BALAG",NULL},
/* 1215E */ { "SIGNE CUNÉIFORME KA FOIS BAR",NULL},
/* 1215F */ { "SIGNE CUNÉIFORME KA FOIS BI",NULL},
/* 12160 */ { "SIGNE CUNÉIFORME KA FOIS ERIN2",NULL},
/* 12161 */ { "SIGNE CUNÉIFORME KA FOIS ECH2",NULL},
/* 12162 */ { "SIGNE CUNÉIFORME KA FOIS GA",NULL},
/* 12163 */ { "SIGNE CUNÉIFORME KA FOIS GAL",NULL},
/* 12164 */ { "SIGNE CUNÉIFORME KA FOIS GAN2 TENOU",NULL},
/* 12165 */ { "SIGNE CUNÉIFORME KA FOIS GAR",NULL},
/* 12166 */ { "SIGNE CUNÉIFORME KA FOIS GAR PLUS CHA3 PLUS A",NULL},
/* 12167 */ { "SIGNE CUNÉIFORME KA FOIS GI",NULL},
/* 12168 */ { "SIGNE CUNÉIFORME KA FOIS GIR2",NULL},
/* 12169 */ { "SIGNE CUNÉIFORME KA FOIS GICH PLUS SAR",NULL},
/* 1216A */ { "SIGNE CUNÉIFORME KA FOIS DEUX GICH CROISÉS",NULL},
/* 1216B */ { "SIGNE CUNÉIFORME KA FOIS GOU",NULL},
/* 1216C */ { "SIGNE CUNÉIFORME KA FOIS GOUR7",NULL},
/* 1216D */ { "SIGNE CUNÉIFORME KA FOIS IGI",NULL},
/* 1216E */ { "SIGNE CUNÉIFORME KA FOIS IM",NULL},
/* 1216F */ { "SIGNE CUNÉIFORME KA FOIS KAK",NULL},
/* 12170 */ { "SIGNE CUNÉIFORME KA FOIS KI",NULL},
/* 12171 */ { "SIGNE CUNÉIFORME KA FOIS KID",NULL},
/* 12172 */ { "SIGNE CUNÉIFORME KA FOIS LI",NULL},
/* 12173 */ { "SIGNE CUNÉIFORME KA FOIS LOU",NULL},
/* 12174 */ { "SIGNE CUNÉIFORME KA FOIS ME",NULL},
/* 12175 */ { "SIGNE CUNÉIFORME KA FOIS ME PLUS DOU",NULL},
/* 12176 */ { "SIGNE CUNÉIFORME KA FOIS ME PLUS GI",NULL},
/* 12177 */ { "SIGNE CUNÉIFORME KA FOIS ME PLUS TE",NULL},
/* 12178 */ { "SIGNE CUNÉIFORME KA FOIS MI",NULL},
/* 12179 */ { "SIGNE CUNÉIFORME KA FOIS MI PLUS NOUNOUZ",NULL},
/* 1217A */ { "SIGNE CUNÉIFORME KA FOIS NE",NULL},
/* 1217B */ { "SIGNE CUNÉIFORME KA FOIS NOUN",NULL},
/* 1217C */ { "SIGNE CUNÉIFORME KA FOIS PI",NULL},
/* 1217D */ { "SIGNE CUNÉIFORME KA FOIS ROU",NULL},
/* 1217E */ { "SIGNE CUNÉIFORME KA FOIS SA",NULL},
/* 1217F */ { "SIGNE CUNÉIFORME KA FOIS SAR",NULL},
/* 12180 */ { "SIGNE CUNÉIFORME KA FOIS CHA",NULL},
/* 12181 */ { "SIGNE CUNÉIFORME KA FOIS CHE",NULL},
/* 12182 */ { "SIGNE CUNÉIFORME KA FOIS CHID",NULL},
/* 12183 */ { "SIGNE CUNÉIFORME KA FOIS CHOU",NULL},
/* 12184 */ { "SIGNE CUNÉIFORME KA FOIS SIG",NULL},
/* 12185 */ { "SIGNE CUNÉIFORME KA FOIS SOUHOUR",NULL},
/* 12186 */ { "SIGNE CUNÉIFORME KA FOIS TAR",NULL},
/* 12187 */ { "SIGNE CUNÉIFORME KA FOIS OU",NULL},
/* 12188 */ { "SIGNE CUNÉIFORME KA FOIS OU2",NULL},
/* 12189 */ { "SIGNE CUNÉIFORME KA FOIS OUD",NULL},
/* 1218A */ { "SIGNE CUNÉIFORME KA FOIS OUMOUM FOIS PA",NULL},
/* 1218B */ { "SIGNE CUNÉIFORME KA FOIS OUCH",NULL},
/* 1218C */ { "SIGNE CUNÉIFORME KA FOIS ZI",NULL},
/* 1218D */ { "SIGNE CUNÉIFORME KA2",NULL},
/* 1218E */ { "SIGNE CUNÉIFORME DEUX KA2 CROISÉS",NULL},
/* 1218F */ { "SIGNE CUNÉIFORME KAB",NULL},
/* 12190 */ { "SIGNE CUNÉIFORME KAD2",NULL},
/* 12191 */ { "SIGNE CUNÉIFORME KAD3",NULL},
/* 12192 */ { "SIGNE CUNÉIFORME KAD4",NULL},
/* 12193 */ { "SIGNE CUNÉIFORME KAD5",NULL},
/* 12194 */ { "SIGNE CUNÉIFORME KAD5 SUR KAD5",NULL},
/* 12195 */ { "SIGNE CUNÉIFORME KAK",NULL},
/* 12196 */ { "SIGNE CUNÉIFORME KAK FOIS IGI GOUNOU",NULL},
/* 12197 */ { "SIGNE CUNÉIFORME KAL",NULL},
/* 12198 */ { "SIGNE CUNÉIFORME KAL FOIS BAD",NULL},
/* 12199 */ { "SIGNE CUNÉIFORME DEUX KAL CROISÉS",NULL},
/* 1219A */ { "SIGNE CUNÉIFORME KAM2",NULL},
/* 1219B */ { "SIGNE CUNÉIFORME KAM4",NULL},
/* 1219C */ { "SIGNE CUNÉIFORME KASKAL",NULL},
/* 1219D */ { "SIGNE CUNÉIFORME KASKAL LAGAB FOIS OU SUR LAGAB FOIS OU",NULL},
/* 1219E */ { "SIGNE CUNÉIFORME KASKAL SUR KASKAL LAGAB FOIS OU SUR LAGAB FOIS OU",NULL},
/* 1219F */ { "SIGNE CUNÉIFORME KECH2",NULL},
/* 121A0 */ { "SIGNE CUNÉIFORME KI",NULL},
/* 121A1 */ { "SIGNE CUNÉIFORME KI FOIS BAD",NULL},
/* 121A2 */ { "SIGNE CUNÉIFORME KI FOIS OU",NULL},
/* 121A3 */ { "SIGNE CUNÉIFORME KI FOIS OUD",NULL},
/* 121A4 */ { "SIGNE CUNÉIFORME KID",NULL},
/* 121A5 */ { "SIGNE CUNÉIFORME KIN",NULL},
/* 121A6 */ { "SIGNE CUNÉIFORME KISAL",NULL},
/* 121A7 */ { "SIGNE CUNÉIFORME KICH",NULL},
/* 121A8 */ { "SIGNE CUNÉIFORME KISIM5",NULL},
/* 121A9 */ { "SIGNE CUNÉIFORME KISIM5 SUR KISIM5",NULL},
/* 121AA */ { "SIGNE CUNÉIFORME KOU",NULL},
/* 121AB */ { "SIGNE CUNÉIFORME KOU SUR HI FOIS ACH2 KOU SUR HI FOIS ACH2",NULL},
/* 121AC */ { "SIGNE CUNÉIFORME KOU3",NULL},
/* 121AD */ { "SIGNE CUNÉIFORME KOU4",NULL},
/* 121AE */ { "SIGNE CUNÉIFORME KOU4 VARIANTE",NULL},
/* 121AF */ { "SIGNE CUNÉIFORME KOU7",NULL},
/* 121B0 */ { "SIGNE CUNÉIFORME KOUL",NULL},
/* 121B1 */ { "SIGNE CUNÉIFORME KOUL GOUNOU",NULL},
/* 121B2 */ { "SIGNE CUNÉIFORME KOUN",NULL},
/* 121B3 */ { "SIGNE CUNÉIFORME KOUR",NULL},
/* 121B4 */ { "SIGNE CUNÉIFORME KOUR ADOSSÉ À KOUR",NULL},
/* 121B5 */ { "SIGNE CUNÉIFORME KOUCHOU2",NULL},
/* 121B6 */ { "SIGNE CUNÉIFORME KWOU318",NULL},
/* 121B7 */ { "SIGNE CUNÉIFORME LA",NULL},
/* 121B8 */ { "SIGNE CUNÉIFORME LAGAB",NULL},
/* 121B9 */ { "SIGNE CUNÉIFORME LAGAB FOIS A",NULL},
/* 121BA */ { "SIGNE CUNÉIFORME LAGAB FOIS A PLUS DA PLUS HA",NULL},
/* 121BB */ { "SIGNE CUNÉIFORME LAGAB FOIS A PLUS GAR",NULL},
/* 121BC */ { "SIGNE CUNÉIFORME LAGAB FOIS A PLUS LAL",NULL},
/* 121BD */ { "SIGNE CUNÉIFORME LAGAB FOIS AL",NULL},
/* 121BE */ { "SIGNE CUNÉIFORME LAGAB FOIS AN",NULL},
/* 121BF */ { "SIGNE CUNÉIFORME LAGAB FOIS ACH ZIDA TENOU",NULL},
/* 121C0 */ { "SIGNE CUNÉIFORME LAGAB FOIS BAD",NULL},
/* 121C1 */ { "SIGNE CUNÉIFORME LAGAB FOIS BI",NULL},
/* 121C2 */ { "SIGNE CUNÉIFORME LAGAB FOIS DAR",NULL},
/* 121C3 */ { "SIGNE CUNÉIFORME LAGAB FOIS EN",NULL},
/* 121C4 */ { "SIGNE CUNÉIFORME LAGAB FOIS GA",NULL},
/* 121C5 */ { "SIGNE CUNÉIFORME LAGAB FOIS GAR",NULL},
/* 121C6 */ { "SIGNE CUNÉIFORME LAGAB FOIS GOUD",NULL},
/* 121C7 */ { "SIGNE CUNÉIFORME LAGAB FOIS GOUD PLUS GOUD",NULL},
/* 121C8 */ { "SIGNE CUNÉIFORME LAGAB FOIS HA",NULL},
/* 121C9 */ { "SIGNE CUNÉIFORME LAGAB FOIS HAL",NULL},
/* 121CA */ { "SIGNE CUNÉIFORME LAGAB FOIS HI FOIS NOUN",NULL},
/* 121CB */ { "SIGNE CUNÉIFORME LAGAB FOIS IGI GOUNOU",NULL},
/* 121CC */ { "SIGNE CUNÉIFORME LAGAB FOIS IM",NULL},
/* 121CD */ { "SIGNE CUNÉIFORME LAGAB FOIS IM PLUS HA",NULL},
/* 121CE */ { "SIGNE CUNÉIFORME LAGAB FOIS IM PLUS LOU",NULL},
/* 121CF */ { "SIGNE CUNÉIFORME LAGAB FOIS KI",NULL},
/* 121D0 */ { "SIGNE CUNÉIFORME LAGAB FOIS KIN",NULL},
/* 121D1 */ { "SIGNE CUNÉIFORME LAGAB FOIS KOU3",NULL},
/* 121D2 */ { "SIGNE CUNÉIFORME LAGAB FOIS KOUL",NULL},
/* 121D3 */ { "SIGNE CUNÉIFORME LAGAB FOIS KOUL PLUS HI PLUS A",NULL},
/* 121D4 */ { "SIGNE CUNÉIFORME LAGAB FOIS LAGAB",NULL},
/* 121D5 */ { "SIGNE CUNÉIFORME LAGAB FOIS LICH",NULL},
/* 121D6 */ { "SIGNE CUNÉIFORME LAGAB FOIS LOU",NULL},
/* 121D7 */ { "SIGNE CUNÉIFORME LAGAB FOIS LOUL",NULL},
/* 121D8 */ { "SIGNE CUNÉIFORME LAGAB FOIS ME",NULL},
/* 121D9 */ { "SIGNE CUNÉIFORME LAGAB FOIS ME PLUS EN",NULL},
/* 121DA */ { "SIGNE CUNÉIFORME LAGAB FOIS MOUCH",NULL},
/* 121DB */ { "SIGNE CUNÉIFORME LAGAB FOIS NE",NULL},
/* 121DC */ { "SIGNE CUNÉIFORME LAGAB FOIS CHE PLUS SOUM",NULL},
/* 121DD */ { "SIGNE CUNÉIFORME LAGAB FOIS CHITA PLUS GICH PLUS ERIN2",NULL},
/* 121DE */ { "SIGNE CUNÉIFORME LAGAB FOIS CHITA PLUS GICH TENOU",NULL},
/* 121DF */ { "SIGNE CUNÉIFORME LAGAB FOIS CHOU2",NULL},
/* 121E0 */ { "SIGNE CUNÉIFORME LAGAB FOIS CHOU2 PLUS CHOU2",NULL},
/* 121E1 */ { "SIGNE CUNÉIFORME LAGAB FOIS SOUM",NULL},
/* 121E2 */ { "SIGNE CUNÉIFORME LAGAB FOIS TAG",NULL},
/* 121E3 */ { "SIGNE CUNÉIFORME LAGAB FOIS TAK4",NULL},
/* 121E4 */ { "SIGNE CUNÉIFORME LAGAB FOIS TE PLUS A PLUS SOU PLUS NA",NULL},
/* 121E5 */ { "SIGNE CUNÉIFORME LAGAB FOIS OU",NULL},
/* 121E6 */ { "SIGNE CUNÉIFORME LAGAB FOIS OU PLUS A",NULL},
/* 121E7 */ { "SIGNE CUNÉIFORME LAGAB FOIS OU PLUS OU PLUS OU",NULL},
/* 121E8 */ { "SIGNE CUNÉIFORME LAGAB FOIS OU2 PLUS ACH",NULL},
/* 121E9 */ { "SIGNE CUNÉIFORME LAGAB FOIS OUD",NULL},
/* 121EA */ { "SIGNE CUNÉIFORME LAGAB FOIS OUCH",NULL},
/* 121EB */ { "SIGNE CUNÉIFORME QUATRE LAGAB EN CROIX",NULL},
/* 121EC */ { "SIGNE CUNÉIFORME LAGAR",NULL},
/* 121ED */ { "SIGNE CUNÉIFORME LAGAR FOIS CHE",NULL},
/* 121EE */ { "SIGNE CUNÉIFORME LAGAR FOIS CHE PLUS SOUM",NULL},
/* 121EF */ { "SIGNE CUNÉIFORME LAGAR GOUNOU",NULL},
/* 121F0 */ { "SIGNE CUNÉIFORME LAGAR GOUNOU SUR LAGAR GOUNOU CHE",NULL},
/* 121F1 */ { "SIGNE CUNÉIFORME LAHCHOU",NULL},
/* 121F2 */ { "SIGNE CUNÉIFORME LAL",NULL},
/* 121F3 */ { "SIGNE CUNÉIFORME LAL FOIS LAL",NULL},
/* 121F4 */ { "SIGNE CUNÉIFORME LAM",NULL},
/* 121F5 */ { "SIGNE CUNÉIFORME LAM FOIS KOUR",NULL},
/* 121F6 */ { "SIGNE CUNÉIFORME LAM FOIS KOUR PLUS ROU",NULL},
/* 121F7 */ { "SIGNE CUNÉIFORME LI",NULL},
/* 121F8 */ { "SIGNE CUNÉIFORME LIL",NULL},
/* 121F9 */ { "SIGNE CUNÉIFORME LIMMOU2",NULL},
/* 121FA */ { "SIGNE CUNÉIFORME LICH",NULL},
/* 121FB */ { "SIGNE CUNÉIFORME LOU",NULL},
/* 121FC */ { "SIGNE CUNÉIFORME LOU FOIS BAD",NULL},
/* 121FD */ { "SIGNE CUNÉIFORME LOU2",NULL},
/* 121FE */ { "SIGNE CUNÉIFORME LOU2 FOIS AL",NULL},
/* 121FF */ { "SIGNE CUNÉIFORME LOU2 FOIS BAD",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_22[] = {
/* 12200 */ { "SIGNE CUNÉIFORME LOU2 FOIS ECH2",NULL},
/* 12201 */ { "SIGNE CUNÉIFORME LOU2 FOIS ECH2 TENOU",NULL},
/* 12202 */ { "SIGNE CUNÉIFORME LOU2 FOIS GAN2 TENOU",NULL},
/* 12203 */ { "SIGNE CUNÉIFORME LOU2 FOIS HI FOIS BAD",NULL},
/* 12204 */ { "SIGNE CUNÉIFORME LOU2 FOIS IM",NULL},
/* 12205 */ { "SIGNE CUNÉIFORME LOU2 FOIS KAD2",NULL},
/* 12206 */ { "SIGNE CUNÉIFORME LOU2 FOIS KAD3",NULL},
/* 12207 */ { "SIGNE CUNÉIFORME LOU2 FOIS KAD3 PLUS ACH",NULL},
/* 12208 */ { "SIGNE CUNÉIFORME LOU2 FOIS KI",NULL},
/* 12209 */ { "SIGNE CUNÉIFORME LOU2 FOIS LA PLUS ACH",NULL},
/* 1220A */ { "SIGNE CUNÉIFORME LOU2 FOIS LAGAB",NULL},
/* 1220B */ { "SIGNE CUNÉIFORME LOU2 FOIS ME PLUS EN",NULL},
/* 1220C */ { "SIGNE CUNÉIFORME LOU2 FOIS NE",NULL},
/* 1220D */ { "SIGNE CUNÉIFORME LOU2 FOIS NOU",NULL},
/* 1220E */ { "SIGNE CUNÉIFORME LOU2 FOIS SI PLUS ACH",NULL},
/* 1220F */ { "SIGNE CUNÉIFORME LOU2 FOIS SIK2 PLUS BOU",NULL},
/* 12210 */ { "SIGNE CUNÉIFORME LOU2 FOIS TOUG2",NULL},
/* 12211 */ { "SIGNE CUNÉIFORME LOU2 TENOU",NULL},
/* 12212 */ { "SIGNE CUNÉIFORME DEUX LOU2 CROISÉS",NULL},
/* 12213 */ { "SIGNE CUNÉIFORME LOU2 ADOSSÉ À LOU2",NULL},
/* 12214 */ { "SIGNE CUNÉIFORME QUATRE LOU2 EN CROIX",NULL},
/* 12215 */ { "SIGNE CUNÉIFORME LOU2 CHECHIG",NULL},
/* 12216 */ { "SIGNE CUNÉIFORME LOU3",NULL},
/* 12217 */ { "SIGNE CUNÉIFORME LOUGAL",NULL},
/* 12218 */ { "SIGNE CUNÉIFORME LOUGAL SUR LOUGAL",NULL},
/* 12219 */ { "SIGNE CUNÉIFORME LOUGAL ADOSSÉ À LOUGAL",NULL},
/* 1221A */ { "SIGNE CUNÉIFORME LOUGAL CHECHIG",NULL},
/* 1221B */ { "SIGNE CUNÉIFORME LOUH",NULL},
/* 1221C */ { "SIGNE CUNÉIFORME LOUL",NULL},
/* 1221D */ { "SIGNE CUNÉIFORME LOUM",NULL},
/* 1221E */ { "SIGNE CUNÉIFORME LOUM SUR LOUM",NULL},
/* 1221F */ { "SIGNE CUNÉIFORME LOUM SUR LOUM GAR SUR GAR",NULL},
/* 12220 */ { "SIGNE CUNÉIFORME MA",NULL},
/* 12221 */ { "SIGNE CUNÉIFORME MA FOIS TAK4",NULL},
/* 12222 */ { "SIGNE CUNÉIFORME MA GOUNOU",NULL},
/* 12223 */ { "SIGNE CUNÉIFORME MA2",NULL},
/* 12224 */ { "SIGNE CUNÉIFORME MAH",NULL},
/* 12225 */ { "SIGNE CUNÉIFORME MAR",NULL},
/* 12226 */ { "SIGNE CUNÉIFORME MACH","	= 1/2 diš\n"
	"	x (signe numéral cunéiforme un ban2 - 1244F)"},
/* 12227 */ { "SIGNE CUNÉIFORME MACH2",NULL},
/* 12228 */ { "SIGNE CUNÉIFORME ME",NULL},
/* 12229 */ { "SIGNE CUNÉIFORME MES",NULL},
/* 1222A */ { "SIGNE CUNÉIFORME MI",NULL},
/* 1222B */ { "SIGNE CUNÉIFORME MIN","	= 2 diš\n"
	"	x (signe numéral cunéiforme trois dich - 12408)"},
/* 1222C */ { "SIGNE CUNÉIFORME MOU",NULL},
/* 1222D */ { "SIGNE CUNÉIFORME MOU SUR MOU",NULL},
/* 1222E */ { "SIGNE CUNÉIFORME MOUG",NULL},
/* 1222F */ { "SIGNE CUNÉIFORME MOUG GOUNOU",NULL},
/* 12230 */ { "SIGNE CUNÉIFORME MOUNSOUB",NULL},
/* 12231 */ { "SIGNE CUNÉIFORME MOURGOU2",NULL},
/* 12232 */ { "SIGNE CUNÉIFORME MOUCH",NULL},
/* 12233 */ { "SIGNE CUNÉIFORME MOUCH FOIS A",NULL},
/* 12234 */ { "SIGNE CUNÉIFORME MOUCH FOIS KOUR",NULL},
/* 12235 */ { "SIGNE CUNÉIFORME MOUCH FOIS ZA",NULL},
/* 12236 */ { "SIGNE CUNÉIFORME MOUCH SUR MOUCH",NULL},
/* 12237 */ { "SIGNE CUNÉIFORME MOUCH SUR MOUCH FOIS A PLUS NA",NULL},
/* 12238 */ { "SIGNE CUNÉIFORME DEUX MOUCH CROISÉS",NULL},
/* 12239 */ { "SIGNE CUNÉIFORME MOUCH3",NULL},
/* 1223A */ { "SIGNE CUNÉIFORME MOUCH3 FOIS A",NULL},
/* 1223B */ { "SIGNE CUNÉIFORME MOUCH3 FOIS A PLUS DI",NULL},
/* 1223C */ { "SIGNE CUNÉIFORME MOUCH3 FOIS DI",NULL},
/* 1223D */ { "SIGNE CUNÉIFORME MOUCH3 GOUNOU",NULL},
/* 1223E */ { "SIGNE CUNÉIFORME NA",NULL},
/* 1223F */ { "SIGNE CUNÉIFORME NA2",NULL},
/* 12240 */ { "SIGNE CUNÉIFORME NAGA",NULL},
/* 12241 */ { "SIGNE CUNÉIFORME NAGA CULBUTÉ",NULL},
/* 12242 */ { "SIGNE CUNÉIFORME NAGA FOIS CHOU TENOU",NULL},
/* 12243 */ { "SIGNE CUNÉIFORME NAGA ADOSSÉ À NAGA",NULL},
/* 12244 */ { "SIGNE CUNÉIFORME NAGAR",NULL},
/* 12245 */ { "SIGNE CUNÉIFORME NAM NOUTILLOU",NULL},
/* 12246 */ { "SIGNE CUNÉIFORME NAM",NULL},
/* 12247 */ { "SIGNE CUNÉIFORME NAM2",NULL},
/* 12248 */ { "SIGNE CUNÉIFORME NE",NULL},
/* 12249 */ { "SIGNE CUNÉIFORME NE FOIS A",NULL},
/* 1224A */ { "SIGNE CUNÉIFORME NE FOIS OUD",NULL},
/* 1224B */ { "SIGNE CUNÉIFORME NE CHECHIG",NULL},
/* 1224C */ { "SIGNE CUNÉIFORME NI",NULL},
/* 1224D */ { "SIGNE CUNÉIFORME NI FOIS E",NULL},
/* 1224E */ { "SIGNE CUNÉIFORME NI2",NULL},
/* 1224F */ { "SIGNE CUNÉIFORME NIM",NULL},
/* 12250 */ { "SIGNE CUNÉIFORME NIM FOIS GAN2 TENOU",NULL},
/* 12251 */ { "SIGNE CUNÉIFORME NIM FOIS GAR PLUS GAN2 TENOU",NULL},
/* 12252 */ { "SIGNE CUNÉIFORME NINDA2",NULL},
/* 12253 */ { "SIGNE CUNÉIFORME NINDA2 FOIS AN",NULL},
/* 12254 */ { "SIGNE CUNÉIFORME NINDA2 FOIS ACH",NULL},
/* 12255 */ { "SIGNE CUNÉIFORME NINDA2 FOIS ACH PLUS ACH",NULL},
/* 12256 */ { "SIGNE CUNÉIFORME NINDA2 FOIS GOUD",NULL},
/* 12257 */ { "SIGNE CUNÉIFORME NINDA2 FOIS ME PLUS GAN2 TENOU",NULL},
/* 12258 */ { "SIGNE CUNÉIFORME NINDA2 FOIS NE",NULL},
/* 12259 */ { "SIGNE CUNÉIFORME NINDA2 FOIS NOUN",NULL},
/* 1225A */ { "SIGNE CUNÉIFORME NINDA2 FOIS CHE",NULL},
/* 1225B */ { "SIGNE CUNÉIFORME NINDA2 FOIS CHE PLUS A AN",NULL},
/* 1225C */ { "SIGNE CUNÉIFORME NINDA2 FOIS CHE PLUS ACH",NULL},
/* 1225D */ { "SIGNE CUNÉIFORME NINDA2 FOIS CHE PLUS ACH PLUS ACH",NULL},
/* 1225E */ { "SIGNE CUNÉIFORME NINDA2 FOIS OU2 PLUS ACH",NULL},
/* 1225F */ { "SIGNE CUNÉIFORME NINDA2 FOIS OUCH",NULL},
/* 12260 */ { "SIGNE CUNÉIFORME NISAG",NULL},
/* 12261 */ { "SIGNE CUNÉIFORME NOU",NULL},
/* 12262 */ { "SIGNE CUNÉIFORME NOU11",NULL},
/* 12263 */ { "SIGNE CUNÉIFORME NOUN",NULL},
/* 12264 */ { "SIGNE CUNÉIFORME NOUN LAGAR FOIS GAR",NULL},
/* 12265 */ { "SIGNE CUNÉIFORME NOUN LAGAR FOIS MACH",NULL},
/* 12266 */ { "SIGNE CUNÉIFORME NOUN LAGAR FOIS SAL",NULL},
/* 12267 */ { "SIGNE CUNÉIFORME NOUN LAGAR FOIS SAL SUR NOUN LAGAR FOIS SAL",NULL},
/* 12268 */ { "SIGNE CUNÉIFORME NOUN LAGAR FOIS OUCH",NULL},
/* 12269 */ { "SIGNE CUNÉIFORME NOUN TENOU",NULL},
/* 1226A */ { "SIGNE CUNÉIFORME NOUN SUR NOUN",NULL},
/* 1226B */ { "SIGNE CUNÉIFORME DEUX NOUN CROISÉS",NULL},
/* 1226C */ { "SIGNE CUNÉIFORME DEUX NOUN CROISÉS LAGAR SUR LAGAR",NULL},
/* 1226D */ { "SIGNE CUNÉIFORME NOUNOUZ",NULL},
/* 1226E */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS ACHGAB",NULL},
/* 1226F */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS BI",NULL},
/* 12270 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS DOUG",NULL},
/* 12271 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS GOUD",NULL},
/* 12272 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS IGI GOUNOU",NULL},
/* 12273 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS KAD3",NULL},
/* 12274 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS LA",NULL},
/* 12275 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS NE",NULL},
/* 12276 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS SILA3",NULL},
/* 12277 */ { "SIGNE CUNÉIFORME NOUNOUZ AB2 FOIS OU2",NULL},
/* 12278 */ { "SIGNE CUNÉIFORME NOUNOUZ KISIM5 FOIS BI",NULL},
/* 12279 */ { "SIGNE CUNÉIFORME NOUNOUZ KISIM5 FOIS BI OU",NULL},
/* 1227A */ { "SIGNE CUNÉIFORME PA","	x (signe numéral cunéiforme deux ban2 - 12450)"},
/* 1227B */ { "SIGNE CUNÉIFORME PAD",NULL},
/* 1227C */ { "SIGNE CUNÉIFORME PAN",NULL},
/* 1227D */ { "SIGNE CUNÉIFORME PAP",NULL},
/* 1227E */ { "SIGNE CUNÉIFORME PECH2",NULL},
/* 1227F */ { "SIGNE CUNÉIFORME PI",NULL},
/* 12280 */ { "SIGNE CUNÉIFORME PI FOIS A",NULL},
/* 12281 */ { "SIGNE CUNÉIFORME PI FOIS AB",NULL},
/* 12282 */ { "SIGNE CUNÉIFORME PI FOIS BI",NULL},
/* 12283 */ { "SIGNE CUNÉIFORME PI FOIS BOU",NULL},
/* 12284 */ { "SIGNE CUNÉIFORME PI FOIS E",NULL},
/* 12285 */ { "SIGNE CUNÉIFORME PI FOIS I",NULL},
/* 12286 */ { "SIGNE CUNÉIFORME PI FOIS IB",NULL},
/* 12287 */ { "SIGNE CUNÉIFORME PI FOIS OU",NULL},
/* 12288 */ { "SIGNE CUNÉIFORME PI FOIS OU2",NULL},
/* 12289 */ { "SIGNE CUNÉIFORME DEUX PI CROISÉS",NULL},
/* 1228A */ { "SIGNE CUNÉIFORME PIRIG",NULL},
/* 1228B */ { "SIGNE CUNÉIFORME PIRIG FOIS KAL",NULL},
/* 1228C */ { "SIGNE CUNÉIFORME PIRIG FOIS OUD",NULL},
/* 1228D */ { "SIGNE CUNÉIFORME PIRIG FOIS ZA",NULL},
/* 1228E */ { "SIGNE CUNÉIFORME PIRIG ADOSSÉ À PIRIG",NULL},
/* 1228F */ { "SIGNE CUNÉIFORME RA",NULL},
/* 12290 */ { "SIGNE CUNÉIFORME RAB",NULL},
/* 12291 */ { "SIGNE CUNÉIFORME RI",NULL},
/* 12292 */ { "SIGNE CUNÉIFORME ROU",NULL},
/* 12293 */ { "SIGNE CUNÉIFORME SA",NULL},
/* 12294 */ { "SIGNE CUNÉIFORME SAG NOUTILLOU",NULL},
/* 12295 */ { "SIGNE CUNÉIFORME SAG",NULL},
/* 12296 */ { "SIGNE CUNÉIFORME SAG FOIS A",NULL},
/* 12297 */ { "SIGNE CUNÉIFORME SAG FOIS DOU",NULL},
/* 12298 */ { "SIGNE CUNÉIFORME SAG FOIS DOUB",NULL},
/* 12299 */ { "SIGNE CUNÉIFORME SAG FOIS HA",NULL},
/* 1229A */ { "SIGNE CUNÉIFORME SAG FOIS KAK",NULL},
/* 1229B */ { "SIGNE CUNÉIFORME SAG FOIS KOUR",NULL},
/* 1229C */ { "SIGNE CUNÉIFORME SAG FOIS LOUM",NULL},
/* 1229D */ { "SIGNE CUNÉIFORME SAG FOIS MI",NULL},
/* 1229E */ { "SIGNE CUNÉIFORME SAG FOIS NOUN",NULL},
/* 1229F */ { "SIGNE CUNÉIFORME SAG FOIS SAL",NULL},
/* 122A0 */ { "SIGNE CUNÉIFORME SAG FOIS CHID",NULL},
/* 122A1 */ { "SIGNE CUNÉIFORME SAG FOIS TAB",NULL},
/* 122A2 */ { "SIGNE CUNÉIFORME SAG FOIS OU2",NULL},
/* 122A3 */ { "SIGNE CUNÉIFORME SAG FOIS OUB",NULL},
/* 122A4 */ { "SIGNE CUNÉIFORME SAG FOIS OUM",NULL},
/* 122A5 */ { "SIGNE CUNÉIFORME SAG FOIS OUR",NULL},
/* 122A6 */ { "SIGNE CUNÉIFORME SAG FOIS OUCH",NULL},
/* 122A7 */ { "SIGNE CUNÉIFORME SAG SUR SAG",NULL},
/* 122A8 */ { "SIGNE CUNÉIFORME SAG GOUNOU",NULL},
/* 122A9 */ { "SIGNE CUNÉIFORME SAL",NULL},
/* 122AA */ { "SIGNE CUNÉIFORME SAL LAGAB FOIS ACH2",NULL},
/* 122AB */ { "SIGNE CUNÉIFORME SANGA2",NULL},
/* 122AC */ { "SIGNE CUNÉIFORME SAR",NULL},
/* 122AD */ { "SIGNE CUNÉIFORME CHA",NULL},
/* 122AE */ { "SIGNE CUNÉIFORME CHA3",NULL},
/* 122AF */ { "SIGNE CUNÉIFORME CHA3 FOIS A",NULL},
/* 122B0 */ { "SIGNE CUNÉIFORME CHA3 FOIS BAD",NULL},
/* 122B1 */ { "SIGNE CUNÉIFORME CHA3 FOIS GICH",NULL},
/* 122B2 */ { "SIGNE CUNÉIFORME CHA3 FOIS NE",NULL},
/* 122B3 */ { "SIGNE CUNÉIFORME CHA3 FOIS CHOU2",NULL},
/* 122B4 */ { "SIGNE CUNÉIFORME CHA3 FOIS TOUR",NULL},
/* 122B5 */ { "SIGNE CUNÉIFORME CHA3 FOIS OU",NULL},
/* 122B6 */ { "SIGNE CUNÉIFORME CHA3 FOIS OU PLUS A",NULL},
/* 122B7 */ { "SIGNE CUNÉIFORME CHA6",NULL},
/* 122B8 */ { "SIGNE CUNÉIFORME CHAB6",NULL},
/* 122B9 */ { "SIGNE CUNÉIFORME CHAR2","	= 1 šar₂\n"
	"	* même glyphe que 1212D HI, sauf dans les textes les plus archaïsants\n"
	"	* le glyphe de référence archaïque est formé par une indentation circulaire réalisée avec l'extrémité du calame\n"
	"	* utilisé pour le logogramme šar₂ et pour 1 šar₂ en cunéiforme\n"
	"	x (signe numéral cunéiforme deux char2 - 12423)"},
/* 122BA */ { "SIGNE CUNÉIFORME CHE",NULL},
/* 122BB */ { "SIGNE CUNÉIFORME CHE HOU",NULL},
/* 122BC */ { "SIGNE CUNÉIFORME CHE SUR CHE GAD SUR GAD GAR SUR GAR",NULL},
/* 122BD */ { "SIGNE CUNÉIFORME CHE SUR CHE TAB SUR TAB GAR SUR GAR",NULL},
/* 122BE */ { "SIGNE CUNÉIFORME CHEG9",NULL},
/* 122BF */ { "SIGNE CUNÉIFORME CHEN",NULL},
/* 122C0 */ { "SIGNE CUNÉIFORME CHECH",NULL},
/* 122C1 */ { "SIGNE CUNÉIFORME CHECH2",NULL},
/* 122C2 */ { "SIGNE CUNÉIFORME CHECHLAM",NULL},
/* 122C3 */ { "SIGNE CUNÉIFORME CHID",NULL},
/* 122C4 */ { "SIGNE CUNÉIFORME CHID FOIS A",NULL},
/* 122C5 */ { "SIGNE CUNÉIFORME CHID FOIS IM",NULL},
/* 122C6 */ { "SIGNE CUNÉIFORME CHIM",NULL},
/* 122C7 */ { "SIGNE CUNÉIFORME CHIM FOIS A",NULL},
/* 122C8 */ { "SIGNE CUNÉIFORME CHIM FOIS BAL",NULL},
/* 122C9 */ { "SIGNE CUNÉIFORME CHIM FOIS BOULOUG",NULL},
/* 122CA */ { "SIGNE CUNÉIFORME CHIM FOIS DIN",NULL},
/* 122CB */ { "SIGNE CUNÉIFORME CHIM FOIS GAR",NULL},
/* 122CC */ { "SIGNE CUNÉIFORME CHIM FOIS IGI",NULL},
/* 122CD */ { "SIGNE CUNÉIFORME CHIM FOIS IGI GOUNOU",NULL},
/* 122CE */ { "SIGNE CUNÉIFORME CHIM FOIS KOUCHOU2",NULL},
/* 122CF */ { "SIGNE CUNÉIFORME CHIM FOIS LOUL",NULL},
/* 122D0 */ { "SIGNE CUNÉIFORME CHIM FOIS MOUG",NULL},
/* 122D1 */ { "SIGNE CUNÉIFORME CHIM FOIS SAL",NULL},
/* 122D2 */ { "SIGNE CUNÉIFORME CHINIG",NULL},
/* 122D3 */ { "SIGNE CUNÉIFORME CHIR",NULL},
/* 122D4 */ { "SIGNE CUNÉIFORME NOU11 TENOU","	* le nom formel de ce caractère en anglais est erroné"},
/* 122D5 */ { "SIGNE CUNÉIFORME NOU11 SUR NOU11 BOUR SUR BOUR","	* le nom formel de ce caractère en anglais est erroné"},
/* 122D6 */ { "SIGNE CUNÉIFORME CHITA",NULL},
/* 122D7 */ { "SIGNE CUNÉIFORME CHOU",NULL},
/* 122D8 */ { "SIGNE CUNÉIFORME CHOU SUR CHOU RENVERSÉ",NULL},
/* 122D9 */ { "SIGNE CUNÉIFORME CHOU2",NULL},
/* 122DA */ { "SIGNE CUNÉIFORME CHOUBOUR",NULL},
/* 122DB */ { "SIGNE CUNÉIFORME SI",NULL},
/* 122DC */ { "SIGNE CUNÉIFORME SI GOUNOU",NULL},
/* 122DD */ { "SIGNE CUNÉIFORME SIG",NULL},
/* 122DE */ { "SIGNE CUNÉIFORME SIG4",NULL},
/* 122DF */ { "SIGNE CUNÉIFORME SIG4 SUR SIG4 CHOU2",NULL},
/* 122E0 */ { "SIGNE CUNÉIFORME SIK2",NULL},
/* 122E1 */ { "SIGNE CUNÉIFORME SILA3",NULL},
/* 122E2 */ { "SIGNE CUNÉIFORME SOU",NULL},
/* 122E3 */ { "SIGNE CUNÉIFORME SOU SUR SOU",NULL},
/* 122E4 */ { "SIGNE CUNÉIFORME SOUD",NULL},
/* 122E5 */ { "SIGNE CUNÉIFORME SOUD2",NULL},
/* 122E6 */ { "SIGNE CUNÉIFORME SOUHOUR",NULL},
/* 122E7 */ { "SIGNE CUNÉIFORME SOUM",NULL},
/* 122E8 */ { "SIGNE CUNÉIFORME SOUMACH",NULL},
/* 122E9 */ { "SIGNE CUNÉIFORME SOUR",NULL},
/* 122EA */ { "SIGNE CUNÉIFORME SOUR9",NULL},
/* 122EB */ { "SIGNE CUNÉIFORME TA",NULL},
/* 122EC */ { "SIGNE CUNÉIFORME TA ASTÉRISQUE",NULL},
/* 122ED */ { "SIGNE CUNÉIFORME TA FOIS HI",NULL},
/* 122EE */ { "SIGNE CUNÉIFORME TA FOIS MI",NULL},
/* 122EF */ { "SIGNE CUNÉIFORME TA GOUNOU",NULL},
/* 122F0 */ { "SIGNE CUNÉIFORME TAB",NULL},
/* 122F1 */ { "SIGNE CUNÉIFORME TAB SUR TAB NI SUR NI DICH SUR DICH",NULL},
/* 122F2 */ { "SIGNE CUNÉIFORME QUATRE TAB EN CROIX",NULL},
/* 122F3 */ { "SIGNE CUNÉIFORME TAG",NULL},
/* 122F4 */ { "SIGNE CUNÉIFORME TAG FOIS BI",NULL},
/* 122F5 */ { "SIGNE CUNÉIFORME TAG FOIS GOUD",NULL},
/* 122F6 */ { "SIGNE CUNÉIFORME TAG FOIS CHE",NULL},
/* 122F7 */ { "SIGNE CUNÉIFORME TAG FOIS CHOU",NULL},
/* 122F8 */ { "SIGNE CUNÉIFORME TAG FOIS TOUG2",NULL},
/* 122F9 */ { "SIGNE CUNÉIFORME TAG FOIS OUD",NULL},
/* 122FA */ { "SIGNE CUNÉIFORME TAK4",NULL},
/* 122FB */ { "SIGNE CUNÉIFORME TAR",NULL},
/* 122FC */ { "SIGNE CUNÉIFORME TE",NULL},
/* 122FD */ { "SIGNE CUNÉIFORME TE GOUNOU",NULL},
/* 122FE */ { "SIGNE CUNÉIFORME TI",NULL},
/* 122FF */ { "SIGNE CUNÉIFORME TI TENOU",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_23[] = {
/* 12300 */ { "SIGNE CUNÉIFORME TIL",NULL},
/* 12301 */ { "SIGNE CUNÉIFORME TIR",NULL},
/* 12302 */ { "SIGNE CUNÉIFORME TIR FOIS TAK4",NULL},
/* 12303 */ { "SIGNE CUNÉIFORME TIR SUR TIR",NULL},
/* 12304 */ { "SIGNE CUNÉIFORME TIR SUR TIR GAD SUR GAD GAR SUR GAR",NULL},
/* 12305 */ { "SIGNE CUNÉIFORME TOU",NULL},
/* 12306 */ { "SIGNE CUNÉIFORME TOUG2",NULL},
/* 12307 */ { "SIGNE CUNÉIFORME TOUK",NULL},
/* 12308 */ { "SIGNE CUNÉIFORME TOUM",NULL},
/* 12309 */ { "SIGNE CUNÉIFORME TOUR",NULL},
/* 1230A */ { "SIGNE CUNÉIFORME TOUR SUR TOUR ZA SUR ZA",NULL},
/* 1230B */ { "SIGNE CUNÉIFORME OU","	= 1 u\n"
	"	= 1 bur₃\n"
	"	x (signe numéral cunéiforme quatre ou - 1240F)"},
/* 1230C */ { "SIGNE CUNÉIFORME OU GOUD",NULL},
/* 1230D */ { "SIGNE CUNÉIFORME OU OU OU","	= 3 u\n"
	"	= 3 bur₃\n"
	"	x (signe numéral cunéiforme quatre ou - 1240F)"},
/* 1230E */ { "SIGNE CUNÉIFORME OU SUR OU PA SUR PA GAR SUR GAR",NULL},
/* 1230F */ { "SIGNE CUNÉIFORME OU SUR OU SOUR SUR SOUR",NULL},
/* 12310 */ { "SIGNE CUNÉIFORME OU SUR OU OU RÉFLÉCHI SUR OU RÉFLÉCHI",NULL},
/* 12311 */ { "SIGNE CUNÉIFORME OU2",NULL},
/* 12312 */ { "SIGNE CUNÉIFORME OUB",NULL},
/* 12313 */ { "SIGNE CUNÉIFORME OUD",NULL},
/* 12314 */ { "SIGNE CUNÉIFORME OUD KOUCHOU2",NULL},
/* 12315 */ { "SIGNE CUNÉIFORME OUD FOIS BAD",NULL},
/* 12316 */ { "SIGNE CUNÉIFORME OUD FOIS MI",NULL},
/* 12317 */ { "SIGNE CUNÉIFORME OUD FOIS OU PLUS OU PLUS OU",NULL},
/* 12318 */ { "SIGNE CUNÉIFORME OUD FOIS OU PLUS OU PLUS OU GOUNOU",NULL},
/* 12319 */ { "SIGNE CUNÉIFORME OUD GOUNOU",NULL},
/* 1231A */ { "SIGNE CUNÉIFORME OUD CHECHIG",NULL},
/* 1231B */ { "SIGNE CUNÉIFORME OUD CHECHIG FOIS BAD",NULL},
/* 1231C */ { "SIGNE CUNÉIFORME OUDOUG",NULL},
/* 1231D */ { "SIGNE CUNÉIFORME OUM",NULL},
/* 1231E */ { "SIGNE CUNÉIFORME OUM FOIS LAGAB",NULL},
/* 1231F */ { "SIGNE CUNÉIFORME OUM FOIS ME PLUS DA",NULL},
/* 12320 */ { "SIGNE CUNÉIFORME OUM FOIS CHA3",NULL},
/* 12321 */ { "SIGNE CUNÉIFORME OUM FOIS OU",NULL},
/* 12322 */ { "SIGNE CUNÉIFORME OUMBIN",NULL},
/* 12323 */ { "SIGNE CUNÉIFORME OUMOUM",NULL},
/* 12324 */ { "SIGNE CUNÉIFORME OUMOUM FOIS KASKAL",NULL},
/* 12325 */ { "SIGNE CUNÉIFORME OUMOUM FOIS PA",NULL},
/* 12326 */ { "SIGNE CUNÉIFORME OUN","	= kalam gounou"},
/* 12327 */ { "SIGNE CUNÉIFORME KALAM","	* le nom formel de ce caractère en anglais est erroné"},
/* 12328 */ { "SIGNE CUNÉIFORME OUR",NULL},
/* 12329 */ { "SIGNE CUNÉIFORME DEUX OUR CROISÉS",NULL},
/* 1232A */ { "SIGNE CUNÉIFORME OUR CHECHIG",NULL},
/* 1232B */ { "SIGNE CUNÉIFORME OUR2",NULL},
/* 1232C */ { "SIGNE CUNÉIFORME OUR2 FOIS A PLUS HA",NULL},
/* 1232D */ { "SIGNE CUNÉIFORME OUR2 FOIS A PLUS NA",NULL},
/* 1232E */ { "SIGNE CUNÉIFORME OUR2 FOIS AL",NULL},
/* 1232F */ { "SIGNE CUNÉIFORME OUR2 FOIS HA",NULL},
/* 12330 */ { "SIGNE CUNÉIFORME OUR2 FOIS NOUN",NULL},
/* 12331 */ { "SIGNE CUNÉIFORME OUR2 FOIS OU2",NULL},
/* 12332 */ { "SIGNE CUNÉIFORME OUR2 FOIS OU2 PLUS ACH",NULL},
/* 12333 */ { "SIGNE CUNÉIFORME OUR2 FOIS OU2 PLUS BI",NULL},
/* 12334 */ { "SIGNE CUNÉIFORME OUR4",NULL},
/* 12335 */ { "SIGNE CUNÉIFORME OURI",NULL},
/* 12336 */ { "SIGNE CUNÉIFORME OURI3",NULL},
/* 12337 */ { "SIGNE CUNÉIFORME OUROU",NULL},
/* 12338 */ { "SIGNE CUNÉIFORME OUROU FOIS A",NULL},
/* 12339 */ { "SIGNE CUNÉIFORME OUROU FOIS ACHGAB",NULL},
/* 1233A */ { "SIGNE CUNÉIFORME OUROU FOIS BAR",NULL},
/* 1233B */ { "SIGNE CUNÉIFORME OUROU FOIS DOUN",NULL},
/* 1233C */ { "SIGNE CUNÉIFORME OUROU FOIS GA",NULL},
/* 1233D */ { "SIGNE CUNÉIFORME OUROU FOIS GAL",NULL},
/* 1233E */ { "SIGNE CUNÉIFORME OUROU FOIS GAN2 TENOU",NULL},
/* 1233F */ { "SIGNE CUNÉIFORME OUROU FOIS GAR",NULL},
/* 12340 */ { "SIGNE CUNÉIFORME OUROU FOIS GOU",NULL},
/* 12341 */ { "SIGNE CUNÉIFORME OUROU FOIS HA",NULL},
/* 12342 */ { "SIGNE CUNÉIFORME OUROU FOIS IGI",NULL},
/* 12343 */ { "SIGNE CUNÉIFORME OUROU FOIS IM",NULL},
/* 12344 */ { "SIGNE CUNÉIFORME OUROU FOIS ICH",NULL},
/* 12345 */ { "SIGNE CUNÉIFORME OUROU FOIS KI",NULL},
/* 12346 */ { "SIGNE CUNÉIFORME OUROU FOIS LOUM",NULL},
/* 12347 */ { "SIGNE CUNÉIFORME OUROU FOIS MIN",NULL},
/* 12348 */ { "SIGNE CUNÉIFORME OUROU FOIS PA",NULL},
/* 12349 */ { "SIGNE CUNÉIFORME OUROU FOIS CHE",NULL},
/* 1234A */ { "SIGNE CUNÉIFORME OUROU FOIS SIG4",NULL},
/* 1234B */ { "SIGNE CUNÉIFORME OUROU FOIS TOU",NULL},
/* 1234C */ { "SIGNE CUNÉIFORME OUROU FOIS OU PLUS GOUD",NULL},
/* 1234D */ { "SIGNE CUNÉIFORME OUROU FOIS OUD",NULL},
/* 1234E */ { "SIGNE CUNÉIFORME OUROU FOIS OUROUDA",NULL},
/* 1234F */ { "SIGNE CUNÉIFORME OUROUDA",NULL},
/* 12350 */ { "SIGNE CUNÉIFORME OUROUDA FOIS OU",NULL},
/* 12351 */ { "SIGNE CUNÉIFORME OUCH",NULL},
/* 12352 */ { "SIGNE CUNÉIFORME OUCH FOIS A",NULL},
/* 12353 */ { "SIGNE CUNÉIFORME OUCH FOIS KOU",NULL},
/* 12354 */ { "SIGNE CUNÉIFORME OUCH FOIS KOUR",NULL},
/* 12355 */ { "SIGNE CUNÉIFORME OUCH FOIS TAK4",NULL},
/* 12356 */ { "SIGNE CUNÉIFORME OUCHX",NULL},
/* 12357 */ { "SIGNE CUNÉIFORME OUCH2",NULL},
/* 12358 */ { "SIGNE CUNÉIFORME OUCHOUMX",NULL},
/* 12359 */ { "SIGNE CUNÉIFORME OUTOUKI",NULL},
/* 1235A */ { "SIGNE CUNÉIFORME OUZ3",NULL},
/* 1235B */ { "SIGNE CUNÉIFORME OUZ3 FOIS KASKAL",NULL},
/* 1235C */ { "SIGNE CUNÉIFORME OUZOU",NULL},
/* 1235D */ { "SIGNE CUNÉIFORME ZA","	x (signe numéral cunéiforme quatre dich - 12409)"},
/* 1235E */ { "SIGNE CUNÉIFORME ZA TENOU","	x (signe numéral cunéiforme quatre ach tenou - 1244C)"},
/* 1235F */ { "SIGNE CUNÉIFORME QUATRE ZA EN CROIX FOIS KOUR",NULL},
/* 12360 */ { "SIGNE CUNÉIFORME ZAG",NULL},
/* 12361 */ { "SIGNE CUNÉIFORME ZAMX",NULL},
/* 12362 */ { "SIGNE CUNÉIFORME ZE2",NULL},
/* 12363 */ { "SIGNE CUNÉIFORME ZI",NULL},
/* 12364 */ { "SIGNE CUNÉIFORME ZI SUR ZI",NULL},
/* 12365 */ { "SIGNE CUNÉIFORME ZI3",NULL},
/* 12366 */ { "SIGNE CUNÉIFORME ZIB",NULL},
/* 12367 */ { "SIGNE CUNÉIFORME ZIB KABA TENOU",NULL},
/* 12368 */ { "SIGNE CUNÉIFORME ZIG",NULL},
/* 12369 */ { "SIGNE CUNÉIFORME ZIZ2",NULL},
/* 1236A */ { "SIGNE CUNÉIFORME ZOU",NULL},
/* 1236B */ { "SIGNE CUNÉIFORME ZOU5",NULL},
/* 1236C */ { "SIGNE CUNÉIFORME ZOU5 FOIS A",NULL},
/* 1236D */ { "SIGNE CUNÉIFORME ZOUBOUR",NULL},
/* 1236E */ { "SIGNE CUNÉIFORME ZOUM",NULL},
/* 1236F */ { "SIGNE CUNÉIFORME KAP ÉLAMITE",NULL},
/* 12370 */ { "SIGNE CUNÉIFORME AB FOIS NOUN",NULL},
/* 12371 */ { "SIGNE CUNÉIFORME AB2 FOIS A",NULL},
/* 12372 */ { "SIGNE CUNÉIFORME AMAR FOIS KOUG",NULL},
/* 12373 */ { "SIGNE CUNÉIFORME DAG KISIM5 FOIS U2 PLUS MASH",NULL},
/* 12374 */ { "SIGNE CUNÉIFORME DAG3",NULL},
/* 12375 */ { "SIGNE CUNÉIFORME DICH PLUS CHOU",NULL},
/* 12376 */ { "SIGNE CUNÉIFORME DOUB FOIS CHÉ",NULL},
/* 12377 */ { "SIGNE CUNÉIFORME ÉZEN FOIS GOUD",NULL},
/* 12378 */ { "SIGNE CUNÉIFORME ÉZEN FOIS SHE",NULL},
/* 12379 */ { "SIGNE CUNÉIFORME GA2 FOIS AN PLUS KAK PLUS A",NULL},
/* 1237A */ { "SIGNE CUNÉIFORME GA2 FOIS ACH2",NULL},
/* 1237B */ { "SIGNE CUNÉIFORME GÉ22",NULL},
/* 1237C */ { "SIGNE CUNÉIFORME GIG",NULL},
/* 1237D */ { "SIGNE CUNÉIFORME HOUCH",NULL},
/* 1237E */ { "SIGNE CUNÉIFORME KA FOIS ANCHÉ",NULL},
/* 1237F */ { "SIGNE CUNÉIFORME KA FOIS ACH3",NULL},
/* 12380 */ { "SIGNE CUNÉIFORME KA FOIS GICH",NULL},
/* 12381 */ { "SIGNE CUNÉIFORME KA FOIS GOUD",NULL},
/* 12382 */ { "SIGNE CUNÉIFORME KA FOIS HI FOIS ACH2",NULL},
/* 12383 */ { "SIGNE CUNÉIFORME KA FOIS LOUM",NULL},
/* 12384 */ { "SIGNE CUNÉIFORME KA FOIS PA",NULL},
/* 12385 */ { "SIGNE CUNÉIFORME KA FOIS CHOUL",NULL},
/* 12386 */ { "SIGNE CUNÉIFORME KA FOIS TOU",NULL},
/* 12387 */ { "SIGNE CUNÉIFORME KA FOIS OUR2",NULL},
/* 12388 */ { "SIGNE CUNÉIFORME LAGAB FOIS GUI",NULL},
/* 12389 */ { "SIGNE CUNÉIFORME LOU2 CHÉCHIG FOIS BAD",NULL},
/* 1238A */ { "SIGNE CUNÉIFORME LOU2 FOIS ECH2 PLUS LAL",NULL},
/* 1238B */ { "SIGNE CUNÉIFORME LOU2 FOIS SHU",NULL},
/* 1238C */ { "SIGNE CUNÉIFORME MECH",NULL},
/* 1238D */ { "SIGNE CUNÉIFORME MOUCH3 FOIS ZA",NULL},
/* 1238E */ { "SIGNE CUNÉIFORME NA4",NULL},
/* 1238F */ { "SIGNE CUNÉIFORME NIN",NULL},
/* 12390 */ { "SIGNE CUNÉIFORME NIN9",NULL},
/* 12391 */ { "SIGNE CUNÉIFORME NINDA2 FOIS BAL",NULL},
/* 12392 */ { "SIGNE CUNÉIFORME NINDA2 FOIS GI",NULL},
/* 12393 */ { "SIGNE CUNÉIFORME NOU11 PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= signe cunéiforme nou11 pivoté de nonante degrés"},
/* 12394 */ { "SIGNE CUNÉIFORME PECH2 ASTÉRISQUE",NULL},
/* 12395 */ { "SIGNE CUNÉIFORME PIR2",NULL},
/* 12396 */ { "SIGNE CUNÉIFORME SAG FOIS IGUI GOUNOU",NULL},
/* 12397 */ { "SIGNE CUNÉIFORME TI2",NULL},
/* 12398 */ { "SIGNE CUNÉIFORME OUM FOIS MÉ",NULL},
/* 12399 */ { "SIGNE CUNÉIFORME OU OU","	= 2 u\n"
	"	= 2 bur₃\n"
	"	x (signe numéral cunéiforme quatre ou - 1240F)"},
/* 1239A */ { NULL,NULL},
/* 1239B */ { NULL,NULL},
/* 1239C */ { NULL,NULL},
/* 1239D */ { NULL,NULL},
/* 1239E */ { NULL,NULL},
/* 1239F */ { NULL,NULL},
/* 123A0 */ { NULL,NULL},
/* 123A1 */ { NULL,NULL},
/* 123A2 */ { NULL,NULL},
/* 123A3 */ { NULL,NULL},
/* 123A4 */ { NULL,NULL},
/* 123A5 */ { NULL,NULL},
/* 123A6 */ { NULL,NULL},
/* 123A7 */ { NULL,NULL},
/* 123A8 */ { NULL,NULL},
/* 123A9 */ { NULL,NULL},
/* 123AA */ { NULL,NULL},
/* 123AB */ { NULL,NULL},
/* 123AC */ { NULL,NULL},
/* 123AD */ { NULL,NULL},
/* 123AE */ { NULL,NULL},
/* 123AF */ { NULL,NULL},
/* 123B0 */ { NULL,NULL},
/* 123B1 */ { NULL,NULL},
/* 123B2 */ { NULL,NULL},
/* 123B3 */ { NULL,NULL},
/* 123B4 */ { NULL,NULL},
/* 123B5 */ { NULL,NULL},
/* 123B6 */ { NULL,NULL},
/* 123B7 */ { NULL,NULL},
/* 123B8 */ { NULL,NULL},
/* 123B9 */ { NULL,NULL},
/* 123BA */ { NULL,NULL},
/* 123BB */ { NULL,NULL},
/* 123BC */ { NULL,NULL},
/* 123BD */ { NULL,NULL},
/* 123BE */ { NULL,NULL},
/* 123BF */ { NULL,NULL},
/* 123C0 */ { NULL,NULL},
/* 123C1 */ { NULL,NULL},
/* 123C2 */ { NULL,NULL},
/* 123C3 */ { NULL,NULL},
/* 123C4 */ { NULL,NULL},
/* 123C5 */ { NULL,NULL},
/* 123C6 */ { NULL,NULL},
/* 123C7 */ { NULL,NULL},
/* 123C8 */ { NULL,NULL},
/* 123C9 */ { NULL,NULL},
/* 123CA */ { NULL,NULL},
/* 123CB */ { NULL,NULL},
/* 123CC */ { NULL,NULL},
/* 123CD */ { NULL,NULL},
/* 123CE */ { NULL,NULL},
/* 123CF */ { NULL,NULL},
/* 123D0 */ { NULL,NULL},
/* 123D1 */ { NULL,NULL},
/* 123D2 */ { NULL,NULL},
/* 123D3 */ { NULL,NULL},
/* 123D4 */ { NULL,NULL},
/* 123D5 */ { NULL,NULL},
/* 123D6 */ { NULL,NULL},
/* 123D7 */ { NULL,NULL},
/* 123D8 */ { NULL,NULL},
/* 123D9 */ { NULL,NULL},
/* 123DA */ { NULL,NULL},
/* 123DB */ { NULL,NULL},
/* 123DC */ { NULL,NULL},
/* 123DD */ { NULL,NULL},
/* 123DE */ { NULL,NULL},
/* 123DF */ { NULL,NULL},
/* 123E0 */ { NULL,NULL},
/* 123E1 */ { NULL,NULL},
/* 123E2 */ { NULL,NULL},
/* 123E3 */ { NULL,NULL},
/* 123E4 */ { NULL,NULL},
/* 123E5 */ { NULL,NULL},
/* 123E6 */ { NULL,NULL},
/* 123E7 */ { NULL,NULL},
/* 123E8 */ { NULL,NULL},
/* 123E9 */ { NULL,NULL},
/* 123EA */ { NULL,NULL},
/* 123EB */ { NULL,NULL},
/* 123EC */ { NULL,NULL},
/* 123ED */ { NULL,NULL},
/* 123EE */ { NULL,NULL},
/* 123EF */ { NULL,NULL},
/* 123F0 */ { NULL,NULL},
/* 123F1 */ { NULL,NULL},
/* 123F2 */ { NULL,NULL},
/* 123F3 */ { NULL,NULL},
/* 123F4 */ { NULL,NULL},
/* 123F5 */ { NULL,NULL},
/* 123F6 */ { NULL,NULL},
/* 123F7 */ { NULL,NULL},
/* 123F8 */ { NULL,NULL},
/* 123F9 */ { NULL,NULL},
/* 123FA */ { NULL,NULL},
/* 123FB */ { NULL,NULL},
/* 123FC */ { NULL,NULL},
/* 123FD */ { NULL,NULL},
/* 123FE */ { NULL,NULL},
/* 123FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_24[] = {
/* 12400 */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX ACH","	= 2 iku\n"
	"	x (signe cunéiforme ach - 12038)"},
/* 12401 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS ACH",NULL},
/* 12402 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE ACH",NULL},
/* 12403 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ ACH",NULL},
/* 12404 */ { "SIGNE NUMÉRAL CUNÉIFORME SIX ACH",NULL},
/* 12405 */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT ACH",NULL},
/* 12406 */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT ACH",NULL},
/* 12407 */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF ACH",NULL},
/* 12408 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS DICH","	x (signe cunéiforme dich - 12079)\n"
	"	x (signe cunéiforme min - 1222B)"},
/* 12409 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE DICH","	= 4 bariga"},
/* 1240A */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ DICH",NULL},
/* 1240B */ { "SIGNE NUMÉRAL CUNÉIFORME SIX DICH",NULL},
/* 1240C */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT DICH",NULL},
/* 1240D */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT DICH",NULL},
/* 1240E */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF DICH",NULL},
/* 1240F */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE OU","	= 4 bur₃\n"
	"	x (signe cunéiforme ou - 1230B)\n"
	"	x (signe cunéiforme ou ou - 12399)\n"
	"	x (signe cunéiforme ou ou ou - 1230D)"},
/* 12410 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ OU",NULL},
/* 12411 */ { "SIGNE NUMÉRAL CUNÉIFORME SIX OU",NULL},
/* 12412 */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT OU",NULL},
/* 12413 */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT OU",NULL},
/* 12414 */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF OU",NULL},
/* 12415 */ { "SIGNE NUMÉRAL CUNÉIFORME UN GECH2",NULL},
/* 12416 */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX GECH2",NULL},
/* 12417 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS GECH2",NULL},
/* 12418 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE GECH2",NULL},
/* 12419 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ GECH2",NULL},
/* 1241A */ { "SIGNE NUMÉRAL CUNÉIFORME SIX GECH2",NULL},
/* 1241B */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT GECH2",NULL},
/* 1241C */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT GECH2",NULL},
/* 1241D */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF GECH2",NULL},
/* 1241E */ { "SIGNE NUMÉRAL CUNÉIFORME UN GECHOU",NULL},
/* 1241F */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX GECHOU",NULL},
/* 12420 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS GECHOU",NULL},
/* 12421 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE GECHOU",NULL},
/* 12422 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ GECHOU",NULL},
/* 12423 */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX CHAR2","	x (signe cunéiforme char2 - 122B9)"},
/* 12424 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS CHAR2",NULL},
/* 12425 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS CHAR2 VARIANTE",NULL},
/* 12426 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE CHAR2",NULL},
/* 12427 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ CHAR2",NULL},
/* 12428 */ { "SIGNE NUMÉRAL CUNÉIFORME SIX CHAR2",NULL},
/* 12429 */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT CHAR2",NULL},
/* 1242A */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT CHAR2",NULL},
/* 1242B */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF CHAR2",NULL},
/* 1242C */ { "SIGNE NUMÉRAL CUNÉIFORME UN CHAROU",NULL},
/* 1242D */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX CHAROU",NULL},
/* 1242E */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS CHAROU",NULL},
/* 1242F */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS CHAROU VARIANTE",NULL},
/* 12430 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE CHAROU",NULL},
/* 12431 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ CHAROU",NULL},
/* 12432 */ { "SIGNE NUMÉRAL CUNÉIFORME CHAR2 FOIS GAL PLUS DICH",NULL},
/* 12433 */ { "SIGNE NUMÉRAL CUNÉIFORME CHAR2 FOIS GAL PLUS MIN",NULL},
/* 12434 */ { "SIGNE NUMÉRAL CUNÉIFORME UN BOUROU",NULL},
/* 12435 */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX BOUROU",NULL},
/* 12436 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS BOUROU",NULL},
/* 12437 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS BOUROU VARIANTE",NULL},
/* 12438 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE BOUROU",NULL},
/* 12439 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ BOUROU",NULL},
/* 1243A */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS VARIANTE ECH16",NULL},
/* 1243B */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS VARIANTE ECH21",NULL},
/* 1243C */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE VARIANTE LIMMOU",NULL},
/* 1243D */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE VARIANTE LIMMOU4",NULL},
/* 1243E */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE VARIANTE LIMMOU A",NULL},
/* 1243F */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE VARIANTE LIMMOU B",NULL},
/* 12440 */ { "SIGNE NUMÉRAL CUNÉIFORME SIX VARIANTE ACH9",NULL},
/* 12441 */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT VARIANTE IMIN3",NULL},
/* 12442 */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT VARIANTE IMIN A",NULL},
/* 12443 */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT VARIANTE IMIN B",NULL},
/* 12444 */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT VARIANTE OUSSOU",NULL},
/* 12445 */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT VARIANTE OUSSOU3",NULL},
/* 12446 */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF VARIANTE ILIMMOU",NULL},
/* 12447 */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF VARIANTE ILIMMOU3",NULL},
/* 12448 */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF VARIANTE ILIMMOU4",NULL},
/* 12449 */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF VARIANTE ILIMMOU A",NULL},
/* 1244A */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX ACH TENOU","	= 2 diš tenû\n"
	"	x (signe cunéiforme ach zida tenou - 12039)"},
/* 1244B */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS ACH TENOU",NULL},
/* 1244C */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE ACH TENOU",NULL},
/* 1244D */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ ACH TENOU",NULL},
/* 1244E */ { "SIGNE NUMÉRAL CUNÉIFORME SIX ACH TENOU",NULL},
/* 1244F */ { "SIGNE NUMÉRAL CUNÉIFORME UN BAN2","	* 12226 devrait être utilisé pour 1/2 diš\n"
	"	x (signe cunéiforme mach - 12226)"},
/* 12450 */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX BAN2",NULL},
/* 12451 */ { "SIGNE NUMÉRAL CUNÉIFORME TROIS BAN2",NULL},
/* 12452 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE BAN2",NULL},
/* 12453 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE BAN2 VARIANTE",NULL},
/* 12454 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ BAN2",NULL},
/* 12455 */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ BAN2 VARIANTE",NULL},
/* 12456 */ { "SIGNE NUMÉRAL CUNÉIFORME NIGIDAMIN","	= 2 bariga\n"
	"	x (signe cunéiforme dich - 12079)"},
/* 12457 */ { "SIGNE NUMÉRAL CUNÉIFORME NIGIDAECH","	= 3 bariga"},
/* 12458 */ { "SIGNE NUMÉRAL CUNÉIFORME UN ECHE3",NULL},
/* 12459 */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX ECHE3",NULL},
/* 1245A */ { "SIGNE NUMÉRAL CUNÉIFORME UN TIERS DICH",NULL},
/* 1245B */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX TIERS DICH",NULL},
/* 1245C */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ SIXIÈMES DICH",NULL},
/* 1245D */ { "SIGNE NUMÉRAL CUNÉIFORME UN TIERS VARIANTE A","	= 1/3 aš courbe\n"
	"	= 1/3 diš courbe"},
/* 1245E */ { "SIGNE NUMÉRAL CUNÉIFORME DEUX TIERS VARIANTE A","	= 2/3 aš courbe\n"
	"	= 2/3 diš courbe"},
/* 1245F */ { "SIGNE NUMÉRAL CUNÉIFORME UN HUITIÈME ACH","	= 1/8 iku"},
/* 12460 */ { "SIGNE NUMÉRAL CUNÉIFORME UN QUART ACH","	= 1/4 iku"},
/* 12461 */ { "SIGNE NUMÉRAL CUNÉIFORME VIEIL ASSYRIEN UN SIXIÈME",NULL},
/* 12462 */ { "SIGNE NUMÉRAL CUNÉIFORME VIEIL ASSYRIEN UN QUART",NULL},
/* 12463 */ { "SIGNE NUMÉRAL CUNÉIFORME UN QUART GOUR","	= variante de la forme 1 bariga"},
/* 12464 */ { "SIGNE NUMÉRAL CUNÉIFORME UN DEMI GOUR","	= variante de la forme 2 bariga\n"
	"	* la séquence 12464 12463 est utilisée pour 3/4 gur"},
/* 12465 */ { "SIGNE NUMÉRAL CUNÉIFORME ÉLAMITE UN TIERS",NULL},
/* 12466 */ { "SIGNE NUMÉRAL CUNÉIFORME ÉLAMITE DEUX TIERS",NULL},
/* 12467 */ { "SIGNE NUMÉRAL CUNÉIFORME ÉLAMITE QUARANTE",NULL},
/* 12468 */ { "SIGNE NUMÉRAL CUNÉIFORME ÉLAMITE CINQUANTE",NULL},
/* 12469 */ { "SIGNE NUMÉRAL CUNÉIFORME QUATRE OU VARIANTE",NULL},
/* 1246A */ { "SIGNE NUMÉRAL CUNÉIFORME CINQ OU VARIANTE",NULL},
/* 1246B */ { "SIGNE NUMÉRAL CUNÉIFORME SIX OU VARIANTE",NULL},
/* 1246C */ { "SIGNE NUMÉRAL CUNÉIFORME SEPT OU VARIANTE",NULL},
/* 1246D */ { "SIGNE NUMÉRAL CUNÉIFORME HUIT OU VARIANTE",NULL},
/* 1246E */ { "SIGNE NUMÉRAL CUNÉIFORME NEUF OU VARIANTE",NULL},
/* 1246F */ { NULL,NULL},
/* 12470 */ { "SÉPARATEUR DE MOTS CUNÉIFORME VIEIL ASSYRIEN","	x (séparateur de mots ougaritique - 1039F)\n"
	"	x (séparateur de mots vieux perse - 103D0)"},
/* 12471 */ { "DEUX-COINS VERTICAL CUNÉIFORME",NULL},
/* 12472 */ { "DEUX-COINS DIAGONAL CUNÉIFORME",NULL},
/* 12473 */ { "TROIS-COINS DIAGONAL CUNÉIFORME",NULL},
/* 12474 */ { "QUATRE-COINS DIAGONAL CUNÉIFORME",NULL},
/* 12475 */ { NULL,NULL},
/* 12476 */ { NULL,NULL},
/* 12477 */ { NULL,NULL},
/* 12478 */ { NULL,NULL},
/* 12479 */ { NULL,NULL},
/* 1247A */ { NULL,NULL},
/* 1247B */ { NULL,NULL},
/* 1247C */ { NULL,NULL},
/* 1247D */ { NULL,NULL},
/* 1247E */ { NULL,NULL},
/* 1247F */ { NULL,NULL},
/* 12480 */ { "SIGNE CUNÉIFORME AB FOIS NOUN DIXOU",NULL},
/* 12481 */ { "SIGNE CUNÉIFORME AB FOIS CHOU2",NULL},
/* 12482 */ { "SIGNE CUNÉIFORME AD FOIS ECH2",NULL},
/* 12483 */ { "SIGNE CUNÉIFORME BAD FOIS DICH DIXOU",NULL},
/* 12484 */ { "SIGNE CUNÉIFORME BAHAR2 FOIS AB2",NULL},
/* 12485 */ { "SIGNE CUNÉIFORME BAHAR2 FOIS NI",NULL},
/* 12486 */ { "SIGNE CUNÉIFORME BAHAR2 FOIS ZA",NULL},
/* 12487 */ { "SIGNE CUNÉIFORME BOU SUR BOU FOIS NA2",NULL},
/* 12488 */ { "SIGNE CUNÉIFORME DA FOIS TAK4",NULL},
/* 12489 */ { "SIGNE CUNÉIFORME DAG FOIS KOUR",NULL},
/* 1248A */ { "SIGNE CUNÉIFORME DIM FOIS IGI",NULL},
/* 1248B */ { "SIGNE CUNÉIFORME DIM FOIS OU OU OU",NULL},
/* 1248C */ { "SIGNE CUNÉIFORME DIM2 FOIS OUD",NULL},
/* 1248D */ { "SIGNE CUNÉIFORME DOUG FOIS ANCHE",NULL},
/* 1248E */ { "SIGNE CUNÉIFORME DOUG FOIS ACH",NULL},
/* 1248F */ { "SIGNE CUNÉIFORME DOUG FOIS ACH À GAUCHE",NULL},
/* 12490 */ { "SIGNE CUNÉIFORME DOUG FOIS DIN",NULL},
/* 12491 */ { "SIGNE CUNÉIFORME DOUG FOIS DOUN",NULL},
/* 12492 */ { "SIGNE CUNÉIFORME DOUG FOIS ERIN2",NULL},
/* 12493 */ { "SIGNE CUNÉIFORME DOUG FOIS GA",NULL},
/* 12494 */ { "SIGNE CUNÉIFORME DOUG FOIS GI",NULL},
/* 12495 */ { "SIGNE CUNÉIFORME DOUG FOIS GIR2 GOUNOU",NULL},
/* 12496 */ { "SIGNE CUNÉIFORME DOUG FOIS GICH",NULL},
/* 12497 */ { "SIGNE CUNÉIFORME DOUG FOIS HA",NULL},
/* 12498 */ { "SIGNE CUNÉIFORME DOUG FOIS HI",NULL},
/* 12499 */ { "SIGNE CUNÉIFORME DOUG FOIS IGI GOUNOU",NULL},
/* 1249A */ { "SIGNE CUNÉIFORME DOUG FOIS KASKAL",NULL},
/* 1249B */ { "SIGNE CUNÉIFORME DOUG FOIS KOUR",NULL},
/* 1249C */ { "SIGNE CUNÉIFORME DOUG FOIS KOUCHOU2",NULL},
/* 1249D */ { "SIGNE CUNÉIFORME DOUG FOIS KOUCHOU2 PLUS KASKAL",NULL},
/* 1249E */ { "SIGNE CUNÉIFORME DOUG FOIS LAK-020",NULL},
/* 1249F */ { "SIGNE CUNÉIFORME DOUG FOIS LAM",NULL},
/* 124A0 */ { "SIGNE CUNÉIFORME DOUG FOIS LAM FOIS KOUR",NULL},
/* 124A1 */ { "SIGNE CUNÉIFORME DOUG FOIS LOUH PLUS GICH",NULL},
/* 124A2 */ { "SIGNE CUNÉIFORME DOUG FOIS MACH",NULL},
/* 124A3 */ { "SIGNE CUNÉIFORME DOUG FOIS MES",NULL},
/* 124A4 */ { "SIGNE CUNÉIFORME DOUG FOIS MI",NULL},
/* 124A5 */ { "SIGNE CUNÉIFORME DOUG FOIS NI",NULL},
/* 124A6 */ { "SIGNE CUNÉIFORME DOUG FOIS PI",NULL},
/* 124A7 */ { "SIGNE CUNÉIFORME DOUG FOIS CHE",NULL},
/* 124A8 */ { "SIGNE CUNÉIFORME DOUG FOIS SI GOUNOU",NULL},
/* 124A9 */ { "SIGNE CUNÉIFORME E2 FOIS KOUR",NULL},
/* 124AA */ { "SIGNE CUNÉIFORME E2 FOIS PAP",NULL},
/* 124AB */ { "SIGNE CUNÉIFORME ERIN2 X",NULL},
/* 124AC */ { "SIGNE CUNÉIFORME DEUX ECH2 CROISÉS",NULL},
/* 124AD */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS ACH",NULL},
/* 124AE */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS HI",NULL},
/* 124AF */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS IGI GOUNOU",NULL},
/* 124B0 */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS LA",NULL},
/* 124B1 */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS LAL",NULL},
/* 124B2 */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS ME",NULL},
/* 124B3 */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS MES",NULL},
/* 124B4 */ { "SIGNE CUNÉIFORME EZEN CHECHIG FOIS SOU",NULL},
/* 124B5 */ { "SIGNE CUNÉIFORME EZEN FOIS SOU",NULL},
/* 124B6 */ { "SIGNE CUNÉIFORME GA2 FOIS BAHAR2",NULL},
/* 124B7 */ { "SIGNE CUNÉIFORME GA2 FOIS DIM GOUNOU",NULL},
/* 124B8 */ { "SIGNE CUNÉIFORME GA2 FOIS DOUG FOIS IGI GOUNOU",NULL},
/* 124B9 */ { "SIGNE CUNÉIFORME GA2 FOIS DOUG FOIS KASKAL",NULL},
/* 124BA */ { "SIGNE CUNÉIFORME GA2 FOIS EREN",NULL},
/* 124BB */ { "SIGNE CUNÉIFORME GA2 FOIS GA",NULL},
/* 124BC */ { "SIGNE CUNÉIFORME GA2 FOIS GAR PLUS DI",NULL},
/* 124BD */ { "SIGNE CUNÉIFORME GA2 FOIS GAR PLUS NE",NULL},
/* 124BE */ { "SIGNE CUNÉIFORME GA2 FOIS HA PLUS A",NULL},
/* 124BF */ { "SIGNE CUNÉIFORME GA2 FOIS KOUCHOU2 PLUS KASKAL",NULL},
/* 124C0 */ { "SIGNE CUNÉIFORME GA2 FOIS LAM",NULL},
/* 124C1 */ { "SIGNE CUNÉIFORME GA2 FOIS LAM FOIS KOUR",NULL},
/* 124C2 */ { "SIGNE CUNÉIFORME GA2 FOIS LOUH",NULL},
/* 124C3 */ { "SIGNE CUNÉIFORME GA2 FOIS MOUCH",NULL},
/* 124C4 */ { "SIGNE CUNÉIFORME GA2 FOIS NE",NULL},
/* 124C5 */ { "SIGNE CUNÉIFORME GA2 FOIS NE PLUS E2",NULL},
/* 124C6 */ { "SIGNE CUNÉIFORME GA2 FOIS NE PLUS GI",NULL},
/* 124C7 */ { "SIGNE CUNÉIFORME GA2 FOIS CHIM",NULL},
/* 124C8 */ { "SIGNE CUNÉIFORME GA2 FOIS ZIZ2",NULL},
/* 124C9 */ { "SIGNE CUNÉIFORME GABA PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= signe cunéiforme gaba pivoté de nonante degrés"},
/* 124CA */ { "SIGNE CUNÉIFORME GECHTIN FOIS OU",NULL},
/* 124CB */ { "SIGNE CUNÉIFORME GICH FOIS DEUX GICH CROISÉS",NULL},
/* 124CC */ { "SIGNE CUNÉIFORME GOU2 FOIS IGI GOUNOU",NULL},
/* 124CD */ { "SIGNE CUNÉIFORME GOUD PLUS GICH FOIS TAK4",NULL},
/* 124CE */ { "SIGNE CUNÉIFORME HA DIXOU GOUNOU",NULL},
/* 124CF */ { "SIGNE CUNÉIFORME HI FOIS ACH SUR HI FOIS ACH",NULL},
/* 124D0 */ { "SIGNE CUNÉIFORME KA FOIS BOU",NULL},
/* 124D1 */ { "SIGNE CUNÉIFORME KA FOIS KA",NULL},
/* 124D2 */ { "SIGNE CUNÉIFORME KA FOIS OU OU OU",NULL},
/* 124D3 */ { "SIGNE CUNÉIFORME KA FOIS OUR",NULL},
/* 124D4 */ { "SIGNE CUNÉIFORME LAGAB FOIS ZOU SUR ZOU",NULL},
/* 124D5 */ { "SIGNE CUNÉIFORME LAK-003",NULL},
/* 124D6 */ { "SIGNE CUNÉIFORME LAK-021",NULL},
/* 124D7 */ { "SIGNE CUNÉIFORME LAK-025",NULL},
/* 124D8 */ { "SIGNE CUNÉIFORME LAK-030",NULL},
/* 124D9 */ { "SIGNE CUNÉIFORME LAK-050",NULL},
/* 124DA */ { "SIGNE CUNÉIFORME LAK-051",NULL},
/* 124DB */ { "SIGNE CUNÉIFORME LAK-062",NULL},
/* 124DC */ { "SIGNE CUNÉIFORME LAK-079 SUR LAK-079 GOUNOU",NULL},
/* 124DD */ { "SIGNE CUNÉIFORME LAK-080",NULL},
/* 124DE */ { "SIGNE CUNÉIFORME LAK-081 SUR LAK-081",NULL},
/* 124DF */ { "SIGNE CUNÉIFORME LAK-092",NULL},
/* 124E0 */ { "SIGNE CUNÉIFORME LAK-130",NULL},
/* 124E1 */ { "SIGNE CUNÉIFORME LAK-142",NULL},
/* 124E2 */ { "SIGNE CUNÉIFORME LAK-210",NULL},
/* 124E3 */ { "SIGNE CUNÉIFORME LAK-219",NULL},
/* 124E4 */ { "SIGNE CUNÉIFORME LAK-220",NULL},
/* 124E5 */ { "SIGNE CUNÉIFORME LAK-225",NULL},
/* 124E6 */ { "SIGNE CUNÉIFORME LAK-228",NULL},
/* 124E7 */ { "SIGNE CUNÉIFORME LAK-238",NULL},
/* 124E8 */ { "SIGNE CUNÉIFORME LAK-265",NULL},
/* 124E9 */ { "SIGNE CUNÉIFORME LAK-266",NULL},
/* 124EA */ { "SIGNE CUNÉIFORME LAK-343",NULL},
/* 124EB */ { "SIGNE CUNÉIFORME LAK-347",NULL},
/* 124EC */ { "SIGNE CUNÉIFORME LAK-348",NULL},
/* 124ED */ { "SIGNE CUNÉIFORME LAK-383",NULL},
/* 124EE */ { "SIGNE CUNÉIFORME LAK-384",NULL},
/* 124EF */ { "SIGNE CUNÉIFORME LAK-390",NULL},
/* 124F0 */ { "SIGNE CUNÉIFORME LAK-441",NULL},
/* 124F1 */ { "SIGNE CUNÉIFORME LAK-449",NULL},
/* 124F2 */ { "SIGNE CUNÉIFORME LAK-449 FOIS GOU",NULL},
/* 124F3 */ { "SIGNE CUNÉIFORME LAK-449 FOIS IGI",NULL},
/* 124F4 */ { "SIGNE CUNÉIFORME LAK-449 FOIS PAP PLUS LOU3",NULL},
/* 124F5 */ { "SIGNE CUNÉIFORME LAK-449 FOIS PAP PLUS PAP PLUS LOU3",NULL},
/* 124F6 */ { "SIGNE CUNÉIFORME LAK-449 FOIS OU2 PLUS BA",NULL},
/* 124F7 */ { "SIGNE CUNÉIFORME LAK-450",NULL},
/* 124F8 */ { "SIGNE CUNÉIFORME LAK-457",NULL},
/* 124F9 */ { "SIGNE CUNÉIFORME LAK-470",NULL},
/* 124FA */ { "SIGNE CUNÉIFORME LAK-483",NULL},
/* 124FB */ { "SIGNE CUNÉIFORME LAK-490",NULL},
/* 124FC */ { "SIGNE CUNÉIFORME LAK-492",NULL},
/* 124FD */ { "SIGNE CUNÉIFORME LAK-493",NULL},
/* 124FE */ { "SIGNE CUNÉIFORME LAK-495",NULL},
/* 124FF */ { "SIGNE CUNÉIFORME LAK-550",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_25[] = {
/* 12500 */ { "SIGNE CUNÉIFORME LAK-608",NULL},
/* 12501 */ { "SIGNE CUNÉIFORME LAK-617",NULL},
/* 12502 */ { "SIGNE CUNÉIFORME LAK-617 FOIS ACH",NULL},
/* 12503 */ { "SIGNE CUNÉIFORME LAK-617 FOIS BAD",NULL},
/* 12504 */ { "SIGNE CUNÉIFORME LAK-617 FOIS DOUN3 GOUNOU GOUNOU",NULL},
/* 12505 */ { "SIGNE CUNÉIFORME LAK-617 FOIS KOU3",NULL},
/* 12506 */ { "SIGNE CUNÉIFORME LAK-617 FOIS LA",NULL},
/* 12507 */ { "SIGNE CUNÉIFORME LAK-617 FOIS TAR",NULL},
/* 12508 */ { "SIGNE CUNÉIFORME LAK-617 FOIS TE",NULL},
/* 12509 */ { "SIGNE CUNÉIFORME LAK-617 FOIS OU2",NULL},
/* 1250A */ { "SIGNE CUNÉIFORME LAK-617 FOIS OUD",NULL},
/* 1250B */ { "SIGNE CUNÉIFORME LAK-617 FOIS OUROUDA",NULL},
/* 1250C */ { "SIGNE CUNÉIFORME LAK-636",NULL},
/* 1250D */ { "SIGNE CUNÉIFORME LAK-648",NULL},
/* 1250E */ { "SIGNE CUNÉIFORME LAK-648 FOIS DOUB",NULL},
/* 1250F */ { "SIGNE CUNÉIFORME LAK-648 FOIS GA",NULL},
/* 12510 */ { "SIGNE CUNÉIFORME LAK-648 FOIS IGI",NULL},
/* 12511 */ { "SIGNE CUNÉIFORME LAK-648 FOIS IGI GOUNOU",NULL},
/* 12512 */ { "SIGNE CUNÉIFORME LAK-648 FOIS NI",NULL},
/* 12513 */ { "SIGNE CUNÉIFORME LAK-648 FOIS PAP PLUS PAP PLUS LOU3",NULL},
/* 12514 */ { "SIGNE CUNÉIFORME LAK-648 FOIS CHECH PLUS KI",NULL},
/* 12515 */ { "SIGNE CUNÉIFORME LAK-648 FOIS OUD",NULL},
/* 12516 */ { "SIGNE CUNÉIFORME LAK-648 FOIS OUROUDA",NULL},
/* 12517 */ { "SIGNE CUNÉIFORME LAK-724",NULL},
/* 12518 */ { "SIGNE CUNÉIFORME LAK-749",NULL},
/* 12519 */ { "SIGNE CUNÉIFORME LOU2 GOUNOU FOIS ACH",NULL},
/* 1251A */ { "SIGNE CUNÉIFORME LOU2 FOIS DICH",NULL},
/* 1251B */ { "SIGNE CUNÉIFORME LOU2 FOIS HAL",NULL},
/* 1251C */ { "SIGNE CUNÉIFORME LOU2 FOIS PAP",NULL},
/* 1251D */ { "SIGNE CUNÉIFORME LOU2 FOIS PAP PLUS PAP PLUS LOU3",NULL},
/* 1251E */ { "SIGNE CUNÉIFORME LOU2 FOIS TAK4",NULL},
/* 1251F */ { "SIGNE CUNÉIFORME MI PLUS ZA7",NULL},
/* 12520 */ { "SIGNE CUNÉIFORME MOUCH SUR MOUCH FOIS GA",NULL},
/* 12521 */ { "SIGNE CUNÉIFORME MOUCH SUR MOUCH FOIS KAK",NULL},
/* 12522 */ { "SIGNE CUNÉIFORME NINDA2 FOIS DIM GOUNOU",NULL},
/* 12523 */ { "SIGNE CUNÉIFORME NINDA2 FOIS GICH",NULL},
/* 12524 */ { "SIGNE CUNÉIFORME NINDA2 FOIS GOUL",NULL},
/* 12525 */ { "SIGNE CUNÉIFORME NINDA2 FOIS HI",NULL},
/* 12526 */ { "SIGNE CUNÉIFORME NINDA2 FOIS KECH2",NULL},
/* 12527 */ { "SIGNE CUNÉIFORME NINDA2 FOIS LAK-050",NULL},
/* 12528 */ { "SIGNE CUNÉIFORME NINDA2 FOIS MACH",NULL},
/* 12529 */ { "SIGNE CUNÉIFORME NINDA2 FOIS PAP PLUS PAP",NULL},
/* 1252A */ { "SIGNE CUNÉIFORME NINDA2 FOIS OU",NULL},
/* 1252B */ { "SIGNE CUNÉIFORME NINDA2 FOIS OU PLUS OU",NULL},
/* 1252C */ { "SIGNE CUNÉIFORME NINDA2 FOIS OUROUDA",NULL},
/* 1252D */ { "SIGNE CUNÉIFORME SAG GOUNOU FOIS HA",NULL},
/* 1252E */ { "SIGNE CUNÉIFORME SAG FOIS EN",NULL},
/* 1252F */ { "SIGNE CUNÉIFORME SAG FOIS CHE À GAUCHE",NULL},
/* 12530 */ { "SIGNE CUNÉIFORME SAG FOIS TAK4",NULL},
/* 12531 */ { "SIGNE CUNÉIFORME CHA6 DIXOU",NULL},
/* 12532 */ { "SIGNE CUNÉIFORME CHE SUR CHE",NULL},
/* 12533 */ { "SIGNE CUNÉIFORME CHE PLUS HOUB2",NULL},
/* 12534 */ { "SIGNE CUNÉIFORME CHE PLUS NAM2",NULL},
/* 12535 */ { "SIGNE CUNÉIFORME CHE PLUS SAR",NULL},
/* 12536 */ { "SIGNE CUNÉIFORME CHUO2 PLUS DOUG FOIS NI",NULL},
/* 12537 */ { "SIGNE CUNÉIFORME CHOU2 PLUS E2 FOIS AN",NULL},
/* 12538 */ { "SIGNE CUNÉIFORME SI FOIS TAK4",NULL},
/* 12539 */ { "SIGNE CUNÉIFORME TAK4 PLUS SAG",NULL},
/* 1253A */ { "SIGNE CUNÉIFORME TOUM FOIS GAN2 DIXOU",NULL},
/* 1253B */ { "SIGNE CUNÉIFORME TOUM FOIS TROIS DICH",NULL},
/* 1253C */ { "SIGNE CUNÉIFORME OUR2 RENVERSÉ",NULL},
/* 1253D */ { "SIGNE CUNÉIFORME OUR2 FOIS OUD",NULL},
/* 1253E */ { "SIGNE CUNÉIFORME OUROU FOIS DARA3",NULL},
/* 1253F */ { "SIGNE CUNÉIFORME OUROU FOIS LAK-668",NULL},
/* 12540 */ { "SIGNE CUNÉIFORME OUROU FOIS LOU3",NULL},
/* 12541 */ { "SIGNE CUNÉIFORME ZA7",NULL},
/* 12542 */ { "SIGNE CUNÉIFORME ZOU SUR ZOU PLUS SAR",NULL},
/* 12543 */ { "SIGNE CUNÉIFORME ZOU5 FOIS TROIS DICH DIXOU",NULL},
/* 12544 */ { NULL,NULL},
/* 12545 */ { NULL,NULL},
/* 12546 */ { NULL,NULL},
/* 12547 */ { NULL,NULL},
/* 12548 */ { NULL,NULL},
/* 12549 */ { NULL,NULL},
/* 1254A */ { NULL,NULL},
/* 1254B */ { NULL,NULL},
/* 1254C */ { NULL,NULL},
/* 1254D */ { NULL,NULL},
/* 1254E */ { NULL,NULL},
/* 1254F */ { NULL,NULL},
/* 12550 */ { NULL,NULL},
/* 12551 */ { NULL,NULL},
/* 12552 */ { NULL,NULL},
/* 12553 */ { NULL,NULL},
/* 12554 */ { NULL,NULL},
/* 12555 */ { NULL,NULL},
/* 12556 */ { NULL,NULL},
/* 12557 */ { NULL,NULL},
/* 12558 */ { NULL,NULL},
/* 12559 */ { NULL,NULL},
/* 1255A */ { NULL,NULL},
/* 1255B */ { NULL,NULL},
/* 1255C */ { NULL,NULL},
/* 1255D */ { NULL,NULL},
/* 1255E */ { NULL,NULL},
/* 1255F */ { NULL,NULL},
/* 12560 */ { NULL,NULL},
/* 12561 */ { NULL,NULL},
/* 12562 */ { NULL,NULL},
/* 12563 */ { NULL,NULL},
/* 12564 */ { NULL,NULL},
/* 12565 */ { NULL,NULL},
/* 12566 */ { NULL,NULL},
/* 12567 */ { NULL,NULL},
/* 12568 */ { NULL,NULL},
/* 12569 */ { NULL,NULL},
/* 1256A */ { NULL,NULL},
/* 1256B */ { NULL,NULL},
/* 1256C */ { NULL,NULL},
/* 1256D */ { NULL,NULL},
/* 1256E */ { NULL,NULL},
/* 1256F */ { NULL,NULL},
/* 12570 */ { NULL,NULL},
/* 12571 */ { NULL,NULL},
/* 12572 */ { NULL,NULL},
/* 12573 */ { NULL,NULL},
/* 12574 */ { NULL,NULL},
/* 12575 */ { NULL,NULL},
/* 12576 */ { NULL,NULL},
/* 12577 */ { NULL,NULL},
/* 12578 */ { NULL,NULL},
/* 12579 */ { NULL,NULL},
/* 1257A */ { NULL,NULL},
/* 1257B */ { NULL,NULL},
/* 1257C */ { NULL,NULL},
/* 1257D */ { NULL,NULL},
/* 1257E */ { NULL,NULL},
/* 1257F */ { NULL,NULL},
/* 12580 */ { NULL,NULL},
/* 12581 */ { NULL,NULL},
/* 12582 */ { NULL,NULL},
/* 12583 */ { NULL,NULL},
/* 12584 */ { NULL,NULL},
/* 12585 */ { NULL,NULL},
/* 12586 */ { NULL,NULL},
/* 12587 */ { NULL,NULL},
/* 12588 */ { NULL,NULL},
/* 12589 */ { NULL,NULL},
/* 1258A */ { NULL,NULL},
/* 1258B */ { NULL,NULL},
/* 1258C */ { NULL,NULL},
/* 1258D */ { NULL,NULL},
/* 1258E */ { NULL,NULL},
/* 1258F */ { NULL,NULL},
/* 12590 */ { NULL,NULL},
/* 12591 */ { NULL,NULL},
/* 12592 */ { NULL,NULL},
/* 12593 */ { NULL,NULL},
/* 12594 */ { NULL,NULL},
/* 12595 */ { NULL,NULL},
/* 12596 */ { NULL,NULL},
/* 12597 */ { NULL,NULL},
/* 12598 */ { NULL,NULL},
/* 12599 */ { NULL,NULL},
/* 1259A */ { NULL,NULL},
/* 1259B */ { NULL,NULL},
/* 1259C */ { NULL,NULL},
/* 1259D */ { NULL,NULL},
/* 1259E */ { NULL,NULL},
/* 1259F */ { NULL,NULL},
/* 125A0 */ { NULL,NULL},
/* 125A1 */ { NULL,NULL},
/* 125A2 */ { NULL,NULL},
/* 125A3 */ { NULL,NULL},
/* 125A4 */ { NULL,NULL},
/* 125A5 */ { NULL,NULL},
/* 125A6 */ { NULL,NULL},
/* 125A7 */ { NULL,NULL},
/* 125A8 */ { NULL,NULL},
/* 125A9 */ { NULL,NULL},
/* 125AA */ { NULL,NULL},
/* 125AB */ { NULL,NULL},
/* 125AC */ { NULL,NULL},
/* 125AD */ { NULL,NULL},
/* 125AE */ { NULL,NULL},
/* 125AF */ { NULL,NULL},
/* 125B0 */ { NULL,NULL},
/* 125B1 */ { NULL,NULL},
/* 125B2 */ { NULL,NULL},
/* 125B3 */ { NULL,NULL},
/* 125B4 */ { NULL,NULL},
/* 125B5 */ { NULL,NULL},
/* 125B6 */ { NULL,NULL},
/* 125B7 */ { NULL,NULL},
/* 125B8 */ { NULL,NULL},
/* 125B9 */ { NULL,NULL},
/* 125BA */ { NULL,NULL},
/* 125BB */ { NULL,NULL},
/* 125BC */ { NULL,NULL},
/* 125BD */ { NULL,NULL},
/* 125BE */ { NULL,NULL},
/* 125BF */ { NULL,NULL},
/* 125C0 */ { NULL,NULL},
/* 125C1 */ { NULL,NULL},
/* 125C2 */ { NULL,NULL},
/* 125C3 */ { NULL,NULL},
/* 125C4 */ { NULL,NULL},
/* 125C5 */ { NULL,NULL},
/* 125C6 */ { NULL,NULL},
/* 125C7 */ { NULL,NULL},
/* 125C8 */ { NULL,NULL},
/* 125C9 */ { NULL,NULL},
/* 125CA */ { NULL,NULL},
/* 125CB */ { NULL,NULL},
/* 125CC */ { NULL,NULL},
/* 125CD */ { NULL,NULL},
/* 125CE */ { NULL,NULL},
/* 125CF */ { NULL,NULL},
/* 125D0 */ { NULL,NULL},
/* 125D1 */ { NULL,NULL},
/* 125D2 */ { NULL,NULL},
/* 125D3 */ { NULL,NULL},
/* 125D4 */ { NULL,NULL},
/* 125D5 */ { NULL,NULL},
/* 125D6 */ { NULL,NULL},
/* 125D7 */ { NULL,NULL},
/* 125D8 */ { NULL,NULL},
/* 125D9 */ { NULL,NULL},
/* 125DA */ { NULL,NULL},
/* 125DB */ { NULL,NULL},
/* 125DC */ { NULL,NULL},
/* 125DD */ { NULL,NULL},
/* 125DE */ { NULL,NULL},
/* 125DF */ { NULL,NULL},
/* 125E0 */ { NULL,NULL},
/* 125E1 */ { NULL,NULL},
/* 125E2 */ { NULL,NULL},
/* 125E3 */ { NULL,NULL},
/* 125E4 */ { NULL,NULL},
/* 125E5 */ { NULL,NULL},
/* 125E6 */ { NULL,NULL},
/* 125E7 */ { NULL,NULL},
/* 125E8 */ { NULL,NULL},
/* 125E9 */ { NULL,NULL},
/* 125EA */ { NULL,NULL},
/* 125EB */ { NULL,NULL},
/* 125EC */ { NULL,NULL},
/* 125ED */ { NULL,NULL},
/* 125EE */ { NULL,NULL},
/* 125EF */ { NULL,NULL},
/* 125F0 */ { NULL,NULL},
/* 125F1 */ { NULL,NULL},
/* 125F2 */ { NULL,NULL},
/* 125F3 */ { NULL,NULL},
/* 125F4 */ { NULL,NULL},
/* 125F5 */ { NULL,NULL},
/* 125F6 */ { NULL,NULL},
/* 125F7 */ { NULL,NULL},
/* 125F8 */ { NULL,NULL},
/* 125F9 */ { NULL,NULL},
/* 125FA */ { NULL,NULL},
/* 125FB */ { NULL,NULL},
/* 125FC */ { NULL,NULL},
/* 125FD */ { NULL,NULL},
/* 125FE */ { NULL,NULL},
/* 125FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_2F[] = {
/* 12F00 */ { NULL,NULL},
/* 12F01 */ { NULL,NULL},
/* 12F02 */ { NULL,NULL},
/* 12F03 */ { NULL,NULL},
/* 12F04 */ { NULL,NULL},
/* 12F05 */ { NULL,NULL},
/* 12F06 */ { NULL,NULL},
/* 12F07 */ { NULL,NULL},
/* 12F08 */ { NULL,NULL},
/* 12F09 */ { NULL,NULL},
/* 12F0A */ { NULL,NULL},
/* 12F0B */ { NULL,NULL},
/* 12F0C */ { NULL,NULL},
/* 12F0D */ { NULL,NULL},
/* 12F0E */ { NULL,NULL},
/* 12F0F */ { NULL,NULL},
/* 12F10 */ { NULL,NULL},
/* 12F11 */ { NULL,NULL},
/* 12F12 */ { NULL,NULL},
/* 12F13 */ { NULL,NULL},
/* 12F14 */ { NULL,NULL},
/* 12F15 */ { NULL,NULL},
/* 12F16 */ { NULL,NULL},
/* 12F17 */ { NULL,NULL},
/* 12F18 */ { NULL,NULL},
/* 12F19 */ { NULL,NULL},
/* 12F1A */ { NULL,NULL},
/* 12F1B */ { NULL,NULL},
/* 12F1C */ { NULL,NULL},
/* 12F1D */ { NULL,NULL},
/* 12F1E */ { NULL,NULL},
/* 12F1F */ { NULL,NULL},
/* 12F20 */ { NULL,NULL},
/* 12F21 */ { NULL,NULL},
/* 12F22 */ { NULL,NULL},
/* 12F23 */ { NULL,NULL},
/* 12F24 */ { NULL,NULL},
/* 12F25 */ { NULL,NULL},
/* 12F26 */ { NULL,NULL},
/* 12F27 */ { NULL,NULL},
/* 12F28 */ { NULL,NULL},
/* 12F29 */ { NULL,NULL},
/* 12F2A */ { NULL,NULL},
/* 12F2B */ { NULL,NULL},
/* 12F2C */ { NULL,NULL},
/* 12F2D */ { NULL,NULL},
/* 12F2E */ { NULL,NULL},
/* 12F2F */ { NULL,NULL},
/* 12F30 */ { NULL,NULL},
/* 12F31 */ { NULL,NULL},
/* 12F32 */ { NULL,NULL},
/* 12F33 */ { NULL,NULL},
/* 12F34 */ { NULL,NULL},
/* 12F35 */ { NULL,NULL},
/* 12F36 */ { NULL,NULL},
/* 12F37 */ { NULL,NULL},
/* 12F38 */ { NULL,NULL},
/* 12F39 */ { NULL,NULL},
/* 12F3A */ { NULL,NULL},
/* 12F3B */ { NULL,NULL},
/* 12F3C */ { NULL,NULL},
/* 12F3D */ { NULL,NULL},
/* 12F3E */ { NULL,NULL},
/* 12F3F */ { NULL,NULL},
/* 12F40 */ { NULL,NULL},
/* 12F41 */ { NULL,NULL},
/* 12F42 */ { NULL,NULL},
/* 12F43 */ { NULL,NULL},
/* 12F44 */ { NULL,NULL},
/* 12F45 */ { NULL,NULL},
/* 12F46 */ { NULL,NULL},
/* 12F47 */ { NULL,NULL},
/* 12F48 */ { NULL,NULL},
/* 12F49 */ { NULL,NULL},
/* 12F4A */ { NULL,NULL},
/* 12F4B */ { NULL,NULL},
/* 12F4C */ { NULL,NULL},
/* 12F4D */ { NULL,NULL},
/* 12F4E */ { NULL,NULL},
/* 12F4F */ { NULL,NULL},
/* 12F50 */ { NULL,NULL},
/* 12F51 */ { NULL,NULL},
/* 12F52 */ { NULL,NULL},
/* 12F53 */ { NULL,NULL},
/* 12F54 */ { NULL,NULL},
/* 12F55 */ { NULL,NULL},
/* 12F56 */ { NULL,NULL},
/* 12F57 */ { NULL,NULL},
/* 12F58 */ { NULL,NULL},
/* 12F59 */ { NULL,NULL},
/* 12F5A */ { NULL,NULL},
/* 12F5B */ { NULL,NULL},
/* 12F5C */ { NULL,NULL},
/* 12F5D */ { NULL,NULL},
/* 12F5E */ { NULL,NULL},
/* 12F5F */ { NULL,NULL},
/* 12F60 */ { NULL,NULL},
/* 12F61 */ { NULL,NULL},
/* 12F62 */ { NULL,NULL},
/* 12F63 */ { NULL,NULL},
/* 12F64 */ { NULL,NULL},
/* 12F65 */ { NULL,NULL},
/* 12F66 */ { NULL,NULL},
/* 12F67 */ { NULL,NULL},
/* 12F68 */ { NULL,NULL},
/* 12F69 */ { NULL,NULL},
/* 12F6A */ { NULL,NULL},
/* 12F6B */ { NULL,NULL},
/* 12F6C */ { NULL,NULL},
/* 12F6D */ { NULL,NULL},
/* 12F6E */ { NULL,NULL},
/* 12F6F */ { NULL,NULL},
/* 12F70 */ { NULL,NULL},
/* 12F71 */ { NULL,NULL},
/* 12F72 */ { NULL,NULL},
/* 12F73 */ { NULL,NULL},
/* 12F74 */ { NULL,NULL},
/* 12F75 */ { NULL,NULL},
/* 12F76 */ { NULL,NULL},
/* 12F77 */ { NULL,NULL},
/* 12F78 */ { NULL,NULL},
/* 12F79 */ { NULL,NULL},
/* 12F7A */ { NULL,NULL},
/* 12F7B */ { NULL,NULL},
/* 12F7C */ { NULL,NULL},
/* 12F7D */ { NULL,NULL},
/* 12F7E */ { NULL,NULL},
/* 12F7F */ { NULL,NULL},
/* 12F80 */ { NULL,NULL},
/* 12F81 */ { NULL,NULL},
/* 12F82 */ { NULL,NULL},
/* 12F83 */ { NULL,NULL},
/* 12F84 */ { NULL,NULL},
/* 12F85 */ { NULL,NULL},
/* 12F86 */ { NULL,NULL},
/* 12F87 */ { NULL,NULL},
/* 12F88 */ { NULL,NULL},
/* 12F89 */ { NULL,NULL},
/* 12F8A */ { NULL,NULL},
/* 12F8B */ { NULL,NULL},
/* 12F8C */ { NULL,NULL},
/* 12F8D */ { NULL,NULL},
/* 12F8E */ { NULL,NULL},
/* 12F8F */ { NULL,NULL},
/* 12F90 */ { "SIGNE CHYPRO-MINOEN CM001",NULL},
/* 12F91 */ { "SIGNE CHYPRO-MINOEN CM002",NULL},
/* 12F92 */ { "SIGNE CHYPRO-MINOEN CM004",NULL},
/* 12F93 */ { "SIGNE CHYPRO-MINOEN CM005",NULL},
/* 12F94 */ { "SIGNE CHYPRO-MINOEN CM006",NULL},
/* 12F95 */ { "SIGNE CHYPRO-MINOEN CM007",NULL},
/* 12F96 */ { "SIGNE CHYPRO-MINOEN CM008",NULL},
/* 12F97 */ { "SIGNE CHYPRO-MINOEN CM009",NULL},
/* 12F98 */ { "SIGNE CHYPRO-MINOEN CM010",NULL},
/* 12F99 */ { "SIGNE CHYPRO-MINOEN CM011",NULL},
/* 12F9A */ { "SIGNE CHYPRO-MINOEN CM012",NULL},
/* 12F9B */ { "SIGNE CHYPRO-MINOEN CM012B",NULL},
/* 12F9C */ { "SIGNE CHYPRO-MINOEN CM013",NULL},
/* 12F9D */ { "SIGNE CHYPRO-MINOEN CM015",NULL},
/* 12F9E */ { "SIGNE CHYPRO-MINOEN CM017",NULL},
/* 12F9F */ { "SIGNE CHYPRO-MINOEN CM019",NULL},
/* 12FA0 */ { "SIGNE CHYPRO-MINOEN CM021",NULL},
/* 12FA1 */ { "SIGNE CHYPRO-MINOEN CM023",NULL},
/* 12FA2 */ { "SIGNE CHYPRO-MINOEN CM024",NULL},
/* 12FA3 */ { "SIGNE CHYPRO-MINOEN CM025",NULL},
/* 12FA4 */ { "SIGNE CHYPRO-MINOEN CM026",NULL},
/* 12FA5 */ { "SIGNE CHYPRO-MINOEN CM027",NULL},
/* 12FA6 */ { "SIGNE CHYPRO-MINOEN CM028",NULL},
/* 12FA7 */ { "SIGNE CHYPRO-MINOEN CM029",NULL},
/* 12FA8 */ { "SIGNE CHYPRO-MINOEN CM030",NULL},
/* 12FA9 */ { "SIGNE CHYPRO-MINOEN CM033",NULL},
/* 12FAA */ { "SIGNE CHYPRO-MINOEN CM034",NULL},
/* 12FAB */ { "SIGNE CHYPRO-MINOEN CM035",NULL},
/* 12FAC */ { "SIGNE CHYPRO-MINOEN CM036",NULL},
/* 12FAD */ { "SIGNE CHYPRO-MINOEN CM037",NULL},
/* 12FAE */ { "SIGNE CHYPRO-MINOEN CM038",NULL},
/* 12FAF */ { "SIGNE CHYPRO-MINOEN CM039",NULL},
/* 12FB0 */ { "SIGNE CHYPRO-MINOEN CM040",NULL},
/* 12FB1 */ { "SIGNE CHYPRO-MINOEN CM041",NULL},
/* 12FB2 */ { "SIGNE CHYPRO-MINOEN CM044",NULL},
/* 12FB3 */ { "SIGNE CHYPRO-MINOEN CM046",NULL},
/* 12FB4 */ { "SIGNE CHYPRO-MINOEN CM047",NULL},
/* 12FB5 */ { "SIGNE CHYPRO-MINOEN CM049",NULL},
/* 12FB6 */ { "SIGNE CHYPRO-MINOEN CM050",NULL},
/* 12FB7 */ { "SIGNE CHYPRO-MINOEN CM051",NULL},
/* 12FB8 */ { "SIGNE CHYPRO-MINOEN CM052",NULL},
/* 12FB9 */ { "SIGNE CHYPRO-MINOEN CM053",NULL},
/* 12FBA */ { "SIGNE CHYPRO-MINOEN CM054",NULL},
/* 12FBB */ { "SIGNE CHYPRO-MINOEN CM055",NULL},
/* 12FBC */ { "SIGNE CHYPRO-MINOEN CM056",NULL},
/* 12FBD */ { "SIGNE CHYPRO-MINOEN CM058",NULL},
/* 12FBE */ { "SIGNE CHYPRO-MINOEN CM059",NULL},
/* 12FBF */ { "SIGNE CHYPRO-MINOEN CM060",NULL},
/* 12FC0 */ { "SIGNE CHYPRO-MINOEN CM061",NULL},
/* 12FC1 */ { "SIGNE CHYPRO-MINOEN CM062",NULL},
/* 12FC2 */ { "SIGNE CHYPRO-MINOEN CM063",NULL},
/* 12FC3 */ { "SIGNE CHYPRO-MINOEN CM064",NULL},
/* 12FC4 */ { "SIGNE CHYPRO-MINOEN CM066",NULL},
/* 12FC5 */ { "SIGNE CHYPRO-MINOEN CM067",NULL},
/* 12FC6 */ { "SIGNE CHYPRO-MINOEN CM068",NULL},
/* 12FC7 */ { "SIGNE CHYPRO-MINOEN CM069",NULL},
/* 12FC8 */ { "SIGNE CHYPRO-MINOEN CM070",NULL},
/* 12FC9 */ { "SIGNE CHYPRO-MINOEN CM071",NULL},
/* 12FCA */ { "SIGNE CHYPRO-MINOEN CM072",NULL},
/* 12FCB */ { "SIGNE CHYPRO-MINOEN CM073",NULL},
/* 12FCC */ { "SIGNE CHYPRO-MINOEN CM074",NULL},
/* 12FCD */ { "SIGNE CHYPRO-MINOEN CM075",NULL},
/* 12FCE */ { "SIGNE CHYPRO-MINOEN CM075B",NULL},
/* 12FCF */ { "SIGNE CHYPRO-MINOEN CM076",NULL},
/* 12FD0 */ { "SIGNE CHYPRO-MINOEN CM078",NULL},
/* 12FD1 */ { "SIGNE CHYPRO-MINOEN CM079",NULL},
/* 12FD2 */ { "SIGNE CHYPRO-MINOEN CM080",NULL},
/* 12FD3 */ { "SIGNE CHYPRO-MINOEN CM081",NULL},
/* 12FD4 */ { "SIGNE CHYPRO-MINOEN CM082",NULL},
/* 12FD5 */ { "SIGNE CHYPRO-MINOEN CM083",NULL},
/* 12FD6 */ { "SIGNE CHYPRO-MINOEN CM084",NULL},
/* 12FD7 */ { "SIGNE CHYPRO-MINOEN CM085",NULL},
/* 12FD8 */ { "SIGNE CHYPRO-MINOEN CM086",NULL},
/* 12FD9 */ { "SIGNE CHYPRO-MINOEN CM087",NULL},
/* 12FDA */ { "SIGNE CHYPRO-MINOEN CM088",NULL},
/* 12FDB */ { "SIGNE CHYPRO-MINOEN CM089",NULL},
/* 12FDC */ { "SIGNE CHYPRO-MINOEN CM090",NULL},
/* 12FDD */ { "SIGNE CHYPRO-MINOEN CM091",NULL},
/* 12FDE */ { "SIGNE CHYPRO-MINOEN CM092",NULL},
/* 12FDF */ { "SIGNE CHYPRO-MINOEN CM094",NULL},
/* 12FE0 */ { "SIGNE CHYPRO-MINOEN CM095",NULL},
/* 12FE1 */ { "SIGNE CHYPRO-MINOEN CM096",NULL},
/* 12FE2 */ { "SIGNE CHYPRO-MINOEN CM097",NULL},
/* 12FE3 */ { "SIGNE CHYPRO-MINOEN CM098",NULL},
/* 12FE4 */ { "SIGNE CHYPRO-MINOEN CM099",NULL},
/* 12FE5 */ { "SIGNE CHYPRO-MINOEN CM100",NULL},
/* 12FE6 */ { "SIGNE CHYPRO-MINOEN CM101",NULL},
/* 12FE7 */ { "SIGNE CHYPRO-MINOEN CM102",NULL},
/* 12FE8 */ { "SIGNE CHYPRO-MINOEN CM103",NULL},
/* 12FE9 */ { "SIGNE CHYPRO-MINOEN CM104",NULL},
/* 12FEA */ { "SIGNE CHYPRO-MINOEN CM105",NULL},
/* 12FEB */ { "SIGNE CHYPRO-MINOEN CM107",NULL},
/* 12FEC */ { "SIGNE CHYPRO-MINOEN CM108",NULL},
/* 12FED */ { "SIGNE CHYPRO-MINOEN CM109",NULL},
/* 12FEE */ { "SIGNE CHYPRO-MINOEN CM110",NULL},
/* 12FEF */ { "SIGNE CHYPRO-MINOEN CM112",NULL},
/* 12FF0 */ { "SIGNE CHYPRO-MINOEN CM114",NULL},
/* 12FF1 */ { "SIGNE CHYPRO-MINOEN CM301",NULL},
/* 12FF2 */ { "SIGNE CHYPRO-MINOEN CM302",NULL},
/* 12FF3 */ { NULL,NULL},
/* 12FF4 */ { NULL,NULL},
/* 12FF5 */ { NULL,NULL},
/* 12FF6 */ { NULL,NULL},
/* 12FF7 */ { NULL,NULL},
/* 12FF8 */ { NULL,NULL},
/* 12FF9 */ { NULL,NULL},
/* 12FFA */ { NULL,NULL},
/* 12FFB */ { NULL,NULL},
/* 12FFC */ { NULL,NULL},
/* 12FFD */ { NULL,NULL},
/* 12FFE */ { NULL,NULL},
/* 12FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_30[] = {
/* 13000 */ { "HIÉROGLYPHE ÉGYPTIEN A001","	* classificateur être humain"},
/* 13001 */ { "HIÉROGLYPHE ÉGYPTIEN A002","	* classificateur manger, boire, parole, silence, pensées, sentiments"},
/* 13002 */ { "HIÉROGLYPHE ÉGYPTIEN A003","	* classificateur assis : ḥmsꞽ"},
/* 13003 */ { "HIÉROGLYPHE ÉGYPTIEN A004","	* classificateur supplication, dissimulation, rejet"},
/* 13004 */ { "HIÉROGLYPHE ÉGYPTIEN A005",NULL},
/* 13005 */ { "HIÉROGLYPHE ÉGYPTIEN A005A","	* logogramme (cacher) : ꞽmn"},
/* 13006 */ { "HIÉROGLYPHE ÉGYPTIEN A006","	* logogramme (pur, propre) : wꜥb"},
/* 13007 */ { "HIÉROGLYPHE ÉGYPTIEN A006A","	* classificateur faire une libation : sṯ"},
/* 13008 */ { "HIÉROGLYPHE ÉGYPTIEN A006B",NULL},
/* 13009 */ { "HIÉROGLYPHE ÉGYPTIEN A007","	* classificateur assis, faible, évanoui"},
/* 1300A */ { "HIÉROGLYPHE ÉGYPTIEN A008","	* classificateur joie, vénération"},
/* 1300B */ { "HIÉROGLYPHE ÉGYPTIEN A009","	* classificateur lever, porter : fꜣꞽ"},
/* 1300C */ { "HIÉROGLYPHE ÉGYPTIEN A010","	* classificateur voile, aviron : sḳdꞽ"},
/* 1300D */ { "HIÉROGLYPHE ÉGYPTIEN A011","	* phonémogramme : ḫnms"},
/* 1300E */ { "HIÉROGLYPHE ÉGYPTIEN A012","	* logogramme (armée) : mšꜥ"},
/* 1300F */ { "HIÉROGLYPHE ÉGYPTIEN A013","	* classificateur rebelle, ennemi"},
/* 13010 */ { "HIÉROGLYPHE ÉGYPTIEN A014","	* classificateur rebelle, adversaire : rḳ"},
/* 13011 */ { "HIÉROGLYPHE ÉGYPTIEN A014A","	* classificateur mort : mt"},
/* 13012 */ { "HIÉROGLYPHE ÉGYPTIEN A015","	* logogramme (tomber) : ḫr\n"
	"	~ 13012 FE03 pivoté de 30 degrés environ"},
/* 13013 */ { "HIÉROGLYPHE ÉGYPTIEN A016","	* classificateur prosternant"},
/* 13014 */ { "HIÉROGLYPHE ÉGYPTIEN A017","	* classificateur jeunesse, enfant"},
/* 13015 */ { "HIÉROGLYPHE ÉGYPTIEN A017A","	* classificateur jeunesse, enfant"},
/* 13016 */ { "HIÉROGLYPHE ÉGYPTIEN A018","	* classificateur enfant (royal)"},
/* 13017 */ { "HIÉROGLYPHE ÉGYPTIEN A019","	* logogramme (vieux, âge avancé) : ꞽꜣw"},
/* 13018 */ { "HIÉROGLYPHE ÉGYPTIEN A020","	* logogramme (aîné) : smsw"},
/* 13019 */ { "HIÉROGLYPHE ÉGYPTIEN A021",NULL},
/* 1301A */ { "HIÉROGLYPHE ÉGYPTIEN A022","	* classificateur statue"},
/* 1301B */ { "HIÉROGLYPHE ÉGYPTIEN A023","	* classificateur souverain : ꞽt.y"},
/* 1301C */ { "HIÉROGLYPHE ÉGYPTIEN A024","	* classificateur force, effort"},
/* 1301D */ { "HIÉROGLYPHE ÉGYPTIEN A025","	* classificateur force, effort"},
/* 1301E */ { "HIÉROGLYPHE ÉGYPTIEN A026","	* logogramme (interjection vocative) : ꞽ"},
/* 1301F */ { "HIÉROGLYPHE ÉGYPTIEN A027","	* phonémogramme/classificateur messager : ꞽn"},
/* 13020 */ { "HIÉROGLYPHE ÉGYPTIEN A028","	* logogramme (être élevé) : ḳꜣꞽ"},
/* 13021 */ { "HIÉROGLYPHE ÉGYPTIEN A029","	* classificateur à l'envers : sḫd"},
/* 13022 */ { "HIÉROGLYPHE ÉGYPTIEN A030","	* classificateur adoration"},
/* 13023 */ { "HIÉROGLYPHE ÉGYPTIEN A031","	* classificateur se détournant"},
/* 13024 */ { "HIÉROGLYPHE ÉGYPTIEN A032","	* classificateur dansant : ḫbꞽ"},
/* 13025 */ { "HIÉROGLYPHE ÉGYPTIEN A032A",NULL},
/* 13026 */ { "HIÉROGLYPHE ÉGYPTIEN A033","	* classificateur errant, déplacé : rw"},
/* 13027 */ { "HIÉROGLYPHE ÉGYPTIEN A034","	* logogramme (manœuvrer, construire) : ḫwsꞽ"},
/* 13028 */ { "HIÉROGLYPHE ÉGYPTIEN A035","	* logogramme (construire) : ḳd"},
/* 13029 */ { "HIÉROGLYPHE ÉGYPTIEN A036","	* logogramme (brasseur) : ꜥf.ty"},
/* 1302A */ { "HIÉROGLYPHE ÉGYPTIEN A037","	* logogramme (brasseur) : ꜥf.ty"},
/* 1302B */ { "HIÉROGLYPHE ÉGYPTIEN A038","	* logogramme (Cusae) : ḳꞽs"},
/* 1302C */ { "HIÉROGLYPHE ÉGYPTIEN A039","	* logogramme (Cusae) : ḳꞽs"},
/* 1302D */ { "HIÉROGLYPHE ÉGYPTIEN A040","	* classificateur divinité"},
/* 1302E */ { "HIÉROGLYPHE ÉGYPTIEN A040A","	* classificateur divinité"},
/* 1302F */ { "HIÉROGLYPHE ÉGYPTIEN A041","	* logogramme (première personne du singulier) : ꞽ"},
/* 13030 */ { "HIÉROGLYPHE ÉGYPTIEN A042","	* classificateur roi : n(y)-sw.t"},
/* 13031 */ { "HIÉROGLYPHE ÉGYPTIEN A042A","	* logogramme (première personne du singulier) : ꞽ"},
/* 13032 */ { "HIÉROGLYPHE ÉGYPTIEN A043","	* classificateur roi"},
/* 13033 */ { "HIÉROGLYPHE ÉGYPTIEN A043A","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 13034 */ { "HIÉROGLYPHE ÉGYPTIEN A044","	* classificateur roi : n.y-sw.t"},
/* 13035 */ { "HIÉROGLYPHE ÉGYPTIEN A045","	* classificateur roi : bꞽ.ty"},
/* 13036 */ { "HIÉROGLYPHE ÉGYPTIEN A045A","	* classificateur roi : n.y-sw.t"},
/* 13037 */ { "HIÉROGLYPHE ÉGYPTIEN A046","	* classificateur roi : bꞽ.tyw"},
/* 13038 */ { "HIÉROGLYPHE ÉGYPTIEN A047","	* logogramme (garder) : sꜣw"},
/* 13039 */ { "HIÉROGLYPHE ÉGYPTIEN A048","	* logogramme (se rapportant à, appartenant à) : ꞽr.y"},
/* 1303A */ { "HIÉROGLYPHE ÉGYPTIEN A049","	* classificateur étranger"},
/* 1303B */ { "HIÉROGLYPHE ÉGYPTIEN A050","	* logogramme (être noble) : špsꞽ"},
/* 1303C */ { "HIÉROGLYPHE ÉGYPTIEN A051","	* logogramme (être noble) : šps"},
/* 1303D */ { "HIÉROGLYPHE ÉGYPTIEN A052","	* classificateur nom (personne décédée)"},
/* 1303E */ { "HIÉROGLYPHE ÉGYPTIEN A053","	* classificateur image, statue, représentation"},
/* 1303F */ { "HIÉROGLYPHE ÉGYPTIEN A054","	* classificateur corps, cadavre, mort"},
/* 13040 */ { "HIÉROGLYPHE ÉGYPTIEN A055","	* logogramme (dormir, passer la nuit) : sḏr"},
/* 13041 */ { "HIÉROGLYPHE ÉGYPTIEN A056","	* classificateur ennemi : ḫft.y"},
/* 13042 */ { "HIÉROGLYPHE ÉGYPTIEN A057","	* logogramme (une offrande que le roi donne) : ḥtp-dꞽ-n.y-sw.t"},
/* 13043 */ { "HIÉROGLYPHE ÉGYPTIEN A058","	* classificateur binage : ḫbs"},
/* 13044 */ { "HIÉROGLYPHE ÉGYPTIEN A059","	* classificateur éloignant : sḥrꞽ"},
/* 13045 */ { "HIÉROGLYPHE ÉGYPTIEN A060","	* logogramme (asperger, disperser) : stꞽ"},
/* 13046 */ { "HIÉROGLYPHE ÉGYPTIEN A061","	* logogramme (revenir en arrière) : ꜥnn"},
/* 13047 */ { "HIÉROGLYPHE ÉGYPTIEN A062","	* logogramme (le grand, chef) : wr"},
/* 13048 */ { "HIÉROGLYPHE ÉGYPTIEN A063",NULL},
/* 13049 */ { "HIÉROGLYPHE ÉGYPTIEN A064","	* classificateur lever, porter : fꜣꞽ"},
/* 1304A */ { "HIÉROGLYPHE ÉGYPTIEN A065","	* logogramme (celui qui appartient au dieu) : ꞽr.y-nṯr"},
/* 1304B */ { "HIÉROGLYPHE ÉGYPTIEN A066","	* logogramme (le musicien, Ihi) : ꞽḥy"},
/* 1304C */ { "HIÉROGLYPHE ÉGYPTIEN A067","	* classificateur nom personnel"},
/* 1304D */ { "HIÉROGLYPHE ÉGYPTIEN A068","	* logogramme (messager) : wpw.ty"},
/* 1304E */ { "HIÉROGLYPHE ÉGYPTIEN A069","	* classificateur occupation, relation"},
/* 1304F */ { "HIÉROGLYPHE ÉGYPTIEN A070","	* logogramme (million, beaucoup) : ḥḥ"},
/* 13050 */ { "HIÉROGLYPHE ÉGYPTIEN B001","	* classificateur féminin"},
/* 13051 */ { "HIÉROGLYPHE ÉGYPTIEN B002","	* classificateur enceinte : ꞽwr"},
/* 13052 */ { "HIÉROGLYPHE ÉGYPTIEN B003","	* classificateur naissance : msꞽ"},
/* 13053 */ { "HIÉROGLYPHE ÉGYPTIEN B004","	* classificateur naissance : msꞽ"},
/* 13054 */ { "HIÉROGLYPHE ÉGYPTIEN B005","	* classificateur allaitement, éducation : rnn"},
/* 13055 */ { "HIÉROGLYPHE ÉGYPTIEN B005A","	* logogramme (tisserande) ou logogramme (nourrice) : ? | mnḫ.t"},
/* 13056 */ { "HIÉROGLYPHE ÉGYPTIEN B006","	* classificateur allaitement, éducation : rnn"},
/* 13057 */ { "HIÉROGLYPHE ÉGYPTIEN B007","	* classificateur royauté féminine"},
/* 13058 */ { "HIÉROGLYPHE ÉGYPTIEN B008","	* classificateur être humain (avec A1) : ḥr.w-nb"},
/* 13059 */ { "HIÉROGLYPHE ÉGYPTIEN B009","	* logogramme (la musicienne) : ꞽḥ.yt"},
/* 1305A */ { "HIÉROGLYPHE ÉGYPTIEN C001","	* logogramme (Rê) : rꜥ"},
/* 1305B */ { "HIÉROGLYPHE ÉGYPTIEN C002","	* logogramme (Rê) : rꜥ"},
/* 1305C */ { "HIÉROGLYPHE ÉGYPTIEN C002A","	* logogramme (Rê) : rꜥ"},
/* 1305D */ { "HIÉROGLYPHE ÉGYPTIEN C002B","	* version « miroir » de 1305C"},
/* 1305E */ { "HIÉROGLYPHE ÉGYPTIEN C002C","	* version « miroir » de 1305B"},
/* 1305F */ { "HIÉROGLYPHE ÉGYPTIEN C003","	* logogramme (Thot) : ḏhwty"},
/* 13060 */ { "HIÉROGLYPHE ÉGYPTIEN C004","	* classificateur Khnoum : ẖnm.w"},
/* 13061 */ { "HIÉROGLYPHE ÉGYPTIEN C005","	* logogramme/phonémogramme (qui rejoint la vie) : ẖnm.t-ꜥnḫ"},
/* 13062 */ { "HIÉROGLYPHE ÉGYPTIEN C006","	* classificateur Anubis/Oupouaout (divinité)"},
/* 13063 */ { "HIÉROGLYPHE ÉGYPTIEN C007","	* logogramme (Seth) : stš/stẖ"},
/* 13064 */ { "HIÉROGLYPHE ÉGYPTIEN C008","	* classificateur Min : gb.tyw"},
/* 13065 */ { "HIÉROGLYPHE ÉGYPTIEN C009","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 13066 */ { "HIÉROGLYPHE ÉGYPTIEN C010","	* logogramme (Maât) : mꜣꜥ.t"},
/* 13067 */ { "HIÉROGLYPHE ÉGYPTIEN C010A","	* logogramme (Maât) : mꜣꜥ.t"},
/* 13068 */ { "HIÉROGLYPHE ÉGYPTIEN C011","	* logogramme (million, beaucoup) : ḥḥ"},
/* 13069 */ { "HIÉROGLYPHE ÉGYPTIEN C012","	* logogramme (Amon) : ꞽmn"},
/* 1306A */ { "HIÉROGLYPHE ÉGYPTIEN C013","	* version « miroir » de 13069"},
/* 1306B */ { "HIÉROGLYPHE ÉGYPTIEN C014","	* logogramme (Amon est sa force (sꜣ-rꜥ nom Ramsès VI)) : ꞽmn-ḥr-ḫpš=f"},
/* 1306C */ { "HIÉROGLYPHE ÉGYPTIEN C015","	* version « miroir » de 1306B"},
/* 1306D */ { "HIÉROGLYPHE ÉGYPTIEN C016","	* logogramme (Atoum) : ꞽtmw"},
/* 1306E */ { "HIÉROGLYPHE ÉGYPTIEN C017","	* classificateur Montou (divinité)"},
/* 1306F */ { "HIÉROGLYPHE ÉGYPTIEN C018","	* classificateur Taténen : tꜣ-ṯnn"},
/* 13070 */ { "HIÉROGLYPHE ÉGYPTIEN C019","	* classificateur Ptah : ptḥ"},
/* 13071 */ { "HIÉROGLYPHE ÉGYPTIEN C020","	* logogramme (Ptah) : ptḥ"},
/* 13072 */ { "HIÉROGLYPHE ÉGYPTIEN C021","	* phonémogramme : bs"},
/* 13073 */ { "HIÉROGLYPHE ÉGYPTIEN C022","	* classificateur lune : ꞽꜥḥ"},
/* 13074 */ { "HIÉROGLYPHE ÉGYPTIEN C023","	* logogramme (Sekhmet) : sḫm.t"},
/* 13075 */ { "HIÉROGLYPHE ÉGYPTIEN C024","	* logogramme (Neith) : n.t"},
/* 13076 */ { "HIÉROGLYPHE ÉGYPTIEN D001","	* logogramme (tête)"},
/* 13077 */ { "HIÉROGLYPHE ÉGYPTIEN D002","	* phonémogramme : ḥr"},
/* 13078 */ { "HIÉROGLYPHE ÉGYPTIEN D003","	* classificateur cheveux"},
/* 13079 */ { "HIÉROGLYPHE ÉGYPTIEN D004","	* phonémogramme : ꞽr"},
/* 1307A */ { "HIÉROGLYPHE ÉGYPTIEN D005","	* classificateur actions liées aux yeux : dgꞽ"},
/* 1307B */ { "HIÉROGLYPHE ÉGYPTIEN D006","	* classificateur actions liées aux yeux : dgꞽ"},
/* 1307C */ { "HIÉROGLYPHE ÉGYPTIEN D007","	* phonémogramme : ꜥntyw"},
/* 1307D */ { "HIÉROGLYPHE ÉGYPTIEN D008","	* phonémogramme : ꜥn"},
/* 1307E */ { "HIÉROGLYPHE ÉGYPTIEN D008A","	* phonémogramme : ꜥn"},
/* 1307F */ { "HIÉROGLYPHE ÉGYPTIEN D009","	* logogramme (pleurer) : rmꞽ"},
/* 13080 */ { "HIÉROGLYPHE ÉGYPTIEN D010","	* logogramme (œil oudjat) : wḏꜣ.t"},
/* 13081 */ { "HIÉROGLYPHE ÉGYPTIEN D011","	* logogramme (1/2)"},
/* 13082 */ { "HIÉROGLYPHE ÉGYPTIEN D012","	* à ne pas confondre avec 131F3 ou 133F8\n"
	"	* 1/4\n"
	"	* classificateur pupille : ḏfḏ"},
/* 13083 */ { "HIÉROGLYPHE ÉGYPTIEN D013","	* 1/8\n"
	"	* classificateur sourcil : ꞽnḥ"},
/* 13084 */ { "HIÉROGLYPHE ÉGYPTIEN D014","	* logogramme (1/16)"},
/* 13085 */ { "HIÉROGLYPHE ÉGYPTIEN D015","	* logogramme (1/32)"},
/* 13086 */ { "HIÉROGLYPHE ÉGYPTIEN D016","	* logogramme (1/64)"},
/* 13087 */ { "HIÉROGLYPHE ÉGYPTIEN D017","	* logogramme (figure, image) : tꞽ.t"},
/* 13088 */ { "HIÉROGLYPHE ÉGYPTIEN D018","	* logogramme (oreille) : msḏr"},
/* 13089 */ { "HIÉROGLYPHE ÉGYPTIEN D019","	* classificateur nez : šr.t"},
/* 1308A */ { "HIÉROGLYPHE ÉGYPTIEN D020","	* classificateur nez : fnḏ"},
/* 1308B */ { "HIÉROGLYPHE ÉGYPTIEN D021","	* bouche\n"
	"	* à ne pas confondre avec 133AB\n"
	"	* phonémogramme : r"},
/* 1308C */ { "HIÉROGLYPHE ÉGYPTIEN D022","	* logogramme (2/3) : r.wy"},
/* 1308D */ { "HIÉROGLYPHE ÉGYPTIEN D023","	* logogramme (3/4) : ḫmt-r.w"},
/* 1308E */ { "HIÉROGLYPHE ÉGYPTIEN D024","	* classificateur lèvre, bord, bordure : sp.t"},
/* 1308F */ { "HIÉROGLYPHE ÉGYPTIEN D025","	* logogramme (lèvres) : sp.ty"},
/* 13090 */ { "HIÉROGLYPHE ÉGYPTIEN D026","	* classificateur sang : snf"},
/* 13091 */ { "HIÉROGLYPHE ÉGYPTIEN D027","	* classificateur poitrine : mnḏ\n"
	"	~ 13091 FE00 pivoté de 90 degrés"},
/* 13092 */ { "HIÉROGLYPHE ÉGYPTIEN D027A","	* variante de 13091"},
/* 13093 */ { "HIÉROGLYPHE ÉGYPTIEN D028","	* logogramme (esprit, essence) : kꜣ\n"
	"	~ 13093 FE01 pivoté de 180 degrés"},
/* 13094 */ { "HIÉROGLYPHE ÉGYPTIEN D029","	* logogramme (esprit, essence) : kꜣ"},
/* 13095 */ { "HIÉROGLYPHE ÉGYPTIEN D030","	* classificateur Néhebkaou : nḥb-kꜣ.w"},
/* 13096 */ { "HIÉROGLYPHE ÉGYPTIEN D031","	* logogramme (prêtre funéraire) : ḥm-kꜣ"},
/* 13097 */ { "HIÉROGLYPHE ÉGYPTIEN D031A","	* logogramme (prêtre funéraire) : ḥm-kꜣ"},
/* 13098 */ { "HIÉROGLYPHE ÉGYPTIEN D032","	* classificateur enveloppant, embrassant, unissant"},
/* 13099 */ { "HIÉROGLYPHE ÉGYPTIEN D033","	* phonémogramme : ẖn"},
/* 1309A */ { "HIÉROGLYPHE ÉGYPTIEN D034","	* logogramme (combattre) : ꜥḥꜣ"},
/* 1309B */ { "HIÉROGLYPHE ÉGYPTIEN D034A","	* logogramme (combattre) : ꜥḥꜣ"},
/* 1309C */ { "HIÉROGLYPHE ÉGYPTIEN D035","	* logogramme (particule négative) : n"},
/* 1309D */ { "HIÉROGLYPHE ÉGYPTIEN D036","	* translittération en A725\n"
	"	x (lettre hébraïque 'aïn - 05E2)\n"
	"	x (lettre arabe 'aïn - 0639)\n"
	"	* phonémogramme : ꜥ"},
/* 1309E */ { "HIÉROGLYPHE ÉGYPTIEN D037","	* phonémogramme : ḏꞽ > dꞽ"},
/* 1309F */ { "HIÉROGLYPHE ÉGYPTIEN D038","	* phonémogramme : m"},
/* 130A0 */ { "HIÉROGLYPHE ÉGYPTIEN D039","	* logogramme (offrir, présenter) : ḥnk"},
/* 130A1 */ { "HIÉROGLYPHE ÉGYPTIEN D040","	* classificateur force, effort"},
/* 130A2 */ { "HIÉROGLYPHE ÉGYPTIEN D041","	* classificateur mouvements ou actions liés au bras"},
/* 130A3 */ { "HIÉROGLYPHE ÉGYPTIEN D042","	* logogramme (coude) : mḥ"},
/* 130A4 */ { "HIÉROGLYPHE ÉGYPTIEN D043","	* logogramme (protéger) : ḫwꞽ"},
/* 130A5 */ { "HIÉROGLYPHE ÉGYPTIEN D044","	* classificateur gouvernant, contrôlant : ḫrp"},
/* 130A6 */ { "HIÉROGLYPHE ÉGYPTIEN D045","	* logogramme (rendre sacré) : ḏsr"},
/* 130A7 */ { "HIÉROGLYPHE ÉGYPTIEN D046","	* phonémogramme : d"},
/* 130A8 */ { "HIÉROGLYPHE ÉGYPTIEN D046A","	* logogramme (senteur, parfum, rosée) : ꞽd.t"},
/* 130A9 */ { "HIÉROGLYPHE ÉGYPTIEN D047","	* classificateur main : ḏr.t"},
/* 130AA */ { "HIÉROGLYPHE ÉGYPTIEN D048","	* logogramme (paume) : šsp"},
/* 130AB */ { "HIÉROGLYPHE ÉGYPTIEN D048A","	* phono-répéteur : ḥnt"},
/* 130AC */ { "HIÉROGLYPHE ÉGYPTIEN D049","	* classificateur saisie, maintien : ꜣmm"},
/* 130AD */ { "HIÉROGLYPHE ÉGYPTIEN D050","	* à ne pas confondre avec 130B7\n"
	"	* 10.000\n"
	"	* logogramme (doigt) : ḏbꜥ"},
/* 130AE */ { "HIÉROGLYPHE ÉGYPTIEN D050A","	* 20.000"},
/* 130AF */ { "HIÉROGLYPHE ÉGYPTIEN D050B","	* 30.000"},
/* 130B0 */ { "HIÉROGLYPHE ÉGYPTIEN D050C","	* 40.000"},
/* 130B1 */ { "HIÉROGLYPHE ÉGYPTIEN D050D","	* 50.000"},
/* 130B2 */ { "HIÉROGLYPHE ÉGYPTIEN D050E","	* 60.000"},
/* 130B3 */ { "HIÉROGLYPHE ÉGYPTIEN D050F","	* 70.000"},
/* 130B4 */ { "HIÉROGLYPHE ÉGYPTIEN D050G","	* 80.000"},
/* 130B5 */ { "HIÉROGLYPHE ÉGYPTIEN D050H","	* 90.000"},
/* 130B6 */ { "HIÉROGLYPHE ÉGYPTIEN D050I","	* 50.000"},
/* 130B7 */ { "HIÉROGLYPHE ÉGYPTIEN D051","	* à ne pas confondre avec 130AD\n"
	"	* classificateur prise : ṯꜣꞽ"},
/* 130B8 */ { "HIÉROGLYPHE ÉGYPTIEN D052","	* phonémogramme : bꜣḥ\n"
	"	~ 130B8 FE03 pivoté de 25 degrés environ"},
/* 130B9 */ { "HIÉROGLYPHE ÉGYPTIEN D052A","	* phonémogramme : sšm"},
/* 130BA */ { "HIÉROGLYPHE ÉGYPTIEN D053","	* phonémogramme : bꜣḥ\n"
	"	~ 130BA FE03 pivoté de 25 degrés environ"},
/* 130BB */ { "HIÉROGLYPHE ÉGYPTIEN D054","	* classificateur mouvement"},
/* 130BC */ { "HIÉROGLYPHE ÉGYPTIEN D054A","	* logogramme (venir) : ꞽwꞽ"},
/* 130BD */ { "HIÉROGLYPHE ÉGYPTIEN D055","	* classificateur mouvement inverse"},
/* 130BE */ { "HIÉROGLYPHE ÉGYPTIEN D056","	* classificateur jambe, pied : rd"},
/* 130BF */ { "HIÉROGLYPHE ÉGYPTIEN D057","	* classificateur dommage, blessure : nkn"},
/* 130C0 */ { "HIÉROGLYPHE ÉGYPTIEN D058","	* phonémogramme : b"},
/* 130C1 */ { "HIÉROGLYPHE ÉGYPTIEN D059","	* phonémogramme : ꜥb"},
/* 130C2 */ { "HIÉROGLYPHE ÉGYPTIEN D060","	* logogramme (être pur, être propre) : wꜥb"},
/* 130C3 */ { "HIÉROGLYPHE ÉGYPTIEN D061","	* phono-répéteur : sꜣḥ"},
/* 130C4 */ { "HIÉROGLYPHE ÉGYPTIEN D062","	* phonémogramme : sꜣḥ"},
/* 130C5 */ { "HIÉROGLYPHE ÉGYPTIEN D063","	* phonémogramme : sꜣḥ"},
/* 130C6 */ { "HIÉROGLYPHE ÉGYPTIEN D064","	* logogramme (main) : ḏr.t"},
/* 130C7 */ { "HIÉROGLYPHE ÉGYPTIEN D065","	* logogramme (enfant, fils, garçon) : šrꞽ"},
/* 130C8 */ { "HIÉROGLYPHE ÉGYPTIEN D066","	* classificateur graver : wdꞽ"},
/* 130C9 */ { "HIÉROGLYPHE ÉGYPTIEN D067","	* 1 héqat\n"
	"	* à ne pas confondre avec 13212"},
/* 130CA */ { "HIÉROGLYPHE ÉGYPTIEN D067A","	* 2 héqat"},
/* 130CB */ { "HIÉROGLYPHE ÉGYPTIEN D067B","	* 3 héqat"},
/* 130CC */ { "HIÉROGLYPHE ÉGYPTIEN D067C","	* 4 héqat"},
/* 130CD */ { "HIÉROGLYPHE ÉGYPTIEN D067D","	* 5 héqat"},
/* 130CE */ { "HIÉROGLYPHE ÉGYPTIEN D067E","	* 6 héqat"},
/* 130CF */ { "HIÉROGLYPHE ÉGYPTIEN D067F","	* 7 héqat"},
/* 130D0 */ { "HIÉROGLYPHE ÉGYPTIEN D067G","	* 8 héqat"},
/* 130D1 */ { "HIÉROGLYPHE ÉGYPTIEN D067H","	* 9 héqat"},
/* 130D2 */ { "HIÉROGLYPHE ÉGYPTIEN E001","	* à ne pas confondre avec 130FD\n"
	"	* logogramme (taureau) : kꜣ"},
/* 130D3 */ { "HIÉROGLYPHE ÉGYPTIEN E002","	* classificateur rage, agression : smꜣ"},
/* 130D4 */ { "HIÉROGLYPHE ÉGYPTIEN E003","	* classificateur veau : bḥs"},
/* 130D5 */ { "HIÉROGLYPHE ÉGYPTIEN E004","	* classificateur divinité vache : mḥ.yt"},
/* 130D6 */ { "HIÉROGLYPHE ÉGYPTIEN E005","	* classificateur préoccupation : ꜣms"},
/* 130D7 */ { "HIÉROGLYPHE ÉGYPTIEN E006","	* logogramme (attelage (de chevaux), cheval) : ḥtr"},
/* 130D8 */ { "HIÉROGLYPHE ÉGYPTIEN E007","	* classificateur âne : ꜥꜣ"},
/* 130D9 */ { "HIÉROGLYPHE ÉGYPTIEN E008","	* logogramme (chevreau) : ꞽb"},
/* 130DA */ { "HIÉROGLYPHE ÉGYPTIEN E008A","	* phono-répéteur : ꞽb"},
/* 130DB */ { "HIÉROGLYPHE ÉGYPTIEN E009","	* phonémogramme : ꞽw"},
/* 130DC */ { "HIÉROGLYPHE ÉGYPTIEN E009A","	* classificateur vache (vache du ciel) : ꞽh.t"},
/* 130DD */ { "HIÉROGLYPHE ÉGYPTIEN E010","	* classificateur bélier : bꜣ"},
/* 130DE */ { "HIÉROGLYPHE ÉGYPTIEN E011","	* phonémogramme : bꜣ"},
/* 130DF */ { "HIÉROGLYPHE ÉGYPTIEN E012","	* classificateur cochon : ꞽpḥ"},
/* 130E0 */ { "HIÉROGLYPHE ÉGYPTIEN E013","	* phonémogramme : mꞽ"},
/* 130E1 */ { "HIÉROGLYPHE ÉGYPTIEN E014","	* classificateur chien, chien de chasse : ṯsm"},
/* 130E2 */ { "HIÉROGLYPHE ÉGYPTIEN E015","	* logogramme (Anubis) : ꞽnp.w"},
/* 130E3 */ { "HIÉROGLYPHE ÉGYPTIEN E016","	* logogramme (initié aux secrets) : ḥr.y-sštꜣ"},
/* 130E4 */ { "HIÉROGLYPHE ÉGYPTIEN E016A","	* classificateur Anubis : ꞽnp.w"},
/* 130E5 */ { "HIÉROGLYPHE ÉGYPTIEN E017","	* phonémogramme : sꜣb"},
/* 130E6 */ { "HIÉROGLYPHE ÉGYPTIEN E017A","	* phonémogramme : sṯꜣ"},
/* 130E7 */ { "HIÉROGLYPHE ÉGYPTIEN E018","	* logogramme (Oupouaout) : wp-wꜣ.wt"},
/* 130E8 */ { "HIÉROGLYPHE ÉGYPTIEN E019","	* classificateur Oupouaout : wp-wꜣ.wt"},
/* 130E9 */ { "HIÉROGLYPHE ÉGYPTIEN E020","	* logogramme (Seth) : stš/stẖ"},
/* 130EA */ { "HIÉROGLYPHE ÉGYPTIEN E020A",NULL},
/* 130EB */ { "HIÉROGLYPHE ÉGYPTIEN E021","	* logogramme (Seth) : stš/stẖ"},
/* 130EC */ { "HIÉROGLYPHE ÉGYPTIEN E022","	* classificateur lion : mꜣꞽ"},
/* 130ED */ { "HIÉROGLYPHE ÉGYPTIEN E023","	* phonémogramme : rw"},
/* 130EE */ { "HIÉROGLYPHE ÉGYPTIEN E024","	* classificateur léopard : ꜣby"},
/* 130EF */ { "HIÉROGLYPHE ÉGYPTIEN E025","	* classificateur hippopotame : ḫꜣb"},
/* 130F0 */ { "HIÉROGLYPHE ÉGYPTIEN E026","	* classificateur éléphant : ꜣbw"},
/* 130F1 */ { "HIÉROGLYPHE ÉGYPTIEN E027","	* classificateur prédire : sr"},
/* 130F2 */ { "HIÉROGLYPHE ÉGYPTIEN E028","	* classificateur oryx : mꜣ-ḥḏ"},
/* 130F3 */ { "HIÉROGLYPHE ÉGYPTIEN E028A","	* logogramme (nome de l'Oryx, 16e nome de Haute-Égypte) : mꜣ-ḥḏ"},
/* 130F4 */ { "HIÉROGLYPHE ÉGYPTIEN E029","	* classificateur gazelle : gḥs"},
/* 130F5 */ { "HIÉROGLYPHE ÉGYPTIEN E030","	* classificateur bouquetin : n(ꞽ)ꜣw"},
/* 130F6 */ { "HIÉROGLYPHE ÉGYPTIEN E031","	* logogramme (rang, dignité) : sꜥḥ"},
/* 130F7 */ { "HIÉROGLYPHE ÉGYPTIEN E032","	* classificateur rage, fureur : ḳnd"},
/* 130F8 */ { "HIÉROGLYPHE ÉGYPTIEN E033","	* classificateur singe : gf"},
/* 130F9 */ { "HIÉROGLYPHE ÉGYPTIEN E034","	* phonémogramme : wn"},
/* 130FA */ { "HIÉROGLYPHE ÉGYPTIEN E034A","	* variante de 130F9"},
/* 130FB */ { "HIÉROGLYPHE ÉGYPTIEN E036","	* logogramme (Thot) : ḏḥwty"},
/* 130FC */ { "HIÉROGLYPHE ÉGYPTIEN E037","	* logogramme (symbole du cycle du temps) : wnšb"},
/* 130FD */ { "HIÉROGLYPHE ÉGYPTIEN E038","	* vache\n"
	"	* à ne pas confondre avec 130D2"},
/* 130FE */ { "HIÉROGLYPHE ÉGYPTIEN F001","	* classificateur taureau, bœuf, bétail : kꜣ"},
/* 130FF */ { "HIÉROGLYPHE ÉGYPTIEN F001A","	* phonémogramme : ḫnt"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_31[] = {
/* 13100 */ { "HIÉROGLYPHE ÉGYPTIEN F002","	* classificateur rage, agression : ḏnd"},
/* 13101 */ { "HIÉROGLYPHE ÉGYPTIEN F003","	* phonémogramme : ꜣt"},
/* 13102 */ { "HIÉROGLYPHE ÉGYPTIEN F004","	* logogramme (début, devant) : ḥꜣ.t"},
/* 13103 */ { "HIÉROGLYPHE ÉGYPTIEN F005","	* phonémogramme : šsꜣ"},
/* 13104 */ { "HIÉROGLYPHE ÉGYPTIEN F006","	* phonémogramme : šsꜣ"},
/* 13105 */ { "HIÉROGLYPHE ÉGYPTIEN F007","	* classificateur valeur, dignité, renommée : šfšf.yt"},
/* 13106 */ { "HIÉROGLYPHE ÉGYPTIEN F008","	* logogramme (valeur, dignité, renommée) : šf.yt"},
/* 13107 */ { "HIÉROGLYPHE ÉGYPTIEN F009","	* logogramme (force) : pḥ.ty"},
/* 13108 */ { "HIÉROGLYPHE ÉGYPTIEN F010","	* classificateur action associée à la gorge : sꜥm"},
/* 13109 */ { "HIÉROGLYPHE ÉGYPTIEN F011","	* classificateur action associée à la gorge : ꜥm"},
/* 1310A */ { "HIÉROGLYPHE ÉGYPTIEN F012","	* phonémogramme : wsr"},
/* 1310B */ { "HIÉROGLYPHE ÉGYPTIEN F013","	* phonémogramme : wp"},
/* 1310C */ { "HIÉROGLYPHE ÉGYPTIEN F013A","	* variante de 1310B"},
/* 1310D */ { "HIÉROGLYPHE ÉGYPTIEN F014","	* logogramme (jour de l'an) : wp-rnp.t"},
/* 1310E */ { "HIÉROGLYPHE ÉGYPTIEN F015","	* logogramme (jour de l'an) : wp-rnp.t"},
/* 1310F */ { "HIÉROGLYPHE ÉGYPTIEN F016","	* logogramme (corne) : ꜥb\n"
	"	~ 1310F FE00 pivoté de 90 degrés\n"
	"	~ 1310F FE03 pivoté de 30 degrés environ"},
/* 13110 */ { "HIÉROGLYPHE ÉGYPTIEN F017","	* logogramme (purification) : ꜥb.w"},
/* 13111 */ { "HIÉROGLYPHE ÉGYPTIEN F018","	* phonémogramme : ḥ"},
/* 13112 */ { "HIÉROGLYPHE ÉGYPTIEN F019","	* classificateur mandibule : ꜥr"},
/* 13113 */ { "HIÉROGLYPHE ÉGYPTIEN F020","	* logogramme (langue) : ns"},
/* 13114 */ { "HIÉROGLYPHE ÉGYPTIEN F021","	* logogramme (oreille) : msḏr"},
/* 13115 */ { "HIÉROGLYPHE ÉGYPTIEN F021A","	* du hiératique\n"
	"	* logogramme (entendre, écouter)"},
/* 13116 */ { "HIÉROGLYPHE ÉGYPTIEN F022","	* phonémogramme : pḥ"},
/* 13117 */ { "HIÉROGLYPHE ÉGYPTIEN F023","	* classificateur patte avant, bras : ḫpš\n"
	"	~ 13117 FE02 pivoté de 270 degrés"},
/* 13118 */ { "HIÉROGLYPHE ÉGYPTIEN F024","	* version « miroir » de 13117\n"
	"	* classificateur patte avant, bras : ḫpš"},
/* 13119 */ { "HIÉROGLYPHE ÉGYPTIEN F025","	* phonémogramme : wḥm"},
/* 1311A */ { "HIÉROGLYPHE ÉGYPTIEN F026","	* phonémogramme : ẖn"},
/* 1311B */ { "HIÉROGLYPHE ÉGYPTIEN F027","	* classificateur animal : ṯsm"},
/* 1311C */ { "HIÉROGLYPHE ÉGYPTIEN F028","	* logogramme (tacheté, multicolore) : sꜣb\n"
	"	~ 1311C FE00 pivoté de 90 degrés"},
/* 1311D */ { "HIÉROGLYPHE ÉGYPTIEN F029","	* phonémogramme : st"},
/* 1311E */ { "HIÉROGLYPHE ÉGYPTIEN F030","	* phonémogramme : šd"},
/* 1311F */ { "HIÉROGLYPHE ÉGYPTIEN F031","	* phonémogramme : ms"},
/* 13120 */ { "HIÉROGLYPHE ÉGYPTIEN F031A","	* variante cursive de 1311F\n"
	"	* phonémogramme : ms"},
/* 13121 */ { "HIÉROGLYPHE ÉGYPTIEN F032","	* translittération en 1E96\n"
	"	* logogramme (ventre, corps) : ẖ.t\n"
	"	~ 13121 FE00 pivoté de 90 degrés"},
/* 13122 */ { "HIÉROGLYPHE ÉGYPTIEN F033","	* phonémogramme : sd"},
/* 13123 */ { "HIÉROGLYPHE ÉGYPTIEN F034","	* logogramme (cœur, esprit, souhait) : ꞽb"},
/* 13124 */ { "HIÉROGLYPHE ÉGYPTIEN F035","	* phonémogramme : nfr"},
/* 13125 */ { "HIÉROGLYPHE ÉGYPTIEN F036","	* phonémogramme : smꜣ"},
/* 13126 */ { "HIÉROGLYPHE ÉGYPTIEN F037","	* classificateur colonne vertébrale, vertèbres : ꞽꜣ.t"},
/* 13127 */ { "HIÉROGLYPHE ÉGYPTIEN F037A","	* logogramme (couper) : šꜥd\n"
	"	~ 13127 FE00 pivoté de 90 degrés"},
/* 13128 */ { "HIÉROGLYPHE ÉGYPTIEN F038","	* classificateur dos, épine dorsale : psḏ"},
/* 13129 */ { "HIÉROGLYPHE ÉGYPTIEN F038A",NULL},
/* 1312A */ { "HIÉROGLYPHE ÉGYPTIEN F039","	* phonémogramme : ꞽmꜣḫ"},
/* 1312B */ { "HIÉROGLYPHE ÉGYPTIEN F040","	* logogramme (être long, s'étirer) : ꜣwꞽ"},
/* 1312C */ { "HIÉROGLYPHE ÉGYPTIEN F041","	* classificateur abattage, maléfique : šꜥ.t"},
/* 1312D */ { "HIÉROGLYPHE ÉGYPTIEN F042","	* classificateur côte : spr"},
/* 1312E */ { "HIÉROGLYPHE ÉGYPTIEN F043","	* classificateur côtes (viande de côtes) : spḥ.t"},
/* 1312F */ { "HIÉROGLYPHE ÉGYPTIEN F044","	* phono-répéteur : ꞽwꜥ\n"
	"	~ 1312F FE03 pivoté de 40 degrés environ [mais pas encore vertical]\n"
	"	~ 1312F FE06 pivoté de 325 degrés environ [horizontal]"},
/* 13130 */ { "HIÉROGLYPHE ÉGYPTIEN F045","	* logogramme (utérus, matrice) : ꞽd.t"},
/* 13131 */ { "HIÉROGLYPHE ÉGYPTIEN F045A","	* phonémogramme : m"},
/* 13132 */ { "HIÉROGLYPHE ÉGYPTIEN F046","	* logogramme (faire le tour, tourner) : pẖr\n"
	"	~ 13132 FE01 pivoté de 180 degrés"},
/* 13133 */ { "HIÉROGLYPHE ÉGYPTIEN F046A","	* version pivotée de 13132\n"
	"	* logogramme (faire le tour, tourner) : pẖr"},
/* 13134 */ { "HIÉROGLYPHE ÉGYPTIEN F047","	* version « miroir » de 13132\n"
	"	* classificateur enroulement, intestin : ḳ(ꜣ)b"},
/* 13135 */ { "HIÉROGLYPHE ÉGYPTIEN F047A","	* version « miroir » de 13133\n"
	"	* logogramme (faire le tour, tourner) : pẖr"},
/* 13136 */ { "HIÉROGLYPHE ÉGYPTIEN F048","	* logogramme (faire le tour, tourner) : pẖr"},
/* 13137 */ { "HIÉROGLYPHE ÉGYPTIEN F049","	* version « miroir » de 13136\n"
	"	* phono-répéteur : wḏb"},
/* 13138 */ { "HIÉROGLYPHE ÉGYPTIEN F050","	* phonémogramme : spẖr"},
/* 13139 */ { "HIÉROGLYPHE ÉGYPTIEN F051","	* phonémogramme : f\n"
	"	~ 13139 FE00 pivoté de 90 degrés\n"
	"	~ 13139 FE01 pivoté de 180 degrés\n"
	"	~ 13139 FE02 pivoté de 270 degrés\n"
	"	~ 13139 FE03 pivoté de 45 degrés environ [vertical]\n"
	"	~ 13139 FE04 pivoté de 135 degrés environ [horizontal]\n"
	"	~ 13139 FE05 pivoté de 225 degrés environ [vertical]\n"
	"	~ 13139 FE06 pivoté de 315 degrés environ [horizontal]"},
/* 1313A */ { "HIÉROGLYPHE ÉGYPTIEN F051A","	* classificateur partie d'un corps : ḥꜥ.w"},
/* 1313B */ { "HIÉROGLYPHE ÉGYPTIEN F051B","	* variante de 1313A\n"
	"	* logogramme (membres, corps) : ḥꜥ.w"},
/* 1313C */ { "HIÉROGLYPHE ÉGYPTIEN F051C","	* version pivotée de 13139"},
/* 1313D */ { "HIÉROGLYPHE ÉGYPTIEN F052","	* classificateur excrément : ḥs"},
/* 1313E */ { "HIÉROGLYPHE ÉGYPTIEN F053","	* phonémogramme : mdw"},
/* 1313F */ { "HIÉROGLYPHE ÉGYPTIEN G001","	* vautour égyptien, alef égyptologique\n"
	"	* à ne pas confondre avec 13142\n"
	"	* translittération en A723\n"
	"	x (lettre hébraïque alef - 05D0)\n"
	"	x (lettre arabe alif hamza en chef - 0623)\n"
	"	* phonémogramme : ꜣ"},
/* 13140 */ { "HIÉROGLYPHE ÉGYPTIEN G002","	* phonémogramme : ꜣꜣ"},
/* 13141 */ { "HIÉROGLYPHE ÉGYPTIEN G003","	* phonémogramme : mꜣ"},
/* 13142 */ { "HIÉROGLYPHE ÉGYPTIEN G004","	* à ne pas confondre avec 1313F\n"
	"	* phonémogramme : tyw"},
/* 13143 */ { "HIÉROGLYPHE ÉGYPTIEN G005","	* logogramme (Horus) : ḥr"},
/* 13144 */ { "HIÉROGLYPHE ÉGYPTIEN G006","	* classificateur faucon : bꞽk"},
/* 13145 */ { "HIÉROGLYPHE ÉGYPTIEN G006A","	* logogramme (seigneur) : nb"},
/* 13146 */ { "HIÉROGLYPHE ÉGYPTIEN G007","	* classificateur êtres divins, choses divines"},
/* 13147 */ { "HIÉROGLYPHE ÉGYPTIEN G007A","	* logogramme (Nemty (divinité)) : nmty"},
/* 13148 */ { "HIÉROGLYPHE ÉGYPTIEN G007B","	* logogramme (Nemty (divinité)) : nmty"},
/* 13149 */ { "HIÉROGLYPHE ÉGYPTIEN G008","	* logogramme (Horus doré) : ḥr-nbw"},
/* 1314A */ { "HIÉROGLYPHE ÉGYPTIEN G009","	* logogramme (Rê-Hor (généralement dans rꜥ-ḥr-ꜣḫ.ty)) : rꜥ-ḥr"},
/* 1314B */ { "HIÉROGLYPHE ÉGYPTIEN G010","	* classificateur barque de Sokar : ḥnw"},
/* 1314C */ { "HIÉROGLYPHE ÉGYPTIEN G011","	* classificateur image de culte : ꜥẖm"},
/* 1314D */ { "HIÉROGLYPHE ÉGYPTIEN G011A",NULL},
/* 1314E */ { "HIÉROGLYPHE ÉGYPTIEN G012","	* classificateur image de culte : ꜥẖm"},
/* 1314F */ { "HIÉROGLYPHE ÉGYPTIEN G013","	* classificateur divinité faucon : spd(.w)"},
/* 13150 */ { "HIÉROGLYPHE ÉGYPTIEN G014","	* logogramme (mère) : mw.t"},
/* 13151 */ { "HIÉROGLYPHE ÉGYPTIEN G015","	* logogramme (mère) : mw.t"},
/* 13152 */ { "HIÉROGLYPHE ÉGYPTIEN G016","	* logogramme (les deux dames (c'est-à-dire Nekhbet et Ouadjet)) : nb.ty"},
/* 13153 */ { "HIÉROGLYPHE ÉGYPTIEN G017","	* phonémogramme : m"},
/* 13154 */ { "HIÉROGLYPHE ÉGYPTIEN G018","	* phonémogramme : mm"},
/* 13155 */ { "HIÉROGLYPHE ÉGYPTIEN G019",NULL},
/* 13156 */ { "HIÉROGLYPHE ÉGYPTIEN G020","	* phonémogramme : m-ꜥ"},
/* 13157 */ { "HIÉROGLYPHE ÉGYPTIEN G020A","	* phonémogramme : mr (ꞽm.y-r)"},
/* 13158 */ { "HIÉROGLYPHE ÉGYPTIEN G021","	* phonémogramme : nḥ"},
/* 13159 */ { "HIÉROGLYPHE ÉGYPTIEN G022","	* phonémogramme : ḏb"},
/* 1315A */ { "HIÉROGLYPHE ÉGYPTIEN G023","	* logogramme (le peuple, les sujets, les gens) : rḫ.yt"},
/* 1315B */ { "HIÉROGLYPHE ÉGYPTIEN G024","	* logogramme (le peuple, les sujets, les gens) : rḫ.yt"},
/* 1315C */ { "HIÉROGLYPHE ÉGYPTIEN G025","	* phonémogramme : ꜣḫ"},
/* 1315D */ { "HIÉROGLYPHE ÉGYPTIEN G026","	* logogramme (Thot) : ḏḥwty"},
/* 1315E */ { "HIÉROGLYPHE ÉGYPTIEN G026A","	* classificateur ibis : hb"},
/* 1315F */ { "HIÉROGLYPHE ÉGYPTIEN G027","	* logogramme (être rouge) : dšr"},
/* 13160 */ { "HIÉROGLYPHE ÉGYPTIEN G028","	* phonémogramme : gm"},
/* 13161 */ { "HIÉROGLYPHE ÉGYPTIEN G029","	* phonémogramme : bꜣ"},
/* 13162 */ { "HIÉROGLYPHE ÉGYPTIEN G030","	* logogramme (âmes) : bꜣ.w"},
/* 13163 */ { "HIÉROGLYPHE ÉGYPTIEN G031","	* classificateur héron : bnw"},
/* 13164 */ { "HIÉROGLYPHE ÉGYPTIEN G032","	* logogramme (inonder) : bꜥḥ"},
/* 13165 */ { "HIÉROGLYPHE ÉGYPTIEN G033","	* phonémogramme : sdꜣ"},
/* 13166 */ { "HIÉROGLYPHE ÉGYPTIEN G034","	* classificateur autruche : nꞽw"},
/* 13167 */ { "HIÉROGLYPHE ÉGYPTIEN G035","	* phonémogramme : ꜥḳ"},
/* 13168 */ { "HIÉROGLYPHE ÉGYPTIEN G036","	* phonémogramme : wr"},
/* 13169 */ { "HIÉROGLYPHE ÉGYPTIEN G036A","	* variante de 13168"},
/* 1316A */ { "HIÉROGLYPHE ÉGYPTIEN G037","	* classificateur négatif, mauvais : ꞽsf.t"},
/* 1316B */ { "HIÉROGLYPHE ÉGYPTIEN G037A","	* variante de 1316A"},
/* 1316C */ { "HIÉROGLYPHE ÉGYPTIEN G038","	* oie\n"
	"	* phonémogramme : gb"},
/* 1316D */ { "HIÉROGLYPHE ÉGYPTIEN G039","	* canard\n"
	"	* logogramme (fils) : sꜣ"},
/* 1316E */ { "HIÉROGLYPHE ÉGYPTIEN G040","	* phonémogramme : pꜣ"},
/* 1316F */ { "HIÉROGLYPHE ÉGYPTIEN G041","	* phonémogramme : ḫn"},
/* 13170 */ { "HIÉROGLYPHE ÉGYPTIEN G042","	* phonémogramme : ḏfꜣ"},
/* 13171 */ { "HIÉROGLYPHE ÉGYPTIEN G043","	* phonémogramme : w"},
/* 13172 */ { "HIÉROGLYPHE ÉGYPTIEN G043A","	* phonémogramme : tw"},
/* 13173 */ { "HIÉROGLYPHE ÉGYPTIEN G044","	* phonémogramme : ww"},
/* 13174 */ { "HIÉROGLYPHE ÉGYPTIEN G045","	* phonémogramme : wꜥ"},
/* 13175 */ { "HIÉROGLYPHE ÉGYPTIEN G045A","	* phonémogramme : dꞽw"},
/* 13176 */ { "HIÉROGLYPHE ÉGYPTIEN G046","	* phonémogramme : mꜣw"},
/* 13177 */ { "HIÉROGLYPHE ÉGYPTIEN G047","	* phonémogramme : ṯꜣ"},
/* 13178 */ { "HIÉROGLYPHE ÉGYPTIEN G048","	* classificateur nid : šš"},
/* 13179 */ { "HIÉROGLYPHE ÉGYPTIEN G049",NULL},
/* 1317A */ { "HIÉROGLYPHE ÉGYPTIEN G050","	* phonémogramme : rḫ.ty"},
/* 1317B */ { "HIÉROGLYPHE ÉGYPTIEN G051","	* classificateur capture du poisson : ḥꜣm"},
/* 1317C */ { "HIÉROGLYPHE ÉGYPTIEN G052","	* classificateur alimentation, nutrition : snm"},
/* 1317D */ { "HIÉROGLYPHE ÉGYPTIEN G053","	* logogramme (âme) : bꜣ"},
/* 1317E */ { "HIÉROGLYPHE ÉGYPTIEN G054","	* phonémogramme : snḏ"},
/* 1317F */ { "HIÉROGLYPHE ÉGYPTIEN H001","	* logogramme (oiseau, volaille) : ꜣpd"},
/* 13180 */ { "HIÉROGLYPHE ÉGYPTIEN H002","	* phono-répéteur : wšm"},
/* 13181 */ { "HIÉROGLYPHE ÉGYPTIEN H003","	* phonémogramme : pꜣḳ"},
/* 13182 */ { "HIÉROGLYPHE ÉGYPTIEN H004","	* classificateur personnes : rmṯ"},
/* 13183 */ { "HIÉROGLYPHE ÉGYPTIEN H005","	* classificateur aile : ḏnḥ\n"
	"	~ 13183 FE02 pivoté de 270 degrés"},
/* 13184 */ { "HIÉROGLYPHE ÉGYPTIEN H006","	* phonémogramme : šw\n"
	"	~ 13184 FE03 pivoté de 25 degrés environ\n"
	"	~ 13184 FE06 pivoté de 335 degrés environ"},
/* 13185 */ { "HIÉROGLYPHE ÉGYPTIEN H006A","	* du hiératique\n"
	"	* phonémogramme : šw"},
/* 13186 */ { "HIÉROGLYPHE ÉGYPTIEN H007","	* classificateur griffe : ꞽꜣf.t"},
/* 13187 */ { "HIÉROGLYPHE ÉGYPTIEN H008","	* logogramme (fils) : sꜣ\n"
	"	~ 13187 FE01 pivoté de 180 degrés"},
/* 13188 */ { "HIÉROGLYPHE ÉGYPTIEN I001","	* phonémogramme : ꜥšꜣ"},
/* 13189 */ { "HIÉROGLYPHE ÉGYPTIEN I002","	* classificateur tortue : štw"},
/* 1318A */ { "HIÉROGLYPHE ÉGYPTIEN I003","	* classificateur agression : ꜣd"},
/* 1318B */ { "HIÉROGLYPHE ÉGYPTIEN I004","	* classificateur Sobek : sbk"},
/* 1318C */ { "HIÉROGLYPHE ÉGYPTIEN I005","	* logogramme (rassembler) : sꜣḳ"},
/* 1318D */ { "HIÉROGLYPHE ÉGYPTIEN I005A","	* classificateur Sobek : sbk"},
/* 1318E */ { "HIÉROGLYPHE ÉGYPTIEN I006","	* phonémogramme : km"},
/* 1318F */ { "HIÉROGLYPHE ÉGYPTIEN I007","	* classificateur divinité : ḥḳ.t"},
/* 13190 */ { "HIÉROGLYPHE ÉGYPTIEN I008","	* logogramme (cent mille) : ḥfn"},
/* 13191 */ { "HIÉROGLYPHE ÉGYPTIEN I009","	* phonémogramme : f"},
/* 13192 */ { "HIÉROGLYPHE ÉGYPTIEN I009A","	* logogramme (aller de l'avant) : prꞽ"},
/* 13193 */ { "HIÉROGLYPHE ÉGYPTIEN I010","	* translittération en 1E0F\n"
	"	* phonémogramme : ḏ"},
/* 13194 */ { "HIÉROGLYPHE ÉGYPTIEN I010A","	* phonémogramme : ḏfꜣ"},
/* 13195 */ { "HIÉROGLYPHE ÉGYPTIEN I011","	* phonémogramme : ḏḏ"},
/* 13196 */ { "HIÉROGLYPHE ÉGYPTIEN I011A","	* logogramme (éternité) : ḏ.t"},
/* 13197 */ { "HIÉROGLYPHE ÉGYPTIEN I012","	* classificateur divinité féminine : nbw.t"},
/* 13198 */ { "HIÉROGLYPHE ÉGYPTIEN I013","	* classificateur divinité féminine (Ouadjet) : wꜣḏ.t"},
/* 13199 */ { "HIÉROGLYPHE ÉGYPTIEN I014","	* classificateur enroulement, sinuosité : ḳꜣb"},
/* 1319A */ { "HIÉROGLYPHE ÉGYPTIEN I015","	* classificateur serpent, uræus : ꞽꜥr.t"},
/* 1319B */ { "HIÉROGLYPHE ÉGYPTIEN K001","	* phonémogramme : ꞽn"},
/* 1319C */ { "HIÉROGLYPHE ÉGYPTIEN K002","	* phono-répéteur : bw\n"
	"	~ 1319C FE03 pivoté de 45 degrés environ"},
/* 1319D */ { "HIÉROGLYPHE ÉGYPTIEN K003","	* logogramme (poisson) : rm\n"
	"	~ 1319D FE03 pivoté de 30 degrés environ"},
/* 1319E */ { "HIÉROGLYPHE ÉGYPTIEN K004","	* phonémogramme : ẖꜣ"},
/* 1319F */ { "HIÉROGLYPHE ÉGYPTIEN K005","	* phono-répéteur : bs\n"
	"	~ 1319F FE03 pivoté de 30 degrés environ"},
/* 131A0 */ { "HIÉROGLYPHE ÉGYPTIEN K006","	* logogramme (écaille) : nšm.t\n"
	"	~ 131A0 FE00 pivoté de 90 degrés\n"
	"	~ 131A0 FE02 pivoté de 270 degrés"},
/* 131A1 */ { "HIÉROGLYPHE ÉGYPTIEN K007","	* classificateur rage, colère : špt"},
/* 131A2 */ { "HIÉROGLYPHE ÉGYPTIEN K008","	* classificateur poisson-chat : nꜥr"},
/* 131A3 */ { "HIÉROGLYPHE ÉGYPTIEN L001","	* logogramme (devenir) : ḫpr"},
/* 131A4 */ { "HIÉROGLYPHE ÉGYPTIEN L002","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 131A5 */ { "HIÉROGLYPHE ÉGYPTIEN L002A","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 131A6 */ { "HIÉROGLYPHE ÉGYPTIEN L003","	x (hiéroglyphe égyptien-13dee - 13DEE)"},
/* 131A7 */ { "HIÉROGLYPHE ÉGYPTIEN L004","	* classificateur criquet : snḥm"},
/* 131A8 */ { "HIÉROGLYPHE ÉGYPTIEN L005","	* classificateur mille-pattes : spꜣ"},
/* 131A9 */ { "HIÉROGLYPHE ÉGYPTIEN L006","	* phonémogramme : ḫꜣ"},
/* 131AA */ { "HIÉROGLYPHE ÉGYPTIEN L006A","	* version « miroir » de 131A9"},
/* 131AB */ { "HIÉROGLYPHE ÉGYPTIEN L007","	* classificateur scorpion : srḳ.t"},
/* 131AC */ { "HIÉROGLYPHE ÉGYPTIEN L008","	* logogramme/phonémogramme (type de scarabée) : ꜥnḫ"},
/* 131AD */ { "HIÉROGLYPHE ÉGYPTIEN M001","	* classificateur arbre, produit d'un arbre : ꜥš"},
/* 131AE */ { "HIÉROGLYPHE ÉGYPTIEN M001A","	* classificateur produit d'un arbre : hbny"},
/* 131AF */ { "HIÉROGLYPHE ÉGYPTIEN M001B","	* phonémogramme : ꞽm=f"},
/* 131B0 */ { "HIÉROGLYPHE ÉGYPTIEN M002","	* phonémogramme : ḥn"},
/* 131B1 */ { "HIÉROGLYPHE ÉGYPTIEN M003","	* phonémogramme : ḫt\n"
	"	~ 131B1 FE00 pivoté de 90 degrés\n"
	"	~ 131B1 FE01 pivoté de 180 degrés\n"
	"	~ 131B1 FE03 pivoté de 45 degrés environ"},
/* 131B2 */ { "HIÉROGLYPHE ÉGYPTIEN M003A","	* phonémogramme : m-ḫt"},
/* 131B3 */ { "HIÉROGLYPHE ÉGYPTIEN M004","	* logogramme (année) : rnp.t"},
/* 131B4 */ { "HIÉROGLYPHE ÉGYPTIEN M005","	* logogramme (temps, saison) : tr"},
/* 131B5 */ { "HIÉROGLYPHE ÉGYPTIEN M006","	* logogramme (temps, saison) : tr"},
/* 131B6 */ { "HIÉROGLYPHE ÉGYPTIEN M007","	* classificateur jeunesse, vigueur, fraîcheur : rnp"},
/* 131B7 */ { "HIÉROGLYPHE ÉGYPTIEN M008","	* phonémogramme : šꜣ"},
/* 131B8 */ { "HIÉROGLYPHE ÉGYPTIEN M009","	* classificateur fleur de lotus : sšn\n"
	"	~ 131B8 FE00 pivoté de 90 degrés"},
/* 131B9 */ { "HIÉROGLYPHE ÉGYPTIEN M010","	* classificateur bouton de lotus : nḥb.t\n"
	"	~ 131B9 FE00 pivoté de 90 degrés"},
/* 131BA */ { "HIÉROGLYPHE ÉGYPTIEN M010A","	* classificateur offrande : wdn\n"
	"	~ 131BA FE02 pivoté de 270 degrés"},
/* 131BB */ { "HIÉROGLYPHE ÉGYPTIEN M011","	* logogramme (offrir) : wdn"},
/* 131BC */ { "HIÉROGLYPHE ÉGYPTIEN M012","	* 1.000\n"
	"	* phonémogramme : ḫꜣ"},
/* 131BD */ { "HIÉROGLYPHE ÉGYPTIEN M012A","	* 2.000"},
/* 131BE */ { "HIÉROGLYPHE ÉGYPTIEN M012B","	* 3.000"},
/* 131BF */ { "HIÉROGLYPHE ÉGYPTIEN M012C","	* 4.000"},
/* 131C0 */ { "HIÉROGLYPHE ÉGYPTIEN M012D","	* 5.000"},
/* 131C1 */ { "HIÉROGLYPHE ÉGYPTIEN M012E","	* 6.000"},
/* 131C2 */ { "HIÉROGLYPHE ÉGYPTIEN M012F","	* 7.000"},
/* 131C3 */ { "HIÉROGLYPHE ÉGYPTIEN M012G","	* 8.000"},
/* 131C4 */ { "HIÉROGLYPHE ÉGYPTIEN M012H","	* 9.000"},
/* 131C5 */ { "HIÉROGLYPHE ÉGYPTIEN M013","	* phonémogramme : wꜣḏ"},
/* 131C6 */ { "HIÉROGLYPHE ÉGYPTIEN M014","	* phonémogramme : wꜣḏ"},
/* 131C7 */ { "HIÉROGLYPHE ÉGYPTIEN M015","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 131C8 */ { "HIÉROGLYPHE ÉGYPTIEN M015A","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 131C9 */ { "HIÉROGLYPHE ÉGYPTIEN M016","	* phonémogramme : ḥꜣ"},
/* 131CA */ { "HIÉROGLYPHE ÉGYPTIEN M016A","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 131CB */ { "HIÉROGLYPHE ÉGYPTIEN M017","	* yod égyptologique\n"
	"	* translittération en A7BD\n"
	"	x (lettre hébraïque yod - 05D9)\n"
	"	x (lettre arabe ya' - 064A)\n"
	"	* phonémogramme : ꞽ\n"
	"	~ 131CB FE00 pivoté de 90 degrés"},
/* 131CC */ { "HIÉROGLYPHE ÉGYPTIEN M017A","	x (hiéroglyphe égyptien z004 - 133ED)\n"
	"	* phonémogramme : y"},
/* 131CD */ { "HIÉROGLYPHE ÉGYPTIEN M018","	* phonémogramme/logogramme (venir) : ꞽy(ꞽ)"},
/* 131CE */ { "HIÉROGLYPHE ÉGYPTIEN M019","	* phonémogramme : ꜥꜣb"},
/* 131CF */ { "HIÉROGLYPHE ÉGYPTIEN M020","	* logogramme (marécage, campagne) : sḫ.t"},
/* 131D0 */ { "HIÉROGLYPHE ÉGYPTIEN M021","	* logogramme (herbe, plante) : sm"},
/* 131D1 */ { "HIÉROGLYPHE ÉGYPTIEN M022","	* classificateur bourgeon, bouton de lotus\n"
	"	* phonémogramme : nḫb"},
/* 131D2 */ { "HIÉROGLYPHE ÉGYPTIEN M022A","	* phonémogramme : nn"},
/* 131D3 */ { "HIÉROGLYPHE ÉGYPTIEN M023","	* logogramme (roi de Haute-Égypte) : n(.y)-sw.t"},
/* 131D4 */ { "HIÉROGLYPHE ÉGYPTIEN M024","	* phonémogramme : rsw/rsy"},
/* 131D5 */ { "HIÉROGLYPHE ÉGYPTIEN M024A","	* logogramme (terre) : tꜣ"},
/* 131D6 */ { "HIÉROGLYPHE ÉGYPTIEN M025","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 131D7 */ { "HIÉROGLYPHE ÉGYPTIEN M026","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 131D8 */ { "HIÉROGLYPHE ÉGYPTIEN M027","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 131D9 */ { "HIÉROGLYPHE ÉGYPTIEN M028","	* logogramme (les dix de Haute-Égypte) : mḏ-šmꜥ.w"},
/* 131DA */ { "HIÉROGLYPHE ÉGYPTIEN M028A","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 131DB */ { "HIÉROGLYPHE ÉGYPTIEN M029","	* logogramme (être doux) : nḏm\n"
	"	~ 131DB FE03 pivoté de 20 degrés environ\n"
	"	~ 131DB FE06 pivoté de 340 degrés environ"},
/* 131DC */ { "HIÉROGLYPHE ÉGYPTIEN M030","	* logogramme (être doux) : bnr/bnꞽ"},
/* 131DD */ { "HIÉROGLYPHE ÉGYPTIEN M031","	* classificateur croissance : srd"},
/* 131DE */ { "HIÉROGLYPHE ÉGYPTIEN M031A","	* classificateur croissance : srd"},
/* 131DF */ { "HIÉROGLYPHE ÉGYPTIEN M032","	* classificateur croissance : rd"},
/* 131E0 */ { "HIÉROGLYPHE ÉGYPTIEN M033","	* logogramme (céréales, orge, blé) : ꞽt\n"
	"	~ 131E0 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 131E1 */ { "HIÉROGLYPHE ÉGYPTIEN M033A","	* variante de 131E0\n"
	"	* classificateur céréales, orge, blé : ꞽt"},
/* 131E2 */ { "HIÉROGLYPHE ÉGYPTIEN M033B","	* variante de 131E0\n"
	"	* classificateur céréales, orge, blé : tbtb"},
/* 131E3 */ { "HIÉROGLYPHE ÉGYPTIEN M034","	* logogramme (épeautre) : bd.t"},
/* 131E4 */ { "HIÉROGLYPHE ÉGYPTIEN M035","	* classificateur tas, quantité : ꜥḥꜥ"},
/* 131E5 */ { "HIÉROGLYPHE ÉGYPTIEN M036","	* phonémogramme : ḏr"},
/* 131E6 */ { "HIÉROGLYPHE ÉGYPTIEN M037","	* variante plus ancienne de 131E5\n"
	"	* phonémogramme : ḏr"},
/* 131E7 */ { "HIÉROGLYPHE ÉGYPTIEN M038","	* classificateur lin : ḥmꜥ"},
/* 131E8 */ { "HIÉROGLYPHE ÉGYPTIEN M039","	* classificateur produit granulaire : snṯr"},
/* 131E9 */ { "HIÉROGLYPHE ÉGYPTIEN M040","	* à ne pas confondre avec 132A7 ou 1342A\n"
	"	* phonémogramme : ꞽs"},
/* 131EA */ { "HIÉROGLYPHE ÉGYPTIEN M040A","	* phonémogramme : ꞽs"},
/* 131EB */ { "HIÉROGLYPHE ÉGYPTIEN M041","	* classificateur bois, bois d'œuvre : ꜥš"},
/* 131EC */ { "HIÉROGLYPHE ÉGYPTIEN M042","	* phonémogramme : wn"},
/* 131ED */ { "HIÉROGLYPHE ÉGYPTIEN M043","	* logogramme (vin) : ꞽrp"},
/* 131EE */ { "HIÉROGLYPHE ÉGYPTIEN M044","	* épine\n"
	"	* à ne pas confondre avec 133DA\n"
	"	* phonémogramme : spd\n"
	"	~ 131EE FE01 pivoté de 180 degrés\n"
	"	~ 131EE FE02 pivoté de 270 degrés\n"
	"	~ 131EE FE06 pivoté de 330 degrés environ"},
/* 131EF */ { "HIÉROGLYPHE ÉGYPTIEN N001","	* logogramme (ciel) : p.t"},
/* 131F0 */ { "HIÉROGLYPHE ÉGYPTIEN N002","	* classificateur nuit : grḥ"},
/* 131F1 */ { "HIÉROGLYPHE ÉGYPTIEN N003","	* variante plus ancienne de 131F0\n"
	"	* classificateur nuit : grḥ"},
/* 131F2 */ { "HIÉROGLYPHE ÉGYPTIEN N004","	* classificateur tempête : sšn"},
/* 131F3 */ { "HIÉROGLYPHE ÉGYPTIEN N005","	* à ne pas confondre avec 13082 ou 133F8\n"
	"	* logogramme (soleil, Rê) : rꜥ"},
/* 131F4 */ { "HIÉROGLYPHE ÉGYPTIEN N006","	* logogramme (soleil, Rê) : rꜥ"},
/* 131F5 */ { "HIÉROGLYPHE ÉGYPTIEN N007","	* logogramme (cours (du jour), besoins quotidiens) : ẖr.t-hrw"},
/* 131F6 */ { "HIÉROGLYPHE ÉGYPTIEN N008","	* classificateur lumière, brillant, croissant : psḏ"},
/* 131F7 */ { "HIÉROGLYPHE ÉGYPTIEN N009","	* variante de 131F8\n"
	"	* phonémogramme : psḏ"},
/* 131F8 */ { "HIÉROGLYPHE ÉGYPTIEN N010","	* variante de 131F7\n"
	"	* phonémogramme : psḏ\n"
	"	~ 131F8 FE01 pivoté de 180 degrés"},
/* 131F9 */ { "HIÉROGLYPHE ÉGYPTIEN N011","	* logogramme (mois) : ꜣbd\n"
	"	~ 131F9 FE00 pivoté de 90 degrés\n"
	"	~ 131F9 FE01 pivoté de 180 degrés"},
/* 131FA */ { "HIÉROGLYPHE ÉGYPTIEN N012","	* classificateur lune : ꞽꜥḥ\n"
	"	~ 131FA FE00 pivoté de 90 degrés\n"
	"	~ 131FA FE01 pivoté de 180 degrés"},
/* 131FB */ { "HIÉROGLYPHE ÉGYPTIEN N013","	* logogramme ((fête du) milieu du mois) : smd.t"},
/* 131FC */ { "HIÉROGLYPHE ÉGYPTIEN N014","	* logogramme (étoile) : sbꜣ"},
/* 131FD */ { "HIÉROGLYPHE ÉGYPTIEN N015","	* classificateur monde souterrain : dwꜣ.t"},
/* 131FE */ { "HIÉROGLYPHE ÉGYPTIEN N016","	* logogramme (terre) : tꜣ"},
/* 131FF */ { "HIÉROGLYPHE ÉGYPTIEN N017","	* variante de 131FE\n"
	"	* logogramme (terre) : tꜣ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_32[] = {
/* 13200 */ { "HIÉROGLYPHE ÉGYPTIEN N018","	* à ne pas confondre avec 132F0, 133D4 ou 133F3\n"
	"	* logogramme (île) : ꞽw"},
/* 13201 */ { "HIÉROGLYPHE ÉGYPTIEN N018A","	* phonémogramme : ꞽmn"},
/* 13202 */ { "HIÉROGLYPHE ÉGYPTIEN N018B",NULL},
/* 13203 */ { "HIÉROGLYPHE ÉGYPTIEN N019","	* logogramme (habitant de l'horizon) : ꜣḫ.ty"},
/* 13204 */ { "HIÉROGLYPHE ÉGYPTIEN N020","	* classificateur rive de fleuve : wḏb"},
/* 13205 */ { "HIÉROGLYPHE ÉGYPTIEN N021","	* logogramme (rive de fleuve) : ꞽdb\n"
	"	~ 13205 FE03 pivoté de 30 degrés environ [mais pas encore vertical]\n"
	"	~ 13205 FE06 pivoté de 330 degrés environ [horizontal]"},
/* 13206 */ { "HIÉROGLYPHE ÉGYPTIEN N022","	* logogramme (rive de fleuve) : ꞽdb"},
/* 13207 */ { "HIÉROGLYPHE ÉGYPTIEN N023","	* classificateur localisation géographique : dmꞽ"},
/* 13208 */ { "HIÉROGLYPHE ÉGYPTIEN N024","	* logogramme (nome, district) : spꜣ.t"},
/* 13209 */ { "HIÉROGLYPHE ÉGYPTIEN N025","	* classificateur terre étrangère, désert : ḫꜣs.t"},
/* 1320A */ { "HIÉROGLYPHE ÉGYPTIEN N025A","	* variante de 13209"},
/* 1320B */ { "HIÉROGLYPHE ÉGYPTIEN N026","	* phonémogramme : ḏw"},
/* 1320C */ { "HIÉROGLYPHE ÉGYPTIEN N027","	* logogramme (horizon) : ꜣḫ.t"},
/* 1320D */ { "HIÉROGLYPHE ÉGYPTIEN N028","	* phonémogramme : ḫꜥ"},
/* 1320E */ { "HIÉROGLYPHE ÉGYPTIEN N029","	* colline\n"
	"	* à ne pas confondre avec 133D8\n"
	"	* translittération en q ou en A723\n"
	"	x (lettre hébraïque qouf - 05E7)\n"
	"	x (lettre arabe qaf - 0642)\n"
	"	* phonémogramme : ḳ"},
/* 1320F */ { "HIÉROGLYPHE ÉGYPTIEN N030","	* logogramme (colline, monticule) : ꞽꜣ.t"},
/* 13210 */ { "HIÉROGLYPHE ÉGYPTIEN N031","	* logogramme (route) : wꜣ.t"},
/* 13211 */ { "HIÉROGLYPHE ÉGYPTIEN N032","	* classificateur argile : sꞽn"},
/* 13212 */ { "HIÉROGLYPHE ÉGYPTIEN N033","	* à ne pas confondre avec 130C9\n"
	"	* classificateur médicaments, encens, huile : snṯr"},
/* 13213 */ { "HIÉROGLYPHE ÉGYPTIEN N033A","	* à ne pas confondre avec 133E7\n"
	"	* classificateur médicaments, encens, huile : ꜥn.tyw"},
/* 13214 */ { "HIÉROGLYPHE ÉGYPTIEN N034","	* classificateur objets métalliques : ꞽḳḥ.w"},
/* 13215 */ { "HIÉROGLYPHE ÉGYPTIEN N034A","	* variante de 13214\n"
	"	* logogramme (métal) : bꞽꜣ"},
/* 13216 */ { "HIÉROGLYPHE ÉGYPTIEN N035","	* phonémogramme : n\n"
	"	~ 13216 FE02 pivoté de 270 degrés"},
/* 13217 */ { "HIÉROGLYPHE ÉGYPTIEN N035A","	* logogramme (eau) : mw"},
/* 13218 */ { "HIÉROGLYPHE ÉGYPTIEN N036","	* phonémogramme : mr"},
/* 13219 */ { "HIÉROGLYPHE ÉGYPTIEN N037","	* lac\n"
	"	* translittération en 0161\n"
	"	* à ne pas confondre avec 1328C\n"
	"	* phonémogramme : š"},
/* 1321A */ { "HIÉROGLYPHE ÉGYPTIEN N037A","	* variante de 13219\n"
	"	* phonémogramme : š"},
/* 1321B */ { "HIÉROGLYPHE ÉGYPTIEN N038","	* variante de 13219\n"
	"	* phonémogramme : š"},
/* 1321C */ { "HIÉROGLYPHE ÉGYPTIEN N039","	* variante de 13219\n"
	"	* phonémogramme : š"},
/* 1321D */ { "HIÉROGLYPHE ÉGYPTIEN N040","	* logogramme (aller) : šm"},
/* 1321E */ { "HIÉROGLYPHE ÉGYPTIEN N041","	* phonémogramme : ḥm"},
/* 1321F */ { "HIÉROGLYPHE ÉGYPTIEN N042","	* variante de 1321E\n"
	"	* phonémogramme : ḥm"},
/* 13220 */ { "HIÉROGLYPHE ÉGYPTIEN NL001","	* logogramme (nome de la Muraille blanche, 1er nome de Basse-Égypte)) : ꞽnb-ḥḏ"},
/* 13221 */ { "HIÉROGLYPHE ÉGYPTIEN NL002","	* logogramme (nome de la Cuisse, 2e nome de Basse-Égypte) : ḫm/ḫpš/ꞽwꜥ"},
/* 13222 */ { "HIÉROGLYPHE ÉGYPTIEN NL003","	* logogramme (nome de l'Occident, 3e nome de Basse-Égypte) : ꞽmn.tt"},
/* 13223 */ { "HIÉROGLYPHE ÉGYPTIEN NL004","	* logogramme (nome inférieur de Neith, 4e nome de Basse-Égypte) : n.t-rs.yt"},
/* 13224 */ { "HIÉROGLYPHE ÉGYPTIEN NL005","	* logogramme (nome supérieur de Neith, 5e nome de Basse-Égypte) : n.t-mḥ.yt"},
/* 13225 */ { "HIÉROGLYPHE ÉGYPTIEN NL005A","	* logogramme (nome supérieur de Neith, 5e nome de Basse-Égypte) : n.t-mḥ.yt"},
/* 13226 */ { "HIÉROGLYPHE ÉGYPTIEN NL006","	* logogramme (nome du Taureau de la montagne, 6e nome de Basse-Égypte) : ḫꜣsw.w"},
/* 13227 */ { "HIÉROGLYPHE ÉGYPTIEN NL007","	* logogramme (nome du Harpon à cordes côté occidental, 7e nome de Basse-Égypte) : wꜥ-m-ḥww-ꞽmn.ty"},
/* 13228 */ { "HIÉROGLYPHE ÉGYPTIEN NL008","	* logogramme (nome du Harpon à cordes côté oriental, 8e nome de Basse-Égypte) : wꜥ-m-ḥww-ꞽꜣb.ty"},
/* 13229 */ { "HIÉROGLYPHE ÉGYPTIEN NL009","	* logogramme (nome d'Andjety, 9e nome de Basse-Égypte) : ꜥnḏ.ty"},
/* 1322A */ { "HIÉROGLYPHE ÉGYPTIEN NL010","	* logogramme (nome du Taureau noir, 10e nome de Basse-Égypte) : km-wr"},
/* 1322B */ { "HIÉROGLYPHE ÉGYPTIEN NL011","	* logogramme (nome du Taureau recensé, 11e nome de Basse-Égypte) : ḥsbw"},
/* 1322C */ { "HIÉROGLYPHE ÉGYPTIEN NL012","	* logogramme (nome du Veau divin, 12e nome de Basse-Égypte) : ṯb-nṯr"},
/* 1322D */ { "HIÉROGLYPHE ÉGYPTIEN NL013","	* logogramme (nome du Sceptre intact, 13e nome de Basse-Égypte) : ḥḳꜣ-ꜥnḏ.w"},
/* 1322E */ { "HIÉROGLYPHE ÉGYPTIEN NL014","	* logogramme (nome du Dressoir oriental, 14e nome de Basse-Égypte) : ḫnt.y-ꞽꜣb.ty"},
/* 1322F */ { "HIÉROGLYPHE ÉGYPTIEN NL015","	* logogramme (nome de l'Ibis, 15e nome de Basse-Égypte) : ḏhwty"},
/* 13230 */ { "HIÉROGLYPHE ÉGYPTIEN NL016","	* logogramme (nome du Dauphin, 16e nome de Basse-Égypte) : ḥꜣ.t-mḥ.yt"},
/* 13231 */ { "HIÉROGLYPHE ÉGYPTIEN NL017","	* logogramme (nome du Trône, 17e nome de Basse-Égypte) : bḥd.t"},
/* 13232 */ { "HIÉROGLYPHE ÉGYPTIEN NL017A","	* logogramme (nome du Trône, 17e nome de Basse-Égypte) : smꜣ-bḥd.t"},
/* 13233 */ { "HIÉROGLYPHE ÉGYPTIEN NL018",NULL},
/* 13234 */ { "HIÉROGLYPHE ÉGYPTIEN NL019",NULL},
/* 13235 */ { "HIÉROGLYPHE ÉGYPTIEN NL020",NULL},
/* 13236 */ { "HIÉROGLYPHE ÉGYPTIEN NU001","	* logogramme (nome du Pays de Nubie, 1er nome de Haute-Égypte) : tꜣ-sty"},
/* 13237 */ { "HIÉROGLYPHE ÉGYPTIEN NU002","	* logogramme (nome du Trône d'Horus, 2e nome de Haute-Égypte) : wṯs-ḥr"},
/* 13238 */ { "HIÉROGLYPHE ÉGYPTIEN NU003","	* logogramme (nome de la Forteresse, 3e nome de Haute-Égypte) : nḫn"},
/* 13239 */ { "HIÉROGLYPHE ÉGYPTIEN NU004","	* logogramme (Thèbes) : wꜣs.t"},
/* 1323A */ { "HIÉROGLYPHE ÉGYPTIEN NU005","	* logogramme (nome des Deux Divinités, 5e nome de Haute-Égypte) : nṯr.wy"},
/* 1323B */ { "HIÉROGLYPHE ÉGYPTIEN NU006","	* logogramme (nome du Crocodile, 6e nome de Haute-Égypte) : ꞽḳr"},
/* 1323C */ { "HIÉROGLYPHE ÉGYPTIEN NU007","	* logogramme (nome de la Bât, 7e nome de Haute-Égypte) : bꜣ.t"},
/* 1323D */ { "HIÉROGLYPHE ÉGYPTIEN NU008","	* logogramme (nome de la Grande Terre, 8e nome de Haute-Égypte) : tꜣ-wr"},
/* 1323E */ { "HIÉROGLYPHE ÉGYPTIEN NU009","	* logogramme (nome de Min, 9e nome de Haute-Égypte) : mnw"},
/* 1323F */ { "HIÉROGLYPHE ÉGYPTIEN NU010","	* logogramme (nome du Cobra, 10e nome de Haute-Égypte) : wꜣḏ.t"},
/* 13240 */ { "HIÉROGLYPHE ÉGYPTIEN NU010A","	* logogramme (nome du Cobra, 10e nome de Haute-Égypte) : wꜣḏ.t"},
/* 13241 */ { "HIÉROGLYPHE ÉGYPTIEN NU011","	* logogramme (nome de Seth, 11e nome de Haute-Égypte) : šꜣ/stẖ/stš"},
/* 13242 */ { "HIÉROGLYPHE ÉGYPTIEN NU011A","	* logogramme (nome de Seth, 11e nome de Haute-Égypte (communément sous stẖ/stš/šꜣ)) : ḥw-n.t"},
/* 13243 */ { "HIÉROGLYPHE ÉGYPTIEN NU012","	* logogramme (nome de la Vipère de montagne, 12e nome de Haute-Égypte) : ꜣtf.t"},
/* 13244 */ { "HIÉROGLYPHE ÉGYPTIEN NU013","	* logogramme (nome supérieur du Sycomore, 13e nome de Haute-Égypte) : nḏf.t-ḫnt.t"},
/* 13245 */ { "HIÉROGLYPHE ÉGYPTIEN NU014","	* logogramme (nome inférieur du Sycomore, 14e nome de Haute-Égypte) : nḏf.t-pḥ.t"},
/* 13246 */ { "HIÉROGLYPHE ÉGYPTIEN NU015","	* logogramme (nome du Lièvre, 15e nome de Haute-Égypte) : wnw.t"},
/* 13247 */ { "HIÉROGLYPHE ÉGYPTIEN NU016","	* logogramme (nome de l'Oryx, 16e nome de Haute-Égypte) : mꜣ-ḥḏ"},
/* 13248 */ { "HIÉROGLYPHE ÉGYPTIEN NU017","	* logogramme (nome du Chacal, 17e nome de Haute-Égypte) : ꞽnpw.t"},
/* 13249 */ { "HIÉROGLYPHE ÉGYPTIEN NU018","	* logogramme (nome du Faucon aux ailes déployées, 18e nome de Haute-Égypte, aussi connu sous le nom de nmty) : dwn-ꜥn.wy"},
/* 1324A */ { "HIÉROGLYPHE ÉGYPTIEN NU018A",NULL},
/* 1324B */ { "HIÉROGLYPHE ÉGYPTIEN NU019","	* logogramme (nome des Deux Sceptres, 19e nome de Haute-Égypte) : bw-ꞽgꜣꞽ"},
/* 1324C */ { "HIÉROGLYPHE ÉGYPTIEN NU020","	* logogramme (Naret, nome supérieur du Laurier-Rose, 20e nome de Haute-Égypte) : nꜥr.t-ḫnt.t"},
/* 1324D */ { "HIÉROGLYPHE ÉGYPTIEN NU021","	* logogramme (nome inférieur du Laurier-Rose, 21e nome de Haute-Égypte) : nꜥr.t-pḥ.t"},
/* 1324E */ { "HIÉROGLYPHE ÉGYPTIEN NU022","	* logogramme (nome du Couteau, 22e nome de Haute-Égypte) : mdnꞽ.t"},
/* 1324F */ { "HIÉROGLYPHE ÉGYPTIEN NU022A","	* logogramme (nome du Couteau, 22e nome de Haute-Égypte) : mdnꞽ.t"},
/* 13250 */ { "HIÉROGLYPHE ÉGYPTIEN O001","	* logogramme (maison, domaine) : pr"},
/* 13251 */ { "HIÉROGLYPHE ÉGYPTIEN O001A","	* logogramme (scriptorium, école (maison de vie)) : pr-ꜥnḫ"},
/* 13252 */ { "HIÉROGLYPHE ÉGYPTIEN O002","	* logogramme (trésor) : pr-ḥḏ"},
/* 13253 */ { "HIÉROGLYPHE ÉGYPTIEN O003","	* logogramme (offrande d'invocation) : pr.t-ḫrw"},
/* 13254 */ { "HIÉROGLYPHE ÉGYPTIEN O004","	x (lettre hébraïque hè - 05D4)\n"
	"	x (lettre arabe hé' - 0647)\n"
	"	* phonémogramme : h"},
/* 13255 */ { "HIÉROGLYPHE ÉGYPTIEN O005","	* phonémogramme : nm"},
/* 13256 */ { "HIÉROGLYPHE ÉGYPTIEN O005A","	* version « miroir » de 13255"},
/* 13257 */ { "HIÉROGLYPHE ÉGYPTIEN O006","	* logogramme (temple, manoir, domaine) : ḥw.t\n"
	"	~ 13257 FE01 pivoté de 180 degrés"},
/* 13258 */ { "HIÉROGLYPHE ÉGYPTIEN O006A","	* début d'enceinte hwt ou serekh\n"
	"	x (hiéroglyphe égyptien o033a - 13282)"},
/* 13259 */ { "HIÉROGLYPHE ÉGYPTIEN O006B","	* début d'enceinte hwt basse"},
/* 1325A */ { "HIÉROGLYPHE ÉGYPTIEN O006C","	* début d'enceinte hwt haute"},
/* 1325B */ { "HIÉROGLYPHE ÉGYPTIEN O006D","	* fin d'enceinte hwt haute"},
/* 1325C */ { "HIÉROGLYPHE ÉGYPTIEN O006E","	* fin d'enceinte hwt basse"},
/* 1325D */ { "HIÉROGLYPHE ÉGYPTIEN O006F","	* fin d'enceinte hwt"},
/* 1325E */ { "HIÉROGLYPHE ÉGYPTIEN O007","	* logogramme (temple, manoir, domaine) : ḥw.t"},
/* 1325F */ { "HIÉROGLYPHE ÉGYPTIEN O008","	* logogramme (le grand domaine, temple) : ḥw.t-ꜥꜣ.t"},
/* 13260 */ { "HIÉROGLYPHE ÉGYPTIEN O009","	* logogramme (Nephtys (divinité)) : nb.t-ḥw.t"},
/* 13261 */ { "HIÉROGLYPHE ÉGYPTIEN O010","	* logogramme (Hathor (divinité)) : ḥw.t-ḥr"},
/* 13262 */ { "HIÉROGLYPHE ÉGYPTIEN O010A","	* logogramme (manoir de vie) : ḥw.t-ꜥnḫ"},
/* 13263 */ { "HIÉROGLYPHE ÉGYPTIEN O010B",NULL},
/* 13264 */ { "HIÉROGLYPHE ÉGYPTIEN O010C",NULL},
/* 13265 */ { "HIÉROGLYPHE ÉGYPTIEN O011","	* logogramme (palais) : ꜥḥ"},
/* 13266 */ { "HIÉROGLYPHE ÉGYPTIEN O012","	* logogramme (palais) : ꜥḥ"},
/* 13267 */ { "HIÉROGLYPHE ÉGYPTIEN O013","	* classificateur enfermant, clôturant, emmurant : sbḫ"},
/* 13268 */ { "HIÉROGLYPHE ÉGYPTIEN O014","	* classificateur porte d'entrée : sbḫ.t"},
/* 13269 */ { "HIÉROGLYPHE ÉGYPTIEN O015","	* logogramme (cour) : wsḫ.t"},
/* 1326A */ { "HIÉROGLYPHE ÉGYPTIEN O016","	* logogramme (portail, portique) : sbḫ.t"},
/* 1326B */ { "HIÉROGLYPHE ÉGYPTIEN O017","	* phonémogramme : tꜣ"},
/* 1326C */ { "HIÉROGLYPHE ÉGYPTIEN O018","	* classificateur sanctuaire, chapelle : kꜣr"},
/* 1326D */ { "HIÉROGLYPHE ÉGYPTIEN O019","	* classificateur sanctuaire : pr-wr"},
/* 1326E */ { "HIÉROGLYPHE ÉGYPTIEN O019A","	* logogramme (sanctuaire, rangée de sanctuaires) : ꞽtr.t"},
/* 1326F */ { "HIÉROGLYPHE ÉGYPTIEN O020","	* classificateur sanctuaire, temple : ꞽtr.ty"},
/* 13270 */ { "HIÉROGLYPHE ÉGYPTIEN O020A","	* variante de 1326F"},
/* 13271 */ { "HIÉROGLYPHE ÉGYPTIEN O021","	* logogramme (pavillon, salle, cabine) : sḥ"},
/* 13272 */ { "HIÉROGLYPHE ÉGYPTIEN O022","	* classificateur cabine : sḥ"},
/* 13273 */ { "HIÉROGLYPHE ÉGYPTIEN O023","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13274 */ { "HIÉROGLYPHE ÉGYPTIEN O024","	* classificateur pyramide, tombe : mr"},
/* 13275 */ { "HIÉROGLYPHE ÉGYPTIEN O024A","	* classificateur temple solaire : sḫ.t-rꜥ"},
/* 13276 */ { "HIÉROGLYPHE ÉGYPTIEN O025","	* classificateur obélisque : tḫn"},
/* 13277 */ { "HIÉROGLYPHE ÉGYPTIEN O025A","	* classificateur temple solaire : nḫn-rꜥ"},
/* 13278 */ { "HIÉROGLYPHE ÉGYPTIEN O026","	* classificateur stèle : wḏ"},
/* 13279 */ { "HIÉROGLYPHE ÉGYPTIEN O027","	* classificateur salle, bureau : ḫꜣ"},
/* 1327A */ { "HIÉROGLYPHE ÉGYPTIEN O028","	* phonémogramme : ꞽwn"},
/* 1327B */ { "HIÉROGLYPHE ÉGYPTIEN O029","	* phonémogramme : ꜥꜣ\n"
	"	~ 1327B FE00 pivoté de 90 degrés\n"
	"	~ 1327B FE02 pivoté de 270 degrés"},
/* 1327C */ { "HIÉROGLYPHE ÉGYPTIEN O029A","	* version pivotée de 1327B\n"
	"	* phonémogramme : ꜥꜣ"},
/* 1327D */ { "HIÉROGLYPHE ÉGYPTIEN O030","	* à ne pas confondre avec 13361\n"
	"	* logogramme (poteau, support) : sḫn.t"},
/* 1327E */ { "HIÉROGLYPHE ÉGYPTIEN O030A",NULL},
/* 1327F */ { "HIÉROGLYPHE ÉGYPTIEN O031","	* logogramme (portail) : ꜥꜣ\n"
	"	~ 1327F FE00 pivoté de 90 degrés\n"
	"	~ 1327F FE01 pivoté de 180 degrés"},
/* 13280 */ { "HIÉROGLYPHE ÉGYPTIEN O032","	* classificateur porte d'entrée : sbꜣ"},
/* 13281 */ { "HIÉROGLYPHE ÉGYPTIEN O033","	* classificateur façade du palais : srḫ"},
/* 13282 */ { "HIÉROGLYPHE ÉGYPTIEN O033A","	* fin d'enceinte serekh\n"
	"	x (hiéroglyphe égyptien o006a - 13258)"},
/* 13283 */ { "HIÉROGLYPHE ÉGYPTIEN O034","	x (hiéroglyphe égyptien s029 - 132F4)\n"
	"	* phonémogramme : s"},
/* 13284 */ { "HIÉROGLYPHE ÉGYPTIEN O035","	* phonémogramme : ꞽs"},
/* 13285 */ { "HIÉROGLYPHE ÉGYPTIEN O036","	* logogramme (mur) : ꞽnb\n"
	"	~ 13285 FE00 pivoté de 90 degrés"},
/* 13286 */ { "HIÉROGLYPHE ÉGYPTIEN O036A","	* début de cartouche à mur fortifié"},
/* 13287 */ { "HIÉROGLYPHE ÉGYPTIEN O036B","	* fin de cartouche à mur fortifié"},
/* 13288 */ { "HIÉROGLYPHE ÉGYPTIEN O036C","	* début d'enceinte à mur fortifié"},
/* 13289 */ { "HIÉROGLYPHE ÉGYPTIEN O036D","	* fin d'enceinte à mur fortifié"},
/* 1328A */ { "HIÉROGLYPHE ÉGYPTIEN O037","	* classificateur renverser, démolir : whn"},
/* 1328B */ { "HIÉROGLYPHE ÉGYPTIEN O038","	* classificateur passage : ꜥrr.yt\n"
	"	~ 1328B FE01 pivoté de 180 degrés"},
/* 1328C */ { "HIÉROGLYPHE ÉGYPTIEN O039","	* à ne pas confondre avec 13219\n"
	"	* classificateur pierre, brique, galet : mꜣṯ\n"
	"	~ 1328C FE00 pivoté de 90 degrés"},
/* 1328D */ { "HIÉROGLYPHE ÉGYPTIEN O040","	* logogramme (escalier) : rwd"},
/* 1328E */ { "HIÉROGLYPHE ÉGYPTIEN O041","	* classificateur ascendant, être élevé : ḳꜣ.y"},
/* 1328F */ { "HIÉROGLYPHE ÉGYPTIEN O042","	* phonémogramme : šsp"},
/* 13290 */ { "HIÉROGLYPHE ÉGYPTIEN O043","	* variante plus ancienne de 1328F\n"
	"	* phonémogramme : šsp"},
/* 13291 */ { "HIÉROGLYPHE ÉGYPTIEN O044","	* logogramme (bureau, rang, fonction) : ꞽꜣw.t"},
/* 13292 */ { "HIÉROGLYPHE ÉGYPTIEN O045","	* logogramme (harem, chambre intérieure) : ꞽp.t"},
/* 13293 */ { "HIÉROGLYPHE ÉGYPTIEN O046","	* logogramme (harem, chambre intérieure) : ꞽp.t"},
/* 13294 */ { "HIÉROGLYPHE ÉGYPTIEN O047","	* logogramme (Hiérakonpolis) : nḫn"},
/* 13295 */ { "HIÉROGLYPHE ÉGYPTIEN O048","	* logogramme (temps, occasion) : sp"},
/* 13296 */ { "HIÉROGLYPHE ÉGYPTIEN O049","	* logogramme (ville, village) : nꞽw.t\n"
	"	~ 13296 FE03 pivoté de 45 degrés [= 135, 225, 315 degrés]"},
/* 13297 */ { "HIÉROGLYPHE ÉGYPTIEN O050","	* classificateur aire de battage : sp.t"},
/* 13298 */ { "HIÉROGLYPHE ÉGYPTIEN O050A","	* version « miroir » de 13299"},
/* 13299 */ { "HIÉROGLYPHE ÉGYPTIEN O050B","	* phono-répéteur / classificateur temps, occasion : sp"},
/* 1329A */ { "HIÉROGLYPHE ÉGYPTIEN O051","	* logogramme (grenier) : šnw.t"},
/* 1329B */ { "HIÉROGLYPHE ÉGYPTIEN P001","	* classificateur mouvement : ḫnt"},
/* 1329C */ { "HIÉROGLYPHE ÉGYPTIEN P001A","	* classificateur renverser, bouleverser : pnꜥ"},
/* 1329D */ { "HIÉROGLYPHE ÉGYPTIEN P002",NULL},
/* 1329E */ { "HIÉROGLYPHE ÉGYPTIEN P003","	* classificateur barque, bateau : (m)skt.t"},
/* 1329F */ { "HIÉROGLYPHE ÉGYPTIEN P003A","	* version « miroir » de 1329E"},
/* 132A0 */ { "HIÉROGLYPHE ÉGYPTIEN P004","	* logogramme (détacher, expliquer) : wḥꜥ"},
/* 132A1 */ { "HIÉROGLYPHE ÉGYPTIEN P005","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 132A2 */ { "HIÉROGLYPHE ÉGYPTIEN P006","	* phonémogramme : ꜥḥꜥ"},
/* 132A3 */ { "HIÉROGLYPHE ÉGYPTIEN P007","	* phonémogramme : ꜥḥꜥ"},
/* 132A4 */ { "HIÉROGLYPHE ÉGYPTIEN P008","	* phonémogramme : ḫrw\n"
	"	~ 132A4 FE01 pivoté de 180 degrés\n"
	"	~ 132A4 FE02 pivoté de 270 degrés\n"
	"	~ 132A4 FE06 pivoté de 315 degrés environ"},
/* 132A5 */ { "HIÉROGLYPHE ÉGYPTIEN P009","	* phonémogramme : ḫrw=f(y)"},
/* 132A6 */ { "HIÉROGLYPHE ÉGYPTIEN P010","	* logogramme (gouvernail) : ḥmw"},
/* 132A7 */ { "HIÉROGLYPHE ÉGYPTIEN P011","	* à ne pas confondre avec 131E9 ou 1342A\n"
	"	* classificateur poteau d'amarrage : mnꞽ.t"},
/* 132A8 */ { "HIÉROGLYPHE ÉGYPTIEN Q001","	* logogramme (siège, trône, lieu) : s.t"},
/* 132A9 */ { "HIÉROGLYPHE ÉGYPTIEN Q002","	* phonémogramme : ws"},
/* 132AA */ { "HIÉROGLYPHE ÉGYPTIEN Q003","	* phonémogramme : p\n"
	"	~ 132AA FE00 pivoté de 90 degrés"},
/* 132AB */ { "HIÉROGLYPHE ÉGYPTIEN Q004","	* classificateur appui-tête : wrs"},
/* 132AC */ { "HIÉROGLYPHE ÉGYPTIEN Q005","	* classificateur boîte : hn(w)"},
/* 132AD */ { "HIÉROGLYPHE ÉGYPTIEN Q006","	* classificateur cercueil : ḳrs.w"},
/* 132AE */ { "HIÉROGLYPHE ÉGYPTIEN Q007","	* classificateur feu, flamme, chaleur : sḏ.t"},
/* 132AF */ { "HIÉROGLYPHE ÉGYPTIEN R001","	* classificateur autel : ḫꜣ(w).t"},
/* 132B0 */ { "HIÉROGLYPHE ÉGYPTIEN R002","	* logogramme (autel) : ḫꜣw.t"},
/* 132B1 */ { "HIÉROGLYPHE ÉGYPTIEN R002A","	* logogramme (autel) : ḫꜣw.t"},
/* 132B2 */ { "HIÉROGLYPHE ÉGYPTIEN R003","	* classificateur fête : ḥ(ꜣ)b"},
/* 132B3 */ { "HIÉROGLYPHE ÉGYPTIEN R003A","	* classificateur table d'offrandes, support de jarre : ḫnt"},
/* 132B4 */ { "HIÉROGLYPHE ÉGYPTIEN R003B",NULL},
/* 132B5 */ { "HIÉROGLYPHE ÉGYPTIEN R004","	* logogramme (offrande) : ḥtp"},
/* 132B6 */ { "HIÉROGLYPHE ÉGYPTIEN R005","	* classificateur fumigation, encensement : kꜣp"},
/* 132B7 */ { "HIÉROGLYPHE ÉGYPTIEN R006","	* logogramme (fumiger, encenser) : kꜣp"},
/* 132B8 */ { "HIÉROGLYPHE ÉGYPTIEN R007","	* logogramme (encens) : snṯr"},
/* 132B9 */ { "HIÉROGLYPHE ÉGYPTIEN R008","	* logogramme (dieu) : nṯr"},
/* 132BA */ { "HIÉROGLYPHE ÉGYPTIEN R009","	* classificateur natron : ḥsmn"},
/* 132BB */ { "HIÉROGLYPHE ÉGYPTIEN R010","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 132BC */ { "HIÉROGLYPHE ÉGYPTIEN R010A","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 132BD */ { "HIÉROGLYPHE ÉGYPTIEN R011","	* phonémogramme : ḏd"},
/* 132BE */ { "HIÉROGLYPHE ÉGYPTIEN R012","	* classificateur étendard : ꞽꜣ.t"},
/* 132BF */ { "HIÉROGLYPHE ÉGYPTIEN R013","	* logogramme (ouest, côté droit) : ꞽmn.t"},
/* 132C0 */ { "HIÉROGLYPHE ÉGYPTIEN R014","	* logogramme (ouest) : ꞽmn.t"},
/* 132C1 */ { "HIÉROGLYPHE ÉGYPTIEN R015","	* phonémogramme : ꜣb"},
/* 132C2 */ { "HIÉROGLYPHE ÉGYPTIEN R016","	* classificateur lutte, bataille : sk.w"},
/* 132C3 */ { "HIÉROGLYPHE ÉGYPTIEN R016A","	* logogramme (Néfertoum) : nfr-tm"},
/* 132C4 */ { "HIÉROGLYPHE ÉGYPTIEN R017","	* logogramme (nome de la Grande Terre, 8e nome de Haute-Égypte) : tꜣ-wr"},
/* 132C5 */ { "HIÉROGLYPHE ÉGYPTIEN R018","	* logogramme (nome de la Grande Terre, 8e nome de Haute-Égypte) : tꜣ-wr"},
/* 132C6 */ { "HIÉROGLYPHE ÉGYPTIEN R019","	* logogramme (Thèbes) : wꜣs.t"},
/* 132C7 */ { "HIÉROGLYPHE ÉGYPTIEN R020","	* logogramme (Séchat (divinité)) : sšꜣ.t"},
/* 132C8 */ { "HIÉROGLYPHE ÉGYPTIEN R021","	* logogramme (Séchat (divinité)) : sšꜣ.t"},
/* 132C9 */ { "HIÉROGLYPHE ÉGYPTIEN R022","	* logogramme (Létopolis) : ḫm"},
/* 132CA */ { "HIÉROGLYPHE ÉGYPTIEN R023","	* logogramme (Min (divinité)) : mnw"},
/* 132CB */ { "HIÉROGLYPHE ÉGYPTIEN R024","	* logogramme (Neith (divinité)) : n.t\n"
	"	~ 132CB FE00 pivoté de 90 degrés"},
/* 132CC */ { "HIÉROGLYPHE ÉGYPTIEN R025","	* logogramme (Neith (divinité)) : n.t"},
/* 132CD */ { "HIÉROGLYPHE ÉGYPTIEN R026","	* phonémogramme : smꜣ"},
/* 132CE */ { "HIÉROGLYPHE ÉGYPTIEN R027","	* logogramme (Neith (divinité)) : n.t"},
/* 132CF */ { "HIÉROGLYPHE ÉGYPTIEN R028","	* logogramme (nome de la Bât, 7e nome de Haute-Égypte) : bꜣ.t"},
/* 132D0 */ { "HIÉROGLYPHE ÉGYPTIEN R029","	* logogramme (sanctuaire, rangée de sanctuaires) : ꞽtr.t"},
/* 132D1 */ { "HIÉROGLYPHE ÉGYPTIEN S001","	* phonémogramme : ḥḏ"},
/* 132D2 */ { "HIÉROGLYPHE ÉGYPTIEN S002","	* classificateur couronne : wrr.t"},
/* 132D3 */ { "HIÉROGLYPHE ÉGYPTIEN S002A","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 132D4 */ { "HIÉROGLYPHE ÉGYPTIEN S003","	* phonémogramme : n"},
/* 132D5 */ { "HIÉROGLYPHE ÉGYPTIEN S004","	* classificateur couronne : n.t"},
/* 132D6 */ { "HIÉROGLYPHE ÉGYPTIEN S005","	* classificateur couronne double : sḫm.ty"},
/* 132D7 */ { "HIÉROGLYPHE ÉGYPTIEN S006","	* classificateur couronne double : sḫm.ty"},
/* 132D8 */ { "HIÉROGLYPHE ÉGYPTIEN S006A","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 132D9 */ { "HIÉROGLYPHE ÉGYPTIEN S007","	* classificateur couronne : ḫprš"},
/* 132DA */ { "HIÉROGLYPHE ÉGYPTIEN S008","	* logogramme (couronne Atef) : ꜣtf"},
/* 132DB */ { "HIÉROGLYPHE ÉGYPTIEN S009","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 132DC */ { "HIÉROGLYPHE ÉGYPTIEN S010","	* logogramme (bande d'étoffe, filet) : mḏḥ\n"
	"	~ 132DC FE00 pivoté de 90 degrés"},
/* 132DD */ { "HIÉROGLYPHE ÉGYPTIEN S011","	* logogramme (collier, pectoral) : wsḫ"},
/* 132DE */ { "HIÉROGLYPHE ÉGYPTIEN S012","	* logogramme (or) : nbw"},
/* 132DF */ { "HIÉROGLYPHE ÉGYPTIEN S013","	* phonémogramme : nb"},
/* 132E0 */ { "HIÉROGLYPHE ÉGYPTIEN S014","	* logogramme (argent) : ḥḏ"},
/* 132E1 */ { "HIÉROGLYPHE ÉGYPTIEN S014A","	* logogramme (or blanc, or fin, électrum) : ḏꜥm"},
/* 132E2 */ { "HIÉROGLYPHE ÉGYPTIEN S014B",NULL},
/* 132E3 */ { "HIÉROGLYPHE ÉGYPTIEN S015","	* logogramme (faïence, verre) : ṯḥn.t"},
/* 132E4 */ { "HIÉROGLYPHE ÉGYPTIEN S016","	* logogramme (faïence, verre) : ṯḥn.t"},
/* 132E5 */ { "HIÉROGLYPHE ÉGYPTIEN S017","	* logogramme (faïence, verre) : ṯḥn.t"},
/* 132E6 */ { "HIÉROGLYPHE ÉGYPTIEN S017A","	* phonémogramme : šsm"},
/* 132E7 */ { "HIÉROGLYPHE ÉGYPTIEN S018","	* classificateur collier : mnꞽ.t\n"
	"	~ 132E7 FE00 pivoté de 90 degrés\n"
	"	~ 132E7 FE02 pivoté de 270 degrés"},
/* 132E8 */ { "HIÉROGLYPHE ÉGYPTIEN S019","	* logogramme (porteur de sceau) : ḫtm.w/y"},
/* 132E9 */ { "HIÉROGLYPHE ÉGYPTIEN S020","	* logogramme (sceau, verrou, scellement) : ḫtm\n"
	"	~ 132E9 FE02 pivoté de 270 degrés\n"
	"	~ 132E9 FE06 pivoté de 300 degrés environ"},
/* 132EA */ { "HIÉROGLYPHE ÉGYPTIEN S021","	* logogramme (collier, pectoral) : wsḫ"},
/* 132EB */ { "HIÉROGLYPHE ÉGYPTIEN S022","	* phonémogramme : sṯ"},
/* 132EC */ { "HIÉROGLYPHE ÉGYPTIEN S023","	* logogramme (unir, assembler) : dmḏ"},
/* 132ED */ { "HIÉROGLYPHE ÉGYPTIEN S024","	* classificateur lier, attacher : ṯs"},
/* 132EE */ { "HIÉROGLYPHE ÉGYPTIEN S025","	* classificateur vêtement, manteau, jupe : mꜣs.t"},
/* 132EF */ { "HIÉROGLYPHE ÉGYPTIEN S026","	* classificateur jupe, tablier royal : šnḏ.wt"},
/* 132F0 */ { "HIÉROGLYPHE ÉGYPTIEN S026A","	* à ne pas confondre avec 13200, 133D4 ou 133F3\n"
	"	* logogramme (pagne, vêtement) : dꜣꞽ.w"},
/* 132F1 */ { "HIÉROGLYPHE ÉGYPTIEN S026B","	* variante de 132F0"},
/* 132F2 */ { "HIÉROGLYPHE ÉGYPTIEN S027","	* logogramme (vêtements) : mnḫ.t"},
/* 132F3 */ { "HIÉROGLYPHE ÉGYPTIEN S028","	* classificateur vêtements : ḥbs"},
/* 132F4 */ { "HIÉROGLYPHE ÉGYPTIEN S029","	x (hiéroglyphe égyptien o034 - 13283)\n"
	"	* phonémogramme : s"},
/* 132F5 */ { "HIÉROGLYPHE ÉGYPTIEN S030","	* phonémogramme : sf"},
/* 132F6 */ { "HIÉROGLYPHE ÉGYPTIEN S031","	* phonémogramme : smꜣ"},
/* 132F7 */ { "HIÉROGLYPHE ÉGYPTIEN S032","	* phonémogramme : sꞽꜣ"},
/* 132F8 */ { "HIÉROGLYPHE ÉGYPTIEN S033","	* classificateur sandale : ṯbw.t\n"
	"	~ 132F8 FE02 pivoté de 270 degrés"},
/* 132F9 */ { "HIÉROGLYPHE ÉGYPTIEN S034","	* logogramme (vie) : ꜥnḫ"},
/* 132FA */ { "HIÉROGLYPHE ÉGYPTIEN S035","	* classificateur ombre, ombrage : mnḳb"},
/* 132FB */ { "HIÉROGLYPHE ÉGYPTIEN S035A","	* variante de 132FA"},
/* 132FC */ { "HIÉROGLYPHE ÉGYPTIEN S036","	* variante plus ancienne de 132FA\n"
	"	* logogramme (ombre, ombrage) : šw.t"},
/* 132FD */ { "HIÉROGLYPHE ÉGYPTIEN S037","	* logogramme (éventail) : ḫw\n"
	"	~ 132FD FE02 pivoté de 270 degrés"},
/* 132FE */ { "HIÉROGLYPHE ÉGYPTIEN S038","	* phonémogramme : ḥḳꜣ"},
/* 132FF */ { "HIÉROGLYPHE ÉGYPTIEN S039","	* logogramme (bâton de berger) : ꜥw.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_33[] = {
/* 13300 */ { "HIÉROGLYPHE ÉGYPTIEN S040","	* phonémogramme : wꜣs"},
/* 13301 */ { "HIÉROGLYPHE ÉGYPTIEN S041","	* classificateur sceptre : ḏꜥm"},
/* 13302 */ { "HIÉROGLYPHE ÉGYPTIEN S042","	* phonémogramme : sḫm\n"
	"	~ 13302 FE02 pivoté de 270 degrés"},
/* 13303 */ { "HIÉROGLYPHE ÉGYPTIEN S043","	* phonémogramme : md(w)\n"
	"	~ 13303 FE02 pivoté de 270 degrés"},
/* 13304 */ { "HIÉROGLYPHE ÉGYPTIEN S044","	* classificateur bâton, sceptre : ꜣsm"},
/* 13305 */ { "HIÉROGLYPHE ÉGYPTIEN S045","	* logogramme (flagellum) : nḫꜣḫꜣ"},
/* 13306 */ { "HIÉROGLYPHE ÉGYPTIEN S046","	* phonémogramme : k"},
/* 13307 */ { "HIÉROGLYPHE ÉGYPTIEN T001","	* phonémogramme : mn\n"
	"	~ 13307 FE00 pivoté de 90 degrés"},
/* 13308 */ { "HIÉROGLYPHE ÉGYPTIEN T002","	* classificateur frappant, heurtant : sḳr\n"
	"	~ 13308 FE01 pivoté de 180 degrés"},
/* 13309 */ { "HIÉROGLYPHE ÉGYPTIEN T003","	* phonémogramme : ḥḏ"},
/* 1330A */ { "HIÉROGLYPHE ÉGYPTIEN T003A","	* phonémogramme : ḥḏw"},
/* 1330B */ { "HIÉROGLYPHE ÉGYPTIEN T004","	* phonémogramme : ḥḏ"},
/* 1330C */ { "HIÉROGLYPHE ÉGYPTIEN T005","	* phonémogramme : ḥḏ"},
/* 1330D */ { "HIÉROGLYPHE ÉGYPTIEN T006","	* phonémogramme : ḥḏḏ"},
/* 1330E */ { "HIÉROGLYPHE ÉGYPTIEN T007","	* logogramme (charpentier) : mḏḥ.w"},
/* 1330F */ { "HIÉROGLYPHE ÉGYPTIEN T007A","	* classificateur hache : ꞽḳḥ.w"},
/* 13310 */ { "HIÉROGLYPHE ÉGYPTIEN T008","	* variante plus ancienne de 13311\n"
	"	* phonémogramme : tp\n"
	"	~ 13310 FE02 pivoté de 270 degrés"},
/* 13311 */ { "HIÉROGLYPHE ÉGYPTIEN T008A","	* phonémogramme : tp\n"
	"	~ 13311 FE02 pivoté de 270 degrés"},
/* 13312 */ { "HIÉROGLYPHE ÉGYPTIEN T009","	* classificateur arc, arme : pḏ.t\n"
	"	~ 13312 FE01 pivoté de 180 degrés\n"
	"	~ 13312 FE02 pivoté de 270 degrés"},
/* 13313 */ { "HIÉROGLYPHE ÉGYPTIEN T009A","	* variante plus ancienne de 13312\n"
	"	* phonémogramme : pḏ\n"
	"	~ 13313 FE01 pivoté de 180 degrés\n"
	"	~ 13313 FE02 pivoté de 270 degrés"},
/* 13314 */ { "HIÉROGLYPHE ÉGYPTIEN T010","	* logogramme (arc) : pḏ.t\n"
	"	~ 13314 FE01 pivoté de 180 degrés\n"
	"	~ 13314 FE02 pivoté de 270 degrés"},
/* 13315 */ { "HIÉROGLYPHE ÉGYPTIEN T011","	* phonémogramme : swn"},
/* 13316 */ { "HIÉROGLYPHE ÉGYPTIEN T011A",NULL},
/* 13317 */ { "HIÉROGLYPHE ÉGYPTIEN T012","	* phonémogramme : rwḏ"},
/* 13318 */ { "HIÉROGLYPHE ÉGYPTIEN T013","	* phono-répéteur : rs"},
/* 13319 */ { "HIÉROGLYPHE ÉGYPTIEN T014","	* phono-répéteur : ḳmꜣ"},
/* 1331A */ { "HIÉROGLYPHE ÉGYPTIEN T015","	* variante plus ancienne de 13319\n"
	"	* phonémogramme : ṯḥn"},
/* 1331B */ { "HIÉROGLYPHE ÉGYPTIEN T016","	* classificateur lame courbée, cimeterre : ḫpš\n"
	"	~ 1331B FE00 pivoté de 90 degrés\n"
	"	~ 1331B FE01 pivoté de 180 degrés"},
/* 1331C */ { "HIÉROGLYPHE ÉGYPTIEN T016A","	* classificateur bras fort, puissance, force : ḫpš\n"
	"	~ 1331C FE02 pivoté de 270 degrés"},
/* 1331D */ { "HIÉROGLYPHE ÉGYPTIEN T017","	* logogramme (char) : wrr.t"},
/* 1331E */ { "HIÉROGLYPHE ÉGYPTIEN T018","	* logogramme (suivant, acolyte) : šms.w"},
/* 1331F */ { "HIÉROGLYPHE ÉGYPTIEN T019","	* classificateur os : ꜣbw"},
/* 13320 */ { "HIÉROGLYPHE ÉGYPTIEN T020","	* variante plus ancienne de 1331F\n"
	"	* classificateur harpon : ḳs"},
/* 13321 */ { "HIÉROGLYPHE ÉGYPTIEN T021","	* logogramme (un, unique) : wꜥ\n"
	"	~ 13321 FE01 pivoté de 180 degrés\n"
	"	~ 13321 FE02 pivoté de 270 degrés"},
/* 13322 */ { "HIÉROGLYPHE ÉGYPTIEN T022","	* phonémogramme : sn\n"
	"	~ 13322 FE00 pivoté de 90 degrés\n"
	"	~ 13322 FE01 pivoté de 180 degrés"},
/* 13323 */ { "HIÉROGLYPHE ÉGYPTIEN T023","	* variante plus récente de 13322\n"
	"	* phonémogramme : sn"},
/* 13324 */ { "HIÉROGLYPHE ÉGYPTIEN T024","	* classificateur capture, mise en filet : ꞽ.ꜥḥ"},
/* 13325 */ { "HIÉROGLYPHE ÉGYPTIEN T025","	* phonémogramme : ḏbꜣ"},
/* 13326 */ { "HIÉROGLYPHE ÉGYPTIEN T026","	* classificateur capture, mise en filet : ꞽbṯ"},
/* 13327 */ { "HIÉROGLYPHE ÉGYPTIEN T027","	* variante plus ancienne de 13326\n"
	"	* classificateur tissage, matériau tissé : sḫt"},
/* 13328 */ { "HIÉROGLYPHE ÉGYPTIEN T028","	* phonémogramme : ẖr"},
/* 13329 */ { "HIÉROGLYPHE ÉGYPTIEN T029","	* logogramme (lieu d'abattage)"},
/* 1332A */ { "HIÉROGLYPHE ÉGYPTIEN T030","	* classificateur dépeçage, abattage : ds"},
/* 1332B */ { "HIÉROGLYPHE ÉGYPTIEN T031","	* phonémogramme : sšm\n"
	"	~ 1332B FE06 pivoté de 340 degrés environ [horizontal]"},
/* 1332C */ { "HIÉROGLYPHE ÉGYPTIEN T032","	* phonémogramme : sšm"},
/* 1332D */ { "HIÉROGLYPHE ÉGYPTIEN T032A","	* phonémogramme : sšm"},
/* 1332E */ { "HIÉROGLYPHE ÉGYPTIEN T033","	* variante plus ancienne de 13326\n"
	"	* logogramme (boucher) : sšm"},
/* 1332F */ { "HIÉROGLYPHE ÉGYPTIEN T033A",NULL},
/* 13330 */ { "HIÉROGLYPHE ÉGYPTIEN T034","	* classificateur couteau : nm"},
/* 13331 */ { "HIÉROGLYPHE ÉGYPTIEN T035","	* variante de 13330\n"
	"	* logogramme (couteau) : nm\n"
	"	~ 13331 FE01 pivoté de 180 degrés\n"
	"	~ 13331 FE02 pivoté de 270 degrés"},
/* 13332 */ { "HIÉROGLYPHE ÉGYPTIEN T036","	* classificateur bouclier : ꞽkm"},
/* 13333 */ { "HIÉROGLYPHE ÉGYPTIEN U001","	* phonémogramme : mꜣ"},
/* 13334 */ { "HIÉROGLYPHE ÉGYPTIEN U002","	* variante stylistique de 13333\n"
	"	* phonémogramme : mꜣ"},
/* 13335 */ { "HIÉROGLYPHE ÉGYPTIEN U003","	* phonémogramme (dans mꜣꜣ, voir) : mꜣ"},
/* 13336 */ { "HIÉROGLYPHE ÉGYPTIEN U004","	* phonémogramme : mꜣꜥ"},
/* 13337 */ { "HIÉROGLYPHE ÉGYPTIEN U005","	* variante stylistique de 13336\n"
	"	* phonémogramme : mꜣꜥ"},
/* 13338 */ { "HIÉROGLYPHE ÉGYPTIEN U006","	* phonémogramme : mr\n"
	"	~ 13338 FE03 pivoté de 30 degrés environ\n"
	"	~ 13338 FE06 pivoté de 320 degrés environ [horizontal]"},
/* 13339 */ { "HIÉROGLYPHE ÉGYPTIEN U006A","	* version pivotée de 13338"},
/* 1333A */ { "HIÉROGLYPHE ÉGYPTIEN U006B","	* version « miroir » de 13339"},
/* 1333B */ { "HIÉROGLYPHE ÉGYPTIEN U007","	* version pivotée de 13338\n"
	"	* phonémogramme : mr"},
/* 1333C */ { "HIÉROGLYPHE ÉGYPTIEN U008","	* phonémogramme : ḥn\n"
	"	~ 1333C FE00 pivoté de 90 degrés"},
/* 1333D */ { "HIÉROGLYPHE ÉGYPTIEN U009","	* classificateur céréales, orge : sšr"},
/* 1333E */ { "HIÉROGLYPHE ÉGYPTIEN U010","	* logogramme (récolte, moisson) : šm.w"},
/* 1333F */ { "HIÉROGLYPHE ÉGYPTIEN U011","	* logogramme (boisseau (10 hins, mesure de volume de céréales)) : ḥḳꜣ.t"},
/* 13340 */ { "HIÉROGLYPHE ÉGYPTIEN U012","	* logogramme (boisseau (10 hins, mesure de volume de céréales)) : ḥḳꜣ.t"},
/* 13341 */ { "HIÉROGLYPHE ÉGYPTIEN U013","	* classificateur charrue, matériau labouré : skꜣ"},
/* 13342 */ { "HIÉROGLYPHE ÉGYPTIEN U014","	* phono-répéteur : šnꜥ"},
/* 13343 */ { "HIÉROGLYPHE ÉGYPTIEN U015","	* phonémogramme : tm"},
/* 13344 */ { "HIÉROGLYPHE ÉGYPTIEN U016","	* phonémogramme : bꞽꜣ"},
/* 13345 */ { "HIÉROGLYPHE ÉGYPTIEN U017","	* phonémogramme : grg"},
/* 13346 */ { "HIÉROGLYPHE ÉGYPTIEN U018","	* variante de 13345\n"
	"	* logogramme (fonder, établir, chasser, poser (un piège)) : grg"},
/* 13347 */ { "HIÉROGLYPHE ÉGYPTIEN U019","	* phonémogramme : nw"},
/* 13348 */ { "HIÉROGLYPHE ÉGYPTIEN U020","	* variante plus ancienne de 13347\n"
	"	* phonémogramme : nw"},
/* 13349 */ { "HIÉROGLYPHE ÉGYPTIEN U021","	* phonémogramme : stp"},
/* 1334A */ { "HIÉROGLYPHE ÉGYPTIEN U022","	* phono-répéteur : mnḫ\n"
	"	~ 1334A FE02 pivoté de 270 degrés"},
/* 1334B */ { "HIÉROGLYPHE ÉGYPTIEN U023","	* phonémogramme : ꜣb/mr"},
/* 1334C */ { "HIÉROGLYPHE ÉGYPTIEN U023A","	* variante stylistique de 1334B\n"
	"	* phonémogramme : mr"},
/* 1334D */ { "HIÉROGLYPHE ÉGYPTIEN U024","	* logogramme (artisan) : ḥmw.w"},
/* 1334E */ { "HIÉROGLYPHE ÉGYPTIEN U025","	* variante plus ancienne de 1334D\n"
	"	* logogramme (artisanat) : ḥmw.t"},
/* 1334F */ { "HIÉROGLYPHE ÉGYPTIEN U026","	* logogramme (ouvrir) : wbꜣ"},
/* 13350 */ { "HIÉROGLYPHE ÉGYPTIEN U027","	* variante plus ancienne de 1334F\n"
	"	* classificateur ouvrir : wbꜣ"},
/* 13351 */ { "HIÉROGLYPHE ÉGYPTIEN U028","	* phonémogramme : ḏꜣ"},
/* 13352 */ { "HIÉROGLYPHE ÉGYPTIEN U029","	* variante plus ancienne de 13351\n"
	"	* phonémogramme : ḏꜣ"},
/* 13353 */ { "HIÉROGLYPHE ÉGYPTIEN U029A","	* phonémogramme : wḏꜣ"},
/* 13354 */ { "HIÉROGLYPHE ÉGYPTIEN U030","	* phonémogramme : tꜣ"},
/* 13355 */ { "HIÉROGLYPHE ÉGYPTIEN U031","	* classificateur restreindre : rtḥ"},
/* 13356 */ { "HIÉROGLYPHE ÉGYPTIEN U032","	* logogramme (broyer, écraser) : sḥm"},
/* 13357 */ { "HIÉROGLYPHE ÉGYPTIEN U032A","	* phono-répéteur : smn"},
/* 13358 */ { "HIÉROGLYPHE ÉGYPTIEN U033","	* phonémogramme : tꞽ"},
/* 13359 */ { "HIÉROGLYPHE ÉGYPTIEN U034","	* phonémogramme : ḫsf"},
/* 1335A */ { "HIÉROGLYPHE ÉGYPTIEN U035","	* phonémogramme : ḫsf"},
/* 1335B */ { "HIÉROGLYPHE ÉGYPTIEN U036","	* phonémogramme : ḥm"},
/* 1335C */ { "HIÉROGLYPHE ÉGYPTIEN U037","	* logogramme (rasoir) : mẖꜥḳ.t"},
/* 1335D */ { "HIÉROGLYPHE ÉGYPTIEN U038","	* logogramme (balance) : mḫꜣ.t"},
/* 1335E */ { "HIÉROGLYPHE ÉGYPTIEN U039","	* classificateur colonne de balance : mḫꜣ.t"},
/* 1335F */ { "HIÉROGLYPHE ÉGYPTIEN U040","	* variante cursive de 1335E\n"
	"	* phonémogramme : rs"},
/* 13360 */ { "HIÉROGLYPHE ÉGYPTIEN U041","	* classificateur peson de balance : tḫ"},
/* 13361 */ { "HIÉROGLYPHE ÉGYPTIEN U042","	* à ne pas confondre avec 1327D\n"
	"	* logogramme (bâton) : ms.t\n"
	"	~ 13361 FE02 pivoté de 270 degrés"},
/* 13362 */ { "HIÉROGLYPHE ÉGYPTIEN V001","	* classificateur cordon, corde\n"
	"	* à ne pas confondre avec 133F2\n"
	"	* logogramme (100) : šn.t"},
/* 13363 */ { "HIÉROGLYPHE ÉGYPTIEN V001A","	* 200"},
/* 13364 */ { "HIÉROGLYPHE ÉGYPTIEN V001B","	* 300"},
/* 13365 */ { "HIÉROGLYPHE ÉGYPTIEN V001C","	* 400"},
/* 13366 */ { "HIÉROGLYPHE ÉGYPTIEN V001D","	* 500"},
/* 13367 */ { "HIÉROGLYPHE ÉGYPTIEN V001E","	* 600"},
/* 13368 */ { "HIÉROGLYPHE ÉGYPTIEN V001F","	* 700"},
/* 13369 */ { "HIÉROGLYPHE ÉGYPTIEN V001G","	* 800"},
/* 1336A */ { "HIÉROGLYPHE ÉGYPTIEN V001H","	* 900"},
/* 1336B */ { "HIÉROGLYPHE ÉGYPTIEN V001I","	* 500"},
/* 1336C */ { "HIÉROGLYPHE ÉGYPTIEN V002","	* logogramme (tirer, traîner, attirer) : sṯꜣ"},
/* 1336D */ { "HIÉROGLYPHE ÉGYPTIEN V002A","	* phonémogramme : stꜣ/sṯꜣ"},
/* 1336E */ { "HIÉROGLYPHE ÉGYPTIEN V003","	* phonémogramme : sṯꜣ.w"},
/* 1336F */ { "HIÉROGLYPHE ÉGYPTIEN V004","	* phonémogramme : wꜣ"},
/* 13370 */ { "HIÉROGLYPHE ÉGYPTIEN V005","	* logogramme (fondation) : snṯ\n"
	"	~ 13370 FE06 pivoté de 320 degrés environ"},
/* 13371 */ { "HIÉROGLYPHE ÉGYPTIEN V006","	* phonémogramme : šs\n"
	"	~ 13371 FE06 pivoté de 315 degrés environ"},
/* 13372 */ { "HIÉROGLYPHE ÉGYPTIEN V007","	* phonémogramme : šn"},
/* 13373 */ { "HIÉROGLYPHE ÉGYPTIEN V007A","	* classificateur tissu : ꞽꜣḳs\n"
	"	~ 13373 FE02 pivoté de 270 degrés"},
/* 13374 */ { "HIÉROGLYPHE ÉGYPTIEN V007B","	* phonémogramme : šn"},
/* 13375 */ { "HIÉROGLYPHE ÉGYPTIEN V008","	* phonémogramme : šn"},
/* 13376 */ { "HIÉROGLYPHE ÉGYPTIEN V009","	* logogramme (entourer, encercler) : šnꞽ"},
/* 13377 */ { "HIÉROGLYPHE ÉGYPTIEN V010","	* logogramme (nom) : rn\n"
	"	~ 13377 FE00 pivoté de 90 degrés"},
/* 13378 */ { "HIÉROGLYPHE ÉGYPTIEN V011","	x (hiéroglyphe égyptien v011d - 1342F)\n"
	"	* classificateur moitié, partie, portion : psš\n"
	"	~ 13378 FE00 pivoté de 90 degrés"},
/* 13379 */ { "HIÉROGLYPHE ÉGYPTIEN V011A","	* début de cartouche"},
/* 1337A */ { "HIÉROGLYPHE ÉGYPTIEN V011B","	* fin de cartouche"},
/* 1337B */ { "HIÉROGLYPHE ÉGYPTIEN V011C","	* fin de cartouche sans nœud"},
/* 1337C */ { "HIÉROGLYPHE ÉGYPTIEN V012","	* classificateur papyrus, livre, document : šꜥ.t"},
/* 1337D */ { "HIÉROGLYPHE ÉGYPTIEN V012A","	* phonémogramme : dḳr\n"
	"	~ 1337D FE02 pivoté de 270 degrés"},
/* 1337E */ { "HIÉROGLYPHE ÉGYPTIEN V012B","	* classificateur papyrus, livre, document : wḏ.w-nṯr.w"},
/* 1337F */ { "HIÉROGLYPHE ÉGYPTIEN V013","	* translittération en 1E6F\n"
	"	* phonémogramme : ṯ"},
/* 13380 */ { "HIÉROGLYPHE ÉGYPTIEN V014","	* variante de 1337F\n"
	"	* phonémogramme : ṯ"},
/* 13381 */ { "HIÉROGLYPHE ÉGYPTIEN V015","	* phonémogramme : ꞽṯ(ꞽ)"},
/* 13382 */ { "HIÉROGLYPHE ÉGYPTIEN V016","	* phonémogramme : sꜣ"},
/* 13383 */ { "HIÉROGLYPHE ÉGYPTIEN V017","	* logogramme (protection) : sꜣ"},
/* 13384 */ { "HIÉROGLYPHE ÉGYPTIEN V018","	* variante plus ancienne de 13383\n"
	"	* logogramme (protection) : sꜣ"},
/* 13385 */ { "HIÉROGLYPHE ÉGYPTIEN V019","	* logogramme (stable) : mḏ.t\n"
	"	~ 13385 FE02 pivoté de 270 degrés"},
/* 13386 */ { "HIÉROGLYPHE ÉGYPTIEN V020","	* à ne pas confondre avec 133AD\n"
	"	* logogramme (10) : mḏ"},
/* 13387 */ { "HIÉROGLYPHE ÉGYPTIEN V020A","	* à ne pas confondre avec 133AE\n"
	"	* 20"},
/* 13388 */ { "HIÉROGLYPHE ÉGYPTIEN V020B","	* 30"},
/* 13389 */ { "HIÉROGLYPHE ÉGYPTIEN V020C","	* 40"},
/* 1338A */ { "HIÉROGLYPHE ÉGYPTIEN V020D","	* 50"},
/* 1338B */ { "HIÉROGLYPHE ÉGYPTIEN V020E","	* 60"},
/* 1338C */ { "HIÉROGLYPHE ÉGYPTIEN V020F","	* 70"},
/* 1338D */ { "HIÉROGLYPHE ÉGYPTIEN V020G","	* 80"},
/* 1338E */ { "HIÉROGLYPHE ÉGYPTIEN V020H","	* 90"},
/* 1338F */ { "HIÉROGLYPHE ÉGYPTIEN V020I","	* variante de 13387\n"
	"	* 20"},
/* 13390 */ { "HIÉROGLYPHE ÉGYPTIEN V020J","	* variante de 13388\n"
	"	* 30"},
/* 13391 */ { "HIÉROGLYPHE ÉGYPTIEN V020K","	* variante de 13389\n"
	"	* 40"},
/* 13392 */ { "HIÉROGLYPHE ÉGYPTIEN V020L","	* variante de 1338A\n"
	"	* 50"},
/* 13393 */ { "HIÉROGLYPHE ÉGYPTIEN V021","	* logogramme (stable) : mḏ.t"},
/* 13394 */ { "HIÉROGLYPHE ÉGYPTIEN V022","	* phonémogramme : mḥ"},
/* 13395 */ { "HIÉROGLYPHE ÉGYPTIEN V023","	* variante plus ancienne de 13394\n"
	"	* phonémogramme : mḥ"},
/* 13396 */ { "HIÉROGLYPHE ÉGYPTIEN V023A","	* phonémogramme : mḥ"},
/* 13397 */ { "HIÉROGLYPHE ÉGYPTIEN V024","	* phonémogramme : wḏ > wd"},
/* 13398 */ { "HIÉROGLYPHE ÉGYPTIEN V025","	* variante plus récente de 13397\n"
	"	* phonémogramme : wḏ > wd"},
/* 13399 */ { "HIÉROGLYPHE ÉGYPTIEN V026","	* phonémogramme : ꜥnḏ\n"
	"	~ 13399 FE00 pivoté de 90 degrés"},
/* 1339A */ { "HIÉROGLYPHE ÉGYPTIEN V027","	* variante plus ancienne de 13399\n"
	"	* phonémogramme : ꜥnḏ\n"
	"	~ 1339A FE00 pivoté de 90 degrés"},
/* 1339B */ { "HIÉROGLYPHE ÉGYPTIEN V028","	* translittération en 1E25\n"
	"	x (lettre arabe ha' - 062D)\n"
	"	* phonémogramme : ḥ"},
/* 1339C */ { "HIÉROGLYPHE ÉGYPTIEN V028A","	* phonémogramme : ḥꜥ"},
/* 1339D */ { "HIÉROGLYPHE ÉGYPTIEN V029","	* phonémogramme : wꜣḥ"},
/* 1339E */ { "HIÉROGLYPHE ÉGYPTIEN V029A","	* phonémogramme : sk"},
/* 1339F */ { "HIÉROGLYPHE ÉGYPTIEN V030","	* phonémogramme : nb"},
/* 133A0 */ { "HIÉROGLYPHE ÉGYPTIEN V030A","	* variante de 1339F"},
/* 133A1 */ { "HIÉROGLYPHE ÉGYPTIEN V031","	x (lettre hébraïque kaf - 05DB)\n"
	"	x (lettre arabe kaf - 0643)\n"
	"	* phonémogramme : k"},
/* 133A2 */ { "HIÉROGLYPHE ÉGYPTIEN V031A","	* version « miroir » de 133A1\n"
	"	* phonémogramme : k"},
/* 133A3 */ { "HIÉROGLYPHE ÉGYPTIEN V032","	* phonémogramme : msn"},
/* 133A4 */ { "HIÉROGLYPHE ÉGYPTIEN V033","	* classificateur lin : sšr"},
/* 133A5 */ { "HIÉROGLYPHE ÉGYPTIEN V033A","	* classificateur sac, paquet : ḳꜣr"},
/* 133A6 */ { "HIÉROGLYPHE ÉGYPTIEN V034","	* variante plus récente de 133A4\n"
	"	* classificateur parfum : st"},
/* 133A7 */ { "HIÉROGLYPHE ÉGYPTIEN V035","	* logogramme (lin) : sšr"},
/* 133A8 */ { "HIÉROGLYPHE ÉGYPTIEN V036","	* phonémogramme : ḥn"},
/* 133A9 */ { "HIÉROGLYPHE ÉGYPTIEN V037","	* phono-répéteur : ꞽdr"},
/* 133AA */ { "HIÉROGLYPHE ÉGYPTIEN V037A","	* phonémogramme : ꞽd"},
/* 133AB */ { "HIÉROGLYPHE ÉGYPTIEN V038","	* à ne pas confondre avec 1308B\n"
	"	* classificateur bander, envelopper : wt"},
/* 133AC */ { "HIÉROGLYPHE ÉGYPTIEN V039","	* logogramme (amulette Tyet) : tꞽ.t"},
/* 133AD */ { "HIÉROGLYPHE ÉGYPTIEN V040","	* à ne pas confondre avec 13386\n"
	"	* 10"},
/* 133AE */ { "HIÉROGLYPHE ÉGYPTIEN V040A","	* à ne pas confondre avec 13387\n"
	"	* 20"},
/* 133AF */ { "HIÉROGLYPHE ÉGYPTIEN W001","	* classificateur huile, onguent : mrḥ.t\n"
	"	~ 133AF FE02 pivoté de 270 degrés"},
/* 133B0 */ { "HIÉROGLYPHE ÉGYPTIEN W002","	* phonémogramme : bꜣs\n"
	"	~ 133B0 FE02 pivoté de 270 degrés"},
/* 133B1 */ { "HIÉROGLYPHE ÉGYPTIEN W003","	* logogramme (fête) : ḥ(ꜣ)b"},
/* 133B2 */ { "HIÉROGLYPHE ÉGYPTIEN W003A","	* variante de 133B1"},
/* 133B3 */ { "HIÉROGLYPHE ÉGYPTIEN W004","	* logogramme (fête) : h(ꜣ)b"},
/* 133B4 */ { "HIÉROGLYPHE ÉGYPTIEN W005","	* logogramme (prêtre lecteur) : ẖr.y-ḥ(ꜣ)b.t"},
/* 133B5 */ { "HIÉROGLYPHE ÉGYPTIEN W006","	* classificateur chaudron : ḥw.t"},
/* 133B6 */ { "HIÉROGLYPHE ÉGYPTIEN W007","	* classificateur granite : mꜣṯ"},
/* 133B7 */ { "HIÉROGLYPHE ÉGYPTIEN W008","	* phono-répéteur : ꜣb"},
/* 133B8 */ { "HIÉROGLYPHE ÉGYPTIEN W009","	* phonémogramme : ẖnm"},
/* 133B9 */ { "HIÉROGLYPHE ÉGYPTIEN W009A","	* version « miroir » de 133B8"},
/* 133BA */ { "HIÉROGLYPHE ÉGYPTIEN W010","	* phonémogramme : ꜥ"},
/* 133BB */ { "HIÉROGLYPHE ÉGYPTIEN W010A","	* phonémogramme : bꜣ"},
/* 133BC */ { "HIÉROGLYPHE ÉGYPTIEN W011","	* phonémogramme : g"},
/* 133BD */ { "HIÉROGLYPHE ÉGYPTIEN W012","	* variante plus ancienne de 133BC\n"
	"	* phonémogramme : g"},
/* 133BE */ { "HIÉROGLYPHE ÉGYPTIEN W013","	* classificateur récipient rouge (terre cuite) : dšr.t"},
/* 133BF */ { "HIÉROGLYPHE ÉGYPTIEN W014","	* phonémogramme : ḥs\n"
	"	~ 133BF FE02 pivoté de 270 degrés"},
/* 133C0 */ { "HIÉROGLYPHE ÉGYPTIEN W014A",NULL},
/* 133C1 */ { "HIÉROGLYPHE ÉGYPTIEN W015","	* logogramme (être frais, rafraîchir) : ḳbḥ"},
/* 133C2 */ { "HIÉROGLYPHE ÉGYPTIEN W016","	* classificateur eau de libation : ḳbḥ"},
/* 133C3 */ { "HIÉROGLYPHE ÉGYPTIEN W017","	* phonémogramme : ḫnt"},
/* 133C4 */ { "HIÉROGLYPHE ÉGYPTIEN W017A","	* variante cursive de 133C3\n"
	"	* phonémogramme : ḫnt"},
/* 133C5 */ { "HIÉROGLYPHE ÉGYPTIEN W018","	* variante plus ancienne de 133C3\n"
	"	* phonémogramme : ḫnt"},
/* 133C6 */ { "HIÉROGLYPHE ÉGYPTIEN W018A","	* variante cursive de 133C5"},
/* 133C7 */ { "HIÉROGLYPHE ÉGYPTIEN W019","	* phonémogramme : mꞽ"},
/* 133C8 */ { "HIÉROGLYPHE ÉGYPTIEN W020","	* classificateur lait : ꞽrṯ.t"},
/* 133C9 */ { "HIÉROGLYPHE ÉGYPTIEN W021","	* classificateur vin : ꞽrp"},
/* 133CA */ { "HIÉROGLYPHE ÉGYPTIEN W022","	* logogramme (bière) : ḥnḳ.t"},
/* 133CB */ { "HIÉROGLYPHE ÉGYPTIEN W023","	* logogramme (bière) : ḥnḳ.t"},
/* 133CC */ { "HIÉROGLYPHE ÉGYPTIEN W024","	* phonémogramme : nw"},
/* 133CD */ { "HIÉROGLYPHE ÉGYPTIEN W024A","	* monogramme « nw(n) » ou « nww »"},
/* 133CE */ { "HIÉROGLYPHE ÉGYPTIEN W025","	* phonémogramme : ꞽn(ꞽ)"},
/* 133CF */ { "HIÉROGLYPHE ÉGYPTIEN X001","	* phonémogramme : t"},
/* 133D0 */ { "HIÉROGLYPHE ÉGYPTIEN X002","	* logogramme (pain) : t"},
/* 133D1 */ { "HIÉROGLYPHE ÉGYPTIEN X003","	* variante de 133D0\n"
	"	* classificateur pain, nourriture"},
/* 133D2 */ { "HIÉROGLYPHE ÉGYPTIEN X004","	* classificateur fête"},
/* 133D3 */ { "HIÉROGLYPHE ÉGYPTIEN X004A","	* variante de 133D2\n"
	"	* phonémogramme : t\n"
	"	~ 133D3 FE00 pivoté de 90 degrés"},
/* 133D4 */ { "HIÉROGLYPHE ÉGYPTIEN X004B","	* variante de 133D2\n"
	"	* à ne pas confondre avec 13200, 132F0 ou 133F3\n"
	"	* classificateur pain, fête / phonémogramme t / logogramme t (pain) / phono-répéteur (sn, fḳꜣ) : t | sn, fḳꜣ"},
/* 133D5 */ { "HIÉROGLYPHE ÉGYPTIEN X005","	* hiératique\n"
	"	* variante de 133D4\n"
	"	* phono-répéteur : sn"},
/* 133D6 */ { "HIÉROGLYPHE ÉGYPTIEN X006","	* classificateur offrande, gâteau, miche : t-ꜣsr"},
/* 133D7 */ { "HIÉROGLYPHE ÉGYPTIEN X006A","	* variante de 133D6"},
/* 133D8 */ { "HIÉROGLYPHE ÉGYPTIEN X007","	* à ne pas confondre avec 1320E\n"
	"	* classificateur nourriture : gs"},
/* 133D9 */ { "HIÉROGLYPHE ÉGYPTIEN X008","	* phonémogramme : ḏꞽ > dꞽ"},
/* 133DA */ { "HIÉROGLYPHE ÉGYPTIEN X008A","	* variante de 133D9\n"
	"	* à ne pas confondre avec 131EE\n"
	"	* classificateur pain : t-ḥḏ"},
/* 133DB */ { "HIÉROGLYPHE ÉGYPTIEN Y001","	* classificateur mots abstraits : sspd.w\n"
	"	~ 133DB FE02 pivoté de 270 degrés"},
/* 133DC */ { "HIÉROGLYPHE ÉGYPTIEN Y001A","	* version pivotée de 133DB\n"
	"	* logogramme (rouleau de papyrus, livre) : mḏꜣ.t"},
/* 133DD */ { "HIÉROGLYPHE ÉGYPTIEN Y002","	* variante plus ancienne de 133DB\n"
	"	* classificateur écriture, choses écrites : mdw\n"
	"	~ 133DD FE02 pivoté de 270 degrés"},
/* 133DE */ { "HIÉROGLYPHE ÉGYPTIEN Y003","	* logogramme (scribe) : sš"},
/* 133DF */ { "HIÉROGLYPHE ÉGYPTIEN Y004","	* version « miroir » de 133DE\n"
	"	* logogramme (scribe) : sš"},
/* 133E0 */ { "HIÉROGLYPHE ÉGYPTIEN Y005","	* phonémogramme : mn"},
/* 133E1 */ { "HIÉROGLYPHE ÉGYPTIEN Y006","	* classificateur jeu, pièce de jeu : sn.t"},
/* 133E2 */ { "HIÉROGLYPHE ÉGYPTIEN Y007","	* classificateur harpe : bn.t"},
/* 133E3 */ { "HIÉROGLYPHE ÉGYPTIEN Y008","	* classificateur sistre : sḫm"},
/* 133E4 */ { "HIÉROGLYPHE ÉGYPTIEN Z001","	* à ne pas confondre avec 133FA\n"
	"	* classificateur sémogramme\n"
	"	~ 133E4 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 133E5 */ { "HIÉROGLYPHE ÉGYPTIEN Z002","	* à ne pas confondre avec 133FC\n"
	"	* classificateur pluriel\n"
	"	~ 133E5 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 133E6 */ { "HIÉROGLYPHE ÉGYPTIEN Z002A","	* variante stylistique de 133E5"},
/* 133E7 */ { "HIÉROGLYPHE ÉGYPTIEN Z002B","	* à ne pas confondre avec 13213\n"
	"	~ 133E7 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 133E8 */ { "HIÉROGLYPHE ÉGYPTIEN Z002C","	* variante de 133E6\n"
	"	* classificateur pluriel\n"
	"	~ 133E8 FE01 pivoté de 180 degrés"},
/* 133E9 */ { "HIÉROGLYPHE ÉGYPTIEN Z002D","	* version pivotée de 133E8\n"
	"	* classificateur pluriel"},
/* 133EA */ { "HIÉROGLYPHE ÉGYPTIEN Z003","	* variante de 133E5\n"
	"	* classificateur pluriel"},
/* 133EB */ { "HIÉROGLYPHE ÉGYPTIEN Z003A","	* version pivotée de 133E5\n"
	"	* classificateur pluriel"},
/* 133EC */ { "HIÉROGLYPHE ÉGYPTIEN Z003B","	* version pivotée de 133E7"},
/* 133ED */ { "HIÉROGLYPHE ÉGYPTIEN Z004","	* classificateur dual\n"
	"	x (hiéroglyphe égyptien m017a - 131CC)\n"
	"	* phonémogramme : y"},
/* 133EE */ { "HIÉROGLYPHE ÉGYPTIEN Z004A","	* à ne pas confondre avec 133FB\n"
	"	* logogramme (deux) : sn.w\n"
	"	~ 133EE FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 133EF */ { "HIÉROGLYPHE ÉGYPTIEN Z005","	* substitut pour des signes dangereux"},
/* 133F0 */ { "HIÉROGLYPHE ÉGYPTIEN Z005A","	* variante de 133EF\n"
	"	* classificateur divinité (remplaçant G7)"},
/* 133F1 */ { "HIÉROGLYPHE ÉGYPTIEN Z006","	* classificateur mort : ḫp.t"},
/* 133F2 */ { "HIÉROGLYPHE ÉGYPTIEN Z007","	* à ne pas confondre avec 13362\n"
	"	* phonémogramme : w\n"
	"	~ 133F2 FE00 pivoté de 90 degrés"},
/* 133F3 */ { "HIÉROGLYPHE ÉGYPTIEN Z008","	* à ne pas confondre avec 13200, 132F0 ou 133D4\n"
	"	* classificateur rond, ovale : šn(.w)"},
/* 133F4 */ { "HIÉROGLYPHE ÉGYPTIEN Z009","	* classificateur diviser : psš"},
/* 133F5 */ { "HIÉROGLYPHE ÉGYPTIEN Z010","	* variante plus ancienne de 133F4\n"
	"	* classificateur casser : ḥbs\n"
	"	~ 133F5 FE00 pivoté de 90 degrés"},
/* 133F6 */ { "HIÉROGLYPHE ÉGYPTIEN Z011","	* phonémogramme : ꞽm\n"
	"	~ 133F6 FE00 pivoté de 90 degrés"},
/* 133F7 */ { "HIÉROGLYPHE ÉGYPTIEN Z012","	* hiératique\n"
	"	* phonémogramme : ḥw"},
/* 133F8 */ { "HIÉROGLYPHE ÉGYPTIEN Z013","	* cercle, signe rond non marqué\n"
	"	* à ne pas confondre avec 13082 ou 131F3"},
/* 133F9 */ { "HIÉROGLYPHE ÉGYPTIEN Z014","	* hiératique\n"
	"	* classificateur sémogramme"},
/* 133FA */ { "HIÉROGLYPHE ÉGYPTIEN Z015","	* à ne pas confondre avec 133E4\n"
	"	* logogramme (un, unique) : wꜥ"},
/* 133FB */ { "HIÉROGLYPHE ÉGYPTIEN Z015A","	* à ne pas confondre avec 133EE\n"
	"	* logogramme (deux) : sn.w"},
/* 133FC */ { "HIÉROGLYPHE ÉGYPTIEN Z015B","	* à ne pas confondre avec 133E5\n"
	"	x (hiéroglyphe égyptien z003 - 133EA)\n"
	"	* logogramme (trois) : ḫmt"},
/* 133FD */ { "HIÉROGLYPHE ÉGYPTIEN Z015C","	* logogramme (quatre) : fd(.w)"},
/* 133FE */ { "HIÉROGLYPHE ÉGYPTIEN Z015D","	* logogramme (cinq) : dꞽw"},
/* 133FF */ { "HIÉROGLYPHE ÉGYPTIEN Z015E","	* logogramme (six) : sꞽs"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_34[] = {
/* 13400 */ { "HIÉROGLYPHE ÉGYPTIEN Z015F","	* logogramme (sept) : sfḫ"},
/* 13401 */ { "HIÉROGLYPHE ÉGYPTIEN Z015G","	* logogramme (huit) : ḫmn"},
/* 13402 */ { "HIÉROGLYPHE ÉGYPTIEN Z015H","	* logogramme (neuf) : psḏ"},
/* 13403 */ { "HIÉROGLYPHE ÉGYPTIEN Z015I","	* variante de 133FE\n"
	"	* logogramme (cinq) : dꞽw"},
/* 13404 */ { "HIÉROGLYPHE ÉGYPTIEN Z016","	* logogramme (un, unique) : wꜥ"},
/* 13405 */ { "HIÉROGLYPHE ÉGYPTIEN Z016A","	* logogramme (deux) : sn.w"},
/* 13406 */ { "HIÉROGLYPHE ÉGYPTIEN Z016B","	* logogramme (trois) : ḫmt"},
/* 13407 */ { "HIÉROGLYPHE ÉGYPTIEN Z016C","	* logogramme (quatre) : fd(.w)"},
/* 13408 */ { "HIÉROGLYPHE ÉGYPTIEN Z016D","	* logogramme (cinq) : dꞽw"},
/* 13409 */ { "HIÉROGLYPHE ÉGYPTIEN Z016E","	* logogramme (six) : sꞽs"},
/* 1340A */ { "HIÉROGLYPHE ÉGYPTIEN Z016F","	* logogramme (sept) : sfḫ"},
/* 1340B */ { "HIÉROGLYPHE ÉGYPTIEN Z016G","	* logogramme (huit) et logogramme (Hermopolis) : ḫmn & ḫmnw"},
/* 1340C */ { "HIÉROGLYPHE ÉGYPTIEN Z016H","	* logogramme (neuf) : psḏ"},
/* 1340D */ { "HIÉROGLYPHE ÉGYPTIEN AA001","	* translittération en 1E2B\n"
	"	x (lettre arabe kha' - 062E)\n"
	"	* phonémogramme : ḫ\n"
	"	~ 1340D FE04 pivoté de 135 degrés environ [= 315 degrés]"},
/* 1340E */ { "HIÉROGLYPHE ÉGYPTIEN AA002","	* classificateur mauvais, maléfique : nḥꜣ"},
/* 1340F */ { "HIÉROGLYPHE ÉGYPTIEN AA003","	* classificateur efflux, odeur (c'est-à-dire excréments) : ḥs"},
/* 13410 */ { "HIÉROGLYPHE ÉGYPTIEN AA004","	* phonémogramme : bꜣ"},
/* 13411 */ { "HIÉROGLYPHE ÉGYPTIEN AA005","	* classificateur rame : ḥpt"},
/* 13412 */ { "HIÉROGLYPHE ÉGYPTIEN AA006","	* phono-répéteur : ṯmꜣ"},
/* 13413 */ { "HIÉROGLYPHE ÉGYPTIEN AA007","	* classificateur présenter : sḳ(r)"},
/* 13414 */ { "HIÉROGLYPHE ÉGYPTIEN AA007A","	* version « miroir » de 13413\n"
	"	* classificateur présenter : sḳ(r)"},
/* 13415 */ { "HIÉROGLYPHE ÉGYPTIEN AA007B",NULL},
/* 13416 */ { "HIÉROGLYPHE ÉGYPTIEN AA008","	* logogramme (nome, district) : spꜣ.t\n"
	"	~ 13416 FE00 pivoté de 90 degrés"},
/* 13417 */ { "HIÉROGLYPHE ÉGYPTIEN AA009","	* classificateur souffrance : wḫd"},
/* 13418 */ { "HIÉROGLYPHE ÉGYPTIEN AA010","	* classificateur écriture : drf"},
/* 13419 */ { "HIÉROGLYPHE ÉGYPTIEN AA011","	* phonémogramme : mꜣꜥ\n"
	"	~ 13419 FE00 pivoté de 90 degrés\n"
	"	~ 13419 FE01 pivoté de 180 degrés\n"
	"	~ 13419 FE02 pivoté de 270 degrés\n"
	"	~ 13419 FE03 pivoté de 15 degrés environ\n"
	"	~ 13419 FE06 pivoté de 345 degrés environ"},
/* 1341A */ { "HIÉROGLYPHE ÉGYPTIEN AA012","	* variante plus ancienne de 13419\n"
	"	* phonémogramme : mꜣꜥ\n"
	"	~ 1341A FE00 pivoté de 90 degrés"},
/* 1341B */ { "HIÉROGLYPHE ÉGYPTIEN AA013","	* phonémogramme : gs"},
/* 1341C */ { "HIÉROGLYPHE ÉGYPTIEN AA014","	* variante plus ancienne de 1341B\n"
	"	* logogramme (côté, moitié) : gs"},
/* 1341D */ { "HIÉROGLYPHE ÉGYPTIEN AA015","	* phonémogramme : m"},
/* 1341E */ { "HIÉROGLYPHE ÉGYPTIEN AA016","	* variante de 1341D\n"
	"	* logogramme (côté, moitié) : gs"},
/* 1341F */ { "HIÉROGLYPHE ÉGYPTIEN AA017","	* phonémogramme : sꜣ"},
/* 13420 */ { "HIÉROGLYPHE ÉGYPTIEN AA018","	* variante plus récente de 1341F\n"
	"	* phonémogramme : s"},
/* 13421 */ { "HIÉROGLYPHE ÉGYPTIEN AA019","	* classificateur sanctuaire, chapelle"},
/* 13422 */ { "HIÉROGLYPHE ÉGYPTIEN AA020","	* phonémogramme : ꜥpr"},
/* 13423 */ { "HIÉROGLYPHE ÉGYPTIEN AA021","	* logogramme (juger, séparer) : wḏꜥ\n"
	"	~ 13423 FE00 pivoté de 90 degrés"},
/* 13424 */ { "HIÉROGLYPHE ÉGYPTIEN AA022","	* logogramme (juger, séparer) : wḏꜥ"},
/* 13425 */ { "HIÉROGLYPHE ÉGYPTIEN AA023","	* logogramme (presser, s'accrocher (à)) : mḏd"},
/* 13426 */ { "HIÉROGLYPHE ÉGYPTIEN AA024","	* variante plus ancienne de 13425\n"
	"	* logogramme (presser, s'accrocher (à)) : mḏd"},
/* 13427 */ { "HIÉROGLYPHE ÉGYPTIEN AA025","	* phonémogramme : smꜣ"},
/* 13428 */ { "HIÉROGLYPHE ÉGYPTIEN AA026","	* phonémogramme : sbꞽ"},
/* 13429 */ { "HIÉROGLYPHE ÉGYPTIEN AA027","	* phonémogramme : nḏ"},
/* 1342A */ { "HIÉROGLYPHE ÉGYPTIEN AA028","	* à ne pas confondre avec 131E9 et 132A7\n"
	"	* phonémogramme : ḳd"},
/* 1342B */ { "HIÉROGLYPHE ÉGYPTIEN AA029","	* variante plus ancienne de 1342A\n"
	"	* phonémogramme : ḳd"},
/* 1342C */ { "HIÉROGLYPHE ÉGYPTIEN AA030","	* logogramme (ornement) : ẖkr\n"
	"	~ 1342C FE02 pivoté de 270 degrés"},
/* 1342D */ { "HIÉROGLYPHE ÉGYPTIEN AA031","	* variante plus ancienne de 1342C\n"
	"	* logogramme (ornement) : ẖkr"},
/* 1342E */ { "HIÉROGLYPHE ÉGYPTIEN AA032","	* logogramme (Nubie) : sty\n"
	"	~ 1342E FE02 pivoté de 270 degrés"},
/* 1342F */ { "HIÉROGLYPHE ÉGYPTIEN V011D","	* début de cartouche noué\n"
	"	* à ne pas confondre avec 13378"},
/* 13430 */ { "HIÉROGLYPHE ÉGYPTIEN CONNECTEUR VERTICAL","	= séparateur de signes : subordination (Manuel de codage)"},
/* 13431 */ { "HIÉROGLYPHE ÉGYPTIEN CONNECTEUR HORIZONTAL","	= séparateur de signes : juxtaposition (Manuel de codage)"},
/* 13432 */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER DANS LE COIN AVANT SUPÉRIEUR",NULL},
/* 13433 */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER DANS LE COIN AVANT INFÉRIEUR",NULL},
/* 13434 */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER DANS LE COIN ARRIÈRE SUPÉRIEUR",NULL},
/* 13435 */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER DANS LE COIN ARRIÈRE INFÉRIEUR",NULL},
/* 13436 */ { "HIÉROGLYPHE ÉGYPTIEN SUPERPOSITION CENTRALE",NULL},
/* 13437 */ { "HIÉROGLYPHE ÉGYPTIEN DÉBUT DE SEGMENT",NULL},
/* 13438 */ { "HIÉROGLYPHE ÉGYPTIEN FIN DE SEGMENT",NULL},
/* 13439 */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER AU CENTRE",NULL},
/* 1343A */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER DANS LA PARTIE SUPÉRIEURE",NULL},
/* 1343B */ { "HIÉROGLYPHE ÉGYPTIEN INSÉRER DANS LA PARTIE INFÉRIEURE",NULL},
/* 1343C */ { "HIÉROGLYPHE ÉGYPTIEN DÉBUT D'ENCEINTE",NULL},
/* 1343D */ { "HIÉROGLYPHE ÉGYPTIEN FIN D'ENCEINTE",NULL},
/* 1343E */ { "HIÉROGLYPHE ÉGYPTIEN DÉBUT D'ENCEINTE MURÉE",NULL},
/* 1343F */ { "HIÉROGLYPHE ÉGYPTIEN FIN D'ENCEINTE MURÉE",NULL},
/* 13440 */ { "HIÉROGLYPHE ÉGYPTIEN EN MIROIR HORIZONTALEMENT",NULL},
/* 13441 */ { "HIÉROGLYPHE ÉGYPTIEN BLANC COMPLET",NULL},
/* 13442 */ { "HIÉROGLYPHE ÉGYPTIEN DEMI-BLANC",NULL},
/* 13443 */ { "HIÉROGLYPHE ÉGYPTIEN SIGNE DE PERTE","	~ 13443 FE00 étendu"},
/* 13444 */ { "HIÉROGLYPHE ÉGYPTIEN SIGNE DE DEMI-PERTE","	~ 13444 FE00 étendu"},
/* 13445 */ { "HIÉROGLYPHE ÉGYPTIEN SIGNE DE PERTE HAUT","	~ 13445 FE00 étendu"},
/* 13446 */ { "HIÉROGLYPHE ÉGYPTIEN SIGNE DE PERTE LARGE","	~ 13446 FE00 étendu"},
/* 13447 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE AVANT SUPÉRIEURE",NULL},
/* 13448 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE AVANT INFÉRIEURE",NULL},
/* 13449 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ À L'AVANT",NULL},
/* 1344A */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE ARRIÈRE SUPÉRIEURE",NULL},
/* 1344B */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE SUPÉRIEURE",NULL},
/* 1344C */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LES PARTIES AVANT INFÉRIEURE ET ARRIÈRE SUPÉRIEURE",NULL},
/* 1344D */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ À L'AVANT ET DANS LA PARTIE SUPÉRIEURE",NULL},
/* 1344E */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE ARRIÈRE INFÉRIEURE",NULL},
/* 1344F */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LES PARTIES AVANT SUPÉRIEURE ET ARRIÈRE INFÉRIEURE",NULL},
/* 13450 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE INFÉRIEURE",NULL},
/* 13451 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ À L'AVANT ET DANS LA PARTIE INFÉRIEURE",NULL},
/* 13452 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ À L'ARRIÈRE",NULL},
/* 13453 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE SUPÉRIEURE ET À L'ARRIÈRE",NULL},
/* 13454 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ DANS LA PARTIE INFÉRIEURE ET À L'ARRIÈRE",NULL},
/* 13455 */ { "HIÉROGLYPHE ÉGYPTIEN MODIFICATEUR ENDOMMAGÉ",NULL},
/* 13456 */ { NULL,NULL},
/* 13457 */ { NULL,NULL},
/* 13458 */ { NULL,NULL},
/* 13459 */ { NULL,NULL},
/* 1345A */ { NULL,NULL},
/* 1345B */ { NULL,NULL},
/* 1345C */ { NULL,NULL},
/* 1345D */ { NULL,NULL},
/* 1345E */ { NULL,NULL},
/* 1345F */ { NULL,NULL},
/* 13460 */ { "HIÉROGLYPHE ÉGYPTIEN-13460","	* classificateur être humain"},
/* 13461 */ { "HIÉROGLYPHE ÉGYPTIEN-13461","	* classificateur être humain : rmn.w"},
/* 13462 */ { "HIÉROGLYPHE ÉGYPTIEN-13462","	* logogramme (première personne du singulier) : ꞽ"},
/* 13463 */ { "HIÉROGLYPHE ÉGYPTIEN-13463","	* classificateur être humain : wnn.yw"},
/* 13464 */ { "HIÉROGLYPHE ÉGYPTIEN-13464","	* classificateur cour, entourage : šny.t"},
/* 13465 */ { "HIÉROGLYPHE ÉGYPTIEN-13465","	* classificateur occupation/relation (pêcheur ou brasseur) : ḏbḥ(.w) | dbḥ"},
/* 13466 */ { "HIÉROGLYPHE ÉGYPTIEN-13466","	* classificateur conspirer, ruminer : wꜣ"},
/* 13467 */ { "HIÉROGLYPHE ÉGYPTIEN-13467","	* classificateur nom personnel"},
/* 13468 */ { "HIÉROGLYPHE ÉGYPTIEN-13468","	* logogramme (ennemis) : ḫft.yw"},
/* 13469 */ { "HIÉROGLYPHE ÉGYPTIEN-13469","	* classificateur être humain (homme pauvre) : šwꜣ.w"},
/* 1346A */ { "HIÉROGLYPHE ÉGYPTIEN-1346A","	* classificateur être humain : ḥnmm.t?"},
/* 1346B */ { "HIÉROGLYPHE ÉGYPTIEN-1346B","	* logogramme (interjection vocative) : ꞽ"},
/* 1346C */ { "HIÉROGLYPHE ÉGYPTIEN-1346C","	* logogramme (première personne du singulier) : ꞽ"},
/* 1346D */ { "HIÉROGLYPHE ÉGYPTIEN-1346D","	* classificateur assis : ḥ(m)sꞽ"},
/* 1346E */ { "HIÉROGLYPHE ÉGYPTIEN-1346E",NULL},
/* 1346F */ { "HIÉROGLYPHE ÉGYPTIEN-1346F","	* classificateur manger, boire, parler, silence, pensées, sentiments"},
/* 13470 */ { "HIÉROGLYPHE ÉGYPTIEN-13470","	* classificateur parole, son : ṯḥḥ.wt"},
/* 13471 */ { "HIÉROGLYPHE ÉGYPTIEN-13471","	* classificateur parole, silence : dbḥ"},
/* 13472 */ { "HIÉROGLYPHE ÉGYPTIEN-13472","	* classificateur acclamation, prise de parole : nhm"},
/* 13473 */ { "HIÉROGLYPHE ÉGYPTIEN-13473","	* classificateur parole, silence : ḏd"},
/* 13474 */ { "HIÉROGLYPHE ÉGYPTIEN-13474","	* classificateur assis, faible, évanoui"},
/* 13475 */ { "HIÉROGLYPHE ÉGYPTIEN-13475",NULL},
/* 13476 */ { "HIÉROGLYPHE ÉGYPTIEN-13476","	* logogramme (louange, adoration) : dwꜣ"},
/* 13477 */ { "HIÉROGLYPHE ÉGYPTIEN-13477","	* classificateur adoration : ꞽꜣw.t"},
/* 13478 */ { "HIÉROGLYPHE ÉGYPTIEN-13478","	* classificateur supplication, dissimulation, rejet"},
/* 13479 */ { "HIÉROGLYPHE ÉGYPTIEN-13479","	* classificateur harponneur, prêtre : msn.ty"},
/* 1347A */ { "HIÉROGLYPHE ÉGYPTIEN-1347A","	* classificateur révérence : ḥfꜣ"},
/* 1347B */ { "HIÉROGLYPHE ÉGYPTIEN-1347B","	* classificateur ennemis : twꜣ.w"},
/* 1347C */ { "HIÉROGLYPHE ÉGYPTIEN-1347C","	* classificateur prisonnier : sḳr-ꜥnḫ"},
/* 1347D */ { "HIÉROGLYPHE ÉGYPTIEN-1347D","	* classificateur être humain, nom personnel"},
/* 1347E */ { "HIÉROGLYPHE ÉGYPTIEN-1347E","	* classificateur joie : hnw"},
/* 1347F */ { "HIÉROGLYPHE ÉGYPTIEN-1347F","	* logogramme (joie) : hnw"},
/* 13480 */ { "HIÉROGLYPHE ÉGYPTIEN-13480","	* classificateur faire de la musique : ḫnw"},
/* 13481 */ { "HIÉROGLYPHE ÉGYPTIEN-13481","	* classificateur joie : hnw"},
/* 13482 */ { "HIÉROGLYPHE ÉGYPTIEN-13482","	* classificateur joie : hnw"},
/* 13483 */ { "HIÉROGLYPHE ÉGYPTIEN-13483","	* classificateur être humain"},
/* 13484 */ { "HIÉROGLYPHE ÉGYPTIEN-13484","	* classificateur être humain : ꞽt"},
/* 13485 */ { "HIÉROGLYPHE ÉGYPTIEN-13485","	* logogramme (musicien) : ḥs.w"},
/* 13486 */ { "HIÉROGLYPHE ÉGYPTIEN-13486","	* classificateur chauve : ꞽꜣs"},
/* 13487 */ { "HIÉROGLYPHE ÉGYPTIEN-13487","	* classificateur musique : ꞽḥy"},
/* 13488 */ { "HIÉROGLYPHE ÉGYPTIEN-13488",NULL},
/* 13489 */ { "HIÉROGLYPHE ÉGYPTIEN-13489","	* classificateur vaciller : mss"},
/* 1348A */ { "HIÉROGLYPHE ÉGYPTIEN-1348A","	* classificateur étranger (Nubien) : nḥs.y"},
/* 1348B */ { "HIÉROGLYPHE ÉGYPTIEN-1348B","	* logogramme (fraterniser) : snsn"},
/* 1348C */ { "HIÉROGLYPHE ÉGYPTIEN-1348C","	* logogramme (fraterniser) : snsn"},
/* 1348D */ { "HIÉROGLYPHE ÉGYPTIEN-1348D","	* classificateur déserteur, errant : tš"},
/* 1348E */ { "HIÉROGLYPHE ÉGYPTIEN-1348E","	* classificateur lutter : ḳmꜣ"},
/* 1348F */ { "HIÉROGLYPHE ÉGYPTIEN-1348F","	* classificateur déféquer : fgn"},
/* 13490 */ { "HIÉROGLYPHE ÉGYPTIEN-13490","	* classificateur être court : ḥwꜥ"},
/* 13491 */ { "HIÉROGLYPHE ÉGYPTIEN-13491","	* logogramme (verser, drainer) : stꞽ"},
/* 13492 */ { "HIÉROGLYPHE ÉGYPTIEN-13492","	* classificateur le froid : ḥs.w"},
/* 13493 */ { "HIÉROGLYPHE ÉGYPTIEN-13493","	* phonémogramme : ꞽn"},
/* 13494 */ { "HIÉROGLYPHE ÉGYPTIEN-13494","	* classificateur vieil homme : kḥkḥ"},
/* 13495 */ { "HIÉROGLYPHE ÉGYPTIEN-13495",NULL},
/* 13496 */ { "HIÉROGLYPHE ÉGYPTIEN-13496","	* classificateur relatif aux cheveux : ꞽꜣs"},
/* 13497 */ { "HIÉROGLYPHE ÉGYPTIEN-13497",NULL},
/* 13498 */ { "HIÉROGLYPHE ÉGYPTIEN-13498","	* phonémogramme : ꜥnt"},
/* 13499 */ { "HIÉROGLYPHE ÉGYPTIEN-13499","	* logogramme (myrrhe) : ꜥnt.yw"},
/* 1349A */ { "HIÉROGLYPHE ÉGYPTIEN-1349A","	* classificateur officiel, noble : sr"},
/* 1349B */ { "HIÉROGLYPHE ÉGYPTIEN-1349B","	* classificateur interjection vocative : ꞽ"},
/* 1349C */ { "HIÉROGLYPHE ÉGYPTIEN-1349C","	* logogramme (plier) : ḳꜥḥ"},
/* 1349D */ { "HIÉROGLYPHE ÉGYPTIEN-1349D","	* classificateur attaquant : tkk"},
/* 1349E */ { "HIÉROGLYPHE ÉGYPTIEN-1349E","	* classificateur soulevant, portant : ṯsꞽ"},
/* 1349F */ { "HIÉROGLYPHE ÉGYPTIEN-1349F",NULL},
/* 134A0 */ { "HIÉROGLYPHE ÉGYPTIEN-134A0",NULL},
/* 134A1 */ { "HIÉROGLYPHE ÉGYPTIEN-134A1","	* classificateur inclinaison : ksw"},
/* 134A2 */ { "HIÉROGLYPHE ÉGYPTIEN-134A2","	* logogramme (prêtre sem) ? : sm"},
/* 134A3 */ { "HIÉROGLYPHE ÉGYPTIEN-134A3","	* classificateur chauve : ꞽꜣs"},
/* 134A4 */ { "HIÉROGLYPHE ÉGYPTIEN-134A4","	* classificateur chauve : ꞽꜣs"},
/* 134A5 */ { "HIÉROGLYPHE ÉGYPTIEN-134A5","	* classificateur adoration : ꞽꜣw"},
/* 134A6 */ { "HIÉROGLYPHE ÉGYPTIEN-134A6",NULL},
/* 134A7 */ { "HIÉROGLYPHE ÉGYPTIEN-134A7","	* classificateur sautant, bondissant : špw"},
/* 134A8 */ { "HIÉROGLYPHE ÉGYPTIEN-134A8","	* classificateur inclinaison : ksw"},
/* 134A9 */ { "HIÉROGLYPHE ÉGYPTIEN-134A9",NULL},
/* 134AA */ { "HIÉROGLYPHE ÉGYPTIEN-134AA","	* classificateur inclinaison : ḫꜣb"},
/* 134AB */ { "HIÉROGLYPHE ÉGYPTIEN-134AB","	* logogramme (baiser la terre) : sn-tꜣ"},
/* 134AC */ { "HIÉROGLYPHE ÉGYPTIEN-134AC","	* classificateur tordre : sps"},
/* 134AD */ { "HIÉROGLYPHE ÉGYPTIEN-134AD","	* phonémogramme : ḳꞽs"},
/* 134AE */ { "HIÉROGLYPHE ÉGYPTIEN-134AE",NULL},
/* 134AF */ { "HIÉROGLYPHE ÉGYPTIEN-134AF","	* logogramme (s'inclinant) : ḫꜣb/ksw"},
/* 134B0 */ { "HIÉROGLYPHE ÉGYPTIEN-134B0","	* classificateur tombant : sḫr"},
/* 134B1 */ { "HIÉROGLYPHE ÉGYPTIEN-134B1","	* logogramme (renverser, jeter à terre) : sḫr"},
/* 134B2 */ { "HIÉROGLYPHE ÉGYPTIEN-134B2","	* classificateur ennemi : mmty"},
/* 134B3 */ { "HIÉROGLYPHE ÉGYPTIEN-134B3","	* classificateur inclinaison, abaissement"},
/* 134B4 */ { "HIÉROGLYPHE ÉGYPTIEN-134B4",NULL},
/* 134B5 */ { "HIÉROGLYPHE ÉGYPTIEN-134B5","	* logogramme (baiser la terre) : sn-tꜣ"},
/* 134B6 */ { "HIÉROGLYPHE ÉGYPTIEN-134B6","	* logogramme (baiser la terre) : sn-tꜣ"},
/* 134B7 */ { "HIÉROGLYPHE ÉGYPTIEN-134B7",NULL},
/* 134B8 */ { "HIÉROGLYPHE ÉGYPTIEN-134B8","	* classificateur inclinaison, abaissement : ksꞽ"},
/* 134B9 */ { "HIÉROGLYPHE ÉGYPTIEN-134B9","	* classificateur cadavre : ẖꜣ.t"},
/* 134BA */ { "HIÉROGLYPHE ÉGYPTIEN-134BA","	* classificateur renverser : hdb"},
/* 134BB */ { "HIÉROGLYPHE ÉGYPTIEN-134BB","	* classificateur cadavre"},
/* 134BC */ { "HIÉROGLYPHE ÉGYPTIEN-134BC","	* classificateur dormir, réveiller : sḏr, sṯs"},
/* 134BD */ { "HIÉROGLYPHE ÉGYPTIEN-134BD","	* classificateur couché sur un côté : sḏr"},
/* 134BE */ { "HIÉROGLYPHE ÉGYPTIEN-134BE",NULL},
/* 134BF */ { "HIÉROGLYPHE ÉGYPTIEN-134BF","	* classificateur nageant : mḥꞽ"},
/* 134C0 */ { "HIÉROGLYPHE ÉGYPTIEN-134C0","	* phonémogramme : nb"},
/* 134C1 */ { "HIÉROGLYPHE ÉGYPTIEN-134C1","	* classificateur nageant : nbꞽ"},
/* 134C2 */ { "HIÉROGLYPHE ÉGYPTIEN-134C2",NULL},
/* 134C3 */ { "HIÉROGLYPHE ÉGYPTIEN-134C3","	* phonémogramme : nb"},
/* 134C4 */ { "HIÉROGLYPHE ÉGYPTIEN-134C4","	* phonémogramme : nb"},
/* 134C5 */ { "HIÉROGLYPHE ÉGYPTIEN-134C5","	* classificateur nageant : nbꞽ"},
/* 134C6 */ { "HIÉROGLYPHE ÉGYPTIEN-134C6","	* logogramme (officiel, noble) : sr"},
/* 134C7 */ { "HIÉROGLYPHE ÉGYPTIEN-134C7","	* logogramme (nome d'Andjety, 9e nome de Basse-Égypte) : ꜥnḏ.ty"},
/* 134C8 */ { "HIÉROGLYPHE ÉGYPTIEN-134C8","	* classificateur statue : twt"},
/* 134C9 */ { "HIÉROGLYPHE ÉGYPTIEN-134C9","	* logogramme (aîné) : wr"},
/* 134CA */ { "HIÉROGLYPHE ÉGYPTIEN-134CA","	* logogramme (aîné (dans ḥr-wr, Haroëris)) : wr"},
/* 134CB */ { "HIÉROGLYPHE ÉGYPTIEN-134CB","	* classificateur souverain : ꞽt.y"},
/* 134CC */ { "HIÉROGLYPHE ÉGYPTIEN-134CC",NULL},
/* 134CD */ { "HIÉROGLYPHE ÉGYPTIEN-134CD","	* classificateur sagesse : sbḳ"},
/* 134CE */ { "HIÉROGLYPHE ÉGYPTIEN-134CE","	* logogramme (aîné de la cour) : sms.w-hꜣy.t"},
/* 134CF */ { "HIÉROGLYPHE ÉGYPTIEN-134CF","	* classificateur statue : twt"},
/* 134D0 */ { "HIÉROGLYPHE ÉGYPTIEN-134D0","	* classificateur abattre"},
/* 134D1 */ { "HIÉROGLYPHE ÉGYPTIEN-134D1","	* logogramme (grand) : wr"},
/* 134D2 */ { "HIÉROGLYPHE ÉGYPTIEN-134D2","	* logogramme (le grand, chef) : wr"},
/* 134D3 */ { "HIÉROGLYPHE ÉGYPTIEN-134D3","	* logogramme (le grand, chef) : wr"},
/* 134D4 */ { "HIÉROGLYPHE ÉGYPTIEN-134D4","	* logogramme (grand) : wr"},
/* 134D5 */ { "HIÉROGLYPHE ÉGYPTIEN-134D5",NULL},
/* 134D6 */ { "HIÉROGLYPHE ÉGYPTIEN-134D6","	* logogramme (le grand, chef) : wr"},
/* 134D7 */ { "HIÉROGLYPHE ÉGYPTIEN-134D7","	* classificateur noble : sr"},
/* 134D8 */ { "HIÉROGLYPHE ÉGYPTIEN-134D8","	* classificateur Orion : sꜣḥ"},
/* 134D9 */ { "HIÉROGLYPHE ÉGYPTIEN-134D9","	* logogramme (fils/enfant de) : sꜣ"},
/* 134DA */ { "HIÉROGLYPHE ÉGYPTIEN-134DA","	* classificateur prêtre lecteur : ẖr.y-ḥb.t ḥr.y-tp"},
/* 134DB */ { "HIÉROGLYPHE ÉGYPTIEN-134DB","	* logogramme (humanité, patriciens) : pꜥ.t"},
/* 134DC */ { "HIÉROGLYPHE ÉGYPTIEN-134DC","	* logogramme (humanité, patriciens) : pꜥ.t"},
/* 134DD */ { "HIÉROGLYPHE ÉGYPTIEN-134DD","	* logogramme (boire) : swr"},
/* 134DE */ { "HIÉROGLYPHE ÉGYPTIEN-134DE","	* classificateur déglutition : sꜥm"},
/* 134DF */ { "HIÉROGLYPHE ÉGYPTIEN-134DF","	* logogramme (boire) : swr"},
/* 134E0 */ { "HIÉROGLYPHE ÉGYPTIEN-134E0","	* classificateur buvant : swr"},
/* 134E1 */ { "HIÉROGLYPHE ÉGYPTIEN-134E1","	* classificateur soulevant, portant : fꜣꞽ"},
/* 134E2 */ { "HIÉROGLYPHE ÉGYPTIEN-134E2","	* classificateur soulevant, portant : fꜣꞽ"},
/* 134E3 */ { "HIÉROGLYPHE ÉGYPTIEN-134E3","	* classificateur soulevant, portant : fꜣꞽ"},
/* 134E4 */ { "HIÉROGLYPHE ÉGYPTIEN-134E4","	* pictogramme agenouillé faisant une offrande"},
/* 134E5 */ { "HIÉROGLYPHE ÉGYPTIEN-134E5","	* classificateur travail : kꜣ.t"},
/* 134E6 */ { "HIÉROGLYPHE ÉGYPTIEN-134E6","	* classificateur travail : kꜣ.t"},
/* 134E7 */ { "HIÉROGLYPHE ÉGYPTIEN-134E7","	* phonémogramme : f"},
/* 134E8 */ { "HIÉROGLYPHE ÉGYPTIEN-134E8","	* classificateur travail : kꜣ.t"},
/* 134E9 */ { "HIÉROGLYPHE ÉGYPTIEN-134E9","	* classificateur travail : kꜣ.t"},
/* 134EA */ { "HIÉROGLYPHE ÉGYPTIEN-134EA","	* logogramme (lever, porter) : fꜣꞽ"},
/* 134EB */ { "HIÉROGLYPHE ÉGYPTIEN-134EB","	* logogramme (lever, porter) : fꜣꞽ"},
/* 134EC */ { "HIÉROGLYPHE ÉGYPTIEN-134EC","	* logogramme (lever le bras) : fꜣꞽ-ꜥ"},
/* 134ED */ { "HIÉROGLYPHE ÉGYPTIEN-134ED","	* logogramme (Heh (divinité)) : ḥḥ"},
/* 134EE */ { "HIÉROGLYPHE ÉGYPTIEN-134EE","	* logogramme (soutenir, élever) : twꜣ"},
/* 134EF */ { "HIÉROGLYPHE ÉGYPTIEN-134EF","	* classificateur maintenir, soutenir (dans le titre ꜥḫ-p.t) : ꜥḫ"},
/* 134F0 */ { "HIÉROGLYPHE ÉGYPTIEN-134F0","	* classificateur interjection vocative"},
/* 134F1 */ { "HIÉROGLYPHE ÉGYPTIEN-134F1","	* phonémogramme (dans snm.t, l'île Biga) : snm"},
/* 134F2 */ { "HIÉROGLYPHE ÉGYPTIEN-134F2","	* phonémogramme : ꞽwn"},
/* 134F3 */ { "HIÉROGLYPHE ÉGYPTIEN-134F3","	* phonémogramme/logogramme (son cœur) : ꞽb=f"},
/* 134F4 */ { "HIÉROGLYPHE ÉGYPTIEN-134F4","	* classificateur peuple : rḫ.yt"},
/* 134F5 */ { "HIÉROGLYPHE ÉGYPTIEN-134F5",NULL},
/* 134F6 */ { "HIÉROGLYPHE ÉGYPTIEN-134F6","	* logogramme (fermier, jardinier) : ꞽb(w)"},
/* 134F7 */ { "HIÉROGLYPHE ÉGYPTIEN-134F7","	* phonémogramme (de fꜣꞽ ḥr) : ḥr=f"},
/* 134F8 */ { "HIÉROGLYPHE ÉGYPTIEN-134F8","	* classificateur moisson : šꜥ"},
/* 134F9 */ { "HIÉROGLYPHE ÉGYPTIEN-134F9","	* classificateur prêtre lecteur : ẖr.y-ḥb.t"},
/* 134FA */ { "HIÉROGLYPHE ÉGYPTIEN-134FA","	* phonémogramme : nn"},
/* 134FB */ { "HIÉROGLYPHE ÉGYPTIEN-134FB","	* logogramme (son nom) : rn=f"},
/* 134FC */ { "HIÉROGLYPHE ÉGYPTIEN-134FC","	* phonémogramme : f"},
/* 134FD */ { "HIÉROGLYPHE ÉGYPTIEN-134FD","	* logogramme (lever, porter) : fꜣꞽ"},
/* 134FE */ { "HIÉROGLYPHE ÉGYPTIEN-134FE","	* classificateur lever, porter : fꜣꞽ"},
/* 134FF */ { "HIÉROGLYPHE ÉGYPTIEN-134FF","	* logogramme (travail) : kꜣ.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_35[] = {
/* 13500 */ { "HIÉROGLYPHE ÉGYPTIEN-13500","	* phonémogramme : f"},
/* 13501 */ { "HIÉROGLYPHE ÉGYPTIEN-13501","	* logogramme (susciter des offrandes) : fꜣꞽ-(ꞽ)ḫ.t"},
/* 13502 */ { "HIÉROGLYPHE ÉGYPTIEN-13502","	* logogramme (susciter des offrandes) : fꜣꞽ-(ꞽ)ḫ.t"},
/* 13503 */ { "HIÉROGLYPHE ÉGYPTIEN-13503",NULL},
/* 13504 */ { "HIÉROGLYPHE ÉGYPTIEN-13504","	* logogramme (soutenir/élever le ciel) : twꜣ-p.t"},
/* 13505 */ { "HIÉROGLYPHE ÉGYPTIEN-13505","	* phonémogramme : f"},
/* 13506 */ { "HIÉROGLYPHE ÉGYPTIEN-13506",NULL},
/* 13507 */ { "HIÉROGLYPHE ÉGYPTIEN-13507","	* phonémogramme : f"},
/* 13508 */ { "HIÉROGLYPHE ÉGYPTIEN-13508","	* phonémogramme : f"},
/* 13509 */ { "HIÉROGLYPHE ÉGYPTIEN-13509",NULL},
/* 1350A */ { "HIÉROGLYPHE ÉGYPTIEN-1350A","	* classificateur offrande : ḫnp"},
/* 1350B */ { "HIÉROGLYPHE ÉGYPTIEN-1350B","	* logogramme (apporter) : ꞽnꞽ"},
/* 1350C */ { "HIÉROGLYPHE ÉGYPTIEN-1350C","	* logogramme (apporter) : ꞽnꞽ"},
/* 1350D */ { "HIÉROGLYPHE ÉGYPTIEN-1350D","	* classificateur force, effort : nḏr/smꜣ"},
/* 1350E */ { "HIÉROGLYPHE ÉGYPTIEN-1350E","	* classificateur force, effort : nḫt"},
/* 1350F */ { "HIÉROGLYPHE ÉGYPTIEN-1350F","	* classificateur mort : mt"},
/* 13510 */ { "HIÉROGLYPHE ÉGYPTIEN-13510","	* logogramme (pur, propre) : wꜥb"},
/* 13511 */ { "HIÉROGLYPHE ÉGYPTIEN-13511","	* logogramme (pur, propre) : wꜥb"},
/* 13512 */ { "HIÉROGLYPHE ÉGYPTIEN-13512","	* logogramme (pur, propre) : wꜥb"},
/* 13513 */ { "HIÉROGLYPHE ÉGYPTIEN-13513","	* logogramme (prêtre ouâb) : wꜥb"},
/* 13514 */ { "HIÉROGLYPHE ÉGYPTIEN-13514","	* logogramme (prêtre ouâb) : wꜥb"},
/* 13515 */ { "HIÉROGLYPHE ÉGYPTIEN-13515",NULL},
/* 13516 */ { "HIÉROGLYPHE ÉGYPTIEN-13516","	* classificateur faire une libation : sṯ"},
/* 13517 */ { "HIÉROGLYPHE ÉGYPTIEN-13517","	* logogramme (pur, propre) : wꜥb"},
/* 13518 */ { "HIÉROGLYPHE ÉGYPTIEN-13518","	* logogramme (pur, propre) : wꜥb"},
/* 13519 */ { "HIÉROGLYPHE ÉGYPTIEN-13519","	* logogramme (être pur, être propre) : wꜥb"},
/* 1351A */ { "HIÉROGLYPHE ÉGYPTIEN-1351A","	* logogramme (pur, propre) : wꜥb"},
/* 1351B */ { "HIÉROGLYPHE ÉGYPTIEN-1351B",NULL},
/* 1351C */ { "HIÉROGLYPHE ÉGYPTIEN-1351C","	* logogramme (prêtre ouâb) : wꜥb"},
/* 1351D */ { "HIÉROGLYPHE ÉGYPTIEN-1351D","	* logogramme (pur, propre) : wꜥb"},
/* 1351E */ { "HIÉROGLYPHE ÉGYPTIEN-1351E","	* logogramme (pur, propre) : wꜥb"},
/* 1351F */ { "HIÉROGLYPHE ÉGYPTIEN-1351F","	* classificateur versant : stꞽ"},
/* 13520 */ { "HIÉROGLYPHE ÉGYPTIEN-13520","	* classificateur versant : stꞽ"},
/* 13521 */ { "HIÉROGLYPHE ÉGYPTIEN-13521",NULL},
/* 13522 */ { "HIÉROGLYPHE ÉGYPTIEN-13522","	* logogramme (verser) : stꞽ"},
/* 13523 */ { "HIÉROGLYPHE ÉGYPTIEN-13523","	* logogramme (verser une libation) ? : ḳbḥ"},
/* 13524 */ { "HIÉROGLYPHE ÉGYPTIEN-13524","	* classificateur saluant : nꞽnꞽ"},
/* 13525 */ { "HIÉROGLYPHE ÉGYPTIEN-13525","	* classificateur asperger, disperser : ntš"},
/* 13526 */ { "HIÉROGLYPHE ÉGYPTIEN-13526","	* logogramme (asperger, disperser) : stꞽ"},
/* 13527 */ { "HIÉROGLYPHE ÉGYPTIEN-13527","	* logogramme (cacher) : ꞽmn"},
/* 13528 */ { "HIÉROGLYPHE ÉGYPTIEN-13528","	* classificateur dissimulation, dissimulé : ꞽmn"},
/* 13529 */ { "HIÉROGLYPHE ÉGYPTIEN-13529","	* classificateur dissimulation, dissimulé : ꞽmn"},
/* 1352A */ { "HIÉROGLYPHE ÉGYPTIEN-1352A","	* logogramme (cacher) : ꞽmn"},
/* 1352B */ { "HIÉROGLYPHE ÉGYPTIEN-1352B","	* classificateur fonte, coulée : nb"},
/* 1352C */ { "HIÉROGLYPHE ÉGYPTIEN-1352C","	* logogramme (surveillant des déserts) : ꞽm.y-r-s.t"},
/* 1352D */ { "HIÉROGLYPHE ÉGYPTIEN-1352D","	* classificateur broyage : nḏ"},
/* 1352E */ { "HIÉROGLYPHE ÉGYPTIEN-1352E","	* classificateur broyage : nḏ"},
/* 1352F */ { "HIÉROGLYPHE ÉGYPTIEN-1352F","	* classificateur mesurer : ḫꜣꞽ"},
/* 13530 */ { "HIÉROGLYPHE ÉGYPTIEN-13530","	* classificateur moisson, récolte : ꜣsḫ"},
/* 13531 */ { "HIÉROGLYPHE ÉGYPTIEN-13531","	* logogramme (enfoncer le poteau d'amarrage) : ḥwꞽ-mnꞽ.t"},
/* 13532 */ { "HIÉROGLYPHE ÉGYPTIEN-13532",NULL},
/* 13533 */ { "HIÉROGLYPHE ÉGYPTIEN-13533","	* logogramme (manœuvrer, construire) : ḫwsꞽ"},
/* 13534 */ { "HIÉROGLYPHE ÉGYPTIEN-13534","	* logogramme (manœuvrer, construire) : ḫwsꞽ"},
/* 13535 */ { "HIÉROGLYPHE ÉGYPTIEN-13535","	* logogramme (construire) : ḳd"},
/* 13536 */ { "HIÉROGLYPHE ÉGYPTIEN-13536","	* logogramme (construire) : ḳd"},
/* 13537 */ { "HIÉROGLYPHE ÉGYPTIEN-13537","	* classificateur construction : sꞽp"},
/* 13538 */ { "HIÉROGLYPHE ÉGYPTIEN-13538","	* classificateur construction : ẖnm"},
/* 13539 */ { "HIÉROGLYPHE ÉGYPTIEN-13539","	* classificateur construction : sps"},
/* 1353A */ { "HIÉROGLYPHE ÉGYPTIEN-1353A","	* logogramme (créer, façonner) : nḥp"},
/* 1353B */ { "HIÉROGLYPHE ÉGYPTIEN-1353B","	* classificateur créer, façonner : nḥp"},
/* 1353C */ { "HIÉROGLYPHE ÉGYPTIEN-1353C","	* classificateur créer : ḳd"},
/* 1353D */ { "HIÉROGLYPHE ÉGYPTIEN-1353D","	* classificateur créer : ḳd"},
/* 1353E */ { "HIÉROGLYPHE ÉGYPTIEN-1353E","	* logogramme (tamiser, presser) : ꜥtḫ"},
/* 1353F */ { "HIÉROGLYPHE ÉGYPTIEN-1353F","	* logogramme (brasseur) : ꜥf.ty"},
/* 13540 */ { "HIÉROGLYPHE ÉGYPTIEN-13540","	* classificateur porte-pot, console : ḫnt"},
/* 13541 */ { "HIÉROGLYPHE ÉGYPTIEN-13541","	* classificateur propulser (un bateau) : wdꞽ"},
/* 13542 */ { "HIÉROGLYPHE ÉGYPTIEN-13542","	* incertain, classificateur ?"},
/* 13543 */ { "HIÉROGLYPHE ÉGYPTIEN-13543","	* logogramme (constructeurs) : ḳd.w"},
/* 13544 */ { "HIÉROGLYPHE ÉGYPTIEN-13544",NULL},
/* 13545 */ { "HIÉROGLYPHE ÉGYPTIEN-13545",NULL},
/* 13546 */ { "HIÉROGLYPHE ÉGYPTIEN-13546","	* incertain (dans sꜣ.w (domaine), et dans une liste d'offrandes après ḥnḳ.t)"},
/* 13547 */ { "HIÉROGLYPHE ÉGYPTIEN-13547","	* classificateur ouvrir (un rouleau) : pg(ꜣ)"},
/* 13548 */ { "HIÉROGLYPHE ÉGYPTIEN-13548","	* logogramme (scribe) : sš"},
/* 13549 */ { "HIÉROGLYPHE ÉGYPTIEN-13549","	* classificateur occupation : bꜣk"},
/* 1354A */ { "HIÉROGLYPHE ÉGYPTIEN-1354A",NULL},
/* 1354B */ { "HIÉROGLYPHE ÉGYPTIEN-1354B","	* logogramme (frapper) : ḥwꞽ"},
/* 1354C */ { "HIÉROGLYPHE ÉGYPTIEN-1354C","	* logogramme (se pencher) : wꜥf"},
/* 1354D */ { "HIÉROGLYPHE ÉGYPTIEN-1354D","	* logogramme (oryx abattu) : mꜣ-ḥḏ sfṯ"},
/* 1354E */ { "HIÉROGLYPHE ÉGYPTIEN-1354E","	* logogramme (garder) : sꜣw"},
/* 1354F */ { "HIÉROGLYPHE ÉGYPTIEN-1354F","	* logogramme (berger) : mnꞽ.w"},
/* 13550 */ { "HIÉROGLYPHE ÉGYPTIEN-13550","	* classificateur berger : nr"},
/* 13551 */ { "HIÉROGLYPHE ÉGYPTIEN-13551","	* classificateur étranger (Asiatique) : ꜥꜣm"},
/* 13552 */ { "HIÉROGLYPHE ÉGYPTIEN-13552","	* logogramme (se rapportant à, appartenant à) : ꞽr.y"},
/* 13553 */ { "HIÉROGLYPHE ÉGYPTIEN-13553","	* logogramme (garder) : sꜣw"},
/* 13554 */ { "HIÉROGLYPHE ÉGYPTIEN-13554","	* logogramme (étranger) : rwty"},
/* 13555 */ { "HIÉROGLYPHE ÉGYPTIEN-13555","	* logogramme (garder) : sꜣw"},
/* 13556 */ { "HIÉROGLYPHE ÉGYPTIEN-13556","	* logogramme (garder) : sꜣw"},
/* 13557 */ { "HIÉROGLYPHE ÉGYPTIEN-13557","	* logogramme (garder) : sꜣw"},
/* 13558 */ { "HIÉROGLYPHE ÉGYPTIEN-13558","	* logogramme (garder) : sꜣw"},
/* 13559 */ { "HIÉROGLYPHE ÉGYPTIEN-13559","	* logogramme (garder) : sꜣw"},
/* 1355A */ { "HIÉROGLYPHE ÉGYPTIEN-1355A","	* logogramme (garder) : sꜣw"},
/* 1355B */ { "HIÉROGLYPHE ÉGYPTIEN-1355B","	* logogramme (garder) : sꜣw"},
/* 1355C */ { "HIÉROGLYPHE ÉGYPTIEN-1355C","	* logogramme (se rapportant à, appartenant à) : ꞽr.y"},
/* 1355D */ { "HIÉROGLYPHE ÉGYPTIEN-1355D","	* classificateur étranger"},
/* 1355E */ { "HIÉROGLYPHE ÉGYPTIEN-1355E","	* classificateur asservir : bꜣk"},
/* 1355F */ { "HIÉROGLYPHE ÉGYPTIEN-1355F","	* incertain"},
/* 13560 */ { "HIÉROGLYPHE ÉGYPTIEN-13560","	* classificateur peuple à arcs, nomades : ꞽwn.tyw"},
/* 13561 */ { "HIÉROGLYPHE ÉGYPTIEN-13561","	* classificateur peuple à arcs, nomades : ꞽwn.tyw"},
/* 13562 */ { "HIÉROGLYPHE ÉGYPTIEN-13562","	* classificateur étranger : fnḫ.w"},
/* 13563 */ { "HIÉROGLYPHE ÉGYPTIEN-13563","	* classificateur errant, déplacé : šmꜣ.y"},
/* 13564 */ { "HIÉROGLYPHE ÉGYPTIEN-13564","	* logogramme (berger) : mnꞽ.w"},
/* 13565 */ { "HIÉROGLYPHE ÉGYPTIEN-13565","	* logogramme (berger) : mnꞽ.w"},
/* 13566 */ { "HIÉROGLYPHE ÉGYPTIEN-13566","	* logogramme (errant, déplacé) : šmꜣ.y"},
/* 13567 */ { "HIÉROGLYPHE ÉGYPTIEN-13567","	* logogramme (prospecteur) : smn.ty"},
/* 13568 */ { "HIÉROGLYPHE ÉGYPTIEN-13568","	* logogramme (berger) : mnꞽ.w"},
/* 13569 */ { "HIÉROGLYPHE ÉGYPTIEN-13569","	* logogramme (berger) : mnꞽ.w"},
/* 1356A */ { "HIÉROGLYPHE ÉGYPTIEN-1356A",NULL},
/* 1356B */ { "HIÉROGLYPHE ÉGYPTIEN-1356B","	* logogramme (aîné) : smsw"},
/* 1356C */ { "HIÉROGLYPHE ÉGYPTIEN-1356C","	* classificateur aîné : smsw"},
/* 1356D */ { "HIÉROGLYPHE ÉGYPTIEN-1356D",NULL},
/* 1356E */ { "HIÉROGLYPHE ÉGYPTIEN-1356E","	* logogramme (protéger) : ḥmꜣg"},
/* 1356F */ { "HIÉROGLYPHE ÉGYPTIEN-1356F","	* logogramme (ériger) : sꜥḥꜥ"},
/* 13570 */ { "HIÉROGLYPHE ÉGYPTIEN-13570","	* logogramme (ériger le pilier djed) : sꜥḥꜥ-ḏd"},
/* 13571 */ { "HIÉROGLYPHE ÉGYPTIEN-13571","	* classificateur érection du pilier djed (classificateur de groupe pour sꜥḥꜥ-ḏd-ꞽn-ꞽr.yw-ḫt-n(y)-sw.t) : sꜥḥꜥ-ḏd-ꞽn-ꞽr.yw-ḫt-n(y)-sw.t"},
/* 13572 */ { "HIÉROGLYPHE ÉGYPTIEN-13572","	* classificateur érigeant : sꜥḥꜥ"},
/* 13573 */ { "HIÉROGLYPHE ÉGYPTIEN-13573","	* logogramme (aîné) : smsw"},
/* 13574 */ { "HIÉROGLYPHE ÉGYPTIEN-13574","	* logogramme (être âgé) : sms"},
/* 13575 */ { "HIÉROGLYPHE ÉGYPTIEN-13575","	* logogramme (myrrhe) : ꜥnt.yw"},
/* 13576 */ { "HIÉROGLYPHE ÉGYPTIEN-13576","	* classificateur divinité : ꞽwn-mw.t=f"},
/* 13577 */ { "HIÉROGLYPHE ÉGYPTIEN-13577","	* logogramme (prêtre sem) : sm"},
/* 13578 */ { "HIÉROGLYPHE ÉGYPTIEN-13578","	* logogramme (être fort) : nḫt"},
/* 13579 */ { "HIÉROGLYPHE ÉGYPTIEN-13579","	* logogramme (Onouris) : ꞽn-ḥr.t"},
/* 1357A */ { "HIÉROGLYPHE ÉGYPTIEN-1357A","	* logogramme (Onouris) : ꞽn-ḥr.t"},
/* 1357B */ { "HIÉROGLYPHE ÉGYPTIEN-1357B",NULL},
/* 1357C */ { "HIÉROGLYPHE ÉGYPTIEN-1357C","	* logogramme (prospecteur) : smn.ty"},
/* 1357D */ { "HIÉROGLYPHE ÉGYPTIEN-1357D",NULL},
/* 1357E */ { "HIÉROGLYPHE ÉGYPTIEN-1357E","	* logogramme (celui qui ouvre les deux portes du ciel) : wn-ꜥꜣ.wy-(n.w)-p.t"},
/* 1357F */ { "HIÉROGLYPHE ÉGYPTIEN-1357F","	* logogramme (portier) : ꞽr.y-ꜥꜣ"},
/* 13580 */ { "HIÉROGLYPHE ÉGYPTIEN-13580","	* phonémogramme : m kꜣ"},
/* 13581 */ { "HIÉROGLYPHE ÉGYPTIEN-13581",NULL},
/* 13582 */ { "HIÉROGLYPHE ÉGYPTIEN-13582","	* logogramme (protéger) : mkꞽ"},
/* 13583 */ { "HIÉROGLYPHE ÉGYPTIEN-13583","	* logogramme (hisser la voile) : fꜣꞽ-ṯꜣw"},
/* 13584 */ { "HIÉROGLYPHE ÉGYPTIEN-13584","	* classificateur présentant : sfsf"},
/* 13585 */ { "HIÉROGLYPHE ÉGYPTIEN-13585","	* logogramme (apporter) : ꞽnꞽ"},
/* 13586 */ { "HIÉROGLYPHE ÉGYPTIEN-13586","	* logogramme (seigneur des deux terres) : nb-tꜣ.wy"},
/* 13587 */ { "HIÉROGLYPHE ÉGYPTIEN-13587","	* classificateur étendre : p(s)š"},
/* 13588 */ { "HIÉROGLYPHE ÉGYPTIEN-13588","	* phono-répéteur : fd"},
/* 13589 */ { "HIÉROGLYPHE ÉGYPTIEN-13589","	* classificateur déraciner : fdꞽ"},
/* 1358A */ { "HIÉROGLYPHE ÉGYPTIEN-1358A","	* phonémogramme : ḫꜣ"},
/* 1358B */ { "HIÉROGLYPHE ÉGYPTIEN-1358B","	* phonémogramme : ḫꜣ-dꞽ.t"},
/* 1358C */ { "HIÉROGLYPHE ÉGYPTIEN-1358C","	* phonémogramme : ḫꜣ-dꞽ.t"},
/* 1358D */ { "HIÉROGLYPHE ÉGYPTIEN-1358D","	* logogramme (illuminer) : nms"},
/* 1358E */ { "HIÉROGLYPHE ÉGYPTIEN-1358E","	* logogramme (armée) : mšꜥ"},
/* 1358F */ { "HIÉROGLYPHE ÉGYPTIEN-1358F","	* classificateur le colérique : dndn.ty"},
/* 13590 */ { "HIÉROGLYPHE ÉGYPTIEN-13590","	* logogramme (messager, tueur) : hb.y"},
/* 13591 */ { "HIÉROGLYPHE ÉGYPTIEN-13591","	* classificateur éloignant : sḥrꞽ"},
/* 13592 */ { "HIÉROGLYPHE ÉGYPTIEN-13592","	* classificateur tueur : ḫꜣbb"},
/* 13593 */ { "HIÉROGLYPHE ÉGYPTIEN-13593","	* classificateur harponneur : ꞽꜣwty"},
/* 13594 */ { "HIÉROGLYPHE ÉGYPTIEN-13594","	* classificateur éloignant : sḥrꞽ"},
/* 13595 */ { "HIÉROGLYPHE ÉGYPTIEN-13595","	* classificateur dansant : ꞽbꜣ"},
/* 13596 */ { "HIÉROGLYPHE ÉGYPTIEN-13596","	* logogramme (être fort) : nḫt"},
/* 13597 */ { "HIÉROGLYPHE ÉGYPTIEN-13597","	* classificateur bataille : mnꜥ"},
/* 13598 */ { "HIÉROGLYPHE ÉGYPTIEN-13598","	* classificateur ?"},
/* 13599 */ { "HIÉROGLYPHE ÉGYPTIEN-13599","	* logogramme (être fort) : nḫt"},
/* 1359A */ { "HIÉROGLYPHE ÉGYPTIEN-1359A",NULL},
/* 1359B */ { "HIÉROGLYPHE ÉGYPTIEN-1359B",NULL},
/* 1359C */ { "HIÉROGLYPHE ÉGYPTIEN-1359C","	* classificateur armée : mšꜥ"},
/* 1359D */ { "HIÉROGLYPHE ÉGYPTIEN-1359D","	* classificateur étranger : šrdn"},
/* 1359E */ { "HIÉROGLYPHE ÉGYPTIEN-1359E","	* classificateur dissimulation, dissimulé : ꞽmn"},
/* 1359F */ { "HIÉROGLYPHE ÉGYPTIEN-1359F","	* classificateur dissimulation, dissimulé : ꞽmn"},
/* 135A0 */ { "HIÉROGLYPHE ÉGYPTIEN-135A0",NULL},
/* 135A1 */ { "HIÉROGLYPHE ÉGYPTIEN-135A1","	* classificateur coureur (étranger) : pḥrr"},
/* 135A2 */ { "HIÉROGLYPHE ÉGYPTIEN-135A2","	* classificateur armée (mot d'emprunt sémitique) : ḏbꞽ"},
/* 135A3 */ { "HIÉROGLYPHE ÉGYPTIEN-135A3",NULL},
/* 135A4 */ { "HIÉROGLYPHE ÉGYPTIEN-135A4","	* classificateur piétiner : tꞽtꞽ"},
/* 135A5 */ { "HIÉROGLYPHE ÉGYPTIEN-135A5","	* logogramme (armée) : mšꜥ"},
/* 135A6 */ { "HIÉROGLYPHE ÉGYPTIEN-135A6","	* classificateur soldatesque : mnf.yt"},
/* 135A7 */ { "HIÉROGLYPHE ÉGYPTIEN-135A7","	* logogramme (armée) : mšꜥ"},
/* 135A8 */ { "HIÉROGLYPHE ÉGYPTIEN-135A8","	* logogramme (armée) ? : mšꜥ"},
/* 135A9 */ { "HIÉROGLYPHE ÉGYPTIEN-135A9","	* logogramme (armée) ? : mšꜥ"},
/* 135AA */ { "HIÉROGLYPHE ÉGYPTIEN-135AA","	* logogramme (armée) : mšꜥ"},
/* 135AB */ { "HIÉROGLYPHE ÉGYPTIEN-135AB","	* logogramme (1er nome de Haute-Égypte) : tꜣ-sṯy"},
/* 135AC */ { "HIÉROGLYPHE ÉGYPTIEN-135AC","	* logogramme (armée) : mšꜥ"},
/* 135AD */ { "HIÉROGLYPHE ÉGYPTIEN-135AD","	* logogramme (armée) ? : mšꜥ"},
/* 135AE */ { "HIÉROGLYPHE ÉGYPTIEN-135AE",NULL},
/* 135AF */ { "HIÉROGLYPHE ÉGYPTIEN-135AF","	* classificateur rebelle, ennemi"},
/* 135B0 */ { "HIÉROGLYPHE ÉGYPTIEN-135B0","	* classificateur rebelle : ẖꜥk-ꞽb"},
/* 135B1 */ { "HIÉROGLYPHE ÉGYPTIEN-135B1","	* classificateur ennemi ?"},
/* 135B2 */ { "HIÉROGLYPHE ÉGYPTIEN-135B2","	* classificateur ennemi : snn.t"},
/* 135B3 */ { "HIÉROGLYPHE ÉGYPTIEN-135B3","	* classificateur ennemi : twꜣ.t"},
/* 135B4 */ { "HIÉROGLYPHE ÉGYPTIEN-135B4","	* classificateur rebelle : sbꞽ"},
/* 135B5 */ { "HIÉROGLYPHE ÉGYPTIEN-135B5","	* logogramme (chefs) : wr"},
/* 135B6 */ { "HIÉROGLYPHE ÉGYPTIEN-135B6","	* classificateur Syrien : ḫr.y"},
/* 135B7 */ { "HIÉROGLYPHE ÉGYPTIEN-135B7","	* classificateur ennemi/rebelle (Xerxès) : ḫšryš"},
/* 135B8 */ { "HIÉROGLYPHE ÉGYPTIEN-135B8","	* classificateur le malveillant : nbḏ"},
/* 135B9 */ { "HIÉROGLYPHE ÉGYPTIEN-135B9","	* classificateur ennemi/rebelle (Xerxès) : ḫšryš"},
/* 135BA */ { "HIÉROGLYPHE ÉGYPTIEN-135BA","	* classificateur rebelle : sbꞽ"},
/* 135BB */ { "HIÉROGLYPHE ÉGYPTIEN-135BB","	* classificateur ennemi : ṯs.tyw"},
/* 135BC */ { "HIÉROGLYPHE ÉGYPTIEN-135BC","	* logogramme (rebelle) : sbꞽ"},
/* 135BD */ { "HIÉROGLYPHE ÉGYPTIEN-135BD",NULL},
/* 135BE */ { "HIÉROGLYPHE ÉGYPTIEN-135BE","	* logogramme (rebelle) : sbꞽ"},
/* 135BF */ { "HIÉROGLYPHE ÉGYPTIEN-135BF","	* logogramme (rebelle) : sbꞽ"},
/* 135C0 */ { "HIÉROGLYPHE ÉGYPTIEN-135C0",NULL},
/* 135C1 */ { "HIÉROGLYPHE ÉGYPTIEN-135C1","	* classificateur rebelle : sbꞽ"},
/* 135C2 */ { "HIÉROGLYPHE ÉGYPTIEN-135C2","	* classificateur ennemi : bdš"},
/* 135C3 */ { "HIÉROGLYPHE ÉGYPTIEN-135C3","	* classificateur rebelle, ennemi : ẖꜣk-ꞽb"},
/* 135C4 */ { "HIÉROGLYPHE ÉGYPTIEN-135C4","	* classificateur ennemi : bdš"},
/* 135C5 */ { "HIÉROGLYPHE ÉGYPTIEN-135C5","	* classificateur rebelle : bṯn"},
/* 135C6 */ { "HIÉROGLYPHE ÉGYPTIEN-135C6","	* classificateur rebelle : sbꞽ"},
/* 135C7 */ { "HIÉROGLYPHE ÉGYPTIEN-135C7","	* classificateur rebelle, ennemi : ẖꜣk-ꞽb"},
/* 135C8 */ { "HIÉROGLYPHE ÉGYPTIEN-135C8","	* classificateur ennemis, forces hostiles : kꞽ.wy"},
/* 135C9 */ { "HIÉROGLYPHE ÉGYPTIEN-135C9","	* classificateur ennemi : šnṯ"},
/* 135CA */ { "HIÉROGLYPHE ÉGYPTIEN-135CA","	* classificateur étrangers (en tant qu'ennemis) : ḫꜣs.t"},
/* 135CB */ { "HIÉROGLYPHE ÉGYPTIEN-135CB","	* classificateur rebelle : sbꞽ"},
/* 135CC */ { "HIÉROGLYPHE ÉGYPTIEN-135CC","	* classificateur rebelle : sbꞽ"},
/* 135CD */ { "HIÉROGLYPHE ÉGYPTIEN-135CD","	* logogramme (ennemi) : ḫft.y"},
/* 135CE */ { "HIÉROGLYPHE ÉGYPTIEN-135CE",NULL},
/* 135CF */ { "HIÉROGLYPHE ÉGYPTIEN-135CF","	* logogramme (rebelle) : sbꞽ"},
/* 135D0 */ { "HIÉROGLYPHE ÉGYPTIEN-135D0","	* logogramme (ennemi/rebelle) : ḫft.y/sbꞽ"},
/* 135D1 */ { "HIÉROGLYPHE ÉGYPTIEN-135D1",NULL},
/* 135D2 */ { "HIÉROGLYPHE ÉGYPTIEN-135D2",NULL},
/* 135D3 */ { "HIÉROGLYPHE ÉGYPTIEN-135D3","	* classificateur ennemi : ḫr.y"},
/* 135D4 */ { "HIÉROGLYPHE ÉGYPTIEN-135D4","	* classificateur peuple à arcs, nomades : ꞽwn.tyw"},
/* 135D5 */ { "HIÉROGLYPHE ÉGYPTIEN-135D5","	* logogramme (prisonnier) : sḳr-ꜥnḫ"},
/* 135D6 */ { "HIÉROGLYPHE ÉGYPTIEN-135D6",NULL},
/* 135D7 */ { "HIÉROGLYPHE ÉGYPTIEN-135D7","	* logogramme (étranger) : ḫꜣs.ty"},
/* 135D8 */ { "HIÉROGLYPHE ÉGYPTIEN-135D8","	* classificateur repousser : msn(ḥ)"},
/* 135D9 */ { "HIÉROGLYPHE ÉGYPTIEN-135D9","	* logogramme (se pencher, soumettre) : wꜥf"},
/* 135DA */ { "HIÉROGLYPHE ÉGYPTIEN-135DA","	* classificateur étranger : mry"},
/* 135DB */ { "HIÉROGLYPHE ÉGYPTIEN-135DB",NULL},
/* 135DC */ { "HIÉROGLYPHE ÉGYPTIEN-135DC","	* classificateur peuple étranger : ḫꜣs.wt nb.wt"},
/* 135DD */ { "HIÉROGLYPHE ÉGYPTIEN-135DD","	* classificateur faible, abattu : bdš.w"},
/* 135DE */ { "HIÉROGLYPHE ÉGYPTIEN-135DE","	* classificateur dansant : ḥpg"},
/* 135DF */ { "HIÉROGLYPHE ÉGYPTIEN-135DF","	* classificateur joie, jubilation : hnw"},
/* 135E0 */ { "HIÉROGLYPHE ÉGYPTIEN-135E0","	* classificateur dansant : ꞽbꜣ"},
/* 135E1 */ { "HIÉROGLYPHE ÉGYPTIEN-135E1","	* classificateur danse : ꞽbꜣ"},
/* 135E2 */ { "HIÉROGLYPHE ÉGYPTIEN-135E2","	* classificateur danse : ꞽbꜣ"},
/* 135E3 */ { "HIÉROGLYPHE ÉGYPTIEN-135E3","	* classificateur jeune soldat : mgꜣ"},
/* 135E4 */ { "HIÉROGLYPHE ÉGYPTIEN-135E4","	* classificateur peur, vénération : hꜣ-snḏ"},
/* 135E5 */ { "HIÉROGLYPHE ÉGYPTIEN-135E5","	* classificateur dansant : ḫbꞽ"},
/* 135E6 */ { "HIÉROGLYPHE ÉGYPTIEN-135E6","	* classificateur dansant : ḫbꞽ"},
/* 135E7 */ { "HIÉROGLYPHE ÉGYPTIEN-135E7","	* classificateur dansant : ḫbꞽ"},
/* 135E8 */ { "HIÉROGLYPHE ÉGYPTIEN-135E8","	* classificateur dansant : ḫbꞽ"},
/* 135E9 */ { "HIÉROGLYPHE ÉGYPTIEN-135E9","	* classificateur peur, vénération : hꜣ-snḏ"},
/* 135EA */ { "HIÉROGLYPHE ÉGYPTIEN-135EA",NULL},
/* 135EB */ { "HIÉROGLYPHE ÉGYPTIEN-135EB","	* logogramme (le grand dieu) : nṯr-ꜥꜣ"},
/* 135EC */ { "HIÉROGLYPHE ÉGYPTIEN-135EC",NULL},
/* 135ED */ { "HIÉROGLYPHE ÉGYPTIEN-135ED","	* logogramme (faire de la musique) : ꞽḥy"},
/* 135EE */ { "HIÉROGLYPHE ÉGYPTIEN-135EE","	* logogramme (le grand dieu) : nṯr-ꜥꜣ"},
/* 135EF */ { "HIÉROGLYPHE ÉGYPTIEN-135EF","	* logogramme (le roi de Basse-Égypte) : bꜽ.ty"},
/* 135F0 */ { "HIÉROGLYPHE ÉGYPTIEN-135F0","	* classificateur divinité : ꞽḥy"},
/* 135F1 */ { "HIÉROGLYPHE ÉGYPTIEN-135F1","	* logogramme (Ihi (divinité)) : ꞽḥy"},
/* 135F2 */ { "HIÉROGLYPHE ÉGYPTIEN-135F2","	* logogramme (le musicien) : ꞽḥy"},
/* 135F3 */ { "HIÉROGLYPHE ÉGYPTIEN-135F3","	* logogramme (le grand dieu) : nṯr-ꜥꜣ"},
/* 135F4 */ { "HIÉROGLYPHE ÉGYPTIEN-135F4","	* logogramme (roi de Haute-Égypte) : n(y)-sw.t"},
/* 135F5 */ { "HIÉROGLYPHE ÉGYPTIEN-135F5","	* logogramme (le grand dieu) : nṯr-ꜥꜣ"},
/* 135F6 */ { "HIÉROGLYPHE ÉGYPTIEN-135F6","	* logogramme (le grand dieu) : nṯr-ꜥꜣ"},
/* 135F7 */ { "HIÉROGLYPHE ÉGYPTIEN-135F7","	* logogramme (Ihi (divinité)) : ꞽḥy"},
/* 135F8 */ { "HIÉROGLYPHE ÉGYPTIEN-135F8","	* logogramme (Harsomtous) : ḥr-smꜣ-tꜣ.wy"},
/* 135F9 */ { "HIÉROGLYPHE ÉGYPTIEN-135F9","	* logogramme (Harsomtous) : ḥr-smꜣ-tꜣ.wy"},
/* 135FA */ { "HIÉROGLYPHE ÉGYPTIEN-135FA","	* logogramme (Harsomtous) : ḥr-smꜣ-tꜣ.wy"},
/* 135FB */ { "HIÉROGLYPHE ÉGYPTIEN-135FB","	* logogramme (chanter) : ḥsꞽ"},
/* 135FC */ { "HIÉROGLYPHE ÉGYPTIEN-135FC","	* phonémogramme : ḥsꞽ"},
/* 135FD */ { "HIÉROGLYPHE ÉGYPTIEN-135FD","	* classificateur musicien : ḫnw"},
/* 135FE */ { "HIÉROGLYPHE ÉGYPTIEN-135FE","	* classificateur jouer de la musique : sbꜣ"},
/* 135FF */ { "HIÉROGLYPHE ÉGYPTIEN-135FF","	* classificateur tambour : mḳmḳ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_36[] = {
/* 13600 */ { "HIÉROGLYPHE ÉGYPTIEN-13600","	* classificateur frappant un tambour : sr"},
/* 13601 */ { "HIÉROGLYPHE ÉGYPTIEN-13601","	* logogramme (musicien, percussionniste) : ḫn.w"},
/* 13602 */ { "HIÉROGLYPHE ÉGYPTIEN-13602","	* classificateur battant, frappant : dbdb"},
/* 13603 */ { "HIÉROGLYPHE ÉGYPTIEN-13603","	* classificateur joueur de luth : ṯnf"},
/* 13604 */ { "HIÉROGLYPHE ÉGYPTIEN-13604","	* logogramme (Cusae) : ḳꞽs"},
/* 13605 */ { "HIÉROGLYPHE ÉGYPTIEN-13605","	* classificateur chasseur, éclaireur : nw"},
/* 13606 */ { "HIÉROGLYPHE ÉGYPTIEN-13606","	* classificateur chasseur, éclaireur : nw"},
/* 13607 */ { "HIÉROGLYPHE ÉGYPTIEN-13607","	* logogramme (être fort, vaillant) : ḳnꞽ"},
/* 13608 */ { "HIÉROGLYPHE ÉGYPTIEN-13608","	* logogramme (le bon début) : tp-nfr"},
/* 13609 */ { "HIÉROGLYPHE ÉGYPTIEN-13609","	* logogramme (Cusae) : ḳꞽs"},
/* 1360A */ { "HIÉROGLYPHE ÉGYPTIEN-1360A","	* logogramme (être fort, vaillant) : ḳnꞽ"},
/* 1360B */ { "HIÉROGLYPHE ÉGYPTIEN-1360B","	* logogramme (être fort, vaillant) : ḳnꞽ"},
/* 1360C */ { "HIÉROGLYPHE ÉGYPTIEN-1360C","	* classificateur char : wrr.yt"},
/* 1360D */ { "HIÉROGLYPHE ÉGYPTIEN-1360D","	* logogramme (triomphateur) : dwn.ty"},
/* 1360E */ { "HIÉROGLYPHE ÉGYPTIEN-1360E",NULL},
/* 1360F */ { "HIÉROGLYPHE ÉGYPTIEN-1360F","	* logogramme (boucherie, animaux pour le sacrifice) : ḫr.yt"},
/* 13610 */ { "HIÉROGLYPHE ÉGYPTIEN-13610","	* pictogramme ((avec) une charrue, (avec) un joug de bœufs, (comme) le premier des hommes) : (m) ḥb (m) ḥtr (m) tp n rmṯ"},
/* 13611 */ { "HIÉROGLYPHE ÉGYPTIEN-13611","	* logogramme (partie de la construction sꜣ-rꜥ nb ḫꜥ.w) : sꜣ-rꜥ-nb"},
/* 13612 */ { "HIÉROGLYPHE ÉGYPTIEN-13612","	* phonémogramme/logogramme (partie de la construction sꜣ-rꜥ nb ḫꜥ.w) : sꜣ nb"},
/* 13613 */ { "HIÉROGLYPHE ÉGYPTIEN-13613","	* classificateur ? : wnty"},
/* 13614 */ { "HIÉROGLYPHE ÉGYPTIEN-13614","	* phonémogramme résine aromatique (styrax ?) : nnyb"},
/* 13615 */ { "HIÉROGLYPHE ÉGYPTIEN-13615","	* phonémogramme (lapis-lazuli) : ḫsbḏ"},
/* 13616 */ { "HIÉROGLYPHE ÉGYPTIEN-13616","	* logogramme (triomphateur) : dwn.ty"},
/* 13617 */ { "HIÉROGLYPHE ÉGYPTIEN-13617","	* phonémogramme (lapis-lazuli) : ḫsbḏ"},
/* 13618 */ { "HIÉROGLYPHE ÉGYPTIEN-13618","	* logogramme (faire le tour) : pẖr"},
/* 13619 */ { "HIÉROGLYPHE ÉGYPTIEN-13619","	* classificateur chasseur, éclaireur : nw"},
/* 1361A */ { "HIÉROGLYPHE ÉGYPTIEN-1361A","	* classificateur prêtre : ꞽwn-mw.t=f"},
/* 1361B */ { "HIÉROGLYPHE ÉGYPTIEN-1361B","	* phonémogramme : wḥꜥ"},
/* 1361C */ { "HIÉROGLYPHE ÉGYPTIEN-1361C",NULL},
/* 1361D */ { "HIÉROGLYPHE ÉGYPTIEN-1361D","	* classificateur jeunesse, enfant : ḫy"},
/* 1361E */ { "HIÉROGLYPHE ÉGYPTIEN-1361E","	* classificateur s'asseoir, être à l'aise : snḏm"},
/* 1361F */ { "HIÉROGLYPHE ÉGYPTIEN-1361F","	* phonémogramme : msdm"},
/* 13620 */ { "HIÉROGLYPHE ÉGYPTIEN-13620","	* classificateur musicien : ḫnw"},
/* 13621 */ { "HIÉROGLYPHE ÉGYPTIEN-13621","	* classificateur enfant, jeune, jeune homme : ḥwn.w"},
/* 13622 */ { "HIÉROGLYPHE ÉGYPTIEN-13622","	* logogramme (enfant sevré) : wḏḥ"},
/* 13623 */ { "HIÉROGLYPHE ÉGYPTIEN-13623","	* phonémogramme : ꜥb"},
/* 13624 */ { "HIÉROGLYPHE ÉGYPTIEN-13624",NULL},
/* 13625 */ { "HIÉROGLYPHE ÉGYPTIEN-13625","	* logogramme (fils de Rê) : sꜣ-rꜥ"},
/* 13626 */ { "HIÉROGLYPHE ÉGYPTIEN-13626","	* logogramme (fils de Rê) : sꜣ-rꜥ"},
/* 13627 */ { "HIÉROGLYPHE ÉGYPTIEN-13627","	* phonémogramme : r + ḫ"},
/* 13628 */ { "HIÉROGLYPHE ÉGYPTIEN-13628","	* classificateur enfant : nḫn.w"},
/* 13629 */ { "HIÉROGLYPHE ÉGYPTIEN-13629","	* classificateur enfant : wḏḥ"},
/* 1362A */ { "HIÉROGLYPHE ÉGYPTIEN-1362A","	* phonémogramme : m"},
/* 1362B */ { "HIÉROGLYPHE ÉGYPTIEN-1362B",NULL},
/* 1362C */ { "HIÉROGLYPHE ÉGYPTIEN-1362C","	* phonémogramme : ḫft-ḥr"},
/* 1362D */ { "HIÉROGLYPHE ÉGYPTIEN-1362D","	* phonémogramme : ḫft-ḥr"},
/* 1362E */ { "HIÉROGLYPHE ÉGYPTIEN-1362E","	* classificateur protecteur : ḫw.y"},
/* 1362F */ { "HIÉROGLYPHE ÉGYPTIEN-1362F","	* phonémogramme : ꜥš"},
/* 13630 */ { "HIÉROGLYPHE ÉGYPTIEN-13630","	* phonémogramme : ḫꜥ"},
/* 13631 */ { "HIÉROGLYPHE ÉGYPTIEN-13631",NULL},
/* 13632 */ { "HIÉROGLYPHE ÉGYPTIEN-13632","	* classificateur Orion : sꜣḥ"},
/* 13633 */ { "HIÉROGLYPHE ÉGYPTIEN-13633","	* classificateur divinité enfant : ḥkꜣ"},
/* 13634 */ { "HIÉROGLYPHE ÉGYPTIEN-13634","	* classificateur enfant : sfy"},
/* 13635 */ { "HIÉROGLYPHE ÉGYPTIEN-13635",NULL},
/* 13636 */ { "HIÉROGLYPHE ÉGYPTIEN-13636","	* logogramme (fils/enfant de) : sꜣ"},
/* 13637 */ { "HIÉROGLYPHE ÉGYPTIEN-13637","	* logogramme (couronnes, apparences) : ḫꜥ.w"},
/* 13638 */ { "HIÉROGLYPHE ÉGYPTIEN-13638","	* logogramme (fils/enfant de) : sꜣ"},
/* 13639 */ { "HIÉROGLYPHE ÉGYPTIEN-13639","	* classificateur enfant : sf(y)"},
/* 1363A */ { "HIÉROGLYPHE ÉGYPTIEN-1363A",NULL},
/* 1363B */ { "HIÉROGLYPHE ÉGYPTIEN-1363B","	* phonémogramme : ḫn"},
/* 1363C */ { "HIÉROGLYPHE ÉGYPTIEN-1363C","	* classificateur expulsant, crachant : nš"},
/* 1363D */ { "HIÉROGLYPHE ÉGYPTIEN-1363D","	* logogramme (nain, pygmée) : dng"},
/* 1363E */ { "HIÉROGLYPHE ÉGYPTIEN-1363E","	* classificateur personne vénérée"},
/* 1363F */ { "HIÉROGLYPHE ÉGYPTIEN-1363F","	* classificateur personne vénérée"},
/* 13640 */ { "HIÉROGLYPHE ÉGYPTIEN-13640","	* classificateur personne vénérée : ꞽt"},
/* 13641 */ { "HIÉROGLYPHE ÉGYPTIEN-13641","	* logogramme (être noble) : šps"},
/* 13642 */ { "HIÉROGLYPHE ÉGYPTIEN-13642","	* logogramme (le discours noble) : mdw-šps"},
/* 13643 */ { "HIÉROGLYPHE ÉGYPTIEN-13643","	* classificateur personne vénérée"},
/* 13644 */ { "HIÉROGLYPHE ÉGYPTIEN-13644","	* logogramme/phonémogramme (offrandes précieuses) : šps.w"},
/* 13645 */ { "HIÉROGLYPHE ÉGYPTIEN-13645","	* logogramme (noble, splendide) : šps"},
/* 13646 */ { "HIÉROGLYPHE ÉGYPTIEN-13646","	* logogramme (être noble) : špsꞽ"},
/* 13647 */ { "HIÉROGLYPHE ÉGYPTIEN-13647","	* classificateur divinité : ꞽtmw"},
/* 13648 */ { "HIÉROGLYPHE ÉGYPTIEN-13648","	* classificateur résider, occuper : ḥmsꞽ"},
/* 13649 */ { "HIÉROGLYPHE ÉGYPTIEN-13649",NULL},
/* 1364A */ { "HIÉROGLYPHE ÉGYPTIEN-1364A","	* logogramme (être noble) : špsꞽ"},
/* 1364B */ { "HIÉROGLYPHE ÉGYPTIEN-1364B",NULL},
/* 1364C */ { "HIÉROGLYPHE ÉGYPTIEN-1364C","	* classificateur noble : sꜥḥ"},
/* 1364D */ { "HIÉROGLYPHE ÉGYPTIEN-1364D","	* logogramme/phonémogramme (offrandes précieuses) : šps.w"},
/* 1364E */ { "HIÉROGLYPHE ÉGYPTIEN-1364E","	* logogramme (être noble) : špsꞽ"},
/* 1364F */ { "HIÉROGLYPHE ÉGYPTIEN-1364F",NULL},
/* 13650 */ { "HIÉROGLYPHE ÉGYPTIEN-13650","	* classificateur personne vénérée"},
/* 13651 */ { "HIÉROGLYPHE ÉGYPTIEN-13651","	* logogramme (Harsomtous) : ḥr-smꜣ-tꜣ.wy"},
/* 13652 */ { "HIÉROGLYPHE ÉGYPTIEN-13652","	* classificateur divinité"},
/* 13653 */ { "HIÉROGLYPHE ÉGYPTIEN-13653",NULL},
/* 13654 */ { "HIÉROGLYPHE ÉGYPTIEN-13654","	* classificateur divinité : mr.ty"},
/* 13655 */ { "HIÉROGLYPHE ÉGYPTIEN-13655","	* classificateur divinité"},
/* 13656 */ { "HIÉROGLYPHE ÉGYPTIEN-13656","	* classificateur roi : n(y)-sw.t"},
/* 13657 */ { "HIÉROGLYPHE ÉGYPTIEN-13657","	* classificateur roi : n(y)-sw.t"},
/* 13658 */ { "HIÉROGLYPHE ÉGYPTIEN-13658",NULL},
/* 13659 */ { "HIÉROGLYPHE ÉGYPTIEN-13659","	* logogramme (première personne du singulier) : ꞽ"},
/* 1365A */ { "HIÉROGLYPHE ÉGYPTIEN-1365A",NULL},
/* 1365B */ { "HIÉROGLYPHE ÉGYPTIEN-1365B","	* classificateur divinité : ꞽtmw"},
/* 1365C */ { "HIÉROGLYPHE ÉGYPTIEN-1365C","	* logogramme (première personne du singulier) : ꞽ"},
/* 1365D */ { "HIÉROGLYPHE ÉGYPTIEN-1365D","	* logogramme (première personne du singulier) : ꞽ"},
/* 1365E */ { "HIÉROGLYPHE ÉGYPTIEN-1365E","	* logogramme (le puissant) : sḫm"},
/* 1365F */ { "HIÉROGLYPHE ÉGYPTIEN-1365F","	* logogramme (majesté) : ḥm"},
/* 13660 */ { "HIÉROGLYPHE ÉGYPTIEN-13660","	* logogramme (roi) : n.y-sw.t"},
/* 13661 */ { "HIÉROGLYPHE ÉGYPTIEN-13661","	* logogramme (Khépri) : ḫprꞽ"},
/* 13662 */ { "HIÉROGLYPHE ÉGYPTIEN-13662","	* logogramme (gouverner) : ḥḳꜣ"},
/* 13663 */ { "HIÉROGLYPHE ÉGYPTIEN-13663","	* logogramme (gouverneur du 9e nome de Basse-Égypte) : ḥḳꜣ-ꜥnḏ.ty"},
/* 13664 */ { "HIÉROGLYPHE ÉGYPTIEN-13664","	* logogramme (souverain) : ḥḳꜣ"},
/* 13665 */ { "HIÉROGLYPHE ÉGYPTIEN-13665","	* classificateur statue : ẖn.ty"},
/* 13666 */ { "HIÉROGLYPHE ÉGYPTIEN-13666","	* logogramme (souverain) : ꞽt.y"},
/* 13667 */ { "HIÉROGLYPHE ÉGYPTIEN-13667","	* logogramme (noble, splendide) : šps"},
/* 13668 */ { "HIÉROGLYPHE ÉGYPTIEN-13668","	* classificateur souverain : ꞽt.y"},
/* 13669 */ { "HIÉROGLYPHE ÉGYPTIEN-13669","	* logogramme (souverain) : ꞽt.y"},
/* 1366A */ { "HIÉROGLYPHE ÉGYPTIEN-1366A",NULL},
/* 1366B */ { "HIÉROGLYPHE ÉGYPTIEN-1366B",NULL},
/* 1366C */ { "HIÉROGLYPHE ÉGYPTIEN-1366C","	* classificateur nom personnel"},
/* 1366D */ { "HIÉROGLYPHE ÉGYPTIEN-1366D","	* classificateur statue : ꞽrw"},
/* 1366E */ { "HIÉROGLYPHE ÉGYPTIEN-1366E","	* classificateur priant, adorant : smnḥ"},
/* 1366F */ { "HIÉROGLYPHE ÉGYPTIEN-1366F","	* classificateur roi : n.y-sw.t"},
/* 13670 */ { "HIÉROGLYPHE ÉGYPTIEN-13670","	* classificateur divinité : kꜣ-ḥtp"},
/* 13671 */ { "HIÉROGLYPHE ÉGYPTIEN-13671","	* classificateur roi : n.y-sw.t"},
/* 13672 */ { "HIÉROGLYPHE ÉGYPTIEN-13672","	* classificateur divinité : ḫnt.y-ꞽmn.tyw"},
/* 13673 */ { "HIÉROGLYPHE ÉGYPTIEN-13673","	* classificateur roi : n.y-sw.t"},
/* 13674 */ { "HIÉROGLYPHE ÉGYPTIEN-13674","	* classificateur roi : n.y-sw.t"},
/* 13675 */ { "HIÉROGLYPHE ÉGYPTIEN-13675","	* classificateur divinité : nṯr"},
/* 13676 */ { "HIÉROGLYPHE ÉGYPTIEN-13676","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 13677 */ { "HIÉROGLYPHE ÉGYPTIEN-13677","	* classificateur roi : n.y-sw.t"},
/* 13678 */ { "HIÉROGLYPHE ÉGYPTIEN-13678","	* classificateur roi : n.y-sw.t"},
/* 13679 */ { "HIÉROGLYPHE ÉGYPTIEN-13679","	* classificateur divinité : ḫnt.y-ꞽmn.tyw"},
/* 1367A */ { "HIÉROGLYPHE ÉGYPTIEN-1367A","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 1367B */ { "HIÉROGLYPHE ÉGYPTIEN-1367B","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 1367C */ { "HIÉROGLYPHE ÉGYPTIEN-1367C","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 1367D */ { "HIÉROGLYPHE ÉGYPTIEN-1367D","	* logogramme (majesté) : ḥm"},
/* 1367E */ { "HIÉROGLYPHE ÉGYPTIEN-1367E","	* logogramme (celui d'Héliopolis) : ꞽwn.y"},
/* 1367F */ { "HIÉROGLYPHE ÉGYPTIEN-1367F","	* logogramme (la couronne blanche) : ḥḏ.t"},
/* 13680 */ { "HIÉROGLYPHE ÉGYPTIEN-13680","	* classificateur divinité : wsꞽr"},
/* 13681 */ { "HIÉROGLYPHE ÉGYPTIEN-13681","	* classificateur Osiris : wsꞽr"},
/* 13682 */ { "HIÉROGLYPHE ÉGYPTIEN-13682","	* classificateur roi : n.y-sw.t"},
/* 13683 */ { "HIÉROGLYPHE ÉGYPTIEN-13683",NULL},
/* 13684 */ { "HIÉROGLYPHE ÉGYPTIEN-13684","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 13685 */ { "HIÉROGLYPHE ÉGYPTIEN-13685","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 13686 */ { "HIÉROGLYPHE ÉGYPTIEN-13686","	* logogramme (roi de Haute-Égypte et de la terre, lorsqu'il apparaît avec le roi de Basse-Égypte, forme n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : n(.y)-sw.t & tꜣ"},
/* 13687 */ { "HIÉROGLYPHE ÉGYPTIEN-13687","	* logogramme (roi de Haute-Égypte et de la terre, lorsqu'il apparaît avec la variante portant la couronne rouge, forme n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : n(.y)-sw.t & tꜣ"},
/* 13688 */ { "HIÉROGLYPHE ÉGYPTIEN-13688","	* logogramme (roi de Haute-Égypte) : n(.y)-sw.t"},
/* 13689 */ { "HIÉROGLYPHE ÉGYPTIEN-13689","	* logogramme (Osiris) : wsꞽr"},
/* 1368A */ { "HIÉROGLYPHE ÉGYPTIEN-1368A","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 1368B */ { "HIÉROGLYPHE ÉGYPTIEN-1368B","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 1368C */ { "HIÉROGLYPHE ÉGYPTIEN-1368C","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 1368D */ { "HIÉROGLYPHE ÉGYPTIEN-1368D","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 1368E */ { "HIÉROGLYPHE ÉGYPTIEN-1368E","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 1368F */ { "HIÉROGLYPHE ÉGYPTIEN-1368F","	* classificateur roi : n(y)-sw.t"},
/* 13690 */ { "HIÉROGLYPHE ÉGYPTIEN-13690","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 13691 */ { "HIÉROGLYPHE ÉGYPTIEN-13691","	* classificateur souverain : ꞽt.y"},
/* 13692 */ { "HIÉROGLYPHE ÉGYPTIEN-13692","	* classificateur roi : n.y-sw.t"},
/* 13693 */ { "HIÉROGLYPHE ÉGYPTIEN-13693","	* logogramme (roi de Basse-Égypte et de la terre, lorsqu'il apparaît avec le roi de Haute-Égypte, forme n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : bꞽ.ty tꜣ"},
/* 13694 */ { "HIÉROGLYPHE ÉGYPTIEN-13694","	* logogramme (roi de Basse-Égypte et de la terre, lorsqu'il apparaît avec la variante portant la couronne blanche, forme n(.y)-sw.t-bꞽ.ty nb tꜣ.wy) : bꞽ.ty tꜣ"},
/* 13695 */ { "HIÉROGLYPHE ÉGYPTIEN-13695","	* logogramme (roi de Haute-Égypte) : n(.y)-sw.t"},
/* 13696 */ { "HIÉROGLYPHE ÉGYPTIEN-13696","	* logogramme (courir) : pḥrr"},
/* 13697 */ { "HIÉROGLYPHE ÉGYPTIEN-13697","	* logogramme (une offrande que le roi donne) : ḥtp-dꞽ-n.y-sw.t"},
/* 13698 */ { "HIÉROGLYPHE ÉGYPTIEN-13698","	* phonémogramme : ṯ"},
/* 13699 */ { "HIÉROGLYPHE ÉGYPTIEN-13699","	* logogramme (Atoum) : ꞽtmw"},
/* 1369A */ { "HIÉROGLYPHE ÉGYPTIEN-1369A","	* logogramme (première personne du singulier) : ꞽ"},
/* 1369B */ { "HIÉROGLYPHE ÉGYPTIEN-1369B","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(y)-sw.t-bꞽ.ty"},
/* 1369C */ { "HIÉROGLYPHE ÉGYPTIEN-1369C","	* classificateur roi, divinité : pꜣ-nṯr-mnḫ"},
/* 1369D */ { "HIÉROGLYPHE ÉGYPTIEN-1369D","	* classificateur roi, divinité : pꜣ-nṯr-mnḫ"},
/* 1369E */ { "HIÉROGLYPHE ÉGYPTIEN-1369E","	* logogramme (Atoum) : ꞽtmw"},
/* 1369F */ { "HIÉROGLYPHE ÉGYPTIEN-1369F","	* classificateur divinité : ꞽtmw"},
/* 136A0 */ { "HIÉROGLYPHE ÉGYPTIEN-136A0","	* logogramme (Atoum) : ꞽtmw"},
/* 136A1 */ { "HIÉROGLYPHE ÉGYPTIEN-136A1","	* classificateur souverain : ꞽt.y"},
/* 136A2 */ { "HIÉROGLYPHE ÉGYPTIEN-136A2","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(y)-sw.t-bꞽ.ty"},
/* 136A3 */ { "HIÉROGLYPHE ÉGYPTIEN-136A3",NULL},
/* 136A4 */ { "HIÉROGLYPHE ÉGYPTIEN-136A4","	* pictogramme prosterné offrant un vase de myrrhe"},
/* 136A5 */ { "HIÉROGLYPHE ÉGYPTIEN-136A5","	* logogramme (souverain) : ꞽt.y"},
/* 136A6 */ { "HIÉROGLYPHE ÉGYPTIEN-136A6","	* classificateur souverain : ꞽt.y"},
/* 136A7 */ { "HIÉROGLYPHE ÉGYPTIEN-136A7","	* classificateur souverain : ꞽt.y"},
/* 136A8 */ { "HIÉROGLYPHE ÉGYPTIEN-136A8",NULL},
/* 136A9 */ { "HIÉROGLYPHE ÉGYPTIEN-136A9","	* logogramme (souverain) : ꞽt.y"},
/* 136AA */ { "HIÉROGLYPHE ÉGYPTIEN-136AA","	* logogramme (souverain) : ꞽt.y"},
/* 136AB */ { "HIÉROGLYPHE ÉGYPTIEN-136AB",NULL},
/* 136AC */ { "HIÉROGLYPHE ÉGYPTIEN-136AC","	* logogramme/phonémogramme (dans ꜥnḏ.ty (Bousiris)) : ꜥnḏ"},
/* 136AD */ { "HIÉROGLYPHE ÉGYPTIEN-136AD","	* logogramme (nome d'Andjety, 9e nome de Basse-Égypte) : ꜥnḏ.ty"},
/* 136AE */ { "HIÉROGLYPHE ÉGYPTIEN-136AE","	* classificateur majesté (se référant spécifiquement à Shou) : ḥm"},
/* 136AF */ { "HIÉROGLYPHE ÉGYPTIEN-136AF","	* classificateur divinité (Geb) : gbb"},
/* 136B0 */ { "HIÉROGLYPHE ÉGYPTIEN-136B0",NULL},
/* 136B1 */ { "HIÉROGLYPHE ÉGYPTIEN-136B1","	* classificateur nom (personne décédée)"},
/* 136B2 */ { "HIÉROGLYPHE ÉGYPTIEN-136B2","	* classificateur nom (personne décédée)"},
/* 136B3 */ { "HIÉROGLYPHE ÉGYPTIEN-136B3",NULL},
/* 136B4 */ { "HIÉROGLYPHE ÉGYPTIEN-136B4","	* classificateur nom (personne décédée)"},
/* 136B5 */ { "HIÉROGLYPHE ÉGYPTIEN-136B5","	* classificateur divinité : wsꞽr"},
/* 136B6 */ { "HIÉROGLYPHE ÉGYPTIEN-136B6","	* classificateur divinité : ḫnt.y-ꞽmn.tyw"},
/* 136B7 */ { "HIÉROGLYPHE ÉGYPTIEN-136B7","	* classificateur création, forme : ꞽr.w"},
/* 136B8 */ { "HIÉROGLYPHE ÉGYPTIEN-136B8","	* classificateur dormir, passer la nuit : sḏr"},
/* 136B9 */ { "HIÉROGLYPHE ÉGYPTIEN-136B9","	* classificateur statue : ẖn.ty"},
/* 136BA */ { "HIÉROGLYPHE ÉGYPTIEN-136BA",NULL},
/* 136BB */ { "HIÉROGLYPHE ÉGYPTIEN-136BB","	* classificateur statue : twt"},
/* 136BC */ { "HIÉROGLYPHE ÉGYPTIEN-136BC",NULL},
/* 136BD */ { "HIÉROGLYPHE ÉGYPTIEN-136BD","	* logogramme (statue) : mnw"},
/* 136BE */ { "HIÉROGLYPHE ÉGYPTIEN-136BE","	* classificateur statue : mnw"},
/* 136BF */ { "HIÉROGLYPHE ÉGYPTIEN-136BF","	* classificateur chaise à porteurs : wr-ꜥ"},
/* 136C0 */ { "HIÉROGLYPHE ÉGYPTIEN-136C0","	* classificateur divinité : ꜥḳ.t-m-rw.ty"},
/* 136C1 */ { "HIÉROGLYPHE ÉGYPTIEN-136C1","	* classificateur statue : smn"},
/* 136C2 */ { "HIÉROGLYPHE ÉGYPTIEN-136C2","	* logogramme (monument) ? : mn.w"},
/* 136C3 */ { "HIÉROGLYPHE ÉGYPTIEN-136C3",NULL},
/* 136C4 */ { "HIÉROGLYPHE ÉGYPTIEN-136C4","	* classificateur s'éveiller : nhsꞽ"},
/* 136C5 */ { "HIÉROGLYPHE ÉGYPTIEN-136C5","	* classificateur dormir : sḏr"},
/* 136C6 */ { "HIÉROGLYPHE ÉGYPTIEN-136C6","	* classificateur : ẖꜣ.t"},
/* 136C7 */ { "HIÉROGLYPHE ÉGYPTIEN-136C7","	* classificateur cadavre : ẖꜣ.t"},
/* 136C8 */ { "HIÉROGLYPHE ÉGYPTIEN-136C8","	* classificateur dormir : sḏr"},
/* 136C9 */ { "HIÉROGLYPHE ÉGYPTIEN-136C9","	* classificateur récipient à onguent sous la forme du roi : snn"},
/* 136CA */ { "HIÉROGLYPHE ÉGYPTIEN-136CA","	* classificateur vin : ꞽrp"},
/* 136CB */ { "HIÉROGLYPHE ÉGYPTIEN-136CB","	* logogramme (vénérer) : dwꜣ"},
/* 136CC */ { "HIÉROGLYPHE ÉGYPTIEN-136CC","	* phonémogramme/logogramme (million, beaucoup) : ḥḥ"},
/* 136CD */ { "HIÉROGLYPHE ÉGYPTIEN-136CD","	* phonémogramme : š"},
/* 136CE */ { "HIÉROGLYPHE ÉGYPTIEN-136CE",NULL},
/* 136CF */ { "HIÉROGLYPHE ÉGYPTIEN-136CF","	* logogramme (aimer) : mrꞽ"},
/* 136D0 */ { "HIÉROGLYPHE ÉGYPTIEN-136D0","	* logogramme (son concitoyen) : nꞽw.ty=f"},
/* 136D1 */ { "HIÉROGLYPHE ÉGYPTIEN-136D1","	* classificateur jouant : ḥꜥb"},
/* 136D2 */ { "HIÉROGLYPHE ÉGYPTIEN-136D2","	* classificateur jouant : ḥꜥb"},
/* 136D3 */ { "HIÉROGLYPHE ÉGYPTIEN-136D3","	* logogramme (dieux) : nṯr.w"},
/* 136D4 */ { "HIÉROGLYPHE ÉGYPTIEN-136D4","	* phonémogramme : ṯ"},
/* 136D5 */ { "HIÉROGLYPHE ÉGYPTIEN-136D5","	* logogramme (majesté) : ḥm.t"},
/* 136D6 */ { "HIÉROGLYPHE ÉGYPTIEN-136D6","	* logogramme (première personne du singulier féminin) : ꞽ"},
/* 136D7 */ { "HIÉROGLYPHE ÉGYPTIEN-136D7","	* classificateur divinité : n.t"},
/* 136D8 */ { "HIÉROGLYPHE ÉGYPTIEN-136D8",NULL},
/* 136D9 */ { "HIÉROGLYPHE ÉGYPTIEN-136D9","	* classificateur divinité : tfn.t"},
/* 136DA */ { "HIÉROGLYPHE ÉGYPTIEN-136DA","	* phonémogramme : ṯ"},
/* 136DB */ { "HIÉROGLYPHE ÉGYPTIEN-136DB","	* classificateur divinité : ẖrsk.t"},
/* 136DC */ { "HIÉROGLYPHE ÉGYPTIEN-136DC","	* classificateur souveraine : ḥḳꜣ.t"},
/* 136DD */ { "HIÉROGLYPHE ÉGYPTIEN-136DD",NULL},
/* 136DE */ { "HIÉROGLYPHE ÉGYPTIEN-136DE","	* logogramme (maîtresse) : ḥnw.t"},
/* 136DF */ { "HIÉROGLYPHE ÉGYPTIEN-136DF","	* classificateur nom personnel : ꜥnḫ=s-n-ꜣs.t"},
/* 136E0 */ { "HIÉROGLYPHE ÉGYPTIEN-136E0","	* classificateur nom personnel : ḥr-ꜥnḫ"},
/* 136E1 */ { "HIÉROGLYPHE ÉGYPTIEN-136E1","	* phonémogramme : n(w)ꞽ"},
/* 136E2 */ { "HIÉROGLYPHE ÉGYPTIEN-136E2","	* logogramme (Maât) : mꜣꜥ.t"},
/* 136E3 */ { "HIÉROGLYPHE ÉGYPTIEN-136E3","	* phonémogramme (dans ḥw.t-ꞽr.yw (salle des archives/scriptorium)) : ꞽr.y"},
/* 136E4 */ { "HIÉROGLYPHE ÉGYPTIEN-136E4","	* classificateur ennemi : ḫft.ywt"},
/* 136E5 */ { "HIÉROGLYPHE ÉGYPTIEN-136E5","	* logogramme (première personne du singulier) : ꞽ"},
/* 136E6 */ { "HIÉROGLYPHE ÉGYPTIEN-136E6","	* classificateur jeunesse : nḫḫ"},
/* 136E7 */ { "HIÉROGLYPHE ÉGYPTIEN-136E7","	* phonémogramme : ṯ"},
/* 136E8 */ { "HIÉROGLYPHE ÉGYPTIEN-136E8","	* classificateur divinité : ꞽmn.t"},
/* 136E9 */ { "HIÉROGLYPHE ÉGYPTIEN-136E9","	* classificateur souveraine : ḥḳꜣ.t"},
/* 136EA */ { "HIÉROGLYPHE ÉGYPTIEN-136EA","	* logogramme (maîtresse) : ḥnw.t"},
/* 136EB */ { "HIÉROGLYPHE ÉGYPTIEN-136EB","	* classificateur divinité : srḳ.t"},
/* 136EC */ { "HIÉROGLYPHE ÉGYPTIEN-136EC",NULL},
/* 136ED */ { "HIÉROGLYPHE ÉGYPTIEN-136ED","	* phonémogramme : f"},
/* 136EE */ { "HIÉROGLYPHE ÉGYPTIEN-136EE","	* classificateur femme : ḥm.t"},
/* 136EF */ { "HIÉROGLYPHE ÉGYPTIEN-136EF","	* classificateur divinité (titre de šntꜣyt) : ḳꜣ.t-bꜣ.w"},
/* 136F0 */ { "HIÉROGLYPHE ÉGYPTIEN-136F0","	* classificateur relation : ꜣb.wt"},
/* 136F1 */ { "HIÉROGLYPHE ÉGYPTIEN-136F1",NULL},
/* 136F2 */ { "HIÉROGLYPHE ÉGYPTIEN-136F2","	* phonémogramme : ṯ"},
/* 136F3 */ { "HIÉROGLYPHE ÉGYPTIEN-136F3","	* classificateur nom (personne décédée)"},
/* 136F4 */ { "HIÉROGLYPHE ÉGYPTIEN-136F4","	* outil de brochage/filage"},
/* 136F5 */ { "HIÉROGLYPHE ÉGYPTIEN-136F5",NULL},
/* 136F6 */ { "HIÉROGLYPHE ÉGYPTIEN-136F6","	* classificateur femme stérile : snb.t"},
/* 136F7 */ { "HIÉROGLYPHE ÉGYPTIEN-136F7","	* classificateur pleurer : ḥꜣꞽ"},
/* 136F8 */ { "HIÉROGLYPHE ÉGYPTIEN-136F8","	* phonémogramme (pour former mr.ty (les deux yeux)) : mrt"},
/* 136F9 */ { "HIÉROGLYPHE ÉGYPTIEN-136F9","	* classificateur accueillir : nyny"},
/* 136FA */ { "HIÉROGLYPHE ÉGYPTIEN-136FA","	* classificateur louer : dwꜣ"},
/* 136FB */ { "HIÉROGLYPHE ÉGYPTIEN-136FB","	* classificateur pleureuse : ḥꜣ.t"},
/* 136FC */ { "HIÉROGLYPHE ÉGYPTIEN-136FC","	* classificateur divinité : wrr.t"},
/* 136FD */ { "HIÉROGLYPHE ÉGYPTIEN-136FD",NULL},
/* 136FE */ { "HIÉROGLYPHE ÉGYPTIEN-136FE","	* classificateur fortune : rnn.t"},
/* 136FF */ { "HIÉROGLYPHE ÉGYPTIEN-136FF","	* classificateur applaudir et phonémogramme : dḫn & s"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_37[] = {
/* 13700 */ { "HIÉROGLYPHE ÉGYPTIEN-13700","	* logogramme (être noble) : šps"},
/* 13701 */ { "HIÉROGLYPHE ÉGYPTIEN-13701","	* logogramme (être noble) : šps"},
/* 13702 */ { "HIÉROGLYPHE ÉGYPTIEN-13702","	* logogramme (être noble) : šps"},
/* 13703 */ { "HIÉROGLYPHE ÉGYPTIEN-13703","	* logogramme (femme de la noblesse) : šps.t"},
/* 13704 */ { "HIÉROGLYPHE ÉGYPTIEN-13704","	* logogramme (femme de la noblesse) : šps.t"},
/* 13705 */ { "HIÉROGLYPHE ÉGYPTIEN-13705","	* logogramme (femme de la noblesse) : šps.t"},
/* 13706 */ { "HIÉROGLYPHE ÉGYPTIEN-13706","	* classificateur nom royauté féminine : ḫnt-kꜣ.w=s"},
/* 13707 */ { "HIÉROGLYPHE ÉGYPTIEN-13707",NULL},
/* 13708 */ { "HIÉROGLYPHE ÉGYPTIEN-13708","	* classificateur nom personnel : ḥtp-ḥr=s"},
/* 13709 */ { "HIÉROGLYPHE ÉGYPTIEN-13709","	* classificateur nom personnel"},
/* 1370A */ { "HIÉROGLYPHE ÉGYPTIEN-1370A","	* logogramme (être noble) : šps"},
/* 1370B */ { "HIÉROGLYPHE ÉGYPTIEN-1370B",NULL},
/* 1370C */ { "HIÉROGLYPHE ÉGYPTIEN-1370C","	* logogramme (être noble) : šps"},
/* 1370D */ { "HIÉROGLYPHE ÉGYPTIEN-1370D","	* classificateur repos : snḏm"},
/* 1370E */ { "HIÉROGLYPHE ÉGYPTIEN-1370E","	* classificateur jeunesse : rnpꞽ"},
/* 1370F */ { "HIÉROGLYPHE ÉGYPTIEN-1370F","	* classificateur nom"},
/* 13710 */ { "HIÉROGLYPHE ÉGYPTIEN-13710","	* classificateur accueillir : nyny"},
/* 13711 */ { "HIÉROGLYPHE ÉGYPTIEN-13711","	* classificateur accueillir : nyny"},
/* 13712 */ { "HIÉROGLYPHE ÉGYPTIEN-13712",NULL},
/* 13713 */ { "HIÉROGLYPHE ÉGYPTIEN-13713","	* classificateur pleureuses : ḥ(ꜣ)y.t"},
/* 13714 */ { "HIÉROGLYPHE ÉGYPTIEN-13714","	* classificateur crieuses, pleureuses : sgb.wt"},
/* 13715 */ { "HIÉROGLYPHE ÉGYPTIEN-13715","	* classificateur divinité : ꜣs.t"},
/* 13716 */ { "HIÉROGLYPHE ÉGYPTIEN-13716","	* classificateur relation : ḫnms.t"},
/* 13717 */ { "HIÉROGLYPHE ÉGYPTIEN-13717","	* classificateur élever, soutenir : ḫy"},
/* 13718 */ { "HIÉROGLYPHE ÉGYPTIEN-13718","	* classificateur chantant : šmꜥ"},
/* 13719 */ { "HIÉROGLYPHE ÉGYPTIEN-13719","	* phonémogramme : sw"},
/* 1371A */ { "HIÉROGLYPHE ÉGYPTIEN-1371A","	* logogramme (gouverner) : ḥḳꜣ"},
/* 1371B */ { "HIÉROGLYPHE ÉGYPTIEN-1371B","	* phonémogramme : nḏ"},
/* 1371C */ { "HIÉROGLYPHE ÉGYPTIEN-1371C","	* classificateur pleureuse : ḥꜣy.t"},
/* 1371D */ { "HIÉROGLYPHE ÉGYPTIEN-1371D",NULL},
/* 1371E */ { "HIÉROGLYPHE ÉGYPTIEN-1371E","	* logogramme (femme de la noblesse) : sr.t"},
/* 1371F */ { "HIÉROGLYPHE ÉGYPTIEN-1371F","	* logogramme (souveraine) : ꞽt.yt"},
/* 13720 */ { "HIÉROGLYPHE ÉGYPTIEN-13720","	* phonémogramme : w"},
/* 13721 */ { "HIÉROGLYPHE ÉGYPTIEN-13721","	* logogramme (être âgé, âge avancé) : ꞽꜣwꞽ"},
/* 13722 */ { "HIÉROGLYPHE ÉGYPTIEN-13722","	* logogramme (dame noble) : rpy.t"},
/* 13723 */ { "HIÉROGLYPHE ÉGYPTIEN-13723","	* logogramme (souveraine) : ꞽt.yt"},
/* 13724 */ { "HIÉROGLYPHE ÉGYPTIEN-13724","	* phonémogramme (cryptographie) : t/r"},
/* 13725 */ { "HIÉROGLYPHE ÉGYPTIEN-13725","	* classificateur pleureuse : ḥꜣy.t"},
/* 13726 */ { "HIÉROGLYPHE ÉGYPTIEN-13726","	* classificateur ? : šꜣ.tw"},
/* 13727 */ { "HIÉROGLYPHE ÉGYPTIEN-13727","	* classificateur danseuse : ꞽhb.t"},
/* 13728 */ { "HIÉROGLYPHE ÉGYPTIEN-13728","	* classificateur allaitement, éducation : ꜣṯ"},
/* 13729 */ { "HIÉROGLYPHE ÉGYPTIEN-13729","	* classificateur : ꜥtꜣ"},
/* 1372A */ { "HIÉROGLYPHE ÉGYPTIEN-1372A",NULL},
/* 1372B */ { "HIÉROGLYPHE ÉGYPTIEN-1372B","	* classificateur sœur royale : sn.t"},
/* 1372C */ { "HIÉROGLYPHE ÉGYPTIEN-1372C","	* classificateur nom personnel royal : nfr-nfr.w-ꞽtn-nfr.ty-ꞽyꞽ.tꞽ"},
/* 1372D */ { "HIÉROGLYPHE ÉGYPTIEN-1372D",NULL},
/* 1372E */ { "HIÉROGLYPHE ÉGYPTIEN-1372E",NULL},
/* 1372F */ { "HIÉROGLYPHE ÉGYPTIEN-1372F","	* logogramme (roi de Haute-Égypte) : n.y-sw.t"},
/* 13730 */ { "HIÉROGLYPHE ÉGYPTIEN-13730","	* phonémogramme : b"},
/* 13731 */ { "HIÉROGLYPHE ÉGYPTIEN-13731",NULL},
/* 13732 */ { "HIÉROGLYPHE ÉGYPTIEN-13732","	* logogramme (réjouissance) : nhm"},
/* 13733 */ { "HIÉROGLYPHE ÉGYPTIEN-13733","	* classificateur se réjouir : nhm"},
/* 13734 */ { "HIÉROGLYPHE ÉGYPTIEN-13734","	* classificateur jubilation : sꜣ-tꜣ"},
/* 13735 */ { "HIÉROGLYPHE ÉGYPTIEN-13735","	* classificateur joueuse de sistre : sḫm.y(t)"},
/* 13736 */ { "HIÉROGLYPHE ÉGYPTIEN-13736","	* classificateur créatrice de rythme : dḫn.t"},
/* 13737 */ { "HIÉROGLYPHE ÉGYPTIEN-13737","	* classificateur naissance : msꞽ"},
/* 13738 */ { "HIÉROGLYPHE ÉGYPTIEN-13738","	* classificateur nourrice : ꜣṯ.(y)t"},
/* 13739 */ { "HIÉROGLYPHE ÉGYPTIEN-13739","	* logogramme (accoucher, mettre au monde) : msꞽ"},
/* 1373A */ { "HIÉROGLYPHE ÉGYPTIEN-1373A","	* classificateur naissance : msꞽ"},
/* 1373B */ { "HIÉROGLYPHE ÉGYPTIEN-1373B","	* classificateur naissance : msꞽ"},
/* 1373C */ { "HIÉROGLYPHE ÉGYPTIEN-1373C","	* classificateur naissance : msꞽ"},
/* 1373D */ { "HIÉROGLYPHE ÉGYPTIEN-1373D","	* classificateur nourrice : ḫnm.t"},
/* 1373E */ { "HIÉROGLYPHE ÉGYPTIEN-1373E",NULL},
/* 1373F */ { "HIÉROGLYPHE ÉGYPTIEN-1373F","	* logogramme (nourrice) : ḫnm.t"},
/* 13740 */ { "HIÉROGLYPHE ÉGYPTIEN-13740","	* logogramme (nourrice) : ḫnm.t"},
/* 13741 */ { "HIÉROGLYPHE ÉGYPTIEN-13741",NULL},
/* 13742 */ { "HIÉROGLYPHE ÉGYPTIEN-13742","	* classificateur allaitement, éducation : rnn"},
/* 13743 */ { "HIÉROGLYPHE ÉGYPTIEN-13743","	* classificateur allaitement, éducation : rnn"},
/* 13744 */ { "HIÉROGLYPHE ÉGYPTIEN-13744","	* classificateur danseuse, acrobate : ḫb.t"},
/* 13745 */ { "HIÉROGLYPHE ÉGYPTIEN-13745","	* phonémogramme : nḏ"},
/* 13746 */ { "HIÉROGLYPHE ÉGYPTIEN-13746",NULL},
/* 13747 */ { "HIÉROGLYPHE ÉGYPTIEN-13747","	* classificateur mouvement de va-et-vient : wnwn"},
/* 13748 */ { "HIÉROGLYPHE ÉGYPTIEN-13748","	* phonémogramme (cryptographie) : st.y-m"},
/* 13749 */ { "HIÉROGLYPHE ÉGYPTIEN-13749","	* logogramme (en combinaison avec \\C268B) : rꜥ-nb"},
/* 1374A */ { "HIÉROGLYPHE ÉGYPTIEN-1374A","	* classificateur lune : ꞽꜥḥ"},
/* 1374B */ { "HIÉROGLYPHE ÉGYPTIEN-1374B","	* classificateur lune/lumière (avec Rê, représentant le Soleil et la Lune comme les deux lumières) : ḥꜣy.ty"},
/* 1374C */ { "HIÉROGLYPHE ÉGYPTIEN-1374C",NULL},
/* 1374D */ { "HIÉROGLYPHE ÉGYPTIEN-1374D","	* logogramme (Geb) : gbb"},
/* 1374E */ { "HIÉROGLYPHE ÉGYPTIEN-1374E","	* logogramme (Geb) : gbb"},
/* 1374F */ { "HIÉROGLYPHE ÉGYPTIEN-1374F","	* logogramme (le créateur de la terre (divinité)) : ꞽr-tꜣ"},
/* 13750 */ { "HIÉROGLYPHE ÉGYPTIEN-13750",NULL},
/* 13751 */ { "HIÉROGLYPHE ÉGYPTIEN-13751","	* logogramme (l'énoncé, divinité) : ḥw"},
/* 13752 */ { "HIÉROGLYPHE ÉGYPTIEN-13752","	* logogramme (l'énoncé, divinité) : ḥw"},
/* 13753 */ { "HIÉROGLYPHE ÉGYPTIEN-13753","	* logogramme (perception/connaissance (divinité)) : sꞽꜣ"},
/* 13754 */ { "HIÉROGLYPHE ÉGYPTIEN-13754","	* logogramme (perception/connaissance (divinité)) : sꞽꜣ"},
/* 13755 */ { "HIÉROGLYPHE ÉGYPTIEN-13755",NULL},
/* 13756 */ { "HIÉROGLYPHE ÉGYPTIEN-13756",NULL},
/* 13757 */ { "HIÉROGLYPHE ÉGYPTIEN-13757",NULL},
/* 13758 */ { "HIÉROGLYPHE ÉGYPTIEN-13758","	* logogramme (première personne du singulier, pour Harsomtous) : ꞽ"},
/* 13759 */ { "HIÉROGLYPHE ÉGYPTIEN-13759","	* classificateur Khépri (divinité)"},
/* 1375A */ { "HIÉROGLYPHE ÉGYPTIEN-1375A","	* logogramme (esprit) : kꜣ"},
/* 1375B */ { "HIÉROGLYPHE ÉGYPTIEN-1375B","	* logogramme (dieu) : nṯr"},
/* 1375C */ { "HIÉROGLYPHE ÉGYPTIEN-1375C","	* classificateur divinité (Chai) : šꞣy"},
/* 1375D */ { "HIÉROGLYPHE ÉGYPTIEN-1375D","	* classificateur divinité : tꜣ-ṯnn"},
/* 1375E */ { "HIÉROGLYPHE ÉGYPTIEN-1375E",NULL},
/* 1375F */ { "HIÉROGLYPHE ÉGYPTIEN-1375F","	* classificateur divinité : pḏ.ty"},
/* 13760 */ { "HIÉROGLYPHE ÉGYPTIEN-13760","	* classificateur divinité (Nekhbet)"},
/* 13761 */ { "HIÉROGLYPHE ÉGYPTIEN-13761","	* logogramme (Khépri) : ḫprꞽ"},
/* 13762 */ { "HIÉROGLYPHE ÉGYPTIEN-13762","	* classificateur Khépri (divinité)"},
/* 13763 */ { "HIÉROGLYPHE ÉGYPTIEN-13763","	* logogramme (Amon) : ꞽmn"},
/* 13764 */ { "HIÉROGLYPHE ÉGYPTIEN-13764","	* classificateur divinité : ꞽn-ḥr-šw"},
/* 13765 */ { "HIÉROGLYPHE ÉGYPTIEN-13765","	* logogramme (Maât et Amon) : mꜣꜥ.t & ꞽmn"},
/* 13766 */ { "HIÉROGLYPHE ÉGYPTIEN-13766","	* logogramme (Amon) : ꞽmn"},
/* 13767 */ { "HIÉROGLYPHE ÉGYPTIEN-13767","	* logogramme (Amon) : ꞽmn"},
/* 13768 */ { "HIÉROGLYPHE ÉGYPTIEN-13768","	* logogramme (image vivante d'Amon) : sḫm-ꜥnḫ-n-ꞽmn"},
/* 13769 */ { "HIÉROGLYPHE ÉGYPTIEN-13769","	* logogramme divinité : ꞽr-ṯꜥw"},
/* 1376A */ { "HIÉROGLYPHE ÉGYPTIEN-1376A",NULL},
/* 1376B */ { "HIÉROGLYPHE ÉGYPTIEN-1376B",NULL},
/* 1376C */ { "HIÉROGLYPHE ÉGYPTIEN-1376C","	* classificateur allaitement, éducation : rnn"},
/* 1376D */ { "HIÉROGLYPHE ÉGYPTIEN-1376D","	* logogramme (Amon) : ꞽmn"},
/* 1376E */ { "HIÉROGLYPHE ÉGYPTIEN-1376E","	* classificateur Oupouaout (divinité)"},
/* 1376F */ { "HIÉROGLYPHE ÉGYPTIEN-1376F",NULL},
/* 13770 */ { "HIÉROGLYPHE ÉGYPTIEN-13770","	* classificateur divinité : ḏsr-m-pr=f-m-sbḫ.t-ꜣḫ.t"},
/* 13771 */ { "HIÉROGLYPHE ÉGYPTIEN-13771","	* phonémogramme : n"},
/* 13772 */ { "HIÉROGLYPHE ÉGYPTIEN-13772","	* classificateur jubilation : hnw"},
/* 13773 */ { "HIÉROGLYPHE ÉGYPTIEN-13773","	* logogramme (repousser) : sḥrꞽ"},
/* 13774 */ { "HIÉROGLYPHE ÉGYPTIEN-13774","	* logogramme (repousser) : sḥrꞽ"},
/* 13775 */ { "HIÉROGLYPHE ÉGYPTIEN-13775",NULL},
/* 13776 */ { "HIÉROGLYPHE ÉGYPTIEN-13776","	* logogramme (repousser) : sḥrꞽ"},
/* 13777 */ { "HIÉROGLYPHE ÉGYPTIEN-13777","	* logogramme (repousser) : sḥrꞽ"},
/* 13778 */ { "HIÉROGLYPHE ÉGYPTIEN-13778","	* classificateur éloignant : sḥrꞽ"},
/* 13779 */ { "HIÉROGLYPHE ÉGYPTIEN-13779","	* logogramme (Douamoutef) : dwꜣ-mw.t=f"},
/* 1377A */ { "HIÉROGLYPHE ÉGYPTIEN-1377A","	* logogramme (être fort) : wsr"},
/* 1377B */ { "HIÉROGLYPHE ÉGYPTIEN-1377B","	* logogramme (souveraine) : ꞽt.yt"},
/* 1377C */ { "HIÉROGLYPHE ÉGYPTIEN-1377C","	* logogramme (Anubis) : ꞽnpw"},
/* 1377D */ { "HIÉROGLYPHE ÉGYPTIEN-1377D","	* classificateur messager : wpw.ty"},
/* 1377E */ { "HIÉROGLYPHE ÉGYPTIEN-1377E","	* logogramme (messager) : wpw.ty"},
/* 1377F */ { "HIÉROGLYPHE ÉGYPTIEN-1377F","	* logogramme (repousser) : sḥrꞽ"},
/* 13780 */ { "HIÉROGLYPHE ÉGYPTIEN-13780","	* logogramme (repousser) : sḥrꞽ"},
/* 13781 */ { "HIÉROGLYPHE ÉGYPTIEN-13781",NULL},
/* 13782 */ { "HIÉROGLYPHE ÉGYPTIEN-13782",NULL},
/* 13783 */ { "HIÉROGLYPHE ÉGYPTIEN-13783",NULL},
/* 13784 */ { "HIÉROGLYPHE ÉGYPTIEN-13784","	* logogramme (repousser) : sḥrꞽ"},
/* 13785 */ { "HIÉROGLYPHE ÉGYPTIEN-13785","	* logogramme : šmꜣ.y"},
/* 13786 */ { "HIÉROGLYPHE ÉGYPTIEN-13786","	* classificateur : nb.w-nr.w"},
/* 13787 */ { "HIÉROGLYPHE ÉGYPTIEN-13787",NULL},
/* 13788 */ { "HIÉROGLYPHE ÉGYPTIEN-13788","	* logogramme (démon de la mort) : šmꜣ.y"},
/* 13789 */ { "HIÉROGLYPHE ÉGYPTIEN-13789","	* logogramme (démon de la mort) : šmꜣ.y"},
/* 1378A */ { "HIÉROGLYPHE ÉGYPTIEN-1378A","	* logogramme (démon de la mort) : šmꜣ.yt"},
/* 1378B */ { "HIÉROGLYPHE ÉGYPTIEN-1378B","	* logogramme (repousser) : sḥrꞽ"},
/* 1378C */ { "HIÉROGLYPHE ÉGYPTIEN-1378C","	* logogramme (inhumation) : ḳrs.t"},
/* 1378D */ { "HIÉROGLYPHE ÉGYPTIEN-1378D","	* classificateur protecteur : (nḏ.t(y)t)"},
/* 1378E */ { "HIÉROGLYPHE ÉGYPTIEN-1378E",NULL},
/* 1378F */ { "HIÉROGLYPHE ÉGYPTIEN-1378F","	* classificateur divinité (Apis) : ḥp"},
/* 13790 */ { "HIÉROGLYPHE ÉGYPTIEN-13790","	* classificateur protecteur : mnw-n(y)-sw.t-m-nḫ.t=f"},
/* 13791 */ { "HIÉROGLYPHE ÉGYPTIEN-13791","	* phonémogramme : wp"},
/* 13792 */ { "HIÉROGLYPHE ÉGYPTIEN-13792",NULL},
/* 13793 */ { "HIÉROGLYPHE ÉGYPTIEN-13793","	* phonémogramme : w"},
/* 13794 */ { "HIÉROGLYPHE ÉGYPTIEN-13794","	* logogramme (Chou) : šw"},
/* 13795 */ { "HIÉROGLYPHE ÉGYPTIEN-13795","	* logogramme (fils/enfant de) : sꜣ"},
/* 13796 */ { "HIÉROGLYPHE ÉGYPTIEN-13796","	* logogramme (Horus) : ḥr"},
/* 13797 */ { "HIÉROGLYPHE ÉGYPTIEN-13797","	* classificateur joie : hnw"},
/* 13798 */ { "HIÉROGLYPHE ÉGYPTIEN-13798","	* classificateur divinité faucon : bḥd.ty"},
/* 13799 */ { "HIÉROGLYPHE ÉGYPTIEN-13799","	* classificateur divinité : snw"},
/* 1379A */ { "HIÉROGLYPHE ÉGYPTIEN-1379A","	* logogramme (majesté) : ḥm"},
/* 1379B */ { "HIÉROGLYPHE ÉGYPTIEN-1379B","	* phonémogramme/logogramme : sḫm"},
/* 1379C */ { "HIÉROGLYPHE ÉGYPTIEN-1379C","	* classificateur divinité : sꜣḳ-ḥꜥ.w"},
/* 1379D */ { "HIÉROGLYPHE ÉGYPTIEN-1379D","	* logogramme (Rê) : rꜥ"},
/* 1379E */ { "HIÉROGLYPHE ÉGYPTIEN-1379E","	* logogramme (Rê) : rꜥ"},
/* 1379F */ { "HIÉROGLYPHE ÉGYPTIEN-1379F","	* logogramme (Rê) : rꜥ"},
/* 137A0 */ { "HIÉROGLYPHE ÉGYPTIEN-137A0","	* logogramme (jour) : hrw"},
/* 137A1 */ { "HIÉROGLYPHE ÉGYPTIEN-137A1","	* logogramme (Rê) : rꜥ"},
/* 137A2 */ { "HIÉROGLYPHE ÉGYPTIEN-137A2","	* logogramme (Rê) : rꜥ"},
/* 137A3 */ { "HIÉROGLYPHE ÉGYPTIEN-137A3",NULL},
/* 137A4 */ { "HIÉROGLYPHE ÉGYPTIEN-137A4","	* logogramme (Rê) : rꜥ"},
/* 137A5 */ { "HIÉROGLYPHE ÉGYPTIEN-137A5","	* logogramme (Rê et image) : rꜥ & sḫm"},
/* 137A6 */ { "HIÉROGLYPHE ÉGYPTIEN-137A6","	* logogramme (Rê et image) : rꜥ & sḫm"},
/* 137A7 */ { "HIÉROGLYPHE ÉGYPTIEN-137A7","	* logogramme (l'œil de Rê) : ꞽr.t-rꜥ"},
/* 137A8 */ { "HIÉROGLYPHE ÉGYPTIEN-137A8","	* logogramme (de Rê) : n rꜥ"},
/* 137A9 */ { "HIÉROGLYPHE ÉGYPTIEN-137A9","	* logogramme (fils de Rê) : sꜣ-rꜥ"},
/* 137AA */ { "HIÉROGLYPHE ÉGYPTIEN-137AA","	* classificateur statue, représentation : sšm(.w)"},
/* 137AB */ { "HIÉROGLYPHE ÉGYPTIEN-137AB","	* classificateur divinité : ꜥꜣ-mꜣꜥ-ḫrw"},
/* 137AC */ { "HIÉROGLYPHE ÉGYPTIEN-137AC","	* logogramme (vivre) : ꜥnḫ"},
/* 137AD */ { "HIÉROGLYPHE ÉGYPTIEN-137AD","	* logogramme (œil d'Horus) : ꞽr.t-ḥr"},
/* 137AE */ { "HIÉROGLYPHE ÉGYPTIEN-137AE","	* phonémogramme/logogramme (seigneur) : nb"},
/* 137AF */ { "HIÉROGLYPHE ÉGYPTIEN-137AF","	* logogramme (majesté) : ḥm"},
/* 137B0 */ { "HIÉROGLYPHE ÉGYPTIEN-137B0","	* logogramme (esprit) : kꜣ"},
/* 137B1 */ { "HIÉROGLYPHE ÉGYPTIEN-137B1","	* logogramme (pouvoir, force) : ḫpš"},
/* 137B2 */ { "HIÉROGLYPHE ÉGYPTIEN-137B2","	* phonémogramme/logogramme : sḫm"},
/* 137B3 */ { "HIÉROGLYPHE ÉGYPTIEN-137B3","	* logogramme (dieu) : nṯr"},
/* 137B4 */ { "HIÉROGLYPHE ÉGYPTIEN-137B4","	* logogramme (bien-aimé d'Horus) : mr.y-ḥr"},
/* 137B5 */ { "HIÉROGLYPHE ÉGYPTIEN-137B5","	* classificateur Sokar (divinité)"},
/* 137B6 */ { "HIÉROGLYPHE ÉGYPTIEN-137B6","	* classificateur Sokar (divinité)"},
/* 137B7 */ { "HIÉROGLYPHE ÉGYPTIEN-137B7",NULL},
/* 137B8 */ { "HIÉROGLYPHE ÉGYPTIEN-137B8","	* classificateur Montou (divinité)"},
/* 137B9 */ { "HIÉROGLYPHE ÉGYPTIEN-137B9","	* classificateur divinité : mr.ty"},
/* 137BA */ { "HIÉROGLYPHE ÉGYPTIEN-137BA","	* logogramme (première personne du singulier) : ꞽ"},
/* 137BB */ { "HIÉROGLYPHE ÉGYPTIEN-137BB",NULL},
/* 137BC */ { "HIÉROGLYPHE ÉGYPTIEN-137BC","	* logogramme (Khonsou) : ḫnsw"},
/* 137BD */ { "HIÉROGLYPHE ÉGYPTIEN-137BD","	* classificateur Khonsou (divinité)"},
/* 137BE */ { "HIÉROGLYPHE ÉGYPTIEN-137BE",NULL},
/* 137BF */ { "HIÉROGLYPHE ÉGYPTIEN-137BF","	* logogramme (celui de l'horizon) : ꜣḫ.ty"},
/* 137C0 */ { "HIÉROGLYPHE ÉGYPTIEN-137C0",NULL},
/* 137C1 */ { "HIÉROGLYPHE ÉGYPTIEN-137C1","	* logogramme (dieu) : nṯr"},
/* 137C2 */ { "HIÉROGLYPHE ÉGYPTIEN-137C2","	* logogramme (dans la construction ꜥnḫ-nṯr-nfr) : ꜥnḫ-nṯr"},
/* 137C3 */ { "HIÉROGLYPHE ÉGYPTIEN-137C3","	* logogramme (dieu et déesse) : nṯr nṯr.t"},
/* 137C4 */ { "HIÉROGLYPHE ÉGYPTIEN-137C4","	* logogramme (dieu) : nṯr"},
/* 137C5 */ { "HIÉROGLYPHE ÉGYPTIEN-137C5","	* logogramme (Rê) : rꜥ"},
/* 137C6 */ { "HIÉROGLYPHE ÉGYPTIEN-137C6","	* logogramme (celui de l'horizon) : ꜣḫ.ty"},
/* 137C7 */ { "HIÉROGLYPHE ÉGYPTIEN-137C7","	* logogramme (Horus, Béhédety) : ḥr-bḥd.ty"},
/* 137C8 */ { "HIÉROGLYPHE ÉGYPTIEN-137C8","	* logogramme (Horus) : ḥr"},
/* 137C9 */ { "HIÉROGLYPHE ÉGYPTIEN-137C9","	* logogramme (Horus, protecteur de son père, Béhédety, au plumage multicolore, donnant la vie) : ḥr-nḏ-ꞽt=f-bḥd.ty-sꜣb-šw.t-dꞽ-ꜥnḫ"},
/* 137CA */ { "HIÉROGLYPHE ÉGYPTIEN-137CA",NULL},
/* 137CB */ { "HIÉROGLYPHE ÉGYPTIEN-137CB","	* logogramme (dieu) : nṯr"},
/* 137CC */ { "HIÉROGLYPHE ÉGYPTIEN-137CC","	* logogramme (celui de l'horizon) : ꜣḫ.ty"},
/* 137CD */ { "HIÉROGLYPHE ÉGYPTIEN-137CD","	* logogramme (Rê) : rꜥ"},
/* 137CE */ { "HIÉROGLYPHE ÉGYPTIEN-137CE","	* logogramme (Horus de l'est) : ḥr-ꞽꜣb.ty"},
/* 137CF */ { "HIÉROGLYPHE ÉGYPTIEN-137CF",NULL},
/* 137D0 */ { "HIÉROGLYPHE ÉGYPTIEN-137D0","	* logogramme (force, pouvoir) : pḥ.ty"},
/* 137D1 */ { "HIÉROGLYPHE ÉGYPTIEN-137D1","	* logogramme (éternité) : nḥḥ"},
/* 137D2 */ { "HIÉROGLYPHE ÉGYPTIEN-137D2","	* logogramme (éternité) : nḥḥ"},
/* 137D3 */ { "HIÉROGLYPHE ÉGYPTIEN-137D3","	* logogramme (éternité) : nḥḥ"},
/* 137D4 */ { "HIÉROGLYPHE ÉGYPTIEN-137D4","	* logogramme (éternité) : nḥḥ"},
/* 137D5 */ { "HIÉROGLYPHE ÉGYPTIEN-137D5","	* logogramme (le seul, unique) : wꜥ.ty"},
/* 137D6 */ { "HIÉROGLYPHE ÉGYPTIEN-137D6","	* classificateur divinité : ꞽn-ḥr.t"},
/* 137D7 */ { "HIÉROGLYPHE ÉGYPTIEN-137D7","	* logogramme (seigneur des deux terres, lorsque utilisé en relation avec une figure à tête de Seth) : nb-tꜣ.wy"},
/* 137D8 */ { "HIÉROGLYPHE ÉGYPTIEN-137D8","	* classificateur harponneur : ꞽ(ꜣ)w.ty"},
/* 137D9 */ { "HIÉROGLYPHE ÉGYPTIEN-137D9",NULL},
/* 137DA */ { "HIÉROGLYPHE ÉGYPTIEN-137DA","	* logogramme (vaillance, force) : ḳn.t"},
/* 137DB */ { "HIÉROGLYPHE ÉGYPTIEN-137DB","	* logogramme (vaillance, force) : ḳn.t"},
/* 137DC */ { "HIÉROGLYPHE ÉGYPTIEN-137DC","	* logogramme (Kébehsénouf) : ḳbḥ-sn.w=f"},
/* 137DD */ { "HIÉROGLYPHE ÉGYPTIEN-137DD",NULL},
/* 137DE */ { "HIÉROGLYPHE ÉGYPTIEN-137DE","	* phonémogramme : ḥr"},
/* 137DF */ { "HIÉROGLYPHE ÉGYPTIEN-137DF","	* logogramme (Wenty) : wnty"},
/* 137E0 */ { "HIÉROGLYPHE ÉGYPTIEN-137E0","	* logogramme (Wenty) : wnty"},
/* 137E1 */ { "HIÉROGLYPHE ÉGYPTIEN-137E1",NULL},
/* 137E2 */ { "HIÉROGLYPHE ÉGYPTIEN-137E2","	* logogramme (Wenty) : wnty"},
/* 137E3 */ { "HIÉROGLYPHE ÉGYPTIEN-137E3","	* classificateur divinité : wnty"},
/* 137E4 */ { "HIÉROGLYPHE ÉGYPTIEN-137E4","	* classificateur harponneur : (ꞽ)ꜣ(w).ty"},
/* 137E5 */ { "HIÉROGLYPHE ÉGYPTIEN-137E5","	* logogramme (harponneur) ou logogramme (Wenty) : ꞽꜣw.ty | wnty"},
/* 137E6 */ { "HIÉROGLYPHE ÉGYPTIEN-137E6","	* logogramme (Wenty) : wnty"},
/* 137E7 */ { "HIÉROGLYPHE ÉGYPTIEN-137E7","	* classificateur divinité (Geb) : gbb"},
/* 137E8 */ { "HIÉROGLYPHE ÉGYPTIEN-137E8","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137E9 */ { "HIÉROGLYPHE ÉGYPTIEN-137E9","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137EA */ { "HIÉROGLYPHE ÉGYPTIEN-137EA","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137EB */ { "HIÉROGLYPHE ÉGYPTIEN-137EB","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137EC */ { "HIÉROGLYPHE ÉGYPTIEN-137EC","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137ED */ { "HIÉROGLYPHE ÉGYPTIEN-137ED","	* logogramme (millions d'années) : ḥḥ (n) ꜥnḫ"},
/* 137EE */ { "HIÉROGLYPHE ÉGYPTIEN-137EE","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137EF */ { "HIÉROGLYPHE ÉGYPTIEN-137EF","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137F0 */ { "HIÉROGLYPHE ÉGYPTIEN-137F0","	* logogramme (éternité) : ḥḥ"},
/* 137F1 */ { "HIÉROGLYPHE ÉGYPTIEN-137F1",NULL},
/* 137F2 */ { "HIÉROGLYPHE ÉGYPTIEN-137F2","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137F3 */ { "HIÉROGLYPHE ÉGYPTIEN-137F3","	* logogramme (toute l'éternité) : ḥḥ nb"},
/* 137F4 */ { "HIÉROGLYPHE ÉGYPTIEN-137F4",NULL},
/* 137F5 */ { "HIÉROGLYPHE ÉGYPTIEN-137F5","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137F6 */ { "HIÉROGLYPHE ÉGYPTIEN-137F6","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137F7 */ { "HIÉROGLYPHE ÉGYPTIEN-137F7","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137F8 */ { "HIÉROGLYPHE ÉGYPTIEN-137F8","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137F9 */ { "HIÉROGLYPHE ÉGYPTIEN-137F9","	* phonémogramme : ḥ"},
/* 137FA */ { "HIÉROGLYPHE ÉGYPTIEN-137FA","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137FB */ { "HIÉROGLYPHE ÉGYPTIEN-137FB",NULL},
/* 137FC */ { "HIÉROGLYPHE ÉGYPTIEN-137FC","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137FD */ { "HIÉROGLYPHE ÉGYPTIEN-137FD","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137FE */ { "HIÉROGLYPHE ÉGYPTIEN-137FE","	* logogramme (million, beaucoup) : ḥḥ"},
/* 137FF */ { "HIÉROGLYPHE ÉGYPTIEN-137FF","	* logogramme (million, beaucoup) : ḥḥ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_38[] = {
/* 13800 */ { "HIÉROGLYPHE ÉGYPTIEN-13800","	* logogramme (million, beaucoup) : ḥḥ"},
/* 13801 */ { "HIÉROGLYPHE ÉGYPTIEN-13801","	* logogramme (million, beaucoup) : ḥḥ"},
/* 13802 */ { "HIÉROGLYPHE ÉGYPTIEN-13802","	* logogramme (million, beaucoup) : ḥḥ"},
/* 13803 */ { "HIÉROGLYPHE ÉGYPTIEN-13803","	* logogramme (million, beaucoup) : ḥḥ"},
/* 13804 */ { "HIÉROGLYPHE ÉGYPTIEN-13804","	* classificateur sevrer : wḏḥ"},
/* 13805 */ { "HIÉROGLYPHE ÉGYPTIEN-13805","	* classificateur sevrer : wḏḥ"},
/* 13806 */ { "HIÉROGLYPHE ÉGYPTIEN-13806","	* logogramme (Atoum) : ꞽtmw"},
/* 13807 */ { "HIÉROGLYPHE ÉGYPTIEN-13807",NULL},
/* 13808 */ { "HIÉROGLYPHE ÉGYPTIEN-13808","	* classificateur enfant : sḏ.ty"},
/* 13809 */ { "HIÉROGLYPHE ÉGYPTIEN-13809","	* logogramme (première personne du singulier) : ꞽ"},
/* 1380A */ { "HIÉROGLYPHE ÉGYPTIEN-1380A","	* logogramme (Horus l'enfant) : ḥr-pꜣ-ẖrd"},
/* 1380B */ { "HIÉROGLYPHE ÉGYPTIEN-1380B","	* classificateur créateur : ḫnm.w"},
/* 1380C */ { "HIÉROGLYPHE ÉGYPTIEN-1380C","	* logogramme (Khnoum) : ẖnm.w"},
/* 1380D */ { "HIÉROGLYPHE ÉGYPTIEN-1380D","	* logogramme (Khnoum) : ẖnm.w"},
/* 1380E */ { "HIÉROGLYPHE ÉGYPTIEN-1380E","	* phonémogramme : ẖnm"},
/* 1380F */ { "HIÉROGLYPHE ÉGYPTIEN-1380F","	* logogramme (Khnoum) : ẖnm.w"},
/* 13810 */ { "HIÉROGLYPHE ÉGYPTIEN-13810","	* logogramme (Khnoum) : ẖnm.w"},
/* 13811 */ { "HIÉROGLYPHE ÉGYPTIEN-13811","	* logogramme (Khnoum) : ẖnm.w"},
/* 13812 */ { "HIÉROGLYPHE ÉGYPTIEN-13812","	* classificateur Khnoum : ẖnm.w"},
/* 13813 */ { "HIÉROGLYPHE ÉGYPTIEN-13813","	* classificateur Khnoum : ẖnm.w"},
/* 13814 */ { "HIÉROGLYPHE ÉGYPTIEN-13814",NULL},
/* 13815 */ { "HIÉROGLYPHE ÉGYPTIEN-13815","	* logogramme (Khnoum) : ẖnm.w"},
/* 13816 */ { "HIÉROGLYPHE ÉGYPTIEN-13816","	* logogramme (créateur) : nḥp"},
/* 13817 */ { "HIÉROGLYPHE ÉGYPTIEN-13817","	* logogramme (créateur) : nḥp"},
/* 13818 */ { "HIÉROGLYPHE ÉGYPTIEN-13818","	* logogramme (construire, créer) : ḳd"},
/* 13819 */ { "HIÉROGLYPHE ÉGYPTIEN-13819","	* logogramme (créer, former) : nḥp"},
/* 1381A */ { "HIÉROGLYPHE ÉGYPTIEN-1381A","	* logogramme (construire) : ẖnm"},
/* 1381B */ { "HIÉROGLYPHE ÉGYPTIEN-1381B","	* phonémogramme : r"},
/* 1381C */ { "HIÉROGLYPHE ÉGYPTIEN-1381C",NULL},
/* 1381D */ { "HIÉROGLYPHE ÉGYPTIEN-1381D","	* logogramme (messager) : wpw.ty"},
/* 1381E */ { "HIÉROGLYPHE ÉGYPTIEN-1381E","	* logogramme (Min) : mnw"},
/* 1381F */ { "HIÉROGLYPHE ÉGYPTIEN-1381F",NULL},
/* 13820 */ { "HIÉROGLYPHE ÉGYPTIEN-13820","	* classificateur divinité : kꜣ-mw.t=f"},
/* 13821 */ { "HIÉROGLYPHE ÉGYPTIEN-13821",NULL},
/* 13822 */ { "HIÉROGLYPHE ÉGYPTIEN-13822",NULL},
/* 13823 */ { "HIÉROGLYPHE ÉGYPTIEN-13823",NULL},
/* 13824 */ { "HIÉROGLYPHE ÉGYPTIEN-13824","	* logogramme (l'inondation) : hꜥpy"},
/* 13825 */ { "HIÉROGLYPHE ÉGYPTIEN-13825","	* logogramme (l'inondation) : hꜥpy"},
/* 13826 */ { "HIÉROGLYPHE ÉGYPTIEN-13826","	* logogramme (le Nil, l'inondation) : hꜥpy"},
/* 13827 */ { "HIÉROGLYPHE ÉGYPTIEN-13827","	* logogramme (le Nil, l'inondation) : hꜥpy"},
/* 13828 */ { "HIÉROGLYPHE ÉGYPTIEN-13828",NULL},
/* 13829 */ { "HIÉROGLYPHE ÉGYPTIEN-13829","	* logogramme (le Nil, l'inondation) : hꜥpy"},
/* 1382A */ { "HIÉROGLYPHE ÉGYPTIEN-1382A",NULL},
/* 1382B */ { "HIÉROGLYPHE ÉGYPTIEN-1382B","	* logogramme (Onouris) : ꞽn-ḥr.t"},
/* 1382C */ { "HIÉROGLYPHE ÉGYPTIEN-1382C",NULL},
/* 1382D */ { "HIÉROGLYPHE ÉGYPTIEN-1382D","	* logogramme (Onouris) : ꞽn-ḥr.t"},
/* 1382E */ { "HIÉROGLYPHE ÉGYPTIEN-1382E","	* logogramme (Orion) : sꜣḥ"},
/* 1382F */ { "HIÉROGLYPHE ÉGYPTIEN-1382F","	* logogramme (Orion) : sꜣḥ"},
/* 13830 */ { "HIÉROGLYPHE ÉGYPTIEN-13830","	* classificateur Osiris : wsꞽr"},
/* 13831 */ { "HIÉROGLYPHE ÉGYPTIEN-13831","	* logogramme (Osiris) : wsꞽr"},
/* 13832 */ { "HIÉROGLYPHE ÉGYPTIEN-13832",NULL},
/* 13833 */ { "HIÉROGLYPHE ÉGYPTIEN-13833","	* logogramme (celui qui appartient à Seth) : stẖ.y"},
/* 13834 */ { "HIÉROGLYPHE ÉGYPTIEN-13834",NULL},
/* 13835 */ { "HIÉROGLYPHE ÉGYPTIEN-13835","	* classificateur Osiris"},
/* 13836 */ { "HIÉROGLYPHE ÉGYPTIEN-13836","	* classificateur Osiris : wsꞽr"},
/* 13837 */ { "HIÉROGLYPHE ÉGYPTIEN-13837","	* classificateur Osiris : ḫnt.y-ꞽmn.tyw"},
/* 13838 */ { "HIÉROGLYPHE ÉGYPTIEN-13838","	* logogramme (Osiris) : wsꞽr"},
/* 13839 */ { "HIÉROGLYPHE ÉGYPTIEN-13839","	* logogramme (Ptah) : ptḥ"},
/* 1383A */ { "HIÉROGLYPHE ÉGYPTIEN-1383A","	* classificateur Ptah : ptḥ"},
/* 1383B */ { "HIÉROGLYPHE ÉGYPTIEN-1383B","	* logogramme (Ptah) : ptḥ"},
/* 1383C */ { "HIÉROGLYPHE ÉGYPTIEN-1383C","	* classificateur divinité (Imhotep)"},
/* 1383D */ { "HIÉROGLYPHE ÉGYPTIEN-1383D","	* logogramme (Ptah) : ptḥ"},
/* 1383E */ { "HIÉROGLYPHE ÉGYPTIEN-1383E","	* logogramme (divin) : nṯr.y"},
/* 1383F */ { "HIÉROGLYPHE ÉGYPTIEN-1383F","	* logogramme (Ptah) : ptḥ"},
/* 13840 */ { "HIÉROGLYPHE ÉGYPTIEN-13840","	* logogramme (divin) : nṯr.y"},
/* 13841 */ { "HIÉROGLYPHE ÉGYPTIEN-13841","	* logogramme (Ptah) : ptḥ"},
/* 13842 */ { "HIÉROGLYPHE ÉGYPTIEN-13842","	* classificateur divinité : nfr-ḥr"},
/* 13843 */ { "HIÉROGLYPHE ÉGYPTIEN-13843","	* logogramme (Rê) : rꜥ"},
/* 13844 */ { "HIÉROGLYPHE ÉGYPTIEN-13844","	* classificateur roi de Haute-Égypte : n(.y)-sw.t"},
/* 13845 */ { "HIÉROGLYPHE ÉGYPTIEN-13845","	* logogramme (Rê) : rꜥ"},
/* 13846 */ { "HIÉROGLYPHE ÉGYPTIEN-13846","	* logogramme (Khépri) : ḫprꞽ"},
/* 13847 */ { "HIÉROGLYPHE ÉGYPTIEN-13847","	* logogramme (le puissant) : sḫm"},
/* 13848 */ { "HIÉROGLYPHE ÉGYPTIEN-13848",NULL},
/* 13849 */ { "HIÉROGLYPHE ÉGYPTIEN-13849","	* logogramme (celui qui appartient à Seth) : stẖ.y"},
/* 1384A */ { "HIÉROGLYPHE ÉGYPTIEN-1384A","	* logogramme (celui qui appartient à Seth) : stẖ.y"},
/* 1384B */ { "HIÉROGLYPHE ÉGYPTIEN-1384B","	* classificateur misère, douleur : ꜣh/ꞽh"},
/* 1384C */ { "HIÉROGLYPHE ÉGYPTIEN-1384C",NULL},
/* 1384D */ { "HIÉROGLYPHE ÉGYPTIEN-1384D",NULL},
/* 1384E */ { "HIÉROGLYPHE ÉGYPTIEN-1384E","	* classificateur le vil : ẖs-ḳd"},
/* 1384F */ { "HIÉROGLYPHE ÉGYPTIEN-1384F","	* classificateur le malveillant : nbḏ"},
/* 13850 */ { "HIÉROGLYPHE ÉGYPTIEN-13850","	* classificateur création, forme : ꞽr.w"},
/* 13851 */ { "HIÉROGLYPHE ÉGYPTIEN-13851","	* logogramme (Sobek) : sbk"},
/* 13852 */ { "HIÉROGLYPHE ÉGYPTIEN-13852","	* classificateur divinité crocodile : sbk-šmꜥ-nfr"},
/* 13853 */ { "HIÉROGLYPHE ÉGYPTIEN-13853","	* phonémogramme (première personne pour sbk-šmꜥ-nfr) : ꞽ"},
/* 13854 */ { "HIÉROGLYPHE ÉGYPTIEN-13854",NULL},
/* 13855 */ { "HIÉROGLYPHE ÉGYPTIEN-13855","	* logogramme (celui qui surveille ses demeures) : rs.t-ḥw.wt=s"},
/* 13856 */ { "HIÉROGLYPHE ÉGYPTIEN-13856","	* logogramme (Sopdou) : spd.w"},
/* 13857 */ { "HIÉROGLYPHE ÉGYPTIEN-13857","	* classificateur gardien : ḥry-sḫ.t"},
/* 13858 */ { "HIÉROGLYPHE ÉGYPTIEN-13858","	* classificateur gardien : ḫsf-sby.w"},
/* 13859 */ { "HIÉROGLYPHE ÉGYPTIEN-13859","	* classificateur divinité babouin (c'est-à-dire Thot) : n.y-mꜣꜥ.t"},
/* 1385A */ { "HIÉROGLYPHE ÉGYPTIEN-1385A","	* logogramme (Hâpy) : ḥp.y"},
/* 1385B */ { "HIÉROGLYPHE ÉGYPTIEN-1385B","	* logogramme (Taténen) : tꜣ-ṯnn"},
/* 1385C */ { "HIÉROGLYPHE ÉGYPTIEN-1385C","	* logogramme (Taténen) : tꜣ-ṯnn"},
/* 1385D */ { "HIÉROGLYPHE ÉGYPTIEN-1385D","	* phonémogramme : ṯn.tꞽ"},
/* 1385E */ { "HIÉROGLYPHE ÉGYPTIEN-1385E","	* classificateur Taténen : tꜣ-ṯnn"},
/* 1385F */ { "HIÉROGLYPHE ÉGYPTIEN-1385F","	* logogramme (Taténen) : tꜣ-ṯnn"},
/* 13860 */ { "HIÉROGLYPHE ÉGYPTIEN-13860","	* logogramme (Taténen) : tꜣ-ṯnn"},
/* 13861 */ { "HIÉROGLYPHE ÉGYPTIEN-13861","	* phonémogramme : ṯn(w)"},
/* 13862 */ { "HIÉROGLYPHE ÉGYPTIEN-13862","	* phonémogramme : sw"},
/* 13863 */ { "HIÉROGLYPHE ÉGYPTIEN-13863","	* logogramme (Taténen) : tꜣ-ṯnn"},
/* 13864 */ { "HIÉROGLYPHE ÉGYPTIEN-13864","	* logogramme (Thot) : ḏhwty"},
/* 13865 */ { "HIÉROGLYPHE ÉGYPTIEN-13865","	* phonémogramme : ḥr.y-ꞽb"},
/* 13866 */ { "HIÉROGLYPHE ÉGYPTIEN-13866","	* classificateur Thot : ꞽpy"},
/* 13867 */ { "HIÉROGLYPHE ÉGYPTIEN-13867",NULL},
/* 13868 */ { "HIÉROGLYPHE ÉGYPTIEN-13868","	* classificateur lune : ꞽꜥḥ"},
/* 13869 */ { "HIÉROGLYPHE ÉGYPTIEN-13869",NULL},
/* 1386A */ { "HIÉROGLYPHE ÉGYPTIEN-1386A","	* classificateur divinité : ḥkꜣ.w"},
/* 1386B */ { "HIÉROGLYPHE ÉGYPTIEN-1386B","	* phonémogramme : ḥr.y-ꞽb"},
/* 1386C */ { "HIÉROGLYPHE ÉGYPTIEN-1386C","	* phonémogramme : ḥr.y-ꞽb"},
/* 1386D */ { "HIÉROGLYPHE ÉGYPTIEN-1386D","	* logogramme/phonémogramme (être grand) : wr"},
/* 1386E */ { "HIÉROGLYPHE ÉGYPTIEN-1386E",NULL},
/* 1386F */ { "HIÉROGLYPHE ÉGYPTIEN-1386F","	* logogramme (Thot) : ḏhwty"},
/* 13870 */ { "HIÉROGLYPHE ÉGYPTIEN-13870",NULL},
/* 13871 */ { "HIÉROGLYPHE ÉGYPTIEN-13871","	* logogramme (fils de Rê) : sꜣ-rꜥ"},
/* 13872 */ { "HIÉROGLYPHE ÉGYPTIEN-13872","	* classificateur dieu de la terre : ꜣkr"},
/* 13873 */ { "HIÉROGLYPHE ÉGYPTIEN-13873","	* logogramme (éternité) : nḥḥ"},
/* 13874 */ { "HIÉROGLYPHE ÉGYPTIEN-13874","	* phonémogramme : dwꜣ.t"},
/* 13875 */ { "HIÉROGLYPHE ÉGYPTIEN-13875","	* phonémogramme : ḥnꜥ"},
/* 13876 */ { "HIÉROGLYPHE ÉGYPTIEN-13876","	* classificateur Anubis : ꜥnḳ.t"},
/* 13877 */ { "HIÉROGLYPHE ÉGYPTIEN-13877","	* classificateur Anubis : ꜥnḳ.t"},
/* 13878 */ { "HIÉROGLYPHE ÉGYPTIEN-13878","	* classificateur Rénénoutet : rnn.(w)ṯ(t)"},
/* 13879 */ { "HIÉROGLYPHE ÉGYPTIEN-13879",NULL},
/* 1387A */ { "HIÉROGLYPHE ÉGYPTIEN-1387A","	* classificateur dans ḥs-nb=s : ḥs"},
/* 1387B */ { "HIÉROGLYPHE ÉGYPTIEN-1387B","	* logogramme (Kekout) : kk.t"},
/* 1387C */ { "HIÉROGLYPHE ÉGYPTIEN-1387C","	* classificateur divinité ?"},
/* 1387D */ { "HIÉROGLYPHE ÉGYPTIEN-1387D","	* classificateur Hathor : ḥw.t-ḥr"},
/* 1387E */ { "HIÉROGLYPHE ÉGYPTIEN-1387E","	* logogramme (Isis) : ꜣs.t"},
/* 1387F */ { "HIÉROGLYPHE ÉGYPTIEN-1387F","	* classificateur divinité féminine (habituellement associée à Hathor)"},
/* 13880 */ { "HIÉROGLYPHE ÉGYPTIEN-13880","	* logogramme : nb"},
/* 13881 */ { "HIÉROGLYPHE ÉGYPTIEN-13881","	* logogramme (la puissante) : sḫm.t"},
/* 13882 */ { "HIÉROGLYPHE ÉGYPTIEN-13882","	* logogramme (majesté) : ḥm.t"},
/* 13883 */ { "HIÉROGLYPHE ÉGYPTIEN-13883","	* logogramme/phonémogramme (seigneur/dame) : nb"},
/* 13884 */ { "HIÉROGLYPHE ÉGYPTIEN-13884","	* logogramme/phonémogramme (dame) : nb.t"},
/* 13885 */ { "HIÉROGLYPHE ÉGYPTIEN-13885","	* logogramme (vie) : ꜥnḫ"},
/* 13886 */ { "HIÉROGLYPHE ÉGYPTIEN-13886","	* logogramme/phonémogramme (efficace/splendide) : mnḫ"},
/* 13887 */ { "HIÉROGLYPHE ÉGYPTIEN-13887",NULL},
/* 13888 */ { "HIÉROGLYPHE ÉGYPTIEN-13888","	* logogramme (maîtresse du sistre) : nb.t-sšš.t"},
/* 13889 */ { "HIÉROGLYPHE ÉGYPTIEN-13889","	* logogramme (maîtresse du sistre) : nb.t-sšš.t"},
/* 1388A */ { "HIÉROGLYPHE ÉGYPTIEN-1388A","	* logogramme (majesté) : ḥm.t"},
/* 1388B */ { "HIÉROGLYPHE ÉGYPTIEN-1388B","	* classificateur divinité : ḥwt-ḥr"},
/* 1388C */ { "HIÉROGLYPHE ÉGYPTIEN-1388C","	* logogramme (réjouissance) : nhm"},
/* 1388D */ { "HIÉROGLYPHE ÉGYPTIEN-1388D","	* logogramme (réjouissance) : nhm"},
/* 1388E */ { "HIÉROGLYPHE ÉGYPTIEN-1388E","	* classificateur soigner : ꜣṯꞽ"},
/* 1388F */ { "HIÉROGLYPHE ÉGYPTIEN-1388F","	* logogramme (soigner, élever (de rnn)) : rr"},
/* 13890 */ { "HIÉROGLYPHE ÉGYPTIEN-13890","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 13891 */ { "HIÉROGLYPHE ÉGYPTIEN-13891","	* logogramme (or) : nbw"},
/* 13892 */ { "HIÉROGLYPHE ÉGYPTIEN-13892","	* logogramme (souveraine) : ḥḳꜣ.t"},
/* 13893 */ { "HIÉROGLYPHE ÉGYPTIEN-13893","	* logogramme (les cieux, le ciel) : p.t"},
/* 13894 */ { "HIÉROGLYPHE ÉGYPTIEN-13894","	* classificateur Hathor : ḥw.t-ḥr"},
/* 13895 */ { "HIÉROGLYPHE ÉGYPTIEN-13895","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 13896 */ { "HIÉROGLYPHE ÉGYPTIEN-13896","	* logogramme (Isis) : ꜣs.t"},
/* 13897 */ { "HIÉROGLYPHE ÉGYPTIEN-13897","	* logogramme (Isis) : ꜣs.t"},
/* 13898 */ { "HIÉROGLYPHE ÉGYPTIEN-13898",NULL},
/* 13899 */ { "HIÉROGLYPHE ÉGYPTIEN-13899","	* logogramme (Isis) : ꜣs.t"},
/* 1389A */ { "HIÉROGLYPHE ÉGYPTIEN-1389A",NULL},
/* 1389B */ { "HIÉROGLYPHE ÉGYPTIEN-1389B","	* classificateur divinité : ꞽp.t-wr.t"},
/* 1389C */ { "HIÉROGLYPHE ÉGYPTIEN-1389C","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 1389D */ { "HIÉROGLYPHE ÉGYPTIEN-1389D","	* logogramme (Isis) : ꜣs.t"},
/* 1389E */ { "HIÉROGLYPHE ÉGYPTIEN-1389E","	* classificateur Isis : ꜣs.t"},
/* 1389F */ { "HIÉROGLYPHE ÉGYPTIEN-1389F","	* logogramme (Isis) : ꜣs.t"},
/* 138A0 */ { "HIÉROGLYPHE ÉGYPTIEN-138A0","	* classificateur divinité : ḥḳꜣ.t"},
/* 138A1 */ { "HIÉROGLYPHE ÉGYPTIEN-138A1","	* classificateur pleureuse : ḥꜣy.t"},
/* 138A2 */ { "HIÉROGLYPHE ÉGYPTIEN-138A2",NULL},
/* 138A3 */ { "HIÉROGLYPHE ÉGYPTIEN-138A3",NULL},
/* 138A4 */ { "HIÉROGLYPHE ÉGYPTIEN-138A4",NULL},
/* 138A5 */ { "HIÉROGLYPHE ÉGYPTIEN-138A5","	* logogramme (Isis) : ꜣs.t"},
/* 138A6 */ { "HIÉROGLYPHE ÉGYPTIEN-138A6","	* logogramme (Isis) : ꜣs.t"},
/* 138A7 */ { "HIÉROGLYPHE ÉGYPTIEN-138A7","	* logogramme (la veuve) : šntꜣy.t"},
/* 138A8 */ { "HIÉROGLYPHE ÉGYPTIEN-138A8","	* logogramme (Isis) : ꜣs.t"},
/* 138A9 */ { "HIÉROGLYPHE ÉGYPTIEN-138A9","	* logogramme (seigneur) : nb"},
/* 138AA */ { "HIÉROGLYPHE ÉGYPTIEN-138AA","	* logogramme (protéger) : ḫwꞽ"},
/* 138AB */ { "HIÉROGLYPHE ÉGYPTIEN-138AB","	* logogramme (protéger) : ḫwꞽ"},
/* 138AC */ { "HIÉROGLYPHE ÉGYPTIEN-138AC","	* phonémogramme : snṯ-ꞽnbw"},
/* 138AD */ { "HIÉROGLYPHE ÉGYPTIEN-138AD","	* logogramme/phonémogramme (dame) : nb.t"},
/* 138AE */ { "HIÉROGLYPHE ÉGYPTIEN-138AE","	* classificateur divinité léonine (féminine) : sḫm.t/bꜣs.tt"},
/* 138AF */ { "HIÉROGLYPHE ÉGYPTIEN-138AF","	* logogramme (Sekhmet) : sḫm.t"},
/* 138B0 */ { "HIÉROGLYPHE ÉGYPTIEN-138B0","	* classificateur divinité léonine (féminine) : sḫm.t"},
/* 138B1 */ { "HIÉROGLYPHE ÉGYPTIEN-138B1",NULL},
/* 138B2 */ { "HIÉROGLYPHE ÉGYPTIEN-138B2","	* classificateur divinité léonine (masculine) : ḥḏ-ḥtp"},
/* 138B3 */ { "HIÉROGLYPHE ÉGYPTIEN-138B3",NULL},
/* 138B4 */ { "HIÉROGLYPHE ÉGYPTIEN-138B4","	* classificateur divinité léonine (masculine) : ḫns-mꜣꜥ.t ; bꜥḥ-ꞽb"},
/* 138B5 */ { "HIÉROGLYPHE ÉGYPTIEN-138B5",NULL},
/* 138B6 */ { "HIÉROGLYPHE ÉGYPTIEN-138B6","	* classificateur divinité léonine (féminine) : bꜣs.tt"},
/* 138B7 */ { "HIÉROGLYPHE ÉGYPTIEN-138B7","	* classificateur divinité léonine (féminine) : sḫm.t"},
/* 138B8 */ { "HIÉROGLYPHE ÉGYPTIEN-138B8","	* logogramme (ville, village) : nꞽw.t"},
/* 138B9 */ { "HIÉROGLYPHE ÉGYPTIEN-138B9","	* logogramme (Sekhmet) : sḫm.t"},
/* 138BA */ { "HIÉROGLYPHE ÉGYPTIEN-138BA","	* classificateur divinité léonine (féminine) : sḫm.t"},
/* 138BB */ { "HIÉROGLYPHE ÉGYPTIEN-138BB","	* classificateur divinité léonine (féminine) : mnḥy.t"},
/* 138BC */ { "HIÉROGLYPHE ÉGYPTIEN-138BC",NULL},
/* 138BD */ { "HIÉROGLYPHE ÉGYPTIEN-138BD",NULL},
/* 138BE */ { "HIÉROGLYPHE ÉGYPTIEN-138BE","	* logogramme (celle qui est sur le trône/les marches (Bastet)) : ḥr.yt-ḫnd.w"},
/* 138BF */ { "HIÉROGLYPHE ÉGYPTIEN-138BF","	* logogramme (être caché) : štꜣ"},
/* 138C0 */ { "HIÉROGLYPHE ÉGYPTIEN-138C0","	* classificateur caché : štꜣ"},
/* 138C1 */ { "HIÉROGLYPHE ÉGYPTIEN-138C1","	* logogramme (être caché) : štꜣ"},
/* 138C2 */ { "HIÉROGLYPHE ÉGYPTIEN-138C2","	* classificateur divinité ? : mꜣ-ꜥnḫ"},
/* 138C3 */ { "HIÉROGLYPHE ÉGYPTIEN-138C3","	* classificateur divinité léonine (féminine) : sḫm.t"},
/* 138C4 */ { "HIÉROGLYPHE ÉGYPTIEN-138C4","	* classificateur divinité léonine (féminine) : bꜣs.tt"},
/* 138C5 */ { "HIÉROGLYPHE ÉGYPTIEN-138C5","	* logogramme (interjection vocative) : ꞽ"},
/* 138C6 */ { "HIÉROGLYPHE ÉGYPTIEN-138C6","	* logogramme (fille de Rê) : sꜣ.t-rꜥ"},
/* 138C7 */ { "HIÉROGLYPHE ÉGYPTIEN-138C7","	* phonémogramme : šms"},
/* 138C8 */ { "HIÉROGLYPHE ÉGYPTIEN-138C8","	* logogramme (Maât) : mꜣꜥ.t"},
/* 138C9 */ { "HIÉROGLYPHE ÉGYPTIEN-138C9","	* logogramme (souveraine de la vérité, Maât) : ḥḳꜣ-mꜣꜥ.t"},
/* 138CA */ { "HIÉROGLYPHE ÉGYPTIEN-138CA","	* logogramme (vérité) : mꜣꜥ"},
/* 138CB */ { "HIÉROGLYPHE ÉGYPTIEN-138CB","	* logogramme (au nom de Ramsès IV) : wsr-mꜣꜥ.t"},
/* 138CC */ { "HIÉROGLYPHE ÉGYPTIEN-138CC","	* classificateur femme : rw.t-"},
/* 138CD */ { "HIÉROGLYPHE ÉGYPTIEN-138CD","	* logogramme (Maât) : mꜣꜥ.t"},
/* 138CE */ { "HIÉROGLYPHE ÉGYPTIEN-138CE","	* classificateur divinité : mꜣꜥ.t"},
/* 138CF */ { "HIÉROGLYPHE ÉGYPTIEN-138CF","	* classificateur vérité : mꜥꜣ.t"},
/* 138D0 */ { "HIÉROGLYPHE ÉGYPTIEN-138D0","	* logogramme/phonémogramme (celui que la vérité/Maât aime) : mr(.y)-mꜣꜥ.t"},
/* 138D1 */ { "HIÉROGLYPHE ÉGYPTIEN-138D1","	* logogramme (Maât) : mꜣꜥ.t"},
/* 138D2 */ { "HIÉROGLYPHE ÉGYPTIEN-138D2","	* logogramme (au nom de Ramsès II) : wsr-mꜣꜥ.t"},
/* 138D3 */ { "HIÉROGLYPHE ÉGYPTIEN-138D3","	* logogramme (au nom de Ramsès II) : wsr-mꜣꜥ.t"},
/* 138D4 */ { "HIÉROGLYPHE ÉGYPTIEN-138D4","	* logogramme (au nom de Ramsès II) : wsr-mꜣꜥ.t"},
/* 138D5 */ { "HIÉROGLYPHE ÉGYPTIEN-138D5","	* logogramme (porte qui délivre la vérité) : rw.t-dꞽ(.t)-mꜣꜥ.t"},
/* 138D6 */ { "HIÉROGLYPHE ÉGYPTIEN-138D6","	* logogramme (être caché) : štꜣ"},
/* 138D7 */ { "HIÉROGLYPHE ÉGYPTIEN-138D7","	* logogramme (Méret) : mr.t"},
/* 138D8 */ { "HIÉROGLYPHE ÉGYPTIEN-138D8","	* classificateur divinité : mr.t"},
/* 138D9 */ { "HIÉROGLYPHE ÉGYPTIEN-138D9","	* classificateur divinité : mr.t"},
/* 138DA */ { "HIÉROGLYPHE ÉGYPTIEN-138DA","	* classificateur divinité, musicienne : nb.tyw"},
/* 138DB */ { "HIÉROGLYPHE ÉGYPTIEN-138DB",NULL},
/* 138DC */ { "HIÉROGLYPHE ÉGYPTIEN-138DC","	* logogramme (Méret) : mr.t"},
/* 138DD */ { "HIÉROGLYPHE ÉGYPTIEN-138DD","	* classificateur divinité : mr.ty"},
/* 138DE */ { "HIÉROGLYPHE ÉGYPTIEN-138DE","	* logogramme (Mout) : mw.t"},
/* 138DF */ { "HIÉROGLYPHE ÉGYPTIEN-138DF","	* logogramme (avec \\C98 et \\C43A, représentant la triade de Dendérah) : ꞽwn.t"},
/* 138E0 */ { "HIÉROGLYPHE ÉGYPTIEN-138E0","	* classificateur majesté : ḥm"},
/* 138E1 */ { "HIÉROGLYPHE ÉGYPTIEN-138E1","	* logogramme (Mout) : mw.t"},
/* 138E2 */ { "HIÉROGLYPHE ÉGYPTIEN-138E2","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 138E3 */ { "HIÉROGLYPHE ÉGYPTIEN-138E3","	* logogramme (Hathor, donnant la vie) : ḥw.t-ḥr-dꞽ-ꜥnḫ"},
/* 138E4 */ { "HIÉROGLYPHE ÉGYPTIEN-138E4","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 138E5 */ { "HIÉROGLYPHE ÉGYPTIEN-138E5","	* phonémogramme : n"},
/* 138E6 */ { "HIÉROGLYPHE ÉGYPTIEN-138E6","	* classificateur divinité : dp.(y)t"},
/* 138E7 */ { "HIÉROGLYPHE ÉGYPTIEN-138E7","	* phonémogramme : n"},
/* 138E8 */ { "HIÉROGLYPHE ÉGYPTIEN-138E8","	* logogramme (Neith) : n.t"},
/* 138E9 */ { "HIÉROGLYPHE ÉGYPTIEN-138E9","	* logogramme (Neith) : n.t"},
/* 138EA */ { "HIÉROGLYPHE ÉGYPTIEN-138EA","	* (cryptographie) phonémogramme : wn"},
/* 138EB */ { "HIÉROGLYPHE ÉGYPTIEN-138EB","	* phonémogramme : n(.t)"},
/* 138EC */ { "HIÉROGLYPHE ÉGYPTIEN-138EC","	* logogramme (roi de Basse-Égypte) : bꞽ.ty"},
/* 138ED */ { "HIÉROGLYPHE ÉGYPTIEN-138ED","	* phonémogramme : nt"},
/* 138EE */ { "HIÉROGLYPHE ÉGYPTIEN-138EE","	* classificateur divinité (Neith) : n.t"},
/* 138EF */ { "HIÉROGLYPHE ÉGYPTIEN-138EF","	* phonémogramme : wnn"},
/* 138F0 */ { "HIÉROGLYPHE ÉGYPTIEN-138F0","	* logogramme (Dendérah) : ꞽꜣ.t-dꞽ"},
/* 138F1 */ { "HIÉROGLYPHE ÉGYPTIEN-138F1","	* logogramme (Nephtys) : nb.t-ḥw.t"},
/* 138F2 */ { "HIÉROGLYPHE ÉGYPTIEN-138F2","	* classificateur sœur (avec Isis) : sn.ty"},
/* 138F3 */ { "HIÉROGLYPHE ÉGYPTIEN-138F3","	* classificateur pleureuse : ḥꜣy.t"},
/* 138F4 */ { "HIÉROGLYPHE ÉGYPTIEN-138F4","	* logogramme (Nephtys) : nb.t-ḥw.t"},
/* 138F5 */ { "HIÉROGLYPHE ÉGYPTIEN-138F5","	* logogramme (les cieux, le ciel) : p.t"},
/* 138F6 */ { "HIÉROGLYPHE ÉGYPTIEN-138F6","	* logogramme (les cieux, le ciel) : p.t"},
/* 138F7 */ { "HIÉROGLYPHE ÉGYPTIEN-138F7","	* phonémogramme : n"},
/* 138F8 */ { "HIÉROGLYPHE ÉGYPTIEN-138F8","	* logogramme (les cieux, le ciel) : p.t"},
/* 138F9 */ { "HIÉROGLYPHE ÉGYPTIEN-138F9","	* logogramme (heure) : wnw.t"},
/* 138FA */ { "HIÉROGLYPHE ÉGYPTIEN-138FA","	* logogramme (ville, village) : nꞽw.t"},
/* 138FB */ { "HIÉROGLYPHE ÉGYPTIEN-138FB","	* logogramme (ville, village) : nꞽw.t"},
/* 138FC */ { "HIÉROGLYPHE ÉGYPTIEN-138FC","	* logogramme (le ciel) : gb.t"},
/* 138FD */ { "HIÉROGLYPHE ÉGYPTIEN-138FD","	* logogramme (les cieux, le ciel) : p.t"},
/* 138FE */ { "HIÉROGLYPHE ÉGYPTIEN-138FE","	* logogramme/phonémogramme (briller) : psḏ"},
/* 138FF */ { "HIÉROGLYPHE ÉGYPTIEN-138FF","	* classificateur divinité (Sothis) : spd.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_39[] = {
/* 13900 */ { "HIÉROGLYPHE ÉGYPTIEN-13900","	* logogramme (Séchat) : sšꜣ.t"},
/* 13901 */ { "HIÉROGLYPHE ÉGYPTIEN-13901",NULL},
/* 13902 */ { "HIÉROGLYPHE ÉGYPTIEN-13902","	* logogramme (Séchat) : sšꜣ.t"},
/* 13903 */ { "HIÉROGLYPHE ÉGYPTIEN-13903","	* logogramme (Séchat) : sšꜣ.t"},
/* 13904 */ { "HIÉROGLYPHE ÉGYPTIEN-13904","	* logogramme (étirement de la corde) : pḏ-šsr"},
/* 13905 */ { "HIÉROGLYPHE ÉGYPTIEN-13905","	* phonémogramme : sbꜣ"},
/* 13906 */ { "HIÉROGLYPHE ÉGYPTIEN-13906",NULL},
/* 13907 */ { "HIÉROGLYPHE ÉGYPTIEN-13907","	* classificateur divinité bovidé : ḥsꜣ.t"},
/* 13908 */ { "HIÉROGLYPHE ÉGYPTIEN-13908","	* logogramme/phonémogramme (seigneur) : nb"},
/* 13909 */ { "HIÉROGLYPHE ÉGYPTIEN-13909","	* logogramme (le trône (Edfou)) : wṯs.t"},
/* 1390A */ { "HIÉROGLYPHE ÉGYPTIEN-1390A","	* logogramme (souveraine) : ꞽt.yt"},
/* 1390B */ { "HIÉROGLYPHE ÉGYPTIEN-1390B","	* logogramme (souveraine) : ꞽt.yt"},
/* 1390C */ { "HIÉROGLYPHE ÉGYPTIEN-1390C","	* logogramme (souveraine) : ꞽt.yt"},
/* 1390D */ { "HIÉROGLYPHE ÉGYPTIEN-1390D","	* logogramme (souveraine) : ḥḳꜣ.t"},
/* 1390E */ { "HIÉROGLYPHE ÉGYPTIEN-1390E","	* logogramme (souveraine) : ꞽt.yt"},
/* 1390F */ { "HIÉROGLYPHE ÉGYPTIEN-1390F","	* logogramme (souveraine) : ḥḳꜣ.t"},
/* 13910 */ { "HIÉROGLYPHE ÉGYPTIEN-13910","	* phonémogramme : wn"},
/* 13911 */ { "HIÉROGLYPHE ÉGYPTIEN-13911","	* phonémogramme : wn"},
/* 13912 */ { "HIÉROGLYPHE ÉGYPTIEN-13912","	* phonémogramme : wn"},
/* 13913 */ { "HIÉROGLYPHE ÉGYPTIEN-13913","	* phonémogramme : wn"},
/* 13914 */ { "HIÉROGLYPHE ÉGYPTIEN-13914","	* phonémogramme : wn"},
/* 13915 */ { "HIÉROGLYPHE ÉGYPTIEN-13915","	* classificateur divinité : ꜥnṯ"},
/* 13916 */ { "HIÉROGLYPHE ÉGYPTIEN-13916","	* logogramme : ḥꜣ.t-mḥ.yt"},
/* 13917 */ { "HIÉROGLYPHE ÉGYPTIEN-13917","	* classificateur divinité : ḥꜣ.t-mḥ.yt"},
/* 13918 */ { "HIÉROGLYPHE ÉGYPTIEN-13918","	* classificateur Heket : ḥḳ.t"},
/* 13919 */ { "HIÉROGLYPHE ÉGYPTIEN-13919","	* logogramme (Kekou) : kk.w"},
/* 1391A */ { "HIÉROGLYPHE ÉGYPTIEN-1391A","	* logogramme (l'ouest) : ꞽmn.t"},
/* 1391B */ { "HIÉROGLYPHE ÉGYPTIEN-1391B","	* logogramme (Serket) : srḳ.t"},
/* 1391C */ { "HIÉROGLYPHE ÉGYPTIEN-1391C","	* logogramme (Thèbes) : wꜣs.t"},
/* 1391D */ { "HIÉROGLYPHE ÉGYPTIEN-1391D","	* phonémogramme : r"},
/* 1391E */ { "HIÉROGLYPHE ÉGYPTIEN-1391E","	* logogramme (lune) ? : ꞽꜥḥ"},
/* 1391F */ { "HIÉROGLYPHE ÉGYPTIEN-1391F","	* classificateur Sekhet, déesse des marais : sḫ.t"},
/* 13920 */ { "HIÉROGLYPHE ÉGYPTIEN-13920","	* classificateur divinité : ḏd.t"},
/* 13921 */ { "HIÉROGLYPHE ÉGYPTIEN-13921","	* classificateur divinité : wr.t-šꜥ.t"},
/* 13922 */ { "HIÉROGLYPHE ÉGYPTIEN-13922","	* logogramme (perception, connaissance) : sꞽꜣ.t"},
/* 13923 */ { "HIÉROGLYPHE ÉGYPTIEN-13923","	* logogramme (matin) : dwꜣ.w"},
/* 13924 */ { "HIÉROGLYPHE ÉGYPTIEN-13924",NULL},
/* 13925 */ { "HIÉROGLYPHE ÉGYPTIEN-13925","	* logogramme (matin) : dwꜣ.w"},
/* 13926 */ { "HIÉROGLYPHE ÉGYPTIEN-13926","	* logogramme (matin) : dwꜣ.w"},
/* 13927 */ { "HIÉROGLYPHE ÉGYPTIEN-13927","	* logogramme (matin) : dwꜣ.w"},
/* 13928 */ { "HIÉROGLYPHE ÉGYPTIEN-13928","	* logogramme (matin) : dwꜣ.w"},
/* 13929 */ { "HIÉROGLYPHE ÉGYPTIEN-13929","	* logogramme (les deux de l'horizon) : ꜣḫty.ty"},
/* 1392A */ { "HIÉROGLYPHE ÉGYPTIEN-1392A","	* logogramme (les (quatre) supports) : sḫn.wt"},
/* 1392B */ { "HIÉROGLYPHE ÉGYPTIEN-1392B","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 1392C */ { "HIÉROGLYPHE ÉGYPTIEN-1392C","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 1392D */ { "HIÉROGLYPHE ÉGYPTIEN-1392D","	* classificateur féminin : mnꞽ.t"},
/* 1392E */ { "HIÉROGLYPHE ÉGYPTIEN-1392E","	* logogramme (tête)"},
/* 1392F */ { "HIÉROGLYPHE ÉGYPTIEN-1392F","	* classificateur rire : nṯḥṯḥ"},
/* 13930 */ { "HIÉROGLYPHE ÉGYPTIEN-13930","	* classificateur crachat : ꞽsd"},
/* 13931 */ { "HIÉROGLYPHE ÉGYPTIEN-13931","	* classificateur lieu de naissance : msḫn.t"},
/* 13932 */ { "HIÉROGLYPHE ÉGYPTIEN-13932","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 13933 */ { "HIÉROGLYPHE ÉGYPTIEN-13933","	* classificateur bâton"},
/* 13934 */ { "HIÉROGLYPHE ÉGYPTIEN-13934","	* phonémogramme : ḥr.y-tp"},
/* 13935 */ { "HIÉROGLYPHE ÉGYPTIEN-13935","	* logogramme (visage) : ḥr"},
/* 13936 */ { "HIÉROGLYPHE ÉGYPTIEN-13936","	* logogramme (visage) : ḥr"},
/* 13937 */ { "HIÉROGLYPHE ÉGYPTIEN-13937","	* classificateur être humain : tm.yw"},
/* 13938 */ { "HIÉROGLYPHE ÉGYPTIEN-13938","	* classificateur occupation : sr"},
/* 13939 */ { "HIÉROGLYPHE ÉGYPTIEN-13939","	* classificateur appelant : nꞽs"},
/* 1393A */ { "HIÉROGLYPHE ÉGYPTIEN-1393A","	* classificateur appelant : ḏsw"},
/* 1393B */ { "HIÉROGLYPHE ÉGYPTIEN-1393B",NULL},
/* 1393C */ { "HIÉROGLYPHE ÉGYPTIEN-1393C",NULL},
/* 1393D */ { "HIÉROGLYPHE ÉGYPTIEN-1393D","	* classificateur mangeant : wnm"},
/* 1393E */ { "HIÉROGLYPHE ÉGYPTIEN-1393E","	* classificateur enfant : ḫrd/nḫn"},
/* 1393F */ { "HIÉROGLYPHE ÉGYPTIEN-1393F","	* classificateur l'enfant, le petit : ḥwn"},
/* 13940 */ { "HIÉROGLYPHE ÉGYPTIEN-13940","	* classificateur allaitant : mnꜥ"},
/* 13941 */ { "HIÉROGLYPHE ÉGYPTIEN-13941","	* classificateur nain, pigmée : dng"},
/* 13942 */ { "HIÉROGLYPHE ÉGYPTIEN-13942","	* classificateur s'incliner, attaquer : ꞽkꞽ"},
/* 13943 */ { "HIÉROGLYPHE ÉGYPTIEN-13943","	* classificateur tomber : sḫr"},
/* 13944 */ { "HIÉROGLYPHE ÉGYPTIEN-13944","	* classificateur appeler : nꞽs"},
/* 13945 */ { "HIÉROGLYPHE ÉGYPTIEN-13945","	* classificateur se réjouir : hnꞽ"},
/* 13946 */ { "HIÉROGLYPHE ÉGYPTIEN-13946","	* classificateur se retournant : nꜥw"},
/* 13947 */ { "HIÉROGLYPHE ÉGYPTIEN-13947",NULL},
/* 13948 */ { "HIÉROGLYPHE ÉGYPTIEN-13948","	* classificateur se réjouir : ḥꜥꞽ"},
/* 13949 */ { "HIÉROGLYPHE ÉGYPTIEN-13949","	* logogramme (Heh, divinité) : ḥḥ"},
/* 1394A */ { "HIÉROGLYPHE ÉGYPTIEN-1394A","	* classificateur à l'envers : sḫdḫd"},
/* 1394B */ { "HIÉROGLYPHE ÉGYPTIEN-1394B","	* classificateur nager : mḥꞽ"},
/* 1394C */ { "HIÉROGLYPHE ÉGYPTIEN-1394C",NULL},
/* 1394D */ { "HIÉROGLYPHE ÉGYPTIEN-1394D","	* classificateur nageant : nbꞽ"},
/* 1394E */ { "HIÉROGLYPHE ÉGYPTIEN-1394E",NULL},
/* 1394F */ { "HIÉROGLYPHE ÉGYPTIEN-1394F","	* logogramme (être grand) : wr"},
/* 13950 */ { "HIÉROGLYPHE ÉGYPTIEN-13950","	* classificateur héraut : ḥww.ty"},
/* 13951 */ { "HIÉROGLYPHE ÉGYPTIEN-13951","	* classificateur emporter, prendre : ḫn(f)"},
/* 13952 */ { "HIÉROGLYPHE ÉGYPTIEN-13952","	* classificateur héraut : ḥww.ty"},
/* 13953 */ { "HIÉROGLYPHE ÉGYPTIEN-13953",NULL},
/* 13954 */ { "HIÉROGLYPHE ÉGYPTIEN-13954","	* classificateur aîné, officiel : sr"},
/* 13955 */ { "HIÉROGLYPHE ÉGYPTIEN-13955","	* classificateur Orion : sꜣḥ"},
/* 13956 */ { "HIÉROGLYPHE ÉGYPTIEN-13956","	* classificateur cracher, vomir : bšꞽ"},
/* 13957 */ { "HIÉROGLYPHE ÉGYPTIEN-13957","	* classificateur lever, porter : fꜣꞽ"},
/* 13958 */ { "HIÉROGLYPHE ÉGYPTIEN-13958","	* classificateur repousser : ḫsr"},
/* 13959 */ { "HIÉROGLYPHE ÉGYPTIEN-13959","	* classificateur s'opposer, se rebeller : ḫsbꞽ"},
/* 1395A */ { "HIÉROGLYPHE ÉGYPTIEN-1395A","	* classificateur étendre : sꜣwꞽ"},
/* 1395B */ { "HIÉROGLYPHE ÉGYPTIEN-1395B","	* classificateur disperser : sṯꞽ"},
/* 1395C */ { "HIÉROGLYPHE ÉGYPTIEN-1395C",NULL},
/* 1395D */ { "HIÉROGLYPHE ÉGYPTIEN-1395D","	* classificateur dansant : rw.t"},
/* 1395E */ { "HIÉROGLYPHE ÉGYPTIEN-1395E","	* classificateur gardant, protégeant : sꜣw"},
/* 1395F */ { "HIÉROGLYPHE ÉGYPTIEN-1395F","	* classificateur buvant : swr"},
/* 13960 */ { "HIÉROGLYPHE ÉGYPTIEN-13960","	* classificateur déraciner : fdꞽ"},
/* 13961 */ { "HIÉROGLYPHE ÉGYPTIEN-13961",NULL},
/* 13962 */ { "HIÉROGLYPHE ÉGYPTIEN-13962","	* classificateur baratter : ꜥḏ"},
/* 13963 */ { "HIÉROGLYPHE ÉGYPTIEN-13963","	* classificateur brisant, détruisant : sḏ dšr.t"},
/* 13964 */ { "HIÉROGLYPHE ÉGYPTIEN-13964","	* classificateur expulser, refouler : rwꞽ"},
/* 13965 */ { "HIÉROGLYPHE ÉGYPTIEN-13965","	* classificateur potier : ḳd.w"},
/* 13966 */ { "HIÉROGLYPHE ÉGYPTIEN-13966","	* classificateur grimper, voler : ḥfdꞽ"},
/* 13967 */ { "HIÉROGLYPHE ÉGYPTIEN-13967","	* classificateur fondre, couler : nbꞽ"},
/* 13968 */ { "HIÉROGLYPHE ÉGYPTIEN-13968",NULL},
/* 13969 */ { "HIÉROGLYPHE ÉGYPTIEN-13969","	* classificateur repousser : ḫs(r)"},
/* 1396A */ { "HIÉROGLYPHE ÉGYPTIEN-1396A","	* logogramme (durée de vie) : ꜥḥꜥ.w"},
/* 1396B */ { "HIÉROGLYPHE ÉGYPTIEN-1396B","	* logogramme (un malveillant) : nbḏ"},
/* 1396C */ { "HIÉROGLYPHE ÉGYPTIEN-1396C",NULL},
/* 1396D */ { "HIÉROGLYPHE ÉGYPTIEN-1396D","	* logogramme (un malveillant) : nbḏ"},
/* 1396E */ { "HIÉROGLYPHE ÉGYPTIEN-1396E","	* classificateur tresses : nꜣb.t"},
/* 1396F */ { "HIÉROGLYPHE ÉGYPTIEN-1396F","	* classificateur tresses : nꜣb.t"},
/* 13970 */ { "HIÉROGLYPHE ÉGYPTIEN-13970","	* logogramme (couvre-chef (tresse de cheveux ?)) : (ꞽ)ꜣr.t"},
/* 13971 */ { "HIÉROGLYPHE ÉGYPTIEN-13971","	* classificateur cuir chevelu, tempe : smꜣ"},
/* 13972 */ { "HIÉROGLYPHE ÉGYPTIEN-13972","	* classificateur mèche de cheveux : ḥnsk.t"},
/* 13973 */ { "HIÉROGLYPHE ÉGYPTIEN-13973","	* logogramme (voir) : mꜥꜥ"},
/* 13974 */ { "HIÉROGLYPHE ÉGYPTIEN-13974","	* classificateur fard à paupières : smd.t"},
/* 13975 */ { "HIÉROGLYPHE ÉGYPTIEN-13975","	* phonémogramme : ꞽrꞽ-ẖr"},
/* 13976 */ { "HIÉROGLYPHE ÉGYPTIEN-13976","	* classificateur actions liées aux yeux : dgꞽ"},
/* 13977 */ { "HIÉROGLYPHE ÉGYPTIEN-13977","	* classificateur actions liées aux yeux : dgꞽ"},
/* 13978 */ { "HIÉROGLYPHE ÉGYPTIEN-13978","	* classificateur actions liées à l'œil : ḫf"},
/* 13979 */ { "HIÉROGLYPHE ÉGYPTIEN-13979","	* classificateur actions liées à l'œil : ptr"},
/* 1397A */ { "HIÉROGLYPHE ÉGYPTIEN-1397A","	* logogramme (voir, regarder) : ptr"},
/* 1397B */ { "HIÉROGLYPHE ÉGYPTIEN-1397B","	* phonémogramme : mꜣ"},
/* 1397C */ { "HIÉROGLYPHE ÉGYPTIEN-1397C","	* classificateur sommeil : ḳd"},
/* 1397D */ { "HIÉROGLYPHE ÉGYPTIEN-1397D","	* phonémogramme : ꜥntyw"},
/* 1397E */ { "HIÉROGLYPHE ÉGYPTIEN-1397E","	* classificateur parure, beauté"},
/* 1397F */ { "HIÉROGLYPHE ÉGYPTIEN-1397F","	* classificateur dormir : ḳdd"},
/* 13980 */ { "HIÉROGLYPHE ÉGYPTIEN-13980","	* classificateur actions liées à l'œil : ptr"},
/* 13981 */ { "HIÉROGLYPHE ÉGYPTIEN-13981",NULL},
/* 13982 */ { "HIÉROGLYPHE ÉGYPTIEN-13982","	* phonémogramme : ꜥn"},
/* 13983 */ { "HIÉROGLYPHE ÉGYPTIEN-13983",NULL},
/* 13984 */ { "HIÉROGLYPHE ÉGYPTIEN-13984","	* phonémogramme : ꜥn"},
/* 13985 */ { "HIÉROGLYPHE ÉGYPTIEN-13985","	* logogramme (se réveiller) : rs"},
/* 13986 */ { "HIÉROGLYPHE ÉGYPTIEN-13986","	* logogramme (pleurer) : rmꞽ"},
/* 13987 */ { "HIÉROGLYPHE ÉGYPTIEN-13987","	* classificateur pleurant, en larmes : rmꞽ"},
/* 13988 */ { "HIÉROGLYPHE ÉGYPTIEN-13988","	* phonémogramme : rm"},
/* 13989 */ { "HIÉROGLYPHE ÉGYPTIEN-13989","	* logogramme (pleurer) : rmꞽ"},
/* 1398A */ { "HIÉROGLYPHE ÉGYPTIEN-1398A","	* classificateur pleurant, en larmes : rmꞽ"},
/* 1398B */ { "HIÉROGLYPHE ÉGYPTIEN-1398B","	* classificateur actions liées aux yeux : dgꞽ"},
/* 1398C */ { "HIÉROGLYPHE ÉGYPTIEN-1398C","	* logogramme (l'« œil éblouissant » (l'Égypte)) : bꜣḳ.t"},
/* 1398D */ { "HIÉROGLYPHE ÉGYPTIEN-1398D","	* logogramme (œil) : ꞽr.t"},
/* 1398E */ { "HIÉROGLYPHE ÉGYPTIEN-1398E","	* logogramme (l'œil de Rê) : ꞽr.t-rꜥ"},
/* 1398F */ { "HIÉROGLYPHE ÉGYPTIEN-1398F","	* logogramme (voir) : mꜣꜣ"},
/* 13990 */ { "HIÉROGLYPHE ÉGYPTIEN-13990","	* classificateur arrière : mḥꜣ"},
/* 13991 */ { "HIÉROGLYPHE ÉGYPTIEN-13991","	* classificateur nez : šr.t"},
/* 13992 */ { "HIÉROGLYPHE ÉGYPTIEN-13992","	* classificateur téter : snḳ"},
/* 13993 */ { "HIÉROGLYPHE ÉGYPTIEN-13993",NULL},
/* 13994 */ { "HIÉROGLYPHE ÉGYPTIEN-13994","	* logogramme (1/3)"},
/* 13995 */ { "HIÉROGLYPHE ÉGYPTIEN-13995","	* logogramme (2/3) : r.wy"},
/* 13996 */ { "HIÉROGLYPHE ÉGYPTIEN-13996","	* interprétant : r"},
/* 13997 */ { "HIÉROGLYPHE ÉGYPTIEN-13997","	* logogramme (lèvre, bordure, bord) : sp.t"},
/* 13998 */ { "HIÉROGLYPHE ÉGYPTIEN-13998","	* logogramme (lèvres) : sp.ty"},
/* 13999 */ { "HIÉROGLYPHE ÉGYPTIEN-13999","	* classificateur crachat : ꞽšš"},
/* 1399A */ { "HIÉROGLYPHE ÉGYPTIEN-1399A","	* logogramme (petit-déjeuner (bain de bouche)) : ꞽꜥ.w-r"},
/* 1399B */ { "HIÉROGLYPHE ÉGYPTIEN-1399B","	* classificateur crachat : nš/nẖ"},
/* 1399C */ { "HIÉROGLYPHE ÉGYPTIEN-1399C","	* phonémogramme : p"},
/* 1399D */ { "HIÉROGLYPHE ÉGYPTIEN-1399D","	* phonémogramme : p"},
/* 1399E */ { "HIÉROGLYPHE ÉGYPTIEN-1399E","	* classificateur barbe ou classificateur cheveux : ḫꜣbs | ḥnsk.t"},
/* 1399F */ { "HIÉROGLYPHE ÉGYPTIEN-1399F","	* logogramme (s'asseoir) : ḥmsꞽ"},
/* 139A0 */ { "HIÉROGLYPHE ÉGYPTIEN-139A0","	* logogramme (esprit, essence) : kꜣ"},
/* 139A1 */ { "HIÉROGLYPHE ÉGYPTIEN-139A1",NULL},
/* 139A2 */ { "HIÉROGLYPHE ÉGYPTIEN-139A2","	* logogramme (esprit, essence) : kꜣ"},
/* 139A3 */ { "HIÉROGLYPHE ÉGYPTIEN-139A3","	* logogramme (esprit/essence de la royauté) : kꜣ-n(.y)-sw.t"},
/* 139A4 */ { "HIÉROGLYPHE ÉGYPTIEN-139A4","	* logogramme (nourriture, provisions) : kꜣ"},
/* 139A5 */ { "HIÉROGLYPHE ÉGYPTIEN-139A5","	* logogramme (nourriture, provisions) : kꜣ"},
/* 139A6 */ { "HIÉROGLYPHE ÉGYPTIEN-139A6","	* logogramme (adjectif relatif négatif) : ꞽw.ty"},
/* 139A7 */ { "HIÉROGLYPHE ÉGYPTIEN-139A7","	* phonémogramme : ḫm"},
/* 139A8 */ { "HIÉROGLYPHE ÉGYPTIEN-139A8",NULL},
/* 139A9 */ { "HIÉROGLYPHE ÉGYPTIEN-139A9","	* phono-répéteur : ḫm"},
/* 139AA */ { "HIÉROGLYPHE ÉGYPTIEN-139AA","	* phono-répéteur (rein) : sḫn"},
/* 139AB */ { "HIÉROGLYPHE ÉGYPTIEN-139AB","	* classificateur embrasser : ḥpt"},
/* 139AC */ { "HIÉROGLYPHE ÉGYPTIEN-139AC","	* logogramme (embrasser) : ḥpt"},
/* 139AD */ { "HIÉROGLYPHE ÉGYPTIEN-139AD","	* classificateur dans ẖꜣm-(ꞽ)ḫ.t : ẖꜥm"},
/* 139AE */ { "HIÉROGLYPHE ÉGYPTIEN-139AE","	* logogramme (prêtre funéraire) : ḥm-kꜣ"},
/* 139AF */ { "HIÉROGLYPHE ÉGYPTIEN-139AF",NULL},
/* 139B0 */ { "HIÉROGLYPHE ÉGYPTIEN-139B0","	* logogramme (ramer, transporter par voie d'eau) : ẖnꞽ"},
/* 139B1 */ { "HIÉROGLYPHE ÉGYPTIEN-139B1","	* classificateur mouvement par bateau : sḳdꞽ"},
/* 139B2 */ { "HIÉROGLYPHE ÉGYPTIEN-139B2","	* logogramme (ramer, transporter par voie d'eau) : ẖnꞽ"},
/* 139B3 */ { "HIÉROGLYPHE ÉGYPTIEN-139B3","	* phonémogramme : ẖn"},
/* 139B4 */ { "HIÉROGLYPHE ÉGYPTIEN-139B4","	* classificateur saisir l'aviron : ḫmꜥ.w-ḥmw"},
/* 139B5 */ { "HIÉROGLYPHE ÉGYPTIEN-139B5","	* phonémogramme : ẖn"},
/* 139B6 */ { "HIÉROGLYPHE ÉGYPTIEN-139B6","	* phonémogramme : ẖn"},
/* 139B7 */ { "HIÉROGLYPHE ÉGYPTIEN-139B7","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139B8 */ { "HIÉROGLYPHE ÉGYPTIEN-139B8","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139B9 */ { "HIÉROGLYPHE ÉGYPTIEN-139B9","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139BA */ { "HIÉROGLYPHE ÉGYPTIEN-139BA","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139BB */ { "HIÉROGLYPHE ÉGYPTIEN-139BB",NULL},
/* 139BC */ { "HIÉROGLYPHE ÉGYPTIEN-139BC","	* logogramme (combattre) (dans ꜥḥꜣ.t (combattant (femme)) : ꜥḥꜣ"},
/* 139BD */ { "HIÉROGLYPHE ÉGYPTIEN-139BD",NULL},
/* 139BE */ { "HIÉROGLYPHE ÉGYPTIEN-139BE","	* logogramme (combattre) (dans ꜥḥꜣ.t (combattant (femme)) : ꜥḥꜣ"},
/* 139BF */ { "HIÉROGLYPHE ÉGYPTIEN-139BF","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139C0 */ { "HIÉROGLYPHE ÉGYPTIEN-139C0","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139C1 */ { "HIÉROGLYPHE ÉGYPTIEN-139C1","	* logogramme (combattre) : ꜥḥꜣ"},
/* 139C2 */ { "HIÉROGLYPHE ÉGYPTIEN-139C2","	* logogramme (particule négative) : n"},
/* 139C3 */ { "HIÉROGLYPHE ÉGYPTIEN-139C3","	* classificateur mouvements ou actions liés au bras : rmn"},
/* 139C4 */ { "HIÉROGLYPHE ÉGYPTIEN-139C4","	* logogramme (bras, main) : ꜥ"},
/* 139C5 */ { "HIÉROGLYPHE ÉGYPTIEN-139C5","	* phonémogramme : dd"},
/* 139C6 */ { "HIÉROGLYPHE ÉGYPTIEN-139C6","	* phonémogramme : m"},
/* 139C7 */ { "HIÉROGLYPHE ÉGYPTIEN-139C7","	* classificateur soutenant, portant : rmn"},
/* 139C8 */ { "HIÉROGLYPHE ÉGYPTIEN-139C8","	* classificateur enveloppant : ꜥtḫ"},
/* 139C9 */ { "HIÉROGLYPHE ÉGYPTIEN-139C9","	* logogramme (bras, épaule) : rmn"},
/* 139CA */ { "HIÉROGLYPHE ÉGYPTIEN-139CA","	* classificateur épaule, bras : rmn"},
/* 139CB */ { "HIÉROGLYPHE ÉGYPTIEN-139CB","	* logogramme (offrir, présenter) ou phonémogramme : ḥnk | (r)dꞽ"},
/* 139CC */ { "HIÉROGLYPHE ÉGYPTIEN-139CC","	* phonémogramme : mk"},
/* 139CD */ { "HIÉROGLYPHE ÉGYPTIEN-139CD","	* logogramme (recevoir) : šsp"},
/* 139CE */ { "HIÉROGLYPHE ÉGYPTIEN-139CE","	* logogramme (cours (du jour) ; besoins quotidiens) : ẖr.t-hrw"},
/* 139CF */ { "HIÉROGLYPHE ÉGYPTIEN-139CF","	* logogramme (cours (du jour) ; besoins quotidiens) : ẖr.t-hrw"},
/* 139D0 */ { "HIÉROGLYPHE ÉGYPTIEN-139D0","	* classificateur force, puissance : wsr"},
/* 139D1 */ { "HIÉROGLYPHE ÉGYPTIEN-139D1","	* logogramme (offrant à Maât) : ḥnk-mꜣꜥ.t"},
/* 139D2 */ { "HIÉROGLYPHE ÉGYPTIEN-139D2",NULL},
/* 139D3 */ { "HIÉROGLYPHE ÉGYPTIEN-139D3","	* classificateur force, effort : dndn, ḏsr"},
/* 139D4 */ { "HIÉROGLYPHE ÉGYPTIEN-139D4",NULL},
/* 139D5 */ { "HIÉROGLYPHE ÉGYPTIEN-139D5","	* logogramme (laver) : ꞽꜥꞽ"},
/* 139D6 */ { "HIÉROGLYPHE ÉGYPTIEN-139D6","	* logogramme (laver) : ꞽꜥꞽ"},
/* 139D7 */ { "HIÉROGLYPHE ÉGYPTIEN-139D7","	* logogramme (laver) : ꞽꜥꞽ"},
/* 139D8 */ { "HIÉROGLYPHE ÉGYPTIEN-139D8",NULL},
/* 139D9 */ { "HIÉROGLYPHE ÉGYPTIEN-139D9",NULL},
/* 139DA */ { "HIÉROGLYPHE ÉGYPTIEN-139DA","	* phonémogramme : ḫꜣ"},
/* 139DB */ { "HIÉROGLYPHE ÉGYPTIEN-139DB","	* classificateur lavage : ꞽꜥꞽ"},
/* 139DC */ { "HIÉROGLYPHE ÉGYPTIEN-139DC","	* logogramme (laver) : ꞽꜥꞽ"},
/* 139DD */ { "HIÉROGLYPHE ÉGYPTIEN-139DD","	* classificateur étirement : hn"},
/* 139DE */ { "HIÉROGLYPHE ÉGYPTIEN-139DE","	* classificateur action négative : ḫb"},
/* 139DF */ { "HIÉROGLYPHE ÉGYPTIEN-139DF","	* classificateur se réjouir : nḥrḥr"},
/* 139E0 */ { "HIÉROGLYPHE ÉGYPTIEN-139E0","	* classificateur appeler : nꞽs"},
/* 139E1 */ { "HIÉROGLYPHE ÉGYPTIEN-139E1","	* logogramme (protéger) : ḫwꞽ"},
/* 139E2 */ { "HIÉROGLYPHE ÉGYPTIEN-139E2","	* logogramme (rendre sacré) : ḏsr"},
/* 139E3 */ { "HIÉROGLYPHE ÉGYPTIEN-139E3",NULL},
/* 139E4 */ { "HIÉROGLYPHE ÉGYPTIEN-139E4",NULL},
/* 139E5 */ { "HIÉROGLYPHE ÉGYPTIEN-139E5",NULL},
/* 139E6 */ { "HIÉROGLYPHE ÉGYPTIEN-139E6","	* classificateur gouverner, contrôler : ḫrp"},
/* 139E7 */ { "HIÉROGLYPHE ÉGYPTIEN-139E7","	* classificateur messager : ḥw(w).t(y)"},
/* 139E8 */ { "HIÉROGLYPHE ÉGYPTIEN-139E8","	* logogramme (sacraliser, être sacré, être splendide) : ḏsr"},
/* 139E9 */ { "HIÉROGLYPHE ÉGYPTIEN-139E9","	* phonémogramme : dꞽ"},
/* 139EA */ { "HIÉROGLYPHE ÉGYPTIEN-139EA","	* classificateur au-delà : dwꜣ.t"},
/* 139EB */ { "HIÉROGLYPHE ÉGYPTIEN-139EB","	* phonémogramme : ḏsr"},
/* 139EC */ { "HIÉROGLYPHE ÉGYPTIEN-139EC","	* classificateur écrire, inscrire : spẖr"},
/* 139ED */ { "HIÉROGLYPHE ÉGYPTIEN-139ED","	* logogramme (écrire, inscrire) : spẖr"},
/* 139EE */ { "HIÉROGLYPHE ÉGYPTIEN-139EE","	* classificateur détruire, renverser : ḫmꞽ"},
/* 139EF */ { "HIÉROGLYPHE ÉGYPTIEN-139EF","	* classificateur aîné, officiel : sr"},
/* 139F0 */ { "HIÉROGLYPHE ÉGYPTIEN-139F0","	* classificateur adoration : dwꜣ"},
/* 139F1 */ { "HIÉROGLYPHE ÉGYPTIEN-139F1","	* logogramme (rendre sacré) : ḏsr"},
/* 139F2 */ { "HIÉROGLYPHE ÉGYPTIEN-139F2","	* logogramme (rendre sacré, être sacré) : ḏsr"},
/* 139F3 */ { "HIÉROGLYPHE ÉGYPTIEN-139F3","	* phonémogramme : ḏsr"},
/* 139F4 */ { "HIÉROGLYPHE ÉGYPTIEN-139F4","	* logogramme (repousser) : ḫsr"},
/* 139F5 */ { "HIÉROGLYPHE ÉGYPTIEN-139F5","	* logogramme (rendre sacré, être sacré) : ḏsr"},
/* 139F6 */ { "HIÉROGLYPHE ÉGYPTIEN-139F6","	* classificateur combat : ẖnn.w"},
/* 139F7 */ { "HIÉROGLYPHE ÉGYPTIEN-139F7","	* phonémogramme : d"},
/* 139F8 */ { "HIÉROGLYPHE ÉGYPTIEN-139F8","	* logogramme (senteur, parfum, rosée) : ꞽd.t"},
/* 139F9 */ { "HIÉROGLYPHE ÉGYPTIEN-139F9","	* phonémogramme : wd"},
/* 139FA */ { "HIÉROGLYPHE ÉGYPTIEN-139FA","	* phonémogramme : šp"},
/* 139FB */ { "HIÉROGLYPHE ÉGYPTIEN-139FB","	* logogramme (senteur, parfum, rosée) : ꞽd.t"},
/* 139FC */ { "HIÉROGLYPHE ÉGYPTIEN-139FC","	* classificateur coupe de la main : kp"},
/* 139FD */ { "HIÉROGLYPHE ÉGYPTIEN-139FD","	* ?"},
/* 139FE */ { "HIÉROGLYPHE ÉGYPTIEN-139FE","	* phonémogramme : ḥnt"},
/* 139FF */ { "HIÉROGLYPHE ÉGYPTIEN-139FF","	* phono-répéteur : ḥnt"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_3A[] = {
/* 13A00 */ { "HIÉROGLYPHE ÉGYPTIEN-13A00","	* classificateur : ḥmꜣg"},
/* 13A01 */ { "HIÉROGLYPHE ÉGYPTIEN-13A01","	* classificateur tenir fermement, saisir : nḏrꞽ"},
/* 13A02 */ { "HIÉROGLYPHE ÉGYPTIEN-13A02","	* logogramme (saisir, empoigner) : ḫfꜥ"},
/* 13A03 */ { "HIÉROGLYPHE ÉGYPTIEN-13A03","	* classificateur presser, enfermer, attacher : ꜥrf"},
/* 13A04 */ { "HIÉROGLYPHE ÉGYPTIEN-13A04","	* classificateur : ḥmꜣg"},
/* 13A05 */ { "HIÉROGLYPHE ÉGYPTIEN-13A05","	* phono-répéteur : fꜥg"},
/* 13A06 */ { "HIÉROGLYPHE ÉGYPTIEN-13A06","	* logogramme (péhou ou canal dans le 4e nome de Basse-Égypte) : mtr"},
/* 13A07 */ { "HIÉROGLYPHE ÉGYPTIEN-13A07","	* classificateur copulant : nk"},
/* 13A08 */ { "HIÉROGLYPHE ÉGYPTIEN-13A08","	* phonémogramme : bꜣḥ"},
/* 13A09 */ { "HIÉROGLYPHE ÉGYPTIEN-13A09","	* classificateur copulation : nk"},
/* 13A0A */ { "HIÉROGLYPHE ÉGYPTIEN-13A0A","	* logogramme (les deux testicules) : ꞽs.wy"},
/* 13A0B */ { "HIÉROGLYPHE ÉGYPTIEN-13A0B","	* classificateur testicules : ẖr.wy"},
/* 13A0C */ { "HIÉROGLYPHE ÉGYPTIEN-13A0C","	* classificateur testicules : ẖr.wy"},
/* 13A0D */ { "HIÉROGLYPHE ÉGYPTIEN-13A0D","	* logogramme/phonémogramme (vache) : ꞽd.t"},
/* 13A0E */ { "HIÉROGLYPHE ÉGYPTIEN-13A0E",NULL},
/* 13A0F */ { "HIÉROGLYPHE ÉGYPTIEN-13A0F","	* phonémogramme : ḥm"},
/* 13A10 */ { "HIÉROGLYPHE ÉGYPTIEN-13A10","	* phonémogramme : wr"},
/* 13A11 */ { "HIÉROGLYPHE ÉGYPTIEN-13A11","	* phonémogramme : wr(.t)"},
/* 13A12 */ { "HIÉROGLYPHE ÉGYPTIEN-13A12","	* classificateur courir : bṯ"},
/* 13A13 */ { "HIÉROGLYPHE ÉGYPTIEN-13A13","	* classificateur tomber : ḫr"},
/* 13A14 */ { "HIÉROGLYPHE ÉGYPTIEN-13A14","	* classificateur retour en arrière : šnꜥ"},
/* 13A15 */ { "HIÉROGLYPHE ÉGYPTIEN-13A15","	* classificateur se répandre : pšš"},
/* 13A16 */ { "HIÉROGLYPHE ÉGYPTIEN-13A16","	* classificateur être à l'envers : sḫd"},
/* 13A17 */ { "HIÉROGLYPHE ÉGYPTIEN-13A17","	* interprétant r et classificateur mouvement : prꞽ"},
/* 13A18 */ { "HIÉROGLYPHE ÉGYPTIEN-13A18","	* phonémogramme (dental) et classificateur mouvement : t & sḳdꞽ"},
/* 13A19 */ { "HIÉROGLYPHE ÉGYPTIEN-13A19","	* phonémogramme : wꜥr"},
/* 13A1A */ { "HIÉROGLYPHE ÉGYPTIEN-13A1A","	* logogramme (transgresser) : thꞽ"},
/* 13A1B */ { "HIÉROGLYPHE ÉGYPTIEN-13A1B","	* classificateur disparaître : snk"},
/* 13A1C */ { "HIÉROGLYPHE ÉGYPTIEN-13A1C","	* logogramme (transgression) : th"},
/* 13A1D */ { "HIÉROGLYPHE ÉGYPTIEN-13A1D","	* logogramme (être pur, être propre) : wꜥb"},
/* 13A1E */ { "HIÉROGLYPHE ÉGYPTIEN-13A1E","	* logogramme (être pur, être propre) : wꜥb"},
/* 13A1F */ { "HIÉROGLYPHE ÉGYPTIEN-13A1F","	* logogramme (être pur, être propre) : wꜥb"},
/* 13A20 */ { "HIÉROGLYPHE ÉGYPTIEN-13A20","	* phonémogramme : ꜣb"},
/* 13A21 */ { "HIÉROGLYPHE ÉGYPTIEN-13A21","	* phonémogramme : sꜣḥ"},
/* 13A22 */ { "HIÉROGLYPHE ÉGYPTIEN-13A22","	* phonémogramme (Orion) : sꜣḥ"},
/* 13A23 */ { "HIÉROGLYPHE ÉGYPTIEN-13A23","	* phonémogramme : sꜣḥ"},
/* 13A24 */ { "HIÉROGLYPHE ÉGYPTIEN-13A24","	* phonémogramme : sꜣḥ"},
/* 13A25 */ { "HIÉROGLYPHE ÉGYPTIEN-13A25",NULL},
/* 13A26 */ { "HIÉROGLYPHE ÉGYPTIEN-13A26","	* phonémogramme : sꜣḥ"},
/* 13A27 */ { "HIÉROGLYPHE ÉGYPTIEN-13A27","	* phonémogramme : gn"},
/* 13A28 */ { "HIÉROGLYPHE ÉGYPTIEN-13A28","	* phonémogramme : gn"},
/* 13A29 */ { "HIÉROGLYPHE ÉGYPTIEN-13A29","	* logogramme (Orion) : sꜣḥ"},
/* 13A2A */ { "HIÉROGLYPHE ÉGYPTIEN-13A2A","	* phonémogramme : sꜣḥ"},
/* 13A2B */ { "HIÉROGLYPHE ÉGYPTIEN-13A2B","	* phonémogramme/logogramme (annales) : gn.wt"},
/* 13A2C */ { "HIÉROGLYPHE ÉGYPTIEN-13A2C",NULL},
/* 13A2D */ { "HIÉROGLYPHE ÉGYPTIEN-13A2D","	* phonémogramme : sꜣḥ"},
/* 13A2E */ { "HIÉROGLYPHE ÉGYPTIEN-13A2E",NULL},
/* 13A2F */ { "HIÉROGLYPHE ÉGYPTIEN-13A2F","	* phonémogramme : sꜣḥ"},
/* 13A30 */ { "HIÉROGLYPHE ÉGYPTIEN-13A30",NULL},
/* 13A31 */ { "HIÉROGLYPHE ÉGYPTIEN-13A31",NULL},
/* 13A32 */ { "HIÉROGLYPHE ÉGYPTIEN-13A32","	* classificateur gorge : nḥb.t"},
/* 13A33 */ { "HIÉROGLYPHE ÉGYPTIEN-13A33","	* classificateur joues, sourcils : mnḏ.ty"},
/* 13A34 */ { "HIÉROGLYPHE ÉGYPTIEN-13A34","	* classificateur gorge : nḥb.t"},
/* 13A35 */ { "HIÉROGLYPHE ÉGYPTIEN-13A35","	* classificateur pupille : ꞽm"},
/* 13A36 */ { "HIÉROGLYPHE ÉGYPTIEN-13A36","	* classificateur portant, transportant : šdꞽ"},
/* 13A37 */ { "HIÉROGLYPHE ÉGYPTIEN-13A37","	* classificateur un violent : mds"},
/* 13A38 */ { "HIÉROGLYPHE ÉGYPTIEN-13A38","	* classificateur ennemi : ẖꜣ.tyw"},
/* 13A39 */ { "HIÉROGLYPHE ÉGYPTIEN-13A39","	* classificateur rage, colère : nšn"},
/* 13A3A */ { "HIÉROGLYPHE ÉGYPTIEN-13A3A",NULL},
/* 13A3B */ { "HIÉROGLYPHE ÉGYPTIEN-13A3B","	* logogramme (Seth) : stš/stẖ"},
/* 13A3C */ { "HIÉROGLYPHE ÉGYPTIEN-13A3C","	* classificateur Seth : nhs"},
/* 13A3D */ { "HIÉROGLYPHE ÉGYPTIEN-13A3D","	* classificateur combat : bꜥr"},
/* 13A3E */ { "HIÉROGLYPHE ÉGYPTIEN-13A3E","	* logogramme (Seth) : stš/stẖ"},
/* 13A3F */ { "HIÉROGLYPHE ÉGYPTIEN-13A3F","	* classificateur Seth : stš"},
/* 13A40 */ { "HIÉROGLYPHE ÉGYPTIEN-13A40","	* classificateur Seth : nhs"},
/* 13A41 */ { "HIÉROGLYPHE ÉGYPTIEN-13A41","	* logogramme (Seth) : stš/stẖ"},
/* 13A42 */ { "HIÉROGLYPHE ÉGYPTIEN-13A42","	* classificateur Seth : nhs"},
/* 13A43 */ { "HIÉROGLYPHE ÉGYPTIEN-13A43","	* classificateur Seth : stš"},
/* 13A44 */ { "HIÉROGLYPHE ÉGYPTIEN-13A44","	* logogramme (nome de Seth, 11e nome de Haute-Égypte) : šꜣ/stẖ/stš"},
/* 13A45 */ { "HIÉROGLYPHE ÉGYPTIEN-13A45","	* classificateur Seth : nhs"},
/* 13A46 */ { "HIÉROGLYPHE ÉGYPTIEN-13A46",NULL},
/* 13A47 */ { "HIÉROGLYPHE ÉGYPTIEN-13A47","	* logogramme (Seth) : stš/stẖ"},
/* 13A48 */ { "HIÉROGLYPHE ÉGYPTIEN-13A48",NULL},
/* 13A49 */ { "HIÉROGLYPHE ÉGYPTIEN-13A49","	* logogramme (Seth) : stš/stẖ"},
/* 13A4A */ { "HIÉROGLYPHE ÉGYPTIEN-13A4A",NULL},
/* 13A4B */ { "HIÉROGLYPHE ÉGYPTIEN-13A4B",NULL},
/* 13A4C */ { "HIÉROGLYPHE ÉGYPTIEN-13A4C","	* logogramme (Seth) : stš/stẖ"},
/* 13A4D */ { "HIÉROGLYPHE ÉGYPTIEN-13A4D",NULL},
/* 13A4E */ { "HIÉROGLYPHE ÉGYPTIEN-13A4E","	* logogramme/phonémogramme (seigneur, dans nb.ty, les deux seigneurs Horus et Seth) : nb"},
/* 13A4F */ { "HIÉROGLYPHE ÉGYPTIEN-13A4F","	* logogramme/phonémogramme (seigneur, dans nb.wy, les deux seigneurs Horus et Seth) : nb"},
/* 13A50 */ { "HIÉROGLYPHE ÉGYPTIEN-13A50","	* logogramme (Seth) : stš/stẖ"},
/* 13A51 */ { "HIÉROGLYPHE ÉGYPTIEN-13A51",NULL},
/* 13A52 */ { "HIÉROGLYPHE ÉGYPTIEN-13A52",NULL},
/* 13A53 */ { "HIÉROGLYPHE ÉGYPTIEN-13A53",NULL},
/* 13A54 */ { "HIÉROGLYPHE ÉGYPTIEN-13A54","	* logogramme (Seth) : stš/stẖ"},
/* 13A55 */ { "HIÉROGLYPHE ÉGYPTIEN-13A55","	* classificateur tempête : ḳr.y"},
/* 13A56 */ { "HIÉROGLYPHE ÉGYPTIEN-13A56","	* classificateur tempête : sšn"},
/* 13A57 */ { "HIÉROGLYPHE ÉGYPTIEN-13A57","	* logogramme/phonémogramme (seigneur, dans nb.wy, les deux seigneurs Horus et Seth) : nb"},
/* 13A58 */ { "HIÉROGLYPHE ÉGYPTIEN-13A58","	* classificateur tempête, nuage de tempête : ḳrr"},
/* 13A59 */ { "HIÉROGLYPHE ÉGYPTIEN-13A59","	* classificateur tempête, nuage de tempête : ḳrr"},
/* 13A5A */ { "HIÉROGLYPHE ÉGYPTIEN-13A5A","	* logogramme/phonémogramme (Hebenou, capitale du 16e nome de Haute-Égypte) : ḥbn.w"},
/* 13A5B */ { "HIÉROGLYPHE ÉGYPTIEN-13A5B","	* logogramme (nome de l'Oryx, 16e nome de Haute-Égypte) : mꜣ-ḥḏ"},
/* 13A5C */ { "HIÉROGLYPHE ÉGYPTIEN-13A5C","	* logogramme (nome de l'Oryx, 16e nome de Haute-Égypte) : mꜣ-ḥḏ"},
/* 13A5D */ { "HIÉROGLYPHE ÉGYPTIEN-13A5D","	* logogramme (nome de l'Oryx, 16e nome de Haute-Égypte) : mꜣ-ḥḏ"},
/* 13A5E */ { "HIÉROGLYPHE ÉGYPTIEN-13A5E","	* classificateur oryx : mꜣ-ḥḏ"},
/* 13A5F */ { "HIÉROGLYPHE ÉGYPTIEN-13A5F","	* phonémogramme : ꞽw"},
/* 13A60 */ { "HIÉROGLYPHE ÉGYPTIEN-13A60","	* phonémogramme : ꞽw"},
/* 13A61 */ { "HIÉROGLYPHE ÉGYPTIEN-13A61",NULL},
/* 13A62 */ { "HIÉROGLYPHE ÉGYPTIEN-13A62","	* classificateur oryx : mꜣ-ḥḏ"},
/* 13A63 */ { "HIÉROGLYPHE ÉGYPTIEN-13A63","	* classificateur rugisseur : hmhm.t(y)"},
/* 13A64 */ { "HIÉROGLYPHE ÉGYPTIEN-13A64","	* logogramme (troupeau, troupe) : ꜥw.t"},
/* 13A65 */ { "HIÉROGLYPHE ÉGYPTIEN-13A65","	* classificateur noble, dignité, rang : sꜥḥ"},
/* 13A66 */ { "HIÉROGLYPHE ÉGYPTIEN-13A66","	* logogram (gazelle) : gḥs"},
/* 13A67 */ { "HIÉROGLYPHE ÉGYPTIEN-13A67","	* phonémogramme : s"},
/* 13A68 */ { "HIÉROGLYPHE ÉGYPTIEN-13A68","	* logogramme (béliers) : bꜣ.w"},
/* 13A69 */ { "HIÉROGLYPHE ÉGYPTIEN-13A69","	* logogramme (fils de Rê) : sꜣ-rꜥ"},
/* 13A6A */ { "HIÉROGLYPHE ÉGYPTIEN-13A6A","	* logogramme (celui d'Edfou) : bḥd.ty"},
/* 13A6B */ { "HIÉROGLYPHE ÉGYPTIEN-13A6B","	* phonémogramme (dans bꜣ-n-rꜥ-mr.y-ꞽmn) : bꜣ"},
/* 13A6C */ { "HIÉROGLYPHE ÉGYPTIEN-13A6C","	* phonémogramme : sḥḏ"},
/* 13A6D */ { "HIÉROGLYPHE ÉGYPTIEN-13A6D","	* phonémogramme : nb"},
/* 13A6E */ { "HIÉROGLYPHE ÉGYPTIEN-13A6E","	* logogramme (au nord de) : mḥ"},
/* 13A6F */ { "HIÉROGLYPHE ÉGYPTIEN-13A6F",NULL},
/* 13A70 */ { "HIÉROGLYPHE ÉGYPTIEN-13A70","	* classificateur divinité bélier : bt"},
/* 13A71 */ { "HIÉROGLYPHE ÉGYPTIEN-13A71","	* phonémogramme : bꜣ"},
/* 13A72 */ { "HIÉROGLYPHE ÉGYPTIEN-13A72","	* phonémogramme : nb"},
/* 13A73 */ { "HIÉROGLYPHE ÉGYPTIEN-13A73",NULL},
/* 13A74 */ { "HIÉROGLYPHE ÉGYPTIEN-13A74","	* ?"},
/* 13A75 */ { "HIÉROGLYPHE ÉGYPTIEN-13A75","	* phonémogramme : ꜣms"},
/* 13A76 */ { "HIÉROGLYPHE ÉGYPTIEN-13A76","	* phonémogramme : š"},
/* 13A77 */ { "HIÉROGLYPHE ÉGYPTIEN-13A77","	* phonémogramme : šsr"},
/* 13A78 */ { "HIÉROGLYPHE ÉGYPTIEN-13A78","	* logogramme/phonémogramme (réjouir, être content) : ꜣms-ꞽb"},
/* 13A79 */ { "HIÉROGLYPHE ÉGYPTIEN-13A79",NULL},
/* 13A7A */ { "HIÉROGLYPHE ÉGYPTIEN-13A7A","	* phonémogramme : ꞽw"},
/* 13A7B */ { "HIÉROGLYPHE ÉGYPTIEN-13A7B","	* phonémogramme : ꞽw"},
/* 13A7C */ { "HIÉROGLYPHE ÉGYPTIEN-13A7C","	* classificateur chacal : wnš.w"},
/* 13A7D */ { "HIÉROGLYPHE ÉGYPTIEN-13A7D","	* phonémogramme/logogramme (ceux qui conduisent) : sb.yw"},
/* 13A7E */ { "HIÉROGLYPHE ÉGYPTIEN-13A7E","	* phonémogramme : ꞽmn.t"},
/* 13A7F */ { "HIÉROGLYPHE ÉGYPTIEN-13A7F","	* phonémogramme/logogramme (au plumage multicolore) : sꜣb-šw.t"},
/* 13A80 */ { "HIÉROGLYPHE ÉGYPTIEN-13A80","	* logogramme (chacal de Haute-Égypte) : sꜣb šmꜥ.w"},
/* 13A81 */ { "HIÉROGLYPHE ÉGYPTIEN-13A81","	* logogramme (Oupouaout de Haute-Égypte) : wp-wꜣ.wt-šmꜥ.w"},
/* 13A82 */ { "HIÉROGLYPHE ÉGYPTIEN-13A82",NULL},
/* 13A83 */ { "HIÉROGLYPHE ÉGYPTIEN-13A83","	* phonémogramme : sṯꜣ"},
/* 13A84 */ { "HIÉROGLYPHE ÉGYPTIEN-13A84","	* logogramme (Oupouaout) ? : wp-wꜣ.wt"},
/* 13A85 */ { "HIÉROGLYPHE ÉGYPTIEN-13A85","	* logogramme (ceux qui conduisent la barque de Rê) : sb.yw-wꞽꜣ-n-rꜥ"},
/* 13A86 */ { "HIÉROGLYPHE ÉGYPTIEN-13A86","	* phonémogramme : ṯsm"},
/* 13A87 */ { "HIÉROGLYPHE ÉGYPTIEN-13A87","	* logogramme (image (secrète d'un dieu)) : sštꜣ"},
/* 13A88 */ { "HIÉROGLYPHE ÉGYPTIEN-13A88","	* logogramme (rendre secret) : sštꜣ"},
/* 13A89 */ { "HIÉROGLYPHE ÉGYPTIEN-13A89","	* logogramme (l'image principale (secrète d'un dieu)) : sštꜣ-tp(.y)"},
/* 13A8A */ { "HIÉROGLYPHE ÉGYPTIEN-13A8A","	* logogramme (image (secrète d'un dieu)) : sštꜣ"},
/* 13A8B */ { "HIÉROGLYPHE ÉGYPTIEN-13A8B","	* classificateur divinité : ꞽnp.w"},
/* 13A8C */ { "HIÉROGLYPHE ÉGYPTIEN-13A8C","	* logogramme (Anubis) : ꞽnp.w"},
/* 13A8D */ { "HIÉROGLYPHE ÉGYPTIEN-13A8D","	* logogramme (Anubis) : ꞽnp.w"},
/* 13A8E */ { "HIÉROGLYPHE ÉGYPTIEN-13A8E","	* logogramme (Anubis) : ꞽnp.w"},
/* 13A8F */ { "HIÉROGLYPHE ÉGYPTIEN-13A8F","	* classificateur divinité canine : wp-wꜣ.wt"},
/* 13A90 */ { "HIÉROGLYPHE ÉGYPTIEN-13A90",NULL},
/* 13A91 */ { "HIÉROGLYPHE ÉGYPTIEN-13A91","	* classificateur divinité canine : wp-wꜣ.wt"},
/* 13A92 */ { "HIÉROGLYPHE ÉGYPTIEN-13A92","	* classificateur divinité canine : wp-wꜣ.wt"},
/* 13A93 */ { "HIÉROGLYPHE ÉGYPTIEN-13A93","	* classificateur divinité canine : wp-wꜣ.wt"},
/* 13A94 */ { "HIÉROGLYPHE ÉGYPTIEN-13A94","	* logogramme (nome du Chacal, 17e nome de Haute-Égypte) : ꞽnpw.t"},
/* 13A95 */ { "HIÉROGLYPHE ÉGYPTIEN-13A95","	* logogramme (nome du Chacal, 17e nome de Haute-Égypte) : ꞽnpw.t"},
/* 13A96 */ { "HIÉROGLYPHE ÉGYPTIEN-13A96",NULL},
/* 13A97 */ { "HIÉROGLYPHE ÉGYPTIEN-13A97","	* logogramme (initié aux secrets) : ḥr.y-sštꜣ"},
/* 13A98 */ { "HIÉROGLYPHE ÉGYPTIEN-13A98","	* logogramme (Anubis) : ꞽnp.w"},
/* 13A99 */ { "HIÉROGLYPHE ÉGYPTIEN-13A99","	* logogramme (chat) : mꞽw.t"},
/* 13A9A */ { "HIÉROGLYPHE ÉGYPTIEN-13A9A","	* logogramme (comme Rê) : mꞽ-rꜥ"},
/* 13A9B */ { "HIÉROGLYPHE ÉGYPTIEN-13A9B","	* phonémogramme : ḫft-ḥr"},
/* 13A9C */ { "HIÉROGLYPHE ÉGYPTIEN-13A9C","	* logogramme (a donné la vie comme Rê) : dꞽ-ꜥnḫ-mꞽ-rꜥ"},
/* 13A9D */ { "HIÉROGLYPHE ÉGYPTIEN-13A9D",NULL},
/* 13A9E */ { "HIÉROGLYPHE ÉGYPTIEN-13A9E","	* logogramme (jeune lionne) : ḥwn.t"},
/* 13A9F */ { "HIÉROGLYPHE ÉGYPTIEN-13A9F","	* phonémogramme : ḫft-ḥr"},
/* 13AA0 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA0","	* phonémogramme : ḫft-ḥr"},
/* 13AA1 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA1","	* phonémogramme : ḫft-ḥr"},
/* 13AA2 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA2","	* phonémogramme : m"},
/* 13AA3 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA3",NULL},
/* 13AA4 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA4","	* phonémogramme : m rw.t(y)"},
/* 13AA5 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA5","	* classificateur cheval : smsm (=ssm.t)"},
/* 13AA6 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA6","	* classificateur cheval : ssm.t"},
/* 13AA7 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA7","	* logogramme (attelage (de chevaux), cheval) : ḥtr"},
/* 13AA8 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA8","	* logogramme (attelage (de chevaux), cheval) : ḥtr"},
/* 13AA9 */ { "HIÉROGLYPHE ÉGYPTIEN-13AA9",NULL},
/* 13AAA */ { "HIÉROGLYPHE ÉGYPTIEN-13AAA","	* classificateur bétail : ꜥw.t"},
/* 13AAB */ { "HIÉROGLYPHE ÉGYPTIEN-13AAB","	* logogramme (rang, dignité) : sꜥḥ"},
/* 13AAC */ { "HIÉROGLYPHE ÉGYPTIEN-13AAC",NULL},
/* 13AAD */ { "HIÉROGLYPHE ÉGYPTIEN-13AAD",NULL},
/* 13AAE */ { "HIÉROGLYPHE ÉGYPTIEN-13AAE","	* classificateur griffon : ꜥḫḫ"},
/* 13AAF */ { "HIÉROGLYPHE ÉGYPTIEN-13AAF","	* logogramme (griffon) : ꜥḫḫ"},
/* 13AB0 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB0","	* logogramme (triomphateur) : dwn.ty"},
/* 13AB1 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB1","	* classificateur déesse hippopotame : ḥḏ.t"},
/* 13AB2 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB2",NULL},
/* 13AB3 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB3","	* classificateur hippopotame : ḫꜣb"},
/* 13AB4 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB4","	* classificateur animal dans l'eau : ꞽm.yw-mw"},
/* 13AB5 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB5","	* logogramme/phonémogramme (Ipet) : ꞽp.t"},
/* 13AB6 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB6","	* phonémogramme/logogramme (dans ꞽp.t-sw.t) : ꞽp.t"},
/* 13AB7 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB7","	* logogramme/phonémogramme (la grande) : wr.t"},
/* 13AB8 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB8","	* logogramme/phonémogramme (la grande) : wr.t"},
/* 13AB9 */ { "HIÉROGLYPHE ÉGYPTIEN-13AB9","	* logogramme (se réjouir) : bnhm"},
/* 13ABA */ { "HIÉROGLYPHE ÉGYPTIEN-13ABA","	* logogramme (première personne du singulier, se référant à Nout) : ꞽ"},
/* 13ABB */ { "HIÉROGLYPHE ÉGYPTIEN-13ABB","	* classificateur chacal : wnš.w"},
/* 13ABC */ { "HIÉROGLYPHE ÉGYPTIEN-13ABC",NULL},
/* 13ABD */ { "HIÉROGLYPHE ÉGYPTIEN-13ABD","	* phonémogramme : wn"},
/* 13ABE */ { "HIÉROGLYPHE ÉGYPTIEN-13ABE","	* phonémogramme : wn"},
/* 13ABF */ { "HIÉROGLYPHE ÉGYPTIEN-13ABF","	* logogramme (nome du Lièvre, 15e nome de Haute-Égypte) : wnw.t"},
/* 13AC0 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC0",NULL},
/* 13AC1 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC1","	* logogramme (seigneur des deux terres) : nb tꜣ.wy"},
/* 13AC2 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC2","	* classificateur lion : mꜣꞽ"},
/* 13AC3 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC3","	* logogramme (lion) : mꜣꞽ/rw/pḥ.tꞽ"},
/* 13AC4 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC4","	* phonémogramme : rw"},
/* 13AC5 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC5","	* classificateur divinité (lionne) : mḥ(.y)t"},
/* 13AC6 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC6",NULL},
/* 13AC7 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC7","	* logogramme (estrade du trône) : ṯnṯꜣ.t"},
/* 13AC8 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC8","	* logogramme (lion) : mꜣꞽ"},
/* 13AC9 */ { "HIÉROGLYPHE ÉGYPTIEN-13AC9",NULL},
/* 13ACA */ { "HIÉROGLYPHE ÉGYPTIEN-13ACA","	* logogramme (lion vivant) : mꜣꞽ-ꜥnḫ"},
/* 13ACB */ { "HIÉROGLYPHE ÉGYPTIEN-13ACB","	* logogramme (lion vivant) : mꜣꞽ-ꜥnḫ"},
/* 13ACC */ { "HIÉROGLYPHE ÉGYPTIEN-13ACC","	* phonémogramme : mds"},
/* 13ACD */ { "HIÉROGLYPHE ÉGYPTIEN-13ACD","	* phonémogramme : ḥsꜣ-šnꜥ"},
/* 13ACE */ { "HIÉROGLYPHE ÉGYPTIEN-13ACE","	* phonémogramme : pẖr"},
/* 13ACF */ { "HIÉROGLYPHE ÉGYPTIEN-13ACF","	* logogramme (présenter) : šms"},
/* 13AD0 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD0","	* logogramme/phonémogramme (roi de Haute-Égypte et de Basse-Égypte, seigneur) : n(.y)-sw.t-bꞽ.ty nb"},
/* 13AD1 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD1","	* logogramme (dans la construction sꜣ-rꜥ nb ḫꜥ.w) : rꜥ + nb"},
/* 13AD2 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD2","	* logogramme (Mehyt, divinité) : mḥ.yt"},
/* 13AD3 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD3","	* logogramme (Pachet) : pꜣḫ.t"},
/* 13AD4 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD4","	* phonémogramme tf et phonémogramme r : tf & r"},
/* 13AD5 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD5","	* phonémogramme : n"},
/* 13AD6 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD6","	* classificateur divinité : twtw"},
/* 13AD7 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD7","	* logogramme (donner, placer) : rdꞽ"},
/* 13AD8 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD8","	* phonémogramme : ḏsr"},
/* 13AD9 */ { "HIÉROGLYPHE ÉGYPTIEN-13AD9","	* phonémogramme : ršw"},
/* 13ADA */ { "HIÉROGLYPHE ÉGYPTIEN-13ADA","	* phonémogramme (dans ꜣwtwkrtr) : kr"},
/* 13ADB */ { "HIÉROGLYPHE ÉGYPTIEN-13ADB","	* logogramme (Rê) : rꜥ"},
/* 13ADC */ { "HIÉROGLYPHE ÉGYPTIEN-13ADC",NULL},
/* 13ADD */ { "HIÉROGLYPHE ÉGYPTIEN-13ADD","	* logogramme (Matit, déesse du 12e nome de Haute-Égypte) : mꜣt.yt"},
/* 13ADE */ { "HIÉROGLYPHE ÉGYPTIEN-13ADE","	* logogramme (verrou de porte) : ḥkn"},
/* 13ADF */ { "HIÉROGLYPHE ÉGYPTIEN-13ADF","	* logogramme (chaque jour) : rꜥ-nb"},
/* 13AE0 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE0","	* logogramme (Pachet) : pꜣḫ.t"},
/* 13AE1 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE1","	* phonémogramme : nb-ḫpš"},
/* 13AE2 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE2","	* phonémogramme : rdꞽ"},
/* 13AE3 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE3","	* logogramme (rendre sacré) : ḏsr"},
/* 13AE4 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE4","	* classificateur agressif comme un lion : tkn"},
/* 13AE5 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE5","	* classificateur léopard : ꜣby"},
/* 13AE6 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE6","	* phonémogramme/logogramme (rage, colère) : ḳnd"},
/* 13AE7 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE7","	* logogramme (Tefrer, lieu géographique) : tfrr"},
/* 13AE8 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE8","	* classificateur singe (divinité) : wpt"},
/* 13AE9 */ { "HIÉROGLYPHE ÉGYPTIEN-13AE9","	* logogramme (Thot) : ḏḥwty"},
/* 13AEA */ { "HIÉROGLYPHE ÉGYPTIEN-13AEA","	* logogramme (roi (de Haute-Égypte)) : n(.y)-sw.t"},
/* 13AEB */ { "HIÉROGLYPHE ÉGYPTIEN-13AEB","	* phonémogramme : bsꜣ"},
/* 13AEC */ { "HIÉROGLYPHE ÉGYPTIEN-13AEC","	* phonémogramme : bsꜣ"},
/* 13AED */ { "HIÉROGLYPHE ÉGYPTIEN-13AED","	* logogramme (scribe) : sš"},
/* 13AEE */ { "HIÉROGLYPHE ÉGYPTIEN-13AEE","	* logogramme (écrire, inscrire) : spẖr"},
/* 13AEF */ { "HIÉROGLYPHE ÉGYPTIEN-13AEF","	* logogramme (jour de l'an) : wp-rnp.t"},
/* 13AF0 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF0","	* logogramme (prononcer des mots, réciter) : ḏd-mdw"},
/* 13AF1 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF1","	* logogramme (récitation par) : ḏd-mdw-ꞽn"},
/* 13AF2 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF2",NULL},
/* 13AF3 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF3",NULL},
/* 13AF4 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF4","	* phonémogramme : sꜣ=f"},
/* 13AF5 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF5","	* phonémogramme : n-sꜣ"},
/* 13AF6 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF6",NULL},
/* 13AF7 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF7","	* classificateur objet rituel : šb.t"},
/* 13AF8 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF8","	* logogramme (symbole du cycle du temps) : wnšb"},
/* 13AF9 */ { "HIÉROGLYPHE ÉGYPTIEN-13AF9","	* logogramme (symbole du cycle du temps) : wnšb"},
/* 13AFA */ { "HIÉROGLYPHE ÉGYPTIEN-13AFA","	* phonémogramme : ꞽn"},
/* 13AFB */ { "HIÉROGLYPHE ÉGYPTIEN-13AFB","	* phonémogramme : ꞽn"},
/* 13AFC */ { "HIÉROGLYPHE ÉGYPTIEN-13AFC",NULL},
/* 13AFD */ { "HIÉROGLYPHE ÉGYPTIEN-13AFD",NULL},
/* 13AFE */ { "HIÉROGLYPHE ÉGYPTIEN-13AFE","	* logogramme (dame de l'écriture) : nb.t-sš"},
/* 13AFF */ { "HIÉROGLYPHE ÉGYPTIEN-13AFF","	* phonémogramme : t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_3B[] = {
/* 13B00 */ { "HIÉROGLYPHE ÉGYPTIEN-13B00","	* logogramme (être bon) : nfr"},
/* 13B01 */ { "HIÉROGLYPHE ÉGYPTIEN-13B01","	* logogramme (être bon) : nfr"},
/* 13B02 */ { "HIÉROGLYPHE ÉGYPTIEN-13B02","	* classificateur babouin : bꜣ.w-ꞽꜣb.tyw"},
/* 13B03 */ { "HIÉROGLYPHE ÉGYPTIEN-13B03","	* phonémogramme : nfr"},
/* 13B04 */ { "HIÉROGLYPHE ÉGYPTIEN-13B04",NULL},
/* 13B05 */ { "HIÉROGLYPHE ÉGYPTIEN-13B05","	* classificateur singe : ꞽwf"},
/* 13B06 */ { "HIÉROGLYPHE ÉGYPTIEN-13B06",NULL},
/* 13B07 */ { "HIÉROGLYPHE ÉGYPTIEN-13B07","	* logogramme/phonémogramme (au beau visage) : nfr(.t)-ḥr"},
/* 13B08 */ { "HIÉROGLYPHE ÉGYPTIEN-13B08","	* logogramme (bonne année) : rnp.t-nfr.t"},
/* 13B09 */ { "HIÉROGLYPHE ÉGYPTIEN-13B09",NULL},
/* 13B0A */ { "HIÉROGLYPHE ÉGYPTIEN-13B0A","	* logogramme (jour de l'an) : wp-rnp.t"},
/* 13B0B */ { "HIÉROGLYPHE ÉGYPTIEN-13B0B","	* phonémogramme : nfr"},
/* 13B0C */ { "HIÉROGLYPHE ÉGYPTIEN-13B0C","	* phonémogramme : nfr.w"},
/* 13B0D */ { "HIÉROGLYPHE ÉGYPTIEN-13B0D","	* phonémogramme : nfr.w"},
/* 13B0E */ { "HIÉROGLYPHE ÉGYPTIEN-13B0E","	* phonémogramme : nfr"},
/* 13B0F */ { "HIÉROGLYPHE ÉGYPTIEN-13B0F","	* logogramme/phonémogramme (la belle fleur de lotus) : nḫb nfr"},
/* 13B10 */ { "HIÉROGLYPHE ÉGYPTIEN-13B10",NULL},
/* 13B11 */ { "HIÉROGLYPHE ÉGYPTIEN-13B11","	* phonémogramme : ḏd + s + r"},
/* 13B12 */ { "HIÉROGLYPHE ÉGYPTIEN-13B12","	* logogramme (orner) ou logogramme (être amical) : sẖkr | ꞽmꜣ"},
/* 13B13 */ { "HIÉROGLYPHE ÉGYPTIEN-13B13","	* ?"},
/* 13B14 */ { "HIÉROGLYPHE ÉGYPTIEN-13B14","	* classificateur souris : pnw"},
/* 13B15 */ { "HIÉROGLYPHE ÉGYPTIEN-13B15","	* logogramme (seigneur) : nb"},
/* 13B16 */ { "HIÉROGLYPHE ÉGYPTIEN-13B16","	* logogramme (seigneur) : nb"},
/* 13B17 */ { "HIÉROGLYPHE ÉGYPTIEN-13B17","	* logogramme rꜥ et nb (dans sꜣ-rꜥ nb ḫꜥ.w) : rꜥ nb"},
/* 13B18 */ { "HIÉROGLYPHE ÉGYPTIEN-13B18","	* logogramme (roi de Haute-Égypte et de Basse-Égypte, seigneur) : n(.y)-sw.t-bꞽ.ty-nb"},
/* 13B19 */ { "HIÉROGLYPHE ÉGYPTIEN-13B19","	* logogramme (seigneur des deux terres) : nb-tꜣ.wy"},
/* 13B1A */ { "HIÉROGLYPHE ÉGYPTIEN-13B1A","	* logogramme (image vivante) : šsp-ꜥnḫ"},
/* 13B1B */ { "HIÉROGLYPHE ÉGYPTIEN-13B1B","	* logogramme (image vivante) : šsp-ꜥnḫ"},
/* 13B1C */ { "HIÉROGLYPHE ÉGYPTIEN-13B1C","	* logogramme (le seigneur unique) : nb-wꜥ"},
/* 13B1D */ { "HIÉROGLYPHE ÉGYPTIEN-13B1D","	* logogramme (le seigneur unique) : nb-wꜥ"},
/* 13B1E */ { "HIÉROGLYPHE ÉGYPTIEN-13B1E","	* logogramme (seigneur) : nb"},
/* 13B1F */ { "HIÉROGLYPHE ÉGYPTIEN-13B1F",NULL},
/* 13B20 */ { "HIÉROGLYPHE ÉGYPTIEN-13B20","	* phonémogramme : m"},
/* 13B21 */ { "HIÉROGLYPHE ÉGYPTIEN-13B21","	* logogramme (seigneur) : nb"},
/* 13B22 */ { "HIÉROGLYPHE ÉGYPTIEN-13B22","	* logogramme (présentant la myrrhe) : šms ꜥntyw"},
/* 13B23 */ { "HIÉROGLYPHE ÉGYPTIEN-13B23","	* logogramme (image, se référant au roi) : šsp"},
/* 13B24 */ { "HIÉROGLYPHE ÉGYPTIEN-13B24",NULL},
/* 13B25 */ { "HIÉROGLYPHE ÉGYPTIEN-13B25","	* logogramme (image) : šsp"},
/* 13B26 */ { "HIÉROGLYPHE ÉGYPTIEN-13B26","	* logogramme (seigneur) : nb"},
/* 13B27 */ { "HIÉROGLYPHE ÉGYPTIEN-13B27","	* classificateur divinité Aker : ꜣkr"},
/* 13B28 */ { "HIÉROGLYPHE ÉGYPTIEN-13B28","	* classificateur divinité Aker : ꜣkr"},
/* 13B29 */ { "HIÉROGLYPHE ÉGYPTIEN-13B29",NULL},
/* 13B2A */ { "HIÉROGLYPHE ÉGYPTIEN-13B2A",NULL},
/* 13B2B */ { "HIÉROGLYPHE ÉGYPTIEN-13B2B","	* classificateur Hâpi : ḥp"},
/* 13B2C */ { "HIÉROGLYPHE ÉGYPTIEN-13B2C","	* phonémogramme : nfr"},
/* 13B2D */ { "HIÉROGLYPHE ÉGYPTIEN-13B2D","	* logogramme (joug de bœufs) : ḥtr"},
/* 13B2E */ { "HIÉROGLYPHE ÉGYPTIEN-13B2E","	* phonémogramme : n-nb"},
/* 13B2F */ { "HIÉROGLYPHE ÉGYPTIEN-13B2F","	* classificateur taureau (spécifiquement dans kꜣ-ḥḏ (le taureau blanc (sacré))) : kꜣ"},
/* 13B30 */ { "HIÉROGLYPHE ÉGYPTIEN-13B30","	* classificateur bovidé (bœuf, taureau, bétail, animal mâle) : ꞽwꜣ"},
/* 13B31 */ { "HIÉROGLYPHE ÉGYPTIEN-13B31","	* classificateur joyeux, content : ꜣms"},
/* 13B32 */ { "HIÉROGLYPHE ÉGYPTIEN-13B32","	* classificateur bovidé (bœuf, taureau, bétail, animal mâle) : ꞽwꜣ"},
/* 13B33 */ { "HIÉROGLYPHE ÉGYPTIEN-13B33","	* logogramme (vache) : ꞽḥ.t"},
/* 13B34 */ { "HIÉROGLYPHE ÉGYPTIEN-13B34","	* logogramme (taureau) : kꜣ"},
/* 13B35 */ { "HIÉROGLYPHE ÉGYPTIEN-13B35","	* logogramme (bœuf sacrificiel) : smꜣ"},
/* 13B36 */ { "HIÉROGLYPHE ÉGYPTIEN-13B36","	* logogramme (bœuf sacrificiel) : smꜣ"},
/* 13B37 */ { "HIÉROGLYPHE ÉGYPTIEN-13B37","	* classificateur Seth : tbh"},
/* 13B38 */ { "HIÉROGLYPHE ÉGYPTIEN-13B38","	* logogramme (bœuf sacrificiel) : smꜣ"},
/* 13B39 */ { "HIÉROGLYPHE ÉGYPTIEN-13B39","	* classificateur tomber : ḫr"},
/* 13B3A */ { "HIÉROGLYPHE ÉGYPTIEN-13B3A",NULL},
/* 13B3B */ { "HIÉROGLYPHE ÉGYPTIEN-13B3B","	* classificateur abattage ? : sꞽd-tꜣ"},
/* 13B3C */ { "HIÉROGLYPHE ÉGYPTIEN-13B3C","	* classificateur préparer à attaquer : ṯwn"},
/* 13B3D */ { "HIÉROGLYPHE ÉGYPTIEN-13B3D",NULL},
/* 13B3E */ { "HIÉROGLYPHE ÉGYPTIEN-13B3E","	* logogramme (nome du Taureau recensé, 11e nome de Basse-Égypte) : ḥsbw"},
/* 13B3F */ { "HIÉROGLYPHE ÉGYPTIEN-13B3F","	* logogramme (nome du Taureau de la montagne, 6e nome de Basse-Égypte) : ḫꜣsw.w"},
/* 13B40 */ { "HIÉROGLYPHE ÉGYPTIEN-13B40","	* logogramme (nome du Taureau de la montagne, 6e nome de Basse-Égypte) : ḫꜣsw.w"},
/* 13B41 */ { "HIÉROGLYPHE ÉGYPTIEN-13B41","	* logogramme (nome du Chacal, 17e nome de Haute-Égypte) : sꜣkꜣ"},
/* 13B42 */ { "HIÉROGLYPHE ÉGYPTIEN-13B42","	* logogramme (nome du Veau divin, 12e nome de Basse-Égypte) : ṯb-nṯr"},
/* 13B43 */ { "HIÉROGLYPHE ÉGYPTIEN-13B43","	* classificateur divinité : nsr-msr"},
/* 13B44 */ { "HIÉROGLYPHE ÉGYPTIEN-13B44","	* phonémogramme (dans ꜣms-ꞽb (se réjouir)) : ꜣms"},
/* 13B45 */ { "HIÉROGLYPHE ÉGYPTIEN-13B45","	* phonémogramme : bꜣẖ"},
/* 13B46 */ { "HIÉROGLYPHE ÉGYPTIEN-13B46","	* classificateur divinité vache : ḥs(ꜣ).t"},
/* 13B47 */ { "HIÉROGLYPHE ÉGYPTIEN-13B47","	* phonémogramme (dans ꜣms-ꞽb) : ꜣms"},
/* 13B48 */ { "HIÉROGLYPHE ÉGYPTIEN-13B48","	* phonémogramme : wbn"},
/* 13B49 */ { "HIÉROGLYPHE ÉGYPTIEN-13B49","	* logogramme (dame) : nb.t"},
/* 13B4A */ { "HIÉROGLYPHE ÉGYPTIEN-13B4A","	* logogramme (Rê et seigneur (dans sꜣ-rꜥ nb ḫꜥ.w)) : rꜥ nb"},
/* 13B4B */ { "HIÉROGLYPHE ÉGYPTIEN-13B4B",NULL},
/* 13B4C */ { "HIÉROGLYPHE ÉGYPTIEN-13B4C","	* logogramme (bétail) : wnḏw"},
/* 13B4D */ { "HIÉROGLYPHE ÉGYPTIEN-13B4D","	* logogramme (roi de Haute-Égypte et de Basse-Égypte, seigneur) : n(.y)-sw.t bꞽ.ty nb"},
/* 13B4E */ { "HIÉROGLYPHE ÉGYPTIEN-13B4E","	* classificateur divinité vache : ḥs(ꜣ).t"},
/* 13B4F */ { "HIÉROGLYPHE ÉGYPTIEN-13B4F","	* logogramme (Rê et seigneur (dans sꜣ-rꜥ nb ḫꜥ.w)) : rꜥ nb"},
/* 13B50 */ { "HIÉROGLYPHE ÉGYPTIEN-13B50","	* classificateur divinité vache : ꞽh.t"},
/* 13B51 */ { "HIÉROGLYPHE ÉGYPTIEN-13B51","	* classificateur divinité vache : ḥs(ꜣ).t"},
/* 13B52 */ { "HIÉROGLYPHE ÉGYPTIEN-13B52",NULL},
/* 13B53 */ { "HIÉROGLYPHE ÉGYPTIEN-13B53","	* phonémogramme (dans km-wr) : wr"},
/* 13B54 */ { "HIÉROGLYPHE ÉGYPTIEN-13B54","	* logogramme (nome du Taureau noir, 10e nome de Basse-Égypte) : km-wr"},
/* 13B55 */ { "HIÉROGLYPHE ÉGYPTIEN-13B55",NULL},
/* 13B56 */ { "HIÉROGLYPHE ÉGYPTIEN-13B56","	* logogramme (nome du Veau divin, 12e nome de Basse-Égypte) : ṯb-nṯr"},
/* 13B57 */ { "HIÉROGLYPHE ÉGYPTIEN-13B57","	* classificateur taureau : kꜣ"},
/* 13B58 */ { "HIÉROGLYPHE ÉGYPTIEN-13B58","	* logogramme (taureau, bœuf) : kꜥ/ꞽḥ"},
/* 13B59 */ { "HIÉROGLYPHE ÉGYPTIEN-13B59","	* classificateur divinité (cracheur de cendres) : ꜣš-ssf"},
/* 13B5A */ { "HIÉROGLYPHE ÉGYPTIEN-13B5A","	* classificateur Âmmout : ꜥmm.t"},
/* 13B5B */ { "HIÉROGLYPHE ÉGYPTIEN-13B5B","	* classificateur rhinocéros : šḳb"},
/* 13B5C */ { "HIÉROGLYPHE ÉGYPTIEN-13B5C","	* phonémogramme : hrw"},
/* 13B5D */ { "HIÉROGLYPHE ÉGYPTIEN-13B5D","	* phonémogramme : sš"},
/* 13B5E */ { "HIÉROGLYPHE ÉGYPTIEN-13B5E",NULL},
/* 13B5F */ { "HIÉROGLYPHE ÉGYPTIEN-13B5F","	* phonémogramme : hrw"},
/* 13B60 */ { "HIÉROGLYPHE ÉGYPTIEN-13B60","	* logogramme (valeur, dignité, renommée) : šf.yt"},
/* 13B61 */ { "HIÉROGLYPHE ÉGYPTIEN-13B61","	* classificateur bélier : rhny"},
/* 13B62 */ { "HIÉROGLYPHE ÉGYPTIEN-13B62","	* classificateur valeur, dignité, renommée : šf.yt"},
/* 13B63 */ { "HIÉROGLYPHE ÉGYPTIEN-13B63","	* classificateur valeur, dignité, renommée : šf.y"},
/* 13B64 */ { "HIÉROGLYPHE ÉGYPTIEN-13B64","	* logogramme (valeur, dignité, renommée) : šf.yt"},
/* 13B65 */ { "HIÉROGLYPHE ÉGYPTIEN-13B65","	* classificateur couronne atef : ꜣtf"},
/* 13B66 */ { "HIÉROGLYPHE ÉGYPTIEN-13B66","	* logogramme (valeur, dignité, renommée) : šf.yt"},
/* 13B67 */ { "HIÉROGLYPHE ÉGYPTIEN-13B67","	* logogramme (valeur, dignité, renommée) : šf.yt"},
/* 13B68 */ { "HIÉROGLYPHE ÉGYPTIEN-13B68","	* classificateur valeur, dignité, renommée : šf.yt"},
/* 13B69 */ { "HIÉROGLYPHE ÉGYPTIEN-13B69","	* logogramme (les huit dieux primordiaux) : ẖnmwy"},
/* 13B6A */ { "HIÉROGLYPHE ÉGYPTIEN-13B6A","	* logogramme (taureau) : kꜣ"},
/* 13B6B */ { "HIÉROGLYPHE ÉGYPTIEN-13B6B","	* phonémogramme : smꜣ"},
/* 13B6C */ { "HIÉROGLYPHE ÉGYPTIEN-13B6C","	* classificateur rage, agression : ḏnd"},
/* 13B6D */ { "HIÉROGLYPHE ÉGYPTIEN-13B6D","	* phonémogramme : šsmw"},
/* 13B6E */ { "HIÉROGLYPHE ÉGYPTIEN-13B6E","	* logogramme (taureau) : kꜣ"},
/* 13B6F */ { "HIÉROGLYPHE ÉGYPTIEN-13B6F","	* classificateur : ḫtn"},
/* 13B70 */ { "HIÉROGLYPHE ÉGYPTIEN-13B70","	* classificateur constellation de la Grande Ourse : msḫt.yw"},
/* 13B71 */ { "HIÉROGLYPHE ÉGYPTIEN-13B71","	* logogramme (taureau) : kꜣ"},
/* 13B72 */ { "HIÉROGLYPHE ÉGYPTIEN-13B72","	* classificateur nez : fnḏ"},
/* 13B73 */ { "HIÉROGLYPHE ÉGYPTIEN-13B73","	* classificateur embrassant : sn"},
/* 13B74 */ { "HIÉROGLYPHE ÉGYPTIEN-13B74","	* classificateur porte à deux battants : ḫns"},
/* 13B75 */ { "HIÉROGLYPHE ÉGYPTIEN-13B75","	* logogramme (porte à deux battants) : ḫns"},
/* 13B76 */ { "HIÉROGLYPHE ÉGYPTIEN-13B76","	* phonémogramme : stꜣ"},
/* 13B77 */ { "HIÉROGLYPHE ÉGYPTIEN-13B77","	* phonémogramme : stꜣ"},
/* 13B78 */ { "HIÉROGLYPHE ÉGYPTIEN-13B78","	* phonémogramme : stꜣ"},
/* 13B79 */ { "HIÉROGLYPHE ÉGYPTIEN-13B79","	* phonémogramme : stꜣ"},
/* 13B7A */ { "HIÉROGLYPHE ÉGYPTIEN-13B7A",NULL},
/* 13B7B */ { "HIÉROGLYPHE ÉGYPTIEN-13B7B","	* phonémogramme : stꜣ"},
/* 13B7C */ { "HIÉROGLYPHE ÉGYPTIEN-13B7C","	* phonémogramme : stꜣ"},
/* 13B7D */ { "HIÉROGLYPHE ÉGYPTIEN-13B7D","	* logogramme (chacal) : sꜣb"},
/* 13B7E */ { "HIÉROGLYPHE ÉGYPTIEN-13B7E",NULL},
/* 13B7F */ { "HIÉROGLYPHE ÉGYPTIEN-13B7F","	* logogramme (Ennéade) : psḏ.t"},
/* 13B80 */ { "HIÉROGLYPHE ÉGYPTIEN-13B80",NULL},
/* 13B81 */ { "HIÉROGLYPHE ÉGYPTIEN-13B81","	* phonémogramme : wsr"},
/* 13B82 */ { "HIÉROGLYPHE ÉGYPTIEN-13B82","	* logogramme (gorge) : ḥt.yt"},
/* 13B83 */ { "HIÉROGLYPHE ÉGYPTIEN-13B83","	* logogramme (gorge) : ḥt.yt"},
/* 13B84 */ { "HIÉROGLYPHE ÉGYPTIEN-13B84",NULL},
/* 13B85 */ { "HIÉROGLYPHE ÉGYPTIEN-13B85","	* phonémogramme : wsr"},
/* 13B86 */ { "HIÉROGLYPHE ÉGYPTIEN-13B86","	* phonémogramme : wsr"},
/* 13B87 */ { "HIÉROGLYPHE ÉGYPTIEN-13B87","	* logogram (gazelle) : gḥs"},
/* 13B88 */ { "HIÉROGLYPHE ÉGYPTIEN-13B88","	* phonémogramme : šsr"},
/* 13B89 */ { "HIÉROGLYPHE ÉGYPTIEN-13B89","	* phonémogramme : šsm"},
/* 13B8A */ { "HIÉROGLYPHE ÉGYPTIEN-13B8A","	* logogramme (antilope) : mꜣ"},
/* 13B8B */ { "HIÉROGLYPHE ÉGYPTIEN-13B8B","	* phonémogramme : šsr"},
/* 13B8C */ { "HIÉROGLYPHE ÉGYPTIEN-13B8C","	* logogramme (ibex) : n(ꞽ)ꜣw"},
/* 13B8D */ { "HIÉROGLYPHE ÉGYPTIEN-13B8D",NULL},
/* 13B8E */ { "HIÉROGLYPHE ÉGYPTIEN-13B8E","	* phonémogramme : dn"},
/* 13B8F */ { "HIÉROGLYPHE ÉGYPTIEN-13B8F","	* phonémogramme : ꜣt"},
/* 13B90 */ { "HIÉROGLYPHE ÉGYPTIEN-13B90","	* phonémogramme : pꜣḫt"},
/* 13B91 */ { "HIÉROGLYPHE ÉGYPTIEN-13B91","	* logogramme (distinguer) et (début, avant) : ṯnꞽ ḥꜣ.t"},
/* 13B92 */ { "HIÉROGLYPHE ÉGYPTIEN-13B92","	* logogramme (début, devant) : ḥꜣ.t"},
/* 13B93 */ { "HIÉROGLYPHE ÉGYPTIEN-13B93","	* classificateur fête de Haker : hꜣkr"},
/* 13B94 */ { "HIÉROGLYPHE ÉGYPTIEN-13B94","	* logogramme (Khonsou) : ḫnsw"},
/* 13B95 */ { "HIÉROGLYPHE ÉGYPTIEN-13B95","	* classificateur force : ꜣ.t"},
/* 13B96 */ { "HIÉROGLYPHE ÉGYPTIEN-13B96",NULL},
/* 13B97 */ { "HIÉROGLYPHE ÉGYPTIEN-13B97","	* phonémogramme : ḫntš"},
/* 13B98 */ { "HIÉROGLYPHE ÉGYPTIEN-13B98","	* phonémogramme : ḫntš"},
/* 13B99 */ { "HIÉROGLYPHE ÉGYPTIEN-13B99",NULL},
/* 13B9A */ { "HIÉROGLYPHE ÉGYPTIEN-13B9A","	* phonémogramme : ḫntš"},
/* 13B9B */ { "HIÉROGLYPHE ÉGYPTIEN-13B9B","	* phonémogramme : ḫntš"},
/* 13B9C */ { "HIÉROGLYPHE ÉGYPTIEN-13B9C","	* phonémogramme : ḫntš"},
/* 13B9D */ { "HIÉROGLYPHE ÉGYPTIEN-13B9D","	* phonémogramme : ḫntš"},
/* 13B9E */ { "HIÉROGLYPHE ÉGYPTIEN-13B9E",NULL},
/* 13B9F */ { "HIÉROGLYPHE ÉGYPTIEN-13B9F","	* phonémogramme : ḫntš"},
/* 13BA0 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA0","	* phono-répéteur : ḫntš"},
/* 13BA1 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA1","	* phonémogramme : ꜣbw"},
/* 13BA2 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA2","	* classificateur hyène : ḥṯ.t"},
/* 13BA3 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA3","	* logogramme (rage) : nšn"},
/* 13BA4 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA4","	* logogramme (jour de l'an) : wp-rnp.t"},
/* 13BA5 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA5","	* logogramme (jour de l'an) : wp-rnp.t"},
/* 13BA6 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA6","	* phonémogramme (communément dans wp-rnp.t) : wp"},
/* 13BA7 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA7",NULL},
/* 13BA8 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA8",NULL},
/* 13BA9 */ { "HIÉROGLYPHE ÉGYPTIEN-13BA9","	* logogramme (celui qui se réveille entier) : rs-wḏꜣ"},
/* 13BAA */ { "HIÉROGLYPHE ÉGYPTIEN-13BAA","	* phonémogramme : dmḏ"},
/* 13BAB */ { "HIÉROGLYPHE ÉGYPTIEN-13BAB","	* phonémogramme : dmḏ"},
/* 13BAC */ { "HIÉROGLYPHE ÉGYPTIEN-13BAC",NULL},
/* 13BAD */ { "HIÉROGLYPHE ÉGYPTIEN-13BAD",NULL},
/* 13BAE */ { "HIÉROGLYPHE ÉGYPTIEN-13BAE","	* logogramme (être vrai) : mꜣꜥ"},
/* 13BAF */ { "HIÉROGLYPHE ÉGYPTIEN-13BAF",NULL},
/* 13BB0 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB0",NULL},
/* 13BB1 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB1",NULL},
/* 13BB2 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB2","	* classificateur mandibule : ꜥr"},
/* 13BB3 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB3","	* phonémogramme : ns"},
/* 13BB4 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB4","	* phonémogramme : ns"},
/* 13BB5 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB5","	* phonémogramme : ns"},
/* 13BB6 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB6","	* logogramme (entendre, écouter)"},
/* 13BB7 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB7","	* logogramme (magie) : ḥkꜣ.w"},
/* 13BB8 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB8","	* phonémogramme : sḳr"},
/* 13BB9 */ { "HIÉROGLYPHE ÉGYPTIEN-13BB9","	* classificateur cuisse : mn.t"},
/* 13BBA */ { "HIÉROGLYPHE ÉGYPTIEN-13BBA",NULL},
/* 13BBB */ { "HIÉROGLYPHE ÉGYPTIEN-13BBB",NULL},
/* 13BBC */ { "HIÉROGLYPHE ÉGYPTIEN-13BBC","	* phonémogramme : sḳr"},
/* 13BBD */ { "HIÉROGLYPHE ÉGYPTIEN-13BBD","	* logogramme (répéter) : wḥm"},
/* 13BBE */ { "HIÉROGLYPHE ÉGYPTIEN-13BBE","	* phonémogramme : nm"},
/* 13BBF */ { "HIÉROGLYPHE ÉGYPTIEN-13BBF","	* phonémogramme : nm"},
/* 13BC0 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC0","	* phonémogramme : kꜣp (gb)"},
/* 13BC1 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC1",NULL},
/* 13BC2 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC2","	* phonémogramme : kꜣp"},
/* 13BC3 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC3","	* phonémogramme : kꜣp"},
/* 13BC4 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC4","	* logogramme (Létopolis) : ḫm"},
/* 13BC5 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC5","	* phonémogramme : bḫ"},
/* 13BC6 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC6","	* phonémogramme : bḫn"},
/* 13BC7 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC7","	* classificateur animal : pꜣ-mꞽw"},
/* 13BC8 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC8","	* phonémogramme : m"},
/* 13BC9 */ { "HIÉROGLYPHE ÉGYPTIEN-13BC9","	* classificateur animal : ꜥw.t"},
/* 13BCA */ { "HIÉROGLYPHE ÉGYPTIEN-13BCA","	* classificateur peau de léopard : bꜣ"},
/* 13BCB */ { "HIÉROGLYPHE ÉGYPTIEN-13BCB","	* classificateur sabot : ꜥꜣg.t"},
/* 13BCC */ { "HIÉROGLYPHE ÉGYPTIEN-13BCC","	* phonémogramme : st"},
/* 13BCD */ { "HIÉROGLYPHE ÉGYPTIEN-13BCD","	* phonémogramme : st"},
/* 13BCE */ { "HIÉROGLYPHE ÉGYPTIEN-13BCE","	* phonémogramme : wt"},
/* 13BCF */ { "HIÉROGLYPHE ÉGYPTIEN-13BCF","	* phonémogramme : ḫnt"},
/* 13BD0 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD0","	* phonémogramme : šd"},
/* 13BD1 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD1","	* phonémogramme : šd"},
/* 13BD2 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD2","	* logogramme (peau, outre) : šd.w"},
/* 13BD3 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD3","	* phonémogramme : ms"},
/* 13BD4 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD4","	* classificateur arrière, bout : pḥ.wy"},
/* 13BD5 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD5","	* phonémogramme : ẖr"},
/* 13BD6 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD6","	* phono-répéteur : sd"},
/* 13BD7 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD7","	* phonémogramme : ꜣbw"},
/* 13BD8 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD8","	* phonémogramme : mꜣ"},
/* 13BD9 */ { "HIÉROGLYPHE ÉGYPTIEN-13BD9",NULL},
/* 13BDA */ { "HIÉROGLYPHE ÉGYPTIEN-13BDA","	* phonémogramme : mꜣṯ"},
/* 13BDB */ { "HIÉROGLYPHE ÉGYPTIEN-13BDB","	* phonémogramme : ꜣbw"},
/* 13BDC */ { "HIÉROGLYPHE ÉGYPTIEN-13BDC","	* phonémogramme : mꜣṯ"},
/* 13BDD */ { "HIÉROGLYPHE ÉGYPTIEN-13BDD","	* phonémogramme : nfr"},
/* 13BDE */ { "HIÉROGLYPHE ÉGYPTIEN-13BDE","	* phonémogramme : nfr"},
/* 13BDF */ { "HIÉROGLYPHE ÉGYPTIEN-13BDF","	* phonémogramme : smꜣ"},
/* 13BE0 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE0","	* phonémogramme : smꜣ"},
/* 13BE1 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE1","	* phonémogramme : smꜣ"},
/* 13BE2 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE2","	* logogramme (qui unit les deux terres) : smꜣ-tꜣ.wy"},
/* 13BE3 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE3","	* classificateur épine dorsale : psḏ"},
/* 13BE4 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE4","	* classificateur dos, épine dorsale : psḏ"},
/* 13BE5 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE5","	* classificateur dos, épine dorsale : psḏ"},
/* 13BE6 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE6","	* classificateur découpe, abattage : ꜥḏy.t"},
/* 13BE7 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE7","	* phono-répéteur : mḥ"},
/* 13BE8 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE8","	* classificateur découpe : šꜥd\n"
	"	~ 13BE8 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 13BE9 */ { "HIÉROGLYPHE ÉGYPTIEN-13BE9","	* classificateur morceaux, pièces : spꞽ\n"
	"	~ 13BE9 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 13BEA */ { "HIÉROGLYPHE ÉGYPTIEN-13BEA","	* phono-répéteur : mḥ\n"
	"	~ 13BEA FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 13BEB */ { "HIÉROGLYPHE ÉGYPTIEN-13BEB","	* phonémogramme : tꜣy"},
/* 13BEC */ { "HIÉROGLYPHE ÉGYPTIEN-13BEC","	* phonémogramme : ꞽmꜣḫ"},
/* 13BED */ { "HIÉROGLYPHE ÉGYPTIEN-13BED",NULL},
/* 13BEE */ { "HIÉROGLYPHE ÉGYPTIEN-13BEE","	* logogramme (être long, s'étirer) : ꜣwꞽ"},
/* 13BEF */ { "HIÉROGLYPHE ÉGYPTIEN-13BEF","	* logogramme (être long, s'étirer) : ꜣwꞽ"},
/* 13BF0 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF0","	* classificateur côte (offrande) : spr"},
/* 13BF1 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF1","	* logogramme (abattage, maléfique) : šꜥ.t"},
/* 13BF2 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF2","	* logogramme (abattage, maléfique) : šꜥ.t"},
/* 13BF3 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF3","	* classificateur côte (offrande) : spr"},
/* 13BF4 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF4",NULL},
/* 13BF5 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF5","	* logogramme (apporter, présenter, offrir, aller) : ms"},
/* 13BF6 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF6","	* phonémogramme et classificateur mouvement (dans thm (fouler, pénétrer)) : m"},
/* 13BF7 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF7","	* phono-répéteur : ꞽwꜥ"},
/* 13BF8 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF8","	* classificateur viande : mḏ-nfr"},
/* 13BF9 */ { "HIÉROGLYPHE ÉGYPTIEN-13BF9",NULL},
/* 13BFA */ { "HIÉROGLYPHE ÉGYPTIEN-13BFA","	* classificateur offrant de la viande : sḫn"},
/* 13BFB */ { "HIÉROGLYPHE ÉGYPTIEN-13BFB","	* phonémogramme : ꞽ(w)n"},
/* 13BFC */ { "HIÉROGLYPHE ÉGYPTIEN-13BFC","	* logogramme (membre) : ꜥ.t"},
/* 13BFD */ { "HIÉROGLYPHE ÉGYPTIEN-13BFD","	* phonémogramme : dbn"},
/* 13BFE */ { "HIÉROGLYPHE ÉGYPTIEN-13BFE","	* phonémogramme (dans m-pẖr) : pẖr"},
/* 13BFF */ { "HIÉROGLYPHE ÉGYPTIEN-13BFF","	* logogramme (faire le tour, tourner) : pẖr"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_3C[] = {
/* 13C00 */ { "HIÉROGLYPHE ÉGYPTIEN-13C00","	* logogramme (faire le tour, tourner) : pẖr"},
/* 13C01 */ { "HIÉROGLYPHE ÉGYPTIEN-13C01","	* classificateur odeur : stꞽ"},
/* 13C02 */ { "HIÉROGLYPHE ÉGYPTIEN-13C02","	* classificateur odeur : stꞽ"},
/* 13C03 */ { "HIÉROGLYPHE ÉGYPTIEN-13C03","	* phonémogramme : ḫ"},
/* 13C04 */ { "HIÉROGLYPHE ÉGYPTIEN-13C04","	* phonémogramme ou classificateur ennemi : ḫ | ḫfty"},
/* 13C05 */ { "HIÉROGLYPHE ÉGYPTIEN-13C05","	* classificateur foie : mꞽs.t"},
/* 13C06 */ { "HIÉROGLYPHE ÉGYPTIEN-13C06",NULL},
/* 13C07 */ { "HIÉROGLYPHE ÉGYPTIEN-13C07","	* classificateur griffes ou crocs : wḫꜣ.w"},
/* 13C08 */ { "HIÉROGLYPHE ÉGYPTIEN-13C08","	* classificateur colonne vertébrale : bḳs.w"},
/* 13C09 */ { "HIÉROGLYPHE ÉGYPTIEN-13C09","	* phonémogramme : tmꜣ"},
/* 13C0A */ { "HIÉROGLYPHE ÉGYPTIEN-13C0A","	* phonémogramme : tm"},
/* 13C0B */ { "HIÉROGLYPHE ÉGYPTIEN-13C0B","	* logogramme (autruche) : nꞽw"},
/* 13C0C */ { "HIÉROGLYPHE ÉGYPTIEN-13C0C",NULL},
/* 13C0D */ { "HIÉROGLYPHE ÉGYPTIEN-13C0D",NULL},
/* 13C0E */ { "HIÉROGLYPHE ÉGYPTIEN-13C0E","	* logogramme (trembler) : sdꜣ"},
/* 13C0F */ { "HIÉROGLYPHE ÉGYPTIEN-13C0F","	* classificateur trembler : sd(ꜣ)d(ꜣ)"},
/* 13C10 */ { "HIÉROGLYPHE ÉGYPTIEN-13C10","	* phonémogramme (comme dans ḫsbd lapis-lazuli) : b"},
/* 13C11 */ { "HIÉROGLYPHE ÉGYPTIEN-13C11","	* logogramme (âme) : bꜣ"},
/* 13C12 */ { "HIÉROGLYPHE ÉGYPTIEN-13C12",NULL},
/* 13C13 */ { "HIÉROGLYPHE ÉGYPTIEN-13C13","	* phono-répéteur : ḥtm"},
/* 13C14 */ { "HIÉROGLYPHE ÉGYPTIEN-13C14","	* phonémogramme : ḫntš"},
/* 13C15 */ { "HIÉROGLYPHE ÉGYPTIEN-13C15","	* logogramme (Sépa) : spꜣ"},
/* 13C16 */ { "HIÉROGLYPHE ÉGYPTIEN-13C16","	* phonémogramme : pꜣ(.yw)"},
/* 13C17 */ { "HIÉROGLYPHE ÉGYPTIEN-13C17","	* logogramme (trembler) : sdꜣ(dꜣ)"},
/* 13C18 */ { "HIÉROGLYPHE ÉGYPTIEN-13C18","	* phonémogramme : pꜣ"},
/* 13C19 */ { "HIÉROGLYPHE ÉGYPTIEN-13C19","	* logogramme (détruire) : ḥtm"},
/* 13C1A */ { "HIÉROGLYPHE ÉGYPTIEN-13C1A","	* classificateur : ḥtm"},
/* 13C1B */ { "HIÉROGLYPHE ÉGYPTIEN-13C1B","	* phonémogramme : ḫn"},
/* 13C1C */ { "HIÉROGLYPHE ÉGYPTIEN-13C1C","	* phonémogramme : ḫntš"},
/* 13C1D */ { "HIÉROGLYPHE ÉGYPTIEN-13C1D","	* phonémogramme : ḫntš"},
/* 13C1E */ { "HIÉROGLYPHE ÉGYPTIEN-13C1E",NULL},
/* 13C1F */ { "HIÉROGLYPHE ÉGYPTIEN-13C1F","	* phonémogramme : ḥtr"},
/* 13C20 */ { "HIÉROGLYPHE ÉGYPTIEN-13C20","	* phonémogramme : ḥtr"},
/* 13C21 */ { "HIÉROGLYPHE ÉGYPTIEN-13C21","	* phonémogramme : ḳmꜣ"},
/* 13C22 */ { "HIÉROGLYPHE ÉGYPTIEN-13C22","	* phonémogramme : ḳmꜣ"},
/* 13C23 */ { "HIÉROGLYPHE ÉGYPTIEN-13C23","	* phonémogramme : ḳmꜣ"},
/* 13C24 */ { "HIÉROGLYPHE ÉGYPTIEN-13C24",NULL},
/* 13C25 */ { "HIÉROGLYPHE ÉGYPTIEN-13C25","	* phonémogramme : ḏfꜣ"},
/* 13C26 */ { "HIÉROGLYPHE ÉGYPTIEN-13C26",NULL},
/* 13C27 */ { "HIÉROGLYPHE ÉGYPTIEN-13C27","	* phonémogramme : smn"},
/* 13C28 */ { "HIÉROGLYPHE ÉGYPTIEN-13C28","	* phono-répéteur : ḥtm"},
/* 13C29 */ { "HIÉROGLYPHE ÉGYPTIEN-13C29","	* phonémogramme : ḏb"},
/* 13C2A */ { "HIÉROGLYPHE ÉGYPTIEN-13C2A","	* classificateur couché, dormant, passant la nuit : sḏr"},
/* 13C2B */ { "HIÉROGLYPHE ÉGYPTIEN-13C2B","	* phonémogramme : gm"},
/* 13C2C */ { "HIÉROGLYPHE ÉGYPTIEN-13C2C",NULL},
/* 13C2D */ { "HIÉROGLYPHE ÉGYPTIEN-13C2D","	* phonémogramme : m"},
/* 13C2E */ { "HIÉROGLYPHE ÉGYPTIEN-13C2E","	* phonémogramme : mr (ꞽm.y-r)"},
/* 13C2F */ { "HIÉROGLYPHE ÉGYPTIEN-13C2F","	* phonémogramme : mr (ꞽm.y-r)"},
/* 13C30 */ { "HIÉROGLYPHE ÉGYPTIEN-13C30","	* phonémogramme/phono-répéteur : ꞽb"},
/* 13C31 */ { "HIÉROGLYPHE ÉGYPTIEN-13C31","	* phonémogramme : ꜥḳ"},
/* 13C32 */ { "HIÉROGLYPHE ÉGYPTIEN-13C32",NULL},
/* 13C33 */ { "HIÉROGLYPHE ÉGYPTIEN-13C33","	* phonémogramme : gm"},
/* 13C34 */ { "HIÉROGLYPHE ÉGYPTIEN-13C34","	* phonémogramme : bꜣ"},
/* 13C35 */ { "HIÉROGLYPHE ÉGYPTIEN-13C35",NULL},
/* 13C36 */ { "HIÉROGLYPHE ÉGYPTIEN-13C36","	* phonémogramme : b"},
/* 13C37 */ { "HIÉROGLYPHE ÉGYPTIEN-13C37","	* logogramme (âme) : bꜣ"},
/* 13C38 */ { "HIÉROGLYPHE ÉGYPTIEN-13C38","	* logogramme (âme) : bꜣ"},
/* 13C39 */ { "HIÉROGLYPHE ÉGYPTIEN-13C39",NULL},
/* 13C3A */ { "HIÉROGLYPHE ÉGYPTIEN-13C3A","	* logogramme (puissance, pouvoir) : bꜣ.w"},
/* 13C3B */ { "HIÉROGLYPHE ÉGYPTIEN-13C3B",NULL},
/* 13C3C */ { "HIÉROGLYPHE ÉGYPTIEN-13C3C","	* logogramme (débiter, ouvrir (la terre)) : bꜣ"},
/* 13C3D */ { "HIÉROGLYPHE ÉGYPTIEN-13C3D",NULL},
/* 13C3E */ { "HIÉROGLYPHE ÉGYPTIEN-13C3E",NULL},
/* 13C3F */ { "HIÉROGLYPHE ÉGYPTIEN-13C3F",NULL},
/* 13C40 */ { "HIÉROGLYPHE ÉGYPTIEN-13C40","	* phonémogramme : ty"},
/* 13C41 */ { "HIÉROGLYPHE ÉGYPTIEN-13C41",NULL},
/* 13C42 */ { "HIÉROGLYPHE ÉGYPTIEN-13C42",NULL},
/* 13C43 */ { "HIÉROGLYPHE ÉGYPTIEN-13C43","	* phonémogramme : yt"},
/* 13C44 */ { "HIÉROGLYPHE ÉGYPTIEN-13C44",NULL},
/* 13C45 */ { "HIÉROGLYPHE ÉGYPTIEN-13C45","	* phonémogramme : ḥꜣm"},
/* 13C46 */ { "HIÉROGLYPHE ÉGYPTIEN-13C46","	* phonémogramme : gm"},
/* 13C47 */ { "HIÉROGLYPHE ÉGYPTIEN-13C47","	* classificateur offrande d'oiseau : nšn"},
/* 13C48 */ { "HIÉROGLYPHE ÉGYPTIEN-13C48","	* classificateur destruction, détruire (dans ce cas spécifiquement dans ḥtm.yt, lieu d'exécution) : ḥtm"},
/* 13C49 */ { "HIÉROGLYPHE ÉGYPTIEN-13C49","	* logogramme (oiseau, volaille) : ꜣpd"},
/* 13C4A */ { "HIÉROGLYPHE ÉGYPTIEN-13C4A","	* phonémogramme : b"},
/* 13C4B */ { "HIÉROGLYPHE ÉGYPTIEN-13C4B","	* logogramme (puissance, pouvoir) : bꜣ.w"},
/* 13C4C */ { "HIÉROGLYPHE ÉGYPTIEN-13C4C","	* logogramme/phonémogramme (dans ḥw.t-bꜣ.w (salle dans le temple d'Esna)) : bꜣ.w"},
/* 13C4D */ { "HIÉROGLYPHE ÉGYPTIEN-13C4D","	* phonémogramme : ꜣḫ"},
/* 13C4E */ { "HIÉROGLYPHE ÉGYPTIEN-13C4E","	* logogramme (dieu) : nṯr"},
/* 13C4F */ { "HIÉROGLYPHE ÉGYPTIEN-13C4F","	* logogramme (dieu) : nṯr"},
/* 13C50 */ { "HIÉROGLYPHE ÉGYPTIEN-13C50","	* logogramme (dieu) : nṯr"},
/* 13C51 */ { "HIÉROGLYPHE ÉGYPTIEN-13C51","	* logogramme (inonder) : bꜥḥ"},
/* 13C52 */ { "HIÉROGLYPHE ÉGYPTIEN-13C52","	* logogramme (âme) : bꜣ"},
/* 13C53 */ { "HIÉROGLYPHE ÉGYPTIEN-13C53",NULL},
/* 13C54 */ { "HIÉROGLYPHE ÉGYPTIEN-13C54","	* logogramme (inonder) : bꜥḥ"},
/* 13C55 */ { "HIÉROGLYPHE ÉGYPTIEN-13C55","	* logogramme (inonder) : bꜥḥ"},
/* 13C56 */ { "HIÉROGLYPHE ÉGYPTIEN-13C56","	* logogramme (inondation) : bꜥḥ"},
/* 13C57 */ { "HIÉROGLYPHE ÉGYPTIEN-13C57","	* logogramme (dieu) : nṯr"},
/* 13C58 */ { "HIÉROGLYPHE ÉGYPTIEN-13C58","	* phonémogramme : b"},
/* 13C59 */ { "HIÉROGLYPHE ÉGYPTIEN-13C59","	* classificateur héron : bnw"},
/* 13C5A */ { "HIÉROGLYPHE ÉGYPTIEN-13C5A","	* phonémogramme : tꜣ"},
/* 13C5B */ { "HIÉROGLYPHE ÉGYPTIEN-13C5B","	* phonémogramme : ꜣḫw"},
/* 13C5C */ { "HIÉROGLYPHE ÉGYPTIEN-13C5C","	* logogramme (dieu) : nṯr"},
/* 13C5D */ { "HIÉROGLYPHE ÉGYPTIEN-13C5D","	* logogramme (Thot) : ḏḥwty"},
/* 13C5E */ { "HIÉROGLYPHE ÉGYPTIEN-13C5E","	* logogramme (être excellent) : ꞽḳr"},
/* 13C5F */ { "HIÉROGLYPHE ÉGYPTIEN-13C5F","	* logogramme (Thot) : ḏḥwty"},
/* 13C60 */ { "HIÉROGLYPHE ÉGYPTIEN-13C60","	* logogramme (dieu) : nṯr"},
/* 13C61 */ { "HIÉROGLYPHE ÉGYPTIEN-13C61",NULL},
/* 13C62 */ { "HIÉROGLYPHE ÉGYPTIEN-13C62","	* logogramme (Thot) : ḏḥwty"},
/* 13C63 */ { "HIÉROGLYPHE ÉGYPTIEN-13C63","	* logogramme (Thot) : ḏḥwty"},
/* 13C64 */ { "HIÉROGLYPHE ÉGYPTIEN-13C64","	* logogramme (dieu) : nṯr"},
/* 13C65 */ { "HIÉROGLYPHE ÉGYPTIEN-13C65","	* logogramme (Thot) : ḏḥwty"},
/* 13C66 */ { "HIÉROGLYPHE ÉGYPTIEN-13C66","	* phonémogramme : ṯꜣ"},
/* 13C67 */ { "HIÉROGLYPHE ÉGYPTIEN-13C67","	* logogramme (dieu) : nṯr"},
/* 13C68 */ { "HIÉROGLYPHE ÉGYPTIEN-13C68","	* logogramme (dieu) : nṯr"},
/* 13C69 */ { "HIÉROGLYPHE ÉGYPTIEN-13C69","	* classificateur Thot : nb ḫmnw"},
/* 13C6A */ { "HIÉROGLYPHE ÉGYPTIEN-13C6A","	* logogramme (dieu) : nṯr"},
/* 13C6B */ { "HIÉROGLYPHE ÉGYPTIEN-13C6B",NULL},
/* 13C6C */ { "HIÉROGLYPHE ÉGYPTIEN-13C6C","	* logogramme (Horus) : ḥr"},
/* 13C6D */ { "HIÉROGLYPHE ÉGYPTIEN-13C6D","	* logogramme (Rê-Hor (généralement dans rꜥ-ḥr-ꜣḫ.ty)) : rꜥ-ḥr"},
/* 13C6E */ { "HIÉROGLYPHE ÉGYPTIEN-13C6E","	* logogramme (Rê-Hor (généralement dans rꜥ-ḥr-ꜣḫ.ty)) : rꜥ-ḥr"},
/* 13C6F */ { "HIÉROGLYPHE ÉGYPTIEN-13C6F","	* logogramme (Rê-Hor (généralement dans rꜥ-ḥr-ꜣḫ.ty)) : rꜥ-ḥr"},
/* 13C70 */ { "HIÉROGLYPHE ÉGYPTIEN-13C70","	* logogramme (Horus) : ḥr"},
/* 13C71 */ { "HIÉROGLYPHE ÉGYPTIEN-13C71","	* logogramme (Horus) : ḥr"},
/* 13C72 */ { "HIÉROGLYPHE ÉGYPTIEN-13C72","	* logogramme (Horus) : ḥr"},
/* 13C73 */ { "HIÉROGLYPHE ÉGYPTIEN-13C73","	* classificateur roi : n(.y)-sw.t"},
/* 13C74 */ { "HIÉROGLYPHE ÉGYPTIEN-13C74","	* phonémogramme : pn"},
/* 13C75 */ { "HIÉROGLYPHE ÉGYPTIEN-13C75","	* phonémogramme : pn"},
/* 13C76 */ { "HIÉROGLYPHE ÉGYPTIEN-13C76","	* classificateur divinité : ꞽmt.t"},
/* 13C77 */ { "HIÉROGLYPHE ÉGYPTIEN-13C77","	* logogramme (Sopdou (divinité)) : spd.w"},
/* 13C78 */ { "HIÉROGLYPHE ÉGYPTIEN-13C78","	* logogramme (la femme Horus) : ḥr.t"},
/* 13C79 */ { "HIÉROGLYPHE ÉGYPTIEN-13C79","	* logogramme (Horus) : ḥr"},
/* 13C7A */ { "HIÉROGLYPHE ÉGYPTIEN-13C7A","	* logogramme (la femelle faucon) : bꞽk.t"},
/* 13C7B */ { "HIÉROGLYPHE ÉGYPTIEN-13C7B","	* logogramme (déesse) : nṯr.t"},
/* 13C7C */ { "HIÉROGLYPHE ÉGYPTIEN-13C7C","	* logogramme (dieu) : nṯr"},
/* 13C7D */ { "HIÉROGLYPHE ÉGYPTIEN-13C7D","	* logogramme (lin (rouge) de haute qualité) : ꞽdmꞽ"},
/* 13C7E */ { "HIÉROGLYPHE ÉGYPTIEN-13C7E",NULL},
/* 13C7F */ { "HIÉROGLYPHE ÉGYPTIEN-13C7F","	* logogramme (ouest) : ꞽmn.t"},
/* 13C80 */ { "HIÉROGLYPHE ÉGYPTIEN-13C80","	* logogramme (nome de l'Occident, 3e nome de Basse-Égypte) : ꞽmn.tt"},
/* 13C81 */ { "HIÉROGLYPHE ÉGYPTIEN-13C81","	* logogramme (lin (rouge) de haute qualité) : ꞽdmꞽ"},
/* 13C82 */ { "HIÉROGLYPHE ÉGYPTIEN-13C82","	* classificateur êtres divins, choses divines"},
/* 13C83 */ { "HIÉROGLYPHE ÉGYPTIEN-13C83","	* logogramme (déesse) : nṯr.t"},
/* 13C84 */ { "HIÉROGLYPHE ÉGYPTIEN-13C84","	* logogramme (déesse) : nṯr.t"},
/* 13C85 */ { "HIÉROGLYPHE ÉGYPTIEN-13C85","	* classificateur divinité (Min) : mnw"},
/* 13C86 */ { "HIÉROGLYPHE ÉGYPTIEN-13C86","	* logogramme (qu'il vive, le dieu) : ꜥnḫ-nṯr"},
/* 13C87 */ { "HIÉROGLYPHE ÉGYPTIEN-13C87","	* logogramme (majesté) : ḥm"},
/* 13C88 */ { "HIÉROGLYPHE ÉGYPTIEN-13C88","	* logogramme (majesté) : ḥm"},
/* 13C89 */ { "HIÉROGLYPHE ÉGYPTIEN-13C89",NULL},
/* 13C8A */ { "HIÉROGLYPHE ÉGYPTIEN-13C8A","	* logogramme (Harsomtous) : ḥr-smꜣ-tꜣ.wy"},
/* 13C8B */ { "HIÉROGLYPHE ÉGYPTIEN-13C8B","	* logogramme (Harsomtous) : ḥr-smꜣ-tꜣ.wy"},
/* 13C8C */ { "HIÉROGLYPHE ÉGYPTIEN-13C8C","	* logogramme (nome des Deux Divinités, 5e nome de Haute-Égypte) : nṯr.wy"},
/* 13C8D */ { "HIÉROGLYPHE ÉGYPTIEN-13C8D","	* logogramme (Trône d'Horus) : wṯs-ḥr"},
/* 13C8E */ { "HIÉROGLYPHE ÉGYPTIEN-13C8E","	* logogramme (Trône d'Horus) : wṯs-ḥr"},
/* 13C8F */ { "HIÉROGLYPHE ÉGYPTIEN-13C8F","	* logogramme (Trône d'Horus) : wṯs-ḥr"},
/* 13C90 */ { "HIÉROGLYPHE ÉGYPTIEN-13C90","	* logogramme (nome du Trône d'Horus, 2e nome de Haute-Égypte) : wṯs-ḥr"},
/* 13C91 */ { "HIÉROGLYPHE ÉGYPTIEN-13C91","	* logogramme (Horus qui est sur la façade du palais) : ḥr-ḥr.y-srḫ"},
/* 13C92 */ { "HIÉROGLYPHE ÉGYPTIEN-13C92","	* logogramme/phonémogramme (Horus, qui perdure sur la façade du palais) : ḥr mn (ḥr) srḫ"},
/* 13C93 */ { "HIÉROGLYPHE ÉGYPTIEN-13C93","	* classificateur celui qui est sur la façade du palais : ḥr.y-srḫ"},
/* 13C94 */ { "HIÉROGLYPHE ÉGYPTIEN-13C94","	* logogramme (le faucon vivant qui est sur la façade du palais) : bꞽk ꜥnḫ ḥr.y srḫ"},
/* 13C95 */ { "HIÉROGLYPHE ÉGYPTIEN-13C95","	* logogramme (trône, façade du palais) : srḫ"},
/* 13C96 */ { "HIÉROGLYPHE ÉGYPTIEN-13C96","	* logogramme (ouest, côté droit) : ꞽmn.t"},
/* 13C97 */ { "HIÉROGLYPHE ÉGYPTIEN-13C97","	* logogramme (ouest, côté droit) : ꞽmn.t"},
/* 13C98 */ { "HIÉROGLYPHE ÉGYPTIEN-13C98","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 13C99 */ { "HIÉROGLYPHE ÉGYPTIEN-13C99","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 13C9A */ { "HIÉROGLYPHE ÉGYPTIEN-13C9A",NULL},
/* 13C9B */ { "HIÉROGLYPHE ÉGYPTIEN-13C9B","	* logogramme (Nemty (divinité)) : nmty"},
/* 13C9C */ { "HIÉROGLYPHE ÉGYPTIEN-13C9C","	* logogramme (Nemty (divinité)) : nmty"},
/* 13C9D */ { "HIÉROGLYPHE ÉGYPTIEN-13C9D","	* logogramme (seigneur) : nb"},
/* 13C9E */ { "HIÉROGLYPHE ÉGYPTIEN-13C9E","	* logogramme (seigneur) : nb"},
/* 13C9F */ { "HIÉROGLYPHE ÉGYPTIEN-13C9F","	* logogramme (seigneur) : nb"},
/* 13CA0 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA0","	* classificateur Sokar : skr"},
/* 13CA1 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA1","	* phonémogramme : p & nst"},
/* 13CA2 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA2","	* logogramme : ẖr.t-nṯr"},
/* 13CA3 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA3","	* logogramme (sanctuaire de Sokar) : šṯy.t"},
/* 13CA4 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA4","	* logogramme (seigneur) : nb"},
/* 13CA5 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA5","	* logogramme (dans bꞽk-n-nbw.t, faucon des dorés) : bꞽk & nbw"},
/* 13CA6 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA6","	* logogramme (Horus doré) : ḥr-nbw"},
/* 13CA7 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA7","	* logogramme (Nemty (divinité)) : nmty"},
/* 13CA8 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA8",NULL},
/* 13CA9 */ { "HIÉROGLYPHE ÉGYPTIEN-13CA9",NULL},
/* 13CAA */ { "HIÉROGLYPHE ÉGYPTIEN-13CAA","	* classificateur lin (rouge) de haute qualité : (ꞽ)dmꞽ"},
/* 13CAB */ { "HIÉROGLYPHE ÉGYPTIEN-13CAB","	* logogramme (lin (rouge) de haute qualité) : ꞽdmꞽ"},
/* 13CAC */ { "HIÉROGLYPHE ÉGYPTIEN-13CAC","	* logogramme (lin (rouge) de haute qualité) : ꞽdmꞽ"},
/* 13CAD */ { "HIÉROGLYPHE ÉGYPTIEN-13CAD","	* logogramme (celui qui déploie ses ailes (divinité (Dewen-anwy))) : dwn-ꜥn.wy"},
/* 13CAE */ { "HIÉROGLYPHE ÉGYPTIEN-13CAE",NULL},
/* 13CAF */ { "HIÉROGLYPHE ÉGYPTIEN-13CAF","	* phonémogramme : ṯꜣ"},
/* 13CB0 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB0","	* phonémogramme et classificateur trône (dans ṯnṯꜣ.t) : ṯꜣ"},
/* 13CB1 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB1",NULL},
/* 13CB2 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB2","	* logogramme (au plumage multicolore) : sꜣb-šw.t"},
/* 13CB3 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB3","	* logogramme (au plumage multicolore) : sꜣb-šw.t"},
/* 13CB4 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB4","	* logogramme (au plumage multicolore) : sꜣb-šw.t"},
/* 13CB5 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB5","	* logogramme (au plumage multicolore) : sꜣb-šw.t"},
/* 13CB6 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB6","	* logogramme (au plumage multicolore, qui surgit de l'horizon) : sꜣb-šw.t-pr-m-ꜣḫ.t"},
/* 13CB7 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB7","	* logogramme (au plumage multicolore, qui surgit de l'horizon) : sꜣb-šw.t-pr-m-ꜣḫ.t"},
/* 13CB8 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB8","	* logogramme (au plumage multicolore, qui surgit de l'horizon) : sꜣb-šw.t-pr-m-ꜣḫ.t"},
/* 13CB9 */ { "HIÉROGLYPHE ÉGYPTIEN-13CB9",NULL},
/* 13CBA */ { "HIÉROGLYPHE ÉGYPTIEN-13CBA","	* logogramme (protéger) : ḫwꞽ"},
/* 13CBB */ { "HIÉROGLYPHE ÉGYPTIEN-13CBB",NULL},
/* 13CBC */ { "HIÉROGLYPHE ÉGYPTIEN-13CBC","	* logogramme (celui qui déploie ses ailes (divinité (Dewen-anwy))) : dwn-ꜥn.wy"},
/* 13CBD */ { "HIÉROGLYPHE ÉGYPTIEN-13CBD",NULL},
/* 13CBE */ { "HIÉROGLYPHE ÉGYPTIEN-13CBE","	* logogramme (protéger) : mkꞽ/ḫwꞽ"},
/* 13CBF */ { "HIÉROGLYPHE ÉGYPTIEN-13CBF","	* classificateur faucon : b(ꞽ)k.t"},
/* 13CC0 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC0","	* classificateur faucon, oiseau de proie : gmḥs"},
/* 13CC1 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC1","	* logogramme (dieu) : nṯr"},
/* 13CC2 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC2","	* logogramme (dieu) : nṯr"},
/* 13CC3 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC3","	* logogramme (Horus) : ḥr"},
/* 13CC4 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC4","	* classificateur image de culte : ꜥẖm"},
/* 13CC5 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC5","	* logogramme (Horus) : ḥr"},
/* 13CC6 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC6","	* logogramme (Haroëris) : ḥr-wr"},
/* 13CC7 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC7","	* logogramme (Haroëris) : ḥr-wr"},
/* 13CC8 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC8","	* logogramme (Haroëris) : ḥr-wr"},
/* 13CC9 */ { "HIÉROGLYPHE ÉGYPTIEN-13CC9","	* logogramme (Sopdou (divinité)) : spd.w"},
/* 13CCA */ { "HIÉROGLYPHE ÉGYPTIEN-13CCA","	* classificateur image de culte : ꜥẖm"},
/* 13CCB */ { "HIÉROGLYPHE ÉGYPTIEN-13CCB",NULL},
/* 13CCC */ { "HIÉROGLYPHE ÉGYPTIEN-13CCC","	* logogramme : sḏr"},
/* 13CCD */ { "HIÉROGLYPHE ÉGYPTIEN-13CCD",NULL},
/* 13CCE */ { "HIÉROGLYPHE ÉGYPTIEN-13CCE",NULL},
/* 13CCF */ { "HIÉROGLYPHE ÉGYPTIEN-13CCF","	* classificateur un type d'oiseau ou classificateur Dédoun (divinité) : bn | ddwn"},
/* 13CD0 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD0","	* phonémogramme : wr"},
/* 13CD1 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD1","	* classificateur négatif, mauvais : ꞽw.ty"},
/* 13CD2 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD2",NULL},
/* 13CD3 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD3","	* phonémogramme : ḏb"},
/* 13CD4 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD4","	* logogramme (brique, plaque, lingot) : ḏb.t"},
/* 13CD5 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD5","	* logogramme (âme) : bꜣ"},
/* 13CD6 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD6","	* logogramme (âme) : bꜣ"},
/* 13CD7 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD7",NULL},
/* 13CD8 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD8",NULL},
/* 13CD9 */ { "HIÉROGLYPHE ÉGYPTIEN-13CD9","	* phonémogramme : b"},
/* 13CDA */ { "HIÉROGLYPHE ÉGYPTIEN-13CDA","	* logogramme (Celui d'Edfou) : bḥd.ty"},
/* 13CDB */ { "HIÉROGLYPHE ÉGYPTIEN-13CDB",NULL},
/* 13CDC */ { "HIÉROGLYPHE ÉGYPTIEN-13CDC","	* logogramme (la femelle faucon) : bꞽk.t"},
/* 13CDD */ { "HIÉROGLYPHE ÉGYPTIEN-13CDD","	* logogramme (déesse) : nṯr.t"},
/* 13CDE */ { "HIÉROGLYPHE ÉGYPTIEN-13CDE","	* logogramme (âme) : bꜣ"},
/* 13CDF */ { "HIÉROGLYPHE ÉGYPTIEN-13CDF",NULL},
/* 13CE0 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE0","	* classificateur descendant : ḫr(.y)"},
/* 13CE1 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE1","	* phonémogramme : ṯꜣ"},
/* 13CE2 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE2","	* logogramme (gibier d'eau) : rꜣ"},
/* 13CE3 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE3","	* classificateur nid : sš"},
/* 13CE4 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE4",NULL},
/* 13CE5 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE5","	* classificateur nid : sš"},
/* 13CE6 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE6","	* phonémogramme : rḫt"},
/* 13CE7 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE7","	* phonémogramme : rḫt"},
/* 13CE8 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE8",NULL},
/* 13CE9 */ { "HIÉROGLYPHE ÉGYPTIEN-13CE9","	* phonémogramme : mḥ"},
/* 13CEA */ { "HIÉROGLYPHE ÉGYPTIEN-13CEA","	* phonémogramme : mḥ"},
/* 13CEB */ { "HIÉROGLYPHE ÉGYPTIEN-13CEB","	* logogramme (nid) : sš"},
/* 13CEC */ { "HIÉROGLYPHE ÉGYPTIEN-13CEC","	* phonémogramme : mḥ"},
/* 13CED */ { "HIÉROGLYPHE ÉGYPTIEN-13CED","	* logogramme (mare, nid) : sš"},
/* 13CEE */ { "HIÉROGLYPHE ÉGYPTIEN-13CEE","	* logogramme (nid) : sš"},
/* 13CEF */ { "HIÉROGLYPHE ÉGYPTIEN-13CEF","	* logogramme (mare, nid, marais) : sš"},
/* 13CF0 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF0","	* classificateur pélican : ḥn.t"},
/* 13CF1 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF1","	* phonémogramme : nḥ"},
/* 13CF2 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF2","	* phonémogramme : nḥ"},
/* 13CF3 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF3","	* phonémogramme : nḥ"},
/* 13CF4 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF4","	* phonémogramme : nḥ"},
/* 13CF5 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF5","	* phonémogramme : ty"},
/* 13CF6 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF6","	* phonémogramme : ty"},
/* 13CF7 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF7","	* logogramme (le peuple, les sujets, les gens) : rḫ.yt"},
/* 13CF8 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF8","	* logogramme (le peuple, les sujets, les gens) : rḫ.yt"},
/* 13CF9 */ { "HIÉROGLYPHE ÉGYPTIEN-13CF9","	* phonémogramme/logogramme (que tout le monde connaît) : rḫ.t-ḥr-nb"},
/* 13CFA */ { "HIÉROGLYPHE ÉGYPTIEN-13CFA","	* logogramme (le peuple, les sujets, les gens) : rḫ.yt"},
/* 13CFB */ { "HIÉROGLYPHE ÉGYPTIEN-13CFB","	* logogramme (le peuple, les sujets, les gens) : rḫ.yt"},
/* 13CFC */ { "HIÉROGLYPHE ÉGYPTIEN-13CFC","	* phonémogramme : tyw"},
/* 13CFD */ { "HIÉROGLYPHE ÉGYPTIEN-13CFD",NULL},
/* 13CFE */ { "HIÉROGLYPHE ÉGYPTIEN-13CFE","	* phonémogramme : ty"},
/* 13CFF */ { "HIÉROGLYPHE ÉGYPTIEN-13CFF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_3D[] = {
/* 13D00 */ { "HIÉROGLYPHE ÉGYPTIEN-13D00","	* phonémogramme : nt"},
/* 13D01 */ { "HIÉROGLYPHE ÉGYPTIEN-13D01",NULL},
/* 13D02 */ { "HIÉROGLYPHE ÉGYPTIEN-13D02","	* logogramme (déesse) : nṯr.t"},
/* 13D03 */ { "HIÉROGLYPHE ÉGYPTIEN-13D03","	* logogramme (Nekhbet (divinité)) : nḫb.t"},
/* 13D04 */ { "HIÉROGLYPHE ÉGYPTIEN-13D04","	* classificateur divinité (Nekhbet) : nḫb.t"},
/* 13D05 */ { "HIÉROGLYPHE ÉGYPTIEN-13D05","	* logogramme (Mout (divinité)) : mw.t"},
/* 13D06 */ { "HIÉROGLYPHE ÉGYPTIEN-13D06","	* classificateur uræus : wr.t"},
/* 13D07 */ { "HIÉROGLYPHE ÉGYPTIEN-13D07","	* logogramme (dame (dans nb.ty)) : nb.t"},
/* 13D08 */ { "HIÉROGLYPHE ÉGYPTIEN-13D08","	* logogramme (fête du nouvel an) : wp-rnp.t"},
/* 13D09 */ { "HIÉROGLYPHE ÉGYPTIEN-13D09","	* logogramme/phonémogramme (protéger) : mkꞽ"},
/* 13D0A */ { "HIÉROGLYPHE ÉGYPTIEN-13D0A","	* logogramme/phonémogramme (protéger) : mkꞽ"},
/* 13D0B */ { "HIÉROGLYPHE ÉGYPTIEN-13D0B","	* logogramme/phonémogramme (protéger) : mkꞽ"},
/* 13D0C */ { "HIÉROGLYPHE ÉGYPTIEN-13D0C",NULL},
/* 13D0D */ { "HIÉROGLYPHE ÉGYPTIEN-13D0D",NULL},
/* 13D0E */ { "HIÉROGLYPHE ÉGYPTIEN-13D0E","	* phonémogramme : ꜣ"},
/* 13D0F */ { "HIÉROGLYPHE ÉGYPTIEN-13D0F","	* logogramme (mère du dieu, dame de) : mw.t-nṯr-nb"},
/* 13D10 */ { "HIÉROGLYPHE ÉGYPTIEN-13D10","	* logogramme (bâton) : mdw"},
/* 13D11 */ { "HIÉROGLYPHE ÉGYPTIEN-13D11","	* classificateur bâton : mdw"},
/* 13D12 */ { "HIÉROGLYPHE ÉGYPTIEN-13D12","	* classificateur bâton"},
/* 13D13 */ { "HIÉROGLYPHE ÉGYPTIEN-13D13","	* classificateur bâton : mdw"},
/* 13D14 */ { "HIÉROGLYPHE ÉGYPTIEN-13D14","	* phonémogramme : mdw"},
/* 13D15 */ { "HIÉROGLYPHE ÉGYPTIEN-13D15","	* logogramme (bâton) : mdw"},
/* 13D16 */ { "HIÉROGLYPHE ÉGYPTIEN-13D16","	* phonémogramme/logogramme (fin) : nfr.(y)t"},
/* 13D17 */ { "HIÉROGLYPHE ÉGYPTIEN-13D17","	* logogramme (voir) : mꜣꜣ"},
/* 13D18 */ { "HIÉROGLYPHE ÉGYPTIEN-13D18","	* phono-répéteur : ꞽmꜣḫ"},
/* 13D19 */ { "HIÉROGLYPHE ÉGYPTIEN-13D19","	* logogramme (parler, dire) : ḏd"},
/* 13D1A */ { "HIÉROGLYPHE ÉGYPTIEN-13D1A","	* classificateur grue cendrée : ḏꜣ(.t)"},
/* 13D1B */ { "HIÉROGLYPHE ÉGYPTIEN-13D1B","	* logogramme (parler, dire) : ḏd"},
/* 13D1C */ { "HIÉROGLYPHE ÉGYPTIEN-13D1C","	* phonémogramme : pg"},
/* 13D1D */ { "HIÉROGLYPHE ÉGYPTIEN-13D1D","	* phonémogramme : ꜣḫ"},
/* 13D1E */ { "HIÉROGLYPHE ÉGYPTIEN-13D1E","	* phonémogramme/logogramme (esprits) : ꜣḫ"},
/* 13D1F */ { "HIÉROGLYPHE ÉGYPTIEN-13D1F","	* phono-répéteur : nr"},
/* 13D20 */ { "HIÉROGLYPHE ÉGYPTIEN-13D20",NULL},
/* 13D21 */ { "HIÉROGLYPHE ÉGYPTIEN-13D21",NULL},
/* 13D22 */ { "HIÉROGLYPHE ÉGYPTIEN-13D22",NULL},
/* 13D23 */ { "HIÉROGLYPHE ÉGYPTIEN-13D23","	* phonémogramme : šps"},
/* 13D24 */ { "HIÉROGLYPHE ÉGYPTIEN-13D24","	* phonémogramme : tꜣš"},
/* 13D25 */ { "HIÉROGLYPHE ÉGYPTIEN-13D25","	* classificateur plume double : šw.ty"},
/* 13D26 */ { "HIÉROGLYPHE ÉGYPTIEN-13D26","	* phonémogramme : r"},
/* 13D27 */ { "HIÉROGLYPHE ÉGYPTIEN-13D27",NULL},
/* 13D28 */ { "HIÉROGLYPHE ÉGYPTIEN-13D28","	* logogramme (griffe, serre) : ꜥn.t"},
/* 13D29 */ { "HIÉROGLYPHE ÉGYPTIEN-13D29","	* logogramme (celui qui est dans un œuf) : ꞽm.yw-swḥ.t"},
/* 13D2A */ { "HIÉROGLYPHE ÉGYPTIEN-13D2A","	* logogramme (Douaou (divinité)) : dwꜣw"},
/* 13D2B */ { "HIÉROGLYPHE ÉGYPTIEN-13D2B","	* phonémogramme : m"},
/* 13D2C */ { "HIÉROGLYPHE ÉGYPTIEN-13D2C","	* phonémogramme : w"},
/* 13D2D */ { "HIÉROGLYPHE ÉGYPTIEN-13D2D","	* phonémogramme : ꜣ"},
/* 13D2E */ { "HIÉROGLYPHE ÉGYPTIEN-13D2E","	* phonémogramme : gb"},
/* 13D2F */ { "HIÉROGLYPHE ÉGYPTIEN-13D2F","	* logogramme (Nehebkaou (divinité)) : nḥb-kꜣ.w"},
/* 13D30 */ { "HIÉROGLYPHE ÉGYPTIEN-13D30","	* classificateur stellion : ḏnf"},
/* 13D31 */ { "HIÉROGLYPHE ÉGYPTIEN-13D31","	* classificateur maléfique : ḏwḏw"},
/* 13D32 */ { "HIÉROGLYPHE ÉGYPTIEN-13D32","	* classificateur Noun : nꞽw"},
/* 13D33 */ { "HIÉROGLYPHE ÉGYPTIEN-13D33","	* logogramme (Sobek (divinité)) : sbk"},
/* 13D34 */ { "HIÉROGLYPHE ÉGYPTIEN-13D34","	* logogramme (nome du Crocodile, 6e nome de Haute-Égypte) : ꞽḳr"},
/* 13D35 */ { "HIÉROGLYPHE ÉGYPTIEN-13D35","	* classificateur divinité (Sobek) : sbk"},
/* 13D36 */ { "HIÉROGLYPHE ÉGYPTIEN-13D36","	* logogramme (nome du Crocodile, 6e nome de Haute-Égypte) : ꞽḳr"},
/* 13D37 */ { "HIÉROGLYPHE ÉGYPTIEN-13D37","	* logogramme (Médinet Habou) : ṯꜣm.t"},
/* 13D38 */ { "HIÉROGLYPHE ÉGYPTIEN-13D38","	* logogramme (nome du Crocodile, 6e nome de Haute-Égypte) : ꞽḳr"},
/* 13D39 */ { "HIÉROGLYPHE ÉGYPTIEN-13D39","	* classificateur animal aquatique : ꞽm.yw-mw"},
/* 13D3A */ { "HIÉROGLYPHE ÉGYPTIEN-13D3A","	* classificateur ennemi sous forme de crocodile : ḫꜥw"},
/* 13D3B */ { "HIÉROGLYPHE ÉGYPTIEN-13D3B","	* logogramme (crocodile) : ꜥfꜥ"},
/* 13D3C */ { "HIÉROGLYPHE ÉGYPTIEN-13D3C","	* classificateur ennemi sous forme de crocodile : ḥnt.y"},
/* 13D3D */ { "HIÉROGLYPHE ÉGYPTIEN-13D3D","	* classificateur ennemi sous forme de crocodile : mg(ꜣ)"},
/* 13D3E */ { "HIÉROGLYPHE ÉGYPTIEN-13D3E","	* classificateur crocodile : ḥnt.y"},
/* 13D3F */ { "HIÉROGLYPHE ÉGYPTIEN-13D3F","	* logogramme (crocodile) : mg(ꜣ)"},
/* 13D40 */ { "HIÉROGLYPHE ÉGYPTIEN-13D40","	* logogramme (Sobek (divinité)) : sbk"},
/* 13D41 */ { "HIÉROGLYPHE ÉGYPTIEN-13D41","	* logogramme (rassembler) : sꜣḳ"},
/* 13D42 */ { "HIÉROGLYPHE ÉGYPTIEN-13D42","	* logogramme (Sobek (divinité)) : sbk"},
/* 13D43 */ { "HIÉROGLYPHE ÉGYPTIEN-13D43","	* logogramme (Sobek-Rê (divinité)) : sbk-rꜥ"},
/* 13D44 */ { "HIÉROGLYPHE ÉGYPTIEN-13D44","	* logogramme (souverain) : ꞽty"},
/* 13D45 */ { "HIÉROGLYPHE ÉGYPTIEN-13D45","	* logogramme (Sobek (divinité)) : sbk"},
/* 13D46 */ { "HIÉROGLYPHE ÉGYPTIEN-13D46","	* phonémogramme : f"},
/* 13D47 */ { "HIÉROGLYPHE ÉGYPTIEN-13D47","	* ?"},
/* 13D48 */ { "HIÉROGLYPHE ÉGYPTIEN-13D48","	* logogramme (Sobek-Rê (divinité)) : sbk-rꜥ"},
/* 13D49 */ { "HIÉROGLYPHE ÉGYPTIEN-13D49","	* classificateur les deux crocodiles : sbk.wy"},
/* 13D4A */ { "HIÉROGLYPHE ÉGYPTIEN-13D4A","	* logogramme (moment de l'attaque) : ꜣ.t"},
/* 13D4B */ { "HIÉROGLYPHE ÉGYPTIEN-13D4B","	* logogramme (Égypte) : km.t"},
/* 13D4C */ { "HIÉROGLYPHE ÉGYPTIEN-13D4C","	* phonémogramme : km"},
/* 13D4D */ { "HIÉROGLYPHE ÉGYPTIEN-13D4D","	* phonémogramme : km"},
/* 13D4E */ { "HIÉROGLYPHE ÉGYPTIEN-13D4E","	* phonémogramme : km"},
/* 13D4F */ { "HIÉROGLYPHE ÉGYPTIEN-13D4F",NULL},
/* 13D50 */ { "HIÉROGLYPHE ÉGYPTIEN-13D50",NULL},
/* 13D51 */ { "HIÉROGLYPHE ÉGYPTIEN-13D51","	* logogramme (cent mille) : ḥfn"},
/* 13D52 */ { "HIÉROGLYPHE ÉGYPTIEN-13D52","	* logogramme (Héqet (divinité)) : ḥḳ.t"},
/* 13D53 */ { "HIÉROGLYPHE ÉGYPTIEN-13D53","	* logogramme (cent mille) : ḥfn"},
/* 13D54 */ { "HIÉROGLYPHE ÉGYPTIEN-13D54","	* classificateur serpent : ꜥḥꜥ"},
/* 13D55 */ { "HIÉROGLYPHE ÉGYPTIEN-13D55","	* logogramme (entrer) : ꜥḳ"},
/* 13D56 */ { "HIÉROGLYPHE ÉGYPTIEN-13D56","	* logogramme (entrer) : ꜥḳ"},
/* 13D57 */ { "HIÉROGLYPHE ÉGYPTIEN-13D57","	* logogramme (aller de l'avant) : prꞽ"},
/* 13D58 */ { "HIÉROGLYPHE ÉGYPTIEN-13D58","	* logogramme (aller de l'avant) : prꞽ"},
/* 13D59 */ { "HIÉROGLYPHE ÉGYPTIEN-13D59","	* classificateur serpent : ꜥḥꜥ"},
/* 13D5A */ { "HIÉROGLYPHE ÉGYPTIEN-13D5A","	* logogramme (durée de vie) : ꜥḥꜥ.w"},
/* 13D5B */ { "HIÉROGLYPHE ÉGYPTIEN-13D5B","	* phonémogramme : ꞽnḏ"},
/* 13D5C */ { "HIÉROGLYPHE ÉGYPTIEN-13D5C","	* phonémogramme : nf"},
/* 13D5D */ { "HIÉROGLYPHE ÉGYPTIEN-13D5D","	* phonémogramme : f"},
/* 13D5E */ { "HIÉROGLYPHE ÉGYPTIEN-13D5E","	* logogramme (père) : ꞽt"},
/* 13D5F */ { "HIÉROGLYPHE ÉGYPTIEN-13D5F","	* phonémogramme : py"},
/* 13D60 */ { "HIÉROGLYPHE ÉGYPTIEN-13D60",NULL},
/* 13D61 */ { "HIÉROGLYPHE ÉGYPTIEN-13D61","	* phonémogramme/logogramme (son nom) : rn=f"},
/* 13D62 */ { "HIÉROGLYPHE ÉGYPTIEN-13D62","	* logogramme (aller de l'avant) : prꞽ"},
/* 13D63 */ { "HIÉROGLYPHE ÉGYPTIEN-13D63","	* phonémogramme : ꞽnḏ"},
/* 13D64 */ { "HIÉROGLYPHE ÉGYPTIEN-13D64","	* logogramme (aller de l'avant) : prꞽ"},
/* 13D65 */ { "HIÉROGLYPHE ÉGYPTIEN-13D65","	* logogramme (divinité) : wr-ḥkꜣ.w"},
/* 13D66 */ { "HIÉROGLYPHE ÉGYPTIEN-13D66",NULL},
/* 13D67 */ { "HIÉROGLYPHE ÉGYPTIEN-13D67","	* phonémogramme/logogramme (éternité) : ḏ.t"},
/* 13D68 */ { "HIÉROGLYPHE ÉGYPTIEN-13D68","	* logogramme (éternité) : ḏ.t"},
/* 13D69 */ { "HIÉROGLYPHE ÉGYPTIEN-13D69","	* classificateur divinité : ḳbḥ.wt"},
/* 13D6A */ { "HIÉROGLYPHE ÉGYPTIEN-13D6A","	* logogramme/phonémogramme (frontière, falaise) : ṯn.w"},
/* 13D6B */ { "HIÉROGLYPHE ÉGYPTIEN-13D6B","	* logogramme (frontière, falaise) : ṯn.w"},
/* 13D6C */ { "HIÉROGLYPHE ÉGYPTIEN-13D6C","	* classificateur divinité : ḳbḥ.wt"},
/* 13D6D */ { "HIÉROGLYPHE ÉGYPTIEN-13D6D","	* logogramme (les deux chaînes montagneuses de la vallée du Nil) : ṯn.wy"},
/* 13D6E */ { "HIÉROGLYPHE ÉGYPTIEN-13D6E","	* logogramme (les deux chaînes montagneuses de la vallée du Nil) : ṯn.wy"},
/* 13D6F */ { "HIÉROGLYPHE ÉGYPTIEN-13D6F","	* logogramme (éternité) : ḏ.t"},
/* 13D70 */ { "HIÉROGLYPHE ÉGYPTIEN-13D70","	* phonémogramme : nt"},
/* 13D71 */ { "HIÉROGLYPHE ÉGYPTIEN-13D71","	* phonémogramme : mḏ"},
/* 13D72 */ { "HIÉROGLYPHE ÉGYPTIEN-13D72","	* phonémogramme (dans ḥḏ-tꜣ, aube, lever du jour) : ḥḏ"},
/* 13D73 */ { "HIÉROGLYPHE ÉGYPTIEN-13D73","	* logogramme (caverne) : ḳr.t"},
/* 13D74 */ { "HIÉROGLYPHE ÉGYPTIEN-13D74","	* logogramme (caverne) : ḳr.t"},
/* 13D75 */ { "HIÉROGLYPHE ÉGYPTIEN-13D75","	* logogramme (caverne) : ḳr.t"},
/* 13D76 */ { "HIÉROGLYPHE ÉGYPTIEN-13D76","	* logogramme (caverne) : ḳr.t"},
/* 13D77 */ { "HIÉROGLYPHE ÉGYPTIEN-13D77","	* logogramme (caverne) : ḳr.t"},
/* 13D78 */ { "HIÉROGLYPHE ÉGYPTIEN-13D78","	* logogramme (les deux cavités, les deux cavernes) : ḳr.ty"},
/* 13D79 */ { "HIÉROGLYPHE ÉGYPTIEN-13D79","	* classificateur divinité féminine"},
/* 13D7A */ { "HIÉROGLYPHE ÉGYPTIEN-13D7A","	* logogramme (dame (dans nb.ty)) : nb.t"},
/* 13D7B */ { "HIÉROGLYPHE ÉGYPTIEN-13D7B","	* logogramme (feu, flamme) : nsr.t"},
/* 13D7C */ { "HIÉROGLYPHE ÉGYPTIEN-13D7C","	* logogramme (feu, flamme) : nsr.t"},
/* 13D7D */ { "HIÉROGLYPHE ÉGYPTIEN-13D7D","	* classificateur les deux yeux oudjat : wḏꜣ.ty"},
/* 13D7E */ { "HIÉROGLYPHE ÉGYPTIEN-13D7E","	* logogramme (déesses) : nṯr.wt"},
/* 13D7F */ { "HIÉROGLYPHE ÉGYPTIEN-13D7F","	* classificateur Ennéade : psḏ.t"},
/* 13D80 */ { "HIÉROGLYPHE ÉGYPTIEN-13D80",NULL},
/* 13D81 */ { "HIÉROGLYPHE ÉGYPTIEN-13D81",NULL},
/* 13D82 */ { "HIÉROGLYPHE ÉGYPTIEN-13D82","	* logogramme (déesse) : nṯr.t"},
/* 13D83 */ { "HIÉROGLYPHE ÉGYPTIEN-13D83","	* logogramme (déesse) : nṯr.t"},
/* 13D84 */ { "HIÉROGLYPHE ÉGYPTIEN-13D84","	* logogramme (déesse) : nṯr.t"},
/* 13D85 */ { "HIÉROGLYPHE ÉGYPTIEN-13D85",NULL},
/* 13D86 */ { "HIÉROGLYPHE ÉGYPTIEN-13D86",NULL},
/* 13D87 */ { "HIÉROGLYPHE ÉGYPTIEN-13D87","	* logogramme (déesses) : nṯr.wt"},
/* 13D88 */ { "HIÉROGLYPHE ÉGYPTIEN-13D88","	* classificateur serpent uræus : wꜣḏ.t"},
/* 13D89 */ { "HIÉROGLYPHE ÉGYPTIEN-13D89","	* logogramme (dame (dans nb.ty)) : nb.t"},
/* 13D8A */ { "HIÉROGLYPHE ÉGYPTIEN-13D8A","	* phonémogramme : n"},
/* 13D8B */ { "HIÉROGLYPHE ÉGYPTIEN-13D8B","	* logogramme (dame (dans nb.ty)) : nb.t"},
/* 13D8C */ { "HIÉROGLYPHE ÉGYPTIEN-13D8C","	* classificateur les deux serpents uræus : wꜣḏ.ty"},
/* 13D8D */ { "HIÉROGLYPHE ÉGYPTIEN-13D8D","	* logogramme (Hathor) : ḥw.t-ḥr"},
/* 13D8E */ { "HIÉROGLYPHE ÉGYPTIEN-13D8E","	* logogramme (déesse) : nṯr.t"},
/* 13D8F */ { "HIÉROGLYPHE ÉGYPTIEN-13D8F","	* logogramme (Rénénoutet) : rnn.wtt"},
/* 13D90 */ { "HIÉROGLYPHE ÉGYPTIEN-13D90","	* phonémogramme/logogramme (encercler avec) : mḥn"},
/* 13D91 */ { "HIÉROGLYPHE ÉGYPTIEN-13D91","	* classificateur serpent, uræus : ꞽꜥr.ty"},
/* 13D92 */ { "HIÉROGLYPHE ÉGYPTIEN-13D92","	* logogramme (Ouadjet (divinité) : wꜣḏ.t"},
/* 13D93 */ { "HIÉROGLYPHE ÉGYPTIEN-13D93","	* logogramme (dame (dans nb.ty)) : nb.t"},
/* 13D94 */ { "HIÉROGLYPHE ÉGYPTIEN-13D94","	* classificateur uræus : wr.t"},
/* 13D95 */ { "HIÉROGLYPHE ÉGYPTIEN-13D95","	* logogramme (dame (dans nb.ty)) : nb.t"},
/* 13D96 */ { "HIÉROGLYPHE ÉGYPTIEN-13D96","	* logogramme (Rénénoutet) : rnn.wtt"},
/* 13D97 */ { "HIÉROGLYPHE ÉGYPTIEN-13D97","	* logogramme (uræus) : mḥn.t"},
/* 13D98 */ { "HIÉROGLYPHE ÉGYPTIEN-13D98","	* classificateur spirale (d'un serpent) : mḥn"},
/* 13D99 */ { "HIÉROGLYPHE ÉGYPTIEN-13D99","	* logogramme (uræus) : mḥn.t"},
/* 13D9A */ { "HIÉROGLYPHE ÉGYPTIEN-13D9A","	* logogramme (uræus) : mḥn.t"},
/* 13D9B */ { "HIÉROGLYPHE ÉGYPTIEN-13D9B","	* logogramme (uræus) : mḥn.t"},
/* 13D9C */ { "HIÉROGLYPHE ÉGYPTIEN-13D9C",NULL},
/* 13D9D */ { "HIÉROGLYPHE ÉGYPTIEN-13D9D","	* logogramme (uræus) : mḥn.t"},
/* 13D9E */ { "HIÉROGLYPHE ÉGYPTIEN-13D9E",NULL},
/* 13D9F */ { "HIÉROGLYPHE ÉGYPTIEN-13D9F",NULL},
/* 13DA0 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA0","	* logogramme (dame de Dendérah) : nb.t ꞽwn.t"},
/* 13DA1 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA1","	* logogramme (dame de Dendérah) : nb.t ꞽwn.t"},
/* 13DA2 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA2","	* phonémogramme/logogramme (ne pas savoir) : n rḫ"},
/* 13DA3 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA3","	* phonémogramme/logogramme (ne pas savoir) : n rḫ"},
/* 13DA4 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA4","	* phono-répétiteur : n rḫ"},
/* 13DA5 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA5","	* phonémogramme/logogramme (ne pas savoir) : n rḫ"},
/* 13DA6 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA6",NULL},
/* 13DA7 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA7","	* logogramme (Rénénoutet) : rnn.wtt"},
/* 13DA8 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA8","	* phonémogramme : (ꞽ)ḫr"},
/* 13DA9 */ { "HIÉROGLYPHE ÉGYPTIEN-13DA9","	* phonémogramme : n"},
/* 13DAA */ { "HIÉROGLYPHE ÉGYPTIEN-13DAA","	* logogramme (les deux cavernes) : ḳr.ty"},
/* 13DAB */ { "HIÉROGLYPHE ÉGYPTIEN-13DAB","	* classificateur serpent"},
/* 13DAC */ { "HIÉROGLYPHE ÉGYPTIEN-13DAC",NULL},
/* 13DAD */ { "HIÉROGLYPHE ÉGYPTIEN-13DAD","	* classificateur serpent"},
/* 13DAE */ { "HIÉROGLYPHE ÉGYPTIEN-13DAE","	* phonémogramme : f"},
/* 13DAF */ { "HIÉROGLYPHE ÉGYPTIEN-13DAF","	* classificateur serpent : nḥꜣ-ḥr"},
/* 13DB0 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB0",NULL},
/* 13DB1 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB1","	* phonémogramme : f"},
/* 13DB2 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB2","	* phonémogramme : f"},
/* 13DB3 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB3","	* phonémogramme et logogramme (âme) : n & bꜣ"},
/* 13DB4 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB4","	* classificateur serpent : ꜥꜣpp"},
/* 13DB5 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB5",NULL},
/* 13DB6 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB6","	* phonémogramme : ꜥ"},
/* 13DB7 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB7","	* logogramme (Chai (divinité)) : šꜣw"},
/* 13DB8 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB8","	* classificateur serpent : ḥfꜣw"},
/* 13DB9 */ { "HIÉROGLYPHE ÉGYPTIEN-13DB9","	* classificateur serpent : pẖr-ḥr"},
/* 13DBA */ { "HIÉROGLYPHE ÉGYPTIEN-13DBA",NULL},
/* 13DBB */ { "HIÉROGLYPHE ÉGYPTIEN-13DBB","	* classificateur serpent : ꜥꜣpp"},
/* 13DBC */ { "HIÉROGLYPHE ÉGYPTIEN-13DBC","	* classificateur serpent : ḥf(ꜣ).t"},
/* 13DBD */ { "HIÉROGLYPHE ÉGYPTIEN-13DBD","	* classificateur serpent, ennemi : bṯw"},
/* 13DBE */ { "HIÉROGLYPHE ÉGYPTIEN-13DBE","	* classificateur serpent/ennemi (Apophis) : ꜥꜣpp"},
/* 13DBF */ { "HIÉROGLYPHE ÉGYPTIEN-13DBF","	* classificateur serpent/ennemi (Apophis) : ꜥꜣpp"},
/* 13DC0 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC0","	* classificateur serpent : ḏw-ḳd"},
/* 13DC1 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC1","	* classificateur serpent/ennemi (Apophis) : ꜥꜣpp"},
/* 13DC2 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC2",NULL},
/* 13DC3 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC3","	* classificateur serpent/ennemi (Apophis) : ꜥ(ꜣ)pp"},
/* 13DC4 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC4","	* classificateur serpent, divinité : km-ꜣ.t=f"},
/* 13DC5 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC5",NULL},
/* 13DC6 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC6",NULL},
/* 13DC7 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC7",NULL},
/* 13DC8 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC8",NULL},
/* 13DC9 */ { "HIÉROGLYPHE ÉGYPTIEN-13DC9",NULL},
/* 13DCA */ { "HIÉROGLYPHE ÉGYPTIEN-13DCA","	* logogramme (le vent du nord) : mḥy.t"},
/* 13DCB */ { "HIÉROGLYPHE ÉGYPTIEN-13DCB","	* phonémogramme rr et classificateur lieu géographique : rr"},
/* 13DCC */ { "HIÉROGLYPHE ÉGYPTIEN-13DCC","	* logogramme (poisson) : rm"},
/* 13DCD */ { "HIÉROGLYPHE ÉGYPTIEN-13DCD","	* phonémogramme : ẖꜣ"},
/* 13DCE */ { "HIÉROGLYPHE ÉGYPTIEN-13DCE","	* logogramme (canal des Deux-Poissons, dans le 2e nome de Haute-Égypte) : ꜥꜣḏ.wy"},
/* 13DCF */ { "HIÉROGLYPHE ÉGYPTIEN-13DCF","	* phonémogramme : ꞽn"},
/* 13DD0 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD0","	* phonémogramme/logogramme (Shenes (lieu géographique)) : Šns"},
/* 13DD1 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD1","	* logogramme (Rê) : rꜥ"},
/* 13DD2 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD2","	* phonémogramme : rꜥ"},
/* 13DD3 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD3","	* phonémogramme : ẖꜣ"},
/* 13DD4 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD4","	* logogramme (nome du Dauphin, 16e nome de Basse-Égypte) : ḥꜣ.t-mḥ.yt"},
/* 13DD5 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD5","	* phonémogramme : ẖꜣ"},
/* 13DD6 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD6","	* logogramme/phonémogramme (déborder, émerger) : bsꞽ"},
/* 13DD7 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD7","	* logogramme/phonémogramme (déborder, émerger) : bsꞽ"},
/* 13DD8 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD8","	* logogramme/phonémogramme (déborder, émerger) : bsꞽ"},
/* 13DD9 */ { "HIÉROGLYPHE ÉGYPTIEN-13DD9","	* logogramme/phonémogramme (déborder, émerger) : bsꞽ"},
/* 13DDA */ { "HIÉROGLYPHE ÉGYPTIEN-13DDA","	* phonémogramme : s"},
/* 13DDB */ { "HIÉROGLYPHE ÉGYPTIEN-13DDB",NULL},
/* 13DDC */ { "HIÉROGLYPHE ÉGYPTIEN-13DDC","	* logogramme (colère, mécontentement) : špt"},
/* 13DDD */ { "HIÉROGLYPHE ÉGYPTIEN-13DDD","	* logogramme (être en colère) : špt"},
/* 13DDE */ { "HIÉROGLYPHE ÉGYPTIEN-13DDE",NULL},
/* 13DDF */ { "HIÉROGLYPHE ÉGYPTIEN-13DDF","	* logogramme (être en colère) : špt"},
/* 13DE0 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE0",NULL},
/* 13DE1 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE1","	* logogramme (devenir) : ḫpr"},
/* 13DE2 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE2","	* logogramme/phonémogramme (vie à) : ꜥnḫ-n"},
/* 13DE3 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE3","	* logogramme (illuminer) : sḥḏ"},
/* 13DE4 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE4","	* classificateur scarabée ailé : ꜥpy"},
/* 13DE5 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE5","	* logogramme (aller de l'avant) : prꞽ"},
/* 13DE6 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE6","	* logogramme (aller de l'avant) : prꞽ"},
/* 13DE7 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE7","	* logogramme (aller de l'avant) : prꞽ"},
/* 13DE8 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE8",NULL},
/* 13DE9 */ { "HIÉROGLYPHE ÉGYPTIEN-13DE9","	* logogramme (qui s'avance depuis l'horizon) : pr-m-ꜣḫ.t"},
/* 13DEA */ { "HIÉROGLYPHE ÉGYPTIEN-13DEA","	* logogramme (le scarabée ailé) : ꜥpy"},
/* 13DEB */ { "HIÉROGLYPHE ÉGYPTIEN-13DEB","	* logogramme (scarabée (amulette)) : ḫprr"},
/* 13DEC */ { "HIÉROGLYPHE ÉGYPTIEN-13DEC","	* phonémogramme : nt"},
/* 13DED */ { "HIÉROGLYPHE ÉGYPTIEN-13DED","	* logogramme (début) : ḥꜣ.t"},
/* 13DEE */ { "HIÉROGLYPHE ÉGYPTIEN-13DEE","	x (hiéroglyphe égyptien l003 - 131A6)\n"
	"	* classificateur mouche, insecte : ꜥff"},
/* 13DEF */ { "HIÉROGLYPHE ÉGYPTIEN-13DEF","	* classificateur guêpe : tkk.t"},
/* 13DF0 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF0","	* phonémogramme : r"},
/* 13DF1 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF1","	* logogramme (mante religieuse) : ḳd.t"},
/* 13DF2 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF2","	* classificateur scorpion : srḳ.t"},
/* 13DF3 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF3",NULL},
/* 13DF4 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF4","	* classificateur Serket/Selkis : srḳ.t"},
/* 13DF5 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF5","	* logogramme (Serket/Selkis (divinité)) : srḳ.t"},
/* 13DF6 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF6","	* logogramme (Serket/Selkis (divinité)) : srḳ.t"},
/* 13DF7 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF7","	* classificateur petit insecte : ꜥpšꜣy.t"},
/* 13DF8 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF8","	* classificateur ouvrir : sꜣš"},
/* 13DF9 */ { "HIÉROGLYPHE ÉGYPTIEN-13DF9","	* classificateur coléoptère : ꜥnḫ"},
/* 13DFA */ { "HIÉROGLYPHE ÉGYPTIEN-13DFA","	* phonémogramme : ꞽmꜣ"},
/* 13DFB */ { "HIÉROGLYPHE ÉGYPTIEN-13DFB","	* logogramme (sycomore) : nh.t"},
/* 13DFC */ { "HIÉROGLYPHE ÉGYPTIEN-13DFC",NULL},
/* 13DFD */ { "HIÉROGLYPHE ÉGYPTIEN-13DFD","	* logogramme (pluie (divinité)) : ḥw.t"},
/* 13DFE */ { "HIÉROGLYPHE ÉGYPTIEN-13DFE","	* logogramme (Neith, 4e et 5e nomes de Basse-Égypte) : n.t"},
/* 13DFF */ { "HIÉROGLYPHE ÉGYPTIEN-13DFF","	* logogramme (nome inférieur du Sycomore, 14e nome de Haute-Égypte) : nḏf.t-pḥ.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_3E[] = {
/* 13E00 */ { "HIÉROGLYPHE ÉGYPTIEN-13E00","	* logogramme (20e et 21e nomes de Haute-Égypte) : nꜥr.t"},
/* 13E01 */ { "HIÉROGLYPHE ÉGYPTIEN-13E01","	* logogramme (20e et 21e nomes de Haute-Égypte) : nꜥr.t"},
/* 13E02 */ { "HIÉROGLYPHE ÉGYPTIEN-13E02","	* logogramme (nome supérieur du Sycomore, 13e nome de Haute-Égypte) : nḏf.t-ḫnt.t"},
/* 13E03 */ { "HIÉROGLYPHE ÉGYPTIEN-13E03","	* classificateur bois de tamaris : ꞽsr.t"},
/* 13E04 */ { "HIÉROGLYPHE ÉGYPTIEN-13E04",NULL},
/* 13E05 */ { "HIÉROGLYPHE ÉGYPTIEN-13E05","	* phono-répéteur : bꜣḳ"},
/* 13E06 */ { "HIÉROGLYPHE ÉGYPTIEN-13E06","	* classificateur bois : mr.t"},
/* 13E07 */ { "HIÉROGLYPHE ÉGYPTIEN-13E07","	* classificateur bois : ꜥš"},
/* 13E08 */ { "HIÉROGLYPHE ÉGYPTIEN-13E08","	* classificateur bois précieux : s(s)ḏ(m)"},
/* 13E09 */ { "HIÉROGLYPHE ÉGYPTIEN-13E09","	* classificateur palmier doum : mꜣmꜣ"},
/* 13E0A */ { "HIÉROGLYPHE ÉGYPTIEN-13E0A","	* classificateur palmier doum : mꜣmꜣ"},
/* 13E0B */ { "HIÉROGLYPHE ÉGYPTIEN-13E0B","	* logogramme (le juste de voix (le mort bienheureux)) : mꜣꜥ-ḫrw"},
/* 13E0C */ { "HIÉROGLYPHE ÉGYPTIEN-13E0C",NULL},
/* 13E0D */ { "HIÉROGLYPHE ÉGYPTIEN-13E0D","	* logogramme (être justifié) : mꜣꜥ-ḫrw"},
/* 13E0E */ { "HIÉROGLYPHE ÉGYPTIEN-13E0E",NULL},
/* 13E0F */ { "HIÉROGLYPHE ÉGYPTIEN-13E0F","	* phono-répéteur : ḏꜥ"},
/* 13E10 */ { "HIÉROGLYPHE ÉGYPTIEN-13E10","	* phonémogramme : ḫr"},
/* 13E11 */ { "HIÉROGLYPHE ÉGYPTIEN-13E11","	* phonémogramme : ḫt"},
/* 13E12 */ { "HIÉROGLYPHE ÉGYPTIEN-13E12",NULL},
/* 13E13 */ { "HIÉROGLYPHE ÉGYPTIEN-13E13","	* phonémogramme : ḫt"},
/* 13E14 */ { "HIÉROGLYPHE ÉGYPTIEN-13E14","	* classificateur plante : twr"},
/* 13E15 */ { "HIÉROGLYPHE ÉGYPTIEN-13E15","	* classificateur huile : sfṯ/ḥꜣ.tt-ꜥš"},
/* 13E16 */ { "HIÉROGLYPHE ÉGYPTIEN-13E16","	* classificateur plante ? : ꞽw.t"},
/* 13E17 */ { "HIÉROGLYPHE ÉGYPTIEN-13E17","	* classificateur plante : twn"},
/* 13E18 */ { "HIÉROGLYPHE ÉGYPTIEN-13E18",NULL},
/* 13E19 */ { "HIÉROGLYPHE ÉGYPTIEN-13E19","	* logogramme (année) : rnp.t"},
/* 13E1A */ { "HIÉROGLYPHE ÉGYPTIEN-13E1A","	* logogramme (année) : rnp.t"},
/* 13E1B */ { "HIÉROGLYPHE ÉGYPTIEN-13E1B","	* logogramme (année) : rnp.t"},
/* 13E1C */ { "HIÉROGLYPHE ÉGYPTIEN-13E1C","	* phono-répéteur : tr"},
/* 13E1D */ { "HIÉROGLYPHE ÉGYPTIEN-13E1D","	* logogramme (année) : rnp.t"},
/* 13E1E */ { "HIÉROGLYPHE ÉGYPTIEN-13E1E","	* logogramme (année) : rnp.t"},
/* 13E1F */ { "HIÉROGLYPHE ÉGYPTIEN-13E1F","	* logogramme (temps, saison) : tr"},
/* 13E20 */ { "HIÉROGLYPHE ÉGYPTIEN-13E20","	* logogramme (être jeune, rajeunir) : rnpꞽ"},
/* 13E21 */ { "HIÉROGLYPHE ÉGYPTIEN-13E21","	* logogramme (être jeune, rajeunir) : rnpꞽ"},
/* 13E22 */ { "HIÉROGLYPHE ÉGYPTIEN-13E22","	* classificateur/phono-répéteur : tr"},
/* 13E23 */ { "HIÉROGLYPHE ÉGYPTIEN-13E23","	* logogramme (temps, saison) : tr"},
/* 13E24 */ { "HIÉROGLYPHE ÉGYPTIEN-13E24",NULL},
/* 13E25 */ { "HIÉROGLYPHE ÉGYPTIEN-13E25",NULL},
/* 13E26 */ { "HIÉROGLYPHE ÉGYPTIEN-13E26","	* logogramme (année) : rnp.t"},
/* 13E27 */ { "HIÉROGLYPHE ÉGYPTIEN-13E27","	* logogramme (être jeune, rajeunir) : rnpꞽ"},
/* 13E28 */ { "HIÉROGLYPHE ÉGYPTIEN-13E28",NULL},
/* 13E29 */ { "HIÉROGLYPHE ÉGYPTIEN-13E29",NULL},
/* 13E2A */ { "HIÉROGLYPHE ÉGYPTIEN-13E2A","	* ?"},
/* 13E2B */ { "HIÉROGLYPHE ÉGYPTIEN-13E2B",NULL},
/* 13E2C */ { "HIÉROGLYPHE ÉGYPTIEN-13E2C",NULL},
/* 13E2D */ { "HIÉROGLYPHE ÉGYPTIEN-13E2D","	* phonémogramme : šꜣ"},
/* 13E2E */ { "HIÉROGLYPHE ÉGYPTIEN-13E2E","	* phonémogramme : šꜣ"},
/* 13E2F */ { "HIÉROGLYPHE ÉGYPTIEN-13E2F","	* logogramme (marais, prairie) : šꜣ"},
/* 13E30 */ { "HIÉROGLYPHE ÉGYPTIEN-13E30","	* classificateur fleur : ms"},
/* 13E31 */ { "HIÉROGLYPHE ÉGYPTIEN-13E31","	* phonémogramme : šꜣ"},
/* 13E32 */ { "HIÉROGLYPHE ÉGYPTIEN-13E32","	* phonémogramme : šꜣ"},
/* 13E33 */ { "HIÉROGLYPHE ÉGYPTIEN-13E33","	* phonémogramme : ḫ"},
/* 13E34 */ { "HIÉROGLYPHE ÉGYPTIEN-13E34","	* phonémogramme : šꜣ"},
/* 13E35 */ { "HIÉROGLYPHE ÉGYPTIEN-13E35","	* phonémogramme : šꜣ"},
/* 13E36 */ { "HIÉROGLYPHE ÉGYPTIEN-13E36","	* phonémogramme : š"},
/* 13E37 */ { "HIÉROGLYPHE ÉGYPTIEN-13E37",NULL},
/* 13E38 */ { "HIÉROGLYPHE ÉGYPTIEN-13E38","	* ?"},
/* 13E39 */ { "HIÉROGLYPHE ÉGYPTIEN-13E39","	* classificateur offrande : wdn"},
/* 13E3A */ { "HIÉROGLYPHE ÉGYPTIEN-13E3A","	* classificateur laitue : ꜥb(w)"},
/* 13E3B */ { "HIÉROGLYPHE ÉGYPTIEN-13E3B",NULL},
/* 13E3C */ { "HIÉROGLYPHE ÉGYPTIEN-13E3C","	* classificateur croissance : srd"},
/* 13E3D */ { "HIÉROGLYPHE ÉGYPTIEN-13E3D",NULL},
/* 13E3E */ { "HIÉROGLYPHE ÉGYPTIEN-13E3E",NULL},
/* 13E3F */ { "HIÉROGLYPHE ÉGYPTIEN-13E3F","	* logogramme (être bon) : nfr"},
/* 13E40 */ { "HIÉROGLYPHE ÉGYPTIEN-13E40","	* classificateur fleur : nḥb.t"},
/* 13E41 */ { "HIÉROGLYPHE ÉGYPTIEN-13E41","	* classificateur plantes, fleurs : ḫꜣ.w"},
/* 13E42 */ { "HIÉROGLYPHE ÉGYPTIEN-13E42","	* classificateur joie : ꜣw-ꞽb"},
/* 13E43 */ { "HIÉROGLYPHE ÉGYPTIEN-13E43","	* classificateur plante / phono-répéteur : hdn"},
/* 13E44 */ { "HIÉROGLYPHE ÉGYPTIEN-13E44","	* classificateur joie : rš(.w)"},
/* 13E45 */ { "HIÉROGLYPHE ÉGYPTIEN-13E45","	* classificateur joie : ꜣw-ꞽb"},
/* 13E46 */ { "HIÉROGLYPHE ÉGYPTIEN-13E46",NULL},
/* 13E47 */ { "HIÉROGLYPHE ÉGYPTIEN-13E47","	* classificateur joie : rš(.w)"},
/* 13E48 */ { "HIÉROGLYPHE ÉGYPTIEN-13E48","	* classificateur fleur : ḥrr(.t)"},
/* 13E49 */ { "HIÉROGLYPHE ÉGYPTIEN-13E49",NULL},
/* 13E4A */ { "HIÉROGLYPHE ÉGYPTIEN-13E4A","	* classificateur fleur : ḥrr(.t)"},
/* 13E4B */ { "HIÉROGLYPHE ÉGYPTIEN-13E4B","	* logogramme (fleur) : sbtt"},
/* 13E4C */ { "HIÉROGLYPHE ÉGYPTIEN-13E4C","	* classificateur fleur : ḥrr(.t)"},
/* 13E4D */ { "HIÉROGLYPHE ÉGYPTIEN-13E4D","	* logogramme (Ounennéfer, titre d'Osiris) : wnn-nfr"},
/* 13E4E */ { "HIÉROGLYPHE ÉGYPTIEN-13E4E","	* classificateur plantes, légumes : sm.w"},
/* 13E4F */ { "HIÉROGLYPHE ÉGYPTIEN-13E4F","	* logogramme (lotus) : nḫb"},
/* 13E50 */ { "HIÉROGLYPHE ÉGYPTIEN-13E50",NULL},
/* 13E51 */ { "HIÉROGLYPHE ÉGYPTIEN-13E51","	* logogramme (lotus) : nḫb"},
/* 13E52 */ { "HIÉROGLYPHE ÉGYPTIEN-13E52","	* classificateur roseau, jonc : ꞽꜣr"},
/* 13E53 */ { "HIÉROGLYPHE ÉGYPTIEN-13E53","	* classificateur roseau, jonc : ꞽꜣr"},
/* 13E54 */ { "HIÉROGLYPHE ÉGYPTIEN-13E54","	* classificateur offrande florale : ms(w)"},
/* 13E55 */ { "HIÉROGLYPHE ÉGYPTIEN-13E55","	* classificateur offrande florale : ms(w)"},
/* 13E56 */ { "HIÉROGLYPHE ÉGYPTIEN-13E56",NULL},
/* 13E57 */ { "HIÉROGLYPHE ÉGYPTIEN-13E57",NULL},
/* 13E58 */ { "HIÉROGLYPHE ÉGYPTIEN-13E58","	* phonémogramme : ḥn"},
/* 13E59 */ { "HIÉROGLYPHE ÉGYPTIEN-13E59","	* logogramme (offrir) : wdn"},
/* 13E5A */ { "HIÉROGLYPHE ÉGYPTIEN-13E5A","	* logogramme (offrir) : wdn"},
/* 13E5B */ { "HIÉROGLYPHE ÉGYPTIEN-13E5B","	* phonémogramme : nfr"},
/* 13E5C */ { "HIÉROGLYPHE ÉGYPTIEN-13E5C","	* phonémogramme : ḫꜣ"},
/* 13E5D */ { "HIÉROGLYPHE ÉGYPTIEN-13E5D","	* phonémogramme ḫꜣ ? (dans le verbe ḫꜣḫꜣ, vanner, disperser) : ḫꜣ"},
/* 13E5E */ { "HIÉROGLYPHE ÉGYPTIEN-13E5E","	* phonémogramme : ḫ"},
/* 13E5F */ { "HIÉROGLYPHE ÉGYPTIEN-13E5F","	* phonémogramme : ḫꜣ"},
/* 13E60 */ { "HIÉROGLYPHE ÉGYPTIEN-13E60","	* logogramme (1.000) : ḫꜣ"},
/* 13E61 */ { "HIÉROGLYPHE ÉGYPTIEN-13E61","	* phonémogramme : šn"},
/* 13E62 */ { "HIÉROGLYPHE ÉGYPTIEN-13E62","	* logogramme (1.000) : ḫꜣ"},
/* 13E63 */ { "HIÉROGLYPHE ÉGYPTIEN-13E63","	* classificateur feuille de lotus : sp(ꜣ).t"},
/* 13E64 */ { "HIÉROGLYPHE ÉGYPTIEN-13E64","	* phonémogramme : ḫꜣ"},
/* 13E65 */ { "HIÉROGLYPHE ÉGYPTIEN-13E65","	* 4.000"},
/* 13E66 */ { "HIÉROGLYPHE ÉGYPTIEN-13E66","	* phonémogramme : wꜣḏ"},
/* 13E67 */ { "HIÉROGLYPHE ÉGYPTIEN-13E67","	* phonémogramme : wꜣḏ"},
/* 13E68 */ { "HIÉROGLYPHE ÉGYPTIEN-13E68",NULL},
/* 13E69 */ { "HIÉROGLYPHE ÉGYPTIEN-13E69",NULL},
/* 13E6A */ { "HIÉROGLYPHE ÉGYPTIEN-13E6A","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 13E6B */ { "HIÉROGLYPHE ÉGYPTIEN-13E6B","	* phonémogramme : ḥs"},
/* 13E6C */ { "HIÉROGLYPHE ÉGYPTIEN-13E6C","	* logogramme (uræus) : wꜣḏ.t"},
/* 13E6D */ { "HIÉROGLYPHE ÉGYPTIEN-13E6D","	* logogramme (uræus) : wꜣḏ.t"},
/* 13E6E */ { "HIÉROGLYPHE ÉGYPTIEN-13E6E","	* logogramme (uræus) : wꜣḏ.t"},
/* 13E6F */ { "HIÉROGLYPHE ÉGYPTIEN-13E6F","	* logogramme (briller, être brillant, éblouir) : ṯḥn"},
/* 13E70 */ { "HIÉROGLYPHE ÉGYPTIEN-13E70","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E71 */ { "HIÉROGLYPHE ÉGYPTIEN-13E71",NULL},
/* 13E72 */ { "HIÉROGLYPHE ÉGYPTIEN-13E72",NULL},
/* 13E73 */ { "HIÉROGLYPHE ÉGYPTIEN-13E73","	* phonémogramme : ḥꜣ"},
/* 13E74 */ { "HIÉROGLYPHE ÉGYPTIEN-13E74","	* classificateur marais, marécage : mḥ.t"},
/* 13E75 */ { "HIÉROGLYPHE ÉGYPTIEN-13E75","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 13E76 */ { "HIÉROGLYPHE ÉGYPTIEN-13E76","	* phonémogramme : ꜣḫ"},
/* 13E77 */ { "HIÉROGLYPHE ÉGYPTIEN-13E77","	* logogramme (Basse-Égypte) : tꜣ-mḥ.w"},
/* 13E78 */ { "HIÉROGLYPHE ÉGYPTIEN-13E78","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E79 */ { "HIÉROGLYPHE ÉGYPTIEN-13E79","	* phonémogramme : ḥꜣ"},
/* 13E7A */ { "HIÉROGLYPHE ÉGYPTIEN-13E7A","	* radicogramme (céréales de Basse-Égypte) : mḥ.w"},
/* 13E7B */ { "HIÉROGLYPHE ÉGYPTIEN-13E7B","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E7C */ { "HIÉROGLYPHE ÉGYPTIEN-13E7C","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E7D */ { "HIÉROGLYPHE ÉGYPTIEN-13E7D","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E7E */ { "HIÉROGLYPHE ÉGYPTIEN-13E7E","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E7F */ { "HIÉROGLYPHE ÉGYPTIEN-13E7F",NULL},
/* 13E80 */ { "HIÉROGLYPHE ÉGYPTIEN-13E80","	* phonémogramme : ḥꜣ"},
/* 13E81 */ { "HIÉROGLYPHE ÉGYPTIEN-13E81","	* classificateur plantes : rnp.wt"},
/* 13E82 */ { "HIÉROGLYPHE ÉGYPTIEN-13E82","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 13E83 */ { "HIÉROGLYPHE ÉGYPTIEN-13E83","	* classificateur offrande florale : ms(w)"},
/* 13E84 */ { "HIÉROGLYPHE ÉGYPTIEN-13E84","	* phonémogramme : ꞽ"},
/* 13E85 */ { "HIÉROGLYPHE ÉGYPTIEN-13E85","	* phonémogramme : ꞽ"},
/* 13E86 */ { "HIÉROGLYPHE ÉGYPTIEN-13E86","	* phonémogramme : ꜥꜣb"},
/* 13E87 */ { "HIÉROGLYPHE ÉGYPTIEN-13E87","	* logogramme (offrande) : ꜥꜣb.t"},
/* 13E88 */ { "HIÉROGLYPHE ÉGYPTIEN-13E88","	* logogramme (offrande) : ꜥꜣb.t"},
/* 13E89 */ { "HIÉROGLYPHE ÉGYPTIEN-13E89","	* logogramme (offrande) : ꜥꜣb.t"},
/* 13E8A */ { "HIÉROGLYPHE ÉGYPTIEN-13E8A","	* logogramme (marécage, campagne) : sḫ.t"},
/* 13E8B */ { "HIÉROGLYPHE ÉGYPTIEN-13E8B","	* classificateur roseaux, joncs : ꞽꜣr.w"},
/* 13E8C */ { "HIÉROGLYPHE ÉGYPTIEN-13E8C","	* phonémogramme : n/rs.y"},
/* 13E8D */ { "HIÉROGLYPHE ÉGYPTIEN-13E8D",NULL},
/* 13E8E */ { "HIÉROGLYPHE ÉGYPTIEN-13E8E","	* phonémogramme : nḫb"},
/* 13E8F */ { "HIÉROGLYPHE ÉGYPTIEN-13E8F","	* phonémogramme : rsw/rsy"},
/* 13E90 */ { "HIÉROGLYPHE ÉGYPTIEN-13E90","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E91 */ { "HIÉROGLYPHE ÉGYPTIEN-13E91","	* phonémogramme : šmꜥ"},
/* 13E92 */ { "HIÉROGLYPHE ÉGYPTIEN-13E92","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E93 */ { "HIÉROGLYPHE ÉGYPTIEN-13E93","	* phonémogramme : rsw/rsy"},
/* 13E94 */ { "HIÉROGLYPHE ÉGYPTIEN-13E94",NULL},
/* 13E95 */ { "HIÉROGLYPHE ÉGYPTIEN-13E95","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E96 */ { "HIÉROGLYPHE ÉGYPTIEN-13E96","	* logogramme (gardien des biens du roi) : ꞽr.y-(ꞽ)ḫ.t-n(.y)-sw.t"},
/* 13E97 */ { "HIÉROGLYPHE ÉGYPTIEN-13E97","	* classificateur plantes : sr{r}.wy"},
/* 13E98 */ { "HIÉROGLYPHE ÉGYPTIEN-13E98","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 13E99 */ { "HIÉROGLYPHE ÉGYPTIEN-13E99","	* phonémogramme : nḫb"},
/* 13E9A */ { "HIÉROGLYPHE ÉGYPTIEN-13E9A","	* logogramme (roi de Haute-Égypte) : n(.y)-sw.t"},
/* 13E9B */ { "HIÉROGLYPHE ÉGYPTIEN-13E9B","	* phonémogramme : šmꜥ"},
/* 13E9C */ { "HIÉROGLYPHE ÉGYPTIEN-13E9C",NULL},
/* 13E9D */ { "HIÉROGLYPHE ÉGYPTIEN-13E9D","	* logogramme (suivre, accompagner) : šms"},
/* 13E9E */ { "HIÉROGLYPHE ÉGYPTIEN-13E9E","	* classificateur mèche de cheveux tressés : ḥnsk.t"},
/* 13E9F */ { "HIÉROGLYPHE ÉGYPTIEN-13E9F","	* classificateur prospère, chanceux : mꜥr"},
/* 13EA0 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA0","	* logogramme (prospère, chanceux) : mꜥr"},
/* 13EA1 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA1","	* logogramme (être doux) : bnr/bnꞽ"},
/* 13EA2 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA2","	* logogramme (être doux) : bnr/bnꞽ"},
/* 13EA3 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA3","	* classificateur plantes : rd"},
/* 13EA4 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA4",NULL},
/* 13EA5 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA5","	* classificateur céréales, orge, blé : sw.t"},
/* 13EA6 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA6","	* logogramme (épeautre) : bd.t"},
/* 13EA7 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA7",NULL},
/* 13EA8 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA8","	* phonémogramme : ḏr"},
/* 13EA9 */ { "HIÉROGLYPHE ÉGYPTIEN-13EA9","	* phonémogramme : ḏr"},
/* 13EAA */ { "HIÉROGLYPHE ÉGYPTIEN-13EAA","	* classificateur ficelage, liaison : dmꜣ"},
/* 13EAB */ { "HIÉROGLYPHE ÉGYPTIEN-13EAB","	* phonémogramme : ḏr"},
/* 13EAC */ { "HIÉROGLYPHE ÉGYPTIEN-13EAC","	* phonémogramme : ḏr"},
/* 13EAD */ { "HIÉROGLYPHE ÉGYPTIEN-13EAD",NULL},
/* 13EAE */ { "HIÉROGLYPHE ÉGYPTIEN-13EAE",NULL},
/* 13EAF */ { "HIÉROGLYPHE ÉGYPTIEN-13EAF","	* phonémogramme : ḏr"},
/* 13EB0 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB0","	* classificateur ficelage, liaison : dmꜣ"},
/* 13EB1 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB1","	* classificateur légume, fruit, plante : rnp.wt"},
/* 13EB2 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB2","	* logogramme ((un récipient) avec de la faïence) : ṯḥn.t"},
/* 13EB3 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB3","	* phonémogramme : ꞽs"},
/* 13EB4 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB4","	* phonémogramme : ꞽs"},
/* 13EB5 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB5","	* phonémogramme : ꞽs"},
/* 13EB6 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB6",NULL},
/* 13EB7 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB7","	* logogramme (jardinier, vigneron) : kꜣn.y"},
/* 13EB8 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB8","	* classificateur vin : ꞽrp"},
/* 13EB9 */ { "HIÉROGLYPHE ÉGYPTIEN-13EB9","	* classificateur figue : dꜣb"},
/* 13EBA */ { "HIÉROGLYPHE ÉGYPTIEN-13EBA","	* classificateur Min ou logogramme (laitue) : mnw | ꜥbw"},
/* 13EBB */ { "HIÉROGLYPHE ÉGYPTIEN-13EBB","	* classificateur unions : ḥḏ(.w)"},
/* 13EBC */ { "HIÉROGLYPHE ÉGYPTIEN-13EBC","	* classificateur plantes : sm"},
/* 13EBD */ { "HIÉROGLYPHE ÉGYPTIEN-13EBD",NULL},
/* 13EBE */ { "HIÉROGLYPHE ÉGYPTIEN-13EBE","	* classificateur laitue : ꜥb.w"},
/* 13EBF */ { "HIÉROGLYPHE ÉGYPTIEN-13EBF",NULL},
/* 13EC0 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC0","	* logogramme (figue) : dꜣb"},
/* 13EC1 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC1",NULL},
/* 13EC2 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC2","	* classificateur ciel inférieur : nn.t"},
/* 13EC3 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC3","	* logogramme (grenier) : šnw.t"},
/* 13EC4 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC4","	* classificateur affliction : nḳm.t"},
/* 13EC5 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC5","	* classificateur caverne : tpḥ.t"},
/* 13EC6 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC6","	* logogramme (eaux primitives) : nw.w"},
/* 13EC7 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC7","	* classificateur sombre, obscurité : snk"},
/* 13EC8 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC8","	* classificateur obscurité (dans la divinité Kekout (kk.t)) : kk.t"},
/* 13EC9 */ { "HIÉROGLYPHE ÉGYPTIEN-13EC9","	* classificateur obscurité : wḫ"},
/* 13ECA */ { "HIÉROGLYPHE ÉGYPTIEN-13ECA","	* classificateur obscurité : wḫꜣ"},
/* 13ECB */ { "HIÉROGLYPHE ÉGYPTIEN-13ECB","	* logogramme (nuit) : grḥ"},
/* 13ECC */ { "HIÉROGLYPHE ÉGYPTIEN-13ECC","	* classificateur nuit : grḥ"},
/* 13ECD */ { "HIÉROGLYPHE ÉGYPTIEN-13ECD","	* phonémogramme : ḥr.y"},
/* 13ECE */ { "HIÉROGLYPHE ÉGYPTIEN-13ECE","	* classificateur aube : ꜥnḏ"},
/* 13ECF */ { "HIÉROGLYPHE ÉGYPTIEN-13ECF","	* logogramme (rosée, parfum, pluie) : ꞽꜣd.t"},
/* 13ED0 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED0","	* classificateur nuage, tempête, humidité, pluie : ꞽgp"},
/* 13ED1 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED1","	* classificateur nébulosité : ḥꜣty"},
/* 13ED2 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED2","	* classificateur temps : nḥḥ"},
/* 13ED3 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED3","	* classificateur divinité : ḥr"},
/* 13ED4 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED4","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED5 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED5","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED6 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED6","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED7 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED7","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED8 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED8","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13ED9 */ { "HIÉROGLYPHE ÉGYPTIEN-13ED9","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13EDA */ { "HIÉROGLYPHE ÉGYPTIEN-13EDA","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13EDB */ { "HIÉROGLYPHE ÉGYPTIEN-13EDB","	* classificateur disperser la lumière, illuminer : wpš"},
/* 13EDC */ { "HIÉROGLYPHE ÉGYPTIEN-13EDC",NULL},
/* 13EDD */ { "HIÉROGLYPHE ÉGYPTIEN-13EDD","	* classificateur disperser la lumière, illuminer : wpš"},
/* 13EDE */ { "HIÉROGLYPHE ÉGYPTIEN-13EDE","	* classificateur lumière, brillant, montant : ꞽꜣḫ.w"},
/* 13EDF */ { "HIÉROGLYPHE ÉGYPTIEN-13EDF","	* classificateur lumière, brillant, montant : ḥḏḏ.wt"},
/* 13EE0 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE0","	* classificateur peuple du soleil : ḥnmm.t"},
/* 13EE1 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE1","	* classificateur briller : wbn"},
/* 13EE2 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE2","	* classificateur lumière, brillant, montant : sḥḏ"},
/* 13EE3 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE3","	* classificateur disperser la lumière, illuminer : wpš"},
/* 13EE4 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE4","	* classificateur période solaire : rnp.t"},
/* 13EE5 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE5",NULL},
/* 13EE6 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE6","	* classificateur période solaire : dwꜣw"},
/* 13EE7 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE7","	* classificateur étendre : ḥdy"},
/* 13EE8 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE8","	* logogramme (le scarabée/soleil ailé) : ꜥpy"},
/* 13EE9 */ { "HIÉROGLYPHE ÉGYPTIEN-13EE9","	* classificateur Horus d'Edfou : bḥd.ty"},
/* 13EEA */ { "HIÉROGLYPHE ÉGYPTIEN-13EEA","	* logogramme (aller de l'avant) : prꞽ"},
/* 13EEB */ { "HIÉROGLYPHE ÉGYPTIEN-13EEB","	* classificateur divinité : ḏḥwty"},
/* 13EEC */ { "HIÉROGLYPHE ÉGYPTIEN-13EEC","	* classificateur divinité : ḏḥwty"},
/* 13EED */ { "HIÉROGLYPHE ÉGYPTIEN-13EED","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13EEE */ { "HIÉROGLYPHE ÉGYPTIEN-13EEE","	* logogramme (roi de Haute-Égypte et de Basse-Égypte) : n(.y)-sw.t-bꞽ.ty"},
/* 13EEF */ { "HIÉROGLYPHE ÉGYPTIEN-13EEF","	* logogramme (se lever, briller) : wbn"},
/* 13EF0 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF0","	* classificateur soleil ailé : ꜥpy"},
/* 13EF1 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF1","	* logogramme (se lever, briller) : wbn"},
/* 13EF2 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF2","	* logogramme (se lever, briller) : wbn"},
/* 13EF3 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF3","	* logogramme (dans rꜥ-nb) : ꞽꜥḥ"},
/* 13EF4 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF4",NULL},
/* 13EF5 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF5","	* logogramme ((fête du) milieu du mois) : smd.t"},
/* 13EF6 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF6","	* logogramme (mois) : ꜣbd"},
/* 13EF7 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF7",NULL},
/* 13EF8 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF8","	* logogramme (briller, être brillant, éblouir) : ṯḥn"},
/* 13EF9 */ { "HIÉROGLYPHE ÉGYPTIEN-13EF9","	* logogramme (Haute-Égypte) : tꜣ-šmꜥ.w"},
/* 13EFA */ { "HIÉROGLYPHE ÉGYPTIEN-13EFA","	* logogramme (Basse-Égypte) : tꜣ-mḥ.w"},
/* 13EFB */ { "HIÉROGLYPHE ÉGYPTIEN-13EFB","	* logogramme (terre) : tꜣ"},
/* 13EFC */ { "HIÉROGLYPHE ÉGYPTIEN-13EFC","	* logogramme (terre) : tꜣ"},
/* 13EFD */ { "HIÉROGLYPHE ÉGYPTIEN-13EFD","	* logogramme (terre) : tꜣ"},
/* 13EFE */ { "HIÉROGLYPHE ÉGYPTIEN-13EFE","	* logogramme (terre) : tꜣ"},
/* 13EFF */ { "HIÉROGLYPHE ÉGYPTIEN-13EFF","	* logogramme (terre) : tꜣ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_3F[] = {
/* 13F00 */ { "HIÉROGLYPHE ÉGYPTIEN-13F00","	* logogramme (Dendérah) : ꞽꜣ.t-dꞽ"},
/* 13F01 */ { "HIÉROGLYPHE ÉGYPTIEN-13F01","	* classificateur grande eau, grand bassin : wrr"},
/* 13F02 */ { "HIÉROGLYPHE ÉGYPTIEN-13F02","	* classificateur lieu géographique : tꜣ"},
/* 13F03 */ { "HIÉROGLYPHE ÉGYPTIEN-13F03","	* classificateur jardin : ḥsp"},
/* 13F04 */ { "HIÉROGLYPHE ÉGYPTIEN-13F04","	* logogramme (nome, district) : spꜣ.t"},
/* 13F05 */ { "HIÉROGLYPHE ÉGYPTIEN-13F05","	* logogramme (nome, district) : spꜣ.t"},
/* 13F06 */ { "HIÉROGLYPHE ÉGYPTIEN-13F06","	* logogramme (nome, district) : spꜣ.t"},
/* 13F07 */ { "HIÉROGLYPHE ÉGYPTIEN-13F07",NULL},
/* 13F08 */ { "HIÉROGLYPHE ÉGYPTIEN-13F08",NULL},
/* 13F09 */ { "HIÉROGLYPHE ÉGYPTIEN-13F09",NULL},
/* 13F0A */ { "HIÉROGLYPHE ÉGYPTIEN-13F0A","	* classificateur jardin : ḥsp"},
/* 13F0B */ { "HIÉROGLYPHE ÉGYPTIEN-13F0B",NULL},
/* 13F0C */ { "HIÉROGLYPHE ÉGYPTIEN-13F0C","	* logogramme (péhou ou canal dans le 4e nome de Basse-Égypte) : mtr"},
/* 13F0D */ { "HIÉROGLYPHE ÉGYPTIEN-13F0D","	* logogramme (nome d'Andjety, 9e nome de Basse-Égypte) : ꜥnḏ.ty"},
/* 13F0E */ { "HIÉROGLYPHE ÉGYPTIEN-13F0E","	* logogramme (20e et 21e nomes de Haute-Égypte) : nꜥr.t"},
/* 13F0F */ { "HIÉROGLYPHE ÉGYPTIEN-13F0F","	* logogramme (nome inférieur du Sycomore, 14e nome de Haute-Égypte) : nḏf.t-pḥ.t"},
/* 13F10 */ { "HIÉROGLYPHE ÉGYPTIEN-13F10","	* logogramme (nome inférieur du Laurier-Rose, 21e nome de Haute-Égypte) : nꜥr.t-pḥ.t"},
/* 13F11 */ { "HIÉROGLYPHE ÉGYPTIEN-13F11","	* logogramme (nome inférieur du Sycomore, 14e nome de Haute-Égypte) : nḏf.t-pḥ.t"},
/* 13F12 */ { "HIÉROGLYPHE ÉGYPTIEN-13F12","	* logogramme (nome du Dressoir oriental, 14e nome de Basse-Égypte) : ḫnt.y-ꞽꜣb.ty"},
/* 13F13 */ { "HIÉROGLYPHE ÉGYPTIEN-13F13","	* logogramme (nome supérieur de l'Enfant royal, 18e nome de Basse-Égypte) : ꞽm.ty-ḫnt.y"},
/* 13F14 */ { "HIÉROGLYPHE ÉGYPTIEN-13F14","	* logogramme (nome de la Vipère de montagne, 12e nome de Haute-Égypte) : ꜣtf.t"},
/* 13F15 */ { "HIÉROGLYPHE ÉGYPTIEN-13F15","	* logogramme (Ha (divinité)) : ḥꜣ"},
/* 13F16 */ { "HIÉROGLYPHE ÉGYPTIEN-13F16","	* logogramme (pays/désert étranger) : ḫꜣs.t"},
/* 13F17 */ { "HIÉROGLYPHE ÉGYPTIEN-13F17","	* classificateur lieu : ty"},
/* 13F18 */ { "HIÉROGLYPHE ÉGYPTIEN-13F18","	* logogramme (lieu de vie (c'est-à-dire l'ouest)) : ꜥnḫ.t"},
/* 13F19 */ { "HIÉROGLYPHE ÉGYPTIEN-13F19","	* logogramme (lieu de vie (c'est-à-dire l'ouest)) : ꜥnḫ.t"},
/* 13F1A */ { "HIÉROGLYPHE ÉGYPTIEN-13F1A","	* classificateur terre étrangère : sṯ.t"},
/* 13F1B */ { "HIÉROGLYPHE ÉGYPTIEN-13F1B","	* logogramme (le maléfique) : ḏw-ḳd"},
/* 13F1C */ { "HIÉROGLYPHE ÉGYPTIEN-13F1C","	* logogramme (nome de la Vipère de montagne, 12e nome de Haute-Égypte) : ꜣtf.t"},
/* 13F1D */ { "HIÉROGLYPHE ÉGYPTIEN-13F1D","	* logogramme (nome de la Vipère de montagne, 12e nome de Haute-Égypte) : ꜣtf.t"},
/* 13F1E */ { "HIÉROGLYPHE ÉGYPTIEN-13F1E","	* logogramme (Ha (divinité)) : ḥꜣ"},
/* 13F1F */ { "HIÉROGLYPHE ÉGYPTIEN-13F1F","	* classificateur médicaments, encens, huile : snṯr\n"
	"	~ 13F1F FE01 pivoté de 180 degrés"},
/* 13F20 */ { "HIÉROGLYPHE ÉGYPTIEN-13F20","	* logogramme (éternité) : nḥḥ"},
/* 13F21 */ { "HIÉROGLYPHE ÉGYPTIEN-13F21","	* logogramme (lieu d'exécution/abattage) : ḫb.t/nm.t"},
/* 13F22 */ { "HIÉROGLYPHE ÉGYPTIEN-13F22",NULL},
/* 13F23 */ { "HIÉROGLYPHE ÉGYPTIEN-13F23","	* logogramme (éternité) : nḥḥ"},
/* 13F24 */ { "HIÉROGLYPHE ÉGYPTIEN-13F24","	* logogramme (apparaître, briller) : ḫꜥꞽ"},
/* 13F25 */ { "HIÉROGLYPHE ÉGYPTIEN-13F25","	* logogramme (colline, monticule) : ꞽꜣ.t"},
/* 13F26 */ { "HIÉROGLYPHE ÉGYPTIEN-13F26","	* logogramme (colline, monticule) : ꞽꜣ.t"},
/* 13F27 */ { "HIÉROGLYPHE ÉGYPTIEN-13F27",NULL},
/* 13F28 */ { "HIÉROGLYPHE ÉGYPTIEN-13F28","	* logogramme (Dendérah) : ꞽꜣ.t-dꞽ"},
/* 13F29 */ { "HIÉROGLYPHE ÉGYPTIEN-13F29","	* phonémogramme : ḥr"},
/* 13F2A */ { "HIÉROGLYPHE ÉGYPTIEN-13F2A","	* classificateur entièrement, tout à fait, en totalité : rsꞽ"},
/* 13F2B */ { "HIÉROGLYPHE ÉGYPTIEN-13F2B",NULL},
/* 13F2C */ { "HIÉROGLYPHE ÉGYPTIEN-13F2C","	* classificateur fenêtre : wsy"},
/* 13F2D */ { "HIÉROGLYPHE ÉGYPTIEN-13F2D","	* logogramme (route) : wꜣ.t"},
/* 13F2E */ { "HIÉROGLYPHE ÉGYPTIEN-13F2E","	* classificateur route, chemin : wꜣ.t"},
/* 13F2F */ { "HIÉROGLYPHE ÉGYPTIEN-13F2F","	* logogramme (temps) : hꜣw"},
/* 13F30 */ { "HIÉROGLYPHE ÉGYPTIEN-13F30","	* classificateur décomposition, pourriture : ꜥwꜣ"},
/* 13F31 */ { "HIÉROGLYPHE ÉGYPTIEN-13F31","	* phonémogramme : n"},
/* 13F32 */ { "HIÉROGLYPHE ÉGYPTIEN-13F32","	* logogramme (île (dans ꞽw-ḏsḏs (oasis d'Al-Bahariya))) : ꞽw"},
/* 13F33 */ { "HIÉROGLYPHE ÉGYPTIEN-13F33","	* logogramme (Dendérah) : ꞽꜣ.t-dꞽ"},
/* 13F34 */ { "HIÉROGLYPHE ÉGYPTIEN-13F34","	* phonémogramme : m"},
/* 13F35 */ { "HIÉROGLYPHE ÉGYPTIEN-13F35",NULL},
/* 13F36 */ { "HIÉROGLYPHE ÉGYPTIEN-13F36","	* classificateur temps : ꜥḥꜥ.w"},
/* 13F37 */ { "HIÉROGLYPHE ÉGYPTIEN-13F37","	* classificateur rive (rivière, forteresse) : ꞽḫm.t"},
/* 13F38 */ { "HIÉROGLYPHE ÉGYPTIEN-13F38","	* classificateur eaux, rivières, lacs : mr-n-ḫꜣ"},
/* 13F39 */ { "HIÉROGLYPHE ÉGYPTIEN-13F39","	* classificateur endiguer, renforcer : ḏnꞽ"},
/* 13F3A */ { "HIÉROGLYPHE ÉGYPTIEN-13F3A","	* logogramme (patauger) : rhnꞽ"},
/* 13F3B */ { "HIÉROGLYPHE ÉGYPTIEN-13F3B","	* phonémogramme : s-m"},
/* 13F3C */ { "HIÉROGLYPHE ÉGYPTIEN-13F3C","	* phonémogramme : š"},
/* 13F3D */ { "HIÉROGLYPHE ÉGYPTIEN-13F3D",NULL},
/* 13F3E */ { "HIÉROGLYPHE ÉGYPTIEN-13F3E","	* phonémogramme : š"},
/* 13F3F */ { "HIÉROGLYPHE ÉGYPTIEN-13F3F","	* logogramme (Hiérakonpolis) : nḫn"},
/* 13F40 */ { "HIÉROGLYPHE ÉGYPTIEN-13F40","	* logogramme (île) : ꞽw"},
/* 13F41 */ { "HIÉROGLYPHE ÉGYPTIEN-13F41","	* logogramme (aller) : šm"},
/* 13F42 */ { "HIÉROGLYPHE ÉGYPTIEN-13F42",NULL},
/* 13F43 */ { "HIÉROGLYPHE ÉGYPTIEN-13F43","	* logogramme (Dendérah) : ꞽꜣ.t-dꞽ"},
/* 13F44 */ { "HIÉROGLYPHE ÉGYPTIEN-13F44","	* phonémogramme : ḥm"},
/* 13F45 */ { "HIÉROGLYPHE ÉGYPTIEN-13F45","	* phonémogramme : ḥm"},
/* 13F46 */ { "HIÉROGLYPHE ÉGYPTIEN-13F46","	* logogramme (cuivre) : ḥmt"},
/* 13F47 */ { "HIÉROGLYPHE ÉGYPTIEN-13F47","	* classificateur métal : bꞽꜣ"},
/* 13F48 */ { "HIÉROGLYPHE ÉGYPTIEN-13F48","	* phonémogramme : mry"},
/* 13F49 */ { "HIÉROGLYPHE ÉGYPTIEN-13F49",NULL},
/* 13F4A */ { "HIÉROGLYPHE ÉGYPTIEN-13F4A","	* classificateur éclair : ḥnb.w"},
/* 13F4B */ { "HIÉROGLYPHE ÉGYPTIEN-13F4B",NULL},
/* 13F4C */ { "HIÉROGLYPHE ÉGYPTIEN-13F4C","	* classificateur deux tombes : ꞽs.wy"},
/* 13F4D */ { "HIÉROGLYPHE ÉGYPTIEN-13F4D","	* logogramme (offrande d'invocation) : pr.t-ḫrw"},
/* 13F4E */ { "HIÉROGLYPHE ÉGYPTIEN-13F4E",NULL},
/* 13F4F */ { "HIÉROGLYPHE ÉGYPTIEN-13F4F","	* logogramme (temple) : gs-pr"},
/* 13F50 */ { "HIÉROGLYPHE ÉGYPTIEN-13F50","	* logogramme (temple) : gs.w-pr.w"},
/* 13F51 */ { "HIÉROGLYPHE ÉGYPTIEN-13F51","	* logogramme (temple) : gs.w-pr.w"},
/* 13F52 */ { "HIÉROGLYPHE ÉGYPTIEN-13F52","	* logogramme (maisons, domaines) : pr.w"},
/* 13F53 */ { "HIÉROGLYPHE ÉGYPTIEN-13F53","	* logogramme (cour) : wsḫ.t"},
/* 13F54 */ { "HIÉROGLYPHE ÉGYPTIEN-13F54","	* classificateur lieu, bâtiment : s.t"},
/* 13F55 */ { "HIÉROGLYPHE ÉGYPTIEN-13F55",NULL},
/* 13F56 */ { "HIÉROGLYPHE ÉGYPTIEN-13F56","	* logogramme (temple, manoir, domaine) : ḥw.t"},
/* 13F57 */ { "HIÉROGLYPHE ÉGYPTIEN-13F57","	* logogramme (temples, manoirs, domaines) : ḥw.wt"},
/* 13F58 */ { "HIÉROGLYPHE ÉGYPTIEN-13F58",NULL},
/* 13F59 */ { "HIÉROGLYPHE ÉGYPTIEN-13F59","	* logogramme (temple, manoir, domaine) : ḥw.t"},
/* 13F5A */ { "HIÉROGLYPHE ÉGYPTIEN-13F5A",NULL},
/* 13F5B */ { "HIÉROGLYPHE ÉGYPTIEN-13F5B","	* logogramme (temples, manoirs, domaines) : ḥw.wt"},
/* 13F5C */ { "HIÉROGLYPHE ÉGYPTIEN-13F5C","	* logogramme (temples, manoirs, domaines) : ḥw.wt"},
/* 13F5D */ { "HIÉROGLYPHE ÉGYPTIEN-13F5D","	* logogramme (Hathor, dame (de)) : ḥw.t-ḥr-nb.t"},
/* 13F5E */ { "HIÉROGLYPHE ÉGYPTIEN-13F5E",NULL},
/* 13F5F */ { "HIÉROGLYPHE ÉGYPTIEN-13F5F",NULL},
/* 13F60 */ { "HIÉROGLYPHE ÉGYPTIEN-13F60","	* logogramme (Nephtys (divinité)) : nb.t-ḥw.t"},
/* 13F61 */ { "HIÉROGLYPHE ÉGYPTIEN-13F61","	* logogramme (Nephtys (divinité)) : nb.t-ḥw.t"},
/* 13F62 */ { "HIÉROGLYPHE ÉGYPTIEN-13F62","	* logogramme (palais) : ꜥḥ"},
/* 13F63 */ { "HIÉROGLYPHE ÉGYPTIEN-13F63","	* logogramme (palais) : ꜥḥ"},
/* 13F64 */ { "HIÉROGLYPHE ÉGYPTIEN-13F64",NULL},
/* 13F65 */ { "HIÉROGLYPHE ÉGYPTIEN-13F65","	* classificateur palais : ꜥḥ"},
/* 13F66 */ { "HIÉROGLYPHE ÉGYPTIEN-13F66",NULL},
/* 13F67 */ { "HIÉROGLYPHE ÉGYPTIEN-13F67","	* logogramme (palais) : ꜥḥ"},
/* 13F68 */ { "HIÉROGLYPHE ÉGYPTIEN-13F68",NULL},
/* 13F69 */ { "HIÉROGLYPHE ÉGYPTIEN-13F69","	* classificateur divin : nṯrꞽ"},
/* 13F6A */ { "HIÉROGLYPHE ÉGYPTIEN-13F6A","	* phonémogramme : wsḫ"},
/* 13F6B */ { "HIÉROGLYPHE ÉGYPTIEN-13F6B","	* phonémogramme : wsḫ"},
/* 13F6C */ { "HIÉROGLYPHE ÉGYPTIEN-13F6C","	* phonémogramme : wsḫ"},
/* 13F6D */ { "HIÉROGLYPHE ÉGYPTIEN-13F6D","	* phonémogramme : wsḫ"},
/* 13F6E */ { "HIÉROGLYPHE ÉGYPTIEN-13F6E","	* logogramme (cour des offrandes) : wsḫ.t-ḥtp"},
/* 13F6F */ { "HIÉROGLYPHE ÉGYPTIEN-13F6F",NULL},
/* 13F70 */ { "HIÉROGLYPHE ÉGYPTIEN-13F70",NULL},
/* 13F71 */ { "HIÉROGLYPHE ÉGYPTIEN-13F71",NULL},
/* 13F72 */ { "HIÉROGLYPHE ÉGYPTIEN-13F72","	* logogramme (mur) : ꞽnb\n"
	"	~ 13F72 FE00 pivoté de 90 degrés [= 270 degrés]"},
/* 13F73 */ { "HIÉROGLYPHE ÉGYPTIEN-13F73","	* classificateur renverser, démolir : snb"},
/* 13F74 */ { "HIÉROGLYPHE ÉGYPTIEN-13F74","	* classificateur renverser, démolir : sšn"},
/* 13F75 */ { "HIÉROGLYPHE ÉGYPTIEN-13F75","	* classificateur lieu géographique : km-wr"},
/* 13F76 */ { "HIÉROGLYPHE ÉGYPTIEN-13F76","	* classificateur lieu géographique (Éléphantine) : ꜣbw"},
/* 13F77 */ { "HIÉROGLYPHE ÉGYPTIEN-13F77",NULL},
/* 13F78 */ { "HIÉROGLYPHE ÉGYPTIEN-13F78","	* classificateur mur : sbty"},
/* 13F79 */ { "HIÉROGLYPHE ÉGYPTIEN-13F79","	* logogramme (Memphis (le mur blanc)) : nb-ḥḏ"},
/* 13F7A */ { "HIÉROGLYPHE ÉGYPTIEN-13F7A",NULL},
/* 13F7B */ { "HIÉROGLYPHE ÉGYPTIEN-13F7B","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F7C */ { "HIÉROGLYPHE ÉGYPTIEN-13F7C","	* classificateur façade du palais : srḫ"},
/* 13F7D */ { "HIÉROGLYPHE ÉGYPTIEN-13F7D",NULL},
/* 13F7E */ { "HIÉROGLYPHE ÉGYPTIEN-13F7E",NULL},
/* 13F7F */ { "HIÉROGLYPHE ÉGYPTIEN-13F7F","	* classificateur façade du palais : srḫ"},
/* 13F80 */ { "HIÉROGLYPHE ÉGYPTIEN-13F80","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F81 */ { "HIÉROGLYPHE ÉGYPTIEN-13F81","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F82 */ { "HIÉROGLYPHE ÉGYPTIEN-13F82","	* logogramme (chapelle) : ḥḏ"},
/* 13F83 */ { "HIÉROGLYPHE ÉGYPTIEN-13F83","	* logogramme (chapelle) : ḥḏ"},
/* 13F84 */ { "HIÉROGLYPHE ÉGYPTIEN-13F84","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F85 */ { "HIÉROGLYPHE ÉGYPTIEN-13F85","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F86 */ { "HIÉROGLYPHE ÉGYPTIEN-13F86","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F87 */ { "HIÉROGLYPHE ÉGYPTIEN-13F87","	* logogramme (façade (de palais) en serekh) : srḫ"},
/* 13F88 */ { "HIÉROGLYPHE ÉGYPTIEN-13F88","	* classificateur pylône, portail : bḫny"},
/* 13F89 */ { "HIÉROGLYPHE ÉGYPTIEN-13F89",NULL},
/* 13F8A */ { "HIÉROGLYPHE ÉGYPTIEN-13F8A","	* logogramme (sanctuaire de Haute-Égypte) : pr-wr"},
/* 13F8B */ { "HIÉROGLYPHE ÉGYPTIEN-13F8B","	* classificateur porte, portail : mꜣh.t"},
/* 13F8C */ { "HIÉROGLYPHE ÉGYPTIEN-13F8C","	* logogramme : ḥw.t"},
/* 13F8D */ { "HIÉROGLYPHE ÉGYPTIEN-13F8D","	* logogramme (chapelle) : kꜣr"},
/* 13F8E */ { "HIÉROGLYPHE ÉGYPTIEN-13F8E","	* logogramme (chapelle)"},
/* 13F8F */ { "HIÉROGLYPHE ÉGYPTIEN-13F8F","	* phonémogramme (dans r-rw.t (extérieur)) : rw.t"},
/* 13F90 */ { "HIÉROGLYPHE ÉGYPTIEN-13F90","	* logogramme (palais) : ꜥḥ"},
/* 13F91 */ { "HIÉROGLYPHE ÉGYPTIEN-13F91","	* logogramme (portail, portique) : sbḫ.t"},
/* 13F92 */ { "HIÉROGLYPHE ÉGYPTIEN-13F92","	* classificateur porte d'entrée : sbꜣ"},
/* 13F93 */ { "HIÉROGLYPHE ÉGYPTIEN-13F93","	* phonémogramme (dans r-rw.t (extérieur)) : rw.t"},
/* 13F94 */ { "HIÉROGLYPHE ÉGYPTIEN-13F94","	* logogramme (porte) : sbꜣ"},
/* 13F95 */ { "HIÉROGLYPHE ÉGYPTIEN-13F95","	* classificateur portail, portique : sbḫ.t"},
/* 13F96 */ { "HIÉROGLYPHE ÉGYPTIEN-13F96","	* classificateur tombeau : ꞽs"},
/* 13F97 */ { "HIÉROGLYPHE ÉGYPTIEN-13F97",NULL},
/* 13F98 */ { "HIÉROGLYPHE ÉGYPTIEN-13F98","	* classificateur portail, portique : sbḫ.t"},
/* 13F99 */ { "HIÉROGLYPHE ÉGYPTIEN-13F99","	* logogramme (porte principale d'un temple) : tꜣy.t"},
/* 13F9A */ { "HIÉROGLYPHE ÉGYPTIEN-13F9A","	* classificateur rideau : tꜣy.ty"},
/* 13F9B */ { "HIÉROGLYPHE ÉGYPTIEN-13F9B",NULL},
/* 13F9C */ { "HIÉROGLYPHE ÉGYPTIEN-13F9C","	* classificateur chapelle funéraire, cénotaphe : mꜥḥꜥ.t"},
/* 13F9D */ { "HIÉROGLYPHE ÉGYPTIEN-13F9D","	* classificateur chapelle : ḥḏ"},
/* 13F9E */ { "HIÉROGLYPHE ÉGYPTIEN-13F9E","	* logogramme (sanctuaire de Haute-Égypte) : pr-wr"},
/* 13F9F */ { "HIÉROGLYPHE ÉGYPTIEN-13F9F","	* logogramme (être divin) : nṯrꞽ"},
/* 13FA0 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA0",NULL},
/* 13FA1 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA1","	* classificateur sanctuaire : pr-wr"},
/* 13FA2 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA2","	* logogramme (sanctuaire de Haute-Égypte) : pr-wr"},
/* 13FA3 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA3","	* logogramme (sanctuaire de Haute-Égypte) : pr-wr"},
/* 13FA4 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA4",NULL},
/* 13FA5 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA5","	* classificateur sanctuaire : ḥḏ-šps"},
/* 13FA6 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA6","	* classificateur sanctuaire : pr-wr"},
/* 13FA7 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA7","	* classificateur chapelle (associée à Min) : sḥn"},
/* 13FA8 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA8","	* logogramme (Ennéade) : psḏ.t"},
/* 13FA9 */ { "HIÉROGLYPHE ÉGYPTIEN-13FA9","	* classificateur sanctuaire : s.t=f-wr.t"},
/* 13FAA */ { "HIÉROGLYPHE ÉGYPTIEN-13FAA",NULL},
/* 13FAB */ { "HIÉROGLYPHE ÉGYPTIEN-13FAB","	* logogramme (sanctuaire de Sokar) : šṯy.t"},
/* 13FAC */ { "HIÉROGLYPHE ÉGYPTIEN-13FAC","	* classificateur sanctuaire, temple : pr-nsr"},
/* 13FAD */ { "HIÉROGLYPHE ÉGYPTIEN-13FAD","	* logogramme (sanctuaire, rangée de sanctuaires) : ꞽtr.t"},
/* 13FAE */ { "HIÉROGLYPHE ÉGYPTIEN-13FAE","	* logogramme (Dendérah) : ꞽwn.t"},
/* 13FAF */ { "HIÉROGLYPHE ÉGYPTIEN-13FAF",NULL},
/* 13FB0 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB0",NULL},
/* 13FB1 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB1","	* logogramme (sanctuaire de Haute-Égypte) : pr-wr"},
/* 13FB2 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB2",NULL},
/* 13FB3 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB3","	* logogramme (portail, portique) : hꜣy,t"},
/* 13FB4 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB4","	* logogramme (plafond, ciel) : hꜣy.t"},
/* 13FB5 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB5","	* logogramme (portail, portique) : hꜣy,t"},
/* 13FB6 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB6","	* ? logogramme (sanctuaire ?) : sḥ"},
/* 13FB7 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB7","	* logogramme (pavillon, salle, cabine) : sḥ"},
/* 13FB8 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB8","	* logogramme (attacher, revêtir) : ꜥrḳ"},
/* 13FB9 */ { "HIÉROGLYPHE ÉGYPTIEN-13FB9",NULL},
/* 13FBA */ { "HIÉROGLYPHE ÉGYPTIEN-13FBA",NULL},
/* 13FBB */ { "HIÉROGLYPHE ÉGYPTIEN-13FBB","	* logogramme (abri divin) : sḥ-nṯr"},
/* 13FBC */ { "HIÉROGLYPHE ÉGYPTIEN-13FBC","	* logogramme (abri) : sḥ"},
/* 13FBD */ { "HIÉROGLYPHE ÉGYPTIEN-13FBD","	* phonémogramme : ꜥrḳ"},
/* 13FBE */ { "HIÉROGLYPHE ÉGYPTIEN-13FBE","	* phonémogramme (dans ꜥrḳ-wr) : ꜥrḳ"},
/* 13FBF */ { "HIÉROGLYPHE ÉGYPTIEN-13FBF","	* phonémogramme : ꜥrḳ"},
/* 13FC0 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC0","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FC1 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC1","	* classificateur estrade du trône : ṯnṯꜣ.t"},
/* 13FC2 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC2",NULL},
/* 13FC3 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC3","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FC4 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC4","	* logogramme (quatre) : (ꞽ)fd.w"},
/* 13FC5 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC5","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FC6 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC6","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FC7 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC7",NULL},
/* 13FC8 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC8",NULL},
/* 13FC9 */ { "HIÉROGLYPHE ÉGYPTIEN-13FC9","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FCA */ { "HIÉROGLYPHE ÉGYPTIEN-13FCA","	* classificateur jubilé, fête-sed : ḥb-sd"},
/* 13FCB */ { "HIÉROGLYPHE ÉGYPTIEN-13FCB","	* classificateur jubilé, fête-sed : ḥb-sd"},
/* 13FCC */ { "HIÉROGLYPHE ÉGYPTIEN-13FCC","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FCD */ { "HIÉROGLYPHE ÉGYPTIEN-13FCD","	* logogramme (fête) : ḥb"},
/* 13FCE */ { "HIÉROGLYPHE ÉGYPTIEN-13FCE","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FCF */ { "HIÉROGLYPHE ÉGYPTIEN-13FCF","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FD0 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD0","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FD1 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD1",NULL},
/* 13FD2 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD2","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FD3 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD3","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FD4 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD4","	* logogramme (jubilé, fête-sed) : ḥb-sd"},
/* 13FD5 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD5","	* logogramme (fête) : h(ꜣ)b"},
/* 13FD6 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD6","	* logogramme (plafond, ciel) : hꜣy.t"},
/* 13FD7 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD7","	* phonémogramme/logogramme : ḥꜣy.t n bꜣ"},
/* 13FD8 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD8","	* classificateur monter, gravir : sꞽꜥ"},
/* 13FD9 */ { "HIÉROGLYPHE ÉGYPTIEN-13FD9","	* ?"},
/* 13FDA */ { "HIÉROGLYPHE ÉGYPTIEN-13FDA","	* classificateur obélisque : tḫn"},
/* 13FDB */ { "HIÉROGLYPHE ÉGYPTIEN-13FDB","	* phonémogramme/logogramme (engendrer, éjaculer, créer) : bnbn"},
/* 13FDC */ { "HIÉROGLYPHE ÉGYPTIEN-13FDC","	* classificateur temple solaire : s.t-ꞽb-rꜥ"},
/* 13FDD */ { "HIÉROGLYPHE ÉGYPTIEN-13FDD","	* classificateur sanctuaire, chapelle : ꞽtr.t"},
/* 13FDE */ { "HIÉROGLYPHE ÉGYPTIEN-13FDE","	* logogramme (sanctuaire, rangée de sanctuaires) : ꞽtr.t"},
/* 13FDF */ { "HIÉROGLYPHE ÉGYPTIEN-13FDF","	* phonémogramme : ꞽwn"},
/* 13FE0 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE0","	* phonémogramme : wṯs"},
/* 13FE1 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE1","	* phonémogramme : ꞽwn"},
/* 13FE2 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE2","	* phonémogramme : ꞽwn"},
/* 13FE3 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE3",NULL},
/* 13FE4 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE4","	* logogramme (colonne papyriforme) : wꜣḏ"},
/* 13FE5 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE5","	* classificateur colonne (salle à colonnes) : wḫꜣ"},
/* 13FE6 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE6",NULL},
/* 13FE7 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE7","	* classificateur colonne (salle à colonnes) : wḫꜣ"},
/* 13FE8 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE8",NULL},
/* 13FE9 */ { "HIÉROGLYPHE ÉGYPTIEN-13FE9",NULL},
/* 13FEA */ { "HIÉROGLYPHE ÉGYPTIEN-13FEA","	* phonémogramme : šnꜥ"},
/* 13FEB */ { "HIÉROGLYPHE ÉGYPTIEN-13FEB","	* classificateur pilier : ꞽwn"},
/* 13FEC */ { "HIÉROGLYPHE ÉGYPTIEN-13FEC","	* logogramme (visage, vue) : ḥr"},
/* 13FED */ { "HIÉROGLYPHE ÉGYPTIEN-13FED",NULL},
/* 13FEE */ { "HIÉROGLYPHE ÉGYPTIEN-13FEE","	* classificateur verrou de porte : ḥkn"},
/* 13FEF */ { "HIÉROGLYPHE ÉGYPTIEN-13FEF","	* classificateur verrou de porte : kfꜣ/pḥ-ꜥḥꜥ"},
/* 13FF0 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF0","	* classificateur verrou de porte : ḳꜣn"},
/* 13FF1 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF1","	* phonémogramme : sn"},
/* 13FF2 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF2","	* phonémogramme : sbb"},
/* 13FF3 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF3","	* classificateur porte d'entrée : sbḫ.t"},
/* 13FF4 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF4","	* classificateur estrade, terrasse, plate-forme : ḫt(.w)"},
/* 13FF5 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF5","	* phonémogramme : sšp"},
/* 13FF6 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF6","	* phonémogramme : šsp"},
/* 13FF7 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF7","	* phonémogramme : šsp"},
/* 13FF8 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF8",NULL},
/* 13FF9 */ { "HIÉROGLYPHE ÉGYPTIEN-13FF9",NULL},
/* 13FFA */ { "HIÉROGLYPHE ÉGYPTIEN-13FFA","	* phonémogramme : šsp"},
/* 13FFB */ { "HIÉROGLYPHE ÉGYPTIEN-13FFB","	* phonémogramme : šsp"},
/* 13FFC */ { "HIÉROGLYPHE ÉGYPTIEN-13FFC",NULL},
/* 13FFD */ { "HIÉROGLYPHE ÉGYPTIEN-13FFD","	* logogramme (champ, terre arable) : ꜣḥ.t"},
/* 13FFE */ { "HIÉROGLYPHE ÉGYPTIEN-13FFE","	* phonémogramme : šsp"},
/* 13FFF */ { "HIÉROGLYPHE ÉGYPTIEN-13FFF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_40[] = {
/* 14000 */ { "HIÉROGLYPHE ÉGYPTIEN-14000","	* classificateur grenier : šnw.wt"},
/* 14001 */ { "HIÉROGLYPHE ÉGYPTIEN-14001",NULL},
/* 14002 */ { "HIÉROGLYPHE ÉGYPTIEN-14002","	* logogramme (grenier) : šnw.t"},
/* 14003 */ { "HIÉROGLYPHE ÉGYPTIEN-14003","	* logogramme (grenier) : šnw.t"},
/* 14004 */ { "HIÉROGLYPHE ÉGYPTIEN-14004",NULL},
/* 14005 */ { "HIÉROGLYPHE ÉGYPTIEN-14005","	* logogramme (grenier) : šnw.t"},
/* 14006 */ { "HIÉROGLYPHE ÉGYPTIEN-14006","	* logogramme (ornement) : ẖkr"},
/* 14007 */ { "HIÉROGLYPHE ÉGYPTIEN-14007","	* logogramme (ornement) : ẖkr"},
/* 14008 */ { "HIÉROGLYPHE ÉGYPTIEN-14008","	* classificateur tour : swn.w"},
/* 14009 */ { "HIÉROGLYPHE ÉGYPTIEN-14009","	* classificateur monter, gravir : sꞽꜥ"},
/* 1400A */ { "HIÉROGLYPHE ÉGYPTIEN-1400A","	* logogramme (l'emblème du culte de Min) : ꞽꜣw.t"},
/* 1400B */ { "HIÉROGLYPHE ÉGYPTIEN-1400B","	* logogramme (bureau, rang, fonction) : ꞽꜣw.t"},
/* 1400C */ { "HIÉROGLYPHE ÉGYPTIEN-1400C","	* logogramme (bureau, rang, fonction) : ꞽꜣw.t"},
/* 1400D */ { "HIÉROGLYPHE ÉGYPTIEN-1400D","	* classificateur harem, chambre intérieure : ꞽp.t"},
/* 1400E */ { "HIÉROGLYPHE ÉGYPTIEN-1400E","	* phonémogramme : ꞽp.t"},
/* 1400F */ { "HIÉROGLYPHE ÉGYPTIEN-1400F","	* phonémogramme : ꞽp.t"},
/* 14010 */ { "HIÉROGLYPHE ÉGYPTIEN-14010","	* phonémogramme : nḫn"},
/* 14011 */ { "HIÉROGLYPHE ÉGYPTIEN-14011","	* logogramme (Hiérakonpolis) : nḫn"},
/* 14012 */ { "HIÉROGLYPHE ÉGYPTIEN-14012","	* logogramme (Hiérakonpolis) : nḫn"},
/* 14013 */ { "HIÉROGLYPHE ÉGYPTIEN-14013",NULL},
/* 14014 */ { "HIÉROGLYPHE ÉGYPTIEN-14014","	* classificateur partie d'un bâtiment : sꜣw"},
/* 14015 */ { "HIÉROGLYPHE ÉGYPTIEN-14015",NULL},
/* 14016 */ { "HIÉROGLYPHE ÉGYPTIEN-14016",NULL},
/* 14017 */ { "HIÉROGLYPHE ÉGYPTIEN-14017","	* classificateur conflagration : snsn.t"},
/* 14018 */ { "HIÉROGLYPHE ÉGYPTIEN-14018","	* logogramme (forteresse) : mn(n).w"},
/* 14019 */ { "HIÉROGLYPHE ÉGYPTIEN-14019","	* classificateur escalier"},
/* 1401A */ { "HIÉROGLYPHE ÉGYPTIEN-1401A","	* classificateur mouvement : nmꞽ"},
/* 1401B */ { "HIÉROGLYPHE ÉGYPTIEN-1401B","	* classificateur bateau, navire, barque : ḥnw"},
/* 1401C */ { "HIÉROGLYPHE ÉGYPTIEN-1401C","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 1401D */ { "HIÉROGLYPHE ÉGYPTIEN-1401D","	* classificateur mouvement : ḫns"},
/* 1401E */ { "HIÉROGLYPHE ÉGYPTIEN-1401E","	* classificateur mouvement : ḫns"},
/* 1401F */ { "HIÉROGLYPHE ÉGYPTIEN-1401F","	* classificateur mouvement : ḏꜣ"},
/* 14020 */ { "HIÉROGLYPHE ÉGYPTIEN-14020","	* classificateur renverser, bouleverser : pnꜥ"},
/* 14021 */ { "HIÉROGLYPHE ÉGYPTIEN-14021","	* classificateur mouvement : ḫd"},
/* 14022 */ { "HIÉROGLYPHE ÉGYPTIEN-14022","	* classificateur bateau, navire : mẖn.t"},
/* 14023 */ { "HIÉROGLYPHE ÉGYPTIEN-14023","	* classificateur mouvement : ẖn"},
/* 14024 */ { "HIÉROGLYPHE ÉGYPTIEN-14024","	* phonémogramme : ꞽm"},
/* 14025 */ { "HIÉROGLYPHE ÉGYPTIEN-14025","	* classificateur chavirer : ꜥḳw"},
/* 14026 */ { "HIÉROGLYPHE ÉGYPTIEN-14026","	* phonémogramme : ꞽm"},
/* 14027 */ { "HIÉROGLYPHE ÉGYPTIEN-14027","	* classificateur amarrage : mnꞽ"},
/* 14028 */ { "HIÉROGLYPHE ÉGYPTIEN-14028","	* classificateur bateau, navire : ꞽm(w)"},
/* 14029 */ { "HIÉROGLYPHE ÉGYPTIEN-14029","	* classificateur mort : smꜣ(-tꜣ)"},
/* 1402A */ { "HIÉROGLYPHE ÉGYPTIEN-1402A",NULL},
/* 1402B */ { "HIÉROGLYPHE ÉGYPTIEN-1402B","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 1402C */ { "HIÉROGLYPHE ÉGYPTIEN-1402C",NULL},
/* 1402D */ { "HIÉROGLYPHE ÉGYPTIEN-1402D",NULL},
/* 1402E */ { "HIÉROGLYPHE ÉGYPTIEN-1402E",NULL},
/* 1402F */ { "HIÉROGLYPHE ÉGYPTIEN-1402F","	* classificateur barque, bateau : (m)skt.t"},
/* 14030 */ { "HIÉROGLYPHE ÉGYPTIEN-14030","	* classificateur barque, bateau : ꜥnḏ(.t)"},
/* 14031 */ { "HIÉROGLYPHE ÉGYPTIEN-14031","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 14032 */ { "HIÉROGLYPHE ÉGYPTIEN-14032","	* classificateur barque, bateau : nšm.t"},
/* 14033 */ { "HIÉROGLYPHE ÉGYPTIEN-14033","	* classificateur barque, bateau : (m)skt.t"},
/* 14034 */ { "HIÉROGLYPHE ÉGYPTIEN-14034","	* classificateur barque, bateau : (m)sk.t"},
/* 14035 */ { "HIÉROGLYPHE ÉGYPTIEN-14035","	* classificateur barque,bateau : mskt.t"},
/* 14036 */ { "HIÉROGLYPHE ÉGYPTIEN-14036","	* classificateur barque, bateau : ḥbꜣ"},
/* 14037 */ { "HIÉROGLYPHE ÉGYPTIEN-14037","	* classificateur flotteur en papyrus : ḥnk"},
/* 14038 */ { "HIÉROGLYPHE ÉGYPTIEN-14038","	* classificateur mouvement : ḫnt.yt"},
/* 14039 */ { "HIÉROGLYPHE ÉGYPTIEN-14039","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 1403A */ { "HIÉROGLYPHE ÉGYPTIEN-1403A","	* logogramme (barque du roi, barque royale) : wꞽꜣ-n(.y)-sw.t"},
/* 1403B */ { "HIÉROGLYPHE ÉGYPTIEN-1403B",NULL},
/* 1403C */ { "HIÉROGLYPHE ÉGYPTIEN-1403C","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 1403D */ { "HIÉROGLYPHE ÉGYPTIEN-1403D",NULL},
/* 1403E */ { "HIÉROGLYPHE ÉGYPTIEN-1403E",NULL},
/* 1403F */ { "HIÉROGLYPHE ÉGYPTIEN-1403F","	* logogramme (aller vers le sud (navigant en amont)) : ḫntꞽ"},
/* 14040 */ { "HIÉROGLYPHE ÉGYPTIEN-14040","	* classificateur navigant en amont, allant vers le sud : ḫnt(ꞽ)"},
/* 14041 */ { "HIÉROGLYPHE ÉGYPTIEN-14041","	* logogramme (aller vers le sud (navigant en amont)) : ḫntꞽ"},
/* 14042 */ { "HIÉROGLYPHE ÉGYPTIEN-14042","	* classificateur navigant en amont, allant vers le sud : ḫnt(ꞽ)"},
/* 14043 */ { "HIÉROGLYPHE ÉGYPTIEN-14043","	* classificateur bateau, navire : sꜣṯ"},
/* 14044 */ { "HIÉROGLYPHE ÉGYPTIEN-14044","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 14045 */ { "HIÉROGLYPHE ÉGYPTIEN-14045","	* classificateur barque, bateau : nšm.t"},
/* 14046 */ { "HIÉROGLYPHE ÉGYPTIEN-14046","	* logogramme/classificateur (barque, bateau) : wꞽꜣ"},
/* 14047 */ { "HIÉROGLYPHE ÉGYPTIEN-14047",NULL},
/* 14048 */ { "HIÉROGLYPHE ÉGYPTIEN-14048","	* classificateur bateau, navire : wṯs-nfr.w"},
/* 14049 */ { "HIÉROGLYPHE ÉGYPTIEN-14049","	* classificateur bateau, navire : wṯs-nfr(.w)"},
/* 1404A */ { "HIÉROGLYPHE ÉGYPTIEN-1404A",NULL},
/* 1404B */ { "HIÉROGLYPHE ÉGYPTIEN-1404B","	* classificateur bateau, navire : wṯs-nfr.w"},
/* 1404C */ { "HIÉROGLYPHE ÉGYPTIEN-1404C","	* classificateur bateau, navire : wṯs-nfr.w"},
/* 1404D */ { "HIÉROGLYPHE ÉGYPTIEN-1404D","	* logogramme (navire, bateau, barque) : wṯs-nfr.w"},
/* 1404E */ { "HIÉROGLYPHE ÉGYPTIEN-1404E","	* logogramme (navire, bateau, barque) : wꞽꜣ"},
/* 1404F */ { "HIÉROGLYPHE ÉGYPTIEN-1404F","	* logogramme (Amon-Rê) : ꞽmn-rꜥ"},
/* 14050 */ { "HIÉROGLYPHE ÉGYPTIEN-14050","	* phonémogramme : wḥꜥ"},
/* 14051 */ { "HIÉROGLYPHE ÉGYPTIEN-14051","	* logogramme : wꞽꜣ"},
/* 14052 */ { "HIÉROGLYPHE ÉGYPTIEN-14052","	* classificateur bateau, navire : (m)ꜥnḏ.t"},
/* 14053 */ { "HIÉROGLYPHE ÉGYPTIEN-14053",NULL},
/* 14054 */ { "HIÉROGLYPHE ÉGYPTIEN-14054","	* classificateur barque, bateau : (m)skt.t"},
/* 14055 */ { "HIÉROGLYPHE ÉGYPTIEN-14055",NULL},
/* 14056 */ { "HIÉROGLYPHE ÉGYPTIEN-14056","	* logogramme (barque des deux faucons divins) : nṯr.wy"},
/* 14057 */ { "HIÉROGLYPHE ÉGYPTIEN-14057","	* classificateur barque : skt.t"},
/* 14058 */ { "HIÉROGLYPHE ÉGYPTIEN-14058","	* classificateur barque : mskt.t"},
/* 14059 */ { "HIÉROGLYPHE ÉGYPTIEN-14059","	* logogramme (Sothis) : spd.t"},
/* 1405A */ { "HIÉROGLYPHE ÉGYPTIEN-1405A","	* logogramme (Orion (constellation)) : sꜣḥ"},
/* 1405B */ { "HIÉROGLYPHE ÉGYPTIEN-1405B",NULL},
/* 1405C */ { "HIÉROGLYPHE ÉGYPTIEN-1405C","	* classificateur barque : wꞽꜣ"},
/* 1405D */ { "HIÉROGLYPHE ÉGYPTIEN-1405D",NULL},
/* 1405E */ { "HIÉROGLYPHE ÉGYPTIEN-1405E","	* logogramme (protection) : gs-dp.t"},
/* 1405F */ { "HIÉROGLYPHE ÉGYPTIEN-1405F","	* logogramme (protection) : gs-dp.t"},
/* 14060 */ { "HIÉROGLYPHE ÉGYPTIEN-14060",NULL},
/* 14061 */ { "HIÉROGLYPHE ÉGYPTIEN-14061","	* phonémogramme : mnḫ.t"},
/* 14062 */ { "HIÉROGLYPHE ÉGYPTIEN-14062","	* logogramme (tissu, vêtements) : mnḫ.t"},
/* 14063 */ { "HIÉROGLYPHE ÉGYPTIEN-14063","	* logogramme (tissu, vêtements) : mnḫ.t"},
/* 14064 */ { "HIÉROGLYPHE ÉGYPTIEN-14064",NULL},
/* 14065 */ { "HIÉROGLYPHE ÉGYPTIEN-14065","	* logogramme (barque Henou de Sokar) ou phonémogramme : ḥnw | skr"},
/* 14066 */ { "HIÉROGLYPHE ÉGYPTIEN-14066","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 14067 */ { "HIÉROGLYPHE ÉGYPTIEN-14067","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 14068 */ { "HIÉROGLYPHE ÉGYPTIEN-14068","	* classificateur barque de Sokar : ḥny"},
/* 14069 */ { "HIÉROGLYPHE ÉGYPTIEN-14069","	* classificateur barque de Sokar : ḥnw"},
/* 1406A */ { "HIÉROGLYPHE ÉGYPTIEN-1406A","	* classificateur barque de Sokar : ḥnw"},
/* 1406B */ { "HIÉROGLYPHE ÉGYPTIEN-1406B","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 1406C */ { "HIÉROGLYPHE ÉGYPTIEN-1406C","	* classificateur barque de Sokar : ḥnw"},
/* 1406D */ { "HIÉROGLYPHE ÉGYPTIEN-1406D","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 1406E */ { "HIÉROGLYPHE ÉGYPTIEN-1406E","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 1406F */ { "HIÉROGLYPHE ÉGYPTIEN-1406F","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 14070 */ { "HIÉROGLYPHE ÉGYPTIEN-14070","	* logogramme (Sokar) : skr"},
/* 14071 */ { "HIÉROGLYPHE ÉGYPTIEN-14071","	* logogramme (Sokar) : skr"},
/* 14072 */ { "HIÉROGLYPHE ÉGYPTIEN-14072",NULL},
/* 14073 */ { "HIÉROGLYPHE ÉGYPTIEN-14073","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 14074 */ { "HIÉROGLYPHE ÉGYPTIEN-14074","	* logogramme (barque Henou de Sokar) : ḥnw"},
/* 14075 */ { "HIÉROGLYPHE ÉGYPTIEN-14075","	* logogramme (Sokar) : skr"},
/* 14076 */ { "HIÉROGLYPHE ÉGYPTIEN-14076","	* phonémogramme : wꜣḥ"},
/* 14077 */ { "HIÉROGLYPHE ÉGYPTIEN-14077","	* phonémogramme : wḥꜥ"},
/* 14078 */ { "HIÉROGLYPHE ÉGYPTIEN-14078","	* logogramme (détacher, expliquer) : wḥꜥ"},
/* 14079 */ { "HIÉROGLYPHE ÉGYPTIEN-14079","	* classificateur bateau, navire : mnš"},
/* 1407A */ { "HIÉROGLYPHE ÉGYPTIEN-1407A","	* classificateur bateau, navire : mnš"},
/* 1407B */ { "HIÉROGLYPHE ÉGYPTIEN-1407B",NULL},
/* 1407C */ { "HIÉROGLYPHE ÉGYPTIEN-1407C","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 1407D */ { "HIÉROGLYPHE ÉGYPTIEN-1407D","	* classificateur vent, souffle, air : mḥy.t"},
/* 1407E */ { "HIÉROGLYPHE ÉGYPTIEN-1407E","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 1407F */ { "HIÉROGLYPHE ÉGYPTIEN-1407F",NULL},
/* 14080 */ { "HIÉROGLYPHE ÉGYPTIEN-14080","	* classificateur vent, souffle, air : mꜣꜥ"},
/* 14081 */ { "HIÉROGLYPHE ÉGYPTIEN-14081","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 14082 */ { "HIÉROGLYPHE ÉGYPTIEN-14082","	* classificateur vent, souffle, air : nfw/y"},
/* 14083 */ { "HIÉROGLYPHE ÉGYPTIEN-14083",NULL},
/* 14084 */ { "HIÉROGLYPHE ÉGYPTIEN-14084","	* classificateur vent, souffle, air : ꞽwn"},
/* 14085 */ { "HIÉROGLYPHE ÉGYPTIEN-14085","	* classificateur vent, souffle, air : nfw/y"},
/* 14086 */ { "HIÉROGLYPHE ÉGYPTIEN-14086","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 14087 */ { "HIÉROGLYPHE ÉGYPTIEN-14087",NULL},
/* 14088 */ { "HIÉROGLYPHE ÉGYPTIEN-14088","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 14089 */ { "HIÉROGLYPHE ÉGYPTIEN-14089","	* classificateur vent, souffle, air : mḥy.t"},
/* 1408A */ { "HIÉROGLYPHE ÉGYPTIEN-1408A","	* logogramme (vent, souffle, air) : ṯꜣw"},
/* 1408B */ { "HIÉROGLYPHE ÉGYPTIEN-1408B","	* phonémogramme : ꜥḥꜥ"},
/* 1408C */ { "HIÉROGLYPHE ÉGYPTIEN-1408C","	* phonémogramme : ꜥḥꜥ"},
/* 1408D */ { "HIÉROGLYPHE ÉGYPTIEN-1408D","	* phonémogramme : ꜥḥꜥ"},
/* 1408E */ { "HIÉROGLYPHE ÉGYPTIEN-1408E",NULL},
/* 1408F */ { "HIÉROGLYPHE ÉGYPTIEN-1408F",NULL},
/* 14090 */ { "HIÉROGLYPHE ÉGYPTIEN-14090","	* logogramme (divinité serpent) : ꜥḥꜥ.w"},
/* 14091 */ { "HIÉROGLYPHE ÉGYPTIEN-14091",NULL},
/* 14092 */ { "HIÉROGLYPHE ÉGYPTIEN-14092",NULL},
/* 14093 */ { "HIÉROGLYPHE ÉGYPTIEN-14093","	* phonémogramme : ẖn"},
/* 14094 */ { "HIÉROGLYPHE ÉGYPTIEN-14094","	* classificateur bacs, ponts : mꜣḏw"},
/* 14095 */ { "HIÉROGLYPHE ÉGYPTIEN-14095","	* phonémogramme : ḥp"},
/* 14096 */ { "HIÉROGLYPHE ÉGYPTIEN-14096",NULL},
/* 14097 */ { "HIÉROGLYPHE ÉGYPTIEN-14097","	* phonémogramme : ḥp"},
/* 14098 */ { "HIÉROGLYPHE ÉGYPTIEN-14098",NULL},
/* 14099 */ { "HIÉROGLYPHE ÉGYPTIEN-14099","	* phonémogramme : ꜣs.t"},
/* 1409A */ { "HIÉROGLYPHE ÉGYPTIEN-1409A","	* phonémogramme : ws"},
/* 1409B */ { "HIÉROGLYPHE ÉGYPTIEN-1409B","	* phonémogramme : ḥtm"},
/* 1409C */ { "HIÉROGLYPHE ÉGYPTIEN-1409C","	* classificateur trône : ns.t"},
/* 1409D */ { "HIÉROGLYPHE ÉGYPTIEN-1409D",NULL},
/* 1409E */ { "HIÉROGLYPHE ÉGYPTIEN-1409E","	* classificateur siège, chaise, trône : ꞽsb.t"},
/* 1409F */ { "HIÉROGLYPHE ÉGYPTIEN-1409F","	* classificateur siège, chaise : ḫndw"},
/* 140A0 */ { "HIÉROGLYPHE ÉGYPTIEN-140A0","	* classificateur chaise à porteurs : spꜣ"},
/* 140A1 */ { "HIÉROGLYPHE ÉGYPTIEN-140A1","	* logogramme (siège, trône, lieu) : s.t"},
/* 140A2 */ { "HIÉROGLYPHE ÉGYPTIEN-140A2",NULL},
/* 140A3 */ { "HIÉROGLYPHE ÉGYPTIEN-140A3","	* phonémogramme : p"},
/* 140A4 */ { "HIÉROGLYPHE ÉGYPTIEN-140A4","	* classificateur chaise à porteurs : wr-ꜥ"},
/* 140A5 */ { "HIÉROGLYPHE ÉGYPTIEN-140A5","	* classificateur siège à dossier ? : pḥḏ.w"},
/* 140A6 */ { "HIÉROGLYPHE ÉGYPTIEN-140A6","	* classificateur appui-tête : wrs"},
/* 140A7 */ { "HIÉROGLYPHE ÉGYPTIEN-140A7",NULL},
/* 140A8 */ { "HIÉROGLYPHE ÉGYPTIEN-140A8","	* classificateur se reposer : sḏr"},
/* 140A9 */ { "HIÉROGLYPHE ÉGYPTIEN-140A9","	* classificateur lit incliné : gsꜣ.t"},
/* 140AA */ { "HIÉROGLYPHE ÉGYPTIEN-140AA","	* classificateur siège, chaise : ḫnd"},
/* 140AB */ { "HIÉROGLYPHE ÉGYPTIEN-140AB","	* classificateur lit : ꜣṯ.t"},
/* 140AC */ { "HIÉROGLYPHE ÉGYPTIEN-140AC","	* classificateur dormir, passer la nuit : sḏr"},
/* 140AD */ { "HIÉROGLYPHE ÉGYPTIEN-140AD","	* classificateur lit : ḥnk(.yt)"},
/* 140AE */ { "HIÉROGLYPHE ÉGYPTIEN-140AE",NULL},
/* 140AF */ { "HIÉROGLYPHE ÉGYPTIEN-140AF","	* logogramme (estrade du trône) : ṯnṯꜣ.t"},
/* 140B0 */ { "HIÉROGLYPHE ÉGYPTIEN-140B0","	* logogramme (miroir) : wn-ḥr"},
/* 140B1 */ { "HIÉROGLYPHE ÉGYPTIEN-140B1","	* classificateur miroir : mꜣw-ḥr"},
/* 140B2 */ { "HIÉROGLYPHE ÉGYPTIEN-140B2","	* classificateur boîte : hn(w)"},
/* 140B3 */ { "HIÉROGLYPHE ÉGYPTIEN-140B3","	* logogramme (exigences, besoins) : dbḥ.w"},
/* 140B4 */ { "HIÉROGLYPHE ÉGYPTIEN-140B4","	* logogramme (exigences, besoins) : dbḥ.w"},
/* 140B5 */ { "HIÉROGLYPHE ÉGYPTIEN-140B5","	* logogramme (exigences, besoins) : dbḥ.w"},
/* 140B6 */ { "HIÉROGLYPHE ÉGYPTIEN-140B6","	* classificateur boîte, coffre : mr.t"},
/* 140B7 */ { "HIÉROGLYPHE ÉGYPTIEN-140B7","	* logogramme (boîte, coffre) : mr.t"},
/* 140B8 */ { "HIÉROGLYPHE ÉGYPTIEN-140B8","	* classificateur table d'offrandes : ꜥbꜣ"},
/* 140B9 */ { "HIÉROGLYPHE ÉGYPTIEN-140B9","	* classificateur sanctuaire, chapelle : kꜣr"},
/* 140BA */ { "HIÉROGLYPHE ÉGYPTIEN-140BA","	* classificateur élever : ṯs"},
/* 140BB */ { "HIÉROGLYPHE ÉGYPTIEN-140BB","	* classificateur enterrer : ḳrs"},
/* 140BC */ { "HIÉROGLYPHE ÉGYPTIEN-140BC","	* classificateur enterrement : ḳrs.t"},
/* 140BD */ { "HIÉROGLYPHE ÉGYPTIEN-140BD","	* classificateur boîte : hn(w)"},
/* 140BE */ { "HIÉROGLYPHE ÉGYPTIEN-140BE",NULL},
/* 140BF */ { "HIÉROGLYPHE ÉGYPTIEN-140BF","	* logogramme (Crocodilopolis) : Šd.t"},
/* 140C0 */ { "HIÉROGLYPHE ÉGYPTIEN-140C0",NULL},
/* 140C1 */ { "HIÉROGLYPHE ÉGYPTIEN-140C1","	* classificateur enterrement : ḳrs"},
/* 140C2 */ { "HIÉROGLYPHE ÉGYPTIEN-140C2","	* classificateur cercueil : ḳrs.w"},
/* 140C3 */ { "HIÉROGLYPHE ÉGYPTIEN-140C3","	* classificateur enterrement : ḳrs"},
/* 140C4 */ { "HIÉROGLYPHE ÉGYPTIEN-140C4","	* logogramme (lier) : mḏḥ"},
/* 140C5 */ { "HIÉROGLYPHE ÉGYPTIEN-140C5","	* classificateur enterrement : ḳrs"},
/* 140C6 */ { "HIÉROGLYPHE ÉGYPTIEN-140C6","	* logogramme (température, tempérament) : srf"},
/* 140C7 */ { "HIÉROGLYPHE ÉGYPTIEN-140C7","	* logogramme (feu) : nsrsr"},
/* 140C8 */ { "HIÉROGLYPHE ÉGYPTIEN-140C8","	* classificateur action liée au feu : nbꞽ"},
/* 140C9 */ { "HIÉROGLYPHE ÉGYPTIEN-140C9",NULL},
/* 140CA */ { "HIÉROGLYPHE ÉGYPTIEN-140CA","	* classificateur brasero : ꜥḫ"},
/* 140CB */ { "HIÉROGLYPHE ÉGYPTIEN-140CB","	* classificateur fête de la combustion : rkḥ"},
/* 140CC */ { "HIÉROGLYPHE ÉGYPTIEN-140CC","	* classificateur pierres de foyer : kt.ꞽt"},
/* 140CD */ { "HIÉROGLYPHE ÉGYPTIEN-140CD","	* classificateur pierres de foyer : kt.ꞽt"},
/* 140CE */ { "HIÉROGLYPHE ÉGYPTIEN-140CE","	* classificateur échelle : mꜣḳ.t"},
/* 140CF */ { "HIÉROGLYPHE ÉGYPTIEN-140CF","	* classificateur autel : ḫꜣ(w).t"},
/* 140D0 */ { "HIÉROGLYPHE ÉGYPTIEN-140D0","	* logogramme (autel) : ḫꜣw.t"},
/* 140D1 */ { "HIÉROGLYPHE ÉGYPTIEN-140D1",NULL},
/* 140D2 */ { "HIÉROGLYPHE ÉGYPTIEN-140D2",NULL},
/* 140D3 */ { "HIÉROGLYPHE ÉGYPTIEN-140D3",NULL},
/* 140D4 */ { "HIÉROGLYPHE ÉGYPTIEN-140D4",NULL},
/* 140D5 */ { "HIÉROGLYPHE ÉGYPTIEN-140D5",NULL},
/* 140D6 */ { "HIÉROGLYPHE ÉGYPTIEN-140D6","	* classificateur provisions, approvisionnements : wꜣg"},
/* 140D7 */ { "HIÉROGLYPHE ÉGYPTIEN-140D7",NULL},
/* 140D8 */ { "HIÉROGLYPHE ÉGYPTIEN-140D8","	* classificateur table : ṯ.t"},
/* 140D9 */ { "HIÉROGLYPHE ÉGYPTIEN-140D9",NULL},
/* 140DA */ { "HIÉROGLYPHE ÉGYPTIEN-140DA","	* classificateur table : ṯ.t"},
/* 140DB */ { "HIÉROGLYPHE ÉGYPTIEN-140DB","	* classificateur table : ṯ.t"},
/* 140DC */ { "HIÉROGLYPHE ÉGYPTIEN-140DC","	* classificateur table : ṯ.t"},
/* 140DD */ { "HIÉROGLYPHE ÉGYPTIEN-140DD","	* classificateur table : ṯ.t"},
/* 140DE */ { "HIÉROGLYPHE ÉGYPTIEN-140DE","	* classificateur table : ṯ.t"},
/* 140DF */ { "HIÉROGLYPHE ÉGYPTIEN-140DF",NULL},
/* 140E0 */ { "HIÉROGLYPHE ÉGYPTIEN-140E0",NULL},
/* 140E1 */ { "HIÉROGLYPHE ÉGYPTIEN-140E1","	* classificateur autel : wḏḥ.w"},
/* 140E2 */ { "HIÉROGLYPHE ÉGYPTIEN-140E2","	* classificateur table d'offrandes : ḥtp"},
/* 140E3 */ { "HIÉROGLYPHE ÉGYPTIEN-140E3","	* classificateur autel, table d'offrandes : wdḥ.w"},
/* 140E4 */ { "HIÉROGLYPHE ÉGYPTIEN-140E4","	* logogramme (autel des offrandes) : wdḥ.w"},
/* 140E5 */ { "HIÉROGLYPHE ÉGYPTIEN-140E5","	* logogramme (support de jarre, buffet) : ḫnt"},
/* 140E6 */ { "HIÉROGLYPHE ÉGYPTIEN-140E6","	* logogramme (offrandes) : ḥtp(.w)"},
/* 140E7 */ { "HIÉROGLYPHE ÉGYPTIEN-140E7","	* classificateur autel : ḫꜣw(.t)"},
/* 140E8 */ { "HIÉROGLYPHE ÉGYPTIEN-140E8",NULL},
/* 140E9 */ { "HIÉROGLYPHE ÉGYPTIEN-140E9",NULL},
/* 140EA */ { "HIÉROGLYPHE ÉGYPTIEN-140EA","	* classificateur autel : ḫꜣw.t"},
/* 140EB */ { "HIÉROGLYPHE ÉGYPTIEN-140EB",NULL},
/* 140EC */ { "HIÉROGLYPHE ÉGYPTIEN-140EC","	* logogramme (autel) : ḫꜣw.t"},
/* 140ED */ { "HIÉROGLYPHE ÉGYPTIEN-140ED","	* logogramme (autel) : ḫꜣw.t"},
/* 140EE */ { "HIÉROGLYPHE ÉGYPTIEN-140EE","	* classificateur autel : ḳdf"},
/* 140EF */ { "HIÉROGLYPHE ÉGYPTIEN-140EF","	* logogramme (autel) : ḫꜣw.t"},
/* 140F0 */ { "HIÉROGLYPHE ÉGYPTIEN-140F0","	* classificateur autel : ḳdf"},
/* 140F1 */ { "HIÉROGLYPHE ÉGYPTIEN-140F1","	* logogramme (autel) : ḫꜣw.t"},
/* 140F2 */ { "HIÉROGLYPHE ÉGYPTIEN-140F2",NULL},
/* 140F3 */ { "HIÉROGLYPHE ÉGYPTIEN-140F3","	* classificateur fumigation, encensement : kꜣp"},
/* 140F4 */ { "HIÉROGLYPHE ÉGYPTIEN-140F4","	* classificateur feu d'encens : snṯr-sḏ.t"},
/* 140F5 */ { "HIÉROGLYPHE ÉGYPTIEN-140F5",NULL},
/* 140F6 */ { "HIÉROGLYPHE ÉGYPTIEN-140F6","	* phonémogramme/logogramme (satisfaire) : (s)ḥtp"},
/* 140F7 */ { "HIÉROGLYPHE ÉGYPTIEN-140F7",NULL},
/* 140F8 */ { "HIÉROGLYPHE ÉGYPTIEN-140F8",NULL},
/* 140F9 */ { "HIÉROGLYPHE ÉGYPTIEN-140F9","	* logogramme (encens) : snṯr"},
/* 140FA */ { "HIÉROGLYPHE ÉGYPTIEN-140FA",NULL},
/* 140FB */ { "HIÉROGLYPHE ÉGYPTIEN-140FB",NULL},
/* 140FC */ { "HIÉROGLYPHE ÉGYPTIEN-140FC","	* logogramme (dieux) : nṯr.w"},
/* 140FD */ { "HIÉROGLYPHE ÉGYPTIEN-140FD","	* logogramme (tous les dieux) : nṯr.w-nb.w"},
/* 140FE */ { "HIÉROGLYPHE ÉGYPTIEN-140FE","	* logogramme (Ennéade) : psḏ.t"},
/* 140FF */ { "HIÉROGLYPHE ÉGYPTIEN-140FF","	* logogramme (dieu et déesse) : nṯr-nṯr.t"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_41[] = {
/* 14100 */ { "HIÉROGLYPHE ÉGYPTIEN-14100","	* logogramme (dieux et déesses) : nṯr.w-nṯr.wt"},
/* 14101 */ { "HIÉROGLYPHE ÉGYPTIEN-14101","	* logogramme (dieux et déesses) : nṯr.w-nṯr.wt"},
/* 14102 */ { "HIÉROGLYPHE ÉGYPTIEN-14102","	* logogramme (dieu et déesse) : nṯr-nṯr.t"},
/* 14103 */ { "HIÉROGLYPHE ÉGYPTIEN-14103",NULL},
/* 14104 */ { "HIÉROGLYPHE ÉGYPTIEN-14104","	* logogramme (natron) : ḥsmn"},
/* 14105 */ { "HIÉROGLYPHE ÉGYPTIEN-14105","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 14106 */ { "HIÉROGLYPHE ÉGYPTIEN-14106","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 14107 */ { "HIÉROGLYPHE ÉGYPTIEN-14107","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 14108 */ { "HIÉROGLYPHE ÉGYPTIEN-14108",NULL},
/* 14109 */ { "HIÉROGLYPHE ÉGYPTIEN-14109","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 1410A */ { "HIÉROGLYPHE ÉGYPTIEN-1410A","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 1410B */ { "HIÉROGLYPHE ÉGYPTIEN-1410B","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 1410C */ { "HIÉROGLYPHE ÉGYPTIEN-1410C","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 1410D */ { "HIÉROGLYPHE ÉGYPTIEN-1410D","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 1410E */ { "HIÉROGLYPHE ÉGYPTIEN-1410E","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 1410F */ { "HIÉROGLYPHE ÉGYPTIEN-1410F",NULL},
/* 14110 */ { "HIÉROGLYPHE ÉGYPTIEN-14110","	* logogramme (nécropole) : ẖr.t-nṯr"},
/* 14111 */ { "HIÉROGLYPHE ÉGYPTIEN-14111","	* logogramme (nome du Faucon aux ailes déployées, 18e nome de Haute-Égypte) : nmt.y"},
/* 14112 */ { "HIÉROGLYPHE ÉGYPTIEN-14112","	* phonémogramme : ḏd-kꜣ-ꞽmn"},
/* 14113 */ { "HIÉROGLYPHE ÉGYPTIEN-14113","	* phonémogramme : psḏ"},
/* 14114 */ { "HIÉROGLYPHE ÉGYPTIEN-14114","	* phonémogramme : ḏd"},
/* 14115 */ { "HIÉROGLYPHE ÉGYPTIEN-14115","	* classificateur étendard : ꞽꜣ.t"},
/* 14116 */ { "HIÉROGLYPHE ÉGYPTIEN-14116","	* classificateur poteau : snw.t"},
/* 14117 */ { "HIÉROGLYPHE ÉGYPTIEN-14117","	* logogramme (étendard) : ꞽꜣ.t"},
/* 14118 */ { "HIÉROGLYPHE ÉGYPTIEN-14118","	* classificateur étendard : ꞽꜣ.t"},
/* 14119 */ { "HIÉROGLYPHE ÉGYPTIEN-14119","	* classificateur miroir : ꜥnḫ"},
/* 1411A */ { "HIÉROGLYPHE ÉGYPTIEN-1411A",NULL},
/* 1411B */ { "HIÉROGLYPHE ÉGYPTIEN-1411B","	* logogramme (Douaou (divinité)) : dwꜣ.w"},
/* 1411C */ { "HIÉROGLYPHE ÉGYPTIEN-1411C","	* logogramme (Sothis) ou logogramme (le plus à l'est) : spd.t | ẖn.ty ꞽꜣb.t"},
/* 1411D */ { "HIÉROGLYPHE ÉGYPTIEN-1411D","	* logogramme (Douaou (divinité)) : dwꜣ.w"},
/* 1411E */ { "HIÉROGLYPHE ÉGYPTIEN-1411E","	* logogramme (bordure, frontière) : ṯnw"},
/* 1411F */ { "HIÉROGLYPHE ÉGYPTIEN-1411F","	* logogramme (ouest) : ꞽmn.t"},
/* 14120 */ { "HIÉROGLYPHE ÉGYPTIEN-14120","	* logogramme (ouest) : ꞽmn.t"},
/* 14121 */ { "HIÉROGLYPHE ÉGYPTIEN-14121","	* logogramme (droite, côté droit) : wnm.y"},
/* 14122 */ { "HIÉROGLYPHE ÉGYPTIEN-14122","	* logogramme (ouest) : ꞽmn.t"},
/* 14123 */ { "HIÉROGLYPHE ÉGYPTIEN-14123",NULL},
/* 14124 */ { "HIÉROGLYPHE ÉGYPTIEN-14124","	* logogramme (ouest) : ꞽmn.t"},
/* 14125 */ { "HIÉROGLYPHE ÉGYPTIEN-14125",NULL},
/* 14126 */ { "HIÉROGLYPHE ÉGYPTIEN-14126","	* logogramme (ouest) : ꞽmn.t"},
/* 14127 */ { "HIÉROGLYPHE ÉGYPTIEN-14127",NULL},
/* 14128 */ { "HIÉROGLYPHE ÉGYPTIEN-14128","	* phonémogramme : ꜣb"},
/* 14129 */ { "HIÉROGLYPHE ÉGYPTIEN-14129","	* logogramme (est) : ꞽꜣb.t"},
/* 1412A */ { "HIÉROGLYPHE ÉGYPTIEN-1412A","	* radicogramme (œil gauche) : ꞽꜣb.t"},
/* 1412B */ { "HIÉROGLYPHE ÉGYPTIEN-1412B","	* logogramme (est) : ꞽꜣb.t"},
/* 1412C */ { "HIÉROGLYPHE ÉGYPTIEN-1412C","	* logogramme (est) : ꞽꜣb.t"},
/* 1412D */ { "HIÉROGLYPHE ÉGYPTIEN-1412D","	* logogramme (est) : ꞽꜣb.t"},
/* 1412E */ { "HIÉROGLYPHE ÉGYPTIEN-1412E",NULL},
/* 1412F */ { "HIÉROGLYPHE ÉGYPTIEN-1412F","	* logogramme (est) : ꞽꜣb.t"},
/* 14130 */ { "HIÉROGLYPHE ÉGYPTIEN-14130",NULL},
/* 14131 */ { "HIÉROGLYPHE ÉGYPTIEN-14131","	* phonémogramme : ꞽꜣb"},
/* 14132 */ { "HIÉROGLYPHE ÉGYPTIEN-14132","	* radicogramme (œil gauche) : ꞽꜣb.t"},
/* 14133 */ { "HIÉROGLYPHE ÉGYPTIEN-14133",NULL},
/* 14134 */ { "HIÉROGLYPHE ÉGYPTIEN-14134",NULL},
/* 14135 */ { "HIÉROGLYPHE ÉGYPTIEN-14135",NULL},
/* 14136 */ { "HIÉROGLYPHE ÉGYPTIEN-14136","	* logogramme (nome de la Grande Terre, 8e nome de Haute-Égypte) : tꜣ-wr"},
/* 14137 */ { "HIÉROGLYPHE ÉGYPTIEN-14137","	* logogramme (nome de la Grande Terre, 8e nome de Haute-Égypte) : tꜣ-wr"},
/* 14138 */ { "HIÉROGLYPHE ÉGYPTIEN-14138","	* logogramme (Abydos) : ꜣbḏw"},
/* 14139 */ { "HIÉROGLYPHE ÉGYPTIEN-14139",NULL},
/* 1413A */ { "HIÉROGLYPHE ÉGYPTIEN-1413A","	* logogramme (Abydos) : ꜣbḏw"},
/* 1413B */ { "HIÉROGLYPHE ÉGYPTIEN-1413B","	* logogramme (Abydos) : ꜣbḏw"},
/* 1413C */ { "HIÉROGLYPHE ÉGYPTIEN-1413C","	* logogramme (Abydos) : ꜣbḏw"},
/* 1413D */ { "HIÉROGLYPHE ÉGYPTIEN-1413D",NULL},
/* 1413E */ { "HIÉROGLYPHE ÉGYPTIEN-1413E","	* phonémogramme : nfr"},
/* 1413F */ { "HIÉROGLYPHE ÉGYPTIEN-1413F","	* logogramme (Néfertoum) : nfr-tm"},
/* 14140 */ { "HIÉROGLYPHE ÉGYPTIEN-14140","	* logogramme (Néfertoum) : nfr-tm"},
/* 14141 */ { "HIÉROGLYPHE ÉGYPTIEN-14141","	* logogramme (Thèbes) : wꜣs.t"},
/* 14142 */ { "HIÉROGLYPHE ÉGYPTIEN-14142","	* logogramme (Thèbes) : wꜣs.t"},
/* 14143 */ { "HIÉROGLYPHE ÉGYPTIEN-14143",NULL},
/* 14144 */ { "HIÉROGLYPHE ÉGYPTIEN-14144","	* logogramme (Séchat (divinité)) : sšꜣ.t"},
/* 14145 */ { "HIÉROGLYPHE ÉGYPTIEN-14145","	* logogramme (Létopolis) : ḫm"},
/* 14146 */ { "HIÉROGLYPHE ÉGYPTIEN-14146",NULL},
/* 14147 */ { "HIÉROGLYPHE ÉGYPTIEN-14147","	* logogramme (Min (divinité)) : mnw"},
/* 14148 */ { "HIÉROGLYPHE ÉGYPTIEN-14148","	* classificateur porte-documents : mks"},
/* 14149 */ { "HIÉROGLYPHE ÉGYPTIEN-14149","	* logogramme/classificateur (celui de Chédyt (c'est-à-dire Sobek)) : šd.ty"},
/* 1414A */ { "HIÉROGLYPHE ÉGYPTIEN-1414A",NULL},
/* 1414B */ { "HIÉROGLYPHE ÉGYPTIEN-1414B",NULL},
/* 1414C */ { "HIÉROGLYPHE ÉGYPTIEN-1414C","	* classificateur base, piédestal, socle (d'un sanctuaire) : ḏbꜣ.t"},
/* 1414D */ { "HIÉROGLYPHE ÉGYPTIEN-1414D","	* classificateur couronne : ḥḏ.t"},
/* 1414E */ { "HIÉROGLYPHE ÉGYPTIEN-1414E","	* logogramme (la couronne blanche) : ḥḏ.t"},
/* 1414F */ { "HIÉROGLYPHE ÉGYPTIEN-1414F","	* logogramme (porteur de l'écharpe (prêtre)) : ꜥrḳ-ꞽns"},
/* 14150 */ { "HIÉROGLYPHE ÉGYPTIEN-14150","	* logogramme (la couronne blanche) : wrr.t"},
/* 14151 */ { "HIÉROGLYPHE ÉGYPTIEN-14151","	* logogramme (Taténen (divinité)) : tꜣ-ṯnn"},
/* 14152 */ { "HIÉROGLYPHE ÉGYPTIEN-14152","	* logogramme (Babi (divinité)) : bꜣby"},
/* 14153 */ { "HIÉROGLYPHE ÉGYPTIEN-14153","	* logogramme (Haute-Égypte) : šmꜥ.w"},
/* 14154 */ { "HIÉROGLYPHE ÉGYPTIEN-14154","	* classificateur couronne : wrr.t"},
/* 14155 */ { "HIÉROGLYPHE ÉGYPTIEN-14155","	* classificateur couronne : wrr.t"},
/* 14156 */ { "HIÉROGLYPHE ÉGYPTIEN-14156","	* logogramme (être divin) : nṯrꞽ"},
/* 14157 */ { "HIÉROGLYPHE ÉGYPTIEN-14157","	* logogramme (Basse-Égypte) : mḥ.w"},
/* 14158 */ { "HIÉROGLYPHE ÉGYPTIEN-14158","	* classificateur couronne : dšr.t/n.t"},
/* 14159 */ { "HIÉROGLYPHE ÉGYPTIEN-14159","	* phonémogramme : wnn"},
/* 1415A */ { "HIÉROGLYPHE ÉGYPTIEN-1415A","	* classificateur la couronne rouge : dšr.t"},
/* 1415B */ { "HIÉROGLYPHE ÉGYPTIEN-1415B","	* classificateur couronne double : sḫm.ty"},
/* 1415C */ { "HIÉROGLYPHE ÉGYPTIEN-1415C","	* logogramme (casque, couronne) : mḏꜣ.t"},
/* 1415D */ { "HIÉROGLYPHE ÉGYPTIEN-1415D","	* logogramme/phonémogramme (charpentier) : mḏḥw"},
/* 1415E */ { "HIÉROGLYPHE ÉGYPTIEN-1415E","	* phonémogramme : k"},
/* 1415F */ { "HIÉROGLYPHE ÉGYPTIEN-1415F","	* phonémogramme : k"},
/* 14160 */ { "HIÉROGLYPHE ÉGYPTIEN-14160","	* classificateur turban : ꜥfn(.t)"},
/* 14161 */ { "HIÉROGLYPHE ÉGYPTIEN-14161","	* classificateur turban : ꞽbs"},
/* 14162 */ { "HIÉROGLYPHE ÉGYPTIEN-14162","	* classificateur turban : ꜥfn.t"},
/* 14163 */ { "HIÉROGLYPHE ÉGYPTIEN-14163",NULL},
/* 14164 */ { "HIÉROGLYPHE ÉGYPTIEN-14164","	* logogramme (lier, enrouler) : mḏḥ"},
/* 14165 */ { "HIÉROGLYPHE ÉGYPTIEN-14165","	* logogramme (lier, enrouler) : mḏḥ"},
/* 14166 */ { "HIÉROGLYPHE ÉGYPTIEN-14166","	* classificateur couronne : ḫꜥ.w"},
/* 14167 */ { "HIÉROGLYPHE ÉGYPTIEN-14167",NULL},
/* 14168 */ { "HIÉROGLYPHE ÉGYPTIEN-14168","	* logogramme (couronne Atef) : ꜣtf"},
/* 14169 */ { "HIÉROGLYPHE ÉGYPTIEN-14169","	* logogramme (couronne Atef) : ꜣtf"},
/* 1416A */ { "HIÉROGLYPHE ÉGYPTIEN-1416A",NULL},
/* 1416B */ { "HIÉROGLYPHE ÉGYPTIEN-1416B","	* logogramme (couronne Hemhem) : hmhm"},
/* 1416C */ { "HIÉROGLYPHE ÉGYPTIEN-1416C","	* logogramme (couronne Hemhem) : hmhm"},
/* 1416D */ { "HIÉROGLYPHE ÉGYPTIEN-1416D","	* logogramme (couronne Hemhem) : hmhm"},
/* 1416E */ { "HIÉROGLYPHE ÉGYPTIEN-1416E","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 1416F */ { "HIÉROGLYPHE ÉGYPTIEN-1416F","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 14170 */ { "HIÉROGLYPHE ÉGYPTIEN-14170","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 14171 */ { "HIÉROGLYPHE ÉGYPTIEN-14171",NULL},
/* 14172 */ { "HIÉROGLYPHE ÉGYPTIEN-14172",NULL},
/* 14173 */ { "HIÉROGLYPHE ÉGYPTIEN-14173","	* logogramme (la couronne à quatre plumes) : ?"},
/* 14174 */ { "HIÉROGLYPHE ÉGYPTIEN-14174","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 14175 */ { "HIÉROGLYPHE ÉGYPTIEN-14175","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 14176 */ { "HIÉROGLYPHE ÉGYPTIEN-14176","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 14177 */ { "HIÉROGLYPHE ÉGYPTIEN-14177","	* logogramme (double-plume, couronne à deux plumes) : šw.ty"},
/* 14178 */ { "HIÉROGLYPHE ÉGYPTIEN-14178","	* phonémogramme : ṯn"},
/* 14179 */ { "HIÉROGLYPHE ÉGYPTIEN-14179","	* logogramme (El Kab) : Nḫb"},
/* 1417A */ { "HIÉROGLYPHE ÉGYPTIEN-1417A","	* phonémogramme : ṯn"},
/* 1417B */ { "HIÉROGLYPHE ÉGYPTIEN-1417B","	* classificateur couronne : ḥp.t"},
/* 1417C */ { "HIÉROGLYPHE ÉGYPTIEN-1417C","	* phonémogramme : ṯn"},
/* 1417D */ { "HIÉROGLYPHE ÉGYPTIEN-1417D","	* logogramme (nome de la Forteresse, 3e nome de Haute-Égypte) : nḫn"},
/* 1417E */ { "HIÉROGLYPHE ÉGYPTIEN-1417E","	* classificateur deux moitiés : p(s)š.ty"},
/* 1417F */ { "HIÉROGLYPHE ÉGYPTIEN-1417F","	* phonémogramme : ṯn"},
/* 14180 */ { "HIÉROGLYPHE ÉGYPTIEN-14180","	* logogramme (l'horizon) : ꜣḫ.t"},
/* 14181 */ { "HIÉROGLYPHE ÉGYPTIEN-14181","	* logogramme (qui s'avance depuis l'horizon) : pr-m-ꜣḫ.t"},
/* 14182 */ { "HIÉROGLYPHE ÉGYPTIEN-14182","	* logogramme (couronne de fleurs, guirlande) : mꜣḥ"},
/* 14183 */ { "HIÉROGLYPHE ÉGYPTIEN-14183","	* logogramme (couronne de fleurs, guirlande) : mꜣḥ"},
/* 14184 */ { "HIÉROGLYPHE ÉGYPTIEN-14184","	* logogramme (couronne de fleurs, guirlande) : mꜣḥ"},
/* 14185 */ { "HIÉROGLYPHE ÉGYPTIEN-14185","	* logogramme (couronne de fleurs, guirlande) : mꜣḥ"},
/* 14186 */ { "HIÉROGLYPHE ÉGYPTIEN-14186","	* logogramme (couronne de fleurs, guirlande) : mꜣḥ"},
/* 14187 */ { "HIÉROGLYPHE ÉGYPTIEN-14187","	* classificateur collier : wsḫ"},
/* 14188 */ { "HIÉROGLYPHE ÉGYPTIEN-14188",NULL},
/* 14189 */ { "HIÉROGLYPHE ÉGYPTIEN-14189","	* classificateur collier : bb"},
/* 1418A */ { "HIÉROGLYPHE ÉGYPTIEN-1418A","	* classificateur collier : bb.t"},
/* 1418B */ { "HIÉROGLYPHE ÉGYPTIEN-1418B","	* classificateur collier : bb"},
/* 1418C */ { "HIÉROGLYPHE ÉGYPTIEN-1418C","	* logogramme (collier) : bb"},
/* 1418D */ { "HIÉROGLYPHE ÉGYPTIEN-1418D","	* classificateur collier : bb"},
/* 1418E */ { "HIÉROGLYPHE ÉGYPTIEN-1418E","	* classificateur collier : bb"},
/* 1418F */ { "HIÉROGLYPHE ÉGYPTIEN-1418F",NULL},
/* 14190 */ { "HIÉROGLYPHE ÉGYPTIEN-14190","	* logogramme (collier, pectoral) : wsḫ"},
/* 14191 */ { "HIÉROGLYPHE ÉGYPTIEN-14191","	* logogramme (collier, pectoral) : wsḫ"},
/* 14192 */ { "HIÉROGLYPHE ÉGYPTIEN-14192","	* classificateur récipient (vases jumeaux pour la myrrhe) : rrm"},
/* 14193 */ { "HIÉROGLYPHE ÉGYPTIEN-14193",NULL},
/* 14194 */ { "HIÉROGLYPHE ÉGYPTIEN-14194","	* classificateur couronne de fleurs, guirlande : m(ꜣ)ḥ"},
/* 14195 */ { "HIÉROGLYPHE ÉGYPTIEN-14195","	* logogramme (collier) : nb"},
/* 14196 */ { "HIÉROGLYPHE ÉGYPTIEN-14196","	* logogramme (être lumineux) : ṯḥn"},
/* 14197 */ { "HIÉROGLYPHE ÉGYPTIEN-14197","	* logogramme (être lumineux) ou classificateur rosée, parfum, pluie : ṯḥn | ꞽꜣd.t"},
/* 14198 */ { "HIÉROGLYPHE ÉGYPTIEN-14198",NULL},
/* 14199 */ { "HIÉROGLYPHE ÉGYPTIEN-14199","	* logogramme (luminosité) : ṯḥn"},
/* 1419A */ { "HIÉROGLYPHE ÉGYPTIEN-1419A","	* logogramme (être lumineux) : ṯḥn"},
/* 1419B */ { "HIÉROGLYPHE ÉGYPTIEN-1419B",NULL},
/* 1419C */ { "HIÉROGLYPHE ÉGYPTIEN-1419C","	* logogramme (être lumineux) : ṯḥn"},
/* 1419D */ { "HIÉROGLYPHE ÉGYPTIEN-1419D","	* logogramme (faïence) : ṯḥn.t"},
/* 1419E */ { "HIÉROGLYPHE ÉGYPTIEN-1419E","	* classificateur lieu, divinité : šsm.t"},
/* 1419F */ { "HIÉROGLYPHE ÉGYPTIEN-1419F","	* logogramme (collier ménat) : mnꞽ.t"},
/* 141A0 */ { "HIÉROGLYPHE ÉGYPTIEN-141A0",NULL},
/* 141A1 */ { "HIÉROGLYPHE ÉGYPTIEN-141A1","	* logogramme (collier ménat) : mnꞽ.t"},
/* 141A2 */ { "HIÉROGLYPHE ÉGYPTIEN-141A2","	* classificateur collier : mnꞽ.t"},
/* 141A3 */ { "HIÉROGLYPHE ÉGYPTIEN-141A3",NULL},
/* 141A4 */ { "HIÉROGLYPHE ÉGYPTIEN-141A4","	* classificateur pectoral : ꜣw(.t)-ꞽb"},
/* 141A5 */ { "HIÉROGLYPHE ÉGYPTIEN-141A5","	* classificateur amulette : wḏꜣ(.w)"},
/* 141A6 */ { "HIÉROGLYPHE ÉGYPTIEN-141A6","	* classificateur amulette : wḏꜣ(.w)"},
/* 141A7 */ { "HIÉROGLYPHE ÉGYPTIEN-141A7","	* classificateur amulette (logogramme dans la ligne 3) ? : wḏꜣ.w"},
/* 141A8 */ { "HIÉROGLYPHE ÉGYPTIEN-141A8","	* phonémogramme : ḫtm"},
/* 141A9 */ { "HIÉROGLYPHE ÉGYPTIEN-141A9","	* phonémogramme : sꜥḥ"},
/* 141AA */ { "HIÉROGLYPHE ÉGYPTIEN-141AA","	* phonémogramme : st"},
/* 141AB */ { "HIÉROGLYPHE ÉGYPTIEN-141AB","	* phonémogramme : st"},
/* 141AC */ { "HIÉROGLYPHE ÉGYPTIEN-141AC","	* classificateur tissu, vêtement : nfr.t"},
/* 141AD */ { "HIÉROGLYPHE ÉGYPTIEN-141AD","	* classificateur bracelet, chevillère : mnf(r).ty"},
/* 141AE */ { "HIÉROGLYPHE ÉGYPTIEN-141AE",NULL},
/* 141AF */ { "HIÉROGLYPHE ÉGYPTIEN-141AF","	* logogramme (jupe, tablier royal) : šnḏ.wt"},
/* 141B0 */ { "HIÉROGLYPHE ÉGYPTIEN-141B0","	* classificateur vêtement : nṯstn"},
/* 141B1 */ { "HIÉROGLYPHE ÉGYPTIEN-141B1","	* logogramme (vêtements) : mnḫ.t"},
/* 141B2 */ { "HIÉROGLYPHE ÉGYPTIEN-141B2","	* classificateur tissu : šsr.w"},
/* 141B3 */ { "HIÉROGLYPHE ÉGYPTIEN-141B3","	* logogramme (vêtements) : mnḫ.t"},
/* 141B4 */ { "HIÉROGLYPHE ÉGYPTIEN-141B4","	* logogramme (vêtements) : mnḫ.t"},
/* 141B5 */ { "HIÉROGLYPHE ÉGYPTIEN-141B5","	* classificateur tissu : šsr.w"},
/* 141B6 */ { "HIÉROGLYPHE ÉGYPTIEN-141B6","	* logogramme (lin à six fils) : sꜽs"},
/* 141B7 */ { "HIÉROGLYPHE ÉGYPTIEN-141B7","	* logogramme (lin) : sšr"},
/* 141B8 */ { "HIÉROGLYPHE ÉGYPTIEN-141B8","	* phonémogramme : dr"},
/* 141B9 */ { "HIÉROGLYPHE ÉGYPTIEN-141B9","	* classificateur vêtements : ḥbs"},
/* 141BA */ { "HIÉROGLYPHE ÉGYPTIEN-141BA","	* phonémogramme : sšm"},
/* 141BB */ { "HIÉROGLYPHE ÉGYPTIEN-141BB",NULL},
/* 141BC */ { "HIÉROGLYPHE ÉGYPTIEN-141BC",NULL},
/* 141BD */ { "HIÉROGLYPHE ÉGYPTIEN-141BD","	* phonémogramme : sšm"},
/* 141BE */ { "HIÉROGLYPHE ÉGYPTIEN-141BE","	* phonémogramme : sšm"},
/* 141BF */ { "HIÉROGLYPHE ÉGYPTIEN-141BF","	* phonémogramme : s"},
/* 141C0 */ { "HIÉROGLYPHE ÉGYPTIEN-141C0","	* phonémogramme : s"},
/* 141C1 */ { "HIÉROGLYPHE ÉGYPTIEN-141C1","	* phonémogramme : sꞽꜣ"},
/* 141C2 */ { "HIÉROGLYPHE ÉGYPTIEN-141C2","	* classificateur tissu : sšr"},
/* 141C3 */ { "HIÉROGLYPHE ÉGYPTIEN-141C3","	* classificateur tissu : npnp.t"},
/* 141C4 */ { "HIÉROGLYPHE ÉGYPTIEN-141C4",NULL},
/* 141C5 */ { "HIÉROGLYPHE ÉGYPTIEN-141C5","	* classificateur temps : nḥḥ"},
/* 141C6 */ { "HIÉROGLYPHE ÉGYPTIEN-141C6","	* classificateur vase en forme d'ânkh : ꜥnḫ"},
/* 141C7 */ { "HIÉROGLYPHE ÉGYPTIEN-141C7","	* logogramme (stabilité et vie) : ḏd-ꜥnḫ"},
/* 141C8 */ { "HIÉROGLYPHE ÉGYPTIEN-141C8","	* logogramme (toute vie, stabilité et domination) : ꜥnḫ-ḏd-wꜣs-nb"},
/* 141C9 */ { "HIÉROGLYPHE ÉGYPTIEN-141C9","	* logogramme (toute vie et domination) : ꜥnḫ-wꜣs-nb"},
/* 141CA */ { "HIÉROGLYPHE ÉGYPTIEN-141CA",NULL},
/* 141CB */ { "HIÉROGLYPHE ÉGYPTIEN-141CB","	* phonémogramme : ḥb"},
/* 141CC */ { "HIÉROGLYPHE ÉGYPTIEN-141CC","	* logogramme (ombre, ombrage) : šw.t"},
/* 141CD */ { "HIÉROGLYPHE ÉGYPTIEN-141CD","	* phono-répéteur/classificateur dans ḥp.ty (limites extrêmes) : ḥp"},
/* 141CE */ { "HIÉROGLYPHE ÉGYPTIEN-141CE","	* phonémogramme : ḥb"},
/* 141CF */ { "HIÉROGLYPHE ÉGYPTIEN-141CF","	* phonémogramme : ḫw"},
/* 141D0 */ { "HIÉROGLYPHE ÉGYPTIEN-141D0","	* phonémogramme : ḫw"},
/* 141D1 */ { "HIÉROGLYPHE ÉGYPTIEN-141D1",NULL},
/* 141D2 */ { "HIÉROGLYPHE ÉGYPTIEN-141D2","	* logogramme (éventail) : ḫw"},
/* 141D3 */ { "HIÉROGLYPHE ÉGYPTIEN-141D3",NULL},
/* 141D4 */ { "HIÉROGLYPHE ÉGYPTIEN-141D4","	* logogramme (Igaï (divinité)) : ꞽgꜣꞽ"},
/* 141D5 */ { "HIÉROGLYPHE ÉGYPTIEN-141D5","	* phonémogramme/logogramme (boisson iatet) : ꞽꜣ.t(yt)"},
/* 141D6 */ { "HIÉROGLYPHE ÉGYPTIEN-141D6","	* phonémogramme/logogramme (boisson iatet) : ꞽꜣ.t(yt)"},
/* 141D7 */ { "HIÉROGLYPHE ÉGYPTIEN-141D7","	* logogramme (Iat (divinité)) : ꞽꜣ.t"},
/* 141D8 */ { "HIÉROGLYPHE ÉGYPTIEN-141D8","	* logogramme (district, région) : w"},
/* 141D9 */ { "HIÉROGLYPHE ÉGYPTIEN-141D9",NULL},
/* 141DA */ { "HIÉROGLYPHE ÉGYPTIEN-141DA","	* phonémogramme : ꜣms"},
/* 141DB */ { "HIÉROGLYPHE ÉGYPTIEN-141DB","	* phonémogramme : md(w)"},
/* 141DC */ { "HIÉROGLYPHE ÉGYPTIEN-141DC","	* phonémogramme : md(w)"},
/* 141DD */ { "HIÉROGLYPHE ÉGYPTIEN-141DD","	* classificateur sceptre : nḥb.t"},
/* 141DE */ { "HIÉROGLYPHE ÉGYPTIEN-141DE","	* logogramme (bâton hetes, bâton) : ḥts"},
/* 141DF */ { "HIÉROGLYPHE ÉGYPTIEN-141DF","	* logogramme (sceptre ames) : ꜣms"},
/* 141E0 */ { "HIÉROGLYPHE ÉGYPTIEN-141E0","	* classificateur bâton, sceptre : ꜣms"},
/* 141E1 */ { "HIÉROGLYPHE ÉGYPTIEN-141E1","	* classificateur vêtements : nṯstn"},
/* 141E2 */ { "HIÉROGLYPHE ÉGYPTIEN-141E2","	* phonémogramme : smꜣ"},
/* 141E3 */ { "HIÉROGLYPHE ÉGYPTIEN-141E3","	* phonémogramme : ḫb"},
/* 141E4 */ { "HIÉROGLYPHE ÉGYPTIEN-141E4","	* phonémogramme : ḫb"},
/* 141E5 */ { "HIÉROGLYPHE ÉGYPTIEN-141E5","	* logogramme (juger, séparer) : wḏꜥ"},
/* 141E6 */ { "HIÉROGLYPHE ÉGYPTIEN-141E6","	* logogramme (juger, séparer) : wḏꜥ"},
/* 141E7 */ { "HIÉROGLYPHE ÉGYPTIEN-141E7","	* logogramme (juger, séparer) : wḏꜥ"},
/* 141E8 */ { "HIÉROGLYPHE ÉGYPTIEN-141E8","	* logogramme (juger, séparer) : wḏꜥ"},
/* 141E9 */ { "HIÉROGLYPHE ÉGYPTIEN-141E9","	* phonémogramme : ꜥpr"},
/* 141EA */ { "HIÉROGLYPHE ÉGYPTIEN-141EA","	* phonémogramme : ꜥpr"},
/* 141EB */ { "HIÉROGLYPHE ÉGYPTIEN-141EB","	* logogramme (contrepoids) : mꜥnḫ.t"},
/* 141EC */ { "HIÉROGLYPHE ÉGYPTIEN-141EC","	* phonémogramme : ꜥpr"},
/* 141ED */ { "HIÉROGLYPHE ÉGYPTIEN-141ED","	* classificateur cracher, expulser : nšꞽ/nẖꞽ"},
/* 141EE */ { "HIÉROGLYPHE ÉGYPTIEN-141EE","	* phonémogramme : ꜥpr"},
/* 141EF */ { "HIÉROGLYPHE ÉGYPTIEN-141EF",NULL},
/* 141F0 */ { "HIÉROGLYPHE ÉGYPTIEN-141F0","	* phonémogramme : ꜥpr"},
/* 141F1 */ { "HIÉROGLYPHE ÉGYPTIEN-141F1","	* classificateur boucle : ḥmꜣṯṯ"},
/* 141F2 */ { "HIÉROGLYPHE ÉGYPTIEN-141F2","	* classificateur bracelet : msktw"},
/* 141F3 */ { "HIÉROGLYPHE ÉGYPTIEN-141F3","	* classificateur tissu, vêtement : mḥ"},
/* 141F4 */ { "HIÉROGLYPHE ÉGYPTIEN-141F4","	* classificateur tissu : wnḫ.wy"},
/* 141F5 */ { "HIÉROGLYPHE ÉGYPTIEN-141F5","	* classificateur dignité, rang : sꜥḥ"},
/* 141F6 */ { "HIÉROGLYPHE ÉGYPTIEN-141F6","	* logogramme (demeure, lieu de naissance, brique de naissance) : msḫn.t"},
/* 141F7 */ { "HIÉROGLYPHE ÉGYPTIEN-141F7","	* logogramme (massue) : ḥḏ"},
/* 141F8 */ { "HIÉROGLYPHE ÉGYPTIEN-141F8",NULL},
/* 141F9 */ { "HIÉROGLYPHE ÉGYPTIEN-141F9",NULL},
/* 141FA */ { "HIÉROGLYPHE ÉGYPTIEN-141FA",NULL},
/* 141FB */ { "HIÉROGLYPHE ÉGYPTIEN-141FB","	* phonémogramme : wḏ"},
/* 141FC */ { "HIÉROGLYPHE ÉGYPTIEN-141FC","	* phonémogramme : wḏ"},
/* 141FD */ { "HIÉROGLYPHE ÉGYPTIEN-141FD","	* phonémogramme : wḏ"},
/* 141FE */ { "HIÉROGLYPHE ÉGYPTIEN-141FE","	* phonémogramme/logogramme (couronne blanche) : ḥḏ.t"},
/* 141FF */ { "HIÉROGLYPHE ÉGYPTIEN-141FF","	* logogramme (argent) : ḥḏ"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_42[] = {
/* 14200 */ { "HIÉROGLYPHE ÉGYPTIEN-14200","	* phonémogramme (dans (tꜣ)-ṯnn (divinité)) : ṯnn"},
/* 14201 */ { "HIÉROGLYPHE ÉGYPTIEN-14201","	* classificateur bouclier : ꞽkm"},
/* 14202 */ { "HIÉROGLYPHE ÉGYPTIEN-14202","	* classificateur bouclier : ꞽkm"},
/* 14203 */ { "HIÉROGLYPHE ÉGYPTIEN-14203","	* logogramme (bouclier) : ꞽkm"},
/* 14204 */ { "HIÉROGLYPHE ÉGYPTIEN-14204","	* logogramme (charpentier) : mḏḥ.w"},
/* 14205 */ { "HIÉROGLYPHE ÉGYPTIEN-14205","	* classificateur passoire, égouttoir : ẖnm.t-wr.t"},
/* 14206 */ { "HIÉROGLYPHE ÉGYPTIEN-14206","	* logogramme (métal) : bꞽꜣ"},
/* 14207 */ { "HIÉROGLYPHE ÉGYPTIEN-14207","	* phonémogramme : mn"},
/* 14208 */ { "HIÉROGLYPHE ÉGYPTIEN-14208","	* phonémogramme : pḏ"},
/* 14209 */ { "HIÉROGLYPHE ÉGYPTIEN-14209","	* logogramme/phonémogramme (tendre) : pḏ"},
/* 1420A */ { "HIÉROGLYPHE ÉGYPTIEN-1420A","	* classificateur au-delà, en dehors : m-rwt"},
/* 1420B */ { "HIÉROGLYPHE ÉGYPTIEN-1420B","	* phonémogramme/logogramme : wpš"},
/* 1420C */ { "HIÉROGLYPHE ÉGYPTIEN-1420C","	* classificateur flèche : šsr"},
/* 1420D */ { "HIÉROGLYPHE ÉGYPTIEN-1420D","	* phonémogramme : swn"},
/* 1420E */ { "HIÉROGLYPHE ÉGYPTIEN-1420E","	* logogramme (Syène (Assouan)) : Swn.w"},
/* 1420F */ { "HIÉROGLYPHE ÉGYPTIEN-1420F","	* phono-répéteur : swn"},
/* 14210 */ { "HIÉROGLYPHE ÉGYPTIEN-14210","	* phonémogramme : sṯ/st"},
/* 14211 */ { "HIÉROGLYPHE ÉGYPTIEN-14211","	* phonémogramme : sṯ/st"},
/* 14212 */ { "HIÉROGLYPHE ÉGYPTIEN-14212",NULL},
/* 14213 */ { "HIÉROGLYPHE ÉGYPTIEN-14213","	* logogramme (Neith) : n.t"},
/* 14214 */ { "HIÉROGLYPHE ÉGYPTIEN-14214","	* logogramme (Neith, 4e et 5e nomes de Basse-Égypte) : n.t"},
/* 14215 */ { "HIÉROGLYPHE ÉGYPTIEN-14215","	* logogramme (Neith, 4e et 5e nomes de Basse-Égypte) : n.t"},
/* 14216 */ { "HIÉROGLYPHE ÉGYPTIEN-14216","	* logogramme (Neith, 4e et 5e nomes de Basse-Égypte) : n.t"},
/* 14217 */ { "HIÉROGLYPHE ÉGYPTIEN-14217","	* logogramme (Neith, 4e et 5e nomes de Basse-Égypte) : n.t"},
/* 14218 */ { "HIÉROGLYPHE ÉGYPTIEN-14218","	* logogramme (nome supérieur de Neith, 5e nome de Basse-Égypte) : n.t-mḥ.yt"},
/* 14219 */ { "HIÉROGLYPHE ÉGYPTIEN-14219","	* logogramme (nome inférieur de Neith, 4e nome de Basse-Égypte) : n.t-rs.yt"},
/* 1421A */ { "HIÉROGLYPHE ÉGYPTIEN-1421A",NULL},
/* 1421B */ { "HIÉROGLYPHE ÉGYPTIEN-1421B","	* logogramme (nome inférieur de Neith, 4e nome de Basse-Égypte) : n.t-rs.yt"},
/* 1421C */ { "HIÉROGLYPHE ÉGYPTIEN-1421C","	* logogramme (nome inférieur de Neith, 4e nome de Basse-Égypte) : n.t-rs.yt"},
/* 1421D */ { "HIÉROGLYPHE ÉGYPTIEN-1421D","	* phonémogramme : ḥms.t"},
/* 1421E */ { "HIÉROGLYPHE ÉGYPTIEN-1421E",NULL},
/* 1421F */ { "HIÉROGLYPHE ÉGYPTIEN-1421F","	* classificateur force vitale féminine : ḥms.t"},
/* 14220 */ { "HIÉROGLYPHE ÉGYPTIEN-14220","	* phonémogramme : sꜣ"},
/* 14221 */ { "HIÉROGLYPHE ÉGYPTIEN-14221","	* logogramme (dos) : sꜣ"},
/* 14222 */ { "HIÉROGLYPHE ÉGYPTIEN-14222","	* phonémogramme : sꜣ"},
/* 14223 */ { "HIÉROGLYPHE ÉGYPTIEN-14223","	* phonémogramme : s"},
/* 14224 */ { "HIÉROGLYPHE ÉGYPTIEN-14224","	* phonémogramme : dmꜣ"},
/* 14225 */ { "HIÉROGLYPHE ÉGYPTIEN-14225","	* phonémogramme/logogramme (mère) : tmꜣ(.t)"},
/* 14226 */ { "HIÉROGLYPHE ÉGYPTIEN-14226","	* phonémogramme : rwḏ"},
/* 14227 */ { "HIÉROGLYPHE ÉGYPTIEN-14227","	* phonémogramme : rwḏ"},
/* 14228 */ { "HIÉROGLYPHE ÉGYPTIEN-14228","	* phono-répéteur : rd"},
/* 14229 */ { "HIÉROGLYPHE ÉGYPTIEN-14229","	* phonémogramme : rs"},
/* 1422A */ { "HIÉROGLYPHE ÉGYPTIEN-1422A","	* phono-répéteur : rs"},
/* 1422B */ { "HIÉROGLYPHE ÉGYPTIEN-1422B","	* phonémogramme/logogramme (conflit) : šnt.t"},
/* 1422C */ { "HIÉROGLYPHE ÉGYPTIEN-1422C",NULL},
/* 1422D */ { "HIÉROGLYPHE ÉGYPTIEN-1422D","	* logogramme/phonémogramme (canal Meter) : Mtr"},
/* 1422E */ { "HIÉROGLYPHE ÉGYPTIEN-1422E","	* phonémogramme : rs-wḏꜣ"},
/* 1422F */ { "HIÉROGLYPHE ÉGYPTIEN-1422F","	* logogramme (être fort, brave, capable) : ḳnꞽ"},
/* 14230 */ { "HIÉROGLYPHE ÉGYPTIEN-14230","	* logogramme (vaillance, force) : ḳn.t"},
/* 14231 */ { "HIÉROGLYPHE ÉGYPTIEN-14231","	* logogramme (épée/cimeterre khépesh) : ḫpš"},
/* 14232 */ { "HIÉROGLYPHE ÉGYPTIEN-14232","	* classificateur être fort, brave, capable : ḳn"},
/* 14233 */ { "HIÉROGLYPHE ÉGYPTIEN-14233","	* logogramme (épée/cimeterre khépesh) : ḫpš"},
/* 14234 */ { "HIÉROGLYPHE ÉGYPTIEN-14234","	* logogramme (être fort, brave, capable) : ḳnꞽ"},
/* 14235 */ { "HIÉROGLYPHE ÉGYPTIEN-14235","	* logogramme (suivre) : šms"},
/* 14236 */ { "HIÉROGLYPHE ÉGYPTIEN-14236","	* logogramme (suivant, acolyte) : šms.w"},
/* 14237 */ { "HIÉROGLYPHE ÉGYPTIEN-14237","	* logogramme (suivre) : šms"},
/* 14238 */ { "HIÉROGLYPHE ÉGYPTIEN-14238","	* classificateur tige, roseau"},
/* 14239 */ { "HIÉROGLYPHE ÉGYPTIEN-14239",NULL},
/* 1423A */ { "HIÉROGLYPHE ÉGYPTIEN-1423A","	* phono-répéteur : twr"},
/* 1423B */ { "HIÉROGLYPHE ÉGYPTIEN-1423B","	* phonémogramme : tr"},
/* 1423C */ { "HIÉROGLYPHE ÉGYPTIEN-1423C","	* phono-répéteur : twr"},
/* 1423D */ { "HIÉROGLYPHE ÉGYPTIEN-1423D","	* phonémogramme : msn"},
/* 1423E */ { "HIÉROGLYPHE ÉGYPTIEN-1423E","	* phonémogramme : tr"},
/* 1423F */ { "HIÉROGLYPHE ÉGYPTIEN-1423F","	* phonémogramme : ḳs"},
/* 14240 */ { "HIÉROGLYPHE ÉGYPTIEN-14240","	* phonémogramme : tr"},
/* 14241 */ { "HIÉROGLYPHE ÉGYPTIEN-14241","	* logogramme (un, unique) : wꜥ"},
/* 14242 */ { "HIÉROGLYPHE ÉGYPTIEN-14242","	* logogramme (un, unique) : wꜥ.t"},
/* 14243 */ { "HIÉROGLYPHE ÉGYPTIEN-14243","	* logogramme (un, unique) : wꜥ"},
/* 14244 */ { "HIÉROGLYPHE ÉGYPTIEN-14244",NULL},
/* 14245 */ { "HIÉROGLYPHE ÉGYPTIEN-14245","	* logogramme (un, unique) : wꜥ"},
/* 14246 */ { "HIÉROGLYPHE ÉGYPTIEN-14246","	* logogramme (un, unique) : wꜥ"},
/* 14247 */ { "HIÉROGLYPHE ÉGYPTIEN-14247","	* logogramme (un, unique) : wꜥ"},
/* 14248 */ { "HIÉROGLYPHE ÉGYPTIEN-14248","	* logogramme (un, unique) : wꜥ"},
/* 14249 */ { "HIÉROGLYPHE ÉGYPTIEN-14249","	* classificateur lance, javelot : nꞽw.y"},
/* 1424A */ { "HIÉROGLYPHE ÉGYPTIEN-1424A","	* phonémogramme : sn"},
/* 1424B */ { "HIÉROGLYPHE ÉGYPTIEN-1424B","	* phonémogramme : sn"},
/* 1424C */ { "HIÉROGLYPHE ÉGYPTIEN-1424C","	* phonémogramme : sn"},
/* 1424D */ { "HIÉROGLYPHE ÉGYPTIEN-1424D","	* phonémogramme : šn"},
/* 1424E */ { "HIÉROGLYPHE ÉGYPTIEN-1424E",NULL},
/* 1424F */ { "HIÉROGLYPHE ÉGYPTIEN-1424F",NULL},
/* 14250 */ { "HIÉROGLYPHE ÉGYPTIEN-14250","	* logogramme (7e et 8e nomes de Basse-Égypte) : wꜥ-m-ḥww"},
/* 14251 */ { "HIÉROGLYPHE ÉGYPTIEN-14251","	* logogramme (7e et 8e nomes de Basse-Égypte) : wꜥ-m-ḥww"},
/* 14252 */ { "HIÉROGLYPHE ÉGYPTIEN-14252",NULL},
/* 14253 */ { "HIÉROGLYPHE ÉGYPTIEN-14253","	* logogramme (nome du Harpon à cordes côté occidental, 7e nome de Basse-Égypte) : wꜥ-m-ḥww-ꞽmn.ty"},
/* 14254 */ { "HIÉROGLYPHE ÉGYPTIEN-14254",NULL},
/* 14255 */ { "HIÉROGLYPHE ÉGYPTIEN-14255",NULL},
/* 14256 */ { "HIÉROGLYPHE ÉGYPTIEN-14256","	* logogramme (nome du Harpon à cordes côté occidental, 7e nome de Basse-Égypte) : wꜥ-m-ḥww-ꞽmn.ty"},
/* 14257 */ { "HIÉROGLYPHE ÉGYPTIEN-14257",NULL},
/* 14258 */ { "HIÉROGLYPHE ÉGYPTIEN-14258",NULL},
/* 14259 */ { "HIÉROGLYPHE ÉGYPTIEN-14259","	* phonémogramme : ꞽh"},
/* 1425A */ { "HIÉROGLYPHE ÉGYPTIEN-1425A","	* logogramme (filet) : ꜥḥ"},
/* 1425B */ { "HIÉROGLYPHE ÉGYPTIEN-1425B","	* classificateur capture, mise en filet : ꞽḥ"},
/* 1425C */ { "HIÉROGLYPHE ÉGYPTIEN-1425C","	* classificateur capture, mise en filet : ꞽḥ"},
/* 1425D */ { "HIÉROGLYPHE ÉGYPTIEN-1425D","	* logogramme (filet) : ꜥḥ/ꞽḥ"},
/* 1425E */ { "HIÉROGLYPHE ÉGYPTIEN-1425E","	* classificateur filet : ꞽḥ.y"},
/* 1425F */ { "HIÉROGLYPHE ÉGYPTIEN-1425F","	* classificateur capture, mise en filet : ꞽḥ.t"},
/* 14260 */ { "HIÉROGLYPHE ÉGYPTIEN-14260","	* classificateur nasse : ḥꜥd"},
/* 14261 */ { "HIÉROGLYPHE ÉGYPTIEN-14261","	* phonémogramme : ḏbꜣ"},
/* 14262 */ { "HIÉROGLYPHE ÉGYPTIEN-14262","	* phonémogramme : ḏbꜣ"},
/* 14263 */ { "HIÉROGLYPHE ÉGYPTIEN-14263","	* phonémogramme : ḏbꜣ"},
/* 14264 */ { "HIÉROGLYPHE ÉGYPTIEN-14264",NULL},
/* 14265 */ { "HIÉROGLYPHE ÉGYPTIEN-14265","	* phonémogramme : ḏbꜣ"},
/* 14266 */ { "HIÉROGLYPHE ÉGYPTIEN-14266",NULL},
/* 14267 */ { "HIÉROGLYPHE ÉGYPTIEN-14267",NULL},
/* 14268 */ { "HIÉROGLYPHE ÉGYPTIEN-14268","	* phonémogramme : sḫt"},
/* 14269 */ { "HIÉROGLYPHE ÉGYPTIEN-14269","	* phonémogramme : sḫt"},
/* 1426A */ { "HIÉROGLYPHE ÉGYPTIEN-1426A","	* phonémogramme : sḫt"},
/* 1426B */ { "HIÉROGLYPHE ÉGYPTIEN-1426B","	* logogramme (tisser, piéger) : sḫt"},
/* 1426C */ { "HIÉROGLYPHE ÉGYPTIEN-1426C","	* phono-répéteur : sḫt"},
/* 1426D */ { "HIÉROGLYPHE ÉGYPTIEN-1426D","	* phonémogramme : sḫt"},
/* 1426E */ { "HIÉROGLYPHE ÉGYPTIEN-1426E","	* classificateur capture, mise en filet : sḫt"},
/* 1426F */ { "HIÉROGLYPHE ÉGYPTIEN-1426F","	* classificateur abri : kꜣp"},
/* 14270 */ { "HIÉROGLYPHE ÉGYPTIEN-14270","	* classificateur filet : ꞽꜣd.t"},
/* 14271 */ { "HIÉROGLYPHE ÉGYPTIEN-14271","	* classificateur filet : (ꞽ)ꜣd(.t)"},
/* 14272 */ { "HIÉROGLYPHE ÉGYPTIEN-14272","	* logogramme (filet) : ꞽꜣd.t"},
/* 14273 */ { "HIÉROGLYPHE ÉGYPTIEN-14273","	* classificateur nasse : sḳ.t"},
/* 14274 */ { "HIÉROGLYPHE ÉGYPTIEN-14274","	* classificateur dépeçage, abattage : mds\n"
	"	~ 14274 FE01 pivoté de 180 degrés\n"
	"	~ 14274 FE02 pivoté de 270 degrés\n"
	"	~ 14274 FE05 pivoté de 250 degrés environ [vertical]\n"
	"	~ 14274 FE06 pivoté de 340 degrés environ [horizontal]"},
/* 14275 */ { "HIÉROGLYPHE ÉGYPTIEN-14275","	* logogramme (silex, dans ds-km, obsidienne) : ds"},
/* 14276 */ { "HIÉROGLYPHE ÉGYPTIEN-14276","	* logogramme (sculpter, inscrire, graver) : ḫtꞽ"},
/* 14277 */ { "HIÉROGLYPHE ÉGYPTIEN-14277","	* logogramme (sculpter, inscrire, graver) : ḫtꞽ"},
/* 14278 */ { "HIÉROGLYPHE ÉGYPTIEN-14278","	* logogramme (sculpter, inscrire, graver) : ḫtꞽ"},
/* 14279 */ { "HIÉROGLYPHE ÉGYPTIEN-14279",NULL},
/* 1427A */ { "HIÉROGLYPHE ÉGYPTIEN-1427A","	* classificateur lieu d'exécution : ḫb.t"},
/* 1427B */ { "HIÉROGLYPHE ÉGYPTIEN-1427B","	* logogramme (lieu d'exécution) : ḫb.t"},
/* 1427C */ { "HIÉROGLYPHE ÉGYPTIEN-1427C","	* logogramme (lieu d'abattage) : nm.t"},
/* 1427D */ { "HIÉROGLYPHE ÉGYPTIEN-1427D","	* logogramme (boucherie, abattage) : šꜥt"},
/* 1427E */ { "HIÉROGLYPHE ÉGYPTIEN-1427E","	* logogramme (boucherie, abattage) : šꜥt"},
/* 1427F */ { "HIÉROGLYPHE ÉGYPTIEN-1427F","	* logogramme (lieu d'abattage/exécution) : nm.t/ḫb.t"},
/* 14280 */ { "HIÉROGLYPHE ÉGYPTIEN-14280","	* logogramme (sculpter, inscrire, graver) : ḫtꞽ"},
/* 14281 */ { "HIÉROGLYPHE ÉGYPTIEN-14281",NULL},
/* 14282 */ { "HIÉROGLYPHE ÉGYPTIEN-14282","	* classificateur puanteur : sṯ"},
/* 14283 */ { "HIÉROGLYPHE ÉGYPTIEN-14283","	* logogramme (lieu d'abattage) : nm.t"},
/* 14284 */ { "HIÉROGLYPHE ÉGYPTIEN-14284",NULL},
/* 14285 */ { "HIÉROGLYPHE ÉGYPTIEN-14285","	* phonémogramme : ds"},
/* 14286 */ { "HIÉROGLYPHE ÉGYPTIEN-14286",NULL},
/* 14287 */ { "HIÉROGLYPHE ÉGYPTIEN-14287","	* phonémogramme : sšm"},
/* 14288 */ { "HIÉROGLYPHE ÉGYPTIEN-14288",NULL},
/* 14289 */ { "HIÉROGLYPHE ÉGYPTIEN-14289","	* classificateur étendre (dans psš-kf (un type de couteau en silex)) : psš"},
/* 1428A */ { "HIÉROGLYPHE ÉGYPTIEN-1428A","	* classificateur provoquer la respiration : srḳ.t"},
/* 1428B */ { "HIÉROGLYPHE ÉGYPTIEN-1428B","	* classificateur pointes (d'un harpon) : bwn"},
/* 1428C */ { "HIÉROGLYPHE ÉGYPTIEN-1428C","	* classificateur crochets : snꜥḥ.t"},
/* 1428D */ { "HIÉROGLYPHE ÉGYPTIEN-1428D","	* classificateur circoncision : sb"},
/* 1428E */ { "HIÉROGLYPHE ÉGYPTIEN-1428E",NULL},
/* 1428F */ { "HIÉROGLYPHE ÉGYPTIEN-1428F","	* phonémogramme : mꜣ"},
/* 14290 */ { "HIÉROGLYPHE ÉGYPTIEN-14290","	* classificateur binage : ḫbss"},
/* 14291 */ { "HIÉROGLYPHE ÉGYPTIEN-14291","	* classificateur binage : ḫbss"},
/* 14292 */ { "HIÉROGLYPHE ÉGYPTIEN-14292","	* logogramme (biner la terre) : ḫbs-tꜣ"},
/* 14293 */ { "HIÉROGLYPHE ÉGYPTIEN-14293","	* classificateur binage : ḫbss"},
/* 14294 */ { "HIÉROGLYPHE ÉGYPTIEN-14294","	* phonémogramme : mr"},
/* 14295 */ { "HIÉROGLYPHE ÉGYPTIEN-14295",NULL},
/* 14296 */ { "HIÉROGLYPHE ÉGYPTIEN-14296","	* classificateur récolte, moisson : šm(.w)"},
/* 14297 */ { "HIÉROGLYPHE ÉGYPTIEN-14297","	* classificateur céréales, orge : npt"},
/* 14298 */ { "HIÉROGLYPHE ÉGYPTIEN-14298","	* classificateur céréales : mh.w"},
/* 14299 */ { "HIÉROGLYPHE ÉGYPTIEN-14299","	* classificateur céréales : mh.w | šmꜥ.w | wꜣḥ.yt"},
/* 1429A */ { "HIÉROGLYPHE ÉGYPTIEN-1429A","	* classificateur céréales : np(r)"},
/* 1429B */ { "HIÉROGLYPHE ÉGYPTIEN-1429B",NULL},
/* 1429C */ { "HIÉROGLYPHE ÉGYPTIEN-1429C","	* phonémogramme : hb"},
/* 1429D */ { "HIÉROGLYPHE ÉGYPTIEN-1429D","	* phono-répéteur : hb"},
/* 1429E */ { "HIÉROGLYPHE ÉGYPTIEN-1429E",NULL},
/* 1429F */ { "HIÉROGLYPHE ÉGYPTIEN-1429F","	* phono-répéteur : hb"},
/* 142A0 */ { "HIÉROGLYPHE ÉGYPTIEN-142A0",NULL},
/* 142A1 */ { "HIÉROGLYPHE ÉGYPTIEN-142A1","	* logogramme (fruit) : pr.t"},
/* 142A2 */ { "HIÉROGLYPHE ÉGYPTIEN-142A2","	* logogramme (fruit) : pr.t"},
/* 142A3 */ { "HIÉROGLYPHE ÉGYPTIEN-142A3","	* phonémogramme : tm"},
/* 142A4 */ { "HIÉROGLYPHE ÉGYPTIEN-142A4","	* phonémogramme : tm"},
/* 142A5 */ { "HIÉROGLYPHE ÉGYPTIEN-142A5",NULL},
/* 142A6 */ { "HIÉROGLYPHE ÉGYPTIEN-142A6","	* phonémogramme : bꞽꜣ"},
/* 142A7 */ { "HIÉROGLYPHE ÉGYPTIEN-142A7","	* classificateur enterrement : ḳrs.t"},
/* 142A8 */ { "HIÉROGLYPHE ÉGYPTIEN-142A8","	* logogramme (Rê-Atoum) : rꜥ-ꞽtm.w"},
/* 142A9 */ { "HIÉROGLYPHE ÉGYPTIEN-142A9","	* logogramme (fonder, établir, chasser, poser (un piège)) : grg"},
/* 142AA */ { "HIÉROGLYPHE ÉGYPTIEN-142AA","	* logogramme (fonder, établir, chasser, poser (un piège)) : grg"},
/* 142AB */ { "HIÉROGLYPHE ÉGYPTIEN-142AB","	* classificateur griffe, ongle : ꜥn.t"},
/* 142AC */ { "HIÉROGLYPHE ÉGYPTIEN-142AC","	* phonémogramme : nw"},
/* 142AD */ { "HIÉROGLYPHE ÉGYPTIEN-142AD","	* logogramme (ongle) : ꜥn.t"},
/* 142AE */ { "HIÉROGLYPHE ÉGYPTIEN-142AE","	* phonémogramme : stp"},
/* 142AF */ { "HIÉROGLYPHE ÉGYPTIEN-142AF","	* classificateur griffe, ongle : ꜥn.t"},
/* 142B0 */ { "HIÉROGLYPHE ÉGYPTIEN-142B0","	* phonémogramme : stp"},
/* 142B1 */ { "HIÉROGLYPHE ÉGYPTIEN-142B1","	* phonémogramme : mnḫ"},
/* 142B2 */ { "HIÉROGLYPHE ÉGYPTIEN-142B2","	* phonémogramme : mnḫ"},
/* 142B3 */ { "HIÉROGLYPHE ÉGYPTIEN-142B3","	* phonémogramme : wbꜣ"},
/* 142B4 */ { "HIÉROGLYPHE ÉGYPTIEN-142B4","	* classificateur ciseau : ḥr.y-ṯꜣ.y-mḏꜣ.t"},
/* 142B5 */ { "HIÉROGLYPHE ÉGYPTIEN-142B5","	* phonémogramme : w"},
/* 142B6 */ { "HIÉROGLYPHE ÉGYPTIEN-142B6",NULL},
/* 142B7 */ { "HIÉROGLYPHE ÉGYPTIEN-142B7","	* phonémogramme : ꜣb"},
/* 142B8 */ { "HIÉROGLYPHE ÉGYPTIEN-142B8","	* phonémogramme : ꜣb"},
/* 142B9 */ { "HIÉROGLYPHE ÉGYPTIEN-142B9","	* phonémogramme : ꜣb"},
/* 142BA */ { "HIÉROGLYPHE ÉGYPTIEN-142BA","	* phonémogramme : mr"},
/* 142BB */ { "HIÉROGLYPHE ÉGYPTIEN-142BB","	* classificateur perçage : htꞽ"},
/* 142BC */ { "HIÉROGLYPHE ÉGYPTIEN-142BC","	* phonémogramme : wb"},
/* 142BD */ { "HIÉROGLYPHE ÉGYPTIEN-142BD","	* phonémogramme : wb"},
/* 142BE */ { "HIÉROGLYPHE ÉGYPTIEN-142BE","	* logogramme (ouvrir) : wbꜣ"},
/* 142BF */ { "HIÉROGLYPHE ÉGYPTIEN-142BF","	* phonémogramme : wb(n)"},
/* 142C0 */ { "HIÉROGLYPHE ÉGYPTIEN-142C0",NULL},
/* 142C1 */ { "HIÉROGLYPHE ÉGYPTIEN-142C1","	* logogramme (ouvrir) : wbꜣ"},
/* 142C2 */ { "HIÉROGLYPHE ÉGYPTIEN-142C2","	* phonémogramme : wḏ"},
/* 142C3 */ { "HIÉROGLYPHE ÉGYPTIEN-142C3",NULL},
/* 142C4 */ { "HIÉROGLYPHE ÉGYPTIEN-142C4","	* phonémogramme : wbꜣ"},
/* 142C5 */ { "HIÉROGLYPHE ÉGYPTIEN-142C5","	* logogramme (artisan) : ḥmw.w"},
/* 142C6 */ { "HIÉROGLYPHE ÉGYPTIEN-142C6","	* phonémogramme : wb"},
/* 142C7 */ { "HIÉROGLYPHE ÉGYPTIEN-142C7","	* logogramme (ouvrir) : wbꜣ"},
/* 142C8 */ { "HIÉROGLYPHE ÉGYPTIEN-142C8","	* phonémogramme : wb"},
/* 142C9 */ { "HIÉROGLYPHE ÉGYPTIEN-142C9","	* logogramme (artisan) : ḥmw.w"},
/* 142CA */ { "HIÉROGLYPHE ÉGYPTIEN-142CA","	* logogramme (ouvrir) : wbꜣ"},
/* 142CB */ { "HIÉROGLYPHE ÉGYPTIEN-142CB","	* logogramme (artisan) : ḥmw.w"},
/* 142CC */ { "HIÉROGLYPHE ÉGYPTIEN-142CC",NULL},
/* 142CD */ { "HIÉROGLYPHE ÉGYPTIEN-142CD","	* logogramme (habile) : ḥmw.w"},
/* 142CE */ { "HIÉROGLYPHE ÉGYPTIEN-142CE","	* logogramme (artisanat) : ḥmw.t"},
/* 142CF */ { "HIÉROGLYPHE ÉGYPTIEN-142CF",NULL},
/* 142D0 */ { "HIÉROGLYPHE ÉGYPTIEN-142D0","	* logogramme (artisan) : ḥmw.w"},
/* 142D1 */ { "HIÉROGLYPHE ÉGYPTIEN-142D1","	* logogramme (ouvrir) : wbꜣ"},
/* 142D2 */ { "HIÉROGLYPHE ÉGYPTIEN-142D2",NULL},
/* 142D3 */ { "HIÉROGLYPHE ÉGYPTIEN-142D3","	* logogramme (artisan) : ḥmw.w"},
/* 142D4 */ { "HIÉROGLYPHE ÉGYPTIEN-142D4","	* logogramme (ouvrir) : wbꜣ"},
/* 142D5 */ { "HIÉROGLYPHE ÉGYPTIEN-142D5","	* logogramme (ouvrir) : wbꜣ"},
/* 142D6 */ { "HIÉROGLYPHE ÉGYPTIEN-142D6","	* logogramme (ouvrir) : wbꜣ"},
/* 142D7 */ { "HIÉROGLYPHE ÉGYPTIEN-142D7","	* phonémogramme : wb"},
/* 142D8 */ { "HIÉROGLYPHE ÉGYPTIEN-142D8","	* phonémogramme : tꜣ"},
/* 142D9 */ { "HIÉROGLYPHE ÉGYPTIEN-142D9","	* phonémogramme : tꜣ"},
/* 142DA */ { "HIÉROGLYPHE ÉGYPTIEN-142DA","	* phonémogramme : mn"},
/* 142DB */ { "HIÉROGLYPHE ÉGYPTIEN-142DB","	* phono-répéteur : smn"},
/* 142DC */ { "HIÉROGLYPHE ÉGYPTIEN-142DC","	* phonémogramme : smn"},
/* 142DD */ { "HIÉROGLYPHE ÉGYPTIEN-142DD","	* phonémogramme : t(ꞽ)"},
/* 142DE */ { "HIÉROGLYPHE ÉGYPTIEN-142DE","	* phonémogramme : ḫsf"},
/* 142DF */ { "HIÉROGLYPHE ÉGYPTIEN-142DF","	* classificateur rasage : ẖꜥḳ"},
/* 142E0 */ { "HIÉROGLYPHE ÉGYPTIEN-142E0","	* logogramme (raser) : ẖꜥḳ"},
/* 142E1 */ { "HIÉROGLYPHE ÉGYPTIEN-142E1",NULL},
/* 142E2 */ { "HIÉROGLYPHE ÉGYPTIEN-142E2","	* classificateur colonne de balance : mḫꜣ.t"},
/* 142E3 */ { "HIÉROGLYPHE ÉGYPTIEN-142E3","	* logogramme (balance, dans mḫꜣ.t-tꜣ.wy) : mḫꜣ.t"},
/* 142E4 */ { "HIÉROGLYPHE ÉGYPTIEN-142E4","	* classificateur colonne de balance : mḫꜣ.t"},
/* 142E5 */ { "HIÉROGLYPHE ÉGYPTIEN-142E5","	* logogramme (lever, élever) : ṯsꞽ"},
/* 142E6 */ { "HIÉROGLYPHE ÉGYPTIEN-142E6",NULL},
/* 142E7 */ { "HIÉROGLYPHE ÉGYPTIEN-142E7",NULL},
/* 142E8 */ { "HIÉROGLYPHE ÉGYPTIEN-142E8","	* classificateur levage, portage : wṯs"},
/* 142E9 */ { "HIÉROGLYPHE ÉGYPTIEN-142E9","	* logogramme (lever, porter) : wṯs"},
/* 142EA */ { "HIÉROGLYPHE ÉGYPTIEN-142EA","	* logogramme (lever, porter) : wṯs"},
/* 142EB */ { "HIÉROGLYPHE ÉGYPTIEN-142EB","	* logogramme (lever, porter) : wṯs"},
/* 142EC */ { "HIÉROGLYPHE ÉGYPTIEN-142EC","	* classificateur levage, portage : ṯs"},
/* 142ED */ { "HIÉROGLYPHE ÉGYPTIEN-142ED",NULL},
/* 142EE */ { "HIÉROGLYPHE ÉGYPTIEN-142EE","	* classificateur élever, soulever : sṯsꞽ"},
/* 142EF */ { "HIÉROGLYPHE ÉGYPTIEN-142EF","	* classificateur outil de mesure ? : ḫꜥ.y"},
/* 142F0 */ { "HIÉROGLYPHE ÉGYPTIEN-142F0","	* classificateur levage, portage : wṯs"},
/* 142F1 */ { "HIÉROGLYPHE ÉGYPTIEN-142F1","	* classificateur levage, portage : ṯs"},
/* 142F2 */ { "HIÉROGLYPHE ÉGYPTIEN-142F2","	* phonémogramme (ꞽn wṯs-ḥr) : wṯs"},
/* 142F3 */ { "HIÉROGLYPHE ÉGYPTIEN-142F3","	* classificateur service, tâche : wnw.t"},
/* 142F4 */ { "HIÉROGLYPHE ÉGYPTIEN-142F4","	* logogramme (service, tâche) : wnw.t"},
/* 142F5 */ { "HIÉROGLYPHE ÉGYPTIEN-142F5",NULL},
/* 142F6 */ { "HIÉROGLYPHE ÉGYPTIEN-142F6","	* logogramme (service, tâche) : wnw.t"},
/* 142F7 */ { "HIÉROGLYPHE ÉGYPTIEN-142F7","	* classificateur instrument astronomique : mrḫ.t"},
/* 142F8 */ { "HIÉROGLYPHE ÉGYPTIEN-142F8","	* logogramme (service, tâche) : wnw.t"},
/* 142F9 */ { "HIÉROGLYPHE ÉGYPTIEN-142F9","	* classificateur longueur, largeur : sḫḫ"},
/* 142FA */ { "HIÉROGLYPHE ÉGYPTIEN-142FA","	* phonémogramme : sḫḫ"},
/* 142FB */ { "HIÉROGLYPHE ÉGYPTIEN-142FB","	* classificateur façonner, créer : nḥp"},
/* 142FC */ { "HIÉROGLYPHE ÉGYPTIEN-142FC","	* logogramme (vie) : ꜥnḫ"},
/* 142FD */ { "HIÉROGLYPHE ÉGYPTIEN-142FD","	* classificateur tour de potier : nḥp"},
/* 142FE */ { "HIÉROGLYPHE ÉGYPTIEN-142FE","	* classificateur potier : ḳd.w"},
/* 142FF */ { "HIÉROGLYPHE ÉGYPTIEN-142FF","	* logogramme (tour de potier) : nḥp"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_43[] = {
/* 14300 */ { "HIÉROGLYPHE ÉGYPTIEN-14300","	* classificateur tour de potier : nḥb"},
/* 14301 */ { "HIÉROGLYPHE ÉGYPTIEN-14301",NULL},
/* 14302 */ { "HIÉROGLYPHE ÉGYPTIEN-14302",NULL},
/* 14303 */ { "HIÉROGLYPHE ÉGYPTIEN-14303","	* logogramme (Chesmou (divinité)) : šsmw"},
/* 14304 */ { "HIÉROGLYPHE ÉGYPTIEN-14304","	* logogramme (Chesmou (divinité)) : šsmw"},
/* 14305 */ { "HIÉROGLYPHE ÉGYPTIEN-14305",NULL},
/* 14306 */ { "HIÉROGLYPHE ÉGYPTIEN-14306","	* logogramme (Chesmou (divinité)) : šsmw"},
/* 14307 */ { "HIÉROGLYPHE ÉGYPTIEN-14307","	* logogramme (Chesmou (divinité)) : šsmw"},
/* 14308 */ { "HIÉROGLYPHE ÉGYPTIEN-14308","	* logogramme (Chesmou (divinité)) : šsmw"},
/* 14309 */ { "HIÉROGLYPHE ÉGYPTIEN-14309",NULL},
/* 1430A */ { "HIÉROGLYPHE ÉGYPTIEN-1430A",NULL},
/* 1430B */ { "HIÉROGLYPHE ÉGYPTIEN-1430B","	* logogramme (Chesmou (divinité)) : šsmw"},
/* 1430C */ { "HIÉROGLYPHE ÉGYPTIEN-1430C",NULL},
/* 1430D */ { "HIÉROGLYPHE ÉGYPTIEN-1430D",NULL},
/* 1430E */ { "HIÉROGLYPHE ÉGYPTIEN-1430E",NULL},
/* 1430F */ { "HIÉROGLYPHE ÉGYPTIEN-1430F","	* logogramme (presser, s'accrocher (à)) : mḏd"},
/* 14310 */ { "HIÉROGLYPHE ÉGYPTIEN-14310","	* classificateur pressant, frappant : mḏd"},
/* 14311 */ { "HIÉROGLYPHE ÉGYPTIEN-14311",NULL},
/* 14312 */ { "HIÉROGLYPHE ÉGYPTIEN-14312","	* phonémogramme : sš"},
/* 14313 */ { "HIÉROGLYPHE ÉGYPTIEN-14313","	* classificateur poudre d'or : nḳr"},
/* 14314 */ { "HIÉROGLYPHE ÉGYPTIEN-14314","	* classificateur cage : štb"},
/* 14315 */ { "HIÉROGLYPHE ÉGYPTIEN-14315","	* classificateur chaudron : ḏsf.w"},
/* 14316 */ { "HIÉROGLYPHE ÉGYPTIEN-14316",NULL},
/* 14317 */ { "HIÉROGLYPHE ÉGYPTIEN-14317","	* phonémogramme : nd"},
/* 14318 */ { "HIÉROGLYPHE ÉGYPTIEN-14318","	* phonémogramme : nḏ"},
/* 14319 */ { "HIÉROGLYPHE ÉGYPTIEN-14319","	* classificateur flamme"},
/* 1431A */ { "HIÉROGLYPHE ÉGYPTIEN-1431A","	* classificateur balayage, essuyage : sk"},
/* 1431B */ { "HIÉROGLYPHE ÉGYPTIEN-1431B","	* classificateur scie : tfꜣ"},
/* 1431C */ { "HIÉROGLYPHE ÉGYPTIEN-1431C","	* classificateur montant d'une échelle : mꜥꜣꜥ"},
/* 1431D */ { "HIÉROGLYPHE ÉGYPTIEN-1431D","	* phonémogramme : ḳd"},
/* 1431E */ { "HIÉROGLYPHE ÉGYPTIEN-1431E",NULL},
/* 1431F */ { "HIÉROGLYPHE ÉGYPTIEN-1431F","	* logogramme (champ, terre arable) : ꜣḥ.t"},
/* 14320 */ { "HIÉROGLYPHE ÉGYPTIEN-14320","	* phono-répéteur / classificateur mouvement : sṯꜣ"},
/* 14321 */ { "HIÉROGLYPHE ÉGYPTIEN-14321","	* phono-répéteur : šn"},
/* 14322 */ { "HIÉROGLYPHE ÉGYPTIEN-14322","	* classificateur vêtements : ḥbs"},
/* 14323 */ { "HIÉROGLYPHE ÉGYPTIEN-14323","	* phonémogramme : šn"},
/* 14324 */ { "HIÉROGLYPHE ÉGYPTIEN-14324","	* logogramme (image cultuelle ?) : dmꞽ/ḫꜣdb"},
/* 14325 */ { "HIÉROGLYPHE ÉGYPTIEN-14325","	* logogramme (nom) : rn"},
/* 14326 */ { "HIÉROGLYPHE ÉGYPTIEN-14326",NULL},
/* 14327 */ { "HIÉROGLYPHE ÉGYPTIEN-14327","	* logogramme (flotteur ? (partie de l'équipement de chasse à l'hippopotame)) : bb"},
/* 14328 */ { "HIÉROGLYPHE ÉGYPTIEN-14328",NULL},
/* 14329 */ { "HIÉROGLYPHE ÉGYPTIEN-14329","	* phonémogramme : dn"},
/* 1432A */ { "HIÉROGLYPHE ÉGYPTIEN-1432A","	* phonémogramme : sꜣ"},
/* 1432B */ { "HIÉROGLYPHE ÉGYPTIEN-1432B","	* phonémogramme : sꜣ"},
/* 1432C */ { "HIÉROGLYPHE ÉGYPTIEN-1432C","	* phonémogramme : sꜣ"},
/* 1432D */ { "HIÉROGLYPHE ÉGYPTIEN-1432D","	* logogramme (protection) : sꜣ"},
/* 1432E */ { "HIÉROGLYPHE ÉGYPTIEN-1432E","	* logogramme (protection) : sꜣ"},
/* 1432F */ { "HIÉROGLYPHE ÉGYPTIEN-1432F","	* phonémogramme : mḏ"},
/* 14330 */ { "HIÉROGLYPHE ÉGYPTIEN-14330",NULL},
/* 14331 */ { "HIÉROGLYPHE ÉGYPTIEN-14331","	* logogramme (19e nome de Haute-Égypte) : brbr"},
/* 14332 */ { "HIÉROGLYPHE ÉGYPTIEN-14332","	* logogramme (19e nome de Haute-Égypte) : brbr"},
/* 14333 */ { "HIÉROGLYPHE ÉGYPTIEN-14333","	* phonémogramme : mḥ"},
/* 14334 */ { "HIÉROGLYPHE ÉGYPTIEN-14334","	* phonémogramme : mḥ"},
/* 14335 */ { "HIÉROGLYPHE ÉGYPTIEN-14335",NULL},
/* 14336 */ { "HIÉROGLYPHE ÉGYPTIEN-14336","	* phonémogramme : ꜥḏ"},
/* 14337 */ { "HIÉROGLYPHE ÉGYPTIEN-14337","	* interprétant : ḥ"},
/* 14338 */ { "HIÉROGLYPHE ÉGYPTIEN-14338","	* interprétant : ḥ"},
/* 14339 */ { "HIÉROGLYPHE ÉGYPTIEN-14339","	* interprétant : ḥ"},
/* 1433A */ { "HIÉROGLYPHE ÉGYPTIEN-1433A",NULL},
/* 1433B */ { "HIÉROGLYPHE ÉGYPTIEN-1433B","	* phonémogramme : sk"},
/* 1433C */ { "HIÉROGLYPHE ÉGYPTIEN-1433C","	* classificateur chasser, repousser : ḫsr"},
/* 1433D */ { "HIÉROGLYPHE ÉGYPTIEN-1433D","	* logogramme (frapper, enfoncer) : ḥwꞽ"},
/* 1433E */ { "HIÉROGLYPHE ÉGYPTIEN-1433E","	* phonémogramme : wꜣḥ"},
/* 1433F */ { "HIÉROGLYPHE ÉGYPTIEN-1433F","	* phonémogramme : wꜣḥ"},
/* 14340 */ { "HIÉROGLYPHE ÉGYPTIEN-14340","	* phonémogramme : wꜣḥ"},
/* 14341 */ { "HIÉROGLYPHE ÉGYPTIEN-14341","	* phonémogramme : wꜣḥ"},
/* 14342 */ { "HIÉROGLYPHE ÉGYPTIEN-14342","	* classificateur mèche : ḥꜥ.t"},
/* 14343 */ { "HIÉROGLYPHE ÉGYPTIEN-14343","	* phonémogramme : k"},
/* 14344 */ { "HIÉROGLYPHE ÉGYPTIEN-14344","	* phonémogramme : gꜣ"},
/* 14345 */ { "HIÉROGLYPHE ÉGYPTIEN-14345","	* phonémogramme : sḫr(.w)"},
/* 14346 */ { "HIÉROGLYPHE ÉGYPTIEN-14346","	* classificateur offrande : dbḥ.t-ḥtp"},
/* 14347 */ { "HIÉROGLYPHE ÉGYPTIEN-14347",NULL},
/* 14348 */ { "HIÉROGLYPHE ÉGYPTIEN-14348","	* phonémogramme : msn"},
/* 14349 */ { "HIÉROGLYPHE ÉGYPTIEN-14349","	* phonémogramme : gꜣw"},
/* 1434A */ { "HIÉROGLYPHE ÉGYPTIEN-1434A","	* phonémogramme : ḥn"},
/* 1434B */ { "HIÉROGLYPHE ÉGYPTIEN-1434B","	* phono-répéteur : ḥn"},
/* 1434C */ { "HIÉROGLYPHE ÉGYPTIEN-1434C","	* phonémogramme : ḥn"},
/* 1434D */ { "HIÉROGLYPHE ÉGYPTIEN-1434D","	* phonémogramme : ḥn"},
/* 1434E */ { "HIÉROGLYPHE ÉGYPTIEN-1434E","	* phonémogramme : ḥn"},
/* 1434F */ { "HIÉROGLYPHE ÉGYPTIEN-1434F","	* phonémogramme : ḥn"},
/* 14350 */ { "HIÉROGLYPHE ÉGYPTIEN-14350","	* phono-répéteur : ḥn"},
/* 14351 */ { "HIÉROGLYPHE ÉGYPTIEN-14351",NULL},
/* 14352 */ { "HIÉROGLYPHE ÉGYPTIEN-14352","	* phonémogramme : sṯꞽ"},
/* 14353 */ { "HIÉROGLYPHE ÉGYPTIEN-14353","	* phonémogramme : ḫnm"},
/* 14354 */ { "HIÉROGLYPHE ÉGYPTIEN-14354","	* phonémogramme : ḥm"},
/* 14355 */ { "HIÉROGLYPHE ÉGYPTIEN-14355","	* logogramme/phonémogramme (utérus) : kꜣ.t"},
/* 14356 */ { "HIÉROGLYPHE ÉGYPTIEN-14356","	* phonémogramme : šd"},
/* 14357 */ { "HIÉROGLYPHE ÉGYPTIEN-14357","	* logogramme (filet) : ꞽḥ/ꜥḥ"},
/* 14358 */ { "HIÉROGLYPHE ÉGYPTIEN-14358","	* logogramme (filet) : ꞽꜣd.t"},
/* 14359 */ { "HIÉROGLYPHE ÉGYPTIEN-14359","	* classificateur huile, onguent : ḥkn(w)"},
/* 1435A */ { "HIÉROGLYPHE ÉGYPTIEN-1435A","	* phonémogramme : bꜣs"},
/* 1435B */ { "HIÉROGLYPHE ÉGYPTIEN-1435B","	* phonémogramme : bꜣs"},
/* 1435C */ { "HIÉROGLYPHE ÉGYPTIEN-1435C","	* classificateur huile, onguent : ꞽbr"},
/* 1435D */ { "HIÉROGLYPHE ÉGYPTIEN-1435D","	* classificateur huile, onguent : mḏ.t"},
/* 1435E */ { "HIÉROGLYPHE ÉGYPTIEN-1435E","	* classificateur liquide, fluide : (ꞽ)ḫ.t bnꞽ(.t)"},
/* 1435F */ { "HIÉROGLYPHE ÉGYPTIEN-1435F","	* classificateur huile, onguent : sgn"},
/* 14360 */ { "HIÉROGLYPHE ÉGYPTIEN-14360","	* classificateur huile, onguent : ḥꜣ.t(y)t"},
/* 14361 */ { "HIÉROGLYPHE ÉGYPTIEN-14361","	* classificateur/logogramme huile, onguent : mr(ḥ.t)"},
/* 14362 */ { "HIÉROGLYPHE ÉGYPTIEN-14362","	* logogramme/phonémogramme (huile, onguent) : mḏ.t(y)"},
/* 14363 */ { "HIÉROGLYPHE ÉGYPTIEN-14363","	* logogramme (seigneur) : nb"},
/* 14364 */ { "HIÉROGLYPHE ÉGYPTIEN-14364","	* logogramme (prêtre lecteur) : ẖr.y-ḥ(ꜣ)b.t"},
/* 14365 */ { "HIÉROGLYPHE ÉGYPTIEN-14365",NULL},
/* 14366 */ { "HIÉROGLYPHE ÉGYPTIEN-14366","	* phonémogramme : kꜣw"},
/* 14367 */ { "HIÉROGLYPHE ÉGYPTIEN-14367","	* phonémogramme : ẖnm"},
/* 14368 */ { "HIÉROGLYPHE ÉGYPTIEN-14368",NULL},
/* 14369 */ { "HIÉROGLYPHE ÉGYPTIEN-14369","	* phonémogramme : ẖnm"},
/* 1436A */ { "HIÉROGLYPHE ÉGYPTIEN-1436A","	* phonémogramme : ẖnm"},
/* 1436B */ { "HIÉROGLYPHE ÉGYPTIEN-1436B","	* phonémogramme : ẖnm"},
/* 1436C */ { "HIÉROGLYPHE ÉGYPTIEN-1436C","	* logogramme (coupe) : ꜥ"},
/* 1436D */ { "HIÉROGLYPHE ÉGYPTIEN-1436D","	* phonémogramme : g"},
/* 1436E */ { "HIÉROGLYPHE ÉGYPTIEN-1436E","	* classificateur jarre, récipient : snb.t"},
/* 1436F */ { "HIÉROGLYPHE ÉGYPTIEN-1436F","	* classificateur frais : ḳb"},
/* 14370 */ { "HIÉROGLYPHE ÉGYPTIEN-14370","	* classificateur être frais, rafraîchir : ḳbḥ"},
/* 14371 */ { "HIÉROGLYPHE ÉGYPTIEN-14371","	* logogramme (eau fraîche, eau de libation) : ḳbḥ.w"},
/* 14372 */ { "HIÉROGLYPHE ÉGYPTIEN-14372","	* classificateur verser, asperger : sṯ(ꞽ)"},
/* 14373 */ { "HIÉROGLYPHE ÉGYPTIEN-14373","	* logogramme (être frais, rafraîchir) : ḳbḥ"},
/* 14374 */ { "HIÉROGLYPHE ÉGYPTIEN-14374","	* logogramme (eau fraîche, eau de libation) : ḳbḥ.w"},
/* 14375 */ { "HIÉROGLYPHE ÉGYPTIEN-14375","	* logogramme (la (première) cataracte) : ḳbḥ.w"},
/* 14376 */ { "HIÉROGLYPHE ÉGYPTIEN-14376","	* phonémogramme/logogramme (dans ḳbḥ.wy (les deux sources, c'est-à-dire l'Égypte)) : ḳbḥ"},
/* 14377 */ { "HIÉROGLYPHE ÉGYPTIEN-14377","	* logogramme (les deux sources, c'est-à-dire l'Égypte) : ḳbḥ.wy"},
/* 14378 */ { "HIÉROGLYPHE ÉGYPTIEN-14378","	* logogramme (eau fraîche, eau de libation) : ḳbḥ.w"},
/* 14379 */ { "HIÉROGLYPHE ÉGYPTIEN-14379","	* phonémogramme : ḫnt"},
/* 1437A */ { "HIÉROGLYPHE ÉGYPTIEN-1437A","	* phonémogramme : ḫnt"},
/* 1437B */ { "HIÉROGLYPHE ÉGYPTIEN-1437B","	* phonémogramme : ḫnt"},
/* 1437C */ { "HIÉROGLYPHE ÉGYPTIEN-1437C","	* phonémogramme : ḫnt"},
/* 1437D */ { "HIÉROGLYPHE ÉGYPTIEN-1437D","	* phonémogramme : ḫnt"},
/* 1437E */ { "HIÉROGLYPHE ÉGYPTIEN-1437E",NULL},
/* 1437F */ { "HIÉROGLYPHE ÉGYPTIEN-1437F","	* phonémogramme : mꞽ"},
/* 14380 */ { "HIÉROGLYPHE ÉGYPTIEN-14380","	* classificateur lait : ꞽrṯ(.t)"},
/* 14381 */ { "HIÉROGLYPHE ÉGYPTIEN-14381","	* classificateur lait : ꞽrṯ.t"},
/* 14382 */ { "HIÉROGLYPHE ÉGYPTIEN-14382",NULL},
/* 14383 */ { "HIÉROGLYPHE ÉGYPTIEN-14383",NULL},
/* 14384 */ { "HIÉROGLYPHE ÉGYPTIEN-14384","	* phonémogramme : mꞽ"},
/* 14385 */ { "HIÉROGLYPHE ÉGYPTIEN-14385","	* classificateur récipient (situle ?) : wšb"},
/* 14386 */ { "HIÉROGLYPHE ÉGYPTIEN-14386","	* logogramme (être pur, être propre) : wꜥb"},
/* 14387 */ { "HIÉROGLYPHE ÉGYPTIEN-14387","	* classificateur déverser, vider : pnḳ"},
/* 14388 */ { "HIÉROGLYPHE ÉGYPTIEN-14388","	* phonémogramme : rd"},
/* 14389 */ { "HIÉROGLYPHE ÉGYPTIEN-14389","	* classificateur cruche à bière : nb.ty"},
/* 1438A */ { "HIÉROGLYPHE ÉGYPTIEN-1438A",NULL},
/* 1438B */ { "HIÉROGLYPHE ÉGYPTIEN-1438B","	* classificateur ivresse : tḫ.t"},
/* 1438C */ { "HIÉROGLYPHE ÉGYPTIEN-1438C","	* classificateur vin : ꞽrp"},
/* 1438D */ { "HIÉROGLYPHE ÉGYPTIEN-1438D",NULL},
/* 1438E */ { "HIÉROGLYPHE ÉGYPTIEN-1438E",NULL},
/* 1438F */ { "HIÉROGLYPHE ÉGYPTIEN-1438F","	* classificateur liquide, fluide : ꞽrp"},
/* 14390 */ { "HIÉROGLYPHE ÉGYPTIEN-14390","	* classificateur jarre : ḥn(.w)"},
/* 14391 */ { "HIÉROGLYPHE ÉGYPTIEN-14391","	* classificateur huile, onguent : mrḥ(.t)"},
/* 14392 */ { "HIÉROGLYPHE ÉGYPTIEN-14392","	* logogramme (les cinq pastilles) : ṯꜣ.w"},
/* 14393 */ { "HIÉROGLYPHE ÉGYPTIEN-14393","	* classificateur cruche : nms.t"},
/* 14394 */ { "HIÉROGLYPHE ÉGYPTIEN-14394",NULL},
/* 14395 */ { "HIÉROGLYPHE ÉGYPTIEN-14395","	* phonémogramme : ꞽn-ḥr"},
/* 14396 */ { "HIÉROGLYPHE ÉGYPTIEN-14396","	* phonémogramme : r"},
/* 14397 */ { "HIÉROGLYPHE ÉGYPTIEN-14397","	* logogramme (Éléphantine) : ꜣbw"},
/* 14398 */ { "HIÉROGLYPHE ÉGYPTIEN-14398",NULL},
/* 14399 */ { "HIÉROGLYPHE ÉGYPTIEN-14399","	* classificateur liquide, fluide : ḥḏ.t"},
/* 1439A */ { "HIÉROGLYPHE ÉGYPTIEN-1439A","	* classificateur jarre, récipient : dšr.yt"},
/* 1439B */ { "HIÉROGLYPHE ÉGYPTIEN-1439B","	* classificateur rupture, destruction : sḏ"},
/* 1439C */ { "HIÉROGLYPHE ÉGYPTIEN-1439C","	* classificateur boisson alcoolique : tḫ"},
/* 1439D */ { "HIÉROGLYPHE ÉGYPTIEN-1439D","	* logogramme (vase à libation) : šps.y"},
/* 1439E */ { "HIÉROGLYPHE ÉGYPTIEN-1439E","	* classificateur remplir : ꜥḥb.t"},
/* 1439F */ { "HIÉROGLYPHE ÉGYPTIEN-1439F","	* classificateur récipient : dšr.t"},
/* 143A0 */ { "HIÉROGLYPHE ÉGYPTIEN-143A0","	* classificateur jarre, récipient : nms.t"},
/* 143A1 */ { "HIÉROGLYPHE ÉGYPTIEN-143A1","	* classificateur jarre, récipient : nms.t"},
/* 143A2 */ { "HIÉROGLYPHE ÉGYPTIEN-143A2","	* classificateur laver : ꞽꜥꞽ"},
/* 143A3 */ { "HIÉROGLYPHE ÉGYPTIEN-143A3","	* logogramme (vase nemset) : nms.t"},
/* 143A4 */ { "HIÉROGLYPHE ÉGYPTIEN-143A4","	* classificateur récipient : ḏwj.w"},
/* 143A5 */ { "HIÉROGLYPHE ÉGYPTIEN-143A5","	* classificateur récipient, jarre : ṯꜣb"},
/* 143A6 */ { "HIÉROGLYPHE ÉGYPTIEN-143A6",NULL},
/* 143A7 */ { "HIÉROGLYPHE ÉGYPTIEN-143A7","	* classificateur jarre, récipient : nms.t"},
/* 143A8 */ { "HIÉROGLYPHE ÉGYPTIEN-143A8","	* classificateur récipient à boire : swr"},
/* 143A9 */ { "HIÉROGLYPHE ÉGYPTIEN-143A9","	* classificateur récipient à boire : ḫꜣw & (ṯ)nꞽw"},
/* 143AA */ { "HIÉROGLYPHE ÉGYPTIEN-143AA",NULL},
/* 143AB */ { "HIÉROGLYPHE ÉGYPTIEN-143AB","	* classificateur plat : dd.t"},
/* 143AC */ { "HIÉROGLYPHE ÉGYPTIEN-143AC",NULL},
/* 143AD */ { "HIÉROGLYPHE ÉGYPTIEN-143AD",NULL},
/* 143AE */ { "HIÉROGLYPHE ÉGYPTIEN-143AE","	* logogramme (un type de récipient) : ḏwꞽ.w"},
/* 143AF */ { "HIÉROGLYPHE ÉGYPTIEN-143AF","	* classificateur lait : ꞽrṯ.t"},
/* 143B0 */ { "HIÉROGLYPHE ÉGYPTIEN-143B0","	* classificateur récipient (possiblement pour contenir de l'huile) : bꜥ/bꜥꜥ"},
/* 143B1 */ { "HIÉROGLYPHE ÉGYPTIEN-143B1",NULL},
/* 143B2 */ { "HIÉROGLYPHE ÉGYPTIEN-143B2",NULL},
/* 143B3 */ { "HIÉROGLYPHE ÉGYPTIEN-143B3","	* logogramme (bière) : ḥnḳ.t"},
/* 143B4 */ { "HIÉROGLYPHE ÉGYPTIEN-143B4","	* logogramme (vase en or pour la myrrhe) : rrm"},
/* 143B5 */ { "HIÉROGLYPHE ÉGYPTIEN-143B5","	* classificateur four : kꜣp.t"},
/* 143B6 */ { "HIÉROGLYPHE ÉGYPTIEN-143B6",NULL},
/* 143B7 */ { "HIÉROGLYPHE ÉGYPTIEN-143B7","	* ?"},
/* 143B8 */ { "HIÉROGLYPHE ÉGYPTIEN-143B8","	* classificateur granite : mꜣṯ"},
/* 143B9 */ { "HIÉROGLYPHE ÉGYPTIEN-143B9","	* phonémogramme : ꜣw"},
/* 143BA */ { "HIÉROGLYPHE ÉGYPTIEN-143BA","	* logogramme (un vase nw, représentant une amulette en lapis-lazuli) : nw"},
/* 143BB */ { "HIÉROGLYPHE ÉGYPTIEN-143BB","	* classificateur bassin pour laver les pieds : mꜥ"},
/* 143BC */ { "HIÉROGLYPHE ÉGYPTIEN-143BC","	* logogramme (père) : ꞽt"},
/* 143BD */ { "HIÉROGLYPHE ÉGYPTIEN-143BD","	* logogramme (père) : ꞽt"},
/* 143BE */ { "HIÉROGLYPHE ÉGYPTIEN-143BE","	* logogramme (père) : ꞽt"},
/* 143BF */ { "HIÉROGLYPHE ÉGYPTIEN-143BF",NULL},
/* 143C0 */ { "HIÉROGLYPHE ÉGYPTIEN-143C0","	* classificateur pain : t"},
/* 143C1 */ { "HIÉROGLYPHE ÉGYPTIEN-143C1","	* classificateur pain : t-ḥḏ"},
/* 143C2 */ { "HIÉROGLYPHE ÉGYPTIEN-143C2","	* classificateur pain, nourriture : t"},
/* 143C3 */ { "HIÉROGLYPHE ÉGYPTIEN-143C3",NULL},
/* 143C4 */ { "HIÉROGLYPHE ÉGYPTIEN-143C4","	* classificateur nourriture : t ḥnḳ.t kꜣ ꜣpd"},
/* 143C5 */ { "HIÉROGLYPHE ÉGYPTIEN-143C5","	* classificateur fête : ꜣbd"},
/* 143C6 */ { "HIÉROGLYPHE ÉGYPTIEN-143C6","	* classificateur nourriture : kꜣ.w"},
/* 143C7 */ { "HIÉROGLYPHE ÉGYPTIEN-143C7","	* classificateur offrande : drp"},
/* 143C8 */ { "HIÉROGLYPHE ÉGYPTIEN-143C8","	* logogramme (type de pain) : šns"},
/* 143C9 */ { "HIÉROGLYPHE ÉGYPTIEN-143C9","	* logogramme (passer) : sn"},
/* 143CA */ { "HIÉROGLYPHE ÉGYPTIEN-143CA",NULL},
/* 143CB */ { "HIÉROGLYPHE ÉGYPTIEN-143CB","	* phonémogramme : pꜣ.t"},
/* 143CC */ { "HIÉROGLYPHE ÉGYPTIEN-143CC","	* classificateur offrande, gâteau, miche : ḥn.w(t)"},
/* 143CD */ { "HIÉROGLYPHE ÉGYPTIEN-143CD",NULL},
/* 143CE */ { "HIÉROGLYPHE ÉGYPTIEN-143CE","	* classificateur pain : t-ꞽm.y-tꜣ"},
/* 143CF */ { "HIÉROGLYPHE ÉGYPTIEN-143CF","	* classificateur mots abstraits : gr"},
/* 143D0 */ { "HIÉROGLYPHE ÉGYPTIEN-143D0","	* classificateur double flûte : mꜣ.t"},
/* 143D1 */ { "HIÉROGLYPHE ÉGYPTIEN-143D1","	* logogramme (écrire, dessiner) : sš"},
/* 143D2 */ { "HIÉROGLYPHE ÉGYPTIEN-143D2","	* logogramme (scribe) : sš"},
/* 143D3 */ { "HIÉROGLYPHE ÉGYPTIEN-143D3","	* classificateur rouge : ṯ(m)s"},
/* 143D4 */ { "HIÉROGLYPHE ÉGYPTIEN-143D4","	* classificateur palette de scribe : gsty"},
/* 143D5 */ { "HIÉROGLYPHE ÉGYPTIEN-143D5","	* classificateur godet à eau de scribe"},
/* 143D6 */ { "HIÉROGLYPHE ÉGYPTIEN-143D6",NULL},
/* 143D7 */ { "HIÉROGLYPHE ÉGYPTIEN-143D7","	* classificateur tablette d'écriture : ꜥn"},
/* 143D8 */ { "HIÉROGLYPHE ÉGYPTIEN-143D8","	* classificateur jeu du serpent : mḥn"},
/* 143D9 */ { "HIÉROGLYPHE ÉGYPTIEN-143D9","	* phonémogramme : ḏꜣ"},
/* 143DA */ { "HIÉROGLYPHE ÉGYPTIEN-143DA","	* phonémogramme : ṯt"},
/* 143DB */ { "HIÉROGLYPHE ÉGYPTIEN-143DB","	* logogramme (dire, parler) : ḏd"},
/* 143DC */ { "HIÉROGLYPHE ÉGYPTIEN-143DC","	* logogramme (dire, parler) : ḏd"},
/* 143DD */ { "HIÉROGLYPHE ÉGYPTIEN-143DD","	* logogramme (dire, parler) : ḏd"},
/* 143DE */ { "HIÉROGLYPHE ÉGYPTIEN-143DE","	* classificateur tambourin : sr"},
/* 143DF */ { "HIÉROGLYPHE ÉGYPTIEN-143DF","	* classificateur tambourin : sr"},
/* 143E0 */ { "HIÉROGLYPHE ÉGYPTIEN-143E0","	* logogramme (balle) : ḥmꜣ"},
/* 143E1 */ { "HIÉROGLYPHE ÉGYPTIEN-143E1","	* classificateur sistre : sšš(.t)"},
/* 143E2 */ { "HIÉROGLYPHE ÉGYPTIEN-143E2","	* logogramme (sistre) : sḫm"},
/* 143E3 */ { "HIÉROGLYPHE ÉGYPTIEN-143E3","	* classificateur sistre : sḫm"},
/* 143E4 */ { "HIÉROGLYPHE ÉGYPTIEN-143E4","	* logogramme (sistre) : sšš.t"},
/* 143E5 */ { "HIÉROGLYPHE ÉGYPTIEN-143E5","	* logogramme (sistre) : sšš.t"},
/* 143E6 */ { "HIÉROGLYPHE ÉGYPTIEN-143E6","	* classificateur tête d'un sistre : bḫn"},
/* 143E7 */ { "HIÉROGLYPHE ÉGYPTIEN-143E7","	* classificateur pluriel"},
/* 143E8 */ { "HIÉROGLYPHE ÉGYPTIEN-143E8",NULL},
/* 143E9 */ { "HIÉROGLYPHE ÉGYPTIEN-143E9","	* phonémogramme : ꞽm.y"},
/* 143EA */ { "HIÉROGLYPHE ÉGYPTIEN-143EA","	* phonémogramme : ꞽm.y"},
/* 143EB */ { "HIÉROGLYPHE ÉGYPTIEN-143EB",NULL},
/* 143EC */ { "HIÉROGLYPHE ÉGYPTIEN-143EC",NULL},
/* 143ED */ { "HIÉROGLYPHE ÉGYPTIEN-143ED",NULL},
/* 143EE */ { "HIÉROGLYPHE ÉGYPTIEN-143EE","	* logogramme (1/2 aroure) : rmn"},
/* 143EF */ { "HIÉROGLYPHE ÉGYPTIEN-143EF","	* classificateur tablette d'écriture : ꜥn"},
/* 143F0 */ { "HIÉROGLYPHE ÉGYPTIEN-143F0","	* classificateur ennemi, adversaire : pꜣ tꜣ-r"},
/* 143F1 */ { "HIÉROGLYPHE ÉGYPTIEN-143F1",NULL},
/* 143F2 */ { "HIÉROGLYPHE ÉGYPTIEN-143F2",NULL},
/* 143F3 */ { "HIÉROGLYPHE ÉGYPTIEN-143F3",NULL},
/* 143F4 */ { "HIÉROGLYPHE ÉGYPTIEN-143F4",NULL},
/* 143F5 */ { "HIÉROGLYPHE ÉGYPTIEN-143F5",NULL},
/* 143F6 */ { "HIÉROGLYPHE ÉGYPTIEN-143F6",NULL},
/* 143F7 */ { "HIÉROGLYPHE ÉGYPTIEN-143F7","	* logogramme : ḏd-mdw"},
/* 143F8 */ { "HIÉROGLYPHE ÉGYPTIEN-143F8","	* phonémogramme : smꜣ"},
/* 143F9 */ { "HIÉROGLYPHE ÉGYPTIEN-143F9",NULL},
/* 143FA */ { "HIÉROGLYPHE ÉGYPTIEN-143FA","	* phonémogramme : ꜣb"},
/* 143FB */ { NULL,NULL},
/* 143FC */ { NULL,NULL},
/* 143FD */ { NULL,NULL},
/* 143FE */ { NULL,NULL},
/* 143FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_44[] = {
/* 14400 */ { "HIÉROGLYPHE ANATOLIEN A001","	= ego"},
/* 14401 */ { "HIÉROGLYPHE ANATOLIEN A002","	= ego2"},
/* 14402 */ { "HIÉROGLYPHE ANATOLIEN A003",NULL},
/* 14403 */ { "HIÉROGLYPHE ANATOLIEN A004","	= mons2"},
/* 14404 */ { "HIÉROGLYPHE ANATOLIEN A005",NULL},
/* 14405 */ { "HIÉROGLYPHE ANATOLIEN A006","	= adorare"},
/* 14406 */ { "HIÉROGLYPHE ANATOLIEN A007","	= edere"},
/* 14407 */ { "HIÉROGLYPHE ANATOLIEN A008","	= bibere"},
/* 14408 */ { "HIÉROGLYPHE ANATOLIEN A009","	= amplecti"},
/* 14409 */ { "HIÉROGLYPHE ANATOLIEN A010","	= caput"},
/* 1440A */ { "HIÉROGLYPHE ANATOLIEN A010A","	= caput+scalprum"},
/* 1440B */ { "HIÉROGLYPHE ANATOLIEN A011",NULL},
/* 1440C */ { "HIÉROGLYPHE ANATOLIEN A012","	= statua"},
/* 1440D */ { "HIÉROGLYPHE ANATOLIEN A013",NULL},
/* 1440E */ { "HIÉROGLYPHE ANATOLIEN A014","	= prae\n"
	"	= « pari » logosyllabique"},
/* 1440F */ { "HIÉROGLYPHE ANATOLIEN A015","	= domina"},
/* 14410 */ { "HIÉROGLYPHE ANATOLIEN A016","	= magnus.domina"},
/* 14411 */ { "HIÉROGLYPHE ANATOLIEN A017","	= rex"},
/* 14412 */ { "HIÉROGLYPHE ANATOLIEN A018","	= magnus.rex"},
/* 14413 */ { "HIÉROGLYPHE ANATOLIEN A019","	= « á » syllabique"},
/* 14414 */ { "HIÉROGLYPHE ANATOLIEN A020",NULL},
/* 14415 */ { "HIÉROGLYPHE ANATOLIEN A021","	= heros"},
/* 14416 */ { "HIÉROGLYPHE ANATOLIEN A022","	= loqui"},
/* 14417 */ { "HIÉROGLYPHE ANATOLIEN A023",NULL},
/* 14418 */ { "HIÉROGLYPHE ANATOLIEN A024","	= lis"},
/* 14419 */ { "HIÉROGLYPHE ANATOLIEN A025","	= oculus"},
/* 1441A */ { "HIÉROGLYPHE ANATOLIEN A026","	= frons"},
/* 1441B */ { "HIÉROGLYPHE ANATOLIEN A026A","	= versus"},
/* 1441C */ { "HIÉROGLYPHE ANATOLIEN A027","	= libare"},
/* 1441D */ { "HIÉROGLYPHE ANATOLIEN A028","	= fortis"},
/* 1441E */ { "HIÉROGLYPHE ANATOLIEN A029","	= « tá » syllabique"},
/* 1441F */ { "HIÉROGLYPHE ANATOLIEN A030",NULL},
/* 14420 */ { "HIÉROGLYPHE ANATOLIEN A031","	= ligare, pugnus+pugnus"},
/* 14421 */ { "HIÉROGLYPHE ANATOLIEN A032","	= bracchium"},
/* 14422 */ { "HIÉROGLYPHE ANATOLIEN A033",NULL},
/* 14423 */ { "HIÉROGLYPHE ANATOLIEN A034","	= post"},
/* 14424 */ { "HIÉROGLYPHE ANATOLIEN A035","	= « na » syllabique"},
/* 14425 */ { "HIÉROGLYPHE ANATOLIEN A036","	= lituus+na"},
/* 14426 */ { "HIÉROGLYPHE ANATOLIEN A037",NULL},
/* 14427 */ { "HIÉROGLYPHE ANATOLIEN A038",NULL},
/* 14428 */ { "HIÉROGLYPHE ANATOLIEN A039","	= pugnus"},
/* 14429 */ { "HIÉROGLYPHE ANATOLIEN A039A","	= pugnus+x"},
/* 1442A */ { "HIÉROGLYPHE ANATOLIEN A040",NULL},
/* 1442B */ { "HIÉROGLYPHE ANATOLIEN A041","	= capere\n"
	"	= « tà » syllabique"},
/* 1442C */ { "HIÉROGLYPHE ANATOLIEN A041A","	= « tà » syllabique"},
/* 1442D */ { "HIÉROGLYPHE ANATOLIEN A042","	= capere2.capere2\n"
	"	= « ta-x? » syllabique"},
/* 1442E */ { "HIÉROGLYPHE ANATOLIEN A043","	= capere2"},
/* 1442F */ { "HIÉROGLYPHE ANATOLIEN A044",NULL},
/* 14430 */ { "HIÉROGLYPHE ANATOLIEN A045","	= infans, filius, frater"},
/* 14431 */ { "HIÉROGLYPHE ANATOLIEN A045A","	= filia"},
/* 14432 */ { "HIÉROGLYPHE ANATOLIEN A046","	= rex.infans, rex.filius"},
/* 14433 */ { "HIÉROGLYPHE ANATOLIEN A046A","	= rex.filia"},
/* 14434 */ { "HIÉROGLYPHE ANATOLIEN A046B","	= magnus.filia"},
/* 14435 */ { "HIÉROGLYPHE ANATOLIEN A047",NULL},
/* 14436 */ { "HIÉROGLYPHE ANATOLIEN A048",NULL},
/* 14437 */ { "HIÉROGLYPHE ANATOLIEN A049","	= « a+tá » syllabique"},
/* 14438 */ { "HIÉROGLYPHE ANATOLIEN A050",NULL},
/* 14439 */ { "HIÉROGLYPHE ANATOLIEN A051",NULL},
/* 1443A */ { "HIÉROGLYPHE ANATOLIEN A052","	= manus.culter"},
/* 1443B */ { "HIÉROGLYPHE ANATOLIEN A053","	= manus+culter, ensis"},
/* 1443C */ { "HIÉROGLYPHE ANATOLIEN A054",NULL},
/* 1443D */ { "HIÉROGLYPHE ANATOLIEN A055","	= « nì » syllabique"},
/* 1443E */ { "HIÉROGLYPHE ANATOLIEN A056","	= « ká » syllabique"},
/* 1443F */ { "HIÉROGLYPHE ANATOLIEN A057","	= infra, sub\n"
	"	= « ká » syllabique"},
/* 14440 */ { "HIÉROGLYPHE ANATOLIEN A058","	= cum"},
/* 14441 */ { "HIÉROGLYPHE ANATOLIEN A059","	= manus"},
/* 14442 */ { "HIÉROGLYPHE ANATOLIEN A060",NULL},
/* 14443 */ { "HIÉROGLYPHE ANATOLIEN A061",NULL},
/* 14444 */ { "HIÉROGLYPHE ANATOLIEN A062","	= longus, manus+minus?"},
/* 14445 */ { "HIÉROGLYPHE ANATOLIEN A063",NULL},
/* 14446 */ { "HIÉROGLYPHE ANATOLIEN A064",NULL},
/* 14447 */ { "HIÉROGLYPHE ANATOLIEN A065","	= ponere"},
/* 14448 */ { "HIÉROGLYPHE ANATOLIEN A066","	= dare\n"
	"	= « pi » syllabique"},
/* 14449 */ { "HIÉROGLYPHE ANATOLIEN A066A","	= « pi » syllabique"},
/* 1444A */ { "HIÉROGLYPHE ANATOLIEN A066B","	= mandare, dare.dare"},
/* 1444B */ { "HIÉROGLYPHE ANATOLIEN A066C","	= mandare2"},
/* 1444C */ { "HIÉROGLYPHE ANATOLIEN A067",NULL},
/* 1444D */ { "HIÉROGLYPHE ANATOLIEN A068",NULL},
/* 1444E */ { "HIÉROGLYPHE ANATOLIEN A069",NULL},
/* 1444F */ { "HIÉROGLYPHE ANATOLIEN A070","	= super\n"
	"	= « sara/i » logosyllabique"},
/* 14450 */ { "HIÉROGLYPHE ANATOLIEN A071",NULL},
/* 14451 */ { "HIÉROGLYPHE ANATOLIEN A072",NULL},
/* 14452 */ { "HIÉROGLYPHE ANATOLIEN A073","	= audire, auris+tu+mi"},
/* 14453 */ { "HIÉROGLYPHE ANATOLIEN A074",NULL},
/* 14454 */ { "HIÉROGLYPHE ANATOLIEN A075",NULL},
/* 14455 */ { "HIÉROGLYPHE ANATOLIEN A076",NULL},
/* 14456 */ { "HIÉROGLYPHE ANATOLIEN A077",NULL},
/* 14457 */ { "HIÉROGLYPHE ANATOLIEN A078","	= ala"},
/* 14458 */ { "HIÉROGLYPHE ANATOLIEN A079","	= femina, mater"},
/* 14459 */ { "HIÉROGLYPHE ANATOLIEN A080","	= Sarma"},
/* 1445A */ { "HIÉROGLYPHE ANATOLIEN A081","	= Sarma2"},
/* 1445B */ { "HIÉROGLYPHE ANATOLIEN A082","	= crus\n"
	"	= « ta6 » syllabique"},
/* 1445C */ { "HIÉROGLYPHE ANATOLIEN A083","	= crus+flumen"},
/* 1445D */ { "HIÉROGLYPHE ANATOLIEN A084","	= crus2\n"
	"	= « nà » syllabique"},
/* 1445E */ { "HIÉROGLYPHE ANATOLIEN A085","	= genuflectere"},
/* 1445F */ { "HIÉROGLYPHE ANATOLIEN A086","	= crus.crus"},
/* 14460 */ { "HIÉROGLYPHE ANATOLIEN A087",NULL},
/* 14461 */ { "HIÉROGLYPHE ANATOLIEN A088",NULL},
/* 14462 */ { "HIÉROGLYPHE ANATOLIEN A089","	= « tu » syllabique"},
/* 14463 */ { "HIÉROGLYPHE ANATOLIEN A090","	= pes\n"
	"	= « ti » syllabique"},
/* 14464 */ { "HIÉROGLYPHE ANATOLIEN A091","	= pes.scala.rotae"},
/* 14465 */ { "HIÉROGLYPHE ANATOLIEN A092",NULL},
/* 14466 */ { "HIÉROGLYPHE ANATOLIEN A093","	= pes2"},
/* 14467 */ { "HIÉROGLYPHE ANATOLIEN A094",NULL},
/* 14468 */ { "HIÉROGLYPHE ANATOLIEN A095","	= pes2.pes2"},
/* 14469 */ { "HIÉROGLYPHE ANATOLIEN A096","	= pes2.pes"},
/* 1446A */ { "HIÉROGLYPHE ANATOLIEN A097","	= leo, bestia"},
/* 1446B */ { "HIÉROGLYPHE ANATOLIEN A097A","	= leo2"},
/* 1446C */ { "HIÉROGLYPHE ANATOLIEN A098","	= canis"},
/* 1446D */ { "HIÉROGLYPHE ANATOLIEN A098A","	= canis2"},
/* 1446E */ { "HIÉROGLYPHE ANATOLIEN A099","	= equus"},
/* 1446F */ { "HIÉROGLYPHE ANATOLIEN A100","	= asinus\n"
	"	= « ta » syllabique"},
/* 14470 */ { "HIÉROGLYPHE ANATOLIEN A100A","	= « ta » syllabique"},
/* 14471 */ { "HIÉROGLYPHE ANATOLIEN A101","	= asinus2"},
/* 14472 */ { "HIÉROGLYPHE ANATOLIEN A101A","	= asinus2a"},
/* 14473 */ { "HIÉROGLYPHE ANATOLIEN A102","	= cervus\n"
	"	= « rú » syllabique"},
/* 14474 */ { "HIÉROGLYPHE ANATOLIEN A102A","	= cervus2\n"
	"	= « rú » syllabique"},
/* 14475 */ { "HIÉROGLYPHE ANATOLIEN A103","	= cervus3\n"
	"	= « rú » syllabique"},
/* 14476 */ { "HIÉROGLYPHE ANATOLIEN A104","	= capra\n"
	"	= « sà » syllabique"},
/* 14477 */ { "HIÉROGLYPHE ANATOLIEN A104A","	= « sà » syllabique"},
/* 14478 */ { "HIÉROGLYPHE ANATOLIEN A104B","	= capra2\n"
	"	= « sà » syllabique"},
/* 14479 */ { "HIÉROGLYPHE ANATOLIEN A104C","	= capra2a\n"
	"	= « sà » syllabique"},
/* 1447A */ { "HIÉROGLYPHE ANATOLIEN A105","	= bos\n"
	"	= « u » syllabique"},
/* 1447B */ { "HIÉROGLYPHE ANATOLIEN A105A","	= bos\n"
	"	= « u » syllabique"},
/* 1447C */ { "HIÉROGLYPHE ANATOLIEN A105B","	= bos2\n"
	"	= « u » syllabique"},
/* 1447D */ { "HIÉROGLYPHE ANATOLIEN A106",NULL},
/* 1447E */ { "HIÉROGLYPHE ANATOLIEN A107","	= bos+mi\n"
	"	= « mu » syllabique\n"
	"	= « muwa » logosyllabique"},
/* 1447F */ { "HIÉROGLYPHE ANATOLIEN A107A","	= « mu » syllabique\n"
	"	= « muwa » logosyllabique"},
/* 14480 */ { "HIÉROGLYPHE ANATOLIEN A107B","	= bos.mi\n"
	"	= « mu » syllabique\n"
	"	= « muwa » logosyllabique"},
/* 14481 */ { "HIÉROGLYPHE ANATOLIEN A107C","	= bos2.mi\n"
	"	= « mu » syllabique\n"
	"	= « muwa » logosyllabique"},
/* 14482 */ { "HIÉROGLYPHE ANATOLIEN A108","	= cornu\n"
	"	= sú"},
/* 14483 */ { "HIÉROGLYPHE ANATOLIEN A109","	= vitellus\n"
	"	= « ma-x » syllabique"},
/* 14484 */ { "HIÉROGLYPHE ANATOLIEN A110","	= ovis\n"
	"	= « ma » syllabique"},
/* 14485 */ { "HIÉROGLYPHE ANATOLIEN A110A","	= « ma » syllabique"},
/* 14486 */ { "HIÉROGLYPHE ANATOLIEN A110B","	= ovis2\n"
	"	= « ma » syllabique"},
/* 14487 */ { "HIÉROGLYPHE ANATOLIEN A111","	= ovis3"},
/* 14488 */ { "HIÉROGLYPHE ANATOLIEN A112","	= lingere\n"
	"	= « za4 » syllabique"},
/* 14489 */ { "HIÉROGLYPHE ANATOLIEN A113",NULL},
/* 1448A */ { "HIÉROGLYPHE ANATOLIEN A114","	= lituus+u"},
/* 1448B */ { "HIÉROGLYPHE ANATOLIEN A115","	= lepus\n"
	"	= « tapa » logosyllabique"},
/* 1448C */ { "HIÉROGLYPHE ANATOLIEN A115A","	= lepus2\n"
	"	= « tapa » logosyllabique"},
/* 1448D */ { "HIÉROGLYPHE ANATOLIEN A116",NULL},
/* 1448E */ { "HIÉROGLYPHE ANATOLIEN A117",NULL},
/* 1448F */ { "HIÉROGLYPHE ANATOLIEN A118",NULL},
/* 14490 */ { "HIÉROGLYPHE ANATOLIEN A119",NULL},
/* 14491 */ { "HIÉROGLYPHE ANATOLIEN A120","	= gryllus"},
/* 14492 */ { "HIÉROGLYPHE ANATOLIEN A121","	= sphinx"},
/* 14493 */ { "HIÉROGLYPHE ANATOLIEN A122",NULL},
/* 14494 */ { "HIÉROGLYPHE ANATOLIEN A123",NULL},
/* 14495 */ { "HIÉROGLYPHE ANATOLIEN A124",NULL},
/* 14496 */ { "HIÉROGLYPHE ANATOLIEN A125","	= « lí » syllabique"},
/* 14497 */ { "HIÉROGLYPHE ANATOLIEN A125A","	= ungula\n"
	"	= « li-x » syllabique"},
/* 14498 */ { "HIÉROGLYPHE ANATOLIEN A126",NULL},
/* 14499 */ { "HIÉROGLYPHE ANATOLIEN A127",NULL},
/* 1449A */ { "HIÉROGLYPHE ANATOLIEN A128","	= avis\n"
	"	= zi4"},
/* 1449B */ { "HIÉROGLYPHE ANATOLIEN A129",NULL},
/* 1449C */ { "HIÉROGLYPHE ANATOLIEN A130","	= avis3"},
/* 1449D */ { "HIÉROGLYPHE ANATOLIEN A131","	= avis5"},
/* 1449E */ { "HIÉROGLYPHE ANATOLIEN A132","	= avis2"},
/* 1449F */ { "HIÉROGLYPHE ANATOLIEN A133","	= aquila, avis4\n"
	"	= « ara/i » syllabique"},
/* 144A0 */ { "HIÉROGLYPHE ANATOLIEN A134","	= « ara/i » syllabique\n"
	"	* 1449F hiéroglyphe anatolien a133 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 144A1 */ { "HIÉROGLYPHE ANATOLIEN A135","	= avis-x"},
/* 144A2 */ { "HIÉROGLYPHE ANATOLIEN A135A",NULL},
/* 144A3 */ { "HIÉROGLYPHE ANATOLIEN A136",NULL},
/* 144A4 */ { "HIÉROGLYPHE ANATOLIEN A137","	= libatio"},
/* 144A5 */ { "HIÉROGLYPHE ANATOLIEN A138","	= piscis"},
/* 144A6 */ { "HIÉROGLYPHE ANATOLIEN A139",NULL},
/* 144A7 */ { "HIÉROGLYPHE ANATOLIEN A140",NULL},
/* 144A8 */ { "HIÉROGLYPHE ANATOLIEN A141",NULL},
/* 144A9 */ { "HIÉROGLYPHE ANATOLIEN A142",NULL},
/* 144AA */ { "HIÉROGLYPHE ANATOLIEN A143",NULL},
/* 144AB */ { "HIÉROGLYPHE ANATOLIEN A144",NULL},
/* 144AC */ { "HIÉROGLYPHE ANATOLIEN A145",NULL},
/* 144AD */ { "HIÉROGLYPHE ANATOLIEN A146",NULL},
/* 144AE */ { "HIÉROGLYPHE ANATOLIEN A147",NULL},
/* 144AF */ { "HIÉROGLYPHE ANATOLIEN A148","	= Janus"},
/* 144B0 */ { "HIÉROGLYPHE ANATOLIEN A149",NULL},
/* 144B1 */ { "HIÉROGLYPHE ANATOLIEN A150",NULL},
/* 144B2 */ { "HIÉROGLYPHE ANATOLIEN A151","	= Telipinu"},
/* 144B3 */ { "HIÉROGLYPHE ANATOLIEN A152",NULL},
/* 144B4 */ { "HIÉROGLYPHE ANATOLIEN A153","	= « nu » syllabique"},
/* 144B5 */ { "HIÉROGLYPHE ANATOLIEN A154",NULL},
/* 144B6 */ { "HIÉROGLYPHE ANATOLIEN A155",NULL},
/* 144B7 */ { "HIÉROGLYPHE ANATOLIEN A156",NULL},
/* 144B8 */ { "HIÉROGLYPHE ANATOLIEN A157",NULL},
/* 144B9 */ { "HIÉROGLYPHE ANATOLIEN A158",NULL},
/* 144BA */ { "HIÉROGLYPHE ANATOLIEN A159",NULL},
/* 144BB */ { "HIÉROGLYPHE ANATOLIEN A160","	= vitis\n"
	"	= « wi(ya) » syllabique"},
/* 144BC */ { "HIÉROGLYPHE ANATOLIEN A161",NULL},
/* 144BD */ { "HIÉROGLYPHE ANATOLIEN A162",NULL},
/* 144BE */ { "HIÉROGLYPHE ANATOLIEN A163",NULL},
/* 144BF */ { "HIÉROGLYPHE ANATOLIEN A164",NULL},
/* 144C0 */ { "HIÉROGLYPHE ANATOLIEN A165","	= bonus\n"
	"	= « wà/ì » syllabique"},
/* 144C1 */ { "HIÉROGLYPHE ANATOLIEN A166","	= « wá/í » syllabique"},
/* 144C2 */ { "HIÉROGLYPHE ANATOLIEN A167",NULL},
/* 144C3 */ { "HIÉROGLYPHE ANATOLIEN A168",NULL},
/* 144C4 */ { "HIÉROGLYPHE ANATOLIEN A169",NULL},
/* 144C5 */ { "HIÉROGLYPHE ANATOLIEN A170",NULL},
/* 144C6 */ { "HIÉROGLYPHE ANATOLIEN A171",NULL},
/* 144C7 */ { "HIÉROGLYPHE ANATOLIEN A172","	= « ta/i5, lá/í » syllabique"},
/* 144C8 */ { "HIÉROGLYPHE ANATOLIEN A173","	= hastarius"},
/* 144C9 */ { "HIÉROGLYPHE ANATOLIEN A174","	= « si » syllabique"},
/* 144CA */ { "HIÉROGLYPHE ANATOLIEN A175","	= lingua\n"
	"	= « la » syllabique"},
/* 144CB */ { "HIÉROGLYPHE ANATOLIEN A176","	= « la+la » syllabique"},
/* 144CC */ { "HIÉROGLYPHE ANATOLIEN A177","	= lingua+clavus"},
/* 144CD */ { "HIÉROGLYPHE ANATOLIEN A178","	= « la+ra+a » syllabique"},
/* 144CE */ { "HIÉROGLYPHE ANATOLIEN A179","	= hordeum\n"
	"	= « hwi-x » syllabique"},
/* 144CF */ { "HIÉROGLYPHE ANATOLIEN A180",NULL},
/* 144D0 */ { "HIÉROGLYPHE ANATOLIEN A181","	= panis\n"
	"	= « pa-x » syllabique"},
/* 144D1 */ { "HIÉROGLYPHE ANATOLIEN A182","	= caelum"},
/* 144D2 */ { "HIÉROGLYPHE ANATOLIEN A183",NULL},
/* 144D3 */ { "HIÉROGLYPHE ANATOLIEN A184",NULL},
/* 144D4 */ { "HIÉROGLYPHE ANATOLIEN A185",NULL},
/* 144D5 */ { "HIÉROGLYPHE ANATOLIEN A186",NULL},
/* 144D6 */ { "HIÉROGLYPHE ANATOLIEN A187",NULL},
/* 144D7 */ { "HIÉROGLYPHE ANATOLIEN A188",NULL},
/* 144D8 */ { "HIÉROGLYPHE ANATOLIEN A189",NULL},
/* 144D9 */ { "HIÉROGLYPHE ANATOLIEN A190","	= sol2"},
/* 144DA */ { "HIÉROGLYPHE ANATOLIEN A191","	= sol"},
/* 144DB */ { "HIÉROGLYPHE ANATOLIEN A192","	= oriens"},
/* 144DC */ { "HIÉROGLYPHE ANATOLIEN A193","	= luna"},
/* 144DD */ { "HIÉROGLYPHE ANATOLIEN A194",NULL},
/* 144DE */ { "HIÉROGLYPHE ANATOLIEN A195",NULL},
/* 144DF */ { "HIÉROGLYPHE ANATOLIEN A196","	= Hatti\n"
	"	= « há » syllabique"},
/* 144E0 */ { "HIÉROGLYPHE ANATOLIEN A197","	= Hatti+li, Hattusili\n"
	"	= « há-li » logosyllabique"},
/* 144E1 */ { "HIÉROGLYPHE ANATOLIEN A198",NULL},
/* 144E2 */ { "HIÉROGLYPHE ANATOLIEN A199","	= tonitrus"},
/* 144E3 */ { "HIÉROGLYPHE ANATOLIEN A200","	= fulgur"},
/* 144E4 */ { "HIÉROGLYPHE ANATOLIEN A201","	= terra, locus\n"
	"	= « wa/i6 » syllabique"},
/* 144E5 */ { "HIÉROGLYPHE ANATOLIEN A202","	= via+terra.scalprum"},
/* 144E6 */ { "HIÉROGLYPHE ANATOLIEN A202A","	= via+terra+scalprum"},
/* 144E7 */ { "HIÉROGLYPHE ANATOLIEN A202B","	= (deus)via+terra"},
/* 144E8 */ { "HIÉROGLYPHE ANATOLIEN A203",NULL},
/* 144E9 */ { "HIÉROGLYPHE ANATOLIEN A204","	= « wa/i5 » syllabique"},
/* 144EA */ { "HIÉROGLYPHE ANATOLIEN A205",NULL},
/* 144EB */ { "HIÉROGLYPHE ANATOLIEN A206",NULL},
/* 144EC */ { "HIÉROGLYPHE ANATOLIEN A207","	= mons\n"
	"	= « wa/i5 » syllabique"},
/* 144ED */ { "HIÉROGLYPHE ANATOLIEN A207A","	= leo+mons.tu+leo"},
/* 144EE */ { "HIÉROGLYPHE ANATOLIEN A208",NULL},
/* 144EF */ { "HIÉROGLYPHE ANATOLIEN A209","	= « i, i(a) » syllabique"},
/* 144F0 */ { "HIÉROGLYPHE ANATOLIEN A209A","	= « i+ra/i, ri+i » syllabique\n"
	"	* 144EF hiéroglyphe anatolien a209 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 144F1 */ { "HIÉROGLYPHE ANATOLIEN A210","	= « ia » syllabique"},
/* 144F2 */ { "HIÉROGLYPHE ANATOLIEN A211",NULL},
/* 144F3 */ { "HIÉROGLYPHE ANATOLIEN A212","	= flumen"},
/* 144F4 */ { "HIÉROGLYPHE ANATOLIEN A213",NULL},
/* 144F5 */ { "HIÉROGLYPHE ANATOLIEN A214","	= « ní » syllabique"},
/* 144F6 */ { "HIÉROGLYPHE ANATOLIEN A215","	= fons"},
/* 144F7 */ { "HIÉROGLYPHE ANATOLIEN A215A","	= « ha » syllabique"},
/* 144F8 */ { "HIÉROGLYPHE ANATOLIEN A216","	= fines\n"
	"	= « arha » syllabique"},
/* 144F9 */ { "HIÉROGLYPHE ANATOLIEN A216A","	= fines+ha, arha"},
/* 144FA */ { "HIÉROGLYPHE ANATOLIEN A217",NULL},
/* 144FB */ { "HIÉROGLYPHE ANATOLIEN A218",NULL},
/* 144FC */ { "HIÉROGLYPHE ANATOLIEN A219",NULL},
/* 144FD */ { "HIÉROGLYPHE ANATOLIEN A220",NULL},
/* 144FE */ { "HIÉROGLYPHE ANATOLIEN A221","	= via"},
/* 144FF */ { "HIÉROGLYPHE ANATOLIEN A222",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_45[] = {
/* 14500 */ { "HIÉROGLYPHE ANATOLIEN A223","	= « sa6 » syllabique"},
/* 14501 */ { "HIÉROGLYPHE ANATOLIEN A224","	= « ha? pa? » syllabique"},
/* 14502 */ { "HIÉROGLYPHE ANATOLIEN A225","	= urbs"},
/* 14503 */ { "HIÉROGLYPHE ANATOLIEN A226","	= Ishuwa"},
/* 14504 */ { "HIÉROGLYPHE ANATOLIEN A227","	= urbs+ra/i?+li, urbs+ra/i?-li"},
/* 14505 */ { "HIÉROGLYPHE ANATOLIEN A227A","	= urbs+li, urbs-li, Mursili"},
/* 14506 */ { "HIÉROGLYPHE ANATOLIEN A228","	= regio\n"
	"	= « tu4 » syllabique"},
/* 14507 */ { "HIÉROGLYPHE ANATOLIEN A229","	= « mí.regio » syllabique"},
/* 14508 */ { "HIÉROGLYPHE ANATOLIEN A230",NULL},
/* 14509 */ { "HIÉROGLYPHE ANATOLIEN A231","	= castrum"},
/* 1450A */ { "HIÉROGLYPHE ANATOLIEN A232",NULL},
/* 1450B */ { "HIÉROGLYPHE ANATOLIEN A233",NULL},
/* 1450C */ { "HIÉROGLYPHE ANATOLIEN A234",NULL},
/* 1450D */ { "HIÉROGLYPHE ANATOLIEN A235","	= turris?"},
/* 1450E */ { "HIÉROGLYPHE ANATOLIEN A236","	= murus?"},
/* 1450F */ { "HIÉROGLYPHE ANATOLIEN A237","	= porta"},
/* 14510 */ { "HIÉROGLYPHE ANATOLIEN A238",NULL},
/* 14511 */ { "HIÉROGLYPHE ANATOLIEN A239","	= porta2"},
/* 14512 */ { "HIÉROGLYPHE ANATOLIEN A240",NULL},
/* 14513 */ { "HIÉROGLYPHE ANATOLIEN A241","	= « ki-x » syllabique"},
/* 14514 */ { "HIÉROGLYPHE ANATOLIEN A242",NULL},
/* 14515 */ { "HIÉROGLYPHE ANATOLIEN A243","	= cubitum"},
/* 14516 */ { "HIÉROGLYPHE ANATOLIEN A244","	= aedificium"},
/* 14517 */ { "HIÉROGLYPHE ANATOLIEN A245","	= vacuus, aedificium+minus"},
/* 14518 */ { "HIÉROGLYPHE ANATOLIEN A246","	= aedificare, aedificium.ponere"},
/* 14519 */ { "HIÉROGLYPHE ANATOLIEN A247","	= domus"},
/* 1451A */ { "HIÉROGLYPHE ANATOLIEN A248","	= delere, domus+minus"},
/* 1451B */ { "HIÉROGLYPHE ANATOLIEN A249","	= deus.domus"},
/* 1451C */ { "HIÉROGLYPHE ANATOLIEN A250","	= magnus.domus"},
/* 1451D */ { "HIÉROGLYPHE ANATOLIEN A251","	= domus+x"},
/* 1451E */ { "HIÉROGLYPHE ANATOLIEN A252","	= domus+scala"},
/* 1451F */ { "HIÉROGLYPHE ANATOLIEN A253",NULL},
/* 14520 */ { "HIÉROGLYPHE ANATOLIEN A254","	= eunuchus2"},
/* 14521 */ { "HIÉROGLYPHE ANATOLIEN A255","	= horreum"},
/* 14522 */ { "HIÉROGLYPHE ANATOLIEN A256",NULL},
/* 14523 */ { "HIÉROGLYPHE ANATOLIEN A257","	= argentum"},
/* 14524 */ { "HIÉROGLYPHE ANATOLIEN A258",NULL},
/* 14525 */ { "HIÉROGLYPHE ANATOLIEN A259",NULL},
/* 14526 */ { "HIÉROGLYPHE ANATOLIEN A260",NULL},
/* 14527 */ { "HIÉROGLYPHE ANATOLIEN A261",NULL},
/* 14528 */ { "HIÉROGLYPHE ANATOLIEN A262",NULL},
/* 14529 */ { "HIÉROGLYPHE ANATOLIEN A263",NULL},
/* 1452A */ { "HIÉROGLYPHE ANATOLIEN A264","	= podium"},
/* 1452B */ { "HIÉROGLYPHE ANATOLIEN A265",NULL},
/* 1452C */ { "HIÉROGLYPHE ANATOLIEN A266","	= pes.regio"},
/* 1452D */ { "HIÉROGLYPHE ANATOLIEN A267","	= stele, lapis+scalprum"},
/* 1452E */ { "HIÉROGLYPHE ANATOLIEN A267A","	= lapis"},
/* 1452F */ { "HIÉROGLYPHE ANATOLIEN A268","	= scalprum"},
/* 14530 */ { "HIÉROGLYPHE ANATOLIEN A269","	= exercitus"},
/* 14531 */ { "HIÉROGLYPHE ANATOLIEN A270",NULL},
/* 14532 */ { "HIÉROGLYPHE ANATOLIEN A271",NULL},
/* 14533 */ { "HIÉROGLYPHE ANATOLIEN A272","	= scutum"},
/* 14534 */ { "HIÉROGLYPHE ANATOLIEN A273",NULL},
/* 14535 */ { "HIÉROGLYPHE ANATOLIEN A274",NULL},
/* 14536 */ { "HIÉROGLYPHE ANATOLIEN A275",NULL},
/* 14537 */ { "HIÉROGLYPHE ANATOLIEN A276","	= frater2"},
/* 14538 */ { "HIÉROGLYPHE ANATOLIEN A277","	= iudex.la, iudex+la"},
/* 14539 */ { "HIÉROGLYPHE ANATOLIEN A278","	= « li » syllabique"},
/* 1453A */ { "HIÉROGLYPHE ANATOLIEN A279",NULL},
/* 1453B */ { "HIÉROGLYPHE ANATOLIEN A280","	= malleus\n"
	"	= « wa/i9 » syllabique"},
/* 1453C */ { "HIÉROGLYPHE ANATOLIEN A281","	= ascia"},
/* 1453D */ { "HIÉROGLYPHE ANATOLIEN A282",NULL},
/* 1453E */ { "HIÉROGLYPHE ANATOLIEN A283","	= « tuzzi » logosyllabique"},
/* 1453F */ { "HIÉROGLYPHE ANATOLIEN A284",NULL},
/* 14540 */ { "HIÉROGLYPHE ANATOLIEN A285","	= iaculum\n"
	"	= « zu? » syllabique\n"
	"	= « zuwa » logosyllabique"},
/* 14541 */ { "HIÉROGLYPHE ANATOLIEN A286","	= « wa/i7 » syllabique"},
/* 14542 */ { "HIÉROGLYPHE ANATOLIEN A287",NULL},
/* 14543 */ { "HIÉROGLYPHE ANATOLIEN A288","	= currus"},
/* 14544 */ { "HIÉROGLYPHE ANATOLIEN A289","	= auriga"},
/* 14545 */ { "HIÉROGLYPHE ANATOLIEN A289A","	= auriga2"},
/* 14546 */ { "HIÉROGLYPHE ANATOLIEN A290","	= « hara/i » syllabique\n"
	"	* 14548 hiéroglyphe anatolien a292 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 14547 */ { "HIÉROGLYPHE ANATOLIEN A291","	= « lì » syllabique"},
/* 14548 */ { "HIÉROGLYPHE ANATOLIEN A292","	= rota\n"
	"	= « hala/i » logosyllabique"},
/* 14549 */ { "HIÉROGLYPHE ANATOLIEN A293",NULL},
/* 1454A */ { "HIÉROGLYPHE ANATOLIEN A294","	= thronus, mensa"},
/* 1454B */ { "HIÉROGLYPHE ANATOLIEN A294A","	= thronus, mensa2\n"
	"	= Sarpa"},
/* 1454C */ { "HIÉROGLYPHE ANATOLIEN A295","	= sol2.thronus/mensa"},
/* 1454D */ { "HIÉROGLYPHE ANATOLIEN A296","	= (deus)mons.Sarpa, (deus)mons.mensa\n"
	"	= thronus"},
/* 1454E */ { "HIÉROGLYPHE ANATOLIEN A297",NULL},
/* 1454F */ { "HIÉROGLYPHE ANATOLIEN A298","	= thronus2"},
/* 14550 */ { "HIÉROGLYPHE ANATOLIEN A299","	= solium\n"
	"	= « í » syllabique"},
/* 14551 */ { "HIÉROGLYPHE ANATOLIEN A299A","	= « iá » syllabique"},
/* 14552 */ { "HIÉROGLYPHE ANATOLIEN A300","	= nepos"},
/* 14553 */ { "HIÉROGLYPHE ANATOLIEN A301","	= lectus"},
/* 14554 */ { "HIÉROGLYPHE ANATOLIEN A302",NULL},
/* 14555 */ { "HIÉROGLYPHE ANATOLIEN A303","	= « sara/i » syllabique\n"
	"	* 1456E hiéroglyphe anatolien a327 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 14556 */ { "HIÉROGLYPHE ANATOLIEN A304","	= « mà » syllabique"},
/* 14557 */ { "HIÉROGLYPHE ANATOLIEN A305","	= fusus"},
/* 14558 */ { "HIÉROGLYPHE ANATOLIEN A306","	= « hí » syllabique"},
/* 14559 */ { "HIÉROGLYPHE ANATOLIEN A307","	= « hu » syllabique"},
/* 1455A */ { "HIÉROGLYPHE ANATOLIEN A308",NULL},
/* 1455B */ { "HIÉROGLYPHE ANATOLIEN A309","	= crux"},
/* 1455C */ { "HIÉROGLYPHE ANATOLIEN A309A","	= crux2"},
/* 1455D */ { "HIÉROGLYPHE ANATOLIEN A310",NULL},
/* 1455E */ { "HIÉROGLYPHE ANATOLIEN A311",NULL},
/* 1455F */ { "HIÉROGLYPHE ANATOLIEN A312",NULL},
/* 14560 */ { "HIÉROGLYPHE ANATOLIEN A313","	= vir\n"
	"	= « zí » syllabique"},
/* 14561 */ { "HIÉROGLYPHE ANATOLIEN A314","	= « ha-x » syllabique"},
/* 14562 */ { "HIÉROGLYPHE ANATOLIEN A315","	= « kar » syllabique\n"
	"	* 14561 hiéroglyphe anatolien a314 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 14563 */ { "HIÉROGLYPHE ANATOLIEN A316","	= « sa7 » syllabique"},
/* 14564 */ { "HIÉROGLYPHE ANATOLIEN A317",NULL},
/* 14565 */ { "HIÉROGLYPHE ANATOLIEN A318","	= Teshub"},
/* 14566 */ { "HIÉROGLYPHE ANATOLIEN A319","	= « ta/i4, la/i » syllabique"},
/* 14567 */ { "HIÉROGLYPHE ANATOLIEN A320",NULL},
/* 14568 */ { "HIÉROGLYPHE ANATOLIEN A321",NULL},
/* 14569 */ { "HIÉROGLYPHE ANATOLIEN A322","	= purus"},
/* 1456A */ { "HIÉROGLYPHE ANATOLIEN A323",NULL},
/* 1456B */ { "HIÉROGLYPHE ANATOLIEN A324",NULL},
/* 1456C */ { "HIÉROGLYPHE ANATOLIEN A325","	= « tú » syllabique"},
/* 1456D */ { "HIÉROGLYPHE ANATOLIEN A326","	= scriba\n"
	"	= « tù » syllabique"},
/* 1456E */ { "HIÉROGLYPHE ANATOLIEN A327","	= sigillum\n"
	"	= « sa5 » syllabique"},
/* 1456F */ { "HIÉROGLYPHE ANATOLIEN A328","	= « pu » syllabique"},
/* 14570 */ { "HIÉROGLYPHE ANATOLIEN A329","	= rel\n"
	"	= « kwi/a » syllabique"},
/* 14571 */ { "HIÉROGLYPHE ANATOLIEN A329A",NULL},
/* 14572 */ { "HIÉROGLYPHE ANATOLIEN A330","	= capere+scalprum"},
/* 14573 */ { "HIÉROGLYPHE ANATOLIEN A331","	= avus"},
/* 14574 */ { "HIÉROGLYPHE ANATOLIEN A332A","	= neg"},
/* 14575 */ { "HIÉROGLYPHE ANATOLIEN A332B","	= neg2\n"
	"	= « ná » syllabique"},
/* 14576 */ { "HIÉROGLYPHE ANATOLIEN A332C","	= neg3"},
/* 14577 */ { "HIÉROGLYPHE ANATOLIEN A333",NULL},
/* 14578 */ { "HIÉROGLYPHE ANATOLIEN A334","	= « pa » syllabique"},
/* 14579 */ { "HIÉROGLYPHE ANATOLIEN A335","	= « zá » syllabique"},
/* 1457A */ { "HIÉROGLYPHE ANATOLIEN A336","	= annus, pithos.scutella, pithos\n"
	"	= « zì » syllabique"},
/* 1457B */ { "HIÉROGLYPHE ANATOLIEN A336A","	= « zì » syllabique"},
/* 1457C */ { "HIÉROGLYPHE ANATOLIEN A336B","	= « zà » syllabique"},
/* 1457D */ { "HIÉROGLYPHE ANATOLIEN A336C","	= « za-x » syllabique"},
/* 1457E */ { "HIÉROGLYPHE ANATOLIEN A337","	= pithos"},
/* 1457F */ { "HIÉROGLYPHE ANATOLIEN A338","	= culter"},
/* 14580 */ { "HIÉROGLYPHE ANATOLIEN A339",NULL},
/* 14581 */ { "HIÉROGLYPHE ANATOLIEN A340","	= annus+annus"},
/* 14582 */ { "HIÉROGLYPHE ANATOLIEN A341","	= vas"},
/* 14583 */ { "HIÉROGLYPHE ANATOLIEN A342",NULL},
/* 14584 */ { "HIÉROGLYPHE ANATOLIEN A343","	= pithos"},
/* 14585 */ { "HIÉROGLYPHE ANATOLIEN A344","	= contractus"},
/* 14586 */ { "HIÉROGLYPHE ANATOLIEN A345","	= urceus"},
/* 14587 */ { "HIÉROGLYPHE ANATOLIEN A346","	= poculum"},
/* 14588 */ { "HIÉROGLYPHE ANATOLIEN A347","	= « hú » syllabique"},
/* 14589 */ { "HIÉROGLYPHE ANATOLIEN A348",NULL},
/* 1458A */ { "HIÉROGLYPHE ANATOLIEN A349",NULL},
/* 1458B */ { "HIÉROGLYPHE ANATOLIEN A350",NULL},
/* 1458C */ { "HIÉROGLYPHE ANATOLIEN A351",NULL},
/* 1458D */ { "HIÉROGLYPHE ANATOLIEN A352",NULL},
/* 1458E */ { "HIÉROGLYPHE ANATOLIEN A353",NULL},
/* 1458F */ { "HIÉROGLYPHE ANATOLIEN A354",NULL},
/* 14590 */ { "HIÉROGLYPHE ANATOLIEN A355","	= sacerdos"},
/* 14591 */ { "HIÉROGLYPHE ANATOLIEN A356",NULL},
/* 14592 */ { "HIÉROGLYPHE ANATOLIEN A357",NULL},
/* 14593 */ { "HIÉROGLYPHE ANATOLIEN A358","	= dies"},
/* 14594 */ { "HIÉROGLYPHE ANATOLIEN A359",NULL},
/* 14595 */ { "HIÉROGLYPHE ANATOLIEN A359A",NULL},
/* 14596 */ { "HIÉROGLYPHE ANATOLIEN A360","	= deus"},
/* 14597 */ { "HIÉROGLYPHE ANATOLIEN A361",NULL},
/* 14598 */ { "HIÉROGLYPHE ANATOLIEN A362","	= « má » syllabique"},
/* 14599 */ { "HIÉROGLYPHE ANATOLIEN A363","	= magnus\n"
	"	= « ur » syllabique"},
/* 1459A */ { "HIÉROGLYPHE ANATOLIEN A364","	= « u » syllabique"},
/* 1459B */ { "HIÉROGLYPHE ANATOLIEN A364A","	= « mu » syllabique"},
/* 1459C */ { "HIÉROGLYPHE ANATOLIEN A365",NULL},
/* 1459D */ { "HIÉROGLYPHE ANATOLIEN A366","	= omnis(+mi)"},
/* 1459E */ { "HIÉROGLYPHE ANATOLIEN A367","	= « tala » logosyllabique"},
/* 1459F */ { "HIÉROGLYPHE ANATOLIEN A368","	= malus"},
/* 145A0 */ { "HIÉROGLYPHE ANATOLIEN A368A","	= malus2"},
/* 145A1 */ { "HIÉROGLYPHE ANATOLIEN A369","	= vita"},
/* 145A2 */ { "HIÉROGLYPHE ANATOLIEN A370","	= bonus2\n"
	"	= « su » syllabique"},
/* 145A3 */ { "HIÉROGLYPHE ANATOLIEN A371","	= iustitia, iudex"},
/* 145A4 */ { "HIÉROGLYPHE ANATOLIEN A371A","	= iudex+ra/i, tara/i-x\n"
	"	* 145A3 hiéroglyphe anatolien a371 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 145A5 */ { "HIÉROGLYPHE ANATOLIEN A372","	= sacerdos2"},
/* 145A6 */ { "HIÉROGLYPHE ANATOLIEN A373",NULL},
/* 145A7 */ { "HIÉROGLYPHE ANATOLIEN A374",NULL},
/* 145A8 */ { "HIÉROGLYPHE ANATOLIEN A375",NULL},
/* 145A9 */ { "HIÉROGLYPHE ANATOLIEN A376","	= « zi, zi/a » syllabique"},
/* 145AA */ { "HIÉROGLYPHE ANATOLIEN A377","	= « za » syllabique"},
/* 145AB */ { "HIÉROGLYPHE ANATOLIEN A378","	= lituus"},
/* 145AC */ { "HIÉROGLYPHE ANATOLIEN A379","	= occidens\n"
	"	= « ià » syllabique"},
/* 145AD */ { "HIÉROGLYPHE ANATOLIEN A380","	= un\n"
	"	= unus\n"
	"	= « sa8 » syllabique"},
/* 145AE */ { "HIÉROGLYPHE ANATOLIEN A381","	= minus"},
/* 145AF */ { "HIÉROGLYPHE ANATOLIEN A381A","	= mori, vir2.minus"},
/* 145B0 */ { "HIÉROGLYPHE ANATOLIEN A382","	= lignum"},
/* 145B1 */ { "HIÉROGLYPHE ANATOLIEN A383 RA OU RI","	x (hiéroglyphe anatolien a134 - 144A0)\n"
	"	x (hiéroglyphe anatolien a209a - 144F0)\n"
	"	x (hiéroglyphe anatolien a290 - 14546)\n"
	"	x (hiéroglyphe anatolien a303 - 14555)\n"
	"	x (hiéroglyphe anatolien a315 - 14562)\n"
	"	x (hiéroglyphe anatolien a371a - 145A4)\n"
	"	x (hiéroglyphe anatolien a389 - 145B9)\n"
	"	x (hiéroglyphe anatolien a450a - 145F8)"},
/* 145B2 */ { "HIÉROGLYPHE ANATOLIEN A383A","	= déterminant personnel"},
/* 145B3 */ { "HIÉROGLYPHE ANATOLIEN A384","	= deux"},
/* 145B4 */ { "HIÉROGLYPHE ANATOLIEN A385","	= deux"},
/* 145B5 */ { "HIÉROGLYPHE ANATOLIEN A386","	= vir2\n"
	"	= diviseur de mot"},
/* 145B6 */ { "HIÉROGLYPHE ANATOLIEN A386A","	= vir2a"},
/* 145B7 */ { "HIÉROGLYPHE ANATOLIEN A387","	= servus\n"
	"	= « mì » syllabique"},
/* 145B8 */ { "HIÉROGLYPHE ANATOLIEN A388","	= trois\n"
	"	= tara/i"},
/* 145B9 */ { "HIÉROGLYPHE ANATOLIEN A389","	= tara/i\n"
	"	* 145B8 hiéroglyphe anatolien a388 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 145BA */ { "HIÉROGLYPHE ANATOLIEN A390","	= dominus"},
/* 145BB */ { "HIÉROGLYPHE ANATOLIEN A391","	= quatre\n"
	"	= « mi » syllabique"},
/* 145BC */ { "HIÉROGLYPHE ANATOLIEN A392","	= cinq"},
/* 145BD */ { "HIÉROGLYPHE ANATOLIEN A393","	= huit"},
/* 145BE */ { "HIÉROGLYPHE ANATOLIEN A394",NULL},
/* 145BF */ { "HIÉROGLYPHE ANATOLIEN A395","	= neuf\n"
	"	= « nú » syllabique"},
/* 145C0 */ { "HIÉROGLYPHE ANATOLIEN A396",NULL},
/* 145C1 */ { "HIÉROGLYPHE ANATOLIEN A397","	= dix\n"
	"	= decem"},
/* 145C2 */ { "HIÉROGLYPHE ANATOLIEN A398",NULL},
/* 145C3 */ { "HIÉROGLYPHE ANATOLIEN A399","	= cent\n"
	"	= centum"},
/* 145C4 */ { "HIÉROGLYPHE ANATOLIEN A400","	= mille"},
/* 145C5 */ { "HIÉROGLYPHE ANATOLIEN A401",NULL},
/* 145C6 */ { "HIÉROGLYPHE ANATOLIEN A402","	= scutella\n"
	"	= « sa4 » syllabique"},
/* 145C7 */ { "HIÉROGLYPHE ANATOLIEN A403",NULL},
/* 145C8 */ { "HIÉROGLYPHE ANATOLIEN A404","	= animal"},
/* 145C9 */ { "HIÉROGLYPHE ANATOLIEN A405",NULL},
/* 145CA */ { "HIÉROGLYPHE ANATOLIEN A406",NULL},
/* 145CB */ { "HIÉROGLYPHE ANATOLIEN A407",NULL},
/* 145CC */ { "HIÉROGLYPHE ANATOLIEN A408",NULL},
/* 145CD */ { "HIÉROGLYPHE ANATOLIEN A409",NULL},
/* 145CE */ { "HIÉROGLYPHE ANATOLIEN A410 MARQUE DE DÉBUT DE LOGOGRAMME",NULL},
/* 145CF */ { "HIÉROGLYPHE ANATOLIEN A410A MARQUE DE FIN DE LOGOGRAMME",NULL},
/* 145D0 */ { "HIÉROGLYPHE ANATOLIEN A411","	= « ni » syllabique"},
/* 145D1 */ { "HIÉROGLYPHE ANATOLIEN A412","	= « ru » syllabique"},
/* 145D2 */ { "HIÉROGLYPHE ANATOLIEN A413","	= « hi » syllabique"},
/* 145D3 */ { "HIÉROGLYPHE ANATOLIEN A414",NULL},
/* 145D4 */ { "HIÉROGLYPHE ANATOLIEN A415","	= « sa » syllabique"},
/* 145D5 */ { "HIÉROGLYPHE ANATOLIEN A416",NULL},
/* 145D6 */ { "HIÉROGLYPHE ANATOLIEN A417","	= « sa-x » syllabique"},
/* 145D7 */ { "HIÉROGLYPHE ANATOLIEN A418",NULL},
/* 145D8 */ { "HIÉROGLYPHE ANATOLIEN A419","	= « mí » syllabique\n"
	"	= « urhi » logosyllabique"},
/* 145D9 */ { "HIÉROGLYPHE ANATOLIEN A420",NULL},
/* 145DA */ { "HIÉROGLYPHE ANATOLIEN A421","	= « us » syllabique"},
/* 145DB */ { "HIÉROGLYPHE ANATOLIEN A422","	= panis.scutella"},
/* 145DC */ { "HIÉROGLYPHE ANATOLIEN A423","	= « ku » syllabique"},
/* 145DD */ { "HIÉROGLYPHE ANATOLIEN A424",NULL},
/* 145DE */ { "HIÉROGLYPHE ANATOLIEN A425",NULL},
/* 145DF */ { "HIÉROGLYPHE ANATOLIEN A426",NULL},
/* 145E0 */ { "HIÉROGLYPHE ANATOLIEN A427",NULL},
/* 145E1 */ { "HIÉROGLYPHE ANATOLIEN A428",NULL},
/* 145E2 */ { "HIÉROGLYPHE ANATOLIEN A429","	= « tana » syllabique"},
/* 145E3 */ { "HIÉROGLYPHE ANATOLIEN A430","	= omnis2\n"
	"	= « pú » syllabique"},
/* 145E4 */ { "HIÉROGLYPHE ANATOLIEN A431",NULL},
/* 145E5 */ { "HIÉROGLYPHE ANATOLIEN A432","	= « zu? » syllabique"},
/* 145E6 */ { "HIÉROGLYPHE ANATOLIEN A433","	= « sá » syllabique"},
/* 145E7 */ { "HIÉROGLYPHE ANATOLIEN A434","	= « ka » syllabique"},
/* 145E8 */ { "HIÉROGLYPHE ANATOLIEN A435","	= « a-x? » syllabique"},
/* 145E9 */ { "HIÉROGLYPHE ANATOLIEN A436",NULL},
/* 145EA */ { "HIÉROGLYPHE ANATOLIEN A437",NULL},
/* 145EB */ { "HIÉROGLYPHE ANATOLIEN A438","	= pastor"},
/* 145EC */ { "HIÉROGLYPHE ANATOLIEN A439","	= « wa/i » syllabique"},
/* 145ED */ { "HIÉROGLYPHE ANATOLIEN A440",NULL},
/* 145EE */ { "HIÉROGLYPHE ANATOLIEN A441",NULL},
/* 145EF */ { "HIÉROGLYPHE ANATOLIEN A442",NULL},
/* 145F0 */ { "HIÉROGLYPHE ANATOLIEN A443",NULL},
/* 145F1 */ { "HIÉROGLYPHE ANATOLIEN A444",NULL},
/* 145F2 */ { "HIÉROGLYPHE ANATOLIEN A445","	= « la, li, lu » syllabique"},
/* 145F3 */ { "HIÉROGLYPHE ANATOLIEN A446","	= « ki » syllabique"},
/* 145F4 */ { "HIÉROGLYPHE ANATOLIEN A447","	= « ni-x » syllabique"},
/* 145F5 */ { "HIÉROGLYPHE ANATOLIEN A448","	= « sù?, zú? » syllabique"},
/* 145F6 */ { "HIÉROGLYPHE ANATOLIEN A449",NULL},
/* 145F7 */ { "HIÉROGLYPHE ANATOLIEN A450","	= « a » syllabique\n"
	"	= fin d'un mot"},
/* 145F8 */ { "HIÉROGLYPHE ANATOLIEN A450A","	= a+ra/i, ra+a\n"
	"	* 145F7 hiéroglyphe anatolien a450 + 145B1 hiéroglyphe anatolien a383 ra ou ri"},
/* 145F9 */ { "HIÉROGLYPHE ANATOLIEN A451","	= « huru » logosyllabique"},
/* 145FA */ { "HIÉROGLYPHE ANATOLIEN A452",NULL},
/* 145FB */ { "HIÉROGLYPHE ANATOLIEN A453",NULL},
/* 145FC */ { "HIÉROGLYPHE ANATOLIEN A454",NULL},
/* 145FD */ { "HIÉROGLYPHE ANATOLIEN A455","	= « la-x » syllabique"},
/* 145FE */ { "HIÉROGLYPHE ANATOLIEN A456","	= « sí? » syllabique"},
/* 145FF */ { "HIÉROGLYPHE ANATOLIEN A457",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_46[] = {
/* 14600 */ { "HIÉROGLYPHE ANATOLIEN A457A",NULL},
/* 14601 */ { "HIÉROGLYPHE ANATOLIEN A458",NULL},
/* 14602 */ { "HIÉROGLYPHE ANATOLIEN A459",NULL},
/* 14603 */ { "HIÉROGLYPHE ANATOLIEN A460",NULL},
/* 14604 */ { "HIÉROGLYPHE ANATOLIEN A461",NULL},
/* 14605 */ { "HIÉROGLYPHE ANATOLIEN A462","	= « ma-x? » syllabique"},
/* 14606 */ { "HIÉROGLYPHE ANATOLIEN A463",NULL},
/* 14607 */ { "HIÉROGLYPHE ANATOLIEN A464",NULL},
/* 14608 */ { "HIÉROGLYPHE ANATOLIEN A465",NULL},
/* 14609 */ { "HIÉROGLYPHE ANATOLIEN A466",NULL},
/* 1460A */ { "HIÉROGLYPHE ANATOLIEN A467",NULL},
/* 1460B */ { "HIÉROGLYPHE ANATOLIEN A468",NULL},
/* 1460C */ { "HIÉROGLYPHE ANATOLIEN A469",NULL},
/* 1460D */ { "HIÉROGLYPHE ANATOLIEN A470","	= douze"},
/* 1460E */ { "HIÉROGLYPHE ANATOLIEN A471",NULL},
/* 1460F */ { "HIÉROGLYPHE ANATOLIEN A472",NULL},
/* 14610 */ { "HIÉROGLYPHE ANATOLIEN A473",NULL},
/* 14611 */ { "HIÉROGLYPHE ANATOLIEN A474","	= eunuchus"},
/* 14612 */ { "HIÉROGLYPHE ANATOLIEN A475",NULL},
/* 14613 */ { "HIÉROGLYPHE ANATOLIEN A476",NULL},
/* 14614 */ { "HIÉROGLYPHE ANATOLIEN A477","	= flammae?"},
/* 14615 */ { "HIÉROGLYPHE ANATOLIEN A478",NULL},
/* 14616 */ { "HIÉROGLYPHE ANATOLIEN A479",NULL},
/* 14617 */ { "HIÉROGLYPHE ANATOLIEN A480",NULL},
/* 14618 */ { "HIÉROGLYPHE ANATOLIEN A481",NULL},
/* 14619 */ { "HIÉROGLYPHE ANATOLIEN A482",NULL},
/* 1461A */ { "HIÉROGLYPHE ANATOLIEN A483",NULL},
/* 1461B */ { "HIÉROGLYPHE ANATOLIEN A484",NULL},
/* 1461C */ { "HIÉROGLYPHE ANATOLIEN A485",NULL},
/* 1461D */ { "HIÉROGLYPHE ANATOLIEN A486","	= falx?"},
/* 1461E */ { "HIÉROGLYPHE ANATOLIEN A487",NULL},
/* 1461F */ { "HIÉROGLYPHE ANATOLIEN A488","	= « tí » syllabique"},
/* 14620 */ { "HIÉROGLYPHE ANATOLIEN A489",NULL},
/* 14621 */ { "HIÉROGLYPHE ANATOLIEN A490",NULL},
/* 14622 */ { "HIÉROGLYPHE ANATOLIEN A491",NULL},
/* 14623 */ { "HIÉROGLYPHE ANATOLIEN A492",NULL},
/* 14624 */ { "HIÉROGLYPHE ANATOLIEN A493",NULL},
/* 14625 */ { "HIÉROGLYPHE ANATOLIEN A494",NULL},
/* 14626 */ { "HIÉROGLYPHE ANATOLIEN A495",NULL},
/* 14627 */ { "HIÉROGLYPHE ANATOLIEN A496",NULL},
/* 14628 */ { "HIÉROGLYPHE ANATOLIEN A497",NULL},
/* 14629 */ { "HIÉROGLYPHE ANATOLIEN A501",NULL},
/* 1462A */ { "HIÉROGLYPHE ANATOLIEN A502",NULL},
/* 1462B */ { "HIÉROGLYPHE ANATOLIEN A503",NULL},
/* 1462C */ { "HIÉROGLYPHE ANATOLIEN A504",NULL},
/* 1462D */ { "HIÉROGLYPHE ANATOLIEN A505",NULL},
/* 1462E */ { "HIÉROGLYPHE ANATOLIEN A506","	= « hana » syllabique"},
/* 1462F */ { "HIÉROGLYPHE ANATOLIEN A507",NULL},
/* 14630 */ { "HIÉROGLYPHE ANATOLIEN A508","	= currere\n"
	"	= « hwi/a » syllabique"},
/* 14631 */ { "HIÉROGLYPHE ANATOLIEN A509",NULL},
/* 14632 */ { "HIÉROGLYPHE ANATOLIEN A510",NULL},
/* 14633 */ { "HIÉROGLYPHE ANATOLIEN A511",NULL},
/* 14634 */ { "HIÉROGLYPHE ANATOLIEN A512",NULL},
/* 14635 */ { "HIÉROGLYPHE ANATOLIEN A513",NULL},
/* 14636 */ { "HIÉROGLYPHE ANATOLIEN A514",NULL},
/* 14637 */ { "HIÉROGLYPHE ANATOLIEN A515",NULL},
/* 14638 */ { "HIÉROGLYPHE ANATOLIEN A516",NULL},
/* 14639 */ { "HIÉROGLYPHE ANATOLIEN A517",NULL},
/* 1463A */ { "HIÉROGLYPHE ANATOLIEN A518",NULL},
/* 1463B */ { "HIÉROGLYPHE ANATOLIEN A519",NULL},
/* 1463C */ { "HIÉROGLYPHE ANATOLIEN A520",NULL},
/* 1463D */ { "HIÉROGLYPHE ANATOLIEN A521",NULL},
/* 1463E */ { "HIÉROGLYPHE ANATOLIEN A522",NULL},
/* 1463F */ { "HIÉROGLYPHE ANATOLIEN A523",NULL},
/* 14640 */ { "HIÉROGLYPHE ANATOLIEN A524","	= propheta?, cornu+caput"},
/* 14641 */ { "HIÉROGLYPHE ANATOLIEN A525","	= princeps"},
/* 14642 */ { "HIÉROGLYPHE ANATOLIEN A526","	= Güterbock G195"},
/* 14643 */ { "HIÉROGLYPHE ANATOLIEN A527","	= aper"},
/* 14644 */ { "HIÉROGLYPHE ANATOLIEN A528","	= tì"},
/* 14645 */ { "HIÉROGLYPHE ANATOLIEN A529","	= lingua+x"},
/* 14646 */ { "HIÉROGLYPHE ANATOLIEN A530",NULL},
/* 14647 */ { NULL,NULL},
/* 14648 */ { NULL,NULL},
/* 14649 */ { NULL,NULL},
/* 1464A */ { NULL,NULL},
/* 1464B */ { NULL,NULL},
/* 1464C */ { NULL,NULL},
/* 1464D */ { NULL,NULL},
/* 1464E */ { NULL,NULL},
/* 1464F */ { NULL,NULL},
/* 14650 */ { NULL,NULL},
/* 14651 */ { NULL,NULL},
/* 14652 */ { NULL,NULL},
/* 14653 */ { NULL,NULL},
/* 14654 */ { NULL,NULL},
/* 14655 */ { NULL,NULL},
/* 14656 */ { NULL,NULL},
/* 14657 */ { NULL,NULL},
/* 14658 */ { NULL,NULL},
/* 14659 */ { NULL,NULL},
/* 1465A */ { NULL,NULL},
/* 1465B */ { NULL,NULL},
/* 1465C */ { NULL,NULL},
/* 1465D */ { NULL,NULL},
/* 1465E */ { NULL,NULL},
/* 1465F */ { NULL,NULL},
/* 14660 */ { NULL,NULL},
/* 14661 */ { NULL,NULL},
/* 14662 */ { NULL,NULL},
/* 14663 */ { NULL,NULL},
/* 14664 */ { NULL,NULL},
/* 14665 */ { NULL,NULL},
/* 14666 */ { NULL,NULL},
/* 14667 */ { NULL,NULL},
/* 14668 */ { NULL,NULL},
/* 14669 */ { NULL,NULL},
/* 1466A */ { NULL,NULL},
/* 1466B */ { NULL,NULL},
/* 1466C */ { NULL,NULL},
/* 1466D */ { NULL,NULL},
/* 1466E */ { NULL,NULL},
/* 1466F */ { NULL,NULL},
/* 14670 */ { NULL,NULL},
/* 14671 */ { NULL,NULL},
/* 14672 */ { NULL,NULL},
/* 14673 */ { NULL,NULL},
/* 14674 */ { NULL,NULL},
/* 14675 */ { NULL,NULL},
/* 14676 */ { NULL,NULL},
/* 14677 */ { NULL,NULL},
/* 14678 */ { NULL,NULL},
/* 14679 */ { NULL,NULL},
/* 1467A */ { NULL,NULL},
/* 1467B */ { NULL,NULL},
/* 1467C */ { NULL,NULL},
/* 1467D */ { NULL,NULL},
/* 1467E */ { NULL,NULL},
/* 1467F */ { NULL,NULL},
/* 14680 */ { NULL,NULL},
/* 14681 */ { NULL,NULL},
/* 14682 */ { NULL,NULL},
/* 14683 */ { NULL,NULL},
/* 14684 */ { NULL,NULL},
/* 14685 */ { NULL,NULL},
/* 14686 */ { NULL,NULL},
/* 14687 */ { NULL,NULL},
/* 14688 */ { NULL,NULL},
/* 14689 */ { NULL,NULL},
/* 1468A */ { NULL,NULL},
/* 1468B */ { NULL,NULL},
/* 1468C */ { NULL,NULL},
/* 1468D */ { NULL,NULL},
/* 1468E */ { NULL,NULL},
/* 1468F */ { NULL,NULL},
/* 14690 */ { NULL,NULL},
/* 14691 */ { NULL,NULL},
/* 14692 */ { NULL,NULL},
/* 14693 */ { NULL,NULL},
/* 14694 */ { NULL,NULL},
/* 14695 */ { NULL,NULL},
/* 14696 */ { NULL,NULL},
/* 14697 */ { NULL,NULL},
/* 14698 */ { NULL,NULL},
/* 14699 */ { NULL,NULL},
/* 1469A */ { NULL,NULL},
/* 1469B */ { NULL,NULL},
/* 1469C */ { NULL,NULL},
/* 1469D */ { NULL,NULL},
/* 1469E */ { NULL,NULL},
/* 1469F */ { NULL,NULL},
/* 146A0 */ { NULL,NULL},
/* 146A1 */ { NULL,NULL},
/* 146A2 */ { NULL,NULL},
/* 146A3 */ { NULL,NULL},
/* 146A4 */ { NULL,NULL},
/* 146A5 */ { NULL,NULL},
/* 146A6 */ { NULL,NULL},
/* 146A7 */ { NULL,NULL},
/* 146A8 */ { NULL,NULL},
/* 146A9 */ { NULL,NULL},
/* 146AA */ { NULL,NULL},
/* 146AB */ { NULL,NULL},
/* 146AC */ { NULL,NULL},
/* 146AD */ { NULL,NULL},
/* 146AE */ { NULL,NULL},
/* 146AF */ { NULL,NULL},
/* 146B0 */ { NULL,NULL},
/* 146B1 */ { NULL,NULL},
/* 146B2 */ { NULL,NULL},
/* 146B3 */ { NULL,NULL},
/* 146B4 */ { NULL,NULL},
/* 146B5 */ { NULL,NULL},
/* 146B6 */ { NULL,NULL},
/* 146B7 */ { NULL,NULL},
/* 146B8 */ { NULL,NULL},
/* 146B9 */ { NULL,NULL},
/* 146BA */ { NULL,NULL},
/* 146BB */ { NULL,NULL},
/* 146BC */ { NULL,NULL},
/* 146BD */ { NULL,NULL},
/* 146BE */ { NULL,NULL},
/* 146BF */ { NULL,NULL},
/* 146C0 */ { NULL,NULL},
/* 146C1 */ { NULL,NULL},
/* 146C2 */ { NULL,NULL},
/* 146C3 */ { NULL,NULL},
/* 146C4 */ { NULL,NULL},
/* 146C5 */ { NULL,NULL},
/* 146C6 */ { NULL,NULL},
/* 146C7 */ { NULL,NULL},
/* 146C8 */ { NULL,NULL},
/* 146C9 */ { NULL,NULL},
/* 146CA */ { NULL,NULL},
/* 146CB */ { NULL,NULL},
/* 146CC */ { NULL,NULL},
/* 146CD */ { NULL,NULL},
/* 146CE */ { NULL,NULL},
/* 146CF */ { NULL,NULL},
/* 146D0 */ { NULL,NULL},
/* 146D1 */ { NULL,NULL},
/* 146D2 */ { NULL,NULL},
/* 146D3 */ { NULL,NULL},
/* 146D4 */ { NULL,NULL},
/* 146D5 */ { NULL,NULL},
/* 146D6 */ { NULL,NULL},
/* 146D7 */ { NULL,NULL},
/* 146D8 */ { NULL,NULL},
/* 146D9 */ { NULL,NULL},
/* 146DA */ { NULL,NULL},
/* 146DB */ { NULL,NULL},
/* 146DC */ { NULL,NULL},
/* 146DD */ { NULL,NULL},
/* 146DE */ { NULL,NULL},
/* 146DF */ { NULL,NULL},
/* 146E0 */ { NULL,NULL},
/* 146E1 */ { NULL,NULL},
/* 146E2 */ { NULL,NULL},
/* 146E3 */ { NULL,NULL},
/* 146E4 */ { NULL,NULL},
/* 146E5 */ { NULL,NULL},
/* 146E6 */ { NULL,NULL},
/* 146E7 */ { NULL,NULL},
/* 146E8 */ { NULL,NULL},
/* 146E9 */ { NULL,NULL},
/* 146EA */ { NULL,NULL},
/* 146EB */ { NULL,NULL},
/* 146EC */ { NULL,NULL},
/* 146ED */ { NULL,NULL},
/* 146EE */ { NULL,NULL},
/* 146EF */ { NULL,NULL},
/* 146F0 */ { NULL,NULL},
/* 146F1 */ { NULL,NULL},
/* 146F2 */ { NULL,NULL},
/* 146F3 */ { NULL,NULL},
/* 146F4 */ { NULL,NULL},
/* 146F5 */ { NULL,NULL},
/* 146F6 */ { NULL,NULL},
/* 146F7 */ { NULL,NULL},
/* 146F8 */ { NULL,NULL},
/* 146F9 */ { NULL,NULL},
/* 146FA */ { NULL,NULL},
/* 146FB */ { NULL,NULL},
/* 146FC */ { NULL,NULL},
/* 146FD */ { NULL,NULL},
/* 146FE */ { NULL,NULL},
/* 146FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_61[] = {
/* 16100 */ { "LETTRE GOUROUNG KHEMA A",NULL},
/* 16101 */ { "LETTRE GOUROUNG KHEMA KA",NULL},
/* 16102 */ { "LETTRE GOUROUNG KHEMA KHA",NULL},
/* 16103 */ { "LETTRE GOUROUNG KHEMA GA",NULL},
/* 16104 */ { "LETTRE GOUROUNG KHEMA GHA",NULL},
/* 16105 */ { "LETTRE GOUROUNG KHEMA NGA",NULL},
/* 16106 */ { "LETTRE GOUROUNG KHEMA TCHA",NULL},
/* 16107 */ { "LETTRE GOUROUNG KHEMA TCHHA",NULL},
/* 16108 */ { "LETTRE GOUROUNG KHEMA DJA",NULL},
/* 16109 */ { "LETTRE GOUROUNG KHEMA DJHA",NULL},
/* 1610A */ { "LETTRE GOUROUNG KHEMA HA",NULL},
/* 1610B */ { "LETTRE GOUROUNG KHEMA TTA",NULL},
/* 1610C */ { "LETTRE GOUROUNG KHEMA TTHA",NULL},
/* 1610D */ { "LETTRE GOUROUNG KHEMA DDA",NULL},
/* 1610E */ { "LETTRE GOUROUNG KHEMA DDHA",NULL},
/* 1610F */ { "LETTRE GOUROUNG KHEMA VA",NULL},
/* 16110 */ { "LETTRE GOUROUNG KHEMA TA",NULL},
/* 16111 */ { "LETTRE GOUROUNG KHEMA THA",NULL},
/* 16112 */ { "LETTRE GOUROUNG KHEMA DA",NULL},
/* 16113 */ { "LETTRE GOUROUNG KHEMA DHA",NULL},
/* 16114 */ { "LETTRE GOUROUNG KHEMA NA",NULL},
/* 16115 */ { "LETTRE GOUROUNG KHEMA PA",NULL},
/* 16116 */ { "LETTRE GOUROUNG KHEMA PHA","	= lettre gouroung khema p'a"},
/* 16117 */ { "LETTRE GOUROUNG KHEMA BA",NULL},
/* 16118 */ { "LETTRE GOUROUNG KHEMA BHA",NULL},
/* 16119 */ { "LETTRE GOUROUNG KHEMA MA",NULL},
/* 1611A */ { "LETTRE GOUROUNG KHEMA YA",NULL},
/* 1611B */ { "LETTRE GOUROUNG KHEMA RA",NULL},
/* 1611C */ { "LETTRE GOUROUNG KHEMA LA",NULL},
/* 1611D */ { "LETTRE GOUROUNG KHEMA SA",NULL},
/* 1611E */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA Â",NULL},
/* 1611F */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA I",NULL},
/* 16120 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA Î",NULL},
/* 16121 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA OU","	: 1611E 1611E"},
/* 16122 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA OÛ","	: 1611E 16129"},
/* 16123 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA É","	: 1611E 1611F"},
/* 16124 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA ÉÉ","	: 16129 1611F"},
/* 16125 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA AI","	: 1611E 16120"},
/* 16126 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA O","	: 16121 1611F"},
/* 16127 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA Ô","	: 16122 1611F"},
/* 16128 */ { "DIACRITIQUE VOYELLE GOUROUNG KHEMA AOU","	: 16121 16120"},
/* 16129 */ { "SIGNE GOUROUNG KHEMA DE LONGUEUR DE VOYELLE",NULL},
/* 1612A */ { "DIACRITIQUE CONSONNE GOUROUNG KHEMA YA MÉDIAL",NULL},
/* 1612B */ { "DIACRITIQUE CONSONNE GOUROUNG KHEMA VA MÉDIAL",NULL},
/* 1612C */ { "DIACRITIQUE CONSONNE GOUROUNG KHEMA HA MÉDIAL",NULL},
/* 1612D */ { "DIACRITIQUE GOUROUNG KHEMA ANOUSVÂRA",NULL},
/* 1612E */ { "DIACRITIQUE CONSONNE GOUROUNG KHEMA RA MÉDIAL",NULL},
/* 1612F */ { "DIACRITIQUE GOUROUNG KHEMA THOLHOMA",NULL},
/* 16130 */ { "CHIFFRE GOUROUNG KHEMA ZÉRO",NULL},
/* 16131 */ { "CHIFFRE GOUROUNG KHEMA UN",NULL},
/* 16132 */ { "CHIFFRE GOUROUNG KHEMA DEUX",NULL},
/* 16133 */ { "CHIFFRE GOUROUNG KHEMA TROIS",NULL},
/* 16134 */ { "CHIFFRE GOUROUNG KHEMA QUATRE",NULL},
/* 16135 */ { "CHIFFRE GOUROUNG KHEMA CINQ",NULL},
/* 16136 */ { "CHIFFRE GOUROUNG KHEMA SIX",NULL},
/* 16137 */ { "CHIFFRE GOUROUNG KHEMA SEPT",NULL},
/* 16138 */ { "CHIFFRE GOUROUNG KHEMA HUIT",NULL},
/* 16139 */ { "CHIFFRE GOUROUNG KHEMA NEUF",NULL},
/* 1613A */ { NULL,NULL},
/* 1613B */ { NULL,NULL},
/* 1613C */ { NULL,NULL},
/* 1613D */ { NULL,NULL},
/* 1613E */ { NULL,NULL},
/* 1613F */ { NULL,NULL},
/* 16140 */ { NULL,NULL},
/* 16141 */ { NULL,NULL},
/* 16142 */ { NULL,NULL},
/* 16143 */ { NULL,NULL},
/* 16144 */ { NULL,NULL},
/* 16145 */ { NULL,NULL},
/* 16146 */ { NULL,NULL},
/* 16147 */ { NULL,NULL},
/* 16148 */ { NULL,NULL},
/* 16149 */ { NULL,NULL},
/* 1614A */ { NULL,NULL},
/* 1614B */ { NULL,NULL},
/* 1614C */ { NULL,NULL},
/* 1614D */ { NULL,NULL},
/* 1614E */ { NULL,NULL},
/* 1614F */ { NULL,NULL},
/* 16150 */ { NULL,NULL},
/* 16151 */ { NULL,NULL},
/* 16152 */ { NULL,NULL},
/* 16153 */ { NULL,NULL},
/* 16154 */ { NULL,NULL},
/* 16155 */ { NULL,NULL},
/* 16156 */ { NULL,NULL},
/* 16157 */ { NULL,NULL},
/* 16158 */ { NULL,NULL},
/* 16159 */ { NULL,NULL},
/* 1615A */ { NULL,NULL},
/* 1615B */ { NULL,NULL},
/* 1615C */ { NULL,NULL},
/* 1615D */ { NULL,NULL},
/* 1615E */ { NULL,NULL},
/* 1615F */ { NULL,NULL},
/* 16160 */ { NULL,NULL},
/* 16161 */ { NULL,NULL},
/* 16162 */ { NULL,NULL},
/* 16163 */ { NULL,NULL},
/* 16164 */ { NULL,NULL},
/* 16165 */ { NULL,NULL},
/* 16166 */ { NULL,NULL},
/* 16167 */ { NULL,NULL},
/* 16168 */ { NULL,NULL},
/* 16169 */ { NULL,NULL},
/* 1616A */ { NULL,NULL},
/* 1616B */ { NULL,NULL},
/* 1616C */ { NULL,NULL},
/* 1616D */ { NULL,NULL},
/* 1616E */ { NULL,NULL},
/* 1616F */ { NULL,NULL},
/* 16170 */ { NULL,NULL},
/* 16171 */ { NULL,NULL},
/* 16172 */ { NULL,NULL},
/* 16173 */ { NULL,NULL},
/* 16174 */ { NULL,NULL},
/* 16175 */ { NULL,NULL},
/* 16176 */ { NULL,NULL},
/* 16177 */ { NULL,NULL},
/* 16178 */ { NULL,NULL},
/* 16179 */ { NULL,NULL},
/* 1617A */ { NULL,NULL},
/* 1617B */ { NULL,NULL},
/* 1617C */ { NULL,NULL},
/* 1617D */ { NULL,NULL},
/* 1617E */ { NULL,NULL},
/* 1617F */ { NULL,NULL},
/* 16180 */ { NULL,NULL},
/* 16181 */ { NULL,NULL},
/* 16182 */ { NULL,NULL},
/* 16183 */ { NULL,NULL},
/* 16184 */ { NULL,NULL},
/* 16185 */ { NULL,NULL},
/* 16186 */ { NULL,NULL},
/* 16187 */ { NULL,NULL},
/* 16188 */ { NULL,NULL},
/* 16189 */ { NULL,NULL},
/* 1618A */ { NULL,NULL},
/* 1618B */ { NULL,NULL},
/* 1618C */ { NULL,NULL},
/* 1618D */ { NULL,NULL},
/* 1618E */ { NULL,NULL},
/* 1618F */ { NULL,NULL},
/* 16190 */ { NULL,NULL},
/* 16191 */ { NULL,NULL},
/* 16192 */ { NULL,NULL},
/* 16193 */ { NULL,NULL},
/* 16194 */ { NULL,NULL},
/* 16195 */ { NULL,NULL},
/* 16196 */ { NULL,NULL},
/* 16197 */ { NULL,NULL},
/* 16198 */ { NULL,NULL},
/* 16199 */ { NULL,NULL},
/* 1619A */ { NULL,NULL},
/* 1619B */ { NULL,NULL},
/* 1619C */ { NULL,NULL},
/* 1619D */ { NULL,NULL},
/* 1619E */ { NULL,NULL},
/* 1619F */ { NULL,NULL},
/* 161A0 */ { NULL,NULL},
/* 161A1 */ { NULL,NULL},
/* 161A2 */ { NULL,NULL},
/* 161A3 */ { NULL,NULL},
/* 161A4 */ { NULL,NULL},
/* 161A5 */ { NULL,NULL},
/* 161A6 */ { NULL,NULL},
/* 161A7 */ { NULL,NULL},
/* 161A8 */ { NULL,NULL},
/* 161A9 */ { NULL,NULL},
/* 161AA */ { NULL,NULL},
/* 161AB */ { NULL,NULL},
/* 161AC */ { NULL,NULL},
/* 161AD */ { NULL,NULL},
/* 161AE */ { NULL,NULL},
/* 161AF */ { NULL,NULL},
/* 161B0 */ { NULL,NULL},
/* 161B1 */ { NULL,NULL},
/* 161B2 */ { NULL,NULL},
/* 161B3 */ { NULL,NULL},
/* 161B4 */ { NULL,NULL},
/* 161B5 */ { NULL,NULL},
/* 161B6 */ { NULL,NULL},
/* 161B7 */ { NULL,NULL},
/* 161B8 */ { NULL,NULL},
/* 161B9 */ { NULL,NULL},
/* 161BA */ { NULL,NULL},
/* 161BB */ { NULL,NULL},
/* 161BC */ { NULL,NULL},
/* 161BD */ { NULL,NULL},
/* 161BE */ { NULL,NULL},
/* 161BF */ { NULL,NULL},
/* 161C0 */ { NULL,NULL},
/* 161C1 */ { NULL,NULL},
/* 161C2 */ { NULL,NULL},
/* 161C3 */ { NULL,NULL},
/* 161C4 */ { NULL,NULL},
/* 161C5 */ { NULL,NULL},
/* 161C6 */ { NULL,NULL},
/* 161C7 */ { NULL,NULL},
/* 161C8 */ { NULL,NULL},
/* 161C9 */ { NULL,NULL},
/* 161CA */ { NULL,NULL},
/* 161CB */ { NULL,NULL},
/* 161CC */ { NULL,NULL},
/* 161CD */ { NULL,NULL},
/* 161CE */ { NULL,NULL},
/* 161CF */ { NULL,NULL},
/* 161D0 */ { NULL,NULL},
/* 161D1 */ { NULL,NULL},
/* 161D2 */ { NULL,NULL},
/* 161D3 */ { NULL,NULL},
/* 161D4 */ { NULL,NULL},
/* 161D5 */ { NULL,NULL},
/* 161D6 */ { NULL,NULL},
/* 161D7 */ { NULL,NULL},
/* 161D8 */ { NULL,NULL},
/* 161D9 */ { NULL,NULL},
/* 161DA */ { NULL,NULL},
/* 161DB */ { NULL,NULL},
/* 161DC */ { NULL,NULL},
/* 161DD */ { NULL,NULL},
/* 161DE */ { NULL,NULL},
/* 161DF */ { NULL,NULL},
/* 161E0 */ { NULL,NULL},
/* 161E1 */ { NULL,NULL},
/* 161E2 */ { NULL,NULL},
/* 161E3 */ { NULL,NULL},
/* 161E4 */ { NULL,NULL},
/* 161E5 */ { NULL,NULL},
/* 161E6 */ { NULL,NULL},
/* 161E7 */ { NULL,NULL},
/* 161E8 */ { NULL,NULL},
/* 161E9 */ { NULL,NULL},
/* 161EA */ { NULL,NULL},
/* 161EB */ { NULL,NULL},
/* 161EC */ { NULL,NULL},
/* 161ED */ { NULL,NULL},
/* 161EE */ { NULL,NULL},
/* 161EF */ { NULL,NULL},
/* 161F0 */ { NULL,NULL},
/* 161F1 */ { NULL,NULL},
/* 161F2 */ { NULL,NULL},
/* 161F3 */ { NULL,NULL},
/* 161F4 */ { NULL,NULL},
/* 161F5 */ { NULL,NULL},
/* 161F6 */ { NULL,NULL},
/* 161F7 */ { NULL,NULL},
/* 161F8 */ { NULL,NULL},
/* 161F9 */ { NULL,NULL},
/* 161FA */ { NULL,NULL},
/* 161FB */ { NULL,NULL},
/* 161FC */ { NULL,NULL},
/* 161FD */ { NULL,NULL},
/* 161FE */ { NULL,NULL},
/* 161FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_68[] = {
/* 16800 */ { "LETTRE BAMOUM DE PHASE 'A' NGKÜ MFON",NULL},
/* 16801 */ { "LETTRE BAMOUM DE PHASE 'A' GBIÉ FON",NULL},
/* 16802 */ { "LETTRE BAMOUM DE PHASE 'A' PON MFON PIPEMGBIÉ",NULL},
/* 16803 */ { "LETTRE BAMOUM DE PHASE 'A' PON MFON PIPEMBA",NULL},
/* 16804 */ { "LETTRE BAMOUM DE PHASE 'A' NAA MFON",NULL},
/* 16805 */ { "LETTRE BAMOUM DE PHASE 'A' SHÜNSHÜT",NULL},
/* 16806 */ { "LETTRE BAMOUM DE PHASE 'A' TITA MFON",NULL},
/* 16807 */ { "LETTRE BAMOUM DE PHASE 'A' NZA MFON",NULL},
/* 16808 */ { "LETTRE BAMOUM DE PHASE 'A' SHINDA PA NJI",NULL},
/* 16809 */ { "LETTRE BAMOUM DE PHASE 'A' PON PA NJI PIPEMGBIÉ",NULL},
/* 1680A */ { "LETTRE BAMOUM DE PHASE 'A' PON PA NJI PIPEMBA",NULL},
/* 1680B */ { "LETTRE BAMOUM DE PHASE 'A' MEMGBIÉ","	* le nom formel de ce caractère en anglais est erroné"},
/* 1680C */ { "LETTRE BAMOUM DE PHASE 'A' TU MEMBA",NULL},
/* 1680D */ { "LETTRE BAMOUM DE PHASE 'A' NGANGU",NULL},
/* 1680E */ { "LETTRE BAMOUM DE PHASE 'A' MEMVÙX",NULL},
/* 1680F */ { "LETTRE BAMOUM DE PHASE 'A' MANSUE",NULL},
/* 16810 */ { "LETTRE BAMOUM DE PHASE 'A' MVÙENGAM",NULL},
/* 16811 */ { "LETTRE BAMOUM DE PHASE 'A' SÙNYAM",NULL},
/* 16812 */ { "LETTRE BAMOUM DE PHASE 'A' NTO'PÈN",NULL},
/* 16813 */ { "LETTRE BAMOUM DE PHASE 'A' KÙKÙTNDA",NULL},
/* 16814 */ { "LETTRE BAMOUM DE PHASE 'A' NKINDI",NULL},
/* 16815 */ { "LETTRE BAMOUM DE PHASE 'A' SUU",NULL},
/* 16816 */ { "LETTRE BAMOUM DE PHASE 'A' NGKÜNZÙM",NULL},
/* 16817 */ { "LETTRE BAMOUM DE PHASE 'A' LAPA'",NULL},
/* 16818 */ { "LETTRE BAMOUM DE PHASE 'A' LÈT KUT",NULL},
/* 16819 */ { "LETTRE BAMOUM DE PHASE 'A' NTAP MFAA",NULL},
/* 1681A */ { "LETTRE BAMOUM DE PHASE 'A' MEKÙP",NULL},
/* 1681B */ { "LETTRE BAMOUM DE PHASE 'A' PASHE",NULL},
/* 1681C */ { "LETTRE BAMOUM DE PHASE 'A' GHÙERE",NULL},
/* 1681D */ { "LETTRE BAMOUM DE PHASE 'A' PAMSHE",NULL},
/* 1681E */ { "LETTRE BAMOUM DE PHASE 'A' MON NGGÙET",NULL},
/* 1681F */ { "LETTRE BAMOUM DE PHASE 'A' NZUN MÙT",NULL},
/* 16820 */ { "LETTRE BAMOUM DE PHASE 'A' U YU' NE",NULL},
/* 16821 */ { "LETTRE BAMOUM DE PHASE 'A' GHÙEGHÙE",NULL},
/* 16822 */ { "LETTRE BAMOUM DE PHASE 'A' NTAP NTAA",NULL},
/* 16823 */ { "LETTRE BAMOUM DE PHASE 'A' SISA",NULL},
/* 16824 */ { "LETTRE BAMOUM DE PHASE 'A' MGBASA",NULL},
/* 16825 */ { "LETTRE BAMOUM DE PHASE 'A' MÙNJOMNDÙ'",NULL},
/* 16826 */ { "LETTRE BAMOUM DE PHASE 'A' MOOMPU'",NULL},
/* 16827 */ { "LETTRE BAMOUM DE PHASE 'A' KAFA",NULL},
/* 16828 */ { "LETTRE BAMOUM DE PHASE 'A' PA LÉREWA",NULL},
/* 16829 */ { "LETTRE BAMOUM DE PHASE 'A' NDA LÉREWA",NULL},
/* 1682A */ { "LETTRE BAMOUM DE PHASE 'A' PÈT",NULL},
/* 1682B */ { "LETTRE BAMOUM DE PHASE 'A' MEMKPÈN",NULL},
/* 1682C */ { "LETTRE BAMOUM DE PHASE 'A' NIKA",NULL},
/* 1682D */ { "LETTRE BAMOUM DE PHASE 'A' PUP",NULL},
/* 1682E */ { "LETTRE BAMOUM DE PHASE 'A' TUEP",NULL},
/* 1682F */ { "LETTRE BAMOUM DE PHASE 'A' LUEP",NULL},
/* 16830 */ { "LETTRE BAMOUM DE PHASE 'A' SONJAM",NULL},
/* 16831 */ { "LETTRE BAMOUM DE PHASE 'A' TÙTÙWÈN",NULL},
/* 16832 */ { "LETTRE BAMOUM DE PHASE 'A' MENYI",NULL},
/* 16833 */ { "LETTRE BAMOUM DE PHASE 'A' KÈT",NULL},
/* 16834 */ { "LETTRE BAMOUM DE PHASE 'A' NDAANGGÙET",NULL},
/* 16835 */ { "LETTRE BAMOUM DE PHASE 'A' KUO'",NULL},
/* 16836 */ { "LETTRE BAMOUM DE PHASE 'A' MOOMÙT",NULL},
/* 16837 */ { "LETTRE BAMOUM DE PHASE 'A' SHUM",NULL},
/* 16838 */ { "LETTRE BAMOUM DE PHASE 'A' LOMME",NULL},
/* 16839 */ { "LETTRE BAMOUM DE PHASE 'A' FIRI",NULL},
/* 1683A */ { "LETTRE BAMOUM DE PHASE 'A' ROM",NULL},
/* 1683B */ { "LETTRE BAMOUM DE PHASE 'A' KPO'",NULL},
/* 1683C */ { "LETTRE BAMOUM DE PHASE 'A' SO'",NULL},
/* 1683D */ { "LETTRE BAMOUM DE PHASE 'A' MAP PIÉT",NULL},
/* 1683E */ { "LETTRE BAMOUM DE PHASE 'A' SHIRE",NULL},
/* 1683F */ { "LETTRE BAMOUM DE PHASE 'A' NTAP",NULL},
/* 16840 */ { "LETTRE BAMOUM DE PHASE 'A' SHO' NSHUT YUM",NULL},
/* 16841 */ { "LETTRE BAMOUM DE PHASE 'A' NYIT MONGKÙE'",NULL},
/* 16842 */ { "LETTRE BAMOUM DE PHASE 'A' PAARE",NULL},
/* 16843 */ { "LETTRE BAMOUM DE PHASE 'A' NKAARE",NULL},
/* 16844 */ { "LETTRE BAMOUM DE PHASE 'A' UNKNOWN",NULL},
/* 16845 */ { "LETTRE BAMOUM DE PHASE 'A' NGGÈN",NULL},
/* 16846 */ { "LETTRE BAMOUM DE PHASE 'A' MESI",NULL},
/* 16847 */ { "LETTRE BAMOUM DE PHASE 'A' NJAM",NULL},
/* 16848 */ { "LETTRE BAMOUM DE PHASE 'A' MBANYI",NULL},
/* 16849 */ { "LETTRE BAMOUM DE PHASE 'A' NYÈT",NULL},
/* 1684A */ { "LETTRE BAMOUM DE PHASE 'A' TÙEN",NULL},
/* 1684B */ { "LETTRE BAMOUM DE PHASE 'A' SOT",NULL},
/* 1684C */ { "LETTRE BAMOUM DE PHASE 'A' PAAM",NULL},
/* 1684D */ { "LETTRE BAMOUM DE PHASE 'A' NSHIÉ",NULL},
/* 1684E */ { "LETTRE BAMOUM DE PHASE 'A' MEM",NULL},
/* 1684F */ { "LETTRE BAMOUM DE PHASE 'A' NYI",NULL},
/* 16850 */ { "LETTRE BAMOUM DE PHASE 'A' KA'",NULL},
/* 16851 */ { "LETTRE BAMOUM DE PHASE 'A' NSHA",NULL},
/* 16852 */ { "LETTRE BAMOUM DE PHASE 'A' VÉ",NULL},
/* 16853 */ { "LETTRE BAMOUM DE PHASE 'A' LU",NULL},
/* 16854 */ { "LETTRE BAMOUM DE PHASE 'A' NÈN",NULL},
/* 16855 */ { "LETTRE BAMOUM DE PHASE 'A' NA'",NULL},
/* 16856 */ { "LETTRE BAMOUM DE PHASE 'A' MBA'",NULL},
/* 16857 */ { "LETTRE BAMOUM DE PHASE 'B' NSHÜT",NULL},
/* 16858 */ { "LETTRE BAMOUM DE PHASE 'B' TU MEMGBIÉ",NULL},
/* 16859 */ { "LETTRE BAMOUM DE PHASE 'B' SIÉ",NULL},
/* 1685A */ { "LETTRE BAMOUM DE PHASE 'B' SÈT TU",NULL},
/* 1685B */ { "LETTRE BAMOUM DE PHASE 'B' LOM NTÙM",NULL},
/* 1685C */ { "LETTRE BAMOUM DE PHASE 'B' MBA MELÉ",NULL},
/* 1685D */ { "LETTRE BAMOUM DE PHASE 'B' KIÉM",NULL},
/* 1685E */ { "LETTRE BAMOUM DE PHASE 'B' YÙRE",NULL},
/* 1685F */ { "LETTRE BAMOUM DE PHASE 'B' MBAARE",NULL},
/* 16860 */ { "LETTRE BAMOUM DE PHASE 'B' KAM",NULL},
/* 16861 */ { "LETTRE BAMOUM DE PHASE 'B' PÉSHI",NULL},
/* 16862 */ { "LETTRE BAMOUM DE PHASE 'B' YAFU LÉREWA",NULL},
/* 16863 */ { "LETTRE BAMOUM DE PHASE 'B' LAM NSHUT NYAM",NULL},
/* 16864 */ { "LETTRE BAMOUM DE PHASE 'B' NTIÉ SHÙO'",NULL},
/* 16865 */ { "LETTRE BAMOUM DE PHASE 'B' NDU NJAA",NULL},
/* 16866 */ { "LETTRE BAMOUM DE PHASE 'B' GHÙGHÙEM",NULL},
/* 16867 */ { "LETTRE BAMOUM DE PHASE 'B' PIT",NULL},
/* 16868 */ { "LETTRE BAMOUM DE PHASE 'B' TU NSIÉ",NULL},
/* 16869 */ { "LETTRE BAMOUM DE PHASE 'B' SHÈT NJA'",NULL},
/* 1686A */ { "LETTRE BAMOUM DE PHASE 'B' SHÙE'TU",NULL},
/* 1686B */ { "LETTRE BAMOUM DE PHASE 'B' MFON TÙE'",NULL},
/* 1686C */ { "LETTRE BAMOUM DE PHASE 'B' MBIT MBAAKÈT",NULL},
/* 1686D */ { "LETTRE BAMOUM DE PHASE 'B' NYI NTÙM",NULL},
/* 1686E */ { "LETTRE BAMOUM DE PHASE 'B' KÙPU'",NULL},
/* 1686F */ { "LETTRE BAMOUM DE PHASE 'B' GHÙGHÈN",NULL},
/* 16870 */ { "LETTRE BAMOUM DE PHASE 'B' KÙYÙX",NULL},
/* 16871 */ { "LETTRE BAMOUM DE PHASE 'B' LAANE",NULL},
/* 16872 */ { "LETTRE BAMOUM DE PHASE 'B' PARUM","	* nsèn dans les phases C à E"},
/* 16873 */ { "LETTRE BAMOUM DE PHASE 'B' VÙM",NULL},
/* 16874 */ { "LETTRE BAMOUM DE PHASE 'B' NGKINDI MVOP",NULL},
/* 16875 */ { "LETTRE BAMOUM DE PHASE 'B' NGGÙ MBU",NULL},
/* 16876 */ { "LETTRE BAMOUM DE PHASE 'B' WUET",NULL},
/* 16877 */ { "LETTRE BAMOUM DE PHASE 'B' SAKÙE",NULL},
/* 16878 */ { "LETTRE BAMOUM DE PHASE 'B' TAAM",NULL},
/* 16879 */ { "LETTRE BAMOUM DE PHASE 'B' MÙ'",NULL},
/* 1687A */ { "LETTRE BAMOUM DE PHASE 'B' NGGUO'",NULL},
/* 1687B */ { "LETTRE BAMOUM DE PHASE 'B' NGGUO' LARGÈ",NULL},
/* 1687C */ { "LETTRE BAMOUM DE PHASE 'B' MFIYA'",NULL},
/* 1687D */ { "LETTRE BAMOUM DE PHASE 'B' SÜ",NULL},
/* 1687E */ { "LETTRE BAMOUM DE PHASE 'B' MBÙRI",NULL},
/* 1687F */ { "LETTRE BAMOUM DE PHASE 'B' MONTIÉN",NULL},
/* 16880 */ { "LETTRE BAMOUM DE PHASE 'B' NYEME",NULL},
/* 16881 */ { "LETTRE BAMOUM DE PHASE 'B' PUNGGAAM","	* le nom formel de ce caractère en anglais est erroné"},
/* 16882 */ { "LETTRE BAMOUM DE PHASE 'B' MÙT NGGÉT",NULL},
/* 16883 */ { "LETTRE BAMOUM DE PHASE 'B' FÙX",NULL},
/* 16884 */ { "LETTRE BAMOUM DE PHASE 'B' MBUO'",NULL},
/* 16885 */ { "LETTRE BAMOUM DE PHASE 'B' FÉ",NULL},
/* 16886 */ { "LETTRE BAMOUM DE PHASE 'B' KÙEM",NULL},
/* 16887 */ { "LETTRE BAMOUM DE PHASE 'B' MA NJÙENA",NULL},
/* 16888 */ { "LETTRE BAMOUM DE PHASE 'B' MA NJU'A",NULL},
/* 16889 */ { "LETTRE BAMOUM DE PHASE 'B' LÈT",NULL},
/* 1688A */ { "LETTRE BAMOUM DE PHASE 'B' NGGAAM",NULL},
/* 1688B */ { "LETTRE BAMOUM DE PHASE 'B' NSÈN",NULL},
/* 1688C */ { "LETTRE BAMOUM DE PHASE 'B' MA",NULL},
/* 1688D */ { "LETTRE BAMOUM DE PHASE 'B' KI'",NULL},
/* 1688E */ { "LETTRE BAMOUM DE PHASE 'B' NGGOM",NULL},
/* 1688F */ { "LETTRE BAMOUM DE PHASE 'C' NGKÜ MEMBA",NULL},
/* 16890 */ { "LETTRE BAMOUM DE PHASE 'C' NZA",NULL},
/* 16891 */ { "LETTRE BAMOUM DE PHASE 'C' YUM",NULL},
/* 16892 */ { "LETTRE BAMOUM DE PHASE 'C' WANGKUO'",NULL},
/* 16893 */ { "LETTRE BAMOUM DE PHASE 'C' NGGÈN",NULL},
/* 16894 */ { "LETTRE BAMOUM DE PHASE 'C' NDÙERÉ",NULL},
/* 16895 */ { "LETTRE BAMOUM DE PHASE 'C' NGKA'",NULL},
/* 16896 */ { "LETTRE BAMOUM DE PHASE 'C' GHARE",NULL},
/* 16897 */ { "LETTRE BAMOUM DE PHASE 'C' MBÉKÉT",NULL},
/* 16898 */ { "LETTRE BAMOUM DE PHASE 'C' GBAYI",NULL},
/* 16899 */ { "LETTRE BAMOUM DE PHASE 'C' NYIR MKPARA' MÙN",NULL},
/* 1689A */ { "LETTRE BAMOUM DE PHASE 'C' NTU MBIT",NULL},
/* 1689B */ { "LETTRE BAMOUM DE PHASE 'C' MBÙM",NULL},
/* 1689C */ { "LETTRE BAMOUM DE PHASE 'C' PIRIÉN",NULL},
/* 1689D */ { "LETTRE BAMOUM DE PHASE 'C' NDOMBU",NULL},
/* 1689E */ { "LETTRE BAMOUM DE PHASE 'C' MBAA CABBAGÈ-TRÉ",NULL},
/* 1689F */ { "LETTRE BAMOUM DE PHASE 'C' KÙSHÙEP",NULL},
/* 168A0 */ { "LETTRE BAMOUM DE PHASE 'C' GHAP",NULL},
/* 168A1 */ { "LETTRE BAMOUM DE PHASE 'C' KÙKA'",NULL},
/* 168A2 */ { "LETTRE BAMOUM DE PHASE 'C' YU MUOME",NULL},
/* 168A3 */ { "LETTRE BAMOUM DE PHASE 'C' NZÙM",NULL},
/* 168A4 */ { "LETTRE BAMOUM DE PHASE 'C' MBÜ",NULL},
/* 168A5 */ { "LETTRE BAMOUM DE PHASE 'C' NSÙEN",NULL},
/* 168A6 */ { "LETTRE BAMOUM DE PHASE 'C' MBIT",NULL},
/* 168A7 */ { "LETTRE BAMOUM DE PHASE 'C' YÙ'",NULL},
/* 168A8 */ { "LETTRE BAMOUM DE PHASE 'C' KPARA'",NULL},
/* 168A9 */ { "LETTRE BAMOUM DE PHASE 'C' KAA",NULL},
/* 168AA */ { "LETTRE BAMOUM DE PHASE 'C' SÙX",NULL},
/* 168AB */ { "LETTRE BAMOUM DE PHASE 'C' NDIDA",NULL},
/* 168AC */ { "LETTRE BAMOUM DE PHASE 'C' TAASHE",NULL},
/* 168AD */ { "LETTRE BAMOUM DE PHASE 'C' NJÜ'",NULL},
/* 168AE */ { "LETTRE BAMOUM DE PHASE 'C' TITA YÜ",NULL},
/* 168AF */ { "LETTRE BAMOUM DE PHASE 'C' SUET",NULL},
/* 168B0 */ { "LETTRE BAMOUM DE PHASE 'C' NGGUEN NYAM",NULL},
/* 168B1 */ { "LETTRE BAMOUM DE PHASE 'C' VÙX",NULL},
/* 168B2 */ { "LETTRE BAMOUM DE PHASE 'C' NANSANA'",NULL},
/* 168B3 */ { "LETTRE BAMOUM DE PHASE 'C' MA KÙERI",NULL},
/* 168B4 */ { "LETTRE BAMOUM DE PHASE 'C' NTAA",NULL},
/* 168B5 */ { "LETTRE BAMOUM DE PHASE 'C' NGGUON",NULL},
/* 168B6 */ { "LETTRE BAMOUM DE PHASE 'C' LAP",NULL},
/* 168B7 */ { "LETTRE BAMOUM DE PHASE 'C' MBIRIÉN",NULL},
/* 168B8 */ { "LETTRE BAMOUM DE PHASE 'C' MGBASA'",NULL},
/* 168B9 */ { "LETTRE BAMOUM DE PHASE 'C' NTÙNGBA",NULL},
/* 168BA */ { "LETTRE BAMOUM DE PHASE 'C' TÙTÙX",NULL},
/* 168BB */ { "LETTRE BAMOUM DE PHASE 'C' NGGUM",NULL},
/* 168BC */ { "LETTRE BAMOUM DE PHASE 'C' FÜ",NULL},
/* 168BD */ { "LETTRE BAMOUM DE PHASE 'C' NDÙT",NULL},
/* 168BE */ { "LETTRE BAMOUM DE PHASE 'C' NSA",NULL},
/* 168BF */ { "LETTRE BAMOUM DE PHASE 'C' NSHA'",NULL},
/* 168C0 */ { "LETTRE BAMOUM DE PHASE 'C' BUNG",NULL},
/* 168C1 */ { "LETTRE BAMOUM DE PHASE 'C' VÙEPÈN",NULL},
/* 168C2 */ { "LETTRE BAMOUM DE PHASE 'C' MBÈRE",NULL},
/* 168C3 */ { "LETTRE BAMOUM DE PHASE 'C' RU",NULL},
/* 168C4 */ { "LETTRE BAMOUM DE PHASE 'C' NJEM",NULL},
/* 168C5 */ { "LETTRE BAMOUM DE PHASE 'C' LAM",NULL},
/* 168C6 */ { "LETTRE BAMOUM DE PHASE 'C' TITUEP",NULL},
/* 168C7 */ { "LETTRE BAMOUM DE PHASE 'C' NSUOT NGOM",NULL},
/* 168C8 */ { "LETTRE BAMOUM DE PHASE 'C' NJÉÉ",NULL},
/* 168C9 */ { "LETTRE BAMOUM DE PHASE 'C' KÈT",NULL},
/* 168CA */ { "LETTRE BAMOUM DE PHASE 'C' NGGU",NULL},
/* 168CB */ { "LETTRE BAMOUM DE PHASE 'C' MESI",NULL},
/* 168CC */ { "LETTRE BAMOUM DE PHASE 'C' MBUEM",NULL},
/* 168CD */ { "LETTRE BAMOUM DE PHASE 'C' LU",NULL},
/* 168CE */ { "LETTRE BAMOUM DE PHASE 'C' KUT",NULL},
/* 168CF */ { "LETTRE BAMOUM DE PHASE 'C' NJAM",NULL},
/* 168D0 */ { "LETTRE BAMOUM DE PHASE 'C' NGOM",NULL},
/* 168D1 */ { "LETTRE BAMOUM DE PHASE 'C' WUP",NULL},
/* 168D2 */ { "LETTRE BAMOUM DE PHASE 'C' NGGUÉT",NULL},
/* 168D3 */ { "LETTRE BAMOUM DE PHASE 'C' NSOM",NULL},
/* 168D4 */ { "LETTRE BAMOUM DE PHASE 'C' NTÈN",NULL},
/* 168D5 */ { "LETTRE BAMOUM DE PHASE 'C' KUOP NKAARE",NULL},
/* 168D6 */ { "LETTRE BAMOUM DE PHASE 'C' NSUN",NULL},
/* 168D7 */ { "LETTRE BAMOUM DE PHASE 'C' NDAM","	* pèn dans la phase D"},
/* 168D8 */ { "LETTRE BAMOUM DE PHASE 'C' MA NSIÉ",NULL},
/* 168D9 */ { "LETTRE BAMOUM DE PHASE 'C' YAA",NULL},
/* 168DA */ { "LETTRE BAMOUM DE PHASE 'C' NDAP",NULL},
/* 168DB */ { "LETTRE BAMOUM DE PHASE 'C' SHÜ'",NULL},
/* 168DC */ { "LETTRE BAMOUM DE PHASE 'C' SHÈTFON","	* le nom formel de ce caractère en anglais est erroné"},
/* 168DD */ { "LETTRE BAMOUM DE PHASE 'C' MBI",NULL},
/* 168DE */ { "LETTRE BAMOUM DE PHASE 'C' MEMBA",NULL},
/* 168DF */ { "LETTRE BAMOUM DE PHASE 'C' MBANYI",NULL},
/* 168E0 */ { "LETTRE BAMOUM DE PHASE 'C' KÙSÙX",NULL},
/* 168E1 */ { "LETTRE BAMOUM DE PHASE 'C' MBÙX",NULL},
/* 168E2 */ { "LETTRE BAMOUM DE PHASE 'C' KÙM",NULL},
/* 168E3 */ { "LETTRE BAMOUM DE PHASE 'C' MBAA PICKÈT",NULL},
/* 168E4 */ { "LETTRE BAMOUM DE PHASE 'C' YUWO'",NULL},
/* 168E5 */ { "LETTRE BAMOUM DE PHASE 'C' NJÙX",NULL},
/* 168E6 */ { "LETTRE BAMOUM DE PHASE 'C' MIÉ",NULL},
/* 168E7 */ { "LETTRE BAMOUM DE PHASE 'C' MUE",NULL},
/* 168E8 */ { "LETTRE BAMOUM DE PHASE 'C' SHI'",NULL},
/* 168E9 */ { "LETTRE BAMOUM DE PHASE 'C' KÈN LAW",NULL},
/* 168EA */ { "LETTRE BAMOUM DE PHASE 'C' KÈN FATIGÜ",NULL},
/* 168EB */ { "LETTRE BAMOUM DE PHASE 'C' NGA'",NULL},
/* 168EC */ { "LETTRE BAMOUM DE PHASE 'C' NA'",NULL},
/* 168ED */ { "LETTRE BAMOUM DE PHASE 'C' LI'",NULL},
/* 168EE */ { "LETTRE BAMOUM DE PHASE 'C' PIN",NULL},
/* 168EF */ { "LETTRE BAMOUM DE PHASE 'C' PÈN",NULL},
/* 168F0 */ { "LETTRE BAMOUM DE PHASE 'C' TÈT",NULL},
/* 168F1 */ { "LETTRE BAMOUM DE PHASE 'D' MBUO",NULL},
/* 168F2 */ { "LETTRE BAMOUM DE PHASE 'D' WAP",NULL},
/* 168F3 */ { "LETTRE BAMOUM DE PHASE 'D' NJI",NULL},
/* 168F4 */ { "LETTRE BAMOUM DE PHASE 'D' MFON",NULL},
/* 168F5 */ { "LETTRE BAMOUM DE PHASE 'D' NJIÉ",NULL},
/* 168F6 */ { "LETTRE BAMOUM DE PHASE 'D' LIÉ",NULL},
/* 168F7 */ { "LETTRE BAMOUM DE PHASE 'D' NJÙT",NULL},
/* 168F8 */ { "LETTRE BAMOUM DE PHASE 'D' NSHÉ",NULL},
/* 168F9 */ { "LETTRE BAMOUM DE PHASE 'D' NGGAAME",NULL},
/* 168FA */ { "LETTRE BAMOUM DE PHASE 'D' NYAM",NULL},
/* 168FB */ { "LETTRE BAMOUM DE PHASE 'D' WUEN","	* ti dans les phases E et F"},
/* 168FC */ { "LETTRE BAMOUM DE PHASE 'D' NGKUN",NULL},
/* 168FD */ { "LETTRE BAMOUM DE PHASE 'D' SHÉ",NULL},
/* 168FE */ { "LETTRE BAMOUM DE PHASE 'D' NGKAP",NULL},
/* 168FF */ { "LETTRE BAMOUM DE PHASE 'D' KÙETMÙN",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_69[] = {
/* 16900 */ { "LETTRE BAMOUM DE PHASE 'D' TÙT",NULL},
/* 16901 */ { "LETTRE BAMOUM DE PHASE 'D' SHÙE",NULL},
/* 16902 */ { "LETTRE BAMOUM DE PHASE 'D' NJAP",NULL},
/* 16903 */ { "LETTRE BAMOUM DE PHASE 'D' SÜ",NULL},
/* 16904 */ { "LETTRE BAMOUM DE PHASE 'D' KÈT",NULL},
/* 16905 */ { "LETTRE BAMOUM DE PHASE 'D' YEMME",NULL},
/* 16906 */ { "LETTRE BAMOUM DE PHASE 'D' KUOM",NULL},
/* 16907 */ { "LETTRE BAMOUM DE PHASE 'D' SAP",NULL},
/* 16908 */ { "LETTRE BAMOUM DE PHASE 'D' MFÙT",NULL},
/* 16909 */ { "LETTRE BAMOUM DE PHASE 'D' NDÙX",NULL},
/* 1690A */ { "LETTRE BAMOUM DE PHASE 'D' MALÉRI",NULL},
/* 1690B */ { "LETTRE BAMOUM DE PHASE 'D' MÙT",NULL},
/* 1690C */ { "LETTRE BAMOUM DE PHASE 'D' SÙE'",NULL},
/* 1690D */ { "LETTRE BAMOUM DE PHASE 'D' YÈN",NULL},
/* 1690E */ { "LETTRE BAMOUM DE PHASE 'D' NJÙEM",NULL},
/* 1690F */ { "LETTRE BAMOUM DE PHASE 'D' KÙOT MBUE",NULL},
/* 16910 */ { "LETTRE BAMOUM DE PHASE 'D' NGKÙRI",NULL},
/* 16911 */ { "LETTRE BAMOUM DE PHASE 'D' TU",NULL},
/* 16912 */ { "LETTRE BAMOUM DE PHASE 'D' GHAA",NULL},
/* 16913 */ { "LETTRE BAMOUM DE PHASE 'D' NGKYÉ",NULL},
/* 16914 */ { "LETTRE BAMOUM DE PHASE 'D' FÙFÙET",NULL},
/* 16915 */ { "LETTRE BAMOUM DE PHASE 'D' NDÉ",NULL},
/* 16916 */ { "LETTRE BAMOUM DE PHASE 'D' MGBOFUM",NULL},
/* 16917 */ { "LETTRE BAMOUM DE PHASE 'D' LÙEP",NULL},
/* 16918 */ { "LETTRE BAMOUM DE PHASE 'D' NDON",NULL},
/* 16919 */ { "LETTRE BAMOUM DE PHASE 'D' MONI",NULL},
/* 1691A */ { "LETTRE BAMOUM DE PHASE 'D' MGBÙN",NULL},
/* 1691B */ { "LETTRE BAMOUM DE PHASE 'D' PUUT",NULL},
/* 1691C */ { "LETTRE BAMOUM DE PHASE 'D' MGBIÉ",NULL},
/* 1691D */ { "LETTRE BAMOUM DE PHASE 'D' MFO",NULL},
/* 1691E */ { "LETTRE BAMOUM DE PHASE 'D' LUM",NULL},
/* 1691F */ { "LETTRE BAMOUM DE PHASE 'D' NSIÉP",NULL},
/* 16920 */ { "LETTRE BAMOUM DE PHASE 'D' MBAA",NULL},
/* 16921 */ { "LETTRE BAMOUM DE PHASE 'D' KWET",NULL},
/* 16922 */ { "LETTRE BAMOUM DE PHASE 'D' NYÈT",NULL},
/* 16923 */ { "LETTRE BAMOUM DE PHASE 'D' TÙEN",NULL},
/* 16924 */ { "LETTRE BAMOUM DE PHASE 'D' SOT",NULL},
/* 16925 */ { "LETTRE BAMOUM DE PHASE 'D' YUWO'",NULL},
/* 16926 */ { "LETTRE BAMOUM DE PHASE 'D' KÙM",NULL},
/* 16927 */ { "LETTRE BAMOUM DE PHASE 'D' REM",NULL},
/* 16928 */ { "LETTRE BAMOUM DE PHASE 'D' TÉÉ",NULL},
/* 16929 */ { "LETTRE BAMOUM DE PHASE 'D' NGKÙE'","	* faame « 8 » dans la phase F"},
/* 1692A */ { "LETTRE BAMOUM DE PHASE 'D' MFÙE",NULL},
/* 1692B */ { "LETTRE BAMOUM DE PHASE 'D' NSIÉT",NULL},
/* 1692C */ { "LETTRE BAMOUM DE PHASE 'D' KÙP",NULL},
/* 1692D */ { "LETTRE BAMOUM DE PHASE 'D' PIP",NULL},
/* 1692E */ { "LETTRE BAMOUM DE PHASE 'D' PÙTE",NULL},
/* 1692F */ { "LETTRE BAMOUM DE PHASE 'D' NYÜ",NULL},
/* 16930 */ { "LETTRE BAMOUM DE PHASE 'D' LÈT","	* lé dans les phases E et F"},
/* 16931 */ { "LETTRE BAMOUM DE PHASE 'D' NGGAAM","	* mu dans les phases E et F"},
/* 16932 */ { "LETTRE BAMOUM DE PHASE 'D' MFIÉ",NULL},
/* 16933 */ { "LETTRE BAMOUM DE PHASE 'D' NGGWEN",NULL},
/* 16934 */ { "LETTRE BAMOUM DE PHASE 'D' YUOM",NULL},
/* 16935 */ { "LETTRE BAMOUM DE PHASE 'D' PAP",NULL},
/* 16936 */ { "LETTRE BAMOUM DE PHASE 'D' YUOP",NULL},
/* 16937 */ { "LETTRE BAMOUM DE PHASE 'D' NDAM",NULL},
/* 16938 */ { "LETTRE BAMOUM DE PHASE 'D' NTÙM",NULL},
/* 16939 */ { "LETTRE BAMOUM DE PHASE 'D' SUE",NULL},
/* 1693A */ { "LETTRE BAMOUM DE PHASE 'D' KUN",NULL},
/* 1693B */ { "LETTRE BAMOUM DE PHASE 'D' NGGÙX",NULL},
/* 1693C */ { "LETTRE BAMOUM DE PHASE 'D' NGKIÉ",NULL},
/* 1693D */ { "LETTRE BAMOUM DE PHASE 'D' TUOT",NULL},
/* 1693E */ { "LETTRE BAMOUM DE PHASE 'D' MÙN",NULL},
/* 1693F */ { "LETTRE BAMOUM DE PHASE 'D' KU'",NULL},
/* 16940 */ { "LETTRE BAMOUM DE PHASE 'D' NSUM",NULL},
/* 16941 */ { "LETTRE BAMOUM DE PHASE 'D' TÙN",NULL},
/* 16942 */ { "LETTRE BAMOUM DE PHASE 'D' MENJÈT",NULL},
/* 16943 */ { "LETTRE BAMOUM DE PHASE 'D' NGGAP",NULL},
/* 16944 */ { "LETTRE BAMOUM DE PHASE 'D' LÙM",NULL},
/* 16945 */ { "LETTRE BAMOUM DE PHASE 'D' NGGUOM",NULL},
/* 16946 */ { "LETTRE BAMOUM DE PHASE 'D' NSHUT",NULL},
/* 16947 */ { "LETTRE BAMOUM DE PHASE 'D' NJÜ'",NULL},
/* 16948 */ { "LETTRE BAMOUM DE PHASE 'D' GHÙE",NULL},
/* 16949 */ { "LETTRE BAMOUM DE PHASE 'D' KU",NULL},
/* 1694A */ { "LETTRE BAMOUM DE PHASE 'D' RÈN OLD",NULL},
/* 1694B */ { "LETTRE BAMOUM DE PHASE 'D' TE",NULL},
/* 1694C */ { "LETTRE BAMOUM DE PHASE 'D' TO'",NULL},
/* 1694D */ { "LETTRE BAMOUM DE PHASE 'D' NYI",NULL},
/* 1694E */ { "LETTRE BAMOUM DE PHASE 'D' RII",NULL},
/* 1694F */ { "LETTRE BAMOUM DE PHASE 'D' LÉÉ",NULL},
/* 16950 */ { "LETTRE BAMOUM DE PHASE 'D' MÉÉ","	* mè' dans la phase E"},
/* 16951 */ { "LETTRE BAMOUM DE PHASE 'D' M",NULL},
/* 16952 */ { "LETTRE BAMOUM DE PHASE 'D' SUU",NULL},
/* 16953 */ { "LETTRE BAMOUM DE PHASE 'D' MU",NULL},
/* 16954 */ { "LETTRE BAMOUM DE PHASE 'D' SHII",NULL},
/* 16955 */ { "LETTRE BAMOUM DE PHASE 'D' SHÙX",NULL},
/* 16956 */ { "LETTRE BAMOUM DE PHASE 'D' KYÉ",NULL},
/* 16957 */ { "LETTRE BAMOUM DE PHASE 'D' NU",NULL},
/* 16958 */ { "LETTRE BAMOUM DE PHASE 'D' SHU",NULL},
/* 16959 */ { "LETTRE BAMOUM DE PHASE 'D' NTÉ",NULL},
/* 1695A */ { "LETTRE BAMOUM DE PHASE 'D' PÉ",NULL},
/* 1695B */ { "LETTRE BAMOUM DE PHASE 'D' NI",NULL},
/* 1695C */ { "LETTRE BAMOUM DE PHASE 'D' SHO'",NULL},
/* 1695D */ { "LETTRE BAMOUM DE PHASE 'D' PU'",NULL},
/* 1695E */ { "LETTRE BAMOUM DE PHASE 'D' MVOP",NULL},
/* 1695F */ { "LETTRE BAMOUM DE PHASE 'D' LO'",NULL},
/* 16960 */ { "LETTRE BAMOUM DE PHASE 'D' RÈN MUCH",NULL},
/* 16961 */ { "LETTRE BAMOUM DE PHASE 'D' TI",NULL},
/* 16962 */ { "LETTRE BAMOUM DE PHASE 'D' NTUU",NULL},
/* 16963 */ { "LETTRE BAMOUM DE PHASE 'D' MBAA SÈPT","	* utilisée après 16985 pour samba « 7 » dans les phases A à D"},
/* 16964 */ { "LETTRE BAMOUM DE PHASE 'D' SA'",NULL},
/* 16965 */ { "LETTRE BAMOUM DE PHASE 'D' FAA","	* utilisée avant 169B8 pour faame « 8 » dans les phases A à D"},
/* 16966 */ { "LETTRE BAMOUM DE PHASE 'E' NDAP","	* i dans la phase F"},
/* 16967 */ { "LETTRE BAMOUM DE PHASE 'E' TOON",NULL},
/* 16968 */ { "LETTRE BAMOUM DE PHASE 'E' MBÙM",NULL},
/* 16969 */ { "LETTRE BAMOUM DE PHASE 'E' LAP","	* mèn dans la phase F"},
/* 1696A */ { "LETTRE BAMOUM DE PHASE 'E' VOM",NULL},
/* 1696B */ { "LETTRE BAMOUM DE PHASE 'E' LOON",NULL},
/* 1696C */ { "LETTRE BAMOUM DE PHASE 'E' PAA",NULL},
/* 1696D */ { "LETTRE BAMOUM DE PHASE 'E' SOM",NULL},
/* 1696E */ { "LETTRE BAMOUM DE PHASE 'E' RA'","	* nga dans la phase F"},
/* 1696F */ { "LETTRE BAMOUM DE PHASE 'E' NSHUOP","	* pa dans la phase F"},
/* 16970 */ { "LETTRE BAMOUM DE PHASE 'E' NDUN","	* pü dans la phase F"},
/* 16971 */ { "LETTRE BAMOUM DE PHASE 'E' PUE","	* fe dans la phase F"},
/* 16972 */ { "LETTRE BAMOUM DE PHASE 'E' TAM",NULL},
/* 16973 */ { "LETTRE BAMOUM DE PHASE 'E' NGKA",NULL},
/* 16974 */ { "LETTRE BAMOUM DE PHASE 'E' KPÙX",NULL},
/* 16975 */ { "LETTRE BAMOUM DE PHASE 'E' WUO",NULL},
/* 16976 */ { "LETTRE BAMOUM DE PHASE 'E' SÉ",NULL},
/* 16977 */ { "LETTRE BAMOUM DE PHASE 'E' NGGÙET",NULL},
/* 16978 */ { "LETTRE BAMOUM DE PHASE 'E' PAAM",NULL},
/* 16979 */ { "LETTRE BAMOUM DE PHASE 'E' TOO",NULL},
/* 1697A */ { "LETTRE BAMOUM DE PHASE 'E' KUOP",NULL},
/* 1697B */ { "LETTRE BAMOUM DE PHASE 'E' LOM",NULL},
/* 1697C */ { "LETTRE BAMOUM DE PHASE 'E' NSHIÉ",NULL},
/* 1697D */ { "LETTRE BAMOUM DE PHASE 'E' NGGOP","	* le nom formel de ce caractère en anglais est erroné"},
/* 1697E */ { "LETTRE BAMOUM DE PHASE 'E' MEM",NULL},
/* 1697F */ { "LETTRE BAMOUM DE PHASE 'E' NGKÙX",NULL},
/* 16980 */ { "LETTRE BAMOUM DE PHASE 'E' NGO'",NULL},
/* 16981 */ { "LETTRE BAMOUM DE PHASE 'E' NSHÜ",NULL},
/* 16982 */ { "LETTRE BAMOUM DE PHASE 'E' RIMGBA",NULL},
/* 16983 */ { "LETTRE BAMOUM DE PHASE 'E' NJÙX",NULL},
/* 16984 */ { "LETTRE BAMOUM DE PHASE 'E' PÉM",NULL},
/* 16985 */ { "LETTRE BAMOUM DE PHASE 'E' SAA","	* utilisée avant 16963 pour samba « 7 » dans les phases A à D"},
/* 16986 */ { "LETTRE BAMOUM DE PHASE 'E' NGGURE",NULL},
/* 16987 */ { "LETTRE BAMOUM DE PHASE 'E' MGBA",NULL},
/* 16988 */ { "LETTRE BAMOUM DE PHASE 'E' GHÙX",NULL},
/* 16989 */ { "LETTRE BAMOUM DE PHASE 'E' NGKÙEM",NULL},
/* 1698A */ { "LETTRE BAMOUM DE PHASE 'E' NJEMLI",NULL},
/* 1698B */ { "LETTRE BAMOUM DE PHASE 'E' MAP",NULL},
/* 1698C */ { "LETTRE BAMOUM DE PHASE 'E' LOOT",NULL},
/* 1698D */ { "LETTRE BAMOUM DE PHASE 'E' NGGÉÉ",NULL},
/* 1698E */ { "LETTRE BAMOUM DE PHASE 'E' NDI'",NULL},
/* 1698F */ { "LETTRE BAMOUM DE PHASE 'E' TEN NTÙM",NULL},
/* 16990 */ { "LETTRE BAMOUM DE PHASE 'E' SÈT",NULL},
/* 16991 */ { "LETTRE BAMOUM DE PHASE 'E' PUM","	* o dans la phase F"},
/* 16992 */ { "LETTRE BAMOUM DE PHASE 'E' NDAA SOFTNÈSS",NULL},
/* 16993 */ { "LETTRE BAMOUM DE PHASE 'E' NGGUESHE NYAM","	* fé dans la phase F"},
/* 16994 */ { "LETTRE BAMOUM DE PHASE 'E' YIÉ",NULL},
/* 16995 */ { "LETTRE BAMOUM DE PHASE 'E' GHÙN",NULL},
/* 16996 */ { "LETTRE BAMOUM DE PHASE 'E' TUE",NULL},
/* 16997 */ { "LETTRE BAMOUM DE PHASE 'E' YÙE",NULL},
/* 16998 */ { "LETTRE BAMOUM DE PHASE 'E' PO",NULL},
/* 16999 */ { "LETTRE BAMOUM DE PHASE 'E' TUME",NULL},
/* 1699A */ { "LETTRE BAMOUM DE PHASE 'E' KÙE",NULL},
/* 1699B */ { "LETTRE BAMOUM DE PHASE 'E' SUEN",NULL},
/* 1699C */ { "LETTRE BAMOUM DE PHASE 'E' TÙE'",NULL},
/* 1699D */ { "LETTRE BAMOUM DE PHASE 'E' VÙE",NULL},
/* 1699E */ { "LETTRE BAMOUM DE PHASE 'E' WÙX",NULL},
/* 1699F */ { "LETTRE BAMOUM DE PHASE 'E' LAAM",NULL},
/* 169A0 */ { "LETTRE BAMOUM DE PHASE 'E' PU","	* également pu' dans la phase E"},
/* 169A1 */ { "LETTRE BAMOUM DE PHASE 'E' TAA'",NULL},
/* 169A2 */ { "LETTRE BAMOUM DE PHASE 'E' GHAAME",NULL},
/* 169A3 */ { "LETTRE BAMOUM DE PHASE 'E' NGÙRÙT",NULL},
/* 169A4 */ { "LETTRE BAMOUM DE PHASE 'E' SHÙE'",NULL},
/* 169A5 */ { "LETTRE BAMOUM DE PHASE 'E' MGBÈN",NULL},
/* 169A6 */ { "LETTRE BAMOUM DE PHASE 'E' MBÉ",NULL},
/* 169A7 */ { "LETTRE BAMOUM DE PHASE 'E' NZA'",NULL},
/* 169A8 */ { "LETTRE BAMOUM DE PHASE 'E' NKOM","	* tèn dans la phase F"},
/* 169A9 */ { "LETTRE BAMOUM DE PHASE 'E' GBÈT",NULL},
/* 169AA */ { "LETTRE BAMOUM DE PHASE 'E' TUM",NULL},
/* 169AB */ { "LETTRE BAMOUM DE PHASE 'E' KÜT",NULL},
/* 169AC */ { "LETTRE BAMOUM DE PHASE 'E' YAP",NULL},
/* 169AD */ { "LETTRE BAMOUM DE PHASE 'E' NYI CLÈAVÈR",NULL},
/* 169AE */ { "LETTRE BAMOUM DE PHASE 'E' YIT",NULL},
/* 169AF */ { "LETTRE BAMOUM DE PHASE 'E' MFÙ'",NULL},
/* 169B0 */ { "LETTRE BAMOUM DE PHASE 'E' NDIA'",NULL},
/* 169B1 */ { "LETTRE BAMOUM DE PHASE 'E' PIÉ'",NULL},
/* 169B2 */ { "LETTRE BAMOUM DE PHASE 'E' YÜ'",NULL},
/* 169B3 */ { "LETTRE BAMOUM DE PHASE 'E' LÙEM",NULL},
/* 169B4 */ { "LETTRE BAMOUM DE PHASE 'E' FÜ",NULL},
/* 169B5 */ { "LETTRE BAMOUM DE PHASE 'E' GBÙX",NULL},
/* 169B6 */ { "LETTRE BAMOUM DE PHASE 'E' NGKUP",NULL},
/* 169B7 */ { "LETTRE BAMOUM DE PHASE 'E' KÈT",NULL},
/* 169B8 */ { "LETTRE BAMOUM DE PHASE 'E' ME","	* utilisée après 16965 pour faame « 8 » dans les phases A à D"},
/* 169B9 */ { "LETTRE BAMOUM DE PHASE 'E' NGKAAMI",NULL},
/* 169BA */ { "LETTRE BAMOUM DE PHASE 'E' GHÈT",NULL},
/* 169BB */ { "LETTRE BAMOUM DE PHASE 'E' FA",NULL},
/* 169BC */ { "LETTRE BAMOUM DE PHASE 'E' NTUM",NULL},
/* 169BD */ { "LETTRE BAMOUM DE PHASE 'E' PÙT",NULL},
/* 169BE */ { "LETTRE BAMOUM DE PHASE 'E' YÙM",NULL},
/* 169BF */ { "LETTRE BAMOUM DE PHASE 'E' NGGÙE",NULL},
/* 169C0 */ { "LETTRE BAMOUM DE PHASE 'E' NYI BÈTWÉN",NULL},
/* 169C1 */ { "LETTRE BAMOUM DE PHASE 'E' NZU'",NULL},
/* 169C2 */ { "LETTRE BAMOUM DE PHASE 'E' POON",NULL},
/* 169C3 */ { "LETTRE BAMOUM DE PHASE 'E' MIÉ",NULL},
/* 169C4 */ { "LETTRE BAMOUM DE PHASE 'E' FÜT",NULL},
/* 169C5 */ { "LETTRE BAMOUM DE PHASE 'E' NE",NULL},
/* 169C6 */ { "LETTRE BAMOUM DE PHASE 'E' MUE",NULL},
/* 169C7 */ { "LETTRE BAMOUM DE PHASE 'E' GHÙE",NULL},
/* 169C8 */ { "LETTRE BAMOUM DE PHASE 'E' FU I",NULL},
/* 169C9 */ { "LETTRE BAMOUM DE PHASE 'E' MVI",NULL},
/* 169CA */ { "LETTRE BAMOUM DE PHASE 'E' PUA'",NULL},
/* 169CB */ { "LETTRE BAMOUM DE PHASE 'E' NGKUM",NULL},
/* 169CC */ { "LETTRE BAMOUM DE PHASE 'E' KUT",NULL},
/* 169CD */ { "LETTRE BAMOUM DE PHASE 'E' PIÈT",NULL},
/* 169CE */ { "LETTRE BAMOUM DE PHASE 'E' NTAP",NULL},
/* 169CF */ { "LETTRE BAMOUM DE PHASE 'E' YÙET",NULL},
/* 169D0 */ { "LETTRE BAMOUM DE PHASE 'E' NGGUP",NULL},
/* 169D1 */ { "LETTRE BAMOUM DE PHASE 'E' PA PÈOPLÈ",NULL},
/* 169D2 */ { "LETTRE BAMOUM DE PHASE 'E' FU CALL",NULL},
/* 169D3 */ { "LETTRE BAMOUM DE PHASE 'E' FOM",NULL},
/* 169D4 */ { "LETTRE BAMOUM DE PHASE 'E' NJÉ",NULL},
/* 169D5 */ { "LETTRE BAMOUM DE PHASE 'E' A",NULL},
/* 169D6 */ { "LETTRE BAMOUM DE PHASE 'E' TO'",NULL},
/* 169D7 */ { "LETTRE BAMOUM DE PHASE 'E' O",NULL},
/* 169D8 */ { "LETTRE BAMOUM DE PHASE 'E' I",NULL},
/* 169D9 */ { "LETTRE BAMOUM DE PHASE 'E' LA'",NULL},
/* 169DA */ { "LETTRE BAMOUM DE PHASE 'E' PA PLURAL",NULL},
/* 169DB */ { "LETTRE BAMOUM DE PHASE 'E' TAA",NULL},
/* 169DC */ { "LETTRE BAMOUM DE PHASE 'E' TA'",NULL},
/* 169DD */ { "LETTRE BAMOUM DE PHASE 'E' NDAA MY HOUSÈ",NULL},
/* 169DE */ { "LETTRE BAMOUM DE PHASE 'E' SHI'",NULL},
/* 169DF */ { "LETTRE BAMOUM DE PHASE 'E' YÙX",NULL},
/* 169E0 */ { "LETTRE BAMOUM DE PHASE 'E' NGUE",NULL},
/* 169E1 */ { "LETTRE BAMOUM DE PHASE 'E' YUEN","	* pi dans la phase F"},
/* 169E2 */ { "LETTRE BAMOUM DE PHASE 'E' YO' SWIMMING",NULL},
/* 169E3 */ { "LETTRE BAMOUM DE PHASE 'E' YO' COVÈR",NULL},
/* 169E4 */ { "LETTRE BAMOUM DE PHASE 'E' YU'",NULL},
/* 169E5 */ { "LETTRE BAMOUM DE PHASE 'E' YUN",NULL},
/* 169E6 */ { "LETTRE BAMOUM DE PHASE 'E' KÙX",NULL},
/* 169E7 */ { "LETTRE BAMOUM DE PHASE 'E' PÙX",NULL},
/* 169E8 */ { "LETTRE BAMOUM DE PHASE 'E' NJÉ ÈPOCH",NULL},
/* 169E9 */ { "LETTRE BAMOUM DE PHASE 'E' PÜ",NULL},
/* 169EA */ { "LETTRE BAMOUM DE PHASE 'E' WÜ",NULL},
/* 169EB */ { "LETTRE BAMOUM DE PHASE 'E' FÉ",NULL},
/* 169EC */ { "LETTRE BAMOUM DE PHASE 'E' VÉ",NULL},
/* 169ED */ { "LETTRE BAMOUM DE PHASE 'E' LU",NULL},
/* 169EE */ { "LETTRE BAMOUM DE PHASE 'E' MI",NULL},
/* 169EF */ { "LETTRE BAMOUM DE PHASE 'E' RÙX",NULL},
/* 169F0 */ { "LETTRE BAMOUM DE PHASE 'E' RE",NULL},
/* 169F1 */ { "LETTRE BAMOUM DE PHASE 'E' NGUET",NULL},
/* 169F2 */ { "LETTRE BAMOUM DE PHASE 'E' NGA",NULL},
/* 169F3 */ { "LETTRE BAMOUM DE PHASE 'E' SHO",NULL},
/* 169F4 */ { "LETTRE BAMOUM DE PHASE 'E' SHO'",NULL},
/* 169F5 */ { "LETTRE BAMOUM DE PHASE 'E' FU RÈMÈDY",NULL},
/* 169F6 */ { "LETTRE BAMOUM DE PHASE 'E' NA",NULL},
/* 169F7 */ { "LETTRE BAMOUM DE PHASE 'E' PI",NULL},
/* 169F8 */ { "LETTRE BAMOUM DE PHASE 'E' LO'",NULL},
/* 169F9 */ { "LETTRE BAMOUM DE PHASE 'E' KO","	* utilisée avant 16A02 pour koghom « 10 » dans les phases A à D\n"
	"	* utilisée avant 16A38 pour kovü « 9 » dans les phases A à D"},
/* 169FA */ { "LETTRE BAMOUM DE PHASE 'E' MÈN",NULL},
/* 169FB */ { "LETTRE BAMOUM DE PHASE 'E' MA",NULL},
/* 169FC */ { "LETTRE BAMOUM DE PHASE 'E' MA'",NULL},
/* 169FD */ { "LETTRE BAMOUM DE PHASE 'E' TÙ",NULL},
/* 169FE */ { "LETTRE BAMOUM DE PHASE 'E' KI","	* koghom dans la phase F"},
/* 169FF */ { "LETTRE BAMOUM DE PHASE 'E' MON",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_6A[] = {
/* 16A00 */ { "LETTRE BAMOUM DE PHASE 'E' TÈN",NULL},
/* 16A01 */ { "LETTRE BAMOUM DE PHASE 'E' FA'",NULL},
/* 16A02 */ { "LETTRE BAMOUM DE PHASE 'E' GHOM","	* utilisée après 169F9 pour koghom « 10 » dans les phases A à D"},
/* 16A03 */ { "LETTRE BAMOUM DE PHASE 'F' KA",NULL},
/* 16A04 */ { "LETTRE BAMOUM DE PHASE 'F' U",NULL},
/* 16A05 */ { "LETTRE BAMOUM DE PHASE 'F' KU",NULL},
/* 16A06 */ { "LETTRE BAMOUM DE PHASE 'F' É",NULL},
/* 16A07 */ { "LETTRE BAMOUM DE PHASE 'F' RÉ",NULL},
/* 16A08 */ { "LETTRE BAMOUM DE PHASE 'F' TE",NULL},
/* 16A09 */ { "LETTRE BAMOUM DE PHASE 'F' NYI",NULL},
/* 16A0A */ { "LETTRE BAMOUM DE PHASE 'F' LA",NULL},
/* 16A0B */ { "LETTRE BAMOUM DE PHASE 'F' RII",NULL},
/* 16A0C */ { "LETTRE BAMOUM DE PHASE 'F' RIÉ",NULL},
/* 16A0D */ { "LETTRE BAMOUM DE PHASE 'F' MÉÉ",NULL},
/* 16A0E */ { "LETTRE BAMOUM DE PHASE 'F' TAA",NULL},
/* 16A0F */ { "LETTRE BAMOUM DE PHASE 'F' NDAA",NULL},
/* 16A10 */ { "LETTRE BAMOUM DE PHASE 'F' NJEM",NULL},
/* 16A11 */ { "LETTRE BAMOUM DE PHASE 'F' M",NULL},
/* 16A12 */ { "LETTRE BAMOUM DE PHASE 'F' SUU",NULL},
/* 16A13 */ { "LETTRE BAMOUM DE PHASE 'F' SHII",NULL},
/* 16A14 */ { "LETTRE BAMOUM DE PHASE 'F' SI",NULL},
/* 16A15 */ { "LETTRE BAMOUM DE PHASE 'F' SÙX",NULL},
/* 16A16 */ { "LETTRE BAMOUM DE PHASE 'F' KYÉ",NULL},
/* 16A17 */ { "LETTRE BAMOUM DE PHASE 'F' KÈT",NULL},
/* 16A18 */ { "LETTRE BAMOUM DE PHASE 'F' NUE",NULL},
/* 16A19 */ { "LETTRE BAMOUM DE PHASE 'F' NU",NULL},
/* 16A1A */ { "LETTRE BAMOUM DE PHASE 'F' NJUE",NULL},
/* 16A1B */ { "LETTRE BAMOUM DE PHASE 'F' YO'",NULL},
/* 16A1C */ { "LETTRE BAMOUM DE PHASE 'F' SHU",NULL},
/* 16A1D */ { "LETTRE BAMOUM DE PHASE 'F' YA",NULL},
/* 16A1E */ { "LETTRE BAMOUM DE PHASE 'F' NSHA",NULL},
/* 16A1F */ { "LETTRE BAMOUM DE PHASE 'F' PÙX",NULL},
/* 16A20 */ { "LETTRE BAMOUM DE PHASE 'F' NTÉ",NULL},
/* 16A21 */ { "LETTRE BAMOUM DE PHASE 'F' WÜ",NULL},
/* 16A22 */ { "LETTRE BAMOUM DE PHASE 'F' PÉ",NULL},
/* 16A23 */ { "LETTRE BAMOUM DE PHASE 'F' RU",NULL},
/* 16A24 */ { "LETTRE BAMOUM DE PHASE 'F' NI",NULL},
/* 16A25 */ { "LETTRE BAMOUM DE PHASE 'F' RÙX",NULL},
/* 16A26 */ { "LETTRE BAMOUM DE PHASE 'F' KÈN",NULL},
/* 16A27 */ { "LETTRE BAMOUM DE PHASE 'F' NGKWEN",NULL},
/* 16A28 */ { "LETTRE BAMOUM DE PHASE 'F' NGGA",NULL},
/* 16A29 */ { "LETTRE BAMOUM DE PHASE 'F' SHO",NULL},
/* 16A2A */ { "LETTRE BAMOUM DE PHASE 'F' PUE",NULL},
/* 16A2B */ { "LETTRE BAMOUM DE PHASE 'F' FOM",NULL},
/* 16A2C */ { "LETTRE BAMOUM DE PHASE 'F' WA",NULL},
/* 16A2D */ { "LETTRE BAMOUM DE PHASE 'F' LI",NULL},
/* 16A2E */ { "LETTRE BAMOUM DE PHASE 'F' LO'",NULL},
/* 16A2F */ { "LETTRE BAMOUM DE PHASE 'F' KO",NULL},
/* 16A30 */ { "LETTRE BAMOUM DE PHASE 'F' MBÈN",NULL},
/* 16A31 */ { "LETTRE BAMOUM DE PHASE 'F' RÈN",NULL},
/* 16A32 */ { "LETTRE BAMOUM DE PHASE 'F' MA",NULL},
/* 16A33 */ { "LETTRE BAMOUM DE PHASE 'F' MO",NULL},
/* 16A34 */ { "LETTRE BAMOUM DE PHASE 'F' MBAA",NULL},
/* 16A35 */ { "LETTRE BAMOUM DE PHASE 'F' TÈT",NULL},
/* 16A36 */ { "LETTRE BAMOUM DE PHASE 'F' KPA",NULL},
/* 16A37 */ { "LETTRE BAMOUM DE PHASE 'F' SAMBA",NULL},
/* 16A38 */ { "LETTRE BAMOUM DE PHASE 'F' VÜ'","	* utilisée après 169F9 pour kovü « 9 » dans les phases A à D"},
/* 16A39 */ { NULL,NULL},
/* 16A3A */ { NULL,NULL},
/* 16A3B */ { NULL,NULL},
/* 16A3C */ { NULL,NULL},
/* 16A3D */ { NULL,NULL},
/* 16A3E */ { NULL,NULL},
/* 16A3F */ { NULL,NULL},
/* 16A40 */ { "LETTRE MRO TA",NULL},
/* 16A41 */ { "LETTRE MRO NGI",NULL},
/* 16A42 */ { "LETTRE MRO YO",NULL},
/* 16A43 */ { "LETTRE MRO MIM",NULL},
/* 16A44 */ { "LETTRE MRO BA",NULL},
/* 16A45 */ { "LETTRE MRO DA",NULL},
/* 16A46 */ { "LETTRE MRO A",NULL},
/* 16A47 */ { "LETTRE MRO PHI",NULL},
/* 16A48 */ { "LETTRE MRO KHAI",NULL},
/* 16A49 */ { "LETTRE MRO HAO",NULL},
/* 16A4A */ { "LETTRE MRO DAI","	= i"},
/* 16A4B */ { "LETTRE MRO CHU",NULL},
/* 16A4C */ { "LETTRE MRO KEAAE",NULL},
/* 16A4D */ { "LETTRE MRO OL",NULL},
/* 16A4E */ { "LETTRE MRO MAEM",NULL},
/* 16A4F */ { "LETTRE MRO NIN",NULL},
/* 16A50 */ { "LETTRE MRO PA",NULL},
/* 16A51 */ { "LETTRE MRO OO",NULL},
/* 16A52 */ { "LETTRE MRO O",NULL},
/* 16A53 */ { "LETTRE MRO RO",NULL},
/* 16A54 */ { "LETTRE MRO SHI",NULL},
/* 16A55 */ { "LETTRE MRO THEA",NULL},
/* 16A56 */ { "LETTRE MRO EA",NULL},
/* 16A57 */ { "LETTRE MRO WA",NULL},
/* 16A58 */ { "LETTRE MRO E",NULL},
/* 16A59 */ { "LETTRE MRO KO",NULL},
/* 16A5A */ { "LETTRE MRO LAN",NULL},
/* 16A5B */ { "LETTRE MRO LA","	* symbole pour « mois »"},
/* 16A5C */ { "LETTRE MRO HAI",NULL},
/* 16A5D */ { "LETTRE MRO RI","	= o"},
/* 16A5E */ { "LETTRE MRO TEK",NULL},
/* 16A5F */ { NULL,NULL},
/* 16A60 */ { "CHIFFRE MRO ZÉRO",NULL},
/* 16A61 */ { "CHIFFRE MRO UN",NULL},
/* 16A62 */ { "CHIFFRE MRO DEUX",NULL},
/* 16A63 */ { "CHIFFRE MRO TROIS",NULL},
/* 16A64 */ { "CHIFFRE MRO QUATRE",NULL},
/* 16A65 */ { "CHIFFRE MRO CINQ",NULL},
/* 16A66 */ { "CHIFFRE MRO SIX",NULL},
/* 16A67 */ { "CHIFFRE MRO SEPT",NULL},
/* 16A68 */ { "CHIFFRE MRO HUIT",NULL},
/* 16A69 */ { "CHIFFRE MRO NEUF",NULL},
/* 16A6A */ { NULL,NULL},
/* 16A6B */ { NULL,NULL},
/* 16A6C */ { NULL,NULL},
/* 16A6D */ { NULL,NULL},
/* 16A6E */ { "DANDA MRO",NULL},
/* 16A6F */ { "DOUBLE DANDA MRO",NULL},
/* 16A70 */ { "LETTRE TANGSA OZ",NULL},
/* 16A71 */ { "LETTRE TANGSA OC",NULL},
/* 16A72 */ { "LETTRE TANGSA OQ",NULL},
/* 16A73 */ { "LETTRE TANGSA OX",NULL},
/* 16A74 */ { "LETTRE TANGSA AZ",NULL},
/* 16A75 */ { "LETTRE TANGSA AC",NULL},
/* 16A76 */ { "LETTRE TANGSA AQ",NULL},
/* 16A77 */ { "LETTRE TANGSA AX",NULL},
/* 16A78 */ { "LETTRE TANGSA VZ",NULL},
/* 16A79 */ { "LETTRE TANGSA VC",NULL},
/* 16A7A */ { "LETTRE TANGSA VQ",NULL},
/* 16A7B */ { "LETTRE TANGSA VX",NULL},
/* 16A7C */ { "LETTRE TANGSA EZ",NULL},
/* 16A7D */ { "LETTRE TANGSA EC",NULL},
/* 16A7E */ { "LETTRE TANGSA EQ",NULL},
/* 16A7F */ { "LETTRE TANGSA EX",NULL},
/* 16A80 */ { "LETTRE TANGSA IZ",NULL},
/* 16A81 */ { "LETTRE TANGSA IC",NULL},
/* 16A82 */ { "LETTRE TANGSA IQ",NULL},
/* 16A83 */ { "LETTRE TANGSA IX",NULL},
/* 16A84 */ { "LETTRE TANGSA UZ",NULL},
/* 16A85 */ { "LETTRE TANGSA UC",NULL},
/* 16A86 */ { "LETTRE TANGSA UQ",NULL},
/* 16A87 */ { "LETTRE TANGSA UX",NULL},
/* 16A88 */ { "LETTRE TANGSA AWZ",NULL},
/* 16A89 */ { "LETTRE TANGSA AWC",NULL},
/* 16A8A */ { "LETTRE TANGSA AWQ",NULL},
/* 16A8B */ { "LETTRE TANGSA AWX",NULL},
/* 16A8C */ { "LETTRE TANGSA UIZ",NULL},
/* 16A8D */ { "LETTRE TANGSA UIC",NULL},
/* 16A8E */ { "LETTRE TANGSA UIQ",NULL},
/* 16A8F */ { "LETTRE TANGSA UIX",NULL},
/* 16A90 */ { "LETTRE TANGSA NG FINAL",NULL},
/* 16A91 */ { "LETTRE TANGSA UEX LONG",NULL},
/* 16A92 */ { "LETTRE TANGSA UEZ COURT",NULL},
/* 16A93 */ { "LETTRE TANGSA AWX COURT",NULL},
/* 16A94 */ { "LETTRE TANGSA UEC",NULL},
/* 16A95 */ { "LETTRE TANGSA UEZ",NULL},
/* 16A96 */ { "LETTRE TANGSA UEQ",NULL},
/* 16A97 */ { "LETTRE TANGSA UEX",NULL},
/* 16A98 */ { "LETTRE TANGSA UIUZ",NULL},
/* 16A99 */ { "LETTRE TANGSA UIUC",NULL},
/* 16A9A */ { "LETTRE TANGSA UIUQ",NULL},
/* 16A9B */ { "LETTRE TANGSA UIUX",NULL},
/* 16A9C */ { "LETTRE TANGSA MZ",NULL},
/* 16A9D */ { "LETTRE TANGSA MC",NULL},
/* 16A9E */ { "LETTRE TANGSA MQ",NULL},
/* 16A9F */ { "LETTRE TANGSA MX",NULL},
/* 16AA0 */ { "LETTRE TANGSA KA",NULL},
/* 16AA1 */ { "LETTRE TANGSA KHA",NULL},
/* 16AA2 */ { "LETTRE TANGSA GA",NULL},
/* 16AA3 */ { "LETTRE TANGSA NGA",NULL},
/* 16AA4 */ { "LETTRE TANGSA SA",NULL},
/* 16AA5 */ { "LETTRE TANGSA YA",NULL},
/* 16AA6 */ { "LETTRE TANGSA WA",NULL},
/* 16AA7 */ { "LETTRE TANGSA PA",NULL},
/* 16AA8 */ { "LETTRE TANGSA NYA",NULL},
/* 16AA9 */ { "LETTRE TANGSA PHA",NULL},
/* 16AAA */ { "LETTRE TANGSA BA",NULL},
/* 16AAB */ { "LETTRE TANGSA MA",NULL},
/* 16AAC */ { "LETTRE TANGSA NA",NULL},
/* 16AAD */ { "LETTRE TANGSA HA",NULL},
/* 16AAE */ { "LETTRE TANGSA LA",NULL},
/* 16AAF */ { "LETTRE TANGSA HTA",NULL},
/* 16AB0 */ { "LETTRE TANGSA TA",NULL},
/* 16AB1 */ { "LETTRE TANGSA DA",NULL},
/* 16AB2 */ { "LETTRE TANGSA RA",NULL},
/* 16AB3 */ { "LETTRE TANGSA NHA",NULL},
/* 16AB4 */ { "LETTRE TANGSA SHA",NULL},
/* 16AB5 */ { "LETTRE TANGSA CA",NULL},
/* 16AB6 */ { "LETTRE TANGSA TSA",NULL},
/* 16AB7 */ { "LETTRE TANGSA GHA",NULL},
/* 16AB8 */ { "LETTRE TANGSA HTTA",NULL},
/* 16AB9 */ { "LETTRE TANGSA THA",NULL},
/* 16ABA */ { "LETTRE TANGSA XA",NULL},
/* 16ABB */ { "LETTRE TANGSA FA",NULL},
/* 16ABC */ { "LETTRE TANGSA DHA",NULL},
/* 16ABD */ { "LETTRE TANGSA CHA",NULL},
/* 16ABE */ { "LETTRE TANGSA ZA",NULL},
/* 16ABF */ { NULL,NULL},
/* 16AC0 */ { "CHIFFRE TANGSA ZÉRO",NULL},
/* 16AC1 */ { "CHIFFRE TANGSA UN",NULL},
/* 16AC2 */ { "CHIFFRE TANGSA DEUX",NULL},
/* 16AC3 */ { "CHIFFRE TANGSA TROIS",NULL},
/* 16AC4 */ { "CHIFFRE TANGSA QUATRE",NULL},
/* 16AC5 */ { "CHIFFRE TANGSA CINQ",NULL},
/* 16AC6 */ { "CHIFFRE TANGSA SIX",NULL},
/* 16AC7 */ { "CHIFFRE TANGSA SEPT",NULL},
/* 16AC8 */ { "CHIFFRE TANGSA HUIT",NULL},
/* 16AC9 */ { "CHIFFRE TANGSA NEUF",NULL},
/* 16ACA */ { NULL,NULL},
/* 16ACB */ { NULL,NULL},
/* 16ACC */ { NULL,NULL},
/* 16ACD */ { NULL,NULL},
/* 16ACE */ { NULL,NULL},
/* 16ACF */ { NULL,NULL},
/* 16AD0 */ { "LETTRE VAH BASSA ENNI",NULL},
/* 16AD1 */ { "LETTRE VAH BASSA KA",NULL},
/* 16AD2 */ { "LETTRE VAH BASSA SÉ",NULL},
/* 16AD3 */ { "LETTRE VAH BASSA FA",NULL},
/* 16AD4 */ { "LETTRE VAH BASSA MBÉ",NULL},
/* 16AD5 */ { "LETTRE VAH BASSA YIÉ",NULL},
/* 16AD6 */ { "LETTRE VAH BASSA GAH",NULL},
/* 16AD7 */ { "LETTRE VAH BASSA DHÎ",NULL},
/* 16AD8 */ { "LETTRE VAH BASSA KPAH",NULL},
/* 16AD9 */ { "LETTRE VAH BASSA DJO",NULL},
/* 16ADA */ { "LETTRE VAH BASSA HWAH",NULL},
/* 16ADB */ { "LETTRE VAH BASSA WA",NULL},
/* 16ADC */ { "LETTRE VAH BASSA ZO",NULL},
/* 16ADD */ { "LETTRE VAH BASSA GBOU",NULL},
/* 16ADE */ { "LETTRE VAH BASSA DO",NULL},
/* 16ADF */ { "LETTRE VAH BASSA TCHÉ",NULL},
/* 16AE0 */ { "LETTRE VAH BASSA OUWOU",NULL},
/* 16AE1 */ { "LETTRE VAH BASSA TO",NULL},
/* 16AE2 */ { "LETTRE VAH BASSA BA",NULL},
/* 16AE3 */ { "LETTRE VAH BASSA VOU",NULL},
/* 16AE4 */ { "LETTRE VAH BASSA YÉIN",NULL},
/* 16AE5 */ { "LETTRE VAH BASSA PA",NULL},
/* 16AE6 */ { "LETTRE VAH BASSA WADDA",NULL},
/* 16AE7 */ { "LETTRE VAH BASSA A",NULL},
/* 16AE8 */ { "LETTRE VAH BASSA O",NULL},
/* 16AE9 */ { "LETTRE VAH BASSA Ô",NULL},
/* 16AEA */ { "LETTRE VAH BASSA OU",NULL},
/* 16AEB */ { "LETTRE VAH BASSA È",NULL},
/* 16AEC */ { "LETTRE VAH BASSA É",NULL},
/* 16AED */ { "LETTRE VAH BASSA I",NULL},
/* 16AEE */ { NULL,NULL},
/* 16AEF */ { NULL,NULL},
/* 16AF0 */ { "DIACRITIQUE VAH BASSA TON HAUT",NULL},
/* 16AF1 */ { "DIACRITIQUE VAH BASSA TON BAS",NULL},
/* 16AF2 */ { "DIACRITIQUE VAH BASSA TON MOYEN",NULL},
/* 16AF3 */ { "DIACRITIQUE VAH BASSA TON MOYEN-BAS",NULL},
/* 16AF4 */ { "DIACRITIQUE VAH BASSA TON MOYEN-HAUT",NULL},
/* 16AF5 */ { "POINT VAH BASSA",NULL},
/* 16AF6 */ { NULL,NULL},
/* 16AF7 */ { NULL,NULL},
/* 16AF8 */ { NULL,NULL},
/* 16AF9 */ { NULL,NULL},
/* 16AFA */ { NULL,NULL},
/* 16AFB */ { NULL,NULL},
/* 16AFC */ { NULL,NULL},
/* 16AFD */ { NULL,NULL},
/* 16AFE */ { NULL,NULL},
/* 16AFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_6B[] = {
/* 16B00 */ { "VOYELLE PAHAWH HMONG KEEB","	= keem"},
/* 16B01 */ { "VOYELLE PAHAWH HMONG KEEV","	= kee"},
/* 16B02 */ { "VOYELLE PAHAWH HMONG KIB","	= kim"},
/* 16B03 */ { "VOYELLE PAHAWH HMONG KIV","	= ki"},
/* 16B04 */ { "VOYELLE PAHAWH HMONG KAUB","	= kaum"},
/* 16B05 */ { "VOYELLE PAHAWH HMONG KAUV","	= kau"},
/* 16B06 */ { "VOYELLE PAHAWH HMONG KUB","	= kum"},
/* 16B07 */ { "VOYELLE PAHAWH HMONG KUV","	= ke"},
/* 16B08 */ { "VOYELLE PAHAWH HMONG KEB","	= kem"},
/* 16B09 */ { "VOYELLE PAHAWH HMONG KEV",NULL},
/* 16B0A */ { "VOYELLE PAHAWH HMONG KAIB","	= kaim"},
/* 16B0B */ { "VOYELLE PAHAWH HMONG KAIV","	= kai"},
/* 16B0C */ { "VOYELLE PAHAWH HMONG KOOB",NULL},
/* 16B0D */ { "VOYELLE PAHAWH HMONG KOOV",NULL},
/* 16B0E */ { "VOYELLE PAHAWH HMONG KAWB",NULL},
/* 16B0F */ { "VOYELLE PAHAWH HMONG KAWV","	= kaw"},
/* 16B10 */ { "VOYELLE PAHAWH HMONG KUAB","	= kuam"},
/* 16B11 */ { "VOYELLE PAHAWH HMONG KUAV","	= kua"},
/* 16B12 */ { "VOYELLE PAHAWH HMONG KOB","	= kom"},
/* 16B13 */ { "VOYELLE PAHAWH HMONG KOV","	= kog"},
/* 16B14 */ { "VOYELLE PAHAWH HMONG KIAB",NULL},
/* 16B15 */ { "VOYELLE PAHAWH HMONG KIAV","	= kia"},
/* 16B16 */ { "VOYELLE PAHAWH HMONG KAB","	= kam"},
/* 16B17 */ { "VOYELLE PAHAWH HMONG KAV",NULL},
/* 16B18 */ { "VOYELLE PAHAWH HMONG KWB","	= kwm"},
/* 16B19 */ { "VOYELLE PAHAWH HMONG KWV",NULL},
/* 16B1A */ { "VOYELLE PAHAWH HMONG KAAB","	= kaam"},
/* 16B1B */ { "VOYELLE PAHAWH HMONG KAAV",NULL},
/* 16B1C */ { "CONSONNE PAHAWH HMONG VAU",NULL},
/* 16B1D */ { "CONSONNE PAHAWH HMONG NTSAU",NULL},
/* 16B1E */ { "CONSONNE PAHAWH HMONG LAU",NULL},
/* 16B1F */ { "CONSONNE PAHAWH HMONG HAU",NULL},
/* 16B20 */ { "CONSONNE PAHAWH HMONG NLAU",NULL},
/* 16B21 */ { "CONSONNE PAHAWH HMONG RAU",NULL},
/* 16B22 */ { "CONSONNE PAHAWH HMONG NKAU",NULL},
/* 16B23 */ { "CONSONNE PAHAWH HMONG QHAU",NULL},
/* 16B24 */ { "CONSONNE PAHAWH HMONG YAU",NULL},
/* 16B25 */ { "CONSONNE PAHAWH HMONG HLAU",NULL},
/* 16B26 */ { "CONSONNE PAHAWH HMONG MAU",NULL},
/* 16B27 */ { "CONSONNE PAHAWH HMONG CHAU",NULL},
/* 16B28 */ { "CONSONNE PAHAWH HMONG NCHAU",NULL},
/* 16B29 */ { "CONSONNE PAHAWH HMONG HNAU",NULL},
/* 16B2A */ { "CONSONNE PAHAWH HMONG PLHAU",NULL},
/* 16B2B */ { "CONSONNE PAHAWH HMONG NTHAU",NULL},
/* 16B2C */ { "CONSONNE PAHAWH HMONG NAU",NULL},
/* 16B2D */ { "CONSONNE PAHAWH HMONG AU",NULL},
/* 16B2E */ { "CONSONNE PAHAWH HMONG XAU",NULL},
/* 16B2F */ { "CONSONNE PAHAWH HMONG CAU",NULL},
/* 16B30 */ { "DIACRITIQUE PAHAWH HMONG CIM TUB",NULL},
/* 16B31 */ { "DIACRITIQUE PAHAWH HMONG CIM SO",NULL},
/* 16B32 */ { "DIACRITIQUE PAHAWH HMONG CIM KES",NULL},
/* 16B33 */ { "DIACRITIQUE PAHAWH HMONG CIM KHAV",NULL},
/* 16B34 */ { "DIACRITIQUE PAHAWH HMONG CIM SUAM",NULL},
/* 16B35 */ { "DIACRITIQUE PAHAWH HMONG CIM HOM",NULL},
/* 16B36 */ { "DIACRITIQUE PAHAWH HMONG CIM TAUM",NULL},
/* 16B37 */ { "SIGNE PAHAWH HMONG VOS THOM","	* équivalent d'un point d'interrogation"},
/* 16B38 */ { "SIGNE PAHAWH HMONG VOS TSHAB CEEB","	* équivalent d'un point d'exclamation"},
/* 16B39 */ { "SIGNE PAHAWH HMONG CIM CHEEM","	* équivalent d'une virgule"},
/* 16B3A */ { "SIGNE PAHAWH HMONG VOS THIAB","	* équivalent d'une perluète\n"
	"	x (perluète - 0026)"},
/* 16B3B */ { "SIGNE PAHAWH HMONG VOS FEEM","	* équivalent du symbole pour cent\n"
	"	x (symbole pour cent - 0025)"},
/* 16B3C */ { "SYMBOLE PAHAWH HMONG XYEEM NTXIV","	* équivalent d'un signe plus"},
/* 16B3D */ { "SYMBOLE PAHAWH HMONG XYEEM RHO","	* équivalent d'un signe moins"},
/* 16B3E */ { "SYMBOLE PAHAWH HMONG XYEEM TOV","	* équivalent d'un signe de multiplication"},
/* 16B3F */ { "SYMBOLE PAHAWH HMONG XYEEM FAIB","	* équivalent d'un signe de division"},
/* 16B40 */ { "SIGNE PAHAWH HMONG VOS SEEV","	* indique une intonation chantante"},
/* 16B41 */ { "SIGNE PAHAWH HMONG MEEJ SUAB","	* indique une prononciation étrangère"},
/* 16B42 */ { "SIGNE PAHAWH HMONG VOS NRUA","	* réduplication"},
/* 16B43 */ { "SIGNE PAHAWH HMONG IB YAM","	* réplication, marque de répétition"},
/* 16B44 */ { "SIGNE PAHAWH HMONG XAUS","	* indique la fin d'une section"},
/* 16B45 */ { "SIGNE PAHAWH HMONG CIM TSOV ROG","	* indique des sujets militaires"},
/* 16B46 */ { NULL,NULL},
/* 16B47 */ { NULL,NULL},
/* 16B48 */ { NULL,NULL},
/* 16B49 */ { NULL,NULL},
/* 16B4A */ { NULL,NULL},
/* 16B4B */ { NULL,NULL},
/* 16B4C */ { NULL,NULL},
/* 16B4D */ { NULL,NULL},
/* 16B4E */ { NULL,NULL},
/* 16B4F */ { NULL,NULL},
/* 16B50 */ { "CHIFFRE PAHAWH HMONG ZÉRO","	* un glyphe circulaire est parfois préféré pour ce caractère"},
/* 16B51 */ { "CHIFFRE PAHAWH HMONG UN",NULL},
/* 16B52 */ { "CHIFFRE PAHAWH HMONG DEUX",NULL},
/* 16B53 */ { "CHIFFRE PAHAWH HMONG TROIS",NULL},
/* 16B54 */ { "CHIFFRE PAHAWH HMONG QUATRE",NULL},
/* 16B55 */ { "CHIFFRE PAHAWH HMONG CINQ",NULL},
/* 16B56 */ { "CHIFFRE PAHAWH HMONG SIX",NULL},
/* 16B57 */ { "CHIFFRE PAHAWH HMONG SEPT",NULL},
/* 16B58 */ { "CHIFFRE PAHAWH HMONG HUIT",NULL},
/* 16B59 */ { "CHIFFRE PAHAWH HMONG NEUF",NULL},
/* 16B5A */ { NULL,NULL},
/* 16B5B */ { "NOMBRE PAHAWH HMONG DIZAINES","	= caum\n"
	"	* un glyphe en forme de barre verticale est parfois préféré pour ce caractère"},
/* 16B5C */ { "NOMBRE PAHAWH HMONG CENTAINES","	= pua"},
/* 16B5D */ { "NOMBRE PAHAWH HMONG DIZAINES DE MILLIERS","	= vam"},
/* 16B5E */ { "NOMBRE PAHAWH HMONG MILLIONS","	= roob"},
/* 16B5F */ { "NOMBRE PAHAWH HMONG CENTAINES DE MILLIONS","	= neev"},
/* 16B60 */ { "NOMBRE PAHAWH HMONG DIZAINES DE MILLIARDS","	= ruav"},
/* 16B61 */ { "NOMBRE PAHAWH HMONG BILLIONS","	= tas"},
/* 16B62 */ { NULL,NULL},
/* 16B63 */ { "SIGNE PAHAWH HMONG VOS LUB","	* un classificateur"},
/* 16B64 */ { "SIGNE PAHAWH HMONG XYOO","	= année"},
/* 16B65 */ { "SIGNE PAHAWH HMONG HLI","	= mois"},
/* 16B66 */ { "SIGNE PAHAWH HMONG TROISIÈME-STADE HLI","	= mois"},
/* 16B67 */ { "SIGNE PAHAWH HMONG ZWJ THAJ","	= date"},
/* 16B68 */ { "SIGNE PAHAWH HMONG HNUB","	= jour"},
/* 16B69 */ { "SIGNE PAHAWH HMONG NQIG","	= lune décroissante"},
/* 16B6A */ { "SIGNE PAHAWH HMONG XIAB","	= lune croissante"},
/* 16B6B */ { "SIGNE PAHAWH HMONG NTUJ","	= saison"},
/* 16B6C */ { "SIGNE PAHAWH HMONG AV","	= la Terre"},
/* 16B6D */ { "SIGNE PAHAWH HMONG TXHEEJ CEEV","	= urgent"},
/* 16B6E */ { "SIGNE PAHAWH HMONG MEEJ TSEEB","	= faits"},
/* 16B6F */ { "SIGNE PAHAWH HMONG TAU","	= reçu"},
/* 16B70 */ { "SIGNE PAHAWH HMONG LOS","	= venir"},
/* 16B71 */ { "SIGNE PAHAWH HMONG MUS","	= aller"},
/* 16B72 */ { "SIGNE PAHAWH HMONG CIM HAIS LUS NTOG NTOG","	= mou"},
/* 16B73 */ { "SIGNE PAHAWH HMONG CIM CUAM TSHOOJ","	= fraction"},
/* 16B74 */ { "SIGNE PAHAWH HMONG CIM TXWV","	= ne pas ouvrir"},
/* 16B75 */ { "SIGNE PAHAWH HMONG CIM TXWV CHWV","	= ne pas toucher"},
/* 16B76 */ { "SIGNE PAHAWH HMONG CIM PUB DAWB","	= donner librement"},
/* 16B77 */ { "SIGNE PAHAWH HMONG CIM NRES TOS","	= arrêter"},
/* 16B78 */ { NULL,NULL},
/* 16B79 */ { NULL,NULL},
/* 16B7A */ { NULL,NULL},
/* 16B7B */ { NULL,NULL},
/* 16B7C */ { NULL,NULL},
/* 16B7D */ { "SIGNE DE CLAN PAHAWH HMONG TSHEEJ","	= Cheng"},
/* 16B7E */ { "SIGNE DE CLAN PAHAWH HMONG YEEG","	= Yeng"},
/* 16B7F */ { "SIGNE DE CLAN PAHAWH HMONG LIS","	= Lee"},
/* 16B80 */ { "SIGNE DE CLAN PAHAWH HMONG LAUJ","	= Lor"},
/* 16B81 */ { "SIGNE DE CLAN PAHAWH HMONG XYOOJ","	= Xiong"},
/* 16B82 */ { "SIGNE DE CLAN PAHAWH HMONG KOO","	= Kong"},
/* 16B83 */ { "SIGNE DE CLAN PAHAWH HMONG HAWJ","	= Her"},
/* 16B84 */ { "SIGNE DE CLAN PAHAWH HMONG MUAS","	= Moua"},
/* 16B85 */ { "SIGNE DE CLAN PAHAWH HMONG THOJ","	= Thao"},
/* 16B86 */ { "SIGNE DE CLAN PAHAWH HMONG TSAB","	= Chang"},
/* 16B87 */ { "SIGNE DE CLAN PAHAWH HMONG PHAB","	= Pha"},
/* 16B88 */ { "SIGNE DE CLAN PAHAWH HMONG KHAB","	= Khang"},
/* 16B89 */ { "SIGNE DE CLAN PAHAWH HMONG HAM","	= Hang"},
/* 16B8A */ { "SIGNE DE CLAN PAHAWH HMONG VAJ","	= Vang"},
/* 16B8B */ { "SIGNE DE CLAN PAHAWH HMONG FAJ","	= Fang"},
/* 16B8C */ { "SIGNE DE CLAN PAHAWH HMONG YAJ","	= Yang"},
/* 16B8D */ { "SIGNE DE CLAN PAHAWH HMONG TSWB","	= Chue"},
/* 16B8E */ { "SIGNE DE CLAN PAHAWH HMONG KWM","	= Kw"},
/* 16B8F */ { "SIGNE DE CLAN PAHAWH HMONG VWJ","	= Vue"},
/* 16B90 */ { NULL,NULL},
/* 16B91 */ { NULL,NULL},
/* 16B92 */ { NULL,NULL},
/* 16B93 */ { NULL,NULL},
/* 16B94 */ { NULL,NULL},
/* 16B95 */ { NULL,NULL},
/* 16B96 */ { NULL,NULL},
/* 16B97 */ { NULL,NULL},
/* 16B98 */ { NULL,NULL},
/* 16B99 */ { NULL,NULL},
/* 16B9A */ { NULL,NULL},
/* 16B9B */ { NULL,NULL},
/* 16B9C */ { NULL,NULL},
/* 16B9D */ { NULL,NULL},
/* 16B9E */ { NULL,NULL},
/* 16B9F */ { NULL,NULL},
/* 16BA0 */ { NULL,NULL},
/* 16BA1 */ { NULL,NULL},
/* 16BA2 */ { NULL,NULL},
/* 16BA3 */ { NULL,NULL},
/* 16BA4 */ { NULL,NULL},
/* 16BA5 */ { NULL,NULL},
/* 16BA6 */ { NULL,NULL},
/* 16BA7 */ { NULL,NULL},
/* 16BA8 */ { NULL,NULL},
/* 16BA9 */ { NULL,NULL},
/* 16BAA */ { NULL,NULL},
/* 16BAB */ { NULL,NULL},
/* 16BAC */ { NULL,NULL},
/* 16BAD */ { NULL,NULL},
/* 16BAE */ { NULL,NULL},
/* 16BAF */ { NULL,NULL},
/* 16BB0 */ { NULL,NULL},
/* 16BB1 */ { NULL,NULL},
/* 16BB2 */ { NULL,NULL},
/* 16BB3 */ { NULL,NULL},
/* 16BB4 */ { NULL,NULL},
/* 16BB5 */ { NULL,NULL},
/* 16BB6 */ { NULL,NULL},
/* 16BB7 */ { NULL,NULL},
/* 16BB8 */ { NULL,NULL},
/* 16BB9 */ { NULL,NULL},
/* 16BBA */ { NULL,NULL},
/* 16BBB */ { NULL,NULL},
/* 16BBC */ { NULL,NULL},
/* 16BBD */ { NULL,NULL},
/* 16BBE */ { NULL,NULL},
/* 16BBF */ { NULL,NULL},
/* 16BC0 */ { NULL,NULL},
/* 16BC1 */ { NULL,NULL},
/* 16BC2 */ { NULL,NULL},
/* 16BC3 */ { NULL,NULL},
/* 16BC4 */ { NULL,NULL},
/* 16BC5 */ { NULL,NULL},
/* 16BC6 */ { NULL,NULL},
/* 16BC7 */ { NULL,NULL},
/* 16BC8 */ { NULL,NULL},
/* 16BC9 */ { NULL,NULL},
/* 16BCA */ { NULL,NULL},
/* 16BCB */ { NULL,NULL},
/* 16BCC */ { NULL,NULL},
/* 16BCD */ { NULL,NULL},
/* 16BCE */ { NULL,NULL},
/* 16BCF */ { NULL,NULL},
/* 16BD0 */ { NULL,NULL},
/* 16BD1 */ { NULL,NULL},
/* 16BD2 */ { NULL,NULL},
/* 16BD3 */ { NULL,NULL},
/* 16BD4 */ { NULL,NULL},
/* 16BD5 */ { NULL,NULL},
/* 16BD6 */ { NULL,NULL},
/* 16BD7 */ { NULL,NULL},
/* 16BD8 */ { NULL,NULL},
/* 16BD9 */ { NULL,NULL},
/* 16BDA */ { NULL,NULL},
/* 16BDB */ { NULL,NULL},
/* 16BDC */ { NULL,NULL},
/* 16BDD */ { NULL,NULL},
/* 16BDE */ { NULL,NULL},
/* 16BDF */ { NULL,NULL},
/* 16BE0 */ { NULL,NULL},
/* 16BE1 */ { NULL,NULL},
/* 16BE2 */ { NULL,NULL},
/* 16BE3 */ { NULL,NULL},
/* 16BE4 */ { NULL,NULL},
/* 16BE5 */ { NULL,NULL},
/* 16BE6 */ { NULL,NULL},
/* 16BE7 */ { NULL,NULL},
/* 16BE8 */ { NULL,NULL},
/* 16BE9 */ { NULL,NULL},
/* 16BEA */ { NULL,NULL},
/* 16BEB */ { NULL,NULL},
/* 16BEC */ { NULL,NULL},
/* 16BED */ { NULL,NULL},
/* 16BEE */ { NULL,NULL},
/* 16BEF */ { NULL,NULL},
/* 16BF0 */ { NULL,NULL},
/* 16BF1 */ { NULL,NULL},
/* 16BF2 */ { NULL,NULL},
/* 16BF3 */ { NULL,NULL},
/* 16BF4 */ { NULL,NULL},
/* 16BF5 */ { NULL,NULL},
/* 16BF6 */ { NULL,NULL},
/* 16BF7 */ { NULL,NULL},
/* 16BF8 */ { NULL,NULL},
/* 16BF9 */ { NULL,NULL},
/* 16BFA */ { NULL,NULL},
/* 16BFB */ { NULL,NULL},
/* 16BFC */ { NULL,NULL},
/* 16BFD */ { NULL,NULL},
/* 16BFE */ { NULL,NULL},
/* 16BFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_6D[] = {
/* 16D00 */ { NULL,NULL},
/* 16D01 */ { NULL,NULL},
/* 16D02 */ { NULL,NULL},
/* 16D03 */ { NULL,NULL},
/* 16D04 */ { NULL,NULL},
/* 16D05 */ { NULL,NULL},
/* 16D06 */ { NULL,NULL},
/* 16D07 */ { NULL,NULL},
/* 16D08 */ { NULL,NULL},
/* 16D09 */ { NULL,NULL},
/* 16D0A */ { NULL,NULL},
/* 16D0B */ { NULL,NULL},
/* 16D0C */ { NULL,NULL},
/* 16D0D */ { NULL,NULL},
/* 16D0E */ { NULL,NULL},
/* 16D0F */ { NULL,NULL},
/* 16D10 */ { NULL,NULL},
/* 16D11 */ { NULL,NULL},
/* 16D12 */ { NULL,NULL},
/* 16D13 */ { NULL,NULL},
/* 16D14 */ { NULL,NULL},
/* 16D15 */ { NULL,NULL},
/* 16D16 */ { NULL,NULL},
/* 16D17 */ { NULL,NULL},
/* 16D18 */ { NULL,NULL},
/* 16D19 */ { NULL,NULL},
/* 16D1A */ { NULL,NULL},
/* 16D1B */ { NULL,NULL},
/* 16D1C */ { NULL,NULL},
/* 16D1D */ { NULL,NULL},
/* 16D1E */ { NULL,NULL},
/* 16D1F */ { NULL,NULL},
/* 16D20 */ { NULL,NULL},
/* 16D21 */ { NULL,NULL},
/* 16D22 */ { NULL,NULL},
/* 16D23 */ { NULL,NULL},
/* 16D24 */ { NULL,NULL},
/* 16D25 */ { NULL,NULL},
/* 16D26 */ { NULL,NULL},
/* 16D27 */ { NULL,NULL},
/* 16D28 */ { NULL,NULL},
/* 16D29 */ { NULL,NULL},
/* 16D2A */ { NULL,NULL},
/* 16D2B */ { NULL,NULL},
/* 16D2C */ { NULL,NULL},
/* 16D2D */ { NULL,NULL},
/* 16D2E */ { NULL,NULL},
/* 16D2F */ { NULL,NULL},
/* 16D30 */ { NULL,NULL},
/* 16D31 */ { NULL,NULL},
/* 16D32 */ { NULL,NULL},
/* 16D33 */ { NULL,NULL},
/* 16D34 */ { NULL,NULL},
/* 16D35 */ { NULL,NULL},
/* 16D36 */ { NULL,NULL},
/* 16D37 */ { NULL,NULL},
/* 16D38 */ { NULL,NULL},
/* 16D39 */ { NULL,NULL},
/* 16D3A */ { NULL,NULL},
/* 16D3B */ { NULL,NULL},
/* 16D3C */ { NULL,NULL},
/* 16D3D */ { NULL,NULL},
/* 16D3E */ { NULL,NULL},
/* 16D3F */ { NULL,NULL},
/* 16D40 */ { "DIACRITIQUE KIRAT RAI ANOUSVÂRA",NULL},
/* 16D41 */ { "DIACRITIQUE KIRAT RAI TONPI",NULL},
/* 16D42 */ { "DIACRITIQUE KIRAT RAI VISARGA",NULL},
/* 16D43 */ { "LETTRE KIRAT RAI A",NULL},
/* 16D44 */ { "LETTRE KIRAT RAI KA",NULL},
/* 16D45 */ { "LETTRE KIRAT RAI KHA",NULL},
/* 16D46 */ { "LETTRE KIRAT RAI GA",NULL},
/* 16D47 */ { "LETTRE KIRAT RAI GHA",NULL},
/* 16D48 */ { "LETTRE KIRAT RAI NGA",NULL},
/* 16D49 */ { "LETTRE KIRAT RAI TCHA",NULL},
/* 16D4A */ { "LETTRE KIRAT RAI TCHHA",NULL},
/* 16D4B */ { "LETTRE KIRAT RAI DJA",NULL},
/* 16D4C */ { "LETTRE KIRAT RAI DJHA",NULL},
/* 16D4D */ { "LETTRE KIRAT RAI ÑA",NULL},
/* 16D4E */ { "LETTRE KIRAT RAI TTA",NULL},
/* 16D4F */ { "LETTRE KIRAT RAI TTHA",NULL},
/* 16D50 */ { "LETTRE KIRAT RAI DDA",NULL},
/* 16D51 */ { "LETTRE KIRAT RAI DDHA",NULL},
/* 16D52 */ { "LETTRE KIRAT RAI TA",NULL},
/* 16D53 */ { "LETTRE KIRAT RAI THA",NULL},
/* 16D54 */ { "LETTRE KIRAT RAI DA",NULL},
/* 16D55 */ { "LETTRE KIRAT RAI DHA",NULL},
/* 16D56 */ { "LETTRE KIRAT RAI NA",NULL},
/* 16D57 */ { "LETTRE KIRAT RAI PA",NULL},
/* 16D58 */ { "LETTRE KIRAT RAI PHA","	= lettre kirat rai p'a"},
/* 16D59 */ { "LETTRE KIRAT RAI BA",NULL},
/* 16D5A */ { "LETTRE KIRAT RAI BHA",NULL},
/* 16D5B */ { "LETTRE KIRAT RAI MA",NULL},
/* 16D5C */ { "LETTRE KIRAT RAI YA",NULL},
/* 16D5D */ { "LETTRE KIRAT RAI RA",NULL},
/* 16D5E */ { "LETTRE KIRAT RAI LA",NULL},
/* 16D5F */ { "LETTRE KIRAT RAI VA",NULL},
/* 16D60 */ { "LETTRE KIRAT RAI SA",NULL},
/* 16D61 */ { "LETTRE KIRAT RAI ÇA",NULL},
/* 16D62 */ { "LETTRE KIRAT RAI HA",NULL},
/* 16D63 */ { "DIACRITIQUE VOYELLE KIRAT RAI Â",NULL},
/* 16D64 */ { "DIACRITIQUE VOYELLE KIRAT RAI I",NULL},
/* 16D65 */ { "DIACRITIQUE VOYELLE KIRAT RAI OU",NULL},
/* 16D66 */ { "DIACRITIQUE VOYELLE KIRAT RAI U",NULL},
/* 16D67 */ { "DIACRITIQUE VOYELLE KIRAT RAI É",NULL},
/* 16D68 */ { "DIACRITIQUE VOYELLE KIRAT RAI AI","	: 16D67 16D67"},
/* 16D69 */ { "DIACRITIQUE VOYELLE KIRAT RAI O","	: 16D63 16D67"},
/* 16D6A */ { "DIACRITIQUE VOYELLE KIRAT RAI AOU","	: 16D69 16D67"},
/* 16D6B */ { "DIACRITIQUE KIRAT RAI VIRÂMA",NULL},
/* 16D6C */ { "DIACRITIQUE KIRAT RAI SÂT",NULL},
/* 16D6D */ { "DIACRITIQUE KIRAT RAI YOUPI",NULL},
/* 16D6E */ { "DANDA KIRAT RAI",NULL},
/* 16D6F */ { "DOUBLE DANDA KIRAT RAI",NULL},
/* 16D70 */ { "CHIFFRE KIRAT RAI ZÉRO",NULL},
/* 16D71 */ { "CHIFFRE KIRAT RAI UN",NULL},
/* 16D72 */ { "CHIFFRE KIRAT RAI DEUX",NULL},
/* 16D73 */ { "CHIFFRE KIRAT RAI TROIS",NULL},
/* 16D74 */ { "CHIFFRE KIRAT RAI QUATRE",NULL},
/* 16D75 */ { "CHIFFRE KIRAT RAI CINQ",NULL},
/* 16D76 */ { "CHIFFRE KIRAT RAI SIX",NULL},
/* 16D77 */ { "CHIFFRE KIRAT RAI SEPT",NULL},
/* 16D78 */ { "CHIFFRE KIRAT RAI HUIT",NULL},
/* 16D79 */ { "CHIFFRE KIRAT RAI NEUF",NULL},
/* 16D7A */ { NULL,NULL},
/* 16D7B */ { NULL,NULL},
/* 16D7C */ { NULL,NULL},
/* 16D7D */ { NULL,NULL},
/* 16D7E */ { NULL,NULL},
/* 16D7F */ { NULL,NULL},
/* 16D80 */ { NULL,NULL},
/* 16D81 */ { NULL,NULL},
/* 16D82 */ { NULL,NULL},
/* 16D83 */ { NULL,NULL},
/* 16D84 */ { NULL,NULL},
/* 16D85 */ { NULL,NULL},
/* 16D86 */ { NULL,NULL},
/* 16D87 */ { NULL,NULL},
/* 16D88 */ { NULL,NULL},
/* 16D89 */ { NULL,NULL},
/* 16D8A */ { NULL,NULL},
/* 16D8B */ { NULL,NULL},
/* 16D8C */ { NULL,NULL},
/* 16D8D */ { NULL,NULL},
/* 16D8E */ { NULL,NULL},
/* 16D8F */ { NULL,NULL},
/* 16D90 */ { NULL,NULL},
/* 16D91 */ { NULL,NULL},
/* 16D92 */ { NULL,NULL},
/* 16D93 */ { NULL,NULL},
/* 16D94 */ { NULL,NULL},
/* 16D95 */ { NULL,NULL},
/* 16D96 */ { NULL,NULL},
/* 16D97 */ { NULL,NULL},
/* 16D98 */ { NULL,NULL},
/* 16D99 */ { NULL,NULL},
/* 16D9A */ { NULL,NULL},
/* 16D9B */ { NULL,NULL},
/* 16D9C */ { NULL,NULL},
/* 16D9D */ { NULL,NULL},
/* 16D9E */ { NULL,NULL},
/* 16D9F */ { NULL,NULL},
/* 16DA0 */ { NULL,NULL},
/* 16DA1 */ { NULL,NULL},
/* 16DA2 */ { NULL,NULL},
/* 16DA3 */ { NULL,NULL},
/* 16DA4 */ { NULL,NULL},
/* 16DA5 */ { NULL,NULL},
/* 16DA6 */ { NULL,NULL},
/* 16DA7 */ { NULL,NULL},
/* 16DA8 */ { NULL,NULL},
/* 16DA9 */ { NULL,NULL},
/* 16DAA */ { NULL,NULL},
/* 16DAB */ { NULL,NULL},
/* 16DAC */ { NULL,NULL},
/* 16DAD */ { NULL,NULL},
/* 16DAE */ { NULL,NULL},
/* 16DAF */ { NULL,NULL},
/* 16DB0 */ { NULL,NULL},
/* 16DB1 */ { NULL,NULL},
/* 16DB2 */ { NULL,NULL},
/* 16DB3 */ { NULL,NULL},
/* 16DB4 */ { NULL,NULL},
/* 16DB5 */ { NULL,NULL},
/* 16DB6 */ { NULL,NULL},
/* 16DB7 */ { NULL,NULL},
/* 16DB8 */ { NULL,NULL},
/* 16DB9 */ { NULL,NULL},
/* 16DBA */ { NULL,NULL},
/* 16DBB */ { NULL,NULL},
/* 16DBC */ { NULL,NULL},
/* 16DBD */ { NULL,NULL},
/* 16DBE */ { NULL,NULL},
/* 16DBF */ { NULL,NULL},
/* 16DC0 */ { NULL,NULL},
/* 16DC1 */ { NULL,NULL},
/* 16DC2 */ { NULL,NULL},
/* 16DC3 */ { NULL,NULL},
/* 16DC4 */ { NULL,NULL},
/* 16DC5 */ { NULL,NULL},
/* 16DC6 */ { NULL,NULL},
/* 16DC7 */ { NULL,NULL},
/* 16DC8 */ { NULL,NULL},
/* 16DC9 */ { NULL,NULL},
/* 16DCA */ { NULL,NULL},
/* 16DCB */ { NULL,NULL},
/* 16DCC */ { NULL,NULL},
/* 16DCD */ { NULL,NULL},
/* 16DCE */ { NULL,NULL},
/* 16DCF */ { NULL,NULL},
/* 16DD0 */ { NULL,NULL},
/* 16DD1 */ { NULL,NULL},
/* 16DD2 */ { NULL,NULL},
/* 16DD3 */ { NULL,NULL},
/* 16DD4 */ { NULL,NULL},
/* 16DD5 */ { NULL,NULL},
/* 16DD6 */ { NULL,NULL},
/* 16DD7 */ { NULL,NULL},
/* 16DD8 */ { NULL,NULL},
/* 16DD9 */ { NULL,NULL},
/* 16DDA */ { NULL,NULL},
/* 16DDB */ { NULL,NULL},
/* 16DDC */ { NULL,NULL},
/* 16DDD */ { NULL,NULL},
/* 16DDE */ { NULL,NULL},
/* 16DDF */ { NULL,NULL},
/* 16DE0 */ { NULL,NULL},
/* 16DE1 */ { NULL,NULL},
/* 16DE2 */ { NULL,NULL},
/* 16DE3 */ { NULL,NULL},
/* 16DE4 */ { NULL,NULL},
/* 16DE5 */ { NULL,NULL},
/* 16DE6 */ { NULL,NULL},
/* 16DE7 */ { NULL,NULL},
/* 16DE8 */ { NULL,NULL},
/* 16DE9 */ { NULL,NULL},
/* 16DEA */ { NULL,NULL},
/* 16DEB */ { NULL,NULL},
/* 16DEC */ { NULL,NULL},
/* 16DED */ { NULL,NULL},
/* 16DEE */ { NULL,NULL},
/* 16DEF */ { NULL,NULL},
/* 16DF0 */ { NULL,NULL},
/* 16DF1 */ { NULL,NULL},
/* 16DF2 */ { NULL,NULL},
/* 16DF3 */ { NULL,NULL},
/* 16DF4 */ { NULL,NULL},
/* 16DF5 */ { NULL,NULL},
/* 16DF6 */ { NULL,NULL},
/* 16DF7 */ { NULL,NULL},
/* 16DF8 */ { NULL,NULL},
/* 16DF9 */ { NULL,NULL},
/* 16DFA */ { NULL,NULL},
/* 16DFB */ { NULL,NULL},
/* 16DFC */ { NULL,NULL},
/* 16DFD */ { NULL,NULL},
/* 16DFE */ { NULL,NULL},
/* 16DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_6E[] = {
/* 16E00 */ { NULL,NULL},
/* 16E01 */ { NULL,NULL},
/* 16E02 */ { NULL,NULL},
/* 16E03 */ { NULL,NULL},
/* 16E04 */ { NULL,NULL},
/* 16E05 */ { NULL,NULL},
/* 16E06 */ { NULL,NULL},
/* 16E07 */ { NULL,NULL},
/* 16E08 */ { NULL,NULL},
/* 16E09 */ { NULL,NULL},
/* 16E0A */ { NULL,NULL},
/* 16E0B */ { NULL,NULL},
/* 16E0C */ { NULL,NULL},
/* 16E0D */ { NULL,NULL},
/* 16E0E */ { NULL,NULL},
/* 16E0F */ { NULL,NULL},
/* 16E10 */ { NULL,NULL},
/* 16E11 */ { NULL,NULL},
/* 16E12 */ { NULL,NULL},
/* 16E13 */ { NULL,NULL},
/* 16E14 */ { NULL,NULL},
/* 16E15 */ { NULL,NULL},
/* 16E16 */ { NULL,NULL},
/* 16E17 */ { NULL,NULL},
/* 16E18 */ { NULL,NULL},
/* 16E19 */ { NULL,NULL},
/* 16E1A */ { NULL,NULL},
/* 16E1B */ { NULL,NULL},
/* 16E1C */ { NULL,NULL},
/* 16E1D */ { NULL,NULL},
/* 16E1E */ { NULL,NULL},
/* 16E1F */ { NULL,NULL},
/* 16E20 */ { NULL,NULL},
/* 16E21 */ { NULL,NULL},
/* 16E22 */ { NULL,NULL},
/* 16E23 */ { NULL,NULL},
/* 16E24 */ { NULL,NULL},
/* 16E25 */ { NULL,NULL},
/* 16E26 */ { NULL,NULL},
/* 16E27 */ { NULL,NULL},
/* 16E28 */ { NULL,NULL},
/* 16E29 */ { NULL,NULL},
/* 16E2A */ { NULL,NULL},
/* 16E2B */ { NULL,NULL},
/* 16E2C */ { NULL,NULL},
/* 16E2D */ { NULL,NULL},
/* 16E2E */ { NULL,NULL},
/* 16E2F */ { NULL,NULL},
/* 16E30 */ { NULL,NULL},
/* 16E31 */ { NULL,NULL},
/* 16E32 */ { NULL,NULL},
/* 16E33 */ { NULL,NULL},
/* 16E34 */ { NULL,NULL},
/* 16E35 */ { NULL,NULL},
/* 16E36 */ { NULL,NULL},
/* 16E37 */ { NULL,NULL},
/* 16E38 */ { NULL,NULL},
/* 16E39 */ { NULL,NULL},
/* 16E3A */ { NULL,NULL},
/* 16E3B */ { NULL,NULL},
/* 16E3C */ { NULL,NULL},
/* 16E3D */ { NULL,NULL},
/* 16E3E */ { NULL,NULL},
/* 16E3F */ { NULL,NULL},
/* 16E40 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE M",NULL},
/* 16E41 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE S",NULL},
/* 16E42 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE V",NULL},
/* 16E43 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE W",NULL},
/* 16E44 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE ATIOU",NULL},
/* 16E45 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE Z",NULL},
/* 16E46 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE KP",NULL},
/* 16E47 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE P",NULL},
/* 16E48 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE T",NULL},
/* 16E49 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE G",NULL},
/* 16E4A */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE F",NULL},
/* 16E4B */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE I",NULL},
/* 16E4C */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE K",NULL},
/* 16E4D */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE A",NULL},
/* 16E4E */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE J",NULL},
/* 16E4F */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE É",NULL},
/* 16E50 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE B",NULL},
/* 16E51 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE C",NULL},
/* 16E52 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE OU",NULL},
/* 16E53 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE YOU",NULL},
/* 16E54 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE L",NULL},
/* 16E55 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE Q",NULL},
/* 16E56 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE H","	* le nom formel de ce caractère en anglais est erroné"},
/* 16E57 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE NG","	* le nom formel de ce caractère en anglais est erroné"},
/* 16E58 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE X",NULL},
/* 16E59 */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE D",NULL},
/* 16E5A */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE E","	* représente la voyelle o ouvert"},
/* 16E5B */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE N",NULL},
/* 16E5C */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE R",NULL},
/* 16E5D */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE O",NULL},
/* 16E5E */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE AÏ",NULL},
/* 16E5F */ { "LETTRE MAJUSCULE MÉDÉFAÏDRINE Y",NULL},
/* 16E60 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE M",NULL},
/* 16E61 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE S",NULL},
/* 16E62 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE V",NULL},
/* 16E63 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE W",NULL},
/* 16E64 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE ATIOU",NULL},
/* 16E65 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE Z",NULL},
/* 16E66 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE KP",NULL},
/* 16E67 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE P",NULL},
/* 16E68 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE T",NULL},
/* 16E69 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE G",NULL},
/* 16E6A */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE F",NULL},
/* 16E6B */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE I",NULL},
/* 16E6C */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE K",NULL},
/* 16E6D */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE A",NULL},
/* 16E6E */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE J",NULL},
/* 16E6F */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE É",NULL},
/* 16E70 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE B",NULL},
/* 16E71 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE C",NULL},
/* 16E72 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE OU",NULL},
/* 16E73 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE YOU",NULL},
/* 16E74 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE L",NULL},
/* 16E75 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE Q",NULL},
/* 16E76 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE H","	* le nom formel de ce caractère en anglais est erroné"},
/* 16E77 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE NG","	* le nom formel de ce caractère en anglais est erroné"},
/* 16E78 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE X",NULL},
/* 16E79 */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE D",NULL},
/* 16E7A */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE E","	* représente la voyelle o ouvert"},
/* 16E7B */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE N",NULL},
/* 16E7C */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE R",NULL},
/* 16E7D */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE O",NULL},
/* 16E7E */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE AÏ",NULL},
/* 16E7F */ { "LETTRE MINUSCULE MÉDÉFAÏDRINE Y",NULL},
/* 16E80 */ { "CHIFFRE MÉDÉFAÏDRINE ZÉRO",NULL},
/* 16E81 */ { "CHIFFRE MÉDÉFAÏDRINE UN",NULL},
/* 16E82 */ { "CHIFFRE MÉDÉFAÏDRINE DEUX",NULL},
/* 16E83 */ { "CHIFFRE MÉDÉFAÏDRINE TROIS",NULL},
/* 16E84 */ { "CHIFFRE MÉDÉFAÏDRINE QUATRE",NULL},
/* 16E85 */ { "CHIFFRE MÉDÉFAÏDRINE CINQ",NULL},
/* 16E86 */ { "CHIFFRE MÉDÉFAÏDRINE SIX",NULL},
/* 16E87 */ { "CHIFFRE MÉDÉFAÏDRINE SEPT",NULL},
/* 16E88 */ { "CHIFFRE MÉDÉFAÏDRINE HUIT",NULL},
/* 16E89 */ { "CHIFFRE MÉDÉFAÏDRINE NEUF",NULL},
/* 16E8A */ { "NOMBRE MÉDÉFAÏDRINE DIX",NULL},
/* 16E8B */ { "NOMBRE MÉDÉFAÏDRINE ONZE",NULL},
/* 16E8C */ { "NOMBRE MÉDÉFAÏDRINE DOUZE",NULL},
/* 16E8D */ { "NOMBRE MÉDÉFAÏDRINE TREIZE",NULL},
/* 16E8E */ { "NOMBRE MÉDÉFAÏDRINE QUATORZE",NULL},
/* 16E8F */ { "NOMBRE MÉDÉFAÏDRINE QUINZE",NULL},
/* 16E90 */ { "NOMBRE MÉDÉFAÏDRINE SEIZE",NULL},
/* 16E91 */ { "NOMBRE MÉDÉFAÏDRINE DIX-SEPT",NULL},
/* 16E92 */ { "NOMBRE MÉDÉFAÏDRINE DIX-HUIT",NULL},
/* 16E93 */ { "NOMBRE MÉDÉFAÏDRINE DIX-NEUF",NULL},
/* 16E94 */ { "CHIFFRE MÉDÉFAÏDRINE VARIANTE DE UN",NULL},
/* 16E95 */ { "CHIFFRE MÉDÉFAÏDRINE VARIANTE DE DEUX",NULL},
/* 16E96 */ { "CHIFFRE MÉDÉFAÏDRINE VARIANTE DE TROIS",NULL},
/* 16E97 */ { "VIRGULE MÉDÉFAÏDRINE",NULL},
/* 16E98 */ { "POINT MÉDÉFAÏDRINE",NULL},
/* 16E99 */ { "SYMBOLE MÉDÉFAÏDRINE AÏVA","	* ou"},
/* 16E9A */ { "EXCLAMATION MÉDÉFAÏDRINE OH",NULL},
/* 16E9B */ { NULL,NULL},
/* 16E9C */ { NULL,NULL},
/* 16E9D */ { NULL,NULL},
/* 16E9E */ { NULL,NULL},
/* 16E9F */ { NULL,NULL},
/* 16EA0 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ ARKAB",NULL},
/* 16EA1 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ BASIGNA",NULL},
/* 16EA2 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ DARBAI",NULL},
/* 16EA3 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ EH",NULL},
/* 16EA4 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ FITKO",NULL},
/* 16EA5 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ GOWAY",NULL},
/* 16EA6 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ HIRDEABO",NULL},
/* 16EA7 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ I",NULL},
/* 16EA8 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ DJAI",NULL},
/* 16EA9 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ KOBO",NULL},
/* 16EAA */ { "LETTRE MAJUSCULE BÉRIA ERFÉ LAKKO",NULL},
/* 16EAB */ { "LETTRE MAJUSCULE BÉRIA ERFÉ MERI",NULL},
/* 16EAC */ { "LETTRE MAJUSCULE BÉRIA ERFÉ NINI",NULL},
/* 16EAD */ { "LETTRE MAJUSCULE BÉRIA ERFÉ GNA",NULL},
/* 16EAE */ { "LETTRE MAJUSCULE BÉRIA ERFÉ NGAY",NULL},
/* 16EAF */ { "LETTRE MAJUSCULE BÉRIA ERFÉ OI",NULL},
/* 16EB0 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ PI",NULL},
/* 16EB1 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ ERIGO",NULL},
/* 16EB2 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ ERIGO TAMURA",NULL},
/* 16EB3 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ SERI",NULL},
/* 16EB4 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ SHEP",NULL},
/* 16EB5 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ TATASOUE",NULL},
/* 16EB6 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ UI",NULL},
/* 16EB7 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ WASSE",NULL},
/* 16EB8 */ { "LETTRE MAJUSCULE BÉRIA ERFÉ AY",NULL},
/* 16EB9 */ { NULL,NULL},
/* 16EBA */ { NULL,NULL},
/* 16EBB */ { "LETTRE MINUSCULE BÉRIA ERFÉ ARKAB",NULL},
/* 16EBC */ { "LETTRE MINUSCULE BÉRIA ERFÉ BASIGNA",NULL},
/* 16EBD */ { "LETTRE MINUSCULE BÉRIA ERFÉ DARBAI",NULL},
/* 16EBE */ { "LETTRE MINUSCULE BÉRIA ERFÉ EH",NULL},
/* 16EBF */ { "LETTRE MINUSCULE BÉRIA ERFÉ FITKO",NULL},
/* 16EC0 */ { "LETTRE MINUSCULE BÉRIA ERFÉ GOWAY",NULL},
/* 16EC1 */ { "LETTRE MINUSCULE BÉRIA ERFÉ HIRDEABO",NULL},
/* 16EC2 */ { "LETTRE MINUSCULE BÉRIA ERFÉ I",NULL},
/* 16EC3 */ { "LETTRE MINUSCULE BÉRIA ERFÉ DJAI",NULL},
/* 16EC4 */ { "LETTRE MINUSCULE BÉRIA ERFÉ KOBO",NULL},
/* 16EC5 */ { "LETTRE MINUSCULE BÉRIA ERFÉ LAKKO",NULL},
/* 16EC6 */ { "LETTRE MINUSCULE BÉRIA ERFÉ MERI",NULL},
/* 16EC7 */ { "LETTRE MINUSCULE BÉRIA ERFÉ NINI",NULL},
/* 16EC8 */ { "LETTRE MINUSCULE BÉRIA ERFÉ GNA",NULL},
/* 16EC9 */ { "LETTRE MINUSCULE BÉRIA ERFÉ NGAY",NULL},
/* 16ECA */ { "LETTRE MINUSCULE BÉRIA ERFÉ OI",NULL},
/* 16ECB */ { "LETTRE MINUSCULE BÉRIA ERFÉ PI",NULL},
/* 16ECC */ { "LETTRE MINUSCULE BÉRIA ERFÉ ERIGO",NULL},
/* 16ECD */ { "LETTRE MINUSCULE BÉRIA ERFÉ ERIGO TAMURA",NULL},
/* 16ECE */ { "LETTRE MINUSCULE BÉRIA ERFÉ SERI",NULL},
/* 16ECF */ { "LETTRE MINUSCULE BÉRIA ERFÉ SHEP",NULL},
/* 16ED0 */ { "LETTRE MINUSCULE BÉRIA ERFÉ TATASOUE",NULL},
/* 16ED1 */ { "LETTRE MINUSCULE BÉRIA ERFÉ UI",NULL},
/* 16ED2 */ { "LETTRE MINUSCULE BÉRIA ERFÉ WASSE",NULL},
/* 16ED3 */ { "LETTRE MINUSCULE BÉRIA ERFÉ AY",NULL},
/* 16ED4 */ { NULL,NULL},
/* 16ED5 */ { NULL,NULL},
/* 16ED6 */ { NULL,NULL},
/* 16ED7 */ { NULL,NULL},
/* 16ED8 */ { NULL,NULL},
/* 16ED9 */ { NULL,NULL},
/* 16EDA */ { NULL,NULL},
/* 16EDB */ { NULL,NULL},
/* 16EDC */ { NULL,NULL},
/* 16EDD */ { NULL,NULL},
/* 16EDE */ { NULL,NULL},
/* 16EDF */ { NULL,NULL},
/* 16EE0 */ { NULL,NULL},
/* 16EE1 */ { NULL,NULL},
/* 16EE2 */ { NULL,NULL},
/* 16EE3 */ { NULL,NULL},
/* 16EE4 */ { NULL,NULL},
/* 16EE5 */ { NULL,NULL},
/* 16EE6 */ { NULL,NULL},
/* 16EE7 */ { NULL,NULL},
/* 16EE8 */ { NULL,NULL},
/* 16EE9 */ { NULL,NULL},
/* 16EEA */ { NULL,NULL},
/* 16EEB */ { NULL,NULL},
/* 16EEC */ { NULL,NULL},
/* 16EED */ { NULL,NULL},
/* 16EEE */ { NULL,NULL},
/* 16EEF */ { NULL,NULL},
/* 16EF0 */ { NULL,NULL},
/* 16EF1 */ { NULL,NULL},
/* 16EF2 */ { NULL,NULL},
/* 16EF3 */ { NULL,NULL},
/* 16EF4 */ { NULL,NULL},
/* 16EF5 */ { NULL,NULL},
/* 16EF6 */ { NULL,NULL},
/* 16EF7 */ { NULL,NULL},
/* 16EF8 */ { NULL,NULL},
/* 16EF9 */ { NULL,NULL},
/* 16EFA */ { NULL,NULL},
/* 16EFB */ { NULL,NULL},
/* 16EFC */ { NULL,NULL},
/* 16EFD */ { NULL,NULL},
/* 16EFE */ { NULL,NULL},
/* 16EFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_6F[] = {
/* 16F00 */ { "LETTRE MIAO PA","	* utilisée pour « ba » en gan yi"},
/* 16F01 */ { "LETTRE MIAO BA",NULL},
/* 16F02 */ { "LETTRE MIAO YI PA","	* utilisée pour « pa » en gan yi"},
/* 16F03 */ { "LETTRE MIAO PLA","	* utilisée en hmong du Sichuan"},
/* 16F04 */ { "LETTRE MIAO MA",NULL},
/* 16F05 */ { "LETTRE MIAO MHA",NULL},
/* 16F06 */ { "LETTRE MIAO MA ARCHAÏQUE","	* utilisée dans l'orthographe primitive de Pollard"},
/* 16F07 */ { "LETTRE MIAO FA",NULL},
/* 16F08 */ { "LETTRE MIAO VA",NULL},
/* 16F09 */ { "LETTRE MIAO VFA","	* utilisée en hei yi (miao noir)"},
/* 16F0A */ { "LETTRE MIAO TA","	* utilisée pour « da » en gan yi"},
/* 16F0B */ { "LETTRE MIAO DA",NULL},
/* 16F0C */ { "LETTRE MIAO YI TTA","	* utilisée en hei yi (miao noir)"},
/* 16F0D */ { "LETTRE MIAO YI TA","	* utilisée pour « ta » en gan yi"},
/* 16F0E */ { "LETTRE MIAO TTA",NULL},
/* 16F0F */ { "LETTRE MIAO DDA",NULL},
/* 16F10 */ { "LETTRE MIAO NA",NULL},
/* 16F11 */ { "LETTRE MIAO NHA",NULL},
/* 16F12 */ { "LETTRE MIAO YI NNA","	* utilisée en hei yi (miao noir)"},
/* 16F13 */ { "LETTRE MIAO NA ARCHAÏQUE","	* utilisée dans l'orthographe primitive de Pollard"},
/* 16F14 */ { "LETTRE MIAO NNA",NULL},
/* 16F15 */ { "LETTRE MIAO NNHA",NULL},
/* 16F16 */ { "LETTRE MIAO LA",NULL},
/* 16F17 */ { "LETTRE MIAO LYA","	* utilisée en hei yi (miao noir)"},
/* 16F18 */ { "LETTRE MIAO LHA",NULL},
/* 16F19 */ { "LETTRE MIAO LHYA","	* utilisée en hei yi (miao noir)"},
/* 16F1A */ { "LETTRE MIAO TLHA",NULL},
/* 16F1B */ { "LETTRE MIAO DLHA",NULL},
/* 16F1C */ { "LETTRE MIAO TLHYA",NULL},
/* 16F1D */ { "LETTRE MIAO DLHYA",NULL},
/* 16F1E */ { "LETTRE MIAO KA","	* utilisée pour « ga » en gan yi"},
/* 16F1F */ { "LETTRE MIAO GA",NULL},
/* 16F20 */ { "LETTRE MIAO YI KA","	* utilisée pour « ka » en gan yi"},
/* 16F21 */ { "LETTRE MIAO QA",NULL},
/* 16F22 */ { "LETTRE MIAO QGA",NULL},
/* 16F23 */ { "LETTRE MIAO NGA",NULL},
/* 16F24 */ { "LETTRE MIAO NGHA",NULL},
/* 16F25 */ { "LETTRE MIAO NGA ARCHAÏQUE","	* utilisée dans l'orthographe primitive de Pollard"},
/* 16F26 */ { "LETTRE MIAO HA",NULL},
/* 16F27 */ { "LETTRE MIAO XA","	* caractère archaïque utilisé dans une orthographe réformée après 1949"},
/* 16F28 */ { "LETTRE MIAO GHA",NULL},
/* 16F29 */ { "LETTRE MIAO GHHA",NULL},
/* 16F2A */ { "LETTRE MIAO TSSA",NULL},
/* 16F2B */ { "LETTRE MIAO DZZA",NULL},
/* 16F2C */ { "LETTRE MIAO ÑA",NULL},
/* 16F2D */ { "LETTRE MIAO ÑHA","	* utilisée en bai yi (miao blanc)"},
/* 16F2E */ { "LETTRE MIAO TSHA",NULL},
/* 16F2F */ { "LETTRE MIAO DZHA",NULL},
/* 16F30 */ { "LETTRE MIAO YI TSHA","	* utilisée pour « tsha » en gan yi"},
/* 16F31 */ { "LETTRE MIAO YI DZHA","	* utilisée en hei yi (miao noir)"},
/* 16F32 */ { "LETTRE MIAO TSHA RÉFORMÉE","	* caractère archaïque utilisé avant l'orthographe réformée de 1949"},
/* 16F33 */ { "LETTRE MIAO SHA",NULL},
/* 16F34 */ { "LETTRE MIAO SSA",NULL},
/* 16F35 */ { "LETTRE MIAO ZHA","	* utilisée en hei yi (miao noir)"},
/* 16F36 */ { "LETTRE MIAO ZSHA","	* utilisée en hei yi (miao noir)"},
/* 16F37 */ { "LETTRE MIAO TSA","	* utilisée pour « dza » en gan yi"},
/* 16F38 */ { "LETTRE MIAO DZA",NULL},
/* 16F39 */ { "LETTRE MIAO YI TSA","	* utilisée pour « tsa » en gan yi"},
/* 16F3A */ { "LETTRE MIAO SA",NULL},
/* 16F3B */ { "LETTRE MIAO ZA",NULL},
/* 16F3C */ { "LETTRE MIAO ZSA","	* utilisée en hei yi (miao noir)"},
/* 16F3D */ { "LETTRE MIAO ZZA",NULL},
/* 16F3E */ { "LETTRE MIAO ZZSA","	* utilisée en hei yi (miao noir)"},
/* 16F3F */ { "LETTRE MIAO ZZA ARCHAÏQUE","	* utilisée dans l'orthographe primitive de Pollard"},
/* 16F40 */ { "LETTRE MIAO ZZYA","	* utilisée en hei yi (miao noir)"},
/* 16F41 */ { "LETTRE MIAO ZZSYA","	* utilisée en hei yi (miao noir)"},
/* 16F42 */ { "LETTRE MIAO WA",NULL},
/* 16F43 */ { "LETTRE MIAO AH","	* coup de glotte"},
/* 16F44 */ { "LETTRE MIAO HHA","	* utilisée en hei yi (miao noir)"},
/* 16F45 */ { "LETTRE MIAO BRI","	* utilisée en miao à petites fleurs"},
/* 16F46 */ { "LETTRE MIAO SYI","	* utilisée en miao à petites fleurs"},
/* 16F47 */ { "LETTRE MIAO DZYI","	* utilisée en miao à petites fleurs"},
/* 16F48 */ { "LETTRE MIAO TE","	* utilisée en bai yi (miao blanc)"},
/* 16F49 */ { "LETTRE MIAO TSE","	* utilisée en bai yi (miao blanc)"},
/* 16F4A */ { "LETTRE MIAO RTE","	* utilisée en bai yi (miao blanc)"},
/* 16F4B */ { NULL,NULL},
/* 16F4C */ { NULL,NULL},
/* 16F4D */ { NULL,NULL},
/* 16F4E */ { NULL,NULL},
/* 16F4F */ { "DIACRITIQUE MIAO BARRE MODIFICATRICE DE CONSONNE","	* utilisé en gan yi\n"
	"	* fonctionne de la même manière que les nouktas indiens"},
/* 16F50 */ { "LETTRE MIAO NASALISATION",NULL},
/* 16F51 */ { "DIACRITIQUE MIAO ASPIRATION",NULL},
/* 16F52 */ { "DIACRITIQUE MIAO VOISEMENT RÉFORMÉ","	* caractère archaïque utilisé dans une orthographe réformée après 1949"},
/* 16F53 */ { "DIACRITIQUE MIAO ASPIRATION RÉFORMÉE","	* caractère archaïque utilisé dans une orthographe réformée après 1949"},
/* 16F54 */ { "DIACRITIQUE VOYELLE MIAO A",NULL},
/* 16F55 */ { "DIACRITIQUE VOYELLE MIAO AA","	* utilisé en lissou oriental"},
/* 16F56 */ { "DIACRITIQUE VOYELLE MIAO AHH","	* utilisé en gan yi"},
/* 16F57 */ { "DIACRITIQUE VOYELLE MIAO AN",NULL},
/* 16F58 */ { "DIACRITIQUE VOYELLE MIAO ANG","	* utilisé aussi pour aw"},
/* 16F59 */ { "DIACRITIQUE VOYELLE MIAO O",NULL},
/* 16F5A */ { "DIACRITIQUE VOYELLE MIAO OO",NULL},
/* 16F5B */ { "DIACRITIQUE VOYELLE MIAO WO","	* utilisé en hei yi (miao noir)"},
/* 16F5C */ { "DIACRITIQUE VOYELLE MIAO W",NULL},
/* 16F5D */ { "DIACRITIQUE VOYELLE MIAO E",NULL},
/* 16F5E */ { "DIACRITIQUE VOYELLE MIAO EN",NULL},
/* 16F5F */ { "DIACRITIQUE VOYELLE MIAO ENG",NULL},
/* 16F60 */ { "DIACRITIQUE VOYELLE MIAO OEY",NULL},
/* 16F61 */ { "DIACRITIQUE VOYELLE MIAO I",NULL},
/* 16F62 */ { "DIACRITIQUE VOYELLE MIAO IA",NULL},
/* 16F63 */ { "DIACRITIQUE VOYELLE MIAO IAN",NULL},
/* 16F64 */ { "DIACRITIQUE VOYELLE MIAO IANG","	* utilisé aussi pour iaw"},
/* 16F65 */ { "DIACRITIQUE VOYELLE MIAO IO",NULL},
/* 16F66 */ { "DIACRITIQUE VOYELLE MIAO IE",NULL},
/* 16F67 */ { "DIACRITIQUE VOYELLE MIAO II","	* utilisé en lissou oriental"},
/* 16F68 */ { "DIACRITIQUE VOYELLE MIAO IU",NULL},
/* 16F69 */ { "DIACRITIQUE VOYELLE MIAO ING","	* utilisé aussi pour in"},
/* 16F6A */ { "DIACRITIQUE VOYELLE MIAO U",NULL},
/* 16F6B */ { "DIACRITIQUE VOYELLE MIAO UA",NULL},
/* 16F6C */ { "DIACRITIQUE VOYELLE MIAO UAN",NULL},
/* 16F6D */ { "DIACRITIQUE VOYELLE MIAO UANG","	* utilisé aussi pour uaw"},
/* 16F6E */ { "DIACRITIQUE VOYELLE MIAO UU","	* utilisé en lissou oriental"},
/* 16F6F */ { "DIACRITIQUE VOYELLE MIAO UEI",NULL},
/* 16F70 */ { "DIACRITIQUE VOYELLE MIAO UNG",NULL},
/* 16F71 */ { "DIACRITIQUE VOYELLE MIAO Y",NULL},
/* 16F72 */ { "DIACRITIQUE VOYELLE MIAO YI",NULL},
/* 16F73 */ { "DIACRITIQUE VOYELLE MIAO AE",NULL},
/* 16F74 */ { "DIACRITIQUE VOYELLE MIAO AEE","	* utilisé en lissou oriental"},
/* 16F75 */ { "DIACRITIQUE VOYELLE MIAO ERR",NULL},
/* 16F76 */ { "DIACRITIQUE VOYELLE MIAO ERR ARRONDI","	* utilisé en lissou oriental"},
/* 16F77 */ { "DIACRITIQUE VOYELLE MIAO ER",NULL},
/* 16F78 */ { "DIACRITIQUE VOYELLE MIAO ER ARRONDI","	* utilisé en lissou oriental"},
/* 16F79 */ { "DIACRITIQUE VOYELLE MIAO AI",NULL},
/* 16F7A */ { "DIACRITIQUE VOYELLE MIAO EI",NULL},
/* 16F7B */ { "DIACRITIQUE VOYELLE MIAO AU",NULL},
/* 16F7C */ { "DIACRITIQUE VOYELLE MIAO OU",NULL},
/* 16F7D */ { "DIACRITIQUE VOYELLE MIAO N",NULL},
/* 16F7E */ { "DIACRITIQUE VOYELLE MIAO NG",NULL},
/* 16F7F */ { "DIACRITIQUE VOYELLE MIAO UOG","	* utilisé en hei yi (miao noir)"},
/* 16F80 */ { "DIACRITIQUE VOYELLE MIAO YUI","	* utilisé en hei yi (miao noir)"},
/* 16F81 */ { "DIACRITIQUE VOYELLE MIAO OG","	* utilisé en gan yi et en bai yi (miao blanc)"},
/* 16F82 */ { "DIACRITIQUE VOYELLE MIAO OER","	* utilisé en gan yi et en miao à petites fleurs"},
/* 16F83 */ { "DIACRITIQUE VOYELLE MIAO VW","	* utilisé en miao à petites fleurs et en bai yi (miao blanc)"},
/* 16F84 */ { "DIACRITIQUE VOYELLE MIAO IG","	* utilisé en bai yi (miao blanc)"},
/* 16F85 */ { "DIACRITIQUE VOYELLE MIAO EA","	* utilisé en bai yi (miao blanc)"},
/* 16F86 */ { "DIACRITIQUE VOYELLE MIAO IONG","	* utilisé en bai yi (miao blanc)"},
/* 16F87 */ { "DIACRITIQUE VOYELLE MIAO UI","	* utilisé en bai yi (miao blanc)"},
/* 16F88 */ { NULL,NULL},
/* 16F89 */ { NULL,NULL},
/* 16F8A */ { NULL,NULL},
/* 16F8B */ { NULL,NULL},
/* 16F8C */ { NULL,NULL},
/* 16F8D */ { NULL,NULL},
/* 16F8E */ { NULL,NULL},
/* 16F8F */ { "DIACRITIQUE TON MIAO À DROITE",NULL},
/* 16F90 */ { "DIACRITIQUE TON MIAO EN CHEF À DROITE",NULL},
/* 16F91 */ { "DIACRITIQUE TON MIAO EN CHEF",NULL},
/* 16F92 */ { "DIACRITIQUE TON MIAO SOUSCRIT",NULL},
/* 16F93 */ { "LETTRE MIAO TON-2",NULL},
/* 16F94 */ { "LETTRE MIAO TON-3",NULL},
/* 16F95 */ { "LETTRE MIAO TON-4",NULL},
/* 16F96 */ { "LETTRE MIAO TON-5",NULL},
/* 16F97 */ { "LETTRE MIAO TON-6",NULL},
/* 16F98 */ { "LETTRE MIAO TON-7",NULL},
/* 16F99 */ { "LETTRE MIAO TON-8",NULL},
/* 16F9A */ { "LETTRE MIAO TON-1 RÉFORMÉ",NULL},
/* 16F9B */ { "LETTRE MIAO TON-2 RÉFORMÉ",NULL},
/* 16F9C */ { "LETTRE MIAO TON-4 RÉFORMÉ",NULL},
/* 16F9D */ { "LETTRE MIAO TON-5 RÉFORMÉ",NULL},
/* 16F9E */ { "LETTRE MIAO TON-6 RÉFORMÉ",NULL},
/* 16F9F */ { "LETTRE MIAO TON-8 RÉFORMÉ",NULL},
/* 16FA0 */ { NULL,NULL},
/* 16FA1 */ { NULL,NULL},
/* 16FA2 */ { NULL,NULL},
/* 16FA3 */ { NULL,NULL},
/* 16FA4 */ { NULL,NULL},
/* 16FA5 */ { NULL,NULL},
/* 16FA6 */ { NULL,NULL},
/* 16FA7 */ { NULL,NULL},
/* 16FA8 */ { NULL,NULL},
/* 16FA9 */ { NULL,NULL},
/* 16FAA */ { NULL,NULL},
/* 16FAB */ { NULL,NULL},
/* 16FAC */ { NULL,NULL},
/* 16FAD */ { NULL,NULL},
/* 16FAE */ { NULL,NULL},
/* 16FAF */ { NULL,NULL},
/* 16FB0 */ { NULL,NULL},
/* 16FB1 */ { NULL,NULL},
/* 16FB2 */ { NULL,NULL},
/* 16FB3 */ { NULL,NULL},
/* 16FB4 */ { NULL,NULL},
/* 16FB5 */ { NULL,NULL},
/* 16FB6 */ { NULL,NULL},
/* 16FB7 */ { NULL,NULL},
/* 16FB8 */ { NULL,NULL},
/* 16FB9 */ { NULL,NULL},
/* 16FBA */ { NULL,NULL},
/* 16FBB */ { NULL,NULL},
/* 16FBC */ { NULL,NULL},
/* 16FBD */ { NULL,NULL},
/* 16FBE */ { NULL,NULL},
/* 16FBF */ { NULL,NULL},
/* 16FC0 */ { NULL,NULL},
/* 16FC1 */ { NULL,NULL},
/* 16FC2 */ { NULL,NULL},
/* 16FC3 */ { NULL,NULL},
/* 16FC4 */ { NULL,NULL},
/* 16FC5 */ { NULL,NULL},
/* 16FC6 */ { NULL,NULL},
/* 16FC7 */ { NULL,NULL},
/* 16FC8 */ { NULL,NULL},
/* 16FC9 */ { NULL,NULL},
/* 16FCA */ { NULL,NULL},
/* 16FCB */ { NULL,NULL},
/* 16FCC */ { NULL,NULL},
/* 16FCD */ { NULL,NULL},
/* 16FCE */ { NULL,NULL},
/* 16FCF */ { NULL,NULL},
/* 16FD0 */ { NULL,NULL},
/* 16FD1 */ { NULL,NULL},
/* 16FD2 */ { NULL,NULL},
/* 16FD3 */ { NULL,NULL},
/* 16FD4 */ { NULL,NULL},
/* 16FD5 */ { NULL,NULL},
/* 16FD6 */ { NULL,NULL},
/* 16FD7 */ { NULL,NULL},
/* 16FD8 */ { NULL,NULL},
/* 16FD9 */ { NULL,NULL},
/* 16FDA */ { NULL,NULL},
/* 16FDB */ { NULL,NULL},
/* 16FDC */ { NULL,NULL},
/* 16FDD */ { NULL,NULL},
/* 16FDE */ { NULL,NULL},
/* 16FDF */ { NULL,NULL},
/* 16FE0 */ { "MARQUE D'ITÉRATION TANGOUTE","	x (marque d'itération idéographique - 3005)"},
/* 16FE1 */ { "MARQUE D'ITÉRATION NÜSHU",NULL},
/* 16FE2 */ { "CROCHET CHINOIS ARCHAÏQUE","	* indique une pause ou une rupture dans le texte"},
/* 16FE3 */ { "MARQUE D'ITÉRATION CHINOISE ARCHAÏQUE","	x (marque d'itération idéographique - 3005)\n"
	"	x (marque d'itération idéographique verticale - 303B)"},
/* 16FE4 */ { "BOURRE PETITE ÉCRITURE KHITANE",NULL},
/* 16FE5 */ { NULL,NULL},
/* 16FE6 */ { NULL,NULL},
/* 16FE7 */ { NULL,NULL},
/* 16FE8 */ { NULL,NULL},
/* 16FE9 */ { NULL,NULL},
/* 16FEA */ { NULL,NULL},
/* 16FEB */ { NULL,NULL},
/* 16FEC */ { NULL,NULL},
/* 16FED */ { NULL,NULL},
/* 16FEE */ { NULL,NULL},
/* 16FEF */ { NULL,NULL},
/* 16FF0 */ { "MARQUE VIETNAMIENNE DE VARIANTE DE LECTURE CA","	x 4E2A\n"
	"	x 4E87"},
/* 16FF1 */ { "MARQUE VIETNAMIENNE DE VARIANTE DE LECTURE NHAY","	x 21FE8"},
/* 16FF2 */ { "PETIT ER SIMPLIFIÉ CHINOIS","	x 513F"},
/* 16FF3 */ { "PETIT ER TRADITIONNEL CHINOIS","	x 5152"},
/* 16FF4 */ { "SIGNE YANGQIN LENT D'UN TEMPS","	x (chiffre de suzhou six - 3026)"},
/* 16FF5 */ { "SIGNE YANGQIN LENT DE TROIS DEMI-TEMPS",NULL},
/* 16FF6 */ { "SIGNE YANGQIN LENT DE DEUX TEMPS",NULL},
/* 16FF7 */ { NULL,NULL},
/* 16FF8 */ { NULL,NULL},
/* 16FF9 */ { NULL,NULL},
/* 16FFA */ { NULL,NULL},
/* 16FFB */ { NULL,NULL},
/* 16FFC */ { NULL,NULL},
/* 16FFD */ { NULL,NULL},
/* 16FFE */ { NULL,NULL},
/* 16FFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_88[] = {
/* 18800 */ { "ÉLÉMENT TANGOUTE-001",NULL},
/* 18801 */ { "ÉLÉMENT TANGOUTE-002",NULL},
/* 18802 */ { "ÉLÉMENT TANGOUTE-003",NULL},
/* 18803 */ { "ÉLÉMENT TANGOUTE-004",NULL},
/* 18804 */ { "ÉLÉMENT TANGOUTE-005",NULL},
/* 18805 */ { "ÉLÉMENT TANGOUTE-006",NULL},
/* 18806 */ { "ÉLÉMENT TANGOUTE-007",NULL},
/* 18807 */ { "ÉLÉMENT TANGOUTE-008",NULL},
/* 18808 */ { "ÉLÉMENT TANGOUTE-009",NULL},
/* 18809 */ { "ÉLÉMENT TANGOUTE-010",NULL},
/* 1880A */ { "ÉLÉMENT TANGOUTE-011",NULL},
/* 1880B */ { "ÉLÉMENT TANGOUTE-012",NULL},
/* 1880C */ { "ÉLÉMENT TANGOUTE-013",NULL},
/* 1880D */ { "ÉLÉMENT TANGOUTE-014",NULL},
/* 1880E */ { "ÉLÉMENT TANGOUTE-015",NULL},
/* 1880F */ { "ÉLÉMENT TANGOUTE-016",NULL},
/* 18810 */ { "ÉLÉMENT TANGOUTE-017",NULL},
/* 18811 */ { "ÉLÉMENT TANGOUTE-018",NULL},
/* 18812 */ { "ÉLÉMENT TANGOUTE-019",NULL},
/* 18813 */ { "ÉLÉMENT TANGOUTE-020",NULL},
/* 18814 */ { "ÉLÉMENT TANGOUTE-021",NULL},
/* 18815 */ { "ÉLÉMENT TANGOUTE-022",NULL},
/* 18816 */ { "ÉLÉMENT TANGOUTE-023",NULL},
/* 18817 */ { "ÉLÉMENT TANGOUTE-024",NULL},
/* 18818 */ { "ÉLÉMENT TANGOUTE-025",NULL},
/* 18819 */ { "ÉLÉMENT TANGOUTE-026",NULL},
/* 1881A */ { "ÉLÉMENT TANGOUTE-027",NULL},
/* 1881B */ { "ÉLÉMENT TANGOUTE-028",NULL},
/* 1881C */ { "ÉLÉMENT TANGOUTE-029",NULL},
/* 1881D */ { "ÉLÉMENT TANGOUTE-030",NULL},
/* 1881E */ { "ÉLÉMENT TANGOUTE-031",NULL},
/* 1881F */ { "ÉLÉMENT TANGOUTE-032",NULL},
/* 18820 */ { "ÉLÉMENT TANGOUTE-033",NULL},
/* 18821 */ { "ÉLÉMENT TANGOUTE-034",NULL},
/* 18822 */ { "ÉLÉMENT TANGOUTE-035",NULL},
/* 18823 */ { "ÉLÉMENT TANGOUTE-036",NULL},
/* 18824 */ { "ÉLÉMENT TANGOUTE-037",NULL},
/* 18825 */ { "ÉLÉMENT TANGOUTE-038",NULL},
/* 18826 */ { "ÉLÉMENT TANGOUTE-039",NULL},
/* 18827 */ { "ÉLÉMENT TANGOUTE-040",NULL},
/* 18828 */ { "ÉLÉMENT TANGOUTE-041",NULL},
/* 18829 */ { "ÉLÉMENT TANGOUTE-042",NULL},
/* 1882A */ { "ÉLÉMENT TANGOUTE-043",NULL},
/* 1882B */ { "ÉLÉMENT TANGOUTE-044",NULL},
/* 1882C */ { "ÉLÉMENT TANGOUTE-045",NULL},
/* 1882D */ { "ÉLÉMENT TANGOUTE-046",NULL},
/* 1882E */ { "ÉLÉMENT TANGOUTE-047",NULL},
/* 1882F */ { "ÉLÉMENT TANGOUTE-048",NULL},
/* 18830 */ { "ÉLÉMENT TANGOUTE-049",NULL},
/* 18831 */ { "ÉLÉMENT TANGOUTE-050",NULL},
/* 18832 */ { "ÉLÉMENT TANGOUTE-051",NULL},
/* 18833 */ { "ÉLÉMENT TANGOUTE-052",NULL},
/* 18834 */ { "ÉLÉMENT TANGOUTE-053",NULL},
/* 18835 */ { "ÉLÉMENT TANGOUTE-054",NULL},
/* 18836 */ { "ÉLÉMENT TANGOUTE-055",NULL},
/* 18837 */ { "ÉLÉMENT TANGOUTE-056",NULL},
/* 18838 */ { "ÉLÉMENT TANGOUTE-057",NULL},
/* 18839 */ { "ÉLÉMENT TANGOUTE-058",NULL},
/* 1883A */ { "ÉLÉMENT TANGOUTE-059",NULL},
/* 1883B */ { "ÉLÉMENT TANGOUTE-060",NULL},
/* 1883C */ { "ÉLÉMENT TANGOUTE-061",NULL},
/* 1883D */ { "ÉLÉMENT TANGOUTE-062",NULL},
/* 1883E */ { "ÉLÉMENT TANGOUTE-063",NULL},
/* 1883F */ { "ÉLÉMENT TANGOUTE-064",NULL},
/* 18840 */ { "ÉLÉMENT TANGOUTE-065",NULL},
/* 18841 */ { "ÉLÉMENT TANGOUTE-066",NULL},
/* 18842 */ { "ÉLÉMENT TANGOUTE-067",NULL},
/* 18843 */ { "ÉLÉMENT TANGOUTE-068",NULL},
/* 18844 */ { "ÉLÉMENT TANGOUTE-069",NULL},
/* 18845 */ { "ÉLÉMENT TANGOUTE-070",NULL},
/* 18846 */ { "ÉLÉMENT TANGOUTE-071",NULL},
/* 18847 */ { "ÉLÉMENT TANGOUTE-072",NULL},
/* 18848 */ { "ÉLÉMENT TANGOUTE-073",NULL},
/* 18849 */ { "ÉLÉMENT TANGOUTE-074",NULL},
/* 1884A */ { "ÉLÉMENT TANGOUTE-075",NULL},
/* 1884B */ { "ÉLÉMENT TANGOUTE-076",NULL},
/* 1884C */ { "ÉLÉMENT TANGOUTE-077",NULL},
/* 1884D */ { "ÉLÉMENT TANGOUTE-078",NULL},
/* 1884E */ { "ÉLÉMENT TANGOUTE-079",NULL},
/* 1884F */ { "ÉLÉMENT TANGOUTE-080",NULL},
/* 18850 */ { "ÉLÉMENT TANGOUTE-081",NULL},
/* 18851 */ { "ÉLÉMENT TANGOUTE-082",NULL},
/* 18852 */ { "ÉLÉMENT TANGOUTE-083",NULL},
/* 18853 */ { "ÉLÉMENT TANGOUTE-084",NULL},
/* 18854 */ { "ÉLÉMENT TANGOUTE-085",NULL},
/* 18855 */ { "ÉLÉMENT TANGOUTE-086",NULL},
/* 18856 */ { "ÉLÉMENT TANGOUTE-087",NULL},
/* 18857 */ { "ÉLÉMENT TANGOUTE-088",NULL},
/* 18858 */ { "ÉLÉMENT TANGOUTE-089",NULL},
/* 18859 */ { "ÉLÉMENT TANGOUTE-090",NULL},
/* 1885A */ { "ÉLÉMENT TANGOUTE-091",NULL},
/* 1885B */ { "ÉLÉMENT TANGOUTE-092",NULL},
/* 1885C */ { "ÉLÉMENT TANGOUTE-093",NULL},
/* 1885D */ { "ÉLÉMENT TANGOUTE-094",NULL},
/* 1885E */ { "ÉLÉMENT TANGOUTE-095",NULL},
/* 1885F */ { "ÉLÉMENT TANGOUTE-096",NULL},
/* 18860 */ { "ÉLÉMENT TANGOUTE-097",NULL},
/* 18861 */ { "ÉLÉMENT TANGOUTE-098",NULL},
/* 18862 */ { "ÉLÉMENT TANGOUTE-099",NULL},
/* 18863 */ { "ÉLÉMENT TANGOUTE-100",NULL},
/* 18864 */ { "ÉLÉMENT TANGOUTE-101",NULL},
/* 18865 */ { "ÉLÉMENT TANGOUTE-102",NULL},
/* 18866 */ { "ÉLÉMENT TANGOUTE-103",NULL},
/* 18867 */ { "ÉLÉMENT TANGOUTE-104",NULL},
/* 18868 */ { "ÉLÉMENT TANGOUTE-105",NULL},
/* 18869 */ { "ÉLÉMENT TANGOUTE-106",NULL},
/* 1886A */ { "ÉLÉMENT TANGOUTE-107",NULL},
/* 1886B */ { "ÉLÉMENT TANGOUTE-108",NULL},
/* 1886C */ { "ÉLÉMENT TANGOUTE-109",NULL},
/* 1886D */ { "ÉLÉMENT TANGOUTE-110",NULL},
/* 1886E */ { "ÉLÉMENT TANGOUTE-111",NULL},
/* 1886F */ { "ÉLÉMENT TANGOUTE-112",NULL},
/* 18870 */ { "ÉLÉMENT TANGOUTE-113",NULL},
/* 18871 */ { "ÉLÉMENT TANGOUTE-114",NULL},
/* 18872 */ { "ÉLÉMENT TANGOUTE-115",NULL},
/* 18873 */ { "ÉLÉMENT TANGOUTE-116",NULL},
/* 18874 */ { "ÉLÉMENT TANGOUTE-117",NULL},
/* 18875 */ { "ÉLÉMENT TANGOUTE-118",NULL},
/* 18876 */ { "ÉLÉMENT TANGOUTE-119",NULL},
/* 18877 */ { "ÉLÉMENT TANGOUTE-120",NULL},
/* 18878 */ { "ÉLÉMENT TANGOUTE-121",NULL},
/* 18879 */ { "ÉLÉMENT TANGOUTE-122",NULL},
/* 1887A */ { "ÉLÉMENT TANGOUTE-123",NULL},
/* 1887B */ { "ÉLÉMENT TANGOUTE-124",NULL},
/* 1887C */ { "ÉLÉMENT TANGOUTE-125",NULL},
/* 1887D */ { "ÉLÉMENT TANGOUTE-126",NULL},
/* 1887E */ { "ÉLÉMENT TANGOUTE-127",NULL},
/* 1887F */ { "ÉLÉMENT TANGOUTE-128",NULL},
/* 18880 */ { "ÉLÉMENT TANGOUTE-129",NULL},
/* 18881 */ { "ÉLÉMENT TANGOUTE-130",NULL},
/* 18882 */ { "ÉLÉMENT TANGOUTE-131",NULL},
/* 18883 */ { "ÉLÉMENT TANGOUTE-132",NULL},
/* 18884 */ { "ÉLÉMENT TANGOUTE-133",NULL},
/* 18885 */ { "ÉLÉMENT TANGOUTE-134",NULL},
/* 18886 */ { "ÉLÉMENT TANGOUTE-135",NULL},
/* 18887 */ { "ÉLÉMENT TANGOUTE-136",NULL},
/* 18888 */ { "ÉLÉMENT TANGOUTE-137",NULL},
/* 18889 */ { "ÉLÉMENT TANGOUTE-138",NULL},
/* 1888A */ { "ÉLÉMENT TANGOUTE-139",NULL},
/* 1888B */ { "ÉLÉMENT TANGOUTE-140",NULL},
/* 1888C */ { "ÉLÉMENT TANGOUTE-141",NULL},
/* 1888D */ { "ÉLÉMENT TANGOUTE-142",NULL},
/* 1888E */ { "ÉLÉMENT TANGOUTE-143",NULL},
/* 1888F */ { "ÉLÉMENT TANGOUTE-144",NULL},
/* 18890 */ { "ÉLÉMENT TANGOUTE-145",NULL},
/* 18891 */ { "ÉLÉMENT TANGOUTE-146",NULL},
/* 18892 */ { "ÉLÉMENT TANGOUTE-147",NULL},
/* 18893 */ { "ÉLÉMENT TANGOUTE-148",NULL},
/* 18894 */ { "ÉLÉMENT TANGOUTE-149",NULL},
/* 18895 */ { "ÉLÉMENT TANGOUTE-150",NULL},
/* 18896 */ { "ÉLÉMENT TANGOUTE-151",NULL},
/* 18897 */ { "ÉLÉMENT TANGOUTE-152",NULL},
/* 18898 */ { "ÉLÉMENT TANGOUTE-153",NULL},
/* 18899 */ { "ÉLÉMENT TANGOUTE-154",NULL},
/* 1889A */ { "ÉLÉMENT TANGOUTE-155",NULL},
/* 1889B */ { "ÉLÉMENT TANGOUTE-156",NULL},
/* 1889C */ { "ÉLÉMENT TANGOUTE-157",NULL},
/* 1889D */ { "ÉLÉMENT TANGOUTE-158",NULL},
/* 1889E */ { "ÉLÉMENT TANGOUTE-159",NULL},
/* 1889F */ { "ÉLÉMENT TANGOUTE-160",NULL},
/* 188A0 */ { "ÉLÉMENT TANGOUTE-161",NULL},
/* 188A1 */ { "ÉLÉMENT TANGOUTE-162",NULL},
/* 188A2 */ { "ÉLÉMENT TANGOUTE-163",NULL},
/* 188A3 */ { "ÉLÉMENT TANGOUTE-164",NULL},
/* 188A4 */ { "ÉLÉMENT TANGOUTE-165",NULL},
/* 188A5 */ { "ÉLÉMENT TANGOUTE-166",NULL},
/* 188A6 */ { "ÉLÉMENT TANGOUTE-167",NULL},
/* 188A7 */ { "ÉLÉMENT TANGOUTE-168",NULL},
/* 188A8 */ { "ÉLÉMENT TANGOUTE-169",NULL},
/* 188A9 */ { "ÉLÉMENT TANGOUTE-170",NULL},
/* 188AA */ { "ÉLÉMENT TANGOUTE-171",NULL},
/* 188AB */ { "ÉLÉMENT TANGOUTE-172",NULL},
/* 188AC */ { "ÉLÉMENT TANGOUTE-173",NULL},
/* 188AD */ { "ÉLÉMENT TANGOUTE-174",NULL},
/* 188AE */ { "ÉLÉMENT TANGOUTE-175",NULL},
/* 188AF */ { "ÉLÉMENT TANGOUTE-176",NULL},
/* 188B0 */ { "ÉLÉMENT TANGOUTE-177",NULL},
/* 188B1 */ { "ÉLÉMENT TANGOUTE-178",NULL},
/* 188B2 */ { "ÉLÉMENT TANGOUTE-179",NULL},
/* 188B3 */ { "ÉLÉMENT TANGOUTE-180",NULL},
/* 188B4 */ { "ÉLÉMENT TANGOUTE-181",NULL},
/* 188B5 */ { "ÉLÉMENT TANGOUTE-182",NULL},
/* 188B6 */ { "ÉLÉMENT TANGOUTE-183",NULL},
/* 188B7 */ { "ÉLÉMENT TANGOUTE-184",NULL},
/* 188B8 */ { "ÉLÉMENT TANGOUTE-185",NULL},
/* 188B9 */ { "ÉLÉMENT TANGOUTE-186",NULL},
/* 188BA */ { "ÉLÉMENT TANGOUTE-187",NULL},
/* 188BB */ { "ÉLÉMENT TANGOUTE-188",NULL},
/* 188BC */ { "ÉLÉMENT TANGOUTE-189",NULL},
/* 188BD */ { "ÉLÉMENT TANGOUTE-190",NULL},
/* 188BE */ { "ÉLÉMENT TANGOUTE-191",NULL},
/* 188BF */ { "ÉLÉMENT TANGOUTE-192",NULL},
/* 188C0 */ { "ÉLÉMENT TANGOUTE-193",NULL},
/* 188C1 */ { "ÉLÉMENT TANGOUTE-194",NULL},
/* 188C2 */ { "ÉLÉMENT TANGOUTE-195",NULL},
/* 188C3 */ { "ÉLÉMENT TANGOUTE-196",NULL},
/* 188C4 */ { "ÉLÉMENT TANGOUTE-197",NULL},
/* 188C5 */ { "ÉLÉMENT TANGOUTE-198",NULL},
/* 188C6 */ { "ÉLÉMENT TANGOUTE-199",NULL},
/* 188C7 */ { "ÉLÉMENT TANGOUTE-200",NULL},
/* 188C8 */ { "ÉLÉMENT TANGOUTE-201",NULL},
/* 188C9 */ { "ÉLÉMENT TANGOUTE-202",NULL},
/* 188CA */ { "ÉLÉMENT TANGOUTE-203",NULL},
/* 188CB */ { "ÉLÉMENT TANGOUTE-204",NULL},
/* 188CC */ { "ÉLÉMENT TANGOUTE-205",NULL},
/* 188CD */ { "ÉLÉMENT TANGOUTE-206",NULL},
/* 188CE */ { "ÉLÉMENT TANGOUTE-207",NULL},
/* 188CF */ { "ÉLÉMENT TANGOUTE-208",NULL},
/* 188D0 */ { "ÉLÉMENT TANGOUTE-209",NULL},
/* 188D1 */ { "ÉLÉMENT TANGOUTE-210",NULL},
/* 188D2 */ { "ÉLÉMENT TANGOUTE-211",NULL},
/* 188D3 */ { "ÉLÉMENT TANGOUTE-212",NULL},
/* 188D4 */ { "ÉLÉMENT TANGOUTE-213",NULL},
/* 188D5 */ { "ÉLÉMENT TANGOUTE-214",NULL},
/* 188D6 */ { "ÉLÉMENT TANGOUTE-215",NULL},
/* 188D7 */ { "ÉLÉMENT TANGOUTE-216",NULL},
/* 188D8 */ { "ÉLÉMENT TANGOUTE-217",NULL},
/* 188D9 */ { "ÉLÉMENT TANGOUTE-218",NULL},
/* 188DA */ { "ÉLÉMENT TANGOUTE-219",NULL},
/* 188DB */ { "ÉLÉMENT TANGOUTE-220",NULL},
/* 188DC */ { "ÉLÉMENT TANGOUTE-221",NULL},
/* 188DD */ { "ÉLÉMENT TANGOUTE-222",NULL},
/* 188DE */ { "ÉLÉMENT TANGOUTE-223",NULL},
/* 188DF */ { "ÉLÉMENT TANGOUTE-224",NULL},
/* 188E0 */ { "ÉLÉMENT TANGOUTE-225",NULL},
/* 188E1 */ { "ÉLÉMENT TANGOUTE-226",NULL},
/* 188E2 */ { "ÉLÉMENT TANGOUTE-227",NULL},
/* 188E3 */ { "ÉLÉMENT TANGOUTE-228",NULL},
/* 188E4 */ { "ÉLÉMENT TANGOUTE-229",NULL},
/* 188E5 */ { "ÉLÉMENT TANGOUTE-230",NULL},
/* 188E6 */ { "ÉLÉMENT TANGOUTE-231",NULL},
/* 188E7 */ { "ÉLÉMENT TANGOUTE-232",NULL},
/* 188E8 */ { "ÉLÉMENT TANGOUTE-233",NULL},
/* 188E9 */ { "ÉLÉMENT TANGOUTE-234",NULL},
/* 188EA */ { "ÉLÉMENT TANGOUTE-235",NULL},
/* 188EB */ { "ÉLÉMENT TANGOUTE-236",NULL},
/* 188EC */ { "ÉLÉMENT TANGOUTE-237",NULL},
/* 188ED */ { "ÉLÉMENT TANGOUTE-238",NULL},
/* 188EE */ { "ÉLÉMENT TANGOUTE-239",NULL},
/* 188EF */ { "ÉLÉMENT TANGOUTE-240",NULL},
/* 188F0 */ { "ÉLÉMENT TANGOUTE-241",NULL},
/* 188F1 */ { "ÉLÉMENT TANGOUTE-242",NULL},
/* 188F2 */ { "ÉLÉMENT TANGOUTE-243",NULL},
/* 188F3 */ { "ÉLÉMENT TANGOUTE-244",NULL},
/* 188F4 */ { "ÉLÉMENT TANGOUTE-245",NULL},
/* 188F5 */ { "ÉLÉMENT TANGOUTE-246",NULL},
/* 188F6 */ { "ÉLÉMENT TANGOUTE-247",NULL},
/* 188F7 */ { "ÉLÉMENT TANGOUTE-248",NULL},
/* 188F8 */ { "ÉLÉMENT TANGOUTE-249",NULL},
/* 188F9 */ { "ÉLÉMENT TANGOUTE-250",NULL},
/* 188FA */ { "ÉLÉMENT TANGOUTE-251",NULL},
/* 188FB */ { "ÉLÉMENT TANGOUTE-252",NULL},
/* 188FC */ { "ÉLÉMENT TANGOUTE-253",NULL},
/* 188FD */ { "ÉLÉMENT TANGOUTE-254",NULL},
/* 188FE */ { "ÉLÉMENT TANGOUTE-255",NULL},
/* 188FF */ { "ÉLÉMENT TANGOUTE-256",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_89[] = {
/* 18900 */ { "ÉLÉMENT TANGOUTE-257",NULL},
/* 18901 */ { "ÉLÉMENT TANGOUTE-258",NULL},
/* 18902 */ { "ÉLÉMENT TANGOUTE-259",NULL},
/* 18903 */ { "ÉLÉMENT TANGOUTE-260",NULL},
/* 18904 */ { "ÉLÉMENT TANGOUTE-261",NULL},
/* 18905 */ { "ÉLÉMENT TANGOUTE-262",NULL},
/* 18906 */ { "ÉLÉMENT TANGOUTE-263",NULL},
/* 18907 */ { "ÉLÉMENT TANGOUTE-264",NULL},
/* 18908 */ { "ÉLÉMENT TANGOUTE-265",NULL},
/* 18909 */ { "ÉLÉMENT TANGOUTE-266",NULL},
/* 1890A */ { "ÉLÉMENT TANGOUTE-267",NULL},
/* 1890B */ { "ÉLÉMENT TANGOUTE-268",NULL},
/* 1890C */ { "ÉLÉMENT TANGOUTE-269",NULL},
/* 1890D */ { "ÉLÉMENT TANGOUTE-270",NULL},
/* 1890E */ { "ÉLÉMENT TANGOUTE-271",NULL},
/* 1890F */ { "ÉLÉMENT TANGOUTE-272",NULL},
/* 18910 */ { "ÉLÉMENT TANGOUTE-273",NULL},
/* 18911 */ { "ÉLÉMENT TANGOUTE-274",NULL},
/* 18912 */ { "ÉLÉMENT TANGOUTE-275",NULL},
/* 18913 */ { "ÉLÉMENT TANGOUTE-276",NULL},
/* 18914 */ { "ÉLÉMENT TANGOUTE-277",NULL},
/* 18915 */ { "ÉLÉMENT TANGOUTE-278",NULL},
/* 18916 */ { "ÉLÉMENT TANGOUTE-279",NULL},
/* 18917 */ { "ÉLÉMENT TANGOUTE-280",NULL},
/* 18918 */ { "ÉLÉMENT TANGOUTE-281",NULL},
/* 18919 */ { "ÉLÉMENT TANGOUTE-282",NULL},
/* 1891A */ { "ÉLÉMENT TANGOUTE-283",NULL},
/* 1891B */ { "ÉLÉMENT TANGOUTE-284",NULL},
/* 1891C */ { "ÉLÉMENT TANGOUTE-285",NULL},
/* 1891D */ { "ÉLÉMENT TANGOUTE-286",NULL},
/* 1891E */ { "ÉLÉMENT TANGOUTE-287",NULL},
/* 1891F */ { "ÉLÉMENT TANGOUTE-288",NULL},
/* 18920 */ { "ÉLÉMENT TANGOUTE-289",NULL},
/* 18921 */ { "ÉLÉMENT TANGOUTE-290",NULL},
/* 18922 */ { "ÉLÉMENT TANGOUTE-291",NULL},
/* 18923 */ { "ÉLÉMENT TANGOUTE-292",NULL},
/* 18924 */ { "ÉLÉMENT TANGOUTE-293",NULL},
/* 18925 */ { "ÉLÉMENT TANGOUTE-294",NULL},
/* 18926 */ { "ÉLÉMENT TANGOUTE-295",NULL},
/* 18927 */ { "ÉLÉMENT TANGOUTE-296",NULL},
/* 18928 */ { "ÉLÉMENT TANGOUTE-297",NULL},
/* 18929 */ { "ÉLÉMENT TANGOUTE-298",NULL},
/* 1892A */ { "ÉLÉMENT TANGOUTE-299",NULL},
/* 1892B */ { "ÉLÉMENT TANGOUTE-300",NULL},
/* 1892C */ { "ÉLÉMENT TANGOUTE-301",NULL},
/* 1892D */ { "ÉLÉMENT TANGOUTE-302",NULL},
/* 1892E */ { "ÉLÉMENT TANGOUTE-303",NULL},
/* 1892F */ { "ÉLÉMENT TANGOUTE-304",NULL},
/* 18930 */ { "ÉLÉMENT TANGOUTE-305",NULL},
/* 18931 */ { "ÉLÉMENT TANGOUTE-306",NULL},
/* 18932 */ { "ÉLÉMENT TANGOUTE-307",NULL},
/* 18933 */ { "ÉLÉMENT TANGOUTE-308",NULL},
/* 18934 */ { "ÉLÉMENT TANGOUTE-309",NULL},
/* 18935 */ { "ÉLÉMENT TANGOUTE-310",NULL},
/* 18936 */ { "ÉLÉMENT TANGOUTE-311",NULL},
/* 18937 */ { "ÉLÉMENT TANGOUTE-312",NULL},
/* 18938 */ { "ÉLÉMENT TANGOUTE-313",NULL},
/* 18939 */ { "ÉLÉMENT TANGOUTE-314",NULL},
/* 1893A */ { "ÉLÉMENT TANGOUTE-315",NULL},
/* 1893B */ { "ÉLÉMENT TANGOUTE-316",NULL},
/* 1893C */ { "ÉLÉMENT TANGOUTE-317",NULL},
/* 1893D */ { "ÉLÉMENT TANGOUTE-318",NULL},
/* 1893E */ { "ÉLÉMENT TANGOUTE-319",NULL},
/* 1893F */ { "ÉLÉMENT TANGOUTE-320",NULL},
/* 18940 */ { "ÉLÉMENT TANGOUTE-321",NULL},
/* 18941 */ { "ÉLÉMENT TANGOUTE-322",NULL},
/* 18942 */ { "ÉLÉMENT TANGOUTE-323",NULL},
/* 18943 */ { "ÉLÉMENT TANGOUTE-324",NULL},
/* 18944 */ { "ÉLÉMENT TANGOUTE-325",NULL},
/* 18945 */ { "ÉLÉMENT TANGOUTE-326",NULL},
/* 18946 */ { "ÉLÉMENT TANGOUTE-327",NULL},
/* 18947 */ { "ÉLÉMENT TANGOUTE-328",NULL},
/* 18948 */ { "ÉLÉMENT TANGOUTE-329",NULL},
/* 18949 */ { "ÉLÉMENT TANGOUTE-330",NULL},
/* 1894A */ { "ÉLÉMENT TANGOUTE-331",NULL},
/* 1894B */ { "ÉLÉMENT TANGOUTE-332",NULL},
/* 1894C */ { "ÉLÉMENT TANGOUTE-333",NULL},
/* 1894D */ { "ÉLÉMENT TANGOUTE-334",NULL},
/* 1894E */ { "ÉLÉMENT TANGOUTE-335",NULL},
/* 1894F */ { "ÉLÉMENT TANGOUTE-336",NULL},
/* 18950 */ { "ÉLÉMENT TANGOUTE-337",NULL},
/* 18951 */ { "ÉLÉMENT TANGOUTE-338",NULL},
/* 18952 */ { "ÉLÉMENT TANGOUTE-339",NULL},
/* 18953 */ { "ÉLÉMENT TANGOUTE-340",NULL},
/* 18954 */ { "ÉLÉMENT TANGOUTE-341",NULL},
/* 18955 */ { "ÉLÉMENT TANGOUTE-342",NULL},
/* 18956 */ { "ÉLÉMENT TANGOUTE-343",NULL},
/* 18957 */ { "ÉLÉMENT TANGOUTE-344",NULL},
/* 18958 */ { "ÉLÉMENT TANGOUTE-345",NULL},
/* 18959 */ { "ÉLÉMENT TANGOUTE-346",NULL},
/* 1895A */ { "ÉLÉMENT TANGOUTE-347",NULL},
/* 1895B */ { "ÉLÉMENT TANGOUTE-348",NULL},
/* 1895C */ { "ÉLÉMENT TANGOUTE-349",NULL},
/* 1895D */ { "ÉLÉMENT TANGOUTE-350",NULL},
/* 1895E */ { "ÉLÉMENT TANGOUTE-351",NULL},
/* 1895F */ { "ÉLÉMENT TANGOUTE-352",NULL},
/* 18960 */ { "ÉLÉMENT TANGOUTE-353",NULL},
/* 18961 */ { "ÉLÉMENT TANGOUTE-354",NULL},
/* 18962 */ { "ÉLÉMENT TANGOUTE-355",NULL},
/* 18963 */ { "ÉLÉMENT TANGOUTE-356",NULL},
/* 18964 */ { "ÉLÉMENT TANGOUTE-357",NULL},
/* 18965 */ { "ÉLÉMENT TANGOUTE-358",NULL},
/* 18966 */ { "ÉLÉMENT TANGOUTE-359",NULL},
/* 18967 */ { "ÉLÉMENT TANGOUTE-360",NULL},
/* 18968 */ { "ÉLÉMENT TANGOUTE-361",NULL},
/* 18969 */ { "ÉLÉMENT TANGOUTE-362",NULL},
/* 1896A */ { "ÉLÉMENT TANGOUTE-363",NULL},
/* 1896B */ { "ÉLÉMENT TANGOUTE-364",NULL},
/* 1896C */ { "ÉLÉMENT TANGOUTE-365",NULL},
/* 1896D */ { "ÉLÉMENT TANGOUTE-366",NULL},
/* 1896E */ { "ÉLÉMENT TANGOUTE-367",NULL},
/* 1896F */ { "ÉLÉMENT TANGOUTE-368",NULL},
/* 18970 */ { "ÉLÉMENT TANGOUTE-369",NULL},
/* 18971 */ { "ÉLÉMENT TANGOUTE-370",NULL},
/* 18972 */ { "ÉLÉMENT TANGOUTE-371",NULL},
/* 18973 */ { "ÉLÉMENT TANGOUTE-372",NULL},
/* 18974 */ { "ÉLÉMENT TANGOUTE-373",NULL},
/* 18975 */ { "ÉLÉMENT TANGOUTE-374",NULL},
/* 18976 */ { "ÉLÉMENT TANGOUTE-375",NULL},
/* 18977 */ { "ÉLÉMENT TANGOUTE-376",NULL},
/* 18978 */ { "ÉLÉMENT TANGOUTE-377",NULL},
/* 18979 */ { "ÉLÉMENT TANGOUTE-378",NULL},
/* 1897A */ { "ÉLÉMENT TANGOUTE-379",NULL},
/* 1897B */ { "ÉLÉMENT TANGOUTE-380",NULL},
/* 1897C */ { "ÉLÉMENT TANGOUTE-381",NULL},
/* 1897D */ { "ÉLÉMENT TANGOUTE-382",NULL},
/* 1897E */ { "ÉLÉMENT TANGOUTE-383",NULL},
/* 1897F */ { "ÉLÉMENT TANGOUTE-384",NULL},
/* 18980 */ { "ÉLÉMENT TANGOUTE-385",NULL},
/* 18981 */ { "ÉLÉMENT TANGOUTE-386",NULL},
/* 18982 */ { "ÉLÉMENT TANGOUTE-387",NULL},
/* 18983 */ { "ÉLÉMENT TANGOUTE-388",NULL},
/* 18984 */ { "ÉLÉMENT TANGOUTE-389",NULL},
/* 18985 */ { "ÉLÉMENT TANGOUTE-390",NULL},
/* 18986 */ { "ÉLÉMENT TANGOUTE-391",NULL},
/* 18987 */ { "ÉLÉMENT TANGOUTE-392",NULL},
/* 18988 */ { "ÉLÉMENT TANGOUTE-393",NULL},
/* 18989 */ { "ÉLÉMENT TANGOUTE-394",NULL},
/* 1898A */ { "ÉLÉMENT TANGOUTE-395",NULL},
/* 1898B */ { "ÉLÉMENT TANGOUTE-396",NULL},
/* 1898C */ { "ÉLÉMENT TANGOUTE-397",NULL},
/* 1898D */ { "ÉLÉMENT TANGOUTE-398",NULL},
/* 1898E */ { "ÉLÉMENT TANGOUTE-399",NULL},
/* 1898F */ { "ÉLÉMENT TANGOUTE-400",NULL},
/* 18990 */ { "ÉLÉMENT TANGOUTE-401",NULL},
/* 18991 */ { "ÉLÉMENT TANGOUTE-402",NULL},
/* 18992 */ { "ÉLÉMENT TANGOUTE-403",NULL},
/* 18993 */ { "ÉLÉMENT TANGOUTE-404",NULL},
/* 18994 */ { "ÉLÉMENT TANGOUTE-405",NULL},
/* 18995 */ { "ÉLÉMENT TANGOUTE-406",NULL},
/* 18996 */ { "ÉLÉMENT TANGOUTE-407",NULL},
/* 18997 */ { "ÉLÉMENT TANGOUTE-408",NULL},
/* 18998 */ { "ÉLÉMENT TANGOUTE-409",NULL},
/* 18999 */ { "ÉLÉMENT TANGOUTE-410",NULL},
/* 1899A */ { "ÉLÉMENT TANGOUTE-411",NULL},
/* 1899B */ { "ÉLÉMENT TANGOUTE-412",NULL},
/* 1899C */ { "ÉLÉMENT TANGOUTE-413",NULL},
/* 1899D */ { "ÉLÉMENT TANGOUTE-414",NULL},
/* 1899E */ { "ÉLÉMENT TANGOUTE-415",NULL},
/* 1899F */ { "ÉLÉMENT TANGOUTE-416",NULL},
/* 189A0 */ { "ÉLÉMENT TANGOUTE-417",NULL},
/* 189A1 */ { "ÉLÉMENT TANGOUTE-418",NULL},
/* 189A2 */ { "ÉLÉMENT TANGOUTE-419",NULL},
/* 189A3 */ { "ÉLÉMENT TANGOUTE-420",NULL},
/* 189A4 */ { "ÉLÉMENT TANGOUTE-421",NULL},
/* 189A5 */ { "ÉLÉMENT TANGOUTE-422",NULL},
/* 189A6 */ { "ÉLÉMENT TANGOUTE-423",NULL},
/* 189A7 */ { "ÉLÉMENT TANGOUTE-424",NULL},
/* 189A8 */ { "ÉLÉMENT TANGOUTE-425",NULL},
/* 189A9 */ { "ÉLÉMENT TANGOUTE-426",NULL},
/* 189AA */ { "ÉLÉMENT TANGOUTE-427",NULL},
/* 189AB */ { "ÉLÉMENT TANGOUTE-428",NULL},
/* 189AC */ { "ÉLÉMENT TANGOUTE-429",NULL},
/* 189AD */ { "ÉLÉMENT TANGOUTE-430",NULL},
/* 189AE */ { "ÉLÉMENT TANGOUTE-431",NULL},
/* 189AF */ { "ÉLÉMENT TANGOUTE-432",NULL},
/* 189B0 */ { "ÉLÉMENT TANGOUTE-433",NULL},
/* 189B1 */ { "ÉLÉMENT TANGOUTE-434",NULL},
/* 189B2 */ { "ÉLÉMENT TANGOUTE-435",NULL},
/* 189B3 */ { "ÉLÉMENT TANGOUTE-436",NULL},
/* 189B4 */ { "ÉLÉMENT TANGOUTE-437",NULL},
/* 189B5 */ { "ÉLÉMENT TANGOUTE-438",NULL},
/* 189B6 */ { "ÉLÉMENT TANGOUTE-439",NULL},
/* 189B7 */ { "ÉLÉMENT TANGOUTE-440",NULL},
/* 189B8 */ { "ÉLÉMENT TANGOUTE-441",NULL},
/* 189B9 */ { "ÉLÉMENT TANGOUTE-442",NULL},
/* 189BA */ { "ÉLÉMENT TANGOUTE-443",NULL},
/* 189BB */ { "ÉLÉMENT TANGOUTE-444",NULL},
/* 189BC */ { "ÉLÉMENT TANGOUTE-445",NULL},
/* 189BD */ { "ÉLÉMENT TANGOUTE-446",NULL},
/* 189BE */ { "ÉLÉMENT TANGOUTE-447",NULL},
/* 189BF */ { "ÉLÉMENT TANGOUTE-448",NULL},
/* 189C0 */ { "ÉLÉMENT TANGOUTE-449",NULL},
/* 189C1 */ { "ÉLÉMENT TANGOUTE-450",NULL},
/* 189C2 */ { "ÉLÉMENT TANGOUTE-451",NULL},
/* 189C3 */ { "ÉLÉMENT TANGOUTE-452",NULL},
/* 189C4 */ { "ÉLÉMENT TANGOUTE-453",NULL},
/* 189C5 */ { "ÉLÉMENT TANGOUTE-454",NULL},
/* 189C6 */ { "ÉLÉMENT TANGOUTE-455",NULL},
/* 189C7 */ { "ÉLÉMENT TANGOUTE-456",NULL},
/* 189C8 */ { "ÉLÉMENT TANGOUTE-457",NULL},
/* 189C9 */ { "ÉLÉMENT TANGOUTE-458",NULL},
/* 189CA */ { "ÉLÉMENT TANGOUTE-459",NULL},
/* 189CB */ { "ÉLÉMENT TANGOUTE-460",NULL},
/* 189CC */ { "ÉLÉMENT TANGOUTE-461",NULL},
/* 189CD */ { "ÉLÉMENT TANGOUTE-462",NULL},
/* 189CE */ { "ÉLÉMENT TANGOUTE-463",NULL},
/* 189CF */ { "ÉLÉMENT TANGOUTE-464",NULL},
/* 189D0 */ { "ÉLÉMENT TANGOUTE-465",NULL},
/* 189D1 */ { "ÉLÉMENT TANGOUTE-466",NULL},
/* 189D2 */ { "ÉLÉMENT TANGOUTE-467",NULL},
/* 189D3 */ { "ÉLÉMENT TANGOUTE-468",NULL},
/* 189D4 */ { "ÉLÉMENT TANGOUTE-469",NULL},
/* 189D5 */ { "ÉLÉMENT TANGOUTE-470",NULL},
/* 189D6 */ { "ÉLÉMENT TANGOUTE-471",NULL},
/* 189D7 */ { "ÉLÉMENT TANGOUTE-472",NULL},
/* 189D8 */ { "ÉLÉMENT TANGOUTE-473",NULL},
/* 189D9 */ { "ÉLÉMENT TANGOUTE-474",NULL},
/* 189DA */ { "ÉLÉMENT TANGOUTE-475",NULL},
/* 189DB */ { "ÉLÉMENT TANGOUTE-476",NULL},
/* 189DC */ { "ÉLÉMENT TANGOUTE-477",NULL},
/* 189DD */ { "ÉLÉMENT TANGOUTE-478",NULL},
/* 189DE */ { "ÉLÉMENT TANGOUTE-479",NULL},
/* 189DF */ { "ÉLÉMENT TANGOUTE-480",NULL},
/* 189E0 */ { "ÉLÉMENT TANGOUTE-481",NULL},
/* 189E1 */ { "ÉLÉMENT TANGOUTE-482",NULL},
/* 189E2 */ { "ÉLÉMENT TANGOUTE-483",NULL},
/* 189E3 */ { "ÉLÉMENT TANGOUTE-484",NULL},
/* 189E4 */ { "ÉLÉMENT TANGOUTE-485",NULL},
/* 189E5 */ { "ÉLÉMENT TANGOUTE-486",NULL},
/* 189E6 */ { "ÉLÉMENT TANGOUTE-487",NULL},
/* 189E7 */ { "ÉLÉMENT TANGOUTE-488",NULL},
/* 189E8 */ { "ÉLÉMENT TANGOUTE-489",NULL},
/* 189E9 */ { "ÉLÉMENT TANGOUTE-490",NULL},
/* 189EA */ { "ÉLÉMENT TANGOUTE-491",NULL},
/* 189EB */ { "ÉLÉMENT TANGOUTE-492",NULL},
/* 189EC */ { "ÉLÉMENT TANGOUTE-493",NULL},
/* 189ED */ { "ÉLÉMENT TANGOUTE-494",NULL},
/* 189EE */ { "ÉLÉMENT TANGOUTE-495",NULL},
/* 189EF */ { "ÉLÉMENT TANGOUTE-496",NULL},
/* 189F0 */ { "ÉLÉMENT TANGOUTE-497",NULL},
/* 189F1 */ { "ÉLÉMENT TANGOUTE-498",NULL},
/* 189F2 */ { "ÉLÉMENT TANGOUTE-499",NULL},
/* 189F3 */ { "ÉLÉMENT TANGOUTE-500",NULL},
/* 189F4 */ { "ÉLÉMENT TANGOUTE-501",NULL},
/* 189F5 */ { "ÉLÉMENT TANGOUTE-502",NULL},
/* 189F6 */ { "ÉLÉMENT TANGOUTE-503",NULL},
/* 189F7 */ { "ÉLÉMENT TANGOUTE-504",NULL},
/* 189F8 */ { "ÉLÉMENT TANGOUTE-505",NULL},
/* 189F9 */ { "ÉLÉMENT TANGOUTE-506",NULL},
/* 189FA */ { "ÉLÉMENT TANGOUTE-507",NULL},
/* 189FB */ { "ÉLÉMENT TANGOUTE-508",NULL},
/* 189FC */ { "ÉLÉMENT TANGOUTE-509",NULL},
/* 189FD */ { "ÉLÉMENT TANGOUTE-510",NULL},
/* 189FE */ { "ÉLÉMENT TANGOUTE-511",NULL},
/* 189FF */ { "ÉLÉMENT TANGOUTE-512",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_8A[] = {
/* 18A00 */ { "ÉLÉMENT TANGOUTE-513",NULL},
/* 18A01 */ { "ÉLÉMENT TANGOUTE-514",NULL},
/* 18A02 */ { "ÉLÉMENT TANGOUTE-515",NULL},
/* 18A03 */ { "ÉLÉMENT TANGOUTE-516",NULL},
/* 18A04 */ { "ÉLÉMENT TANGOUTE-517",NULL},
/* 18A05 */ { "ÉLÉMENT TANGOUTE-518",NULL},
/* 18A06 */ { "ÉLÉMENT TANGOUTE-519",NULL},
/* 18A07 */ { "ÉLÉMENT TANGOUTE-520",NULL},
/* 18A08 */ { "ÉLÉMENT TANGOUTE-521",NULL},
/* 18A09 */ { "ÉLÉMENT TANGOUTE-522",NULL},
/* 18A0A */ { "ÉLÉMENT TANGOUTE-523",NULL},
/* 18A0B */ { "ÉLÉMENT TANGOUTE-524",NULL},
/* 18A0C */ { "ÉLÉMENT TANGOUTE-525",NULL},
/* 18A0D */ { "ÉLÉMENT TANGOUTE-526",NULL},
/* 18A0E */ { "ÉLÉMENT TANGOUTE-527",NULL},
/* 18A0F */ { "ÉLÉMENT TANGOUTE-528",NULL},
/* 18A10 */ { "ÉLÉMENT TANGOUTE-529",NULL},
/* 18A11 */ { "ÉLÉMENT TANGOUTE-530",NULL},
/* 18A12 */ { "ÉLÉMENT TANGOUTE-531",NULL},
/* 18A13 */ { "ÉLÉMENT TANGOUTE-532",NULL},
/* 18A14 */ { "ÉLÉMENT TANGOUTE-533",NULL},
/* 18A15 */ { "ÉLÉMENT TANGOUTE-534",NULL},
/* 18A16 */ { "ÉLÉMENT TANGOUTE-535",NULL},
/* 18A17 */ { "ÉLÉMENT TANGOUTE-536",NULL},
/* 18A18 */ { "ÉLÉMENT TANGOUTE-537",NULL},
/* 18A19 */ { "ÉLÉMENT TANGOUTE-538",NULL},
/* 18A1A */ { "ÉLÉMENT TANGOUTE-539",NULL},
/* 18A1B */ { "ÉLÉMENT TANGOUTE-540",NULL},
/* 18A1C */ { "ÉLÉMENT TANGOUTE-541",NULL},
/* 18A1D */ { "ÉLÉMENT TANGOUTE-542",NULL},
/* 18A1E */ { "ÉLÉMENT TANGOUTE-543",NULL},
/* 18A1F */ { "ÉLÉMENT TANGOUTE-544",NULL},
/* 18A20 */ { "ÉLÉMENT TANGOUTE-545",NULL},
/* 18A21 */ { "ÉLÉMENT TANGOUTE-546",NULL},
/* 18A22 */ { "ÉLÉMENT TANGOUTE-547",NULL},
/* 18A23 */ { "ÉLÉMENT TANGOUTE-548",NULL},
/* 18A24 */ { "ÉLÉMENT TANGOUTE-549",NULL},
/* 18A25 */ { "ÉLÉMENT TANGOUTE-550",NULL},
/* 18A26 */ { "ÉLÉMENT TANGOUTE-551",NULL},
/* 18A27 */ { "ÉLÉMENT TANGOUTE-552",NULL},
/* 18A28 */ { "ÉLÉMENT TANGOUTE-553",NULL},
/* 18A29 */ { "ÉLÉMENT TANGOUTE-554",NULL},
/* 18A2A */ { "ÉLÉMENT TANGOUTE-555",NULL},
/* 18A2B */ { "ÉLÉMENT TANGOUTE-556",NULL},
/* 18A2C */ { "ÉLÉMENT TANGOUTE-557",NULL},
/* 18A2D */ { "ÉLÉMENT TANGOUTE-558",NULL},
/* 18A2E */ { "ÉLÉMENT TANGOUTE-559",NULL},
/* 18A2F */ { "ÉLÉMENT TANGOUTE-560",NULL},
/* 18A30 */ { "ÉLÉMENT TANGOUTE-561",NULL},
/* 18A31 */ { "ÉLÉMENT TANGOUTE-562",NULL},
/* 18A32 */ { "ÉLÉMENT TANGOUTE-563",NULL},
/* 18A33 */ { "ÉLÉMENT TANGOUTE-564",NULL},
/* 18A34 */ { "ÉLÉMENT TANGOUTE-565",NULL},
/* 18A35 */ { "ÉLÉMENT TANGOUTE-566",NULL},
/* 18A36 */ { "ÉLÉMENT TANGOUTE-567",NULL},
/* 18A37 */ { "ÉLÉMENT TANGOUTE-568",NULL},
/* 18A38 */ { "ÉLÉMENT TANGOUTE-569",NULL},
/* 18A39 */ { "ÉLÉMENT TANGOUTE-570",NULL},
/* 18A3A */ { "ÉLÉMENT TANGOUTE-571",NULL},
/* 18A3B */ { "ÉLÉMENT TANGOUTE-572",NULL},
/* 18A3C */ { "ÉLÉMENT TANGOUTE-573",NULL},
/* 18A3D */ { "ÉLÉMENT TANGOUTE-574",NULL},
/* 18A3E */ { "ÉLÉMENT TANGOUTE-575",NULL},
/* 18A3F */ { "ÉLÉMENT TANGOUTE-576",NULL},
/* 18A40 */ { "ÉLÉMENT TANGOUTE-577",NULL},
/* 18A41 */ { "ÉLÉMENT TANGOUTE-578",NULL},
/* 18A42 */ { "ÉLÉMENT TANGOUTE-579",NULL},
/* 18A43 */ { "ÉLÉMENT TANGOUTE-580",NULL},
/* 18A44 */ { "ÉLÉMENT TANGOUTE-581",NULL},
/* 18A45 */ { "ÉLÉMENT TANGOUTE-582",NULL},
/* 18A46 */ { "ÉLÉMENT TANGOUTE-583",NULL},
/* 18A47 */ { "ÉLÉMENT TANGOUTE-584",NULL},
/* 18A48 */ { "ÉLÉMENT TANGOUTE-585",NULL},
/* 18A49 */ { "ÉLÉMENT TANGOUTE-586",NULL},
/* 18A4A */ { "ÉLÉMENT TANGOUTE-587",NULL},
/* 18A4B */ { "ÉLÉMENT TANGOUTE-588",NULL},
/* 18A4C */ { "ÉLÉMENT TANGOUTE-589",NULL},
/* 18A4D */ { "ÉLÉMENT TANGOUTE-590",NULL},
/* 18A4E */ { "ÉLÉMENT TANGOUTE-591",NULL},
/* 18A4F */ { "ÉLÉMENT TANGOUTE-592",NULL},
/* 18A50 */ { "ÉLÉMENT TANGOUTE-593",NULL},
/* 18A51 */ { "ÉLÉMENT TANGOUTE-594",NULL},
/* 18A52 */ { "ÉLÉMENT TANGOUTE-595",NULL},
/* 18A53 */ { "ÉLÉMENT TANGOUTE-596",NULL},
/* 18A54 */ { "ÉLÉMENT TANGOUTE-597",NULL},
/* 18A55 */ { "ÉLÉMENT TANGOUTE-598",NULL},
/* 18A56 */ { "ÉLÉMENT TANGOUTE-599",NULL},
/* 18A57 */ { "ÉLÉMENT TANGOUTE-600",NULL},
/* 18A58 */ { "ÉLÉMENT TANGOUTE-601",NULL},
/* 18A59 */ { "ÉLÉMENT TANGOUTE-602",NULL},
/* 18A5A */ { "ÉLÉMENT TANGOUTE-603",NULL},
/* 18A5B */ { "ÉLÉMENT TANGOUTE-604",NULL},
/* 18A5C */ { "ÉLÉMENT TANGOUTE-605",NULL},
/* 18A5D */ { "ÉLÉMENT TANGOUTE-606",NULL},
/* 18A5E */ { "ÉLÉMENT TANGOUTE-607",NULL},
/* 18A5F */ { "ÉLÉMENT TANGOUTE-608",NULL},
/* 18A60 */ { "ÉLÉMENT TANGOUTE-609",NULL},
/* 18A61 */ { "ÉLÉMENT TANGOUTE-610",NULL},
/* 18A62 */ { "ÉLÉMENT TANGOUTE-611",NULL},
/* 18A63 */ { "ÉLÉMENT TANGOUTE-612",NULL},
/* 18A64 */ { "ÉLÉMENT TANGOUTE-613",NULL},
/* 18A65 */ { "ÉLÉMENT TANGOUTE-614",NULL},
/* 18A66 */ { "ÉLÉMENT TANGOUTE-615",NULL},
/* 18A67 */ { "ÉLÉMENT TANGOUTE-616",NULL},
/* 18A68 */ { "ÉLÉMENT TANGOUTE-617",NULL},
/* 18A69 */ { "ÉLÉMENT TANGOUTE-618",NULL},
/* 18A6A */ { "ÉLÉMENT TANGOUTE-619",NULL},
/* 18A6B */ { "ÉLÉMENT TANGOUTE-620",NULL},
/* 18A6C */ { "ÉLÉMENT TANGOUTE-621",NULL},
/* 18A6D */ { "ÉLÉMENT TANGOUTE-622",NULL},
/* 18A6E */ { "ÉLÉMENT TANGOUTE-623",NULL},
/* 18A6F */ { "ÉLÉMENT TANGOUTE-624",NULL},
/* 18A70 */ { "ÉLÉMENT TANGOUTE-625",NULL},
/* 18A71 */ { "ÉLÉMENT TANGOUTE-626",NULL},
/* 18A72 */ { "ÉLÉMENT TANGOUTE-627",NULL},
/* 18A73 */ { "ÉLÉMENT TANGOUTE-628",NULL},
/* 18A74 */ { "ÉLÉMENT TANGOUTE-629",NULL},
/* 18A75 */ { "ÉLÉMENT TANGOUTE-630",NULL},
/* 18A76 */ { "ÉLÉMENT TANGOUTE-631",NULL},
/* 18A77 */ { "ÉLÉMENT TANGOUTE-632",NULL},
/* 18A78 */ { "ÉLÉMENT TANGOUTE-633",NULL},
/* 18A79 */ { "ÉLÉMENT TANGOUTE-634",NULL},
/* 18A7A */ { "ÉLÉMENT TANGOUTE-635",NULL},
/* 18A7B */ { "ÉLÉMENT TANGOUTE-636",NULL},
/* 18A7C */ { "ÉLÉMENT TANGOUTE-637",NULL},
/* 18A7D */ { "ÉLÉMENT TANGOUTE-638",NULL},
/* 18A7E */ { "ÉLÉMENT TANGOUTE-639",NULL},
/* 18A7F */ { "ÉLÉMENT TANGOUTE-640",NULL},
/* 18A80 */ { "ÉLÉMENT TANGOUTE-641",NULL},
/* 18A81 */ { "ÉLÉMENT TANGOUTE-642",NULL},
/* 18A82 */ { "ÉLÉMENT TANGOUTE-643",NULL},
/* 18A83 */ { "ÉLÉMENT TANGOUTE-644",NULL},
/* 18A84 */ { "ÉLÉMENT TANGOUTE-645",NULL},
/* 18A85 */ { "ÉLÉMENT TANGOUTE-646",NULL},
/* 18A86 */ { "ÉLÉMENT TANGOUTE-647",NULL},
/* 18A87 */ { "ÉLÉMENT TANGOUTE-648",NULL},
/* 18A88 */ { "ÉLÉMENT TANGOUTE-649",NULL},
/* 18A89 */ { "ÉLÉMENT TANGOUTE-650",NULL},
/* 18A8A */ { "ÉLÉMENT TANGOUTE-651",NULL},
/* 18A8B */ { "ÉLÉMENT TANGOUTE-652",NULL},
/* 18A8C */ { "ÉLÉMENT TANGOUTE-653",NULL},
/* 18A8D */ { "ÉLÉMENT TANGOUTE-654",NULL},
/* 18A8E */ { "ÉLÉMENT TANGOUTE-655",NULL},
/* 18A8F */ { "ÉLÉMENT TANGOUTE-656",NULL},
/* 18A90 */ { "ÉLÉMENT TANGOUTE-657",NULL},
/* 18A91 */ { "ÉLÉMENT TANGOUTE-658",NULL},
/* 18A92 */ { "ÉLÉMENT TANGOUTE-659",NULL},
/* 18A93 */ { "ÉLÉMENT TANGOUTE-660",NULL},
/* 18A94 */ { "ÉLÉMENT TANGOUTE-661",NULL},
/* 18A95 */ { "ÉLÉMENT TANGOUTE-662",NULL},
/* 18A96 */ { "ÉLÉMENT TANGOUTE-663",NULL},
/* 18A97 */ { "ÉLÉMENT TANGOUTE-664",NULL},
/* 18A98 */ { "ÉLÉMENT TANGOUTE-665",NULL},
/* 18A99 */ { "ÉLÉMENT TANGOUTE-666",NULL},
/* 18A9A */ { "ÉLÉMENT TANGOUTE-667",NULL},
/* 18A9B */ { "ÉLÉMENT TANGOUTE-668",NULL},
/* 18A9C */ { "ÉLÉMENT TANGOUTE-669",NULL},
/* 18A9D */ { "ÉLÉMENT TANGOUTE-670",NULL},
/* 18A9E */ { "ÉLÉMENT TANGOUTE-671",NULL},
/* 18A9F */ { "ÉLÉMENT TANGOUTE-672",NULL},
/* 18AA0 */ { "ÉLÉMENT TANGOUTE-673",NULL},
/* 18AA1 */ { "ÉLÉMENT TANGOUTE-674",NULL},
/* 18AA2 */ { "ÉLÉMENT TANGOUTE-675",NULL},
/* 18AA3 */ { "ÉLÉMENT TANGOUTE-676",NULL},
/* 18AA4 */ { "ÉLÉMENT TANGOUTE-677",NULL},
/* 18AA5 */ { "ÉLÉMENT TANGOUTE-678",NULL},
/* 18AA6 */ { "ÉLÉMENT TANGOUTE-679",NULL},
/* 18AA7 */ { "ÉLÉMENT TANGOUTE-680",NULL},
/* 18AA8 */ { "ÉLÉMENT TANGOUTE-681",NULL},
/* 18AA9 */ { "ÉLÉMENT TANGOUTE-682",NULL},
/* 18AAA */ { "ÉLÉMENT TANGOUTE-683",NULL},
/* 18AAB */ { "ÉLÉMENT TANGOUTE-684",NULL},
/* 18AAC */ { "ÉLÉMENT TANGOUTE-685",NULL},
/* 18AAD */ { "ÉLÉMENT TANGOUTE-686",NULL},
/* 18AAE */ { "ÉLÉMENT TANGOUTE-687",NULL},
/* 18AAF */ { "ÉLÉMENT TANGOUTE-688",NULL},
/* 18AB0 */ { "ÉLÉMENT TANGOUTE-689",NULL},
/* 18AB1 */ { "ÉLÉMENT TANGOUTE-690",NULL},
/* 18AB2 */ { "ÉLÉMENT TANGOUTE-691",NULL},
/* 18AB3 */ { "ÉLÉMENT TANGOUTE-692",NULL},
/* 18AB4 */ { "ÉLÉMENT TANGOUTE-693",NULL},
/* 18AB5 */ { "ÉLÉMENT TANGOUTE-694",NULL},
/* 18AB6 */ { "ÉLÉMENT TANGOUTE-695",NULL},
/* 18AB7 */ { "ÉLÉMENT TANGOUTE-696",NULL},
/* 18AB8 */ { "ÉLÉMENT TANGOUTE-697",NULL},
/* 18AB9 */ { "ÉLÉMENT TANGOUTE-698",NULL},
/* 18ABA */ { "ÉLÉMENT TANGOUTE-699",NULL},
/* 18ABB */ { "ÉLÉMENT TANGOUTE-700",NULL},
/* 18ABC */ { "ÉLÉMENT TANGOUTE-701",NULL},
/* 18ABD */ { "ÉLÉMENT TANGOUTE-702",NULL},
/* 18ABE */ { "ÉLÉMENT TANGOUTE-703",NULL},
/* 18ABF */ { "ÉLÉMENT TANGOUTE-704",NULL},
/* 18AC0 */ { "ÉLÉMENT TANGOUTE-705",NULL},
/* 18AC1 */ { "ÉLÉMENT TANGOUTE-706",NULL},
/* 18AC2 */ { "ÉLÉMENT TANGOUTE-707",NULL},
/* 18AC3 */ { "ÉLÉMENT TANGOUTE-708",NULL},
/* 18AC4 */ { "ÉLÉMENT TANGOUTE-709",NULL},
/* 18AC5 */ { "ÉLÉMENT TANGOUTE-710",NULL},
/* 18AC6 */ { "ÉLÉMENT TANGOUTE-711",NULL},
/* 18AC7 */ { "ÉLÉMENT TANGOUTE-712",NULL},
/* 18AC8 */ { "ÉLÉMENT TANGOUTE-713",NULL},
/* 18AC9 */ { "ÉLÉMENT TANGOUTE-714",NULL},
/* 18ACA */ { "ÉLÉMENT TANGOUTE-715",NULL},
/* 18ACB */ { "ÉLÉMENT TANGOUTE-716",NULL},
/* 18ACC */ { "ÉLÉMENT TANGOUTE-717",NULL},
/* 18ACD */ { "ÉLÉMENT TANGOUTE-718",NULL},
/* 18ACE */ { "ÉLÉMENT TANGOUTE-719",NULL},
/* 18ACF */ { "ÉLÉMENT TANGOUTE-720",NULL},
/* 18AD0 */ { "ÉLÉMENT TANGOUTE-721",NULL},
/* 18AD1 */ { "ÉLÉMENT TANGOUTE-722",NULL},
/* 18AD2 */ { "ÉLÉMENT TANGOUTE-723",NULL},
/* 18AD3 */ { "ÉLÉMENT TANGOUTE-724",NULL},
/* 18AD4 */ { "ÉLÉMENT TANGOUTE-725",NULL},
/* 18AD5 */ { "ÉLÉMENT TANGOUTE-726",NULL},
/* 18AD6 */ { "ÉLÉMENT TANGOUTE-727",NULL},
/* 18AD7 */ { "ÉLÉMENT TANGOUTE-728",NULL},
/* 18AD8 */ { "ÉLÉMENT TANGOUTE-729",NULL},
/* 18AD9 */ { "ÉLÉMENT TANGOUTE-730",NULL},
/* 18ADA */ { "ÉLÉMENT TANGOUTE-731",NULL},
/* 18ADB */ { "ÉLÉMENT TANGOUTE-732",NULL},
/* 18ADC */ { "ÉLÉMENT TANGOUTE-733",NULL},
/* 18ADD */ { "ÉLÉMENT TANGOUTE-734",NULL},
/* 18ADE */ { "ÉLÉMENT TANGOUTE-735",NULL},
/* 18ADF */ { "ÉLÉMENT TANGOUTE-736",NULL},
/* 18AE0 */ { "ÉLÉMENT TANGOUTE-737",NULL},
/* 18AE1 */ { "ÉLÉMENT TANGOUTE-738",NULL},
/* 18AE2 */ { "ÉLÉMENT TANGOUTE-739",NULL},
/* 18AE3 */ { "ÉLÉMENT TANGOUTE-740",NULL},
/* 18AE4 */ { "ÉLÉMENT TANGOUTE-741",NULL},
/* 18AE5 */ { "ÉLÉMENT TANGOUTE-742",NULL},
/* 18AE6 */ { "ÉLÉMENT TANGOUTE-743",NULL},
/* 18AE7 */ { "ÉLÉMENT TANGOUTE-744",NULL},
/* 18AE8 */ { "ÉLÉMENT TANGOUTE-745",NULL},
/* 18AE9 */ { "ÉLÉMENT TANGOUTE-746",NULL},
/* 18AEA */ { "ÉLÉMENT TANGOUTE-747",NULL},
/* 18AEB */ { "ÉLÉMENT TANGOUTE-748",NULL},
/* 18AEC */ { "ÉLÉMENT TANGOUTE-749",NULL},
/* 18AED */ { "ÉLÉMENT TANGOUTE-750",NULL},
/* 18AEE */ { "ÉLÉMENT TANGOUTE-751",NULL},
/* 18AEF */ { "ÉLÉMENT TANGOUTE-752",NULL},
/* 18AF0 */ { "ÉLÉMENT TANGOUTE-753",NULL},
/* 18AF1 */ { "ÉLÉMENT TANGOUTE-754",NULL},
/* 18AF2 */ { "ÉLÉMENT TANGOUTE-755",NULL},
/* 18AF3 */ { "ÉLÉMENT TANGOUTE-756","	* deux traits"},
/* 18AF4 */ { "ÉLÉMENT TANGOUTE-757","	* huit traits"},
/* 18AF5 */ { "ÉLÉMENT TANGOUTE-758","	* sept traits"},
/* 18AF6 */ { "ÉLÉMENT TANGOUTE-759","	* huit traits"},
/* 18AF7 */ { "ÉLÉMENT TANGOUTE-760","	* six traits"},
/* 18AF8 */ { "ÉLÉMENT TANGOUTE-761","	* sept traits"},
/* 18AF9 */ { "ÉLÉMENT TANGOUTE-762","	* dix traits"},
/* 18AFA */ { "ÉLÉMENT TANGOUTE-763","	* deux traits"},
/* 18AFB */ { "ÉLÉMENT TANGOUTE-764","	* deux traits"},
/* 18AFC */ { "ÉLÉMENT TANGOUTE-765","	* trois traits"},
/* 18AFD */ { "ÉLÉMENT TANGOUTE-766","	* trois traits"},
/* 18AFE */ { "ÉLÉMENT TANGOUTE-767","	* quatre traits"},
/* 18AFF */ { "ÉLÉMENT TANGOUTE-768","	* quatre traits"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_8B[] = {
/* 18B00 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B00",NULL},
/* 18B01 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B01",NULL},
/* 18B02 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B02",NULL},
/* 18B03 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B03",NULL},
/* 18B04 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B04",NULL},
/* 18B05 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B05",NULL},
/* 18B06 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B06",NULL},
/* 18B07 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B07",NULL},
/* 18B08 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B08",NULL},
/* 18B09 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B09",NULL},
/* 18B0A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B0A",NULL},
/* 18B0B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B0B",NULL},
/* 18B0C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B0C",NULL},
/* 18B0D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B0D",NULL},
/* 18B0E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B0E",NULL},
/* 18B0F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B0F",NULL},
/* 18B10 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B10",NULL},
/* 18B11 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B11",NULL},
/* 18B12 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B12",NULL},
/* 18B13 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B13",NULL},
/* 18B14 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B14",NULL},
/* 18B15 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B15",NULL},
/* 18B16 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B16",NULL},
/* 18B17 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B17",NULL},
/* 18B18 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B18",NULL},
/* 18B19 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B19",NULL},
/* 18B1A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B1A",NULL},
/* 18B1B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B1B",NULL},
/* 18B1C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B1C",NULL},
/* 18B1D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B1D",NULL},
/* 18B1E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B1E",NULL},
/* 18B1F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B1F",NULL},
/* 18B20 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B20",NULL},
/* 18B21 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B21",NULL},
/* 18B22 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B22",NULL},
/* 18B23 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B23",NULL},
/* 18B24 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B24",NULL},
/* 18B25 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B25",NULL},
/* 18B26 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B26",NULL},
/* 18B27 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B27",NULL},
/* 18B28 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B28",NULL},
/* 18B29 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B29",NULL},
/* 18B2A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B2A",NULL},
/* 18B2B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B2B",NULL},
/* 18B2C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B2C",NULL},
/* 18B2D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B2D",NULL},
/* 18B2E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B2E",NULL},
/* 18B2F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B2F",NULL},
/* 18B30 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B30",NULL},
/* 18B31 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B31",NULL},
/* 18B32 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B32",NULL},
/* 18B33 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B33",NULL},
/* 18B34 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B34",NULL},
/* 18B35 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B35",NULL},
/* 18B36 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B36",NULL},
/* 18B37 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B37",NULL},
/* 18B38 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B38",NULL},
/* 18B39 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B39",NULL},
/* 18B3A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B3A",NULL},
/* 18B3B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B3B",NULL},
/* 18B3C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B3C",NULL},
/* 18B3D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B3D",NULL},
/* 18B3E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B3E",NULL},
/* 18B3F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B3F",NULL},
/* 18B40 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B40",NULL},
/* 18B41 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B41",NULL},
/* 18B42 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B42",NULL},
/* 18B43 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B43",NULL},
/* 18B44 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B44",NULL},
/* 18B45 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B45",NULL},
/* 18B46 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B46",NULL},
/* 18B47 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B47",NULL},
/* 18B48 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B48",NULL},
/* 18B49 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B49",NULL},
/* 18B4A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B4A",NULL},
/* 18B4B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B4B",NULL},
/* 18B4C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B4C",NULL},
/* 18B4D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B4D",NULL},
/* 18B4E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B4E",NULL},
/* 18B4F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B4F",NULL},
/* 18B50 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B50",NULL},
/* 18B51 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B51",NULL},
/* 18B52 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B52",NULL},
/* 18B53 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B53",NULL},
/* 18B54 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B54",NULL},
/* 18B55 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B55",NULL},
/* 18B56 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B56",NULL},
/* 18B57 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B57",NULL},
/* 18B58 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B58",NULL},
/* 18B59 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B59",NULL},
/* 18B5A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B5A",NULL},
/* 18B5B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B5B",NULL},
/* 18B5C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B5C",NULL},
/* 18B5D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B5D",NULL},
/* 18B5E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B5E",NULL},
/* 18B5F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B5F",NULL},
/* 18B60 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B60",NULL},
/* 18B61 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B61",NULL},
/* 18B62 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B62",NULL},
/* 18B63 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B63",NULL},
/* 18B64 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B64",NULL},
/* 18B65 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B65",NULL},
/* 18B66 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B66",NULL},
/* 18B67 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B67",NULL},
/* 18B68 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B68",NULL},
/* 18B69 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B69",NULL},
/* 18B6A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B6A",NULL},
/* 18B6B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B6B",NULL},
/* 18B6C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B6C",NULL},
/* 18B6D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B6D",NULL},
/* 18B6E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B6E",NULL},
/* 18B6F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B6F",NULL},
/* 18B70 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B70",NULL},
/* 18B71 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B71",NULL},
/* 18B72 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B72",NULL},
/* 18B73 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B73",NULL},
/* 18B74 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B74",NULL},
/* 18B75 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B75",NULL},
/* 18B76 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B76",NULL},
/* 18B77 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B77",NULL},
/* 18B78 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B78",NULL},
/* 18B79 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B79",NULL},
/* 18B7A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B7A",NULL},
/* 18B7B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B7B",NULL},
/* 18B7C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B7C",NULL},
/* 18B7D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B7D",NULL},
/* 18B7E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B7E",NULL},
/* 18B7F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B7F",NULL},
/* 18B80 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B80",NULL},
/* 18B81 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B81",NULL},
/* 18B82 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B82",NULL},
/* 18B83 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B83",NULL},
/* 18B84 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B84",NULL},
/* 18B85 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B85",NULL},
/* 18B86 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B86",NULL},
/* 18B87 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B87",NULL},
/* 18B88 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B88",NULL},
/* 18B89 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B89",NULL},
/* 18B8A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B8A",NULL},
/* 18B8B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B8B",NULL},
/* 18B8C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B8C",NULL},
/* 18B8D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B8D",NULL},
/* 18B8E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B8E",NULL},
/* 18B8F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B8F",NULL},
/* 18B90 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B90",NULL},
/* 18B91 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B91",NULL},
/* 18B92 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B92",NULL},
/* 18B93 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B93",NULL},
/* 18B94 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B94",NULL},
/* 18B95 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B95",NULL},
/* 18B96 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B96",NULL},
/* 18B97 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B97",NULL},
/* 18B98 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B98",NULL},
/* 18B99 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B99",NULL},
/* 18B9A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B9A",NULL},
/* 18B9B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B9B",NULL},
/* 18B9C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B9C",NULL},
/* 18B9D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B9D",NULL},
/* 18B9E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B9E",NULL},
/* 18B9F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18B9F",NULL},
/* 18BA0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA0",NULL},
/* 18BA1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA1",NULL},
/* 18BA2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA2",NULL},
/* 18BA3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA3",NULL},
/* 18BA4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA4",NULL},
/* 18BA5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA5",NULL},
/* 18BA6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA6",NULL},
/* 18BA7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA7",NULL},
/* 18BA8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA8",NULL},
/* 18BA9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BA9",NULL},
/* 18BAA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BAA",NULL},
/* 18BAB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BAB",NULL},
/* 18BAC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BAC",NULL},
/* 18BAD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BAD",NULL},
/* 18BAE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BAE",NULL},
/* 18BAF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BAF",NULL},
/* 18BB0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB0",NULL},
/* 18BB1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB1",NULL},
/* 18BB2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB2",NULL},
/* 18BB3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB3",NULL},
/* 18BB4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB4",NULL},
/* 18BB5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB5",NULL},
/* 18BB6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB6",NULL},
/* 18BB7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB7",NULL},
/* 18BB8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB8",NULL},
/* 18BB9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BB9",NULL},
/* 18BBA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BBA",NULL},
/* 18BBB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BBB",NULL},
/* 18BBC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BBC",NULL},
/* 18BBD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BBD",NULL},
/* 18BBE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BBE",NULL},
/* 18BBF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BBF",NULL},
/* 18BC0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC0",NULL},
/* 18BC1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC1",NULL},
/* 18BC2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC2",NULL},
/* 18BC3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC3",NULL},
/* 18BC4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC4",NULL},
/* 18BC5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC5",NULL},
/* 18BC6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC6",NULL},
/* 18BC7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC7",NULL},
/* 18BC8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC8",NULL},
/* 18BC9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BC9",NULL},
/* 18BCA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BCA",NULL},
/* 18BCB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BCB",NULL},
/* 18BCC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BCC",NULL},
/* 18BCD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BCD",NULL},
/* 18BCE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BCE",NULL},
/* 18BCF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BCF",NULL},
/* 18BD0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD0",NULL},
/* 18BD1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD1",NULL},
/* 18BD2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD2",NULL},
/* 18BD3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD3",NULL},
/* 18BD4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD4",NULL},
/* 18BD5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD5",NULL},
/* 18BD6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD6",NULL},
/* 18BD7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD7",NULL},
/* 18BD8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD8",NULL},
/* 18BD9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BD9",NULL},
/* 18BDA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BDA",NULL},
/* 18BDB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BDB",NULL},
/* 18BDC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BDC",NULL},
/* 18BDD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BDD",NULL},
/* 18BDE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BDE","	x (caractère petite écriture khitane-18cca - 18CCA)"},
/* 18BDF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BDF",NULL},
/* 18BE0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE0",NULL},
/* 18BE1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE1",NULL},
/* 18BE2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE2",NULL},
/* 18BE3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE3",NULL},
/* 18BE4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE4",NULL},
/* 18BE5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE5",NULL},
/* 18BE6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE6",NULL},
/* 18BE7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE7",NULL},
/* 18BE8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE8",NULL},
/* 18BE9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BE9",NULL},
/* 18BEA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BEA",NULL},
/* 18BEB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BEB",NULL},
/* 18BEC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BEC",NULL},
/* 18BED */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BED",NULL},
/* 18BEE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BEE",NULL},
/* 18BEF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BEF",NULL},
/* 18BF0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF0",NULL},
/* 18BF1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF1",NULL},
/* 18BF2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF2",NULL},
/* 18BF3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF3",NULL},
/* 18BF4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF4",NULL},
/* 18BF5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF5",NULL},
/* 18BF6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF6",NULL},
/* 18BF7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF7",NULL},
/* 18BF8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF8",NULL},
/* 18BF9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BF9",NULL},
/* 18BFA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BFA",NULL},
/* 18BFB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BFB",NULL},
/* 18BFC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BFC",NULL},
/* 18BFD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BFD",NULL},
/* 18BFE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BFE",NULL},
/* 18BFF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18BFF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_8C[] = {
/* 18C00 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C00",NULL},
/* 18C01 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C01",NULL},
/* 18C02 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C02",NULL},
/* 18C03 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C03",NULL},
/* 18C04 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C04",NULL},
/* 18C05 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C05",NULL},
/* 18C06 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C06",NULL},
/* 18C07 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C07",NULL},
/* 18C08 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C08",NULL},
/* 18C09 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C09",NULL},
/* 18C0A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C0A",NULL},
/* 18C0B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C0B",NULL},
/* 18C0C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C0C",NULL},
/* 18C0D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C0D",NULL},
/* 18C0E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C0E",NULL},
/* 18C0F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C0F",NULL},
/* 18C10 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C10",NULL},
/* 18C11 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C11",NULL},
/* 18C12 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C12",NULL},
/* 18C13 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C13",NULL},
/* 18C14 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C14",NULL},
/* 18C15 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C15",NULL},
/* 18C16 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C16",NULL},
/* 18C17 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C17",NULL},
/* 18C18 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C18",NULL},
/* 18C19 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C19",NULL},
/* 18C1A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C1A",NULL},
/* 18C1B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C1B",NULL},
/* 18C1C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C1C",NULL},
/* 18C1D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C1D",NULL},
/* 18C1E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C1E",NULL},
/* 18C1F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C1F",NULL},
/* 18C20 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C20",NULL},
/* 18C21 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C21",NULL},
/* 18C22 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C22",NULL},
/* 18C23 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C23",NULL},
/* 18C24 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C24",NULL},
/* 18C25 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C25",NULL},
/* 18C26 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C26",NULL},
/* 18C27 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C27",NULL},
/* 18C28 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C28",NULL},
/* 18C29 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C29",NULL},
/* 18C2A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C2A",NULL},
/* 18C2B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C2B",NULL},
/* 18C2C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C2C",NULL},
/* 18C2D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C2D",NULL},
/* 18C2E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C2E",NULL},
/* 18C2F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C2F",NULL},
/* 18C30 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C30",NULL},
/* 18C31 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C31",NULL},
/* 18C32 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C32",NULL},
/* 18C33 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C33",NULL},
/* 18C34 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C34",NULL},
/* 18C35 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C35",NULL},
/* 18C36 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C36",NULL},
/* 18C37 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C37",NULL},
/* 18C38 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C38",NULL},
/* 18C39 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C39",NULL},
/* 18C3A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C3A",NULL},
/* 18C3B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C3B",NULL},
/* 18C3C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C3C",NULL},
/* 18C3D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C3D",NULL},
/* 18C3E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C3E",NULL},
/* 18C3F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C3F",NULL},
/* 18C40 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C40",NULL},
/* 18C41 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C41",NULL},
/* 18C42 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C42",NULL},
/* 18C43 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C43",NULL},
/* 18C44 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C44",NULL},
/* 18C45 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C45",NULL},
/* 18C46 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C46",NULL},
/* 18C47 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C47",NULL},
/* 18C48 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C48",NULL},
/* 18C49 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C49",NULL},
/* 18C4A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C4A",NULL},
/* 18C4B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C4B",NULL},
/* 18C4C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C4C",NULL},
/* 18C4D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C4D",NULL},
/* 18C4E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C4E",NULL},
/* 18C4F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C4F",NULL},
/* 18C50 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C50",NULL},
/* 18C51 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C51",NULL},
/* 18C52 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C52",NULL},
/* 18C53 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C53",NULL},
/* 18C54 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C54",NULL},
/* 18C55 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C55",NULL},
/* 18C56 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C56",NULL},
/* 18C57 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C57",NULL},
/* 18C58 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C58",NULL},
/* 18C59 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C59",NULL},
/* 18C5A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C5A",NULL},
/* 18C5B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C5B",NULL},
/* 18C5C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C5C",NULL},
/* 18C5D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C5D",NULL},
/* 18C5E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C5E",NULL},
/* 18C5F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C5F",NULL},
/* 18C60 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C60",NULL},
/* 18C61 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C61",NULL},
/* 18C62 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C62",NULL},
/* 18C63 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C63",NULL},
/* 18C64 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C64",NULL},
/* 18C65 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C65",NULL},
/* 18C66 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C66",NULL},
/* 18C67 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C67",NULL},
/* 18C68 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C68",NULL},
/* 18C69 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C69",NULL},
/* 18C6A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C6A",NULL},
/* 18C6B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C6B",NULL},
/* 18C6C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C6C",NULL},
/* 18C6D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C6D",NULL},
/* 18C6E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C6E",NULL},
/* 18C6F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C6F",NULL},
/* 18C70 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C70",NULL},
/* 18C71 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C71",NULL},
/* 18C72 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C72",NULL},
/* 18C73 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C73",NULL},
/* 18C74 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C74",NULL},
/* 18C75 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C75",NULL},
/* 18C76 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C76",NULL},
/* 18C77 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C77",NULL},
/* 18C78 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C78",NULL},
/* 18C79 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C79",NULL},
/* 18C7A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C7A",NULL},
/* 18C7B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C7B",NULL},
/* 18C7C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C7C",NULL},
/* 18C7D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C7D",NULL},
/* 18C7E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C7E",NULL},
/* 18C7F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C7F",NULL},
/* 18C80 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C80",NULL},
/* 18C81 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C81",NULL},
/* 18C82 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C82",NULL},
/* 18C83 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C83",NULL},
/* 18C84 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C84",NULL},
/* 18C85 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C85",NULL},
/* 18C86 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C86",NULL},
/* 18C87 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C87",NULL},
/* 18C88 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C88",NULL},
/* 18C89 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C89",NULL},
/* 18C8A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C8A",NULL},
/* 18C8B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C8B",NULL},
/* 18C8C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C8C",NULL},
/* 18C8D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C8D",NULL},
/* 18C8E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C8E",NULL},
/* 18C8F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C8F",NULL},
/* 18C90 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C90",NULL},
/* 18C91 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C91",NULL},
/* 18C92 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C92",NULL},
/* 18C93 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C93",NULL},
/* 18C94 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C94",NULL},
/* 18C95 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C95",NULL},
/* 18C96 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C96",NULL},
/* 18C97 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C97",NULL},
/* 18C98 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C98",NULL},
/* 18C99 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C99",NULL},
/* 18C9A */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C9A",NULL},
/* 18C9B */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C9B",NULL},
/* 18C9C */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C9C",NULL},
/* 18C9D */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C9D",NULL},
/* 18C9E */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C9E",NULL},
/* 18C9F */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18C9F",NULL},
/* 18CA0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA0",NULL},
/* 18CA1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA1",NULL},
/* 18CA2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA2",NULL},
/* 18CA3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA3",NULL},
/* 18CA4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA4",NULL},
/* 18CA5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA5",NULL},
/* 18CA6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA6",NULL},
/* 18CA7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA7",NULL},
/* 18CA8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA8",NULL},
/* 18CA9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CA9",NULL},
/* 18CAA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CAA",NULL},
/* 18CAB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CAB",NULL},
/* 18CAC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CAC",NULL},
/* 18CAD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CAD",NULL},
/* 18CAE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CAE",NULL},
/* 18CAF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CAF",NULL},
/* 18CB0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB0",NULL},
/* 18CB1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB1",NULL},
/* 18CB2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB2",NULL},
/* 18CB3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB3",NULL},
/* 18CB4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB4",NULL},
/* 18CB5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB5",NULL},
/* 18CB6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB6",NULL},
/* 18CB7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB7",NULL},
/* 18CB8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB8",NULL},
/* 18CB9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CB9",NULL},
/* 18CBA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CBA",NULL},
/* 18CBB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CBB",NULL},
/* 18CBC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CBC",NULL},
/* 18CBD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CBD",NULL},
/* 18CBE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CBE",NULL},
/* 18CBF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CBF",NULL},
/* 18CC0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC0",NULL},
/* 18CC1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC1",NULL},
/* 18CC2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC2",NULL},
/* 18CC3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC3",NULL},
/* 18CC4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC4",NULL},
/* 18CC5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC5",NULL},
/* 18CC6 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC6",NULL},
/* 18CC7 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC7",NULL},
/* 18CC8 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC8",NULL},
/* 18CC9 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CC9",NULL},
/* 18CCA */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CCA","	x (caractère petite écriture khitane-18bde - 18BDE)"},
/* 18CCB */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CCB",NULL},
/* 18CCC */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CCC",NULL},
/* 18CCD */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CCD",NULL},
/* 18CCE */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CCE",NULL},
/* 18CCF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CCF",NULL},
/* 18CD0 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CD0",NULL},
/* 18CD1 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CD1",NULL},
/* 18CD2 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CD2",NULL},
/* 18CD3 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CD3",NULL},
/* 18CD4 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CD4",NULL},
/* 18CD5 */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CD5",NULL},
/* 18CD6 */ { NULL,NULL},
/* 18CD7 */ { NULL,NULL},
/* 18CD8 */ { NULL,NULL},
/* 18CD9 */ { NULL,NULL},
/* 18CDA */ { NULL,NULL},
/* 18CDB */ { NULL,NULL},
/* 18CDC */ { NULL,NULL},
/* 18CDD */ { NULL,NULL},
/* 18CDE */ { NULL,NULL},
/* 18CDF */ { NULL,NULL},
/* 18CE0 */ { NULL,NULL},
/* 18CE1 */ { NULL,NULL},
/* 18CE2 */ { NULL,NULL},
/* 18CE3 */ { NULL,NULL},
/* 18CE4 */ { NULL,NULL},
/* 18CE5 */ { NULL,NULL},
/* 18CE6 */ { NULL,NULL},
/* 18CE7 */ { NULL,NULL},
/* 18CE8 */ { NULL,NULL},
/* 18CE9 */ { NULL,NULL},
/* 18CEA */ { NULL,NULL},
/* 18CEB */ { NULL,NULL},
/* 18CEC */ { NULL,NULL},
/* 18CED */ { NULL,NULL},
/* 18CEE */ { NULL,NULL},
/* 18CEF */ { NULL,NULL},
/* 18CF0 */ { NULL,NULL},
/* 18CF1 */ { NULL,NULL},
/* 18CF2 */ { NULL,NULL},
/* 18CF3 */ { NULL,NULL},
/* 18CF4 */ { NULL,NULL},
/* 18CF5 */ { NULL,NULL},
/* 18CF6 */ { NULL,NULL},
/* 18CF7 */ { NULL,NULL},
/* 18CF8 */ { NULL,NULL},
/* 18CF9 */ { NULL,NULL},
/* 18CFA */ { NULL,NULL},
/* 18CFB */ { NULL,NULL},
/* 18CFC */ { NULL,NULL},
/* 18CFD */ { NULL,NULL},
/* 18CFE */ { NULL,NULL},
/* 18CFF */ { "CARACTÈRE PETITE ÉCRITURE KHITANE-18CFF","	* représente un caractère disparu ou illisible"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_8D[] = {
/* 18D00 */ { NULL,NULL},
/* 18D01 */ { NULL,NULL},
/* 18D02 */ { NULL,NULL},
/* 18D03 */ { NULL,NULL},
/* 18D04 */ { NULL,NULL},
/* 18D05 */ { NULL,NULL},
/* 18D06 */ { NULL,NULL},
/* 18D07 */ { NULL,NULL},
/* 18D08 */ { NULL,NULL},
/* 18D09 */ { NULL,NULL},
/* 18D0A */ { NULL,NULL},
/* 18D0B */ { NULL,NULL},
/* 18D0C */ { NULL,NULL},
/* 18D0D */ { NULL,NULL},
/* 18D0E */ { NULL,NULL},
/* 18D0F */ { NULL,NULL},
/* 18D10 */ { NULL,NULL},
/* 18D11 */ { NULL,NULL},
/* 18D12 */ { NULL,NULL},
/* 18D13 */ { NULL,NULL},
/* 18D14 */ { NULL,NULL},
/* 18D15 */ { NULL,NULL},
/* 18D16 */ { NULL,NULL},
/* 18D17 */ { NULL,NULL},
/* 18D18 */ { NULL,NULL},
/* 18D19 */ { NULL,NULL},
/* 18D1A */ { NULL,NULL},
/* 18D1B */ { NULL,NULL},
/* 18D1C */ { NULL,NULL},
/* 18D1D */ { NULL,NULL},
/* 18D1E */ { NULL,NULL},
/* 18D1F */ { NULL,NULL},
/* 18D20 */ { NULL,NULL},
/* 18D21 */ { NULL,NULL},
/* 18D22 */ { NULL,NULL},
/* 18D23 */ { NULL,NULL},
/* 18D24 */ { NULL,NULL},
/* 18D25 */ { NULL,NULL},
/* 18D26 */ { NULL,NULL},
/* 18D27 */ { NULL,NULL},
/* 18D28 */ { NULL,NULL},
/* 18D29 */ { NULL,NULL},
/* 18D2A */ { NULL,NULL},
/* 18D2B */ { NULL,NULL},
/* 18D2C */ { NULL,NULL},
/* 18D2D */ { NULL,NULL},
/* 18D2E */ { NULL,NULL},
/* 18D2F */ { NULL,NULL},
/* 18D30 */ { NULL,NULL},
/* 18D31 */ { NULL,NULL},
/* 18D32 */ { NULL,NULL},
/* 18D33 */ { NULL,NULL},
/* 18D34 */ { NULL,NULL},
/* 18D35 */ { NULL,NULL},
/* 18D36 */ { NULL,NULL},
/* 18D37 */ { NULL,NULL},
/* 18D38 */ { NULL,NULL},
/* 18D39 */ { NULL,NULL},
/* 18D3A */ { NULL,NULL},
/* 18D3B */ { NULL,NULL},
/* 18D3C */ { NULL,NULL},
/* 18D3D */ { NULL,NULL},
/* 18D3E */ { NULL,NULL},
/* 18D3F */ { NULL,NULL},
/* 18D40 */ { NULL,NULL},
/* 18D41 */ { NULL,NULL},
/* 18D42 */ { NULL,NULL},
/* 18D43 */ { NULL,NULL},
/* 18D44 */ { NULL,NULL},
/* 18D45 */ { NULL,NULL},
/* 18D46 */ { NULL,NULL},
/* 18D47 */ { NULL,NULL},
/* 18D48 */ { NULL,NULL},
/* 18D49 */ { NULL,NULL},
/* 18D4A */ { NULL,NULL},
/* 18D4B */ { NULL,NULL},
/* 18D4C */ { NULL,NULL},
/* 18D4D */ { NULL,NULL},
/* 18D4E */ { NULL,NULL},
/* 18D4F */ { NULL,NULL},
/* 18D50 */ { NULL,NULL},
/* 18D51 */ { NULL,NULL},
/* 18D52 */ { NULL,NULL},
/* 18D53 */ { NULL,NULL},
/* 18D54 */ { NULL,NULL},
/* 18D55 */ { NULL,NULL},
/* 18D56 */ { NULL,NULL},
/* 18D57 */ { NULL,NULL},
/* 18D58 */ { NULL,NULL},
/* 18D59 */ { NULL,NULL},
/* 18D5A */ { NULL,NULL},
/* 18D5B */ { NULL,NULL},
/* 18D5C */ { NULL,NULL},
/* 18D5D */ { NULL,NULL},
/* 18D5E */ { NULL,NULL},
/* 18D5F */ { NULL,NULL},
/* 18D60 */ { NULL,NULL},
/* 18D61 */ { NULL,NULL},
/* 18D62 */ { NULL,NULL},
/* 18D63 */ { NULL,NULL},
/* 18D64 */ { NULL,NULL},
/* 18D65 */ { NULL,NULL},
/* 18D66 */ { NULL,NULL},
/* 18D67 */ { NULL,NULL},
/* 18D68 */ { NULL,NULL},
/* 18D69 */ { NULL,NULL},
/* 18D6A */ { NULL,NULL},
/* 18D6B */ { NULL,NULL},
/* 18D6C */ { NULL,NULL},
/* 18D6D */ { NULL,NULL},
/* 18D6E */ { NULL,NULL},
/* 18D6F */ { NULL,NULL},
/* 18D70 */ { NULL,NULL},
/* 18D71 */ { NULL,NULL},
/* 18D72 */ { NULL,NULL},
/* 18D73 */ { NULL,NULL},
/* 18D74 */ { NULL,NULL},
/* 18D75 */ { NULL,NULL},
/* 18D76 */ { NULL,NULL},
/* 18D77 */ { NULL,NULL},
/* 18D78 */ { NULL,NULL},
/* 18D79 */ { NULL,NULL},
/* 18D7A */ { NULL,NULL},
/* 18D7B */ { NULL,NULL},
/* 18D7C */ { NULL,NULL},
/* 18D7D */ { NULL,NULL},
/* 18D7E */ { NULL,NULL},
/* 18D7F */ { NULL,NULL},
/* 18D80 */ { "ÉLÉMENT TANGOUTE-769","	* sept traits"},
/* 18D81 */ { "ÉLÉMENT TANGOUTE-770","	* trois traits"},
/* 18D82 */ { "ÉLÉMENT TANGOUTE-771",NULL},
/* 18D83 */ { "ÉLÉMENT TANGOUTE-772",NULL},
/* 18D84 */ { "ÉLÉMENT TANGOUTE-773",NULL},
/* 18D85 */ { "ÉLÉMENT TANGOUTE-774",NULL},
/* 18D86 */ { "ÉLÉMENT TANGOUTE-775",NULL},
/* 18D87 */ { "ÉLÉMENT TANGOUTE-776",NULL},
/* 18D88 */ { "ÉLÉMENT TANGOUTE-777",NULL},
/* 18D89 */ { "ÉLÉMENT TANGOUTE-778",NULL},
/* 18D8A */ { "ÉLÉMENT TANGOUTE-779",NULL},
/* 18D8B */ { "ÉLÉMENT TANGOUTE-780",NULL},
/* 18D8C */ { "ÉLÉMENT TANGOUTE-781",NULL},
/* 18D8D */ { "ÉLÉMENT TANGOUTE-782",NULL},
/* 18D8E */ { "ÉLÉMENT TANGOUTE-783",NULL},
/* 18D8F */ { "ÉLÉMENT TANGOUTE-784",NULL},
/* 18D90 */ { "ÉLÉMENT TANGOUTE-785",NULL},
/* 18D91 */ { "ÉLÉMENT TANGOUTE-786",NULL},
/* 18D92 */ { "ÉLÉMENT TANGOUTE-787",NULL},
/* 18D93 */ { "ÉLÉMENT TANGOUTE-788",NULL},
/* 18D94 */ { "ÉLÉMENT TANGOUTE-789",NULL},
/* 18D95 */ { "ÉLÉMENT TANGOUTE-790",NULL},
/* 18D96 */ { "ÉLÉMENT TANGOUTE-791",NULL},
/* 18D97 */ { "ÉLÉMENT TANGOUTE-792",NULL},
/* 18D98 */ { "ÉLÉMENT TANGOUTE-793",NULL},
/* 18D99 */ { "ÉLÉMENT TANGOUTE-794",NULL},
/* 18D9A */ { "ÉLÉMENT TANGOUTE-795",NULL},
/* 18D9B */ { "ÉLÉMENT TANGOUTE-796",NULL},
/* 18D9C */ { "ÉLÉMENT TANGOUTE-797",NULL},
/* 18D9D */ { "ÉLÉMENT TANGOUTE-798",NULL},
/* 18D9E */ { "ÉLÉMENT TANGOUTE-799",NULL},
/* 18D9F */ { "ÉLÉMENT TANGOUTE-800",NULL},
/* 18DA0 */ { "ÉLÉMENT TANGOUTE-801",NULL},
/* 18DA1 */ { "ÉLÉMENT TANGOUTE-802",NULL},
/* 18DA2 */ { "ÉLÉMENT TANGOUTE-803",NULL},
/* 18DA3 */ { "ÉLÉMENT TANGOUTE-804",NULL},
/* 18DA4 */ { "ÉLÉMENT TANGOUTE-805",NULL},
/* 18DA5 */ { "ÉLÉMENT TANGOUTE-806",NULL},
/* 18DA6 */ { "ÉLÉMENT TANGOUTE-807",NULL},
/* 18DA7 */ { "ÉLÉMENT TANGOUTE-808",NULL},
/* 18DA8 */ { "ÉLÉMENT TANGOUTE-809",NULL},
/* 18DA9 */ { "ÉLÉMENT TANGOUTE-810",NULL},
/* 18DAA */ { "ÉLÉMENT TANGOUTE-811",NULL},
/* 18DAB */ { "ÉLÉMENT TANGOUTE-812",NULL},
/* 18DAC */ { "ÉLÉMENT TANGOUTE-813",NULL},
/* 18DAD */ { "ÉLÉMENT TANGOUTE-814",NULL},
/* 18DAE */ { "ÉLÉMENT TANGOUTE-815",NULL},
/* 18DAF */ { "ÉLÉMENT TANGOUTE-816",NULL},
/* 18DB0 */ { "ÉLÉMENT TANGOUTE-817",NULL},
/* 18DB1 */ { "ÉLÉMENT TANGOUTE-818",NULL},
/* 18DB2 */ { "ÉLÉMENT TANGOUTE-819",NULL},
/* 18DB3 */ { "ÉLÉMENT TANGOUTE-820",NULL},
/* 18DB4 */ { "ÉLÉMENT TANGOUTE-821",NULL},
/* 18DB5 */ { "ÉLÉMENT TANGOUTE-822",NULL},
/* 18DB6 */ { "ÉLÉMENT TANGOUTE-823",NULL},
/* 18DB7 */ { "ÉLÉMENT TANGOUTE-824",NULL},
/* 18DB8 */ { "ÉLÉMENT TANGOUTE-825",NULL},
/* 18DB9 */ { "ÉLÉMENT TANGOUTE-826",NULL},
/* 18DBA */ { "ÉLÉMENT TANGOUTE-827",NULL},
/* 18DBB */ { "ÉLÉMENT TANGOUTE-828",NULL},
/* 18DBC */ { "ÉLÉMENT TANGOUTE-829",NULL},
/* 18DBD */ { "ÉLÉMENT TANGOUTE-830",NULL},
/* 18DBE */ { "ÉLÉMENT TANGOUTE-831",NULL},
/* 18DBF */ { "ÉLÉMENT TANGOUTE-832",NULL},
/* 18DC0 */ { "ÉLÉMENT TANGOUTE-833",NULL},
/* 18DC1 */ { "ÉLÉMENT TANGOUTE-834",NULL},
/* 18DC2 */ { "ÉLÉMENT TANGOUTE-835",NULL},
/* 18DC3 */ { "ÉLÉMENT TANGOUTE-836",NULL},
/* 18DC4 */ { "ÉLÉMENT TANGOUTE-837",NULL},
/* 18DC5 */ { "ÉLÉMENT TANGOUTE-838",NULL},
/* 18DC6 */ { "ÉLÉMENT TANGOUTE-839",NULL},
/* 18DC7 */ { "ÉLÉMENT TANGOUTE-840",NULL},
/* 18DC8 */ { "ÉLÉMENT TANGOUTE-841",NULL},
/* 18DC9 */ { "ÉLÉMENT TANGOUTE-842",NULL},
/* 18DCA */ { "ÉLÉMENT TANGOUTE-843",NULL},
/* 18DCB */ { "ÉLÉMENT TANGOUTE-844",NULL},
/* 18DCC */ { "ÉLÉMENT TANGOUTE-845",NULL},
/* 18DCD */ { "ÉLÉMENT TANGOUTE-846",NULL},
/* 18DCE */ { "ÉLÉMENT TANGOUTE-847",NULL},
/* 18DCF */ { "ÉLÉMENT TANGOUTE-848",NULL},
/* 18DD0 */ { "ÉLÉMENT TANGOUTE-849",NULL},
/* 18DD1 */ { "ÉLÉMENT TANGOUTE-850",NULL},
/* 18DD2 */ { "ÉLÉMENT TANGOUTE-851",NULL},
/* 18DD3 */ { "ÉLÉMENT TANGOUTE-852",NULL},
/* 18DD4 */ { "ÉLÉMENT TANGOUTE-853",NULL},
/* 18DD5 */ { "ÉLÉMENT TANGOUTE-854",NULL},
/* 18DD6 */ { "ÉLÉMENT TANGOUTE-855",NULL},
/* 18DD7 */ { "ÉLÉMENT TANGOUTE-856",NULL},
/* 18DD8 */ { "ÉLÉMENT TANGOUTE-857",NULL},
/* 18DD9 */ { "ÉLÉMENT TANGOUTE-858",NULL},
/* 18DDA */ { "ÉLÉMENT TANGOUTE-859",NULL},
/* 18DDB */ { "ÉLÉMENT TANGOUTE-860",NULL},
/* 18DDC */ { "ÉLÉMENT TANGOUTE-861",NULL},
/* 18DDD */ { "ÉLÉMENT TANGOUTE-862",NULL},
/* 18DDE */ { "ÉLÉMENT TANGOUTE-863",NULL},
/* 18DDF */ { "ÉLÉMENT TANGOUTE-864",NULL},
/* 18DE0 */ { "ÉLÉMENT TANGOUTE-865",NULL},
/* 18DE1 */ { "ÉLÉMENT TANGOUTE-866",NULL},
/* 18DE2 */ { "ÉLÉMENT TANGOUTE-867",NULL},
/* 18DE3 */ { "ÉLÉMENT TANGOUTE-868",NULL},
/* 18DE4 */ { "ÉLÉMENT TANGOUTE-869",NULL},
/* 18DE5 */ { "ÉLÉMENT TANGOUTE-870",NULL},
/* 18DE6 */ { "ÉLÉMENT TANGOUTE-871",NULL},
/* 18DE7 */ { "ÉLÉMENT TANGOUTE-872",NULL},
/* 18DE8 */ { "ÉLÉMENT TANGOUTE-873",NULL},
/* 18DE9 */ { "ÉLÉMENT TANGOUTE-874",NULL},
/* 18DEA */ { "ÉLÉMENT TANGOUTE-875",NULL},
/* 18DEB */ { "ÉLÉMENT TANGOUTE-876",NULL},
/* 18DEC */ { "ÉLÉMENT TANGOUTE-877",NULL},
/* 18DED */ { "ÉLÉMENT TANGOUTE-878",NULL},
/* 18DEE */ { "ÉLÉMENT TANGOUTE-879",NULL},
/* 18DEF */ { "ÉLÉMENT TANGOUTE-880",NULL},
/* 18DF0 */ { "ÉLÉMENT TANGOUTE-881",NULL},
/* 18DF1 */ { "ÉLÉMENT TANGOUTE-882",NULL},
/* 18DF2 */ { "ÉLÉMENT TANGOUTE-883",NULL},
/* 18DF3 */ { NULL,NULL},
/* 18DF4 */ { NULL,NULL},
/* 18DF5 */ { NULL,NULL},
/* 18DF6 */ { NULL,NULL},
/* 18DF7 */ { NULL,NULL},
/* 18DF8 */ { NULL,NULL},
/* 18DF9 */ { NULL,NULL},
/* 18DFA */ { NULL,NULL},
/* 18DFB */ { NULL,NULL},
/* 18DFC */ { NULL,NULL},
/* 18DFD */ { NULL,NULL},
/* 18DFE */ { NULL,NULL},
/* 18DFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_AF[] = {
/* 1AF00 */ { NULL,NULL},
/* 1AF01 */ { NULL,NULL},
/* 1AF02 */ { NULL,NULL},
/* 1AF03 */ { NULL,NULL},
/* 1AF04 */ { NULL,NULL},
/* 1AF05 */ { NULL,NULL},
/* 1AF06 */ { NULL,NULL},
/* 1AF07 */ { NULL,NULL},
/* 1AF08 */ { NULL,NULL},
/* 1AF09 */ { NULL,NULL},
/* 1AF0A */ { NULL,NULL},
/* 1AF0B */ { NULL,NULL},
/* 1AF0C */ { NULL,NULL},
/* 1AF0D */ { NULL,NULL},
/* 1AF0E */ { NULL,NULL},
/* 1AF0F */ { NULL,NULL},
/* 1AF10 */ { NULL,NULL},
/* 1AF11 */ { NULL,NULL},
/* 1AF12 */ { NULL,NULL},
/* 1AF13 */ { NULL,NULL},
/* 1AF14 */ { NULL,NULL},
/* 1AF15 */ { NULL,NULL},
/* 1AF16 */ { NULL,NULL},
/* 1AF17 */ { NULL,NULL},
/* 1AF18 */ { NULL,NULL},
/* 1AF19 */ { NULL,NULL},
/* 1AF1A */ { NULL,NULL},
/* 1AF1B */ { NULL,NULL},
/* 1AF1C */ { NULL,NULL},
/* 1AF1D */ { NULL,NULL},
/* 1AF1E */ { NULL,NULL},
/* 1AF1F */ { NULL,NULL},
/* 1AF20 */ { NULL,NULL},
/* 1AF21 */ { NULL,NULL},
/* 1AF22 */ { NULL,NULL},
/* 1AF23 */ { NULL,NULL},
/* 1AF24 */ { NULL,NULL},
/* 1AF25 */ { NULL,NULL},
/* 1AF26 */ { NULL,NULL},
/* 1AF27 */ { NULL,NULL},
/* 1AF28 */ { NULL,NULL},
/* 1AF29 */ { NULL,NULL},
/* 1AF2A */ { NULL,NULL},
/* 1AF2B */ { NULL,NULL},
/* 1AF2C */ { NULL,NULL},
/* 1AF2D */ { NULL,NULL},
/* 1AF2E */ { NULL,NULL},
/* 1AF2F */ { NULL,NULL},
/* 1AF30 */ { NULL,NULL},
/* 1AF31 */ { NULL,NULL},
/* 1AF32 */ { NULL,NULL},
/* 1AF33 */ { NULL,NULL},
/* 1AF34 */ { NULL,NULL},
/* 1AF35 */ { NULL,NULL},
/* 1AF36 */ { NULL,NULL},
/* 1AF37 */ { NULL,NULL},
/* 1AF38 */ { NULL,NULL},
/* 1AF39 */ { NULL,NULL},
/* 1AF3A */ { NULL,NULL},
/* 1AF3B */ { NULL,NULL},
/* 1AF3C */ { NULL,NULL},
/* 1AF3D */ { NULL,NULL},
/* 1AF3E */ { NULL,NULL},
/* 1AF3F */ { NULL,NULL},
/* 1AF40 */ { NULL,NULL},
/* 1AF41 */ { NULL,NULL},
/* 1AF42 */ { NULL,NULL},
/* 1AF43 */ { NULL,NULL},
/* 1AF44 */ { NULL,NULL},
/* 1AF45 */ { NULL,NULL},
/* 1AF46 */ { NULL,NULL},
/* 1AF47 */ { NULL,NULL},
/* 1AF48 */ { NULL,NULL},
/* 1AF49 */ { NULL,NULL},
/* 1AF4A */ { NULL,NULL},
/* 1AF4B */ { NULL,NULL},
/* 1AF4C */ { NULL,NULL},
/* 1AF4D */ { NULL,NULL},
/* 1AF4E */ { NULL,NULL},
/* 1AF4F */ { NULL,NULL},
/* 1AF50 */ { NULL,NULL},
/* 1AF51 */ { NULL,NULL},
/* 1AF52 */ { NULL,NULL},
/* 1AF53 */ { NULL,NULL},
/* 1AF54 */ { NULL,NULL},
/* 1AF55 */ { NULL,NULL},
/* 1AF56 */ { NULL,NULL},
/* 1AF57 */ { NULL,NULL},
/* 1AF58 */ { NULL,NULL},
/* 1AF59 */ { NULL,NULL},
/* 1AF5A */ { NULL,NULL},
/* 1AF5B */ { NULL,NULL},
/* 1AF5C */ { NULL,NULL},
/* 1AF5D */ { NULL,NULL},
/* 1AF5E */ { NULL,NULL},
/* 1AF5F */ { NULL,NULL},
/* 1AF60 */ { NULL,NULL},
/* 1AF61 */ { NULL,NULL},
/* 1AF62 */ { NULL,NULL},
/* 1AF63 */ { NULL,NULL},
/* 1AF64 */ { NULL,NULL},
/* 1AF65 */ { NULL,NULL},
/* 1AF66 */ { NULL,NULL},
/* 1AF67 */ { NULL,NULL},
/* 1AF68 */ { NULL,NULL},
/* 1AF69 */ { NULL,NULL},
/* 1AF6A */ { NULL,NULL},
/* 1AF6B */ { NULL,NULL},
/* 1AF6C */ { NULL,NULL},
/* 1AF6D */ { NULL,NULL},
/* 1AF6E */ { NULL,NULL},
/* 1AF6F */ { NULL,NULL},
/* 1AF70 */ { NULL,NULL},
/* 1AF71 */ { NULL,NULL},
/* 1AF72 */ { NULL,NULL},
/* 1AF73 */ { NULL,NULL},
/* 1AF74 */ { NULL,NULL},
/* 1AF75 */ { NULL,NULL},
/* 1AF76 */ { NULL,NULL},
/* 1AF77 */ { NULL,NULL},
/* 1AF78 */ { NULL,NULL},
/* 1AF79 */ { NULL,NULL},
/* 1AF7A */ { NULL,NULL},
/* 1AF7B */ { NULL,NULL},
/* 1AF7C */ { NULL,NULL},
/* 1AF7D */ { NULL,NULL},
/* 1AF7E */ { NULL,NULL},
/* 1AF7F */ { NULL,NULL},
/* 1AF80 */ { NULL,NULL},
/* 1AF81 */ { NULL,NULL},
/* 1AF82 */ { NULL,NULL},
/* 1AF83 */ { NULL,NULL},
/* 1AF84 */ { NULL,NULL},
/* 1AF85 */ { NULL,NULL},
/* 1AF86 */ { NULL,NULL},
/* 1AF87 */ { NULL,NULL},
/* 1AF88 */ { NULL,NULL},
/* 1AF89 */ { NULL,NULL},
/* 1AF8A */ { NULL,NULL},
/* 1AF8B */ { NULL,NULL},
/* 1AF8C */ { NULL,NULL},
/* 1AF8D */ { NULL,NULL},
/* 1AF8E */ { NULL,NULL},
/* 1AF8F */ { NULL,NULL},
/* 1AF90 */ { NULL,NULL},
/* 1AF91 */ { NULL,NULL},
/* 1AF92 */ { NULL,NULL},
/* 1AF93 */ { NULL,NULL},
/* 1AF94 */ { NULL,NULL},
/* 1AF95 */ { NULL,NULL},
/* 1AF96 */ { NULL,NULL},
/* 1AF97 */ { NULL,NULL},
/* 1AF98 */ { NULL,NULL},
/* 1AF99 */ { NULL,NULL},
/* 1AF9A */ { NULL,NULL},
/* 1AF9B */ { NULL,NULL},
/* 1AF9C */ { NULL,NULL},
/* 1AF9D */ { NULL,NULL},
/* 1AF9E */ { NULL,NULL},
/* 1AF9F */ { NULL,NULL},
/* 1AFA0 */ { NULL,NULL},
/* 1AFA1 */ { NULL,NULL},
/* 1AFA2 */ { NULL,NULL},
/* 1AFA3 */ { NULL,NULL},
/* 1AFA4 */ { NULL,NULL},
/* 1AFA5 */ { NULL,NULL},
/* 1AFA6 */ { NULL,NULL},
/* 1AFA7 */ { NULL,NULL},
/* 1AFA8 */ { NULL,NULL},
/* 1AFA9 */ { NULL,NULL},
/* 1AFAA */ { NULL,NULL},
/* 1AFAB */ { NULL,NULL},
/* 1AFAC */ { NULL,NULL},
/* 1AFAD */ { NULL,NULL},
/* 1AFAE */ { NULL,NULL},
/* 1AFAF */ { NULL,NULL},
/* 1AFB0 */ { NULL,NULL},
/* 1AFB1 */ { NULL,NULL},
/* 1AFB2 */ { NULL,NULL},
/* 1AFB3 */ { NULL,NULL},
/* 1AFB4 */ { NULL,NULL},
/* 1AFB5 */ { NULL,NULL},
/* 1AFB6 */ { NULL,NULL},
/* 1AFB7 */ { NULL,NULL},
/* 1AFB8 */ { NULL,NULL},
/* 1AFB9 */ { NULL,NULL},
/* 1AFBA */ { NULL,NULL},
/* 1AFBB */ { NULL,NULL},
/* 1AFBC */ { NULL,NULL},
/* 1AFBD */ { NULL,NULL},
/* 1AFBE */ { NULL,NULL},
/* 1AFBF */ { NULL,NULL},
/* 1AFC0 */ { NULL,NULL},
/* 1AFC1 */ { NULL,NULL},
/* 1AFC2 */ { NULL,NULL},
/* 1AFC3 */ { NULL,NULL},
/* 1AFC4 */ { NULL,NULL},
/* 1AFC5 */ { NULL,NULL},
/* 1AFC6 */ { NULL,NULL},
/* 1AFC7 */ { NULL,NULL},
/* 1AFC8 */ { NULL,NULL},
/* 1AFC9 */ { NULL,NULL},
/* 1AFCA */ { NULL,NULL},
/* 1AFCB */ { NULL,NULL},
/* 1AFCC */ { NULL,NULL},
/* 1AFCD */ { NULL,NULL},
/* 1AFCE */ { NULL,NULL},
/* 1AFCF */ { NULL,NULL},
/* 1AFD0 */ { NULL,NULL},
/* 1AFD1 */ { NULL,NULL},
/* 1AFD2 */ { NULL,NULL},
/* 1AFD3 */ { NULL,NULL},
/* 1AFD4 */ { NULL,NULL},
/* 1AFD5 */ { NULL,NULL},
/* 1AFD6 */ { NULL,NULL},
/* 1AFD7 */ { NULL,NULL},
/* 1AFD8 */ { NULL,NULL},
/* 1AFD9 */ { NULL,NULL},
/* 1AFDA */ { NULL,NULL},
/* 1AFDB */ { NULL,NULL},
/* 1AFDC */ { NULL,NULL},
/* 1AFDD */ { NULL,NULL},
/* 1AFDE */ { NULL,NULL},
/* 1AFDF */ { NULL,NULL},
/* 1AFE0 */ { NULL,NULL},
/* 1AFE1 */ { NULL,NULL},
/* 1AFE2 */ { NULL,NULL},
/* 1AFE3 */ { NULL,NULL},
/* 1AFE4 */ { NULL,NULL},
/* 1AFE5 */ { NULL,NULL},
/* 1AFE6 */ { NULL,NULL},
/* 1AFE7 */ { NULL,NULL},
/* 1AFE8 */ { NULL,NULL},
/* 1AFE9 */ { NULL,NULL},
/* 1AFEA */ { NULL,NULL},
/* 1AFEB */ { NULL,NULL},
/* 1AFEC */ { NULL,NULL},
/* 1AFED */ { NULL,NULL},
/* 1AFEE */ { NULL,NULL},
/* 1AFEF */ { NULL,NULL},
/* 1AFF0 */ { "CARACTÈRE KATAKANA TON-2 MINNAN",NULL},
/* 1AFF1 */ { "CARACTÈRE KATAKANA TON-3 MINNAN",NULL},
/* 1AFF2 */ { "CARACTÈRE KATAKANA TON-4 MINNAN",NULL},
/* 1AFF3 */ { "CARACTÈRE KATAKANA TON-5 MINNAN",NULL},
/* 1AFF4 */ { NULL,NULL},
/* 1AFF5 */ { "CARACTÈRE KATAKANA TON-7 MINNAN",NULL},
/* 1AFF6 */ { "CARACTÈRE KATAKANA TON-8 MINNAN",NULL},
/* 1AFF7 */ { "CARACTÈRE KATAKANA TON-1 NASALISÉ MINNAN",NULL},
/* 1AFF8 */ { "CARACTÈRE KATAKANA TON-2 NASALISÉ MINNAN",NULL},
/* 1AFF9 */ { "CARACTÈRE KATAKANA TON-3 NASALISÉ MINNAN",NULL},
/* 1AFFA */ { "CARACTÈRE KATAKANA TON-4 NASALISÉ MINNAN",NULL},
/* 1AFFB */ { "CARACTÈRE KATAKANA TON-5 NASALISÉ MINNAN",NULL},
/* 1AFFC */ { NULL,NULL},
/* 1AFFD */ { "CARACTÈRE KATAKANA TON-7 NASALISÉ MINNAN",NULL},
/* 1AFFE */ { "CARACTÈRE KATAKANA TON-8 NASALISÉ MINNAN",NULL},
/* 1AFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_B0[] = {
/* 1B000 */ { "CARACTÈRE KATAKANA E ARCHAÏQUE",NULL},
/* 1B001 */ { "CARACTÈRE HENTAIGANA E-1","	* le nom formel de ce caractère en anglais est erroné\n"
	"	* dérivé de 6C5F"},
/* 1B002 */ { "CARACTÈRE HENTAIGANA A-1","	* dérivé de 5B89"},
/* 1B003 */ { "CARACTÈRE HENTAIGANA A-2","	* dérivé de 611B"},
/* 1B004 */ { "CARACTÈRE HENTAIGANA A-3","	* dérivé de 963F"},
/* 1B005 */ { "CARACTÈRE HENTAIGANA A-WO","	* dérivé de 60E1"},
/* 1B006 */ { "CARACTÈRE HENTAIGANA I-1","	* dérivé de 4EE5"},
/* 1B007 */ { "CARACTÈRE HENTAIGANA I-2","	* dérivé de 4F0A"},
/* 1B008 */ { "CARACTÈRE HENTAIGANA I-3","	* dérivé de 610F"},
/* 1B009 */ { "CARACTÈRE HENTAIGANA I-4","	* dérivé de 79FB"},
/* 1B00A */ { "CARACTÈRE HENTAIGANA U-1","	* dérivé de 5B87"},
/* 1B00B */ { "CARACTÈRE HENTAIGANA U-2","	* dérivé de 5B87"},
/* 1B00C */ { "CARACTÈRE HENTAIGANA U-3","	* dérivé de 6182"},
/* 1B00D */ { "CARACTÈRE HENTAIGANA U-4","	* dérivé de 6709"},
/* 1B00E */ { "CARACTÈRE HENTAIGANA U-5","	* dérivé de 96F2"},
/* 1B00F */ { "CARACTÈRE HENTAIGANA E-2","	* dérivé de 76C8"},
/* 1B010 */ { "CARACTÈRE HENTAIGANA E-3","	* dérivé de 7E01"},
/* 1B011 */ { "CARACTÈRE HENTAIGANA E-4","	* dérivé de 8863"},
/* 1B012 */ { "CARACTÈRE HENTAIGANA E-5","	* dérivé de 8863"},
/* 1B013 */ { "CARACTÈRE HENTAIGANA E-6","	* dérivé de 8981"},
/* 1B014 */ { "CARACTÈRE HENTAIGANA O-1","	* dérivé de 65BC"},
/* 1B015 */ { "CARACTÈRE HENTAIGANA O-2","	* dérivé de 65BC"},
/* 1B016 */ { "CARACTÈRE HENTAIGANA O-3","	* dérivé de 96B1"},
/* 1B017 */ { "CARACTÈRE HENTAIGANA KA-1","	* dérivé de 4F73"},
/* 1B018 */ { "CARACTÈRE HENTAIGANA KA-2","	* dérivé de 52A0"},
/* 1B019 */ { "CARACTÈRE HENTAIGANA KA-3","	* dérivé de 53EF"},
/* 1B01A */ { "CARACTÈRE HENTAIGANA KA-4","	* dérivé de 53EF"},
/* 1B01B */ { "CARACTÈRE HENTAIGANA KA-5","	* dérivé de 5609"},
/* 1B01C */ { "CARACTÈRE HENTAIGANA KA-6","	* dérivé de 6211"},
/* 1B01D */ { "CARACTÈRE HENTAIGANA KA-7","	* dérivé de 6B5F"},
/* 1B01E */ { "CARACTÈRE HENTAIGANA KA-8","	* dérivé de 8CC0"},
/* 1B01F */ { "CARACTÈRE HENTAIGANA KA-9","	* dérivé de 9591"},
/* 1B020 */ { "CARACTÈRE HENTAIGANA KA-10","	* dérivé de 9999"},
/* 1B021 */ { "CARACTÈRE HENTAIGANA KA-11","	* dérivé de 99D5"},
/* 1B022 */ { "CARACTÈRE HENTAIGANA KA-KE","	* dérivé de 5BB6"},
/* 1B023 */ { "CARACTÈRE HENTAIGANA KI-1","	* dérivé de 559C"},
/* 1B024 */ { "CARACTÈRE HENTAIGANA KI-2","	* dérivé de 5E7E"},
/* 1B025 */ { "CARACTÈRE HENTAIGANA KI-3","	* dérivé de 5E7E"},
/* 1B026 */ { "CARACTÈRE HENTAIGANA KI-4","	* dérivé de 652F"},
/* 1B027 */ { "CARACTÈRE HENTAIGANA KI-5","	* dérivé de 6728"},
/* 1B028 */ { "CARACTÈRE HENTAIGANA KI-6","	* dérivé de 7948"},
/* 1B029 */ { "CARACTÈRE HENTAIGANA KI-7","	* dérivé de 8CB4"},
/* 1B02A */ { "CARACTÈRE HENTAIGANA KI-8","	* dérivé de 8D77"},
/* 1B02B */ { "CARACTÈRE HENTAIGANA KU-1","	* dérivé de 4E45"},
/* 1B02C */ { "CARACTÈRE HENTAIGANA KU-2","	* dérivé de 4E45"},
/* 1B02D */ { "CARACTÈRE HENTAIGANA KU-3","	* dérivé de 4E5D"},
/* 1B02E */ { "CARACTÈRE HENTAIGANA KU-4","	* dérivé de 4F9B"},
/* 1B02F */ { "CARACTÈRE HENTAIGANA KU-5","	* dérivé de 5036"},
/* 1B030 */ { "CARACTÈRE HENTAIGANA KU-6","	* dérivé de 5177"},
/* 1B031 */ { "CARACTÈRE HENTAIGANA KU-7","	* dérivé de 6C42"},
/* 1B032 */ { "CARACTÈRE HENTAIGANA KE-1","	* dérivé de 4ECB"},
/* 1B033 */ { "CARACTÈRE HENTAIGANA KE-2","	* dérivé de 4ECB"},
/* 1B034 */ { "CARACTÈRE HENTAIGANA KE-3","	* dérivé de 5E0C"},
/* 1B035 */ { "CARACTÈRE HENTAIGANA KE-4","	* dérivé de 6C23"},
/* 1B036 */ { "CARACTÈRE HENTAIGANA KE-5","	* dérivé de 8A08"},
/* 1B037 */ { "CARACTÈRE HENTAIGANA KE-6","	* dérivé de 9063"},
/* 1B038 */ { "CARACTÈRE HENTAIGANA KO-1","	* dérivé de 53E4"},
/* 1B039 */ { "CARACTÈRE HENTAIGANA KO-2","	* dérivé de 6545"},
/* 1B03A */ { "CARACTÈRE HENTAIGANA KO-3","	* dérivé de 8A31"},
/* 1B03B */ { "CARACTÈRE HENTAIGANA KO-KI","	* dérivé de 671F"},
/* 1B03C */ { "CARACTÈRE HENTAIGANA SA-1","	* dérivé de 4E4D"},
/* 1B03D */ { "CARACTÈRE HENTAIGANA SA-2","	* dérivé de 4F50"},
/* 1B03E */ { "CARACTÈRE HENTAIGANA SA-3","	* dérivé de 4F50"},
/* 1B03F */ { "CARACTÈRE HENTAIGANA SA-4","	* dérivé de 5DE6"},
/* 1B040 */ { "CARACTÈRE HENTAIGANA SA-5","	* dérivé de 5DEE"},
/* 1B041 */ { "CARACTÈRE HENTAIGANA SA-6","	* dérivé de 6563"},
/* 1B042 */ { "CARACTÈRE HENTAIGANA SA-7","	* dérivé de 659C"},
/* 1B043 */ { "CARACTÈRE HENTAIGANA SA-8","	* dérivé de 6C99"},
/* 1B044 */ { "CARACTÈRE HENTAIGANA SI-1","	* dérivé de 4E4B"},
/* 1B045 */ { "CARACTÈRE HENTAIGANA SI-2","	* dérivé de 4E4B"},
/* 1B046 */ { "CARACTÈRE HENTAIGANA SI-3","	* dérivé de 4E8B"},
/* 1B047 */ { "CARACTÈRE HENTAIGANA SI-4","	* dérivé de 56DB"},
/* 1B048 */ { "CARACTÈRE HENTAIGANA SI-5","	* dérivé de 5FD7"},
/* 1B049 */ { "CARACTÈRE HENTAIGANA SI-6","	* dérivé de 65B0"},
/* 1B04A */ { "CARACTÈRE HENTAIGANA SU-1","	* dérivé de 53D7"},
/* 1B04B */ { "CARACTÈRE HENTAIGANA SU-2","	* dérivé de 58FD"},
/* 1B04C */ { "CARACTÈRE HENTAIGANA SU-3","	* dérivé de 6578"},
/* 1B04D */ { "CARACTÈRE HENTAIGANA SU-4","	* dérivé de 6578"},
/* 1B04E */ { "CARACTÈRE HENTAIGANA SU-5","	* dérivé de 6625"},
/* 1B04F */ { "CARACTÈRE HENTAIGANA SU-6","	* dérivé de 6625"},
/* 1B050 */ { "CARACTÈRE HENTAIGANA SU-7","	* dérivé de 9808"},
/* 1B051 */ { "CARACTÈRE HENTAIGANA SU-8","	* dérivé de 9808"},
/* 1B052 */ { "CARACTÈRE HENTAIGANA SE-1","	* dérivé de 4E16"},
/* 1B053 */ { "CARACTÈRE HENTAIGANA SE-2","	* dérivé de 4E16"},
/* 1B054 */ { "CARACTÈRE HENTAIGANA SE-3","	* dérivé de 4E16"},
/* 1B055 */ { "CARACTÈRE HENTAIGANA SE-4","	* dérivé de 52E2"},
/* 1B056 */ { "CARACTÈRE HENTAIGANA SE-5","	* dérivé de 8072"},
/* 1B057 */ { "CARACTÈRE HENTAIGANA SO-1","	* dérivé de 6240"},
/* 1B058 */ { "CARACTÈRE HENTAIGANA SO-2","	* dérivé de 6240"},
/* 1B059 */ { "CARACTÈRE HENTAIGANA SO-3","	* dérivé de 66FE"},
/* 1B05A */ { "CARACTÈRE HENTAIGANA SO-4","	* dérivé de 66FE"},
/* 1B05B */ { "CARACTÈRE HENTAIGANA SO-5","	* dérivé de 695A"},
/* 1B05C */ { "CARACTÈRE HENTAIGANA SO-6","	* dérivé de 8607"},
/* 1B05D */ { "CARACTÈRE HENTAIGANA SO-7","	* dérivé de 8655"},
/* 1B05E */ { "CARACTÈRE HENTAIGANA TA-1","	* dérivé de 5802"},
/* 1B05F */ { "CARACTÈRE HENTAIGANA TA-2","	* dérivé de 591A"},
/* 1B060 */ { "CARACTÈRE HENTAIGANA TA-3","	* dérivé de 591A"},
/* 1B061 */ { "CARACTÈRE HENTAIGANA TA-4","	* dérivé de 7576"},
/* 1B062 */ { "CARACTÈRE HENTAIGANA TI-1","	* dérivé de 5343"},
/* 1B063 */ { "CARACTÈRE HENTAIGANA TI-2","	* dérivé de 5730"},
/* 1B064 */ { "CARACTÈRE HENTAIGANA TI-3","	* dérivé de 667A"},
/* 1B065 */ { "CARACTÈRE HENTAIGANA TI-4","	* dérivé de 77E5"},
/* 1B066 */ { "CARACTÈRE HENTAIGANA TI-5","	* dérivé de 77E5"},
/* 1B067 */ { "CARACTÈRE HENTAIGANA TI-6","	* dérivé de 81F4"},
/* 1B068 */ { "CARACTÈRE HENTAIGANA TI-7","	* dérivé de 9072"},
/* 1B069 */ { "CARACTÈRE HENTAIGANA TU-1","	* dérivé de 5DDD"},
/* 1B06A */ { "CARACTÈRE HENTAIGANA TU-2","	* dérivé de 5DDD"},
/* 1B06B */ { "CARACTÈRE HENTAIGANA TU-3","	* dérivé de 6D25"},
/* 1B06C */ { "CARACTÈRE HENTAIGANA TU-4","	* dérivé de 90FD"},
/* 1B06D */ { "CARACTÈRE HENTAIGANA TU-TO","	* dérivé de 5F92"},
/* 1B06E */ { "CARACTÈRE HENTAIGANA TE-1","	* dérivé de 4EAD"},
/* 1B06F */ { "CARACTÈRE HENTAIGANA TE-2","	* dérivé de 4F4E"},
/* 1B070 */ { "CARACTÈRE HENTAIGANA TE-3","	* dérivé de 50B3"},
/* 1B071 */ { "CARACTÈRE HENTAIGANA TE-4","	* dérivé de 5929"},
/* 1B072 */ { "CARACTÈRE HENTAIGANA TE-5","	* dérivé de 5929"},
/* 1B073 */ { "CARACTÈRE HENTAIGANA TE-6","	* dérivé de 5929"},
/* 1B074 */ { "CARACTÈRE HENTAIGANA TE-7","	* dérivé de 5E1D"},
/* 1B075 */ { "CARACTÈRE HENTAIGANA TE-8","	* dérivé de 5F16"},
/* 1B076 */ { "CARACTÈRE HENTAIGANA TE-9","	* dérivé de 8F49"},
/* 1B077 */ { "CARACTÈRE HENTAIGANA TO-1","	* dérivé de 571F"},
/* 1B078 */ { "CARACTÈRE HENTAIGANA TO-2","	* dérivé de 5EA6"},
/* 1B079 */ { "CARACTÈRE HENTAIGANA TO-3","	* dérivé de 6771"},
/* 1B07A */ { "CARACTÈRE HENTAIGANA TO-4","	* dérivé de 767B"},
/* 1B07B */ { "CARACTÈRE HENTAIGANA TO-5","	* dérivé de 767B"},
/* 1B07C */ { "CARACTÈRE HENTAIGANA TO-6","	* dérivé de 7825"},
/* 1B07D */ { "CARACTÈRE HENTAIGANA TO-RA","	* dérivé de 7B49"},
/* 1B07E */ { "CARACTÈRE HENTAIGANA NA-1","	* dérivé de 5357"},
/* 1B07F */ { "CARACTÈRE HENTAIGANA NA-2","	* dérivé de 540D"},
/* 1B080 */ { "CARACTÈRE HENTAIGANA NA-3","	* dérivé de 5948"},
/* 1B081 */ { "CARACTÈRE HENTAIGANA NA-4","	* dérivé de 5948"},
/* 1B082 */ { "CARACTÈRE HENTAIGANA NA-5","	* dérivé de 5948"},
/* 1B083 */ { "CARACTÈRE HENTAIGANA NA-6","	* dérivé de 83DC"},
/* 1B084 */ { "CARACTÈRE HENTAIGANA NA-7","	* dérivé de 90A3"},
/* 1B085 */ { "CARACTÈRE HENTAIGANA NA-8","	* dérivé de 90A3"},
/* 1B086 */ { "CARACTÈRE HENTAIGANA NA-9","	* dérivé de 96E3"},
/* 1B087 */ { "CARACTÈRE HENTAIGANA NI-1","	* dérivé de 4E39"},
/* 1B088 */ { "CARACTÈRE HENTAIGANA NI-2","	* dérivé de 4E8C"},
/* 1B089 */ { "CARACTÈRE HENTAIGANA NI-3","	* dérivé de 4EC1"},
/* 1B08A */ { "CARACTÈRE HENTAIGANA NI-4","	* dérivé de 5152"},
/* 1B08B */ { "CARACTÈRE HENTAIGANA NI-5","	* dérivé de 723E"},
/* 1B08C */ { "CARACTÈRE HENTAIGANA NI-6","	* dérivé de 723E"},
/* 1B08D */ { "CARACTÈRE HENTAIGANA NI-7","	* dérivé de 8033"},
/* 1B08E */ { "CARACTÈRE HENTAIGANA NI-TE","	* dérivé de 800C"},
/* 1B08F */ { "CARACTÈRE HENTAIGANA NU-1","	* dérivé de 52AA"},
/* 1B090 */ { "CARACTÈRE HENTAIGANA NU-2","	* dérivé de 5974"},
/* 1B091 */ { "CARACTÈRE HENTAIGANA NU-3","	* dérivé de 6012"},
/* 1B092 */ { "CARACTÈRE HENTAIGANA NE-1","	* dérivé de 5E74"},
/* 1B093 */ { "CARACTÈRE HENTAIGANA NE-2","	* dérivé de 5E74"},
/* 1B094 */ { "CARACTÈRE HENTAIGANA NE-3","	* dérivé de 5E74"},
/* 1B095 */ { "CARACTÈRE HENTAIGANA NE-4","	* dérivé de 6839"},
/* 1B096 */ { "CARACTÈRE HENTAIGANA NE-5","	* dérivé de 71B1"},
/* 1B097 */ { "CARACTÈRE HENTAIGANA NE-6","	* dérivé de 79B0"},
/* 1B098 */ { "CARACTÈRE HENTAIGANA NE-KO","	* dérivé de 5B50"},
/* 1B099 */ { "CARACTÈRE HENTAIGANA NO-1","	* dérivé de 4E43"},
/* 1B09A */ { "CARACTÈRE HENTAIGANA NO-2","	* dérivé de 6FC3"},
/* 1B09B */ { "CARACTÈRE HENTAIGANA NO-3","	* dérivé de 80FD"},
/* 1B09C */ { "CARACTÈRE HENTAIGANA NO-4","	* dérivé de 80FD"},
/* 1B09D */ { "CARACTÈRE HENTAIGANA NO-5","	* dérivé de 8FB2"},
/* 1B09E */ { "CARACTÈRE HENTAIGANA HA-1","	* dérivé de 516B"},
/* 1B09F */ { "CARACTÈRE HENTAIGANA HA-2","	* dérivé de 534A"},
/* 1B0A0 */ { "CARACTÈRE HENTAIGANA HA-3","	* dérivé de 5A46"},
/* 1B0A1 */ { "CARACTÈRE HENTAIGANA HA-4","	* dérivé de 6CE2"},
/* 1B0A2 */ { "CARACTÈRE HENTAIGANA HA-5","	* dérivé de 76E4"},
/* 1B0A3 */ { "CARACTÈRE HENTAIGANA HA-6","	* dérivé de 76E4"},
/* 1B0A4 */ { "CARACTÈRE HENTAIGANA HA-7","	* dérivé de 7834"},
/* 1B0A5 */ { "CARACTÈRE HENTAIGANA HA-8","	* dérivé de 8005"},
/* 1B0A6 */ { "CARACTÈRE HENTAIGANA HA-9","	* dérivé de 8005"},
/* 1B0A7 */ { "CARACTÈRE HENTAIGANA HA-10","	* dérivé de 8449"},
/* 1B0A8 */ { "CARACTÈRE HENTAIGANA HA-11","	* dérivé de 9817"},
/* 1B0A9 */ { "CARACTÈRE HENTAIGANA HI-1","	* dérivé de 60B2"},
/* 1B0AA */ { "CARACTÈRE HENTAIGANA HI-2","	* dérivé de 65E5"},
/* 1B0AB */ { "CARACTÈRE HENTAIGANA HI-3","	* dérivé de 6BD4"},
/* 1B0AC */ { "CARACTÈRE HENTAIGANA HI-4","	* dérivé de 907F"},
/* 1B0AD */ { "CARACTÈRE HENTAIGANA HI-5","	* dérivé de 975E"},
/* 1B0AE */ { "CARACTÈRE HENTAIGANA HI-6","	* dérivé de 98DB"},
/* 1B0AF */ { "CARACTÈRE HENTAIGANA HI-7","	* dérivé de 98DB"},
/* 1B0B0 */ { "CARACTÈRE HENTAIGANA HU-1","	* dérivé de 4E0D"},
/* 1B0B1 */ { "CARACTÈRE HENTAIGANA HU-2","	* dérivé de 5A66"},
/* 1B0B2 */ { "CARACTÈRE HENTAIGANA HU-3","	* dérivé de 5E03"},
/* 1B0B3 */ { "CARACTÈRE HENTAIGANA HE-1","	* dérivé de 500D"},
/* 1B0B4 */ { "CARACTÈRE HENTAIGANA HE-2","	* dérivé de 5F0A"},
/* 1B0B5 */ { "CARACTÈRE HENTAIGANA HE-3","	* dérivé de 5F0A"},
/* 1B0B6 */ { "CARACTÈRE HENTAIGANA HE-4","	* dérivé de 904D"},
/* 1B0B7 */ { "CARACTÈRE HENTAIGANA HE-5","	* dérivé de 908A"},
/* 1B0B8 */ { "CARACTÈRE HENTAIGANA HE-6","	* dérivé de 908A"},
/* 1B0B9 */ { "CARACTÈRE HENTAIGANA HE-7","	* dérivé de 90E8"},
/* 1B0BA */ { "CARACTÈRE HENTAIGANA HO-1","	* dérivé de 4FDD"},
/* 1B0BB */ { "CARACTÈRE HENTAIGANA HO-2","	* dérivé de 4FDD"},
/* 1B0BC */ { "CARACTÈRE HENTAIGANA HO-3","	* dérivé de 5831"},
/* 1B0BD */ { "CARACTÈRE HENTAIGANA HO-4","	* dérivé de 5949"},
/* 1B0BE */ { "CARACTÈRE HENTAIGANA HO-5","	* dérivé de 5BF6"},
/* 1B0BF */ { "CARACTÈRE HENTAIGANA HO-6","	* dérivé de 672C"},
/* 1B0C0 */ { "CARACTÈRE HENTAIGANA HO-7","	* dérivé de 672C"},
/* 1B0C1 */ { "CARACTÈRE HENTAIGANA HO-8","	* dérivé de 8C50"},
/* 1B0C2 */ { "CARACTÈRE HENTAIGANA MA-1","	* dérivé de 4E07"},
/* 1B0C3 */ { "CARACTÈRE HENTAIGANA MA-2","	* dérivé de 672B"},
/* 1B0C4 */ { "CARACTÈRE HENTAIGANA MA-3","	* dérivé de 672B"},
/* 1B0C5 */ { "CARACTÈRE HENTAIGANA MA-4","	* dérivé de 6EFF"},
/* 1B0C6 */ { "CARACTÈRE HENTAIGANA MA-5","	* dérivé de 6EFF"},
/* 1B0C7 */ { "CARACTÈRE HENTAIGANA MA-6","	* dérivé de 842C"},
/* 1B0C8 */ { "CARACTÈRE HENTAIGANA MA-7","	* dérivé de 9EBB"},
/* 1B0C9 */ { "CARACTÈRE HENTAIGANA MI-1","	* dérivé de 4E09"},
/* 1B0CA */ { "CARACTÈRE HENTAIGANA MI-2","	* dérivé de 5FAE"},
/* 1B0CB */ { "CARACTÈRE HENTAIGANA MI-3","	* dérivé de 7F8E"},
/* 1B0CC */ { "CARACTÈRE HENTAIGANA MI-4","	* dérivé de 7F8E"},
/* 1B0CD */ { "CARACTÈRE HENTAIGANA MI-5","	* dérivé de 7F8E"},
/* 1B0CE */ { "CARACTÈRE HENTAIGANA MI-6","	* dérivé de 898B"},
/* 1B0CF */ { "CARACTÈRE HENTAIGANA MI-7","	* dérivé de 8EAB"},
/* 1B0D0 */ { "CARACTÈRE HENTAIGANA MU-1","	* dérivé de 6B66"},
/* 1B0D1 */ { "CARACTÈRE HENTAIGANA MU-2","	* dérivé de 7121"},
/* 1B0D2 */ { "CARACTÈRE HENTAIGANA MU-3","	* dérivé de 725F"},
/* 1B0D3 */ { "CARACTÈRE HENTAIGANA MU-4","	* dérivé de 821E"},
/* 1B0D4 */ { "CARACTÈRE HENTAIGANA ME-1","	* dérivé de 514D"},
/* 1B0D5 */ { "CARACTÈRE HENTAIGANA ME-2","	* dérivé de 9762"},
/* 1B0D6 */ { "CARACTÈRE HENTAIGANA ME-MA","	* dérivé de 99AC"},
/* 1B0D7 */ { "CARACTÈRE HENTAIGANA MO-1","	* dérivé de 6BCD"},
/* 1B0D8 */ { "CARACTÈRE HENTAIGANA MO-2","	* dérivé de 6BDB"},
/* 1B0D9 */ { "CARACTÈRE HENTAIGANA MO-3","	* dérivé de 6BDB"},
/* 1B0DA */ { "CARACTÈRE HENTAIGANA MO-4","	* dérivé de 6BDB"},
/* 1B0DB */ { "CARACTÈRE HENTAIGANA MO-5","	* dérivé de 8302"},
/* 1B0DC */ { "CARACTÈRE HENTAIGANA MO-6","	* dérivé de 88F3"},
/* 1B0DD */ { "CARACTÈRE HENTAIGANA YA-1","	* dérivé de 4E5F"},
/* 1B0DE */ { "CARACTÈRE HENTAIGANA YA-2","	* dérivé de 4E5F"},
/* 1B0DF */ { "CARACTÈRE HENTAIGANA YA-3","	* dérivé de 5C4B"},
/* 1B0E0 */ { "CARACTÈRE HENTAIGANA YA-4","	* dérivé de 8036"},
/* 1B0E1 */ { "CARACTÈRE HENTAIGANA YA-5","	* dérivé de 8036"},
/* 1B0E2 */ { "CARACTÈRE HENTAIGANA YA-YO","	* dérivé de 591C"},
/* 1B0E3 */ { "CARACTÈRE HENTAIGANA YU-1","	* dérivé de 6E38"},
/* 1B0E4 */ { "CARACTÈRE HENTAIGANA YU-2","	* dérivé de 7531"},
/* 1B0E5 */ { "CARACTÈRE HENTAIGANA YU-3","	* dérivé de 7531"},
/* 1B0E6 */ { "CARACTÈRE HENTAIGANA YU-4","	* dérivé de 904A"},
/* 1B0E7 */ { "CARACTÈRE HENTAIGANA YO-1","	* dérivé de 4EE3"},
/* 1B0E8 */ { "CARACTÈRE HENTAIGANA YO-2","	* dérivé de 4F59"},
/* 1B0E9 */ { "CARACTÈRE HENTAIGANA YO-3","	* dérivé de 8207"},
/* 1B0EA */ { "CARACTÈRE HENTAIGANA YO-4","	* dérivé de 8207"},
/* 1B0EB */ { "CARACTÈRE HENTAIGANA YO-5","	* dérivé de 8207"},
/* 1B0EC */ { "CARACTÈRE HENTAIGANA YO-6","	* dérivé de 9918"},
/* 1B0ED */ { "CARACTÈRE HENTAIGANA RA-1","	* dérivé de 7F85"},
/* 1B0EE */ { "CARACTÈRE HENTAIGANA RA-2","	* dérivé de 826F"},
/* 1B0EF */ { "CARACTÈRE HENTAIGANA RA-3","	* dérivé de 826F"},
/* 1B0F0 */ { "CARACTÈRE HENTAIGANA RA-4","	* dérivé de 826F"},
/* 1B0F1 */ { "CARACTÈRE HENTAIGANA RI-1","	* dérivé de 5229"},
/* 1B0F2 */ { "CARACTÈRE HENTAIGANA RI-2","	* dérivé de 5229"},
/* 1B0F3 */ { "CARACTÈRE HENTAIGANA RI-3","	* dérivé de 674E"},
/* 1B0F4 */ { "CARACTÈRE HENTAIGANA RI-4","	* dérivé de 68A8"},
/* 1B0F5 */ { "CARACTÈRE HENTAIGANA RI-5","	* dérivé de 7406"},
/* 1B0F6 */ { "CARACTÈRE HENTAIGANA RI-6","	* dérivé de 91CC"},
/* 1B0F7 */ { "CARACTÈRE HENTAIGANA RI-7","	* dérivé de 96E2"},
/* 1B0F8 */ { "CARACTÈRE HENTAIGANA RU-1","	* dérivé de 6D41"},
/* 1B0F9 */ { "CARACTÈRE HENTAIGANA RU-2","	* dérivé de 7559"},
/* 1B0FA */ { "CARACTÈRE HENTAIGANA RU-3","	* dérivé de 7559"},
/* 1B0FB */ { "CARACTÈRE HENTAIGANA RU-4","	* dérivé de 7559"},
/* 1B0FC */ { "CARACTÈRE HENTAIGANA RU-5","	* dérivé de 7D2F"},
/* 1B0FD */ { "CARACTÈRE HENTAIGANA RU-6","	* dérivé de 985E"},
/* 1B0FE */ { "CARACTÈRE HENTAIGANA RE-1","	* dérivé de 79AE"},
/* 1B0FF */ { "CARACTÈRE HENTAIGANA RE-2","	* dérivé de 79AE"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_B1[] = {
/* 1B100 */ { "CARACTÈRE HENTAIGANA RE-3","	* dérivé de 9023"},
/* 1B101 */ { "CARACTÈRE HENTAIGANA RE-4","	* dérivé de 9E97"},
/* 1B102 */ { "CARACTÈRE HENTAIGANA RO-1","	* dérivé de 5442"},
/* 1B103 */ { "CARACTÈRE HENTAIGANA RO-2","	* dérivé de 5442"},
/* 1B104 */ { "CARACTÈRE HENTAIGANA RO-3","	* dérivé de 5A41"},
/* 1B105 */ { "CARACTÈRE HENTAIGANA RO-4","	* dérivé de 6A13"},
/* 1B106 */ { "CARACTÈRE HENTAIGANA RO-5","	* dérivé de 8DEF"},
/* 1B107 */ { "CARACTÈRE HENTAIGANA RO-6","	* dérivé de 9732"},
/* 1B108 */ { "CARACTÈRE HENTAIGANA WA-1","	* dérivé de 502D"},
/* 1B109 */ { "CARACTÈRE HENTAIGANA WA-2","	* dérivé de 548C"},
/* 1B10A */ { "CARACTÈRE HENTAIGANA WA-3","	* dérivé de 548C"},
/* 1B10B */ { "CARACTÈRE HENTAIGANA WA-4","	* dérivé de 738B"},
/* 1B10C */ { "CARACTÈRE HENTAIGANA WA-5","	* dérivé de 738B"},
/* 1B10D */ { "CARACTÈRE HENTAIGANA WI-1","	* dérivé de 4E95"},
/* 1B10E */ { "CARACTÈRE HENTAIGANA WI-2","	* dérivé de 4E95"},
/* 1B10F */ { "CARACTÈRE HENTAIGANA WI-3","	* dérivé de 5C45"},
/* 1B110 */ { "CARACTÈRE HENTAIGANA WI-4","	* dérivé de 7232"},
/* 1B111 */ { "CARACTÈRE HENTAIGANA WI-5","	* dérivé de 907A"},
/* 1B112 */ { "CARACTÈRE HENTAIGANA WE-1","	* dérivé de 60E0"},
/* 1B113 */ { "CARACTÈRE HENTAIGANA WE-2","	* dérivé de 885E"},
/* 1B114 */ { "CARACTÈRE HENTAIGANA WE-3","	* dérivé de 885E"},
/* 1B115 */ { "CARACTÈRE HENTAIGANA WE-4","	* dérivé de 885E"},
/* 1B116 */ { "CARACTÈRE HENTAIGANA WO-1","	* dérivé de 4E4E"},
/* 1B117 */ { "CARACTÈRE HENTAIGANA WO-2","	* dérivé de 4E4E"},
/* 1B118 */ { "CARACTÈRE HENTAIGANA WO-3","	* dérivé de 5C3E"},
/* 1B119 */ { "CARACTÈRE HENTAIGANA WO-4","	* dérivé de 7DD2"},
/* 1B11A */ { "CARACTÈRE HENTAIGANA WO-5","	* dérivé de 8D8A"},
/* 1B11B */ { "CARACTÈRE HENTAIGANA WO-6","	* dérivé de 9060"},
/* 1B11C */ { "CARACTÈRE HENTAIGANA WO-7","	* dérivé de 9060"},
/* 1B11D */ { "CARACTÈRE HENTAIGANA N-MU-MO-1","	* dérivé de 65E0"},
/* 1B11E */ { "CARACTÈRE HENTAIGANA N-MU-MO-2","	* dérivé de 65E0"},
/* 1B11F */ { "CARACTÈRE HIRAGANA WU ARCHAÏQUE","	* dérivé de 6C59"},
/* 1B120 */ { "CARACTÈRE KATAKANA YI ARCHAÏQUE",NULL},
/* 1B121 */ { "CARACTÈRE KATAKANA YE ARCHAÏQUE",NULL},
/* 1B122 */ { "CARACTÈRE KATAKANA WU ARCHAÏQUE",NULL},
/* 1B123 */ { NULL,NULL},
/* 1B124 */ { NULL,NULL},
/* 1B125 */ { NULL,NULL},
/* 1B126 */ { NULL,NULL},
/* 1B127 */ { NULL,NULL},
/* 1B128 */ { NULL,NULL},
/* 1B129 */ { NULL,NULL},
/* 1B12A */ { NULL,NULL},
/* 1B12B */ { NULL,NULL},
/* 1B12C */ { NULL,NULL},
/* 1B12D */ { NULL,NULL},
/* 1B12E */ { NULL,NULL},
/* 1B12F */ { NULL,NULL},
/* 1B130 */ { NULL,NULL},
/* 1B131 */ { NULL,NULL},
/* 1B132 */ { "CARACTÈRE HIRAGANA PETIT KO",NULL},
/* 1B133 */ { NULL,NULL},
/* 1B134 */ { NULL,NULL},
/* 1B135 */ { NULL,NULL},
/* 1B136 */ { NULL,NULL},
/* 1B137 */ { NULL,NULL},
/* 1B138 */ { NULL,NULL},
/* 1B139 */ { NULL,NULL},
/* 1B13A */ { NULL,NULL},
/* 1B13B */ { NULL,NULL},
/* 1B13C */ { NULL,NULL},
/* 1B13D */ { NULL,NULL},
/* 1B13E */ { NULL,NULL},
/* 1B13F */ { NULL,NULL},
/* 1B140 */ { NULL,NULL},
/* 1B141 */ { NULL,NULL},
/* 1B142 */ { NULL,NULL},
/* 1B143 */ { NULL,NULL},
/* 1B144 */ { NULL,NULL},
/* 1B145 */ { NULL,NULL},
/* 1B146 */ { NULL,NULL},
/* 1B147 */ { NULL,NULL},
/* 1B148 */ { NULL,NULL},
/* 1B149 */ { NULL,NULL},
/* 1B14A */ { NULL,NULL},
/* 1B14B */ { NULL,NULL},
/* 1B14C */ { NULL,NULL},
/* 1B14D */ { NULL,NULL},
/* 1B14E */ { NULL,NULL},
/* 1B14F */ { NULL,NULL},
/* 1B150 */ { "CARACTÈRE HIRAGANA PETIT WI",NULL},
/* 1B151 */ { "CARACTÈRE HIRAGANA PETIT WE",NULL},
/* 1B152 */ { "CARACTÈRE HIRAGANA PETIT WO",NULL},
/* 1B153 */ { NULL,NULL},
/* 1B154 */ { NULL,NULL},
/* 1B155 */ { "CARACTÈRE KATAKANA PETIT KO",NULL},
/* 1B156 */ { NULL,NULL},
/* 1B157 */ { NULL,NULL},
/* 1B158 */ { NULL,NULL},
/* 1B159 */ { NULL,NULL},
/* 1B15A */ { NULL,NULL},
/* 1B15B */ { NULL,NULL},
/* 1B15C */ { NULL,NULL},
/* 1B15D */ { NULL,NULL},
/* 1B15E */ { NULL,NULL},
/* 1B15F */ { NULL,NULL},
/* 1B160 */ { NULL,NULL},
/* 1B161 */ { NULL,NULL},
/* 1B162 */ { NULL,NULL},
/* 1B163 */ { NULL,NULL},
/* 1B164 */ { "CARACTÈRE KATAKANA PETIT WI",NULL},
/* 1B165 */ { "CARACTÈRE KATAKANA PETIT WE",NULL},
/* 1B166 */ { "CARACTÈRE KATAKANA PETIT WO",NULL},
/* 1B167 */ { "CARACTÈRE KATAKANA PETIT N",NULL},
/* 1B168 */ { NULL,NULL},
/* 1B169 */ { NULL,NULL},
/* 1B16A */ { NULL,NULL},
/* 1B16B */ { NULL,NULL},
/* 1B16C */ { NULL,NULL},
/* 1B16D */ { NULL,NULL},
/* 1B16E */ { NULL,NULL},
/* 1B16F */ { NULL,NULL},
/* 1B170 */ { "CARACTÈRE NÜSHU-1B170","	x 4E00"},
/* 1B171 */ { "CARACTÈRE NÜSHU-1B171","	x 4E8C"},
/* 1B172 */ { "CARACTÈRE NÜSHU-1B172",NULL},
/* 1B173 */ { "CARACTÈRE NÜSHU-1B173",NULL},
/* 1B174 */ { "CARACTÈRE NÜSHU-1B174",NULL},
/* 1B175 */ { "CARACTÈRE NÜSHU-1B175",NULL},
/* 1B176 */ { "CARACTÈRE NÜSHU-1B176",NULL},
/* 1B177 */ { "CARACTÈRE NÜSHU-1B177",NULL},
/* 1B178 */ { "CARACTÈRE NÜSHU-1B178","	x 6C34"},
/* 1B179 */ { "CARACTÈRE NÜSHU-1B179",NULL},
/* 1B17A */ { "CARACTÈRE NÜSHU-1B17A",NULL},
/* 1B17B */ { "CARACTÈRE NÜSHU-1B17B",NULL},
/* 1B17C */ { "CARACTÈRE NÜSHU-1B17C",NULL},
/* 1B17D */ { "CARACTÈRE NÜSHU-1B17D",NULL},
/* 1B17E */ { "CARACTÈRE NÜSHU-1B17E",NULL},
/* 1B17F */ { "CARACTÈRE NÜSHU-1B17F",NULL},
/* 1B180 */ { "CARACTÈRE NÜSHU-1B180","	x 571F"},
/* 1B181 */ { "CARACTÈRE NÜSHU-1B181",NULL},
/* 1B182 */ { "CARACTÈRE NÜSHU-1B182",NULL},
/* 1B183 */ { "CARACTÈRE NÜSHU-1B183","	x 5DE5"},
/* 1B184 */ { "CARACTÈRE NÜSHU-1B184",NULL},
/* 1B185 */ { "CARACTÈRE NÜSHU-1B185","	x 4E2A"},
/* 1B186 */ { "CARACTÈRE NÜSHU-1B186",NULL},
/* 1B187 */ { "CARACTÈRE NÜSHU-1B187",NULL},
/* 1B188 */ { "CARACTÈRE NÜSHU-1B188",NULL},
/* 1B189 */ { "CARACTÈRE NÜSHU-1B189",NULL},
/* 1B18A */ { "CARACTÈRE NÜSHU-1B18A","	x 4E09"},
/* 1B18B */ { "CARACTÈRE NÜSHU-1B18B",NULL},
/* 1B18C */ { "CARACTÈRE NÜSHU-1B18C",NULL},
/* 1B18D */ { "CARACTÈRE NÜSHU-1B18D",NULL},
/* 1B18E */ { "CARACTÈRE NÜSHU-1B18E",NULL},
/* 1B18F */ { "CARACTÈRE NÜSHU-1B18F",NULL},
/* 1B190 */ { "CARACTÈRE NÜSHU-1B190",NULL},
/* 1B191 */ { "CARACTÈRE NÜSHU-1B191",NULL},
/* 1B192 */ { "CARACTÈRE NÜSHU-1B192",NULL},
/* 1B193 */ { "CARACTÈRE NÜSHU-1B193",NULL},
/* 1B194 */ { "CARACTÈRE NÜSHU-1B194","	x 592B"},
/* 1B195 */ { "CARACTÈRE NÜSHU-1B195","	x 706B"},
/* 1B196 */ { "CARACTÈRE NÜSHU-1B196",NULL},
/* 1B197 */ { "CARACTÈRE NÜSHU-1B197",NULL},
/* 1B198 */ { "CARACTÈRE NÜSHU-1B198",NULL},
/* 1B199 */ { "CARACTÈRE NÜSHU-1B199",NULL},
/* 1B19A */ { "CARACTÈRE NÜSHU-1B19A",NULL},
/* 1B19B */ { "CARACTÈRE NÜSHU-1B19B",NULL},
/* 1B19C */ { "CARACTÈRE NÜSHU-1B19C",NULL},
/* 1B19D */ { "CARACTÈRE NÜSHU-1B19D",NULL},
/* 1B19E */ { "CARACTÈRE NÜSHU-1B19E",NULL},
/* 1B19F */ { "CARACTÈRE NÜSHU-1B19F",NULL},
/* 1B1A0 */ { "CARACTÈRE NÜSHU-1B1A0",NULL},
/* 1B1A1 */ { "CARACTÈRE NÜSHU-1B1A1","	x 4EA1"},
/* 1B1A2 */ { "CARACTÈRE NÜSHU-1B1A2",NULL},
/* 1B1A3 */ { "CARACTÈRE NÜSHU-1B1A3",NULL},
/* 1B1A4 */ { "CARACTÈRE NÜSHU-1B1A4",NULL},
/* 1B1A5 */ { "CARACTÈRE NÜSHU-1B1A5",NULL},
/* 1B1A6 */ { "CARACTÈRE NÜSHU-1B1A6",NULL},
/* 1B1A7 */ { "CARACTÈRE NÜSHU-1B1A7","	x 738B"},
/* 1B1A8 */ { "CARACTÈRE NÜSHU-1B1A8","	x 672A"},
/* 1B1A9 */ { "CARACTÈRE NÜSHU-1B1A9",NULL},
/* 1B1AA */ { "CARACTÈRE NÜSHU-1B1AA",NULL},
/* 1B1AB */ { "CARACTÈRE NÜSHU-1B1AB","	x 5185"},
/* 1B1AC */ { "CARACTÈRE NÜSHU-1B1AC",NULL},
/* 1B1AD */ { "CARACTÈRE NÜSHU-1B1AD",NULL},
/* 1B1AE */ { "CARACTÈRE NÜSHU-1B1AE",NULL},
/* 1B1AF */ { "CARACTÈRE NÜSHU-1B1AF",NULL},
/* 1B1B0 */ { "CARACTÈRE NÜSHU-1B1B0",NULL},
/* 1B1B1 */ { "CARACTÈRE NÜSHU-1B1B1",NULL},
/* 1B1B2 */ { "CARACTÈRE NÜSHU-1B1B2",NULL},
/* 1B1B3 */ { "CARACTÈRE NÜSHU-1B1B3",NULL},
/* 1B1B4 */ { "CARACTÈRE NÜSHU-1B1B4",NULL},
/* 1B1B5 */ { "CARACTÈRE NÜSHU-1B1B5",NULL},
/* 1B1B6 */ { "CARACTÈRE NÜSHU-1B1B6",NULL},
/* 1B1B7 */ { "CARACTÈRE NÜSHU-1B1B7",NULL},
/* 1B1B8 */ { "CARACTÈRE NÜSHU-1B1B8",NULL},
/* 1B1B9 */ { "CARACTÈRE NÜSHU-1B1B9",NULL},
/* 1B1BA */ { "CARACTÈRE NÜSHU-1B1BA",NULL},
/* 1B1BB */ { "CARACTÈRE NÜSHU-1B1BB",NULL},
/* 1B1BC */ { "CARACTÈRE NÜSHU-1B1BC",NULL},
/* 1B1BD */ { "CARACTÈRE NÜSHU-1B1BD",NULL},
/* 1B1BE */ { "CARACTÈRE NÜSHU-1B1BE",NULL},
/* 1B1BF */ { "CARACTÈRE NÜSHU-1B1BF",NULL},
/* 1B1C0 */ { "CARACTÈRE NÜSHU-1B1C0",NULL},
/* 1B1C1 */ { "CARACTÈRE NÜSHU-1B1C1",NULL},
/* 1B1C2 */ { "CARACTÈRE NÜSHU-1B1C2",NULL},
/* 1B1C3 */ { "CARACTÈRE NÜSHU-1B1C3",NULL},
/* 1B1C4 */ { "CARACTÈRE NÜSHU-1B1C4",NULL},
/* 1B1C5 */ { "CARACTÈRE NÜSHU-1B1C5",NULL},
/* 1B1C6 */ { "CARACTÈRE NÜSHU-1B1C6",NULL},
/* 1B1C7 */ { "CARACTÈRE NÜSHU-1B1C7",NULL},
/* 1B1C8 */ { "CARACTÈRE NÜSHU-1B1C8",NULL},
/* 1B1C9 */ { "CARACTÈRE NÜSHU-1B1C9",NULL},
/* 1B1CA */ { "CARACTÈRE NÜSHU-1B1CA",NULL},
/* 1B1CB */ { "CARACTÈRE NÜSHU-1B1CB",NULL},
/* 1B1CC */ { "CARACTÈRE NÜSHU-1B1CC","	x 540E"},
/* 1B1CD */ { "CARACTÈRE NÜSHU-1B1CD",NULL},
/* 1B1CE */ { "CARACTÈRE NÜSHU-1B1CE",NULL},
/* 1B1CF */ { "CARACTÈRE NÜSHU-1B1CF",NULL},
/* 1B1D0 */ { "CARACTÈRE NÜSHU-1B1D0",NULL},
/* 1B1D1 */ { "CARACTÈRE NÜSHU-1B1D1",NULL},
/* 1B1D2 */ { "CARACTÈRE NÜSHU-1B1D2",NULL},
/* 1B1D3 */ { "CARACTÈRE NÜSHU-1B1D3",NULL},
/* 1B1D4 */ { "CARACTÈRE NÜSHU-1B1D4",NULL},
/* 1B1D5 */ { "CARACTÈRE NÜSHU-1B1D5",NULL},
/* 1B1D6 */ { "CARACTÈRE NÜSHU-1B1D6",NULL},
/* 1B1D7 */ { "CARACTÈRE NÜSHU-1B1D7",NULL},
/* 1B1D8 */ { "CARACTÈRE NÜSHU-1B1D8",NULL},
/* 1B1D9 */ { "CARACTÈRE NÜSHU-1B1D9",NULL},
/* 1B1DA */ { "CARACTÈRE NÜSHU-1B1DA",NULL},
/* 1B1DB */ { "CARACTÈRE NÜSHU-1B1DB",NULL},
/* 1B1DC */ { "CARACTÈRE NÜSHU-1B1DC",NULL},
/* 1B1DD */ { "CARACTÈRE NÜSHU-1B1DD",NULL},
/* 1B1DE */ { "CARACTÈRE NÜSHU-1B1DE",NULL},
/* 1B1DF */ { "CARACTÈRE NÜSHU-1B1DF",NULL},
/* 1B1E0 */ { "CARACTÈRE NÜSHU-1B1E0",NULL},
/* 1B1E1 */ { "CARACTÈRE NÜSHU-1B1E1",NULL},
/* 1B1E2 */ { "CARACTÈRE NÜSHU-1B1E2",NULL},
/* 1B1E3 */ { "CARACTÈRE NÜSHU-1B1E3",NULL},
/* 1B1E4 */ { "CARACTÈRE NÜSHU-1B1E4",NULL},
/* 1B1E5 */ { "CARACTÈRE NÜSHU-1B1E5",NULL},
/* 1B1E6 */ { "CARACTÈRE NÜSHU-1B1E6",NULL},
/* 1B1E7 */ { "CARACTÈRE NÜSHU-1B1E7",NULL},
/* 1B1E8 */ { "CARACTÈRE NÜSHU-1B1E8",NULL},
/* 1B1E9 */ { "CARACTÈRE NÜSHU-1B1E9",NULL},
/* 1B1EA */ { "CARACTÈRE NÜSHU-1B1EA",NULL},
/* 1B1EB */ { "CARACTÈRE NÜSHU-1B1EB",NULL},
/* 1B1EC */ { "CARACTÈRE NÜSHU-1B1EC",NULL},
/* 1B1ED */ { "CARACTÈRE NÜSHU-1B1ED",NULL},
/* 1B1EE */ { "CARACTÈRE NÜSHU-1B1EE",NULL},
/* 1B1EF */ { "CARACTÈRE NÜSHU-1B1EF",NULL},
/* 1B1F0 */ { "CARACTÈRE NÜSHU-1B1F0","	x 53E4"},
/* 1B1F1 */ { "CARACTÈRE NÜSHU-1B1F1",NULL},
/* 1B1F2 */ { "CARACTÈRE NÜSHU-1B1F2",NULL},
/* 1B1F3 */ { "CARACTÈRE NÜSHU-1B1F3",NULL},
/* 1B1F4 */ { "CARACTÈRE NÜSHU-1B1F4",NULL},
/* 1B1F5 */ { "CARACTÈRE NÜSHU-1B1F5",NULL},
/* 1B1F6 */ { "CARACTÈRE NÜSHU-1B1F6",NULL},
/* 1B1F7 */ { "CARACTÈRE NÜSHU-1B1F7",NULL},
/* 1B1F8 */ { "CARACTÈRE NÜSHU-1B1F8",NULL},
/* 1B1F9 */ { "CARACTÈRE NÜSHU-1B1F9",NULL},
/* 1B1FA */ { "CARACTÈRE NÜSHU-1B1FA",NULL},
/* 1B1FB */ { "CARACTÈRE NÜSHU-1B1FB",NULL},
/* 1B1FC */ { "CARACTÈRE NÜSHU-1B1FC",NULL},
/* 1B1FD */ { "CARACTÈRE NÜSHU-1B1FD",NULL},
/* 1B1FE */ { "CARACTÈRE NÜSHU-1B1FE",NULL},
/* 1B1FF */ { "CARACTÈRE NÜSHU-1B1FF",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_B2[] = {
/* 1B200 */ { "CARACTÈRE NÜSHU-1B200",NULL},
/* 1B201 */ { "CARACTÈRE NÜSHU-1B201","	x 591A"},
/* 1B202 */ { "CARACTÈRE NÜSHU-1B202",NULL},
/* 1B203 */ { "CARACTÈRE NÜSHU-1B203",NULL},
/* 1B204 */ { "CARACTÈRE NÜSHU-1B204",NULL},
/* 1B205 */ { "CARACTÈRE NÜSHU-1B205","	x 7532"},
/* 1B206 */ { "CARACTÈRE NÜSHU-1B206",NULL},
/* 1B207 */ { "CARACTÈRE NÜSHU-1B207",NULL},
/* 1B208 */ { "CARACTÈRE NÜSHU-1B208",NULL},
/* 1B209 */ { "CARACTÈRE NÜSHU-1B209",NULL},
/* 1B20A */ { "CARACTÈRE NÜSHU-1B20A","	x 53CC"},
/* 1B20B */ { "CARACTÈRE NÜSHU-1B20B",NULL},
/* 1B20C */ { "CARACTÈRE NÜSHU-1B20C",NULL},
/* 1B20D */ { "CARACTÈRE NÜSHU-1B20D",NULL},
/* 1B20E */ { "CARACTÈRE NÜSHU-1B20E","	x 7530"},
/* 1B20F */ { "CARACTÈRE NÜSHU-1B20F",NULL},
/* 1B210 */ { "CARACTÈRE NÜSHU-1B210",NULL},
/* 1B211 */ { "CARACTÈRE NÜSHU-1B211",NULL},
/* 1B212 */ { "CARACTÈRE NÜSHU-1B212",NULL},
/* 1B213 */ { "CARACTÈRE NÜSHU-1B213","	x 5723"},
/* 1B214 */ { "CARACTÈRE NÜSHU-1B214",NULL},
/* 1B215 */ { "CARACTÈRE NÜSHU-1B215",NULL},
/* 1B216 */ { "CARACTÈRE NÜSHU-1B216","	x 65E9"},
/* 1B217 */ { "CARACTÈRE NÜSHU-1B217",NULL},
/* 1B218 */ { "CARACTÈRE NÜSHU-1B218",NULL},
/* 1B219 */ { "CARACTÈRE NÜSHU-1B219",NULL},
/* 1B21A */ { "CARACTÈRE NÜSHU-1B21A",NULL},
/* 1B21B */ { "CARACTÈRE NÜSHU-1B21B",NULL},
/* 1B21C */ { "CARACTÈRE NÜSHU-1B21C",NULL},
/* 1B21D */ { "CARACTÈRE NÜSHU-1B21D",NULL},
/* 1B21E */ { "CARACTÈRE NÜSHU-1B21E",NULL},
/* 1B21F */ { "CARACTÈRE NÜSHU-1B21F",NULL},
/* 1B220 */ { "CARACTÈRE NÜSHU-1B220",NULL},
/* 1B221 */ { "CARACTÈRE NÜSHU-1B221",NULL},
/* 1B222 */ { "CARACTÈRE NÜSHU-1B222",NULL},
/* 1B223 */ { "CARACTÈRE NÜSHU-1B223",NULL},
/* 1B224 */ { "CARACTÈRE NÜSHU-1B224",NULL},
/* 1B225 */ { "CARACTÈRE NÜSHU-1B225",NULL},
/* 1B226 */ { "CARACTÈRE NÜSHU-1B226",NULL},
/* 1B227 */ { "CARACTÈRE NÜSHU-1B227",NULL},
/* 1B228 */ { "CARACTÈRE NÜSHU-1B228",NULL},
/* 1B229 */ { "CARACTÈRE NÜSHU-1B229",NULL},
/* 1B22A */ { "CARACTÈRE NÜSHU-1B22A",NULL},
/* 1B22B */ { "CARACTÈRE NÜSHU-1B22B",NULL},
/* 1B22C */ { "CARACTÈRE NÜSHU-1B22C",NULL},
/* 1B22D */ { "CARACTÈRE NÜSHU-1B22D",NULL},
/* 1B22E */ { "CARACTÈRE NÜSHU-1B22E","	x 6286"},
/* 1B22F */ { "CARACTÈRE NÜSHU-1B22F",NULL},
/* 1B230 */ { "CARACTÈRE NÜSHU-1B230",NULL},
/* 1B231 */ { "CARACTÈRE NÜSHU-1B231",NULL},
/* 1B232 */ { "CARACTÈRE NÜSHU-1B232",NULL},
/* 1B233 */ { "CARACTÈRE NÜSHU-1B233",NULL},
/* 1B234 */ { "CARACTÈRE NÜSHU-1B234",NULL},
/* 1B235 */ { "CARACTÈRE NÜSHU-1B235",NULL},
/* 1B236 */ { "CARACTÈRE NÜSHU-1B236",NULL},
/* 1B237 */ { "CARACTÈRE NÜSHU-1B237",NULL},
/* 1B238 */ { "CARACTÈRE NÜSHU-1B238",NULL},
/* 1B239 */ { "CARACTÈRE NÜSHU-1B239",NULL},
/* 1B23A */ { "CARACTÈRE NÜSHU-1B23A",NULL},
/* 1B23B */ { "CARACTÈRE NÜSHU-1B23B",NULL},
/* 1B23C */ { "CARACTÈRE NÜSHU-1B23C",NULL},
/* 1B23D */ { "CARACTÈRE NÜSHU-1B23D",NULL},
/* 1B23E */ { "CARACTÈRE NÜSHU-1B23E",NULL},
/* 1B23F */ { "CARACTÈRE NÜSHU-1B23F",NULL},
/* 1B240 */ { "CARACTÈRE NÜSHU-1B240",NULL},
/* 1B241 */ { "CARACTÈRE NÜSHU-1B241",NULL},
/* 1B242 */ { "CARACTÈRE NÜSHU-1B242",NULL},
/* 1B243 */ { "CARACTÈRE NÜSHU-1B243",NULL},
/* 1B244 */ { "CARACTÈRE NÜSHU-1B244","	x 91CC"},
/* 1B245 */ { "CARACTÈRE NÜSHU-1B245",NULL},
/* 1B246 */ { "CARACTÈRE NÜSHU-1B246",NULL},
/* 1B247 */ { "CARACTÈRE NÜSHU-1B247",NULL},
/* 1B248 */ { "CARACTÈRE NÜSHU-1B248",NULL},
/* 1B249 */ { "CARACTÈRE NÜSHU-1B249",NULL},
/* 1B24A */ { "CARACTÈRE NÜSHU-1B24A",NULL},
/* 1B24B */ { "CARACTÈRE NÜSHU-1B24B",NULL},
/* 1B24C */ { "CARACTÈRE NÜSHU-1B24C",NULL},
/* 1B24D */ { "CARACTÈRE NÜSHU-1B24D",NULL},
/* 1B24E */ { "CARACTÈRE NÜSHU-1B24E",NULL},
/* 1B24F */ { "CARACTÈRE NÜSHU-1B24F",NULL},
/* 1B250 */ { "CARACTÈRE NÜSHU-1B250",NULL},
/* 1B251 */ { "CARACTÈRE NÜSHU-1B251",NULL},
/* 1B252 */ { "CARACTÈRE NÜSHU-1B252",NULL},
/* 1B253 */ { "CARACTÈRE NÜSHU-1B253",NULL},
/* 1B254 */ { "CARACTÈRE NÜSHU-1B254",NULL},
/* 1B255 */ { "CARACTÈRE NÜSHU-1B255",NULL},
/* 1B256 */ { "CARACTÈRE NÜSHU-1B256",NULL},
/* 1B257 */ { "CARACTÈRE NÜSHU-1B257",NULL},
/* 1B258 */ { "CARACTÈRE NÜSHU-1B258",NULL},
/* 1B259 */ { "CARACTÈRE NÜSHU-1B259",NULL},
/* 1B25A */ { "CARACTÈRE NÜSHU-1B25A",NULL},
/* 1B25B */ { "CARACTÈRE NÜSHU-1B25B",NULL},
/* 1B25C */ { "CARACTÈRE NÜSHU-1B25C",NULL},
/* 1B25D */ { "CARACTÈRE NÜSHU-1B25D",NULL},
/* 1B25E */ { "CARACTÈRE NÜSHU-1B25E",NULL},
/* 1B25F */ { "CARACTÈRE NÜSHU-1B25F",NULL},
/* 1B260 */ { "CARACTÈRE NÜSHU-1B260",NULL},
/* 1B261 */ { "CARACTÈRE NÜSHU-1B261",NULL},
/* 1B262 */ { "CARACTÈRE NÜSHU-1B262",NULL},
/* 1B263 */ { "CARACTÈRE NÜSHU-1B263",NULL},
/* 1B264 */ { "CARACTÈRE NÜSHU-1B264",NULL},
/* 1B265 */ { "CARACTÈRE NÜSHU-1B265","	x 53F7"},
/* 1B266 */ { "CARACTÈRE NÜSHU-1B266",NULL},
/* 1B267 */ { "CARACTÈRE NÜSHU-1B267",NULL},
/* 1B268 */ { "CARACTÈRE NÜSHU-1B268",NULL},
/* 1B269 */ { "CARACTÈRE NÜSHU-1B269",NULL},
/* 1B26A */ { "CARACTÈRE NÜSHU-1B26A",NULL},
/* 1B26B */ { "CARACTÈRE NÜSHU-1B26B",NULL},
/* 1B26C */ { "CARACTÈRE NÜSHU-1B26C",NULL},
/* 1B26D */ { "CARACTÈRE NÜSHU-1B26D",NULL},
/* 1B26E */ { "CARACTÈRE NÜSHU-1B26E",NULL},
/* 1B26F */ { "CARACTÈRE NÜSHU-1B26F",NULL},
/* 1B270 */ { "CARACTÈRE NÜSHU-1B270",NULL},
/* 1B271 */ { "CARACTÈRE NÜSHU-1B271",NULL},
/* 1B272 */ { "CARACTÈRE NÜSHU-1B272",NULL},
/* 1B273 */ { "CARACTÈRE NÜSHU-1B273",NULL},
/* 1B274 */ { "CARACTÈRE NÜSHU-1B274",NULL},
/* 1B275 */ { "CARACTÈRE NÜSHU-1B275",NULL},
/* 1B276 */ { "CARACTÈRE NÜSHU-1B276",NULL},
/* 1B277 */ { "CARACTÈRE NÜSHU-1B277",NULL},
/* 1B278 */ { "CARACTÈRE NÜSHU-1B278",NULL},
/* 1B279 */ { "CARACTÈRE NÜSHU-1B279",NULL},
/* 1B27A */ { "CARACTÈRE NÜSHU-1B27A",NULL},
/* 1B27B */ { "CARACTÈRE NÜSHU-1B27B",NULL},
/* 1B27C */ { "CARACTÈRE NÜSHU-1B27C",NULL},
/* 1B27D */ { "CARACTÈRE NÜSHU-1B27D",NULL},
/* 1B27E */ { "CARACTÈRE NÜSHU-1B27E",NULL},
/* 1B27F */ { "CARACTÈRE NÜSHU-1B27F",NULL},
/* 1B280 */ { "CARACTÈRE NÜSHU-1B280",NULL},
/* 1B281 */ { "CARACTÈRE NÜSHU-1B281",NULL},
/* 1B282 */ { "CARACTÈRE NÜSHU-1B282",NULL},
/* 1B283 */ { "CARACTÈRE NÜSHU-1B283",NULL},
/* 1B284 */ { "CARACTÈRE NÜSHU-1B284",NULL},
/* 1B285 */ { "CARACTÈRE NÜSHU-1B285",NULL},
/* 1B286 */ { "CARACTÈRE NÜSHU-1B286",NULL},
/* 1B287 */ { "CARACTÈRE NÜSHU-1B287",NULL},
/* 1B288 */ { "CARACTÈRE NÜSHU-1B288",NULL},
/* 1B289 */ { "CARACTÈRE NÜSHU-1B289",NULL},
/* 1B28A */ { "CARACTÈRE NÜSHU-1B28A",NULL},
/* 1B28B */ { "CARACTÈRE NÜSHU-1B28B",NULL},
/* 1B28C */ { "CARACTÈRE NÜSHU-1B28C",NULL},
/* 1B28D */ { "CARACTÈRE NÜSHU-1B28D",NULL},
/* 1B28E */ { "CARACTÈRE NÜSHU-1B28E",NULL},
/* 1B28F */ { "CARACTÈRE NÜSHU-1B28F",NULL},
/* 1B290 */ { "CARACTÈRE NÜSHU-1B290",NULL},
/* 1B291 */ { "CARACTÈRE NÜSHU-1B291",NULL},
/* 1B292 */ { "CARACTÈRE NÜSHU-1B292",NULL},
/* 1B293 */ { "CARACTÈRE NÜSHU-1B293",NULL},
/* 1B294 */ { "CARACTÈRE NÜSHU-1B294",NULL},
/* 1B295 */ { "CARACTÈRE NÜSHU-1B295",NULL},
/* 1B296 */ { "CARACTÈRE NÜSHU-1B296",NULL},
/* 1B297 */ { "CARACTÈRE NÜSHU-1B297",NULL},
/* 1B298 */ { "CARACTÈRE NÜSHU-1B298",NULL},
/* 1B299 */ { "CARACTÈRE NÜSHU-1B299",NULL},
/* 1B29A */ { "CARACTÈRE NÜSHU-1B29A",NULL},
/* 1B29B */ { "CARACTÈRE NÜSHU-1B29B",NULL},
/* 1B29C */ { "CARACTÈRE NÜSHU-1B29C",NULL},
/* 1B29D */ { "CARACTÈRE NÜSHU-1B29D",NULL},
/* 1B29E */ { "CARACTÈRE NÜSHU-1B29E",NULL},
/* 1B29F */ { "CARACTÈRE NÜSHU-1B29F",NULL},
/* 1B2A0 */ { "CARACTÈRE NÜSHU-1B2A0",NULL},
/* 1B2A1 */ { "CARACTÈRE NÜSHU-1B2A1",NULL},
/* 1B2A2 */ { "CARACTÈRE NÜSHU-1B2A2",NULL},
/* 1B2A3 */ { "CARACTÈRE NÜSHU-1B2A3","	x 82F1"},
/* 1B2A4 */ { "CARACTÈRE NÜSHU-1B2A4",NULL},
/* 1B2A5 */ { "CARACTÈRE NÜSHU-1B2A5",NULL},
/* 1B2A6 */ { "CARACTÈRE NÜSHU-1B2A6",NULL},
/* 1B2A7 */ { "CARACTÈRE NÜSHU-1B2A7",NULL},
/* 1B2A8 */ { "CARACTÈRE NÜSHU-1B2A8",NULL},
/* 1B2A9 */ { "CARACTÈRE NÜSHU-1B2A9",NULL},
/* 1B2AA */ { "CARACTÈRE NÜSHU-1B2AA",NULL},
/* 1B2AB */ { "CARACTÈRE NÜSHU-1B2AB",NULL},
/* 1B2AC */ { "CARACTÈRE NÜSHU-1B2AC",NULL},
/* 1B2AD */ { "CARACTÈRE NÜSHU-1B2AD",NULL},
/* 1B2AE */ { "CARACTÈRE NÜSHU-1B2AE",NULL},
/* 1B2AF */ { "CARACTÈRE NÜSHU-1B2AF",NULL},
/* 1B2B0 */ { "CARACTÈRE NÜSHU-1B2B0",NULL},
/* 1B2B1 */ { "CARACTÈRE NÜSHU-1B2B1",NULL},
/* 1B2B2 */ { "CARACTÈRE NÜSHU-1B2B2",NULL},
/* 1B2B3 */ { "CARACTÈRE NÜSHU-1B2B3",NULL},
/* 1B2B4 */ { "CARACTÈRE NÜSHU-1B2B4",NULL},
/* 1B2B5 */ { "CARACTÈRE NÜSHU-1B2B5",NULL},
/* 1B2B6 */ { "CARACTÈRE NÜSHU-1B2B6",NULL},
/* 1B2B7 */ { "CARACTÈRE NÜSHU-1B2B7",NULL},
/* 1B2B8 */ { "CARACTÈRE NÜSHU-1B2B8",NULL},
/* 1B2B9 */ { "CARACTÈRE NÜSHU-1B2B9",NULL},
/* 1B2BA */ { "CARACTÈRE NÜSHU-1B2BA",NULL},
/* 1B2BB */ { "CARACTÈRE NÜSHU-1B2BB",NULL},
/* 1B2BC */ { "CARACTÈRE NÜSHU-1B2BC",NULL},
/* 1B2BD */ { "CARACTÈRE NÜSHU-1B2BD",NULL},
/* 1B2BE */ { "CARACTÈRE NÜSHU-1B2BE",NULL},
/* 1B2BF */ { "CARACTÈRE NÜSHU-1B2BF",NULL},
/* 1B2C0 */ { "CARACTÈRE NÜSHU-1B2C0",NULL},
/* 1B2C1 */ { "CARACTÈRE NÜSHU-1B2C1","	x 9580"},
/* 1B2C2 */ { "CARACTÈRE NÜSHU-1B2C2",NULL},
/* 1B2C3 */ { "CARACTÈRE NÜSHU-1B2C3",NULL},
/* 1B2C4 */ { "CARACTÈRE NÜSHU-1B2C4",NULL},
/* 1B2C5 */ { "CARACTÈRE NÜSHU-1B2C5",NULL},
/* 1B2C6 */ { "CARACTÈRE NÜSHU-1B2C6",NULL},
/* 1B2C7 */ { "CARACTÈRE NÜSHU-1B2C7",NULL},
/* 1B2C8 */ { "CARACTÈRE NÜSHU-1B2C8",NULL},
/* 1B2C9 */ { "CARACTÈRE NÜSHU-1B2C9",NULL},
/* 1B2CA */ { "CARACTÈRE NÜSHU-1B2CA",NULL},
/* 1B2CB */ { "CARACTÈRE NÜSHU-1B2CB",NULL},
/* 1B2CC */ { "CARACTÈRE NÜSHU-1B2CC",NULL},
/* 1B2CD */ { "CARACTÈRE NÜSHU-1B2CD",NULL},
/* 1B2CE */ { "CARACTÈRE NÜSHU-1B2CE",NULL},
/* 1B2CF */ { "CARACTÈRE NÜSHU-1B2CF",NULL},
/* 1B2D0 */ { "CARACTÈRE NÜSHU-1B2D0",NULL},
/* 1B2D1 */ { "CARACTÈRE NÜSHU-1B2D1","	x 57CB"},
/* 1B2D2 */ { "CARACTÈRE NÜSHU-1B2D2",NULL},
/* 1B2D3 */ { "CARACTÈRE NÜSHU-1B2D3",NULL},
/* 1B2D4 */ { "CARACTÈRE NÜSHU-1B2D4",NULL},
/* 1B2D5 */ { "CARACTÈRE NÜSHU-1B2D5",NULL},
/* 1B2D6 */ { "CARACTÈRE NÜSHU-1B2D6","	x 83AB"},
/* 1B2D7 */ { "CARACTÈRE NÜSHU-1B2D7",NULL},
/* 1B2D8 */ { "CARACTÈRE NÜSHU-1B2D8",NULL},
/* 1B2D9 */ { "CARACTÈRE NÜSHU-1B2D9",NULL},
/* 1B2DA */ { "CARACTÈRE NÜSHU-1B2DA",NULL},
/* 1B2DB */ { "CARACTÈRE NÜSHU-1B2DB",NULL},
/* 1B2DC */ { "CARACTÈRE NÜSHU-1B2DC",NULL},
/* 1B2DD */ { "CARACTÈRE NÜSHU-1B2DD",NULL},
/* 1B2DE */ { "CARACTÈRE NÜSHU-1B2DE",NULL},
/* 1B2DF */ { "CARACTÈRE NÜSHU-1B2DF",NULL},
/* 1B2E0 */ { "CARACTÈRE NÜSHU-1B2E0",NULL},
/* 1B2E1 */ { "CARACTÈRE NÜSHU-1B2E1",NULL},
/* 1B2E2 */ { "CARACTÈRE NÜSHU-1B2E2",NULL},
/* 1B2E3 */ { "CARACTÈRE NÜSHU-1B2E3",NULL},
/* 1B2E4 */ { "CARACTÈRE NÜSHU-1B2E4",NULL},
/* 1B2E5 */ { "CARACTÈRE NÜSHU-1B2E5",NULL},
/* 1B2E6 */ { "CARACTÈRE NÜSHU-1B2E6",NULL},
/* 1B2E7 */ { "CARACTÈRE NÜSHU-1B2E7",NULL},
/* 1B2E8 */ { "CARACTÈRE NÜSHU-1B2E8",NULL},
/* 1B2E9 */ { "CARACTÈRE NÜSHU-1B2E9",NULL},
/* 1B2EA */ { "CARACTÈRE NÜSHU-1B2EA",NULL},
/* 1B2EB */ { "CARACTÈRE NÜSHU-1B2EB",NULL},
/* 1B2EC */ { "CARACTÈRE NÜSHU-1B2EC",NULL},
/* 1B2ED */ { "CARACTÈRE NÜSHU-1B2ED",NULL},
/* 1B2EE */ { "CARACTÈRE NÜSHU-1B2EE",NULL},
/* 1B2EF */ { "CARACTÈRE NÜSHU-1B2EF",NULL},
/* 1B2F0 */ { "CARACTÈRE NÜSHU-1B2F0",NULL},
/* 1B2F1 */ { "CARACTÈRE NÜSHU-1B2F1",NULL},
/* 1B2F2 */ { "CARACTÈRE NÜSHU-1B2F2",NULL},
/* 1B2F3 */ { "CARACTÈRE NÜSHU-1B2F3",NULL},
/* 1B2F4 */ { "CARACTÈRE NÜSHU-1B2F4",NULL},
/* 1B2F5 */ { "CARACTÈRE NÜSHU-1B2F5",NULL},
/* 1B2F6 */ { "CARACTÈRE NÜSHU-1B2F6",NULL},
/* 1B2F7 */ { "CARACTÈRE NÜSHU-1B2F7",NULL},
/* 1B2F8 */ { "CARACTÈRE NÜSHU-1B2F8",NULL},
/* 1B2F9 */ { "CARACTÈRE NÜSHU-1B2F9",NULL},
/* 1B2FA */ { "CARACTÈRE NÜSHU-1B2FA",NULL},
/* 1B2FB */ { "CARACTÈRE NÜSHU-1B2FB",NULL},
/* 1B2FC */ { NULL,NULL},
/* 1B2FD */ { NULL,NULL},
/* 1B2FE */ { NULL,NULL},
/* 1B2FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_BC[] = {
/* 1BC00 */ { "LETTRE DE STÉNO DUPLOYÉ H","	* chinook, Pernin, Sloan, Perrault"},
/* 1BC01 */ { "LETTRE DE STÉNO DUPLOYÉ X","	* langues salishennes"},
/* 1BC02 */ { "LETTRE DE STÉNO DUPLOYÉ P","	* chinook : chiffre 1"},
/* 1BC03 */ { "LETTRE DE STÉNO DUPLOYÉ T","	* chinook : chiffre 2"},
/* 1BC04 */ { "LETTRE DE STÉNO DUPLOYÉ F","	* chinook : chiffre 3"},
/* 1BC05 */ { "LETTRE DE STÉNO DUPLOYÉ K","	* tracée en descendant et vers la gauche\n"
	"	* chinook : chiffre 4"},
/* 1BC06 */ { "LETTRE DE STÉNO DUPLOYÉ L","	* tracée en remontant et vers la droite\n"
	"	* Pernin : R"},
/* 1BC07 */ { "LETTRE DE STÉNO DUPLOYÉ B","	x (affixe de sténo duployé sécante verticale souscrite - 1BC73)\n"
	"	x (affixe de sténo duployé sécante verticale médiane - 1BC74)\n"
	"	x (affixe de sténo duployé sécante verticale suscrite - 1BC75)"},
/* 1BC08 */ { "LETTRE DE STÉNO DUPLOYÉ D","	x (affixe de sténo duployé sécante horizontale gauche - 1BC70)\n"
	"	x (affixe de sténo duployé sécante horizontale médiane - 1BC71)\n"
	"	x (affixe de sténo duployé sécante horizontale droite - 1BC72)"},
/* 1BC09 */ { "LETTRE DE STÉNO DUPLOYÉ V",NULL},
/* 1BC0A */ { "LETTRE DE STÉNO DUPLOYÉ G","	* tracée en descendant et vers la gauche"},
/* 1BC0B */ { "LETTRE DE STÉNO DUPLOYÉ R","	* tracée en remontant et vers la droite\n"
	"	* chinook : chiffre 5\n"
	"	* français : milliards\n"
	"	* Pernin : L\n"
	"	* Pernin (Practical Reporter) : signe de répétition de mot"},
/* 1BC0C */ { "LETTRE DE STÉNO DUPLOYÉ P N","	* Sloan : B B\n"
	"	x (lettre de sténo duployé p - 1BC02)\n"
	"	x (lettre de sténo duployé n - 1BC1A)"},
/* 1BC0D */ { "LETTRE DE STÉNO DUPLOYÉ D S","	* Sloan : D D\n"
	"	x (lettre de sténo duployé d - 1BC08)\n"
	"	x (lettre de sténo duployé s - 1BC1C)"},
/* 1BC0E */ { "LETTRE DE STÉNO DUPLOYÉ F N","	* Sloan : V V\n"
	"	x (lettre de sténo duployé f - 1BC04)\n"
	"	x (lettre de sténo duployé n - 1BC1A)"},
/* 1BC0F */ { "LETTRE DE STÉNO DUPLOYÉ K M","	* tracée en descendant et vers la gauche\n"
	"	* Sloan : G G\n"
	"	x (lettre de sténo duployé k - 1BC05)\n"
	"	x (lettre de sténo duployé m - 1BC19)"},
/* 1BC10 */ { "LETTRE DE STÉNO DUPLOYÉ R S","	* tracée en remontant et vers la droite\n"
	"	* Sloan : R R\n"
	"	x (lettre de sténo duployé r - 1BC0B)\n"
	"	x (lettre de sténo duployé s - 1BC1C)"},
/* 1BC11 */ { "LETTRE DE STÉNO DUPLOYÉ TH","	* chinook, Sloan, Pernin, Perrault"},
/* 1BC12 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN DH",NULL},
/* 1BC13 */ { "LETTRE DE STÉNO DUPLOYÉ DH","	* chinook\n"
	"	x (lettre de sténo duployé d - 1BC08)"},
/* 1BC14 */ { "LETTRE DE STÉNO DUPLOYÉ KK","	* tracée en descendant et vers la gauche\n"
	"	* chinook"},
/* 1BC15 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN J","	* tracée en descendant et vers la gauche"},
/* 1BC16 */ { "LETTRE DE STÉNO DUPLOYÉ HL","	* tracée en remontant et vers la droite\n"
	"	* chinook"},
/* 1BC17 */ { "LETTRE DE STÉNO DUPLOYÉ LH","	* tracée en remontant et vers la droite\n"
	"	* chinook"},
/* 1BC18 */ { "LETTRE DE STÉNO DUPLOYÉ RH","	* tracée en remontant et vers la droite\n"
	"	* chinook"},
/* 1BC19 */ { "LETTRE DE STÉNO DUPLOYÉ M","	* chinook : chiffre 6"},
/* 1BC1A */ { "LETTRE DE STÉNO DUPLOYÉ N","	* chinook : chiffre 7"},
/* 1BC1B */ { "LETTRE DE STÉNO DUPLOYÉ J","	* chinook : chiffre 8\n"
	"	* chinook, Pernin : sh"},
/* 1BC1C */ { "LETTRE DE STÉNO DUPLOYÉ S","	* chinook : chiffre 9\n"
	"	* français : centaines"},
/* 1BC1D */ { "LETTRE DE STÉNO DUPLOYÉ M N","	* roumain : mai mult (pas le signe roumain « mult mai »)"},
/* 1BC1E */ { "LETTRE DE STÉNO DUPLOYÉ N M","	* pas le signe roumain « nu nu »"},
/* 1BC1F */ { "LETTRE DE STÉNO DUPLOYÉ J M","	* pas le signe roumain « ceea ce »"},
/* 1BC20 */ { "LETTRE DE STÉNO DUPLOYÉ S J","	* pas le signe roumain « să se »"},
/* 1BC21 */ { "LETTRE DE STÉNO DUPLOYÉ M POINT","	* roumain : mijloc"},
/* 1BC22 */ { "LETTRE DE STÉNO DUPLOYÉ N POINT","	* chinook : ng\n"
	"	* roumain : signe nici"},
/* 1BC23 */ { "LETTRE DE STÉNO DUPLOYÉ J POINT","	* chinook : ch\n"
	"	* roumain : ce, ci\n"
	"	* Sloan : zh\n"
	"	* chinook, Perrault : j"},
/* 1BC24 */ { "LETTRE DE STÉNO DUPLOYÉ J POINT MÉDIAN ET POINT SUSCRIT","	* signe isolé\n"
	"	* roumain : signe ici și colo"},
/* 1BC25 */ { "LETTRE DE STÉNO DUPLOYÉ S POINT","	* chinook : ts\n"
	"	* chinook, roumain, Sloan : z"},
/* 1BC26 */ { "LETTRE DE STÉNO DUPLOYÉ S POINT SOUSCRIT","	* roumain : ș"},
/* 1BC27 */ { "LETTRE DE STÉNO DUPLOYÉ M S","	* Sloan : m m"},
/* 1BC28 */ { "LETTRE DE STÉNO DUPLOYÉ N S","	* Pernin, Sloan, Perrault : ng"},
/* 1BC29 */ { "LETTRE DE STÉNO DUPLOYÉ J S","	* roumain : ge, gi\n"
	"	* Pernin, Perrault : zh\n"
	"	* Sloan : ch"},
/* 1BC2A */ { "LETTRE DE STÉNO DUPLOYÉ S S","	* français, Sloan\n"
	"	* roumain : ț\n"
	"	* Pernin, Perrault : z"},
/* 1BC2B */ { "LETTRE DE STÉNO DUPLOYÉ M N S",NULL},
/* 1BC2C */ { "LETTRE DE STÉNO DUPLOYÉ N M S",NULL},
/* 1BC2D */ { "LETTRE DE STÉNO DUPLOYÉ J M S",NULL},
/* 1BC2E */ { "LETTRE DE STÉNO DUPLOYÉ S J S",NULL},
/* 1BC2F */ { "LETTRE DE STÉNO DUPLOYÉ J S POINT","	* Sloan : ch dur\n"
	"	* Pernin, Perrault : ch"},
/* 1BC30 */ { "LETTRE DE STÉNO DUPLOYÉ J N",NULL},
/* 1BC31 */ { "LETTRE DE STÉNO DUPLOYÉ J N S",NULL},
/* 1BC32 */ { "LETTRE DE STÉNO DUPLOYÉ S T","	* Pernin, Perrault\n"
	"	* Sloan : sm"},
/* 1BC33 */ { "LETTRE DE STÉNO DUPLOYÉ S T R","	* Pernin, Perrault\n"
	"	* Sloan : sn"},
/* 1BC34 */ { "LETTRE DE STÉNO DUPLOYÉ S P","	* Pernin, Perrault\n"
	"	* Sloan : kw"},
/* 1BC35 */ { "LETTRE DE STÉNO DUPLOYÉ S P R","	* Pernin, Perrault\n"
	"	* Sloan : skw"},
/* 1BC36 */ { "LETTRE DE STÉNO DUPLOYÉ T S","	* Perrault\n"
	"	* Sloan : std"},
/* 1BC37 */ { "LETTRE DE STÉNO DUPLOYÉ T R S","	* Perrault\n"
	"	* Sloan : sst"},
/* 1BC38 */ { "LETTRE DE STÉNO DUPLOYÉ W","	* Sloan, Perrault, Pernin\n"
	"	* prend la forme d'un crochet ou d'une onde après k et g"},
/* 1BC39 */ { "LETTRE DE STÉNO DUPLOYÉ WH",NULL},
/* 1BC3A */ { "LETTRE DE STÉNO DUPLOYÉ W R","	* Perrault\n"
	"	* Sloan : sw"},
/* 1BC3B */ { "LETTRE DE STÉNO DUPLOYÉ S N","	* Perrault\n"
	"	* Pernin : krs\n"
	"	* Sloan : sp"},
/* 1BC3C */ { "LETTRE DE STÉNO DUPLOYÉ S M","	* Perrault\n"
	"	* Pernin : grs\n"
	"	* Sloan : sl"},
/* 1BC3D */ { "LETTRE DE STÉNO DUPLOYÉ K R S","	* Perrault"},
/* 1BC3E */ { "LETTRE DE STÉNO DUPLOYÉ G R S","	* Perrault"},
/* 1BC3F */ { "LETTRE DE STÉNO DUPLOYÉ S K","	* Perrault, Pernin\n"
	"	* Sloan : ts"},
/* 1BC40 */ { "LETTRE DE STÉNO DUPLOYÉ S K R","	* Perrault, Pernin\n"
	"	* Sloan : ds"},
/* 1BC41 */ { "LETTRE DE STÉNO DUPLOYÉ A","	* chinook : dizaines"},
/* 1BC42 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN OW","	* voyelle en cercle réfléchi"},
/* 1BC43 */ { "LETTRE DE STÉNO DUPLOYÉ OA","	* Pernin : aw\n"
	"	* Perrault : aw"},
/* 1BC44 */ { "LETTRE DE STÉNO DUPLOYÉ O","	* chinook : chiffre 0"},
/* 1BC45 */ { "LETTRE DE STÉNO DUPLOYÉ AOU",NULL},
/* 1BC46 */ { "LETTRE DE STÉNO DUPLOYÉ I","	* tracée de façon à s'adapter à l'angle de sortie du caractère précédent\n"
	"	* orientation primaire (à droite et vers le haut)\n"
	"	* Perrault : a long, e bref (avec accents)"},
/* 1BC47 */ { "LETTRE DE STÉNO DUPLOYÉ E","	* tracée de façon à s'adapter à l'angle de sortie du caractère précédent\n"
	"	* orientation secondaire (à gauche et vers le bas)\n"
	"	* Sloan : a long\n"
	"	* Perrault : i bref, e long (avec point)\n"
	"	x (affixe de sténo duployé e crochet attaché - 1BC7A)"},
/* 1BC48 */ { "LETTRE DE STÉNO DUPLOYÉ IE","	* sert de voyelle fixe et dans les abréviations composées de voyelles seulement\n"
	"	* Duployé\n"
	"	* Pernin : a"},
/* 1BC49 */ { "LETTRE DE STÉNO DUPLOYÉ I BREF","	* sert de voyelle fixe et dans les abréviations composées de voyelles seulement\n"
	"	* Pernin, Duployé\n"
	"	* Duployé consolidé : r t r"},
/* 1BC4A */ { "LETTRE DE STÉNO DUPLOYÉ UI","	* sert de voyelle fixe et dans les abréviations composées de voyelles seulement\n"
	"	* Duployé\n"
	"	* Pernin : e"},
/* 1BC4B */ { "LETTRE DE STÉNO DUPLOYÉ EE","	* sert de voyelle fixe et dans les abréviations composées de voyelles seulement\n"
	"	* Pernin, Duployé"},
/* 1BC4C */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN EH",NULL},
/* 1BC4D */ { "LETTRE DE STÉNO DUPLOYÉ I ROUMAIN","	* tracée de façon à s'adapter à l'angle de sortie du caractère précédent, avec un point maintenant la position relative\n"
	"	* orientation secondaire (à gauche et vers le bas)"},
/* 1BC4E */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN EE",NULL},
/* 1BC4F */ { "LETTRE DE STÉNO DUPLOYÉ I LONG","	* Pernin\n"
	"	* même angle que le « f » lorsqu'elle est adjacente à une consonne de type « k »"},
/* 1BC50 */ { "LETTRE DE STÉNO DUPLOYÉ YE",NULL},
/* 1BC51 */ { "LETTRE DE STÉNO DUPLOYÉ U","	* tracée de façon à s'adapter à l'angle de sortie du caractère précédent\n"
	"	* orientation primaire (à droite et vers le haut)\n"
	"	* roumain : en\n"
	"	x (lettre de sténo duployé w - 1BC38)\n"
	"	x (lettre de sténo duployé u roumain - 1BC56)\n"
	"	x (lettre de sténo duployé u long - 1BC55)"},
/* 1BC52 */ { "LETTRE DE STÉNO DUPLOYÉ EU","	* tracée de façon à s'adapter à l'angle de sortie du caractère précédent\n"
	"	* orientation secondaire (à gauche et vers le bas)\n"
	"	* roumain : an\n"
	"	* dans l'usage français, peut avoir un point dans certaines circonstances"},
/* 1BC53 */ { "LETTRE DE STÉNO DUPLOYÉ XW","	* Perrault : oû\n"
	"	* pas le « eu » du français"},
/* 1BC54 */ { "LETTRE DE STÉNO DUPLOYÉ U N","	x (lettre de sténo duployé n - 1BC1A)"},
/* 1BC55 */ { "LETTRE DE STÉNO DUPLOYÉ U LONG","	* ne peut pas pivoter de façon à s'adapter à l'angle de sortie du caractère précédent\n"
	"	* Pernin, Perrault"},
/* 1BC56 */ { "LETTRE DE STÉNO DUPLOYÉ U ROUMAIN",NULL},
/* 1BC57 */ { "LETTRE DE STÉNO DUPLOYÉ UH","	* Sloan"},
/* 1BC58 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN U",NULL},
/* 1BC59 */ { "LETTRE DE STÉNO DUPLOYÉ OOH","	* Sloan"},
/* 1BC5A */ { "LETTRE DE STÉNO DUPLOYÉ OW","	* ne devrait pas être utilisée pour le « u » du roumain"},
/* 1BC5B */ { "LETTRE DE STÉNO DUPLOYÉ OU","	* ne devrait pas être utilisée pour le « ow » de Perrault\n"
	"	* chinook : oo"},
/* 1BC5C */ { "LETTRE DE STÉNO DUPLOYÉ WA","	* chinook\n"
	"	* chinook : centaines\n"
	"	* Perrault : oy\n"
	"	* pas la combinaison roumaine o + a"},
/* 1BC5D */ { "LETTRE DE STÉNO DUPLOYÉ WO","	* chinook"},
/* 1BC5E */ { "LETTRE DE STÉNO DUPLOYÉ WI","	* chinook"},
/* 1BC5F */ { "LETTRE DE STÉNO DUPLOYÉ WEI","	* langues salishennes"},
/* 1BC60 */ { "LETTRE DE STÉNO DUPLOYÉ WOW","	* langues salishennes"},
/* 1BC61 */ { "LETTRE DE STÉNO DUPLOYÉ U NASAL","	* orientation secondaire ; direction fixe vers le bas\n"
	"	* français : nombre 1\n"
	"	* Pernin : in\n"
	"	* Duployé consolidé : affixe int-r-"},
/* 1BC62 */ { "LETTRE DE STÉNO DUPLOYÉ O NASAL","	* orientation secondaire ; direction fixe vers le haut\n"
	"	* voyelle nasale neutre pour transcrire une voyelle nasale ambiguë d'orientation secondaire\n"
	"	* Pernin : om, im\n"
	"	* Perrault : lettres an, en, in, un (avec accents)\n"
	"	* Duployé consolidé : affixe int-r-"},
/* 1BC63 */ { "LETTRE DE STÉNO DUPLOYÉ I NASAL","	* orientation primaire ; direction fixe vers le bas\n"
	"	* Pernin : im\n"
	"	* Duployé consolidé : affixe int-r-"},
/* 1BC64 */ { "LETTRE DE STÉNO DUPLOYÉ A NASAL","	* orientation primaire ; direction fixe vers le haut\n"
	"	* voyelle nasale neutre pour transcrire une voyelle nasale ambiguë d'orientation primaire\n"
	"	* Perrault : n vocalique - an, en, in, un (avec accents)\n"
	"	* Pernin : on\n"
	"	* roumain : în\n"
	"	* roumain : préfixe numéral multiplicatif"},
/* 1BC65 */ { "LETTRE DE STÉNO DUPLOYÉ-PERNIN AN","	* tracée vers le bas"},
/* 1BC66 */ { "LETTRE DE STÉNO DUPLOYÉ-PERNIN AM","	* tracée vers le bas"},
/* 1BC67 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN EN",NULL},
/* 1BC68 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN AN",NULL},
/* 1BC69 */ { "LETTRE DE STÉNO DUPLOYÉ-SLOAN ON",NULL},
/* 1BC6A */ { "LETTRE DE STÉNO DUPLOYÉ M VOCALIQUE","	* voyelle d'orientation primaire\n"
	"	* Perrault : am, em, im, um (avec accents)"},
/* 1BC6B */ { NULL,NULL},
/* 1BC6C */ { NULL,NULL},
/* 1BC6D */ { NULL,NULL},
/* 1BC6E */ { NULL,NULL},
/* 1BC6F */ { NULL,NULL},
/* 1BC70 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE HORIZONTALE GAUCHE","	* Pernin (Practical Reporter) : extra-\n"
	"	x (lettre de sténo duployé d - 1BC08)"},
/* 1BC71 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE HORIZONTALE MÉDIANE","	* Pernin (Practical Reporter) : inter-"},
/* 1BC72 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE HORIZONTALE DROITE","	* Pernin (Practical Reporter) : contra-"},
/* 1BC73 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE VERTICALE SOUSCRITE","	* Pernin (Practical Reporter) : sub-\n"
	"	x (lettre de sténo duployé b - 1BC07)"},
/* 1BC74 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE VERTICALE MÉDIANE","	* Pernin (Practical Reporter) : trans-"},
/* 1BC75 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE VERTICALE SUSCRITE","	* Pernin (Practical Reporter) : super-"},
/* 1BC76 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE ATTACHÉE","	* croise généralement à angle droit un caractère adjacent, mais a tendance à s'incliner en direction de l'angle sud-ouest/nord-est, contrairement à 1BC77\n"
	"	* en préfixe, prend une position relative opposée à celle du glyphe suivant\n"
	"	* affixe sécant neutre par défaut\n"
	"	* français : suffixe -anse\n"
	"	* Pernin : préfixe pre-\n"
	"	* Sloan : affixe ax-/-ext"},
/* 1BC77 */ { "AFFIXE DE STÉNO DUPLOYÉ SÉCANTE GAUCHE À DROITE ATTACHÉE","	* croise généralement à angle droit un caractère adjacent, mais a tendance à s'incliner en direction de l'angle nord-ouest/sud-est, contrairement à 1BC76\n"
	"	* en suffixe, prend une position relative opposée à celle du glyphe suivant\n"
	"	* Pernin : préfixe per-"},
/* 1BC78 */ { "AFFIXE DE STÉNO DUPLOYÉ TANGENTE ATTACHÉE","	* en préfixe, prend une position relative opposée à celle du glyphe suivant\n"
	"	* français : suffixe -tan\n"
	"	* roumain : str-/-str"},
/* 1BC79 */ { "AFFIXE DE STÉNO DUPLOYÉ HAMEÇON ATTACHÉ","	* caractère mobile\n"
	"	* français : suffixe -sionnaire"},
/* 1BC7A */ { "AFFIXE DE STÉNO DUPLOYÉ E CROCHET ATTACHÉ","	* glyphe rétrograde s'ouvrant vers le haut ou le vers le bas en fonction de la lettre précédente\n"
	"	* français : suffixe -te\n"
	"	x (lettre de sténo duployé e - 1BC47)"},
/* 1BC7B */ { "AFFIXE DE STÉNO DUPLOYÉ I CROCHET ATTACHÉ","	* glyphe rétrograde s'ouvrant vers la gauche ou vers la droite en fonction de la lettre précédente\n"
	"	* français : suffixe -tou\n"
	"	* Sloan : affixe irre-/-ary\n"
	"	x (lettre de sténo duployé i - 1BC46)"},
/* 1BC7C */ { "AFFIXE DE STÉNO DUPLOYÉ CROSSE TANGENTE ATTACHÉE","	* affixe attaché\n"
	"	* roumain : affixe ist-/-ism\n"
	"	* Duployé consolidé : préfixe t-r-"},
/* 1BC7D */ { NULL,NULL},
/* 1BC7E */ { NULL,NULL},
/* 1BC7F */ { NULL,NULL},
/* 1BC80 */ { "AFFIXE DE STÉNO DUPLOYÉ AIGU SUSCRIT","	* français : suffixe -ment\n"
	"	* roumain : suffixe -mant\n"
	"	* Pernin : sub-\n"
	"	* Pernin (Practical Reporter) : préfixe pro-\n"
	"	x (lettre modificative accent aigu - 02CA)"},
/* 1BC81 */ { "AFFIXE DE STÉNO DUPLOYÉ AIGU SERRÉ SUSCRIT","	* en suffixe, se place au-dessus et sur la droite de la lettre suivante\n"
	"	* Pernin : pro-"},
/* 1BC82 */ { "AFFIXE DE STÉNO DUPLOYÉ GRAVE SUSCRIT","	* français : suffixe -ien\n"
	"	* Pernin : préfixe con-\n"
	"	x (lettre modificative accent grave - 02CB)"},
/* 1BC83 */ { "AFFIXE DE STÉNO DUPLOYÉ GRAVE LONG SUSCRIT","	* Pernin : préfixe contra-"},
/* 1BC84 */ { "AFFIXE DE STÉNO DUPLOYÉ POINT SUSCRIT","	* français : milliers\n"
	"	* français : suffixe -eur\n"
	"	* roumain : affixe trans-/-lui\n"
	"	* pas pour les centaines en roumain ; utiliser 0307 et 0308\n"
	"	x (point en chef - 02D9)"},
/* 1BC85 */ { "AFFIXE DE STÉNO DUPLOYÉ CERCLE SUSCRIT","	* français : nombre ordinal\n"
	"	* français : suffixe -euse\n"
	"	* pas pour le suffixe degré ou pour cent en roumain\n"
	"	x (symbole degré - 00B0)\n"
	"	x (rond en chef - 02DA)"},
/* 1BC86 */ { "AFFIXE DE STÉNO DUPLOYÉ LIGNE SUSCRITE","	* français : suffixe -iste\n"
	"	* roumain : affixe -tor\n"
	"	* Pernin : affixe dis-\n"
	"	x (lettre modificative macron - 02C9)"},
/* 1BC87 */ { "AFFIXE DE STÉNO DUPLOYÉ ONDE SUSCRITE","	* français : suffixe -ificatif\n"
	"	x (petit tilde - 02DC)"},
/* 1BC88 */ { "AFFIXE DE STÉNO DUPLOYÉ VERTICAL SUSCRIT","	* sert aussi d'affixe attaché vertical suscrit, avec 200D (liant sans chasse)\n"
	"	* environ deux fois plus court que la lettre de sténo Duployé p\n"
	"	* en préfixe, tracé en descendant\n"
	"	* Pernin : 200D + -ime\n"
	"	* Sloan : tele-\n"
	"	x (lettre de sténo duployé p - 1BC02)"},
/* 1BC89 */ { NULL,NULL},
/* 1BC8A */ { NULL,NULL},
/* 1BC8B */ { NULL,NULL},
/* 1BC8C */ { NULL,NULL},
/* 1BC8D */ { NULL,NULL},
/* 1BC8E */ { NULL,NULL},
/* 1BC8F */ { NULL,NULL},
/* 1BC90 */ { "AFFIXE DE STÉNO DUPLOYÉ AIGU SOUSCRIT","	* français : suffixe -cion\n"
	"	* Pernin : préfixe ex-\n"
	"	x (lettre modificative accent aigu bas - 02CF)"},
/* 1BC91 */ { "AFFIXE DE STÉNO DUPLOYÉ AIGU SERRÉ SOUSCRIT","	* en suffixe, se place en dessous et sur la droite de la lettre suivante\n"
	"	* Pernin : suf-, sug-"},
/* 1BC92 */ { "AFFIXE DE STÉNO DUPLOYÉ GRAVE SOUSCRIT","	* français : suffixe -ion\n"
	"	* français : millions\n"
	"	x (lettre modificative accent grave bas - 02CE)"},
/* 1BC93 */ { "AFFIXE DE STÉNO DUPLOYÉ GRAVE LONG SOUSCRIT","	* Pernin : extra-"},
/* 1BC94 */ { "AFFIXE DE STÉNO DUPLOYÉ POINT SOUSCRIT","	* français : suffixe -ié\n"
	"	* français : nombre itératif\n"
	"	* roumain : affixe inter-\n"
	"	* pas pour « millions » en roumain ; utiliser 0323 et 0324"},
/* 1BC95 */ { "AFFIXE DE STÉNO DUPLOYÉ CERCLE SOUSCRIT","	* français : suffixe -ière\n"
	"	* français : pour cent\n"
	"	x (lettre modificative rond bas - 02F3)"},
/* 1BC96 */ { "AFFIXE DE STÉNO DUPLOYÉ LIGNE SOUSCRITE","	* français : suffixe -isme\n"
	"	* Pernin : affixe mis-\n"
	"	x (lettre modificative signe moins - 02D7)"},
/* 1BC97 */ { "AFFIXE DE STÉNO DUPLOYÉ ONDE SOUSCRITE","	* français : suffixe -ification\n"
	"	x (lettre modificative tilde bas - 02F7)"},
/* 1BC98 */ { "AFFIXE DE STÉNO DUPLOYÉ VERTICAL SOUSCRIT","	* sert aussi d'affixe attaché vertical souscrit, avec 200D (liant sans chasse)\n"
	"	* environ moitié moins long que la lettre de sténo Duployé p\n"
	"	* en préfixe, tracé en remontant\n"
	"	* Pernin : 200D + -ine\n"
	"	x (lettre de sténo duployé p - 1BC02)"},
/* 1BC99 */ { "AFFIXE DE STÉNO DUPLOYÉ FLÈCHE SOUSCRITE","	* roumain : préfixe sub-"},
/* 1BC9A */ { NULL,NULL},
/* 1BC9B */ { NULL,NULL},
/* 1BC9C */ { "SIGNE DE STÉNO DUPLOYÉ O CROIX","	* chinook : Likalisti"},
/* 1BC9D */ { "SÉLECTEUR DE LETTRE ÉPAISSE DE STÉNO DUPLOYÉ",NULL},
/* 1BC9E */ { "MARQUE DOUBLE DE STÉNO DUPLOYÉ","	* roumain, Sloan\n"
	"	* devrait être utilisée avec m, n, j et s pour les signes des mots roumains « mai mult », « nu nu », « ceea ce » et « să se »\n"
	"	* peut être doublée et triplée"},
/* 1BC9F */ { "PONCTUATION DE STÉNO DUPLOYÉ POINT CHINOOK",NULL},
/* 1BCA0 */ { "FORMATAGE DE STÉNO DE CHEVAUCHEMENT DE LETTRE",NULL},
/* 1BCA1 */ { "FORMATAGE DE STÉNO DE CHEVAUCHEMENT CONTINU",NULL},
/* 1BCA2 */ { "FORMATAGE DE STÉNO RABAISSEUR","	* roumain : affixe -tsion-\n"
	"	* Sloan : finale contractée oo/o + 200B"},
/* 1BCA3 */ { "FORMATAGE DE STÉNO REHAUSSEUR","	* Sloan : finale contractée uh/au/aui + 200B"},
/* 1BCA4 */ { NULL,NULL},
/* 1BCA5 */ { NULL,NULL},
/* 1BCA6 */ { NULL,NULL},
/* 1BCA7 */ { NULL,NULL},
/* 1BCA8 */ { NULL,NULL},
/* 1BCA9 */ { NULL,NULL},
/* 1BCAA */ { NULL,NULL},
/* 1BCAB */ { NULL,NULL},
/* 1BCAC */ { NULL,NULL},
/* 1BCAD */ { NULL,NULL},
/* 1BCAE */ { NULL,NULL},
/* 1BCAF */ { NULL,NULL},
/* 1BCB0 */ { NULL,NULL},
/* 1BCB1 */ { NULL,NULL},
/* 1BCB2 */ { NULL,NULL},
/* 1BCB3 */ { NULL,NULL},
/* 1BCB4 */ { NULL,NULL},
/* 1BCB5 */ { NULL,NULL},
/* 1BCB6 */ { NULL,NULL},
/* 1BCB7 */ { NULL,NULL},
/* 1BCB8 */ { NULL,NULL},
/* 1BCB9 */ { NULL,NULL},
/* 1BCBA */ { NULL,NULL},
/* 1BCBB */ { NULL,NULL},
/* 1BCBC */ { NULL,NULL},
/* 1BCBD */ { NULL,NULL},
/* 1BCBE */ { NULL,NULL},
/* 1BCBF */ { NULL,NULL},
/* 1BCC0 */ { NULL,NULL},
/* 1BCC1 */ { NULL,NULL},
/* 1BCC2 */ { NULL,NULL},
/* 1BCC3 */ { NULL,NULL},
/* 1BCC4 */ { NULL,NULL},
/* 1BCC5 */ { NULL,NULL},
/* 1BCC6 */ { NULL,NULL},
/* 1BCC7 */ { NULL,NULL},
/* 1BCC8 */ { NULL,NULL},
/* 1BCC9 */ { NULL,NULL},
/* 1BCCA */ { NULL,NULL},
/* 1BCCB */ { NULL,NULL},
/* 1BCCC */ { NULL,NULL},
/* 1BCCD */ { NULL,NULL},
/* 1BCCE */ { NULL,NULL},
/* 1BCCF */ { NULL,NULL},
/* 1BCD0 */ { NULL,NULL},
/* 1BCD1 */ { NULL,NULL},
/* 1BCD2 */ { NULL,NULL},
/* 1BCD3 */ { NULL,NULL},
/* 1BCD4 */ { NULL,NULL},
/* 1BCD5 */ { NULL,NULL},
/* 1BCD6 */ { NULL,NULL},
/* 1BCD7 */ { NULL,NULL},
/* 1BCD8 */ { NULL,NULL},
/* 1BCD9 */ { NULL,NULL},
/* 1BCDA */ { NULL,NULL},
/* 1BCDB */ { NULL,NULL},
/* 1BCDC */ { NULL,NULL},
/* 1BCDD */ { NULL,NULL},
/* 1BCDE */ { NULL,NULL},
/* 1BCDF */ { NULL,NULL},
/* 1BCE0 */ { NULL,NULL},
/* 1BCE1 */ { NULL,NULL},
/* 1BCE2 */ { NULL,NULL},
/* 1BCE3 */ { NULL,NULL},
/* 1BCE4 */ { NULL,NULL},
/* 1BCE5 */ { NULL,NULL},
/* 1BCE6 */ { NULL,NULL},
/* 1BCE7 */ { NULL,NULL},
/* 1BCE8 */ { NULL,NULL},
/* 1BCE9 */ { NULL,NULL},
/* 1BCEA */ { NULL,NULL},
/* 1BCEB */ { NULL,NULL},
/* 1BCEC */ { NULL,NULL},
/* 1BCED */ { NULL,NULL},
/* 1BCEE */ { NULL,NULL},
/* 1BCEF */ { NULL,NULL},
/* 1BCF0 */ { NULL,NULL},
/* 1BCF1 */ { NULL,NULL},
/* 1BCF2 */ { NULL,NULL},
/* 1BCF3 */ { NULL,NULL},
/* 1BCF4 */ { NULL,NULL},
/* 1BCF5 */ { NULL,NULL},
/* 1BCF6 */ { NULL,NULL},
/* 1BCF7 */ { NULL,NULL},
/* 1BCF8 */ { NULL,NULL},
/* 1BCF9 */ { NULL,NULL},
/* 1BCFA */ { NULL,NULL},
/* 1BCFB */ { NULL,NULL},
/* 1BCFC */ { NULL,NULL},
/* 1BCFD */ { NULL,NULL},
/* 1BCFE */ { NULL,NULL},
/* 1BCFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_CC[] = {
/* 1CC00 */ { "GO-KART POINTANT VERS LE HAUT",NULL},
/* 1CC01 */ { "GO-KART POINTANT À DROITE",NULL},
/* 1CC02 */ { "BONHOMME ALLUMETTE POINTANT À GAUCHE",NULL},
/* 1CC03 */ { "BONHOMME ALLUMETTE POINTANT À DROITE",NULL},
/* 1CC04 */ { "BONHOMME ALLUMETTE POINTANT VERS LE BAS",NULL},
/* 1CC05 */ { "SEGMENT DE RÈGLE HORIZONTAL INFÉRIEUR",NULL},
/* 1CC06 */ { "SEGMENT DE RÈGLE VERTICAL DROIT",NULL},
/* 1CC07 */ { "SEGMENT DE RÈGLE DROIT INFÉRIEUR",NULL},
/* 1CC08 */ { "ANTENNE",NULL},
/* 1CC09 */ { "SEGMENT HORIZONTAL DE RÉSISTANCE",NULL},
/* 1CC0A */ { "SEGMENT VERTICAL DE RÉSISTANCE",NULL},
/* 1CC0B */ { "TIERS GAUCHE D'INDUCTEUR",NULL},
/* 1CC0C */ { "TIERS CENTRAL D'INDUCTEUR",NULL},
/* 1CC0D */ { "TIERS DROIT D'INDUCTEUR",NULL},
/* 1CC0E */ { "DIODE POINTANT À GAUCHE",NULL},
/* 1CC0F */ { "DIODE POINTANT À DROITE",NULL},
/* 1CC10 */ { "TRANSISTOR NPN",NULL},
/* 1CC11 */ { "TRANSISTOR PNP",NULL},
/* 1CC12 */ { "RÉCEPTACLE",NULL},
/* 1CC13 */ { "CONDENSATEUR HORIZONTAL",NULL},
/* 1CC14 */ { "CONDENSATEUR VERTICAL",NULL},
/* 1CC15 */ { "PORTE LOGIQUE OU",NULL},
/* 1CC16 */ { "PORTE LOGIQUE ET",NULL},
/* 1CC17 */ { "PORTE LOGIQUE AVEC ENTRÉES INVERSÉES",NULL},
/* 1CC18 */ { "PORTE LOGIQUE AVEC SORTIE INVERSÉE",NULL},
/* 1CC19 */ { "PORTE LOGIQUE TAMPON",NULL},
/* 1CC1A */ { "PORTE LOGIQUE TAMPON AVEC ENTRÉE INVERSÉE",NULL},
/* 1CC1B */ { "FILET FIN HORIZONTAL ET SUPÉRIEUR DROIT",NULL},
/* 1CC1C */ { "FILET FIN HORIZONTAL ET INFÉRIEUR DROIT",NULL},
/* 1CC1D */ { "FILET FIN EN HAUT ET SUPÉRIEUR GAUCHE",NULL},
/* 1CC1E */ { "FILET FIN EN BAS ET INFÉRIEUR GAUCHE",NULL},
/* 1CC1F */ { "DOUBLE DIAGONALE DU COIN SUPÉRIEUR DROIT AU COIN INFÉRIEUR GAUCHE",NULL},
/* 1CC20 */ { "DOUBLE DIAGONALE DU COIN SUPÉRIEUR GAUCHE AU COIN INFÉRIEUR DROIT",NULL},
/* 1CC21 */ { "QUART DE PAVÉ ISOLÉ-1",NULL},
/* 1CC22 */ { "QUART DE PAVÉ ISOLÉ-2",NULL},
/* 1CC23 */ { "QUART DE PAVÉ ISOLÉ-12",NULL},
/* 1CC24 */ { "QUART DE PAVÉ ISOLÉ-3",NULL},
/* 1CC25 */ { "QUART DE PAVÉ ISOLÉ-13",NULL},
/* 1CC26 */ { "QUART DE PAVÉ ISOLÉ-23",NULL},
/* 1CC27 */ { "QUART DE PAVÉ ISOLÉ-123",NULL},
/* 1CC28 */ { "QUART DE PAVÉ ISOLÉ-4",NULL},
/* 1CC29 */ { "QUART DE PAVÉ ISOLÉ-14",NULL},
/* 1CC2A */ { "QUART DE PAVÉ ISOLÉ-24",NULL},
/* 1CC2B */ { "QUART DE PAVÉ ISOLÉ-124",NULL},
/* 1CC2C */ { "QUART DE PAVÉ ISOLÉ-34",NULL},
/* 1CC2D */ { "QUART DE PAVÉ ISOLÉ-134",NULL},
/* 1CC2E */ { "QUART DE PAVÉ ISOLÉ-234",NULL},
/* 1CC2F */ { "QUART DE PAVÉ ISOLÉ-1234",NULL},
/* 1CC30 */ { "DOUZIÈME DE CERCLE SUPÉRIEUR GAUCHE",NULL},
/* 1CC31 */ { "DOUZIÈME DE CERCLE CENTRE SUPÉRIEUR GAUCHE",NULL},
/* 1CC32 */ { "DOUZIÈME DE CERCLE CENTRE SUPÉRIEUR DROIT",NULL},
/* 1CC33 */ { "DOUZIÈME DE CERCLE SUPÉRIEUR DROIT",NULL},
/* 1CC34 */ { "DOUZIÈME DE CERCLE MILIEU SUPÉRIEUR GAUCHE",NULL},
/* 1CC35 */ { "QUART DE CERCLE SUPÉRIEUR GAUCHE",NULL},
/* 1CC36 */ { "QUART DE CERCLE SUPÉRIEUR DROIT",NULL},
/* 1CC37 */ { "DOUZIÈME DE CERCLE MILIEU SUPÉRIEUR DROIT",NULL},
/* 1CC38 */ { "DOUZIÈME DE CERCLE MILIEU INFÉRIEUR GAUCHE",NULL},
/* 1CC39 */ { "QUART DE CERCLE INFÉRIEUR GAUCHE",NULL},
/* 1CC3A */ { "QUART DE CERCLE INFÉRIEUR DROIT",NULL},
/* 1CC3B */ { "DOUZIÈME DE CERCLE MILIEU INFÉRIEUR DROIT",NULL},
/* 1CC3C */ { "DOUZIÈME DE CERCLE INFÉRIEUR GAUCHE",NULL},
/* 1CC3D */ { "DOUZIÈME DE CERCLE CENTRE INFÉRIEUR GAUCHE",NULL},
/* 1CC3E */ { "DOUZIÈME DE CERCLE CENTRE INFÉRIEUR DROIT",NULL},
/* 1CC3F */ { "DOUZIÈME DE CERCLE INFÉRIEUR DROIT",NULL},
/* 1CC40 */ { "REMPLISSAGE HORIZONTAL ÉPARS",NULL},
/* 1CC41 */ { "REMPLISSAGE VERTICAL ÉPARS",NULL},
/* 1CC42 */ { "REMPLISSAGE CROISILLON ORTHOGONAL",NULL},
/* 1CC43 */ { "REMPLISSAGE CROISILLON DIAGONAL",NULL},
/* 1CC44 */ { "REMPLISSAGE VERTICAL DENSE",NULL},
/* 1CC45 */ { "REMPLISSAGE HORIZONTAL DENSE",NULL},
/* 1CC46 */ { "CADRE DE REMPLISSAGE À POINTILLÉ-1",NULL},
/* 1CC47 */ { "CADRE DE REMPLISSAGE À POINTILLÉ-2",NULL},
/* 1CC48 */ { "BERCEAU ORIENTÉ À GAUCHE",NULL},
/* 1CC49 */ { "BERCEAU ORIENTÉ À DROITE",NULL},
/* 1CC4A */ { "SOUCOUPE VOLANTE AVEC RAYONS",NULL},
/* 1CC4B */ { "SOUCOUPE VOLANTE SANS RAYONS",NULL},
/* 1CC4C */ { "MONSTRE EXTRA-TERRESTRE MÂCHOIRES OUVERTES",NULL},
/* 1CC4D */ { "MONSTRE EXTRA-TERRESTRE MÂCHOIRES FERMÉES",NULL},
/* 1CC4E */ { "CALMAR EXTRA-TERRESTRE TENTACULES OUVERTES",NULL},
/* 1CC4F */ { "CALMAR EXTRA-TERRESTRE TENTACULES FERMÉES",NULL},
/* 1CC50 */ { "CRABE EXTRA-TERRESTRE SE DÉPLAÇANT À DROITE",NULL},
/* 1CC51 */ { "CRABE EXTRA-TERRESTRE SE DÉPLAÇANT À GAUCHE",NULL},
/* 1CC52 */ { "ARAIGNÉE EXTRA-TERRESTRE EN POSITION ACCROUPIE",NULL},
/* 1CC53 */ { "ARAIGNÉE EXTRA-TERRESTRE ÉTENDUE",NULL},
/* 1CC54 */ { "MONSTRE EXTRA-TERRESTRE ÉTAPE-1",NULL},
/* 1CC55 */ { "MONSTRE EXTRA-TERRESTRE ÉTAPE-2",NULL},
/* 1CC56 */ { "FUSÉE ORIENTÉE POINTANT À GAUCHE",NULL},
/* 1CC57 */ { "FUSÉE ORIENTÉE POINTANT VERS LE HAUT",NULL},
/* 1CC58 */ { "FUSÉE ORIENTÉE POINTANT À DROITE",NULL},
/* 1CC59 */ { "FUSÉE ORIENTÉE POINTANT VERS LE BAS",NULL},
/* 1CC5A */ { "MOITIÉ SUPÉRIEURE DE ROBOT ORIENTÉ À GAUCHE",NULL},
/* 1CC5B */ { "MOITIÉ SUPÉRIEURE DE ROBOT ORIENTÉ VERS L'AVANT",NULL},
/* 1CC5C */ { "MOITIÉ SUPÉRIEURE DE ROBOT ORIENTÉ À DROITE",NULL},
/* 1CC5D */ { "MOITIÉ INFÉRIEURE DE ROBOT ORIENTÉ À GAUCHE",NULL},
/* 1CC5E */ { "MOITIÉ INFÉRIEURE DE ROBOT ORIENTÉ VERS L'AVANT",NULL},
/* 1CC5F */ { "MOITIÉ INFÉRIEURE DE ROBOT ORIENTÉ À DROITE",NULL},
/* 1CC60 */ { "BOMBE ATOMIQUE POINTANT À GAUCHE",NULL},
/* 1CC61 */ { "BOMBE ATOMIQUE POINTANT VERS LE HAUT",NULL},
/* 1CC62 */ { "BOMBE ATOMIQUE POINTANT À DROITE",NULL},
/* 1CC63 */ { "BOMBE ATOMIQUE POINTANT VERS LE BAS",NULL},
/* 1CC64 */ { "NUAGE EN CHAMPIGNON",NULL},
/* 1CC65 */ { "FUSIL POINTANT À GAUCHE",NULL},
/* 1CC66 */ { "FUSIL POINTANT VERS LE HAUT",NULL},
/* 1CC67 */ { "FUSIL POINTANT À DROITE",NULL},
/* 1CC68 */ { "FUSIL POINTANT VERS LE BAS",NULL},
/* 1CC69 */ { "HUIT RAYONS VERS L'INTÉRIEUR",NULL},
/* 1CC6A */ { "HUIT RAYONS VERS L'EXTÉRIEUR",NULL},
/* 1CC6B */ { "GRAND CERCLE NOIR MOINS LE QUART GAUCHE",NULL},
/* 1CC6C */ { "GRAND CERCLE NOIR MOINS LE QUART SUPÉRIEUR",NULL},
/* 1CC6D */ { "GRAND CERCLE NOIR MOINS LE QUART DROIT",NULL},
/* 1CC6E */ { "GRAND CERCLE NOIR MOINS LE QUART INFÉRIEUR",NULL},
/* 1CC6F */ { "VISAGE NEUTRE NOIR",NULL},
/* 1CC70 */ { "TÊTE DE SERPENT ORIENTÉE À GAUCHE AVEC BOUCHE OUVERTE",NULL},
/* 1CC71 */ { "TÊTE DE SERPENT ORIENTÉE VERS LE HAUT AVEC BOUCHE OUVERTE",NULL},
/* 1CC72 */ { "TÊTE DE SERPENT ORIENTÉE À DROITE AVEC BOUCHE OUVERTE",NULL},
/* 1CC73 */ { "TÊTE DE SERPENT ORIENTÉE VERS LE BAS AVEC BOUCHE OUVERTE",NULL},
/* 1CC74 */ { "TÊTE DE SERPENT ORIENTÉE À GAUCHE AVEC BOUCHE FERMÉE",NULL},
/* 1CC75 */ { "TÊTE DE SERPENT ORIENTÉE VERS LE HAUT AVEC BOUCHE FERMÉE",NULL},
/* 1CC76 */ { "TÊTE DE SERPENT ORIENTÉE À DROITE AVEC BOUCHE FERMÉE",NULL},
/* 1CC77 */ { "TÊTE DE SERPENT ORIENTÉE VERS LE BAS AVEC BOUCHE FERMÉE",NULL},
/* 1CC78 */ { "VAGUE D'ÉNERGIE POINTANT À GAUCHE",NULL},
/* 1CC79 */ { "VAGUE D'ÉNERGIE POINTANT VERS LE HAUT",NULL},
/* 1CC7A */ { "VAGUE D'ÉNERGIE POINTANT À DROITE",NULL},
/* 1CC7B */ { "VAGUE D'ÉNERGIE POINTANT VERS LE BAS",NULL},
/* 1CC7C */ { "SPIRALE CARRÉE EN PARTANT DU COIN SUPÉRIEUR GAUCHE",NULL},
/* 1CC7D */ { "SPIRALE CARRÉE EN PARTANT DU COIN SUPÉRIEUR DROIT",NULL},
/* 1CC7E */ { "SPIRALE CARRÉE EN PARTANT DU COIN INFÉRIEUR DROIT",NULL},
/* 1CC7F */ { "SPIRALE CARRÉE EN PARTANT DU COIN INFÉRIEUR GAUCHE",NULL},
/* 1CC80 */ { "TRIANGLE À LIGNES POINTANT À GAUCHE",NULL},
/* 1CC81 */ { "TRIANGLE À LIGNES POINTANT VERS LE HAUT",NULL},
/* 1CC82 */ { "TRIANGLE À LIGNES POINTANT À DROITE",NULL},
/* 1CC83 */ { "TRIANGLE À LIGNES POINTANT VERS LE BAS",NULL},
/* 1CC84 */ { "ÉCHELLE VERTICALE",NULL},
/* 1CC85 */ { "ÉCHELLE HORIZONTALE",NULL},
/* 1CC86 */ { "POINTEUR BLANC INFÉRIEUR GAUCHE",NULL},
/* 1CC87 */ { "POINTEUR BLANC INFÉRIEUR DROIT",NULL},
/* 1CC88 */ { "DEUX ANNEAUX ALIGNÉS HORIZONTALEMENT","	x (symbole lié - 2BFA)"},
/* 1CC89 */ { "QUADRILATÈRE À QUATRE SAUTOIRS DANS LES ANGLES",NULL},
/* 1CC8A */ { "QUADRILATÈRE À QUATRE DIAGONALES DANS LES ANGLES",NULL},
/* 1CC8B */ { "QUADRILATÈRE À QUATRE TRIANGLES NOIRS DANS LES ANGLES",NULL},
/* 1CC8C */ { "OUVERTURE CARRÉE",NULL},
/* 1CC8D */ { "LOSANGE NOIR AU BLANC",NULL},
/* 1CC8E */ { "HUITIÈMES GAUCHE ET SUPÉRIEUR DE PAVÉ CONTENANT UN PETIT CARRÉ NOIR",NULL},
/* 1CC8F */ { "PETIT CARRÉ NOIR AU BLANC",NULL},
/* 1CC90 */ { "LIGNE VERTICALE AVEC QUATRE REPÈRES",NULL},
/* 1CC91 */ { "LIGNE HORIZONTALE AVEC QUATRE REPÈRES",NULL},
/* 1CC92 */ { "POISSON ORIENTÉ À GAUCHE",NULL},
/* 1CC93 */ { "POISSON ORIENTÉ À DROITE",NULL},
/* 1CC94 */ { "POISSON ORIENTÉ À GAUCHE AVEC LA BOUCHE OUVERTE",NULL},
/* 1CC95 */ { "POISSON ORIENTÉ À DROITE AVEC LA BOUCHE OUVERTE",NULL},
/* 1CC96 */ { "OISEAU BATTANT DES AILES",NULL},
/* 1CC97 */ { "VOITURE DE COURSE POINTANT VERS LA GAUCHE",NULL},
/* 1CC98 */ { "VOITURE DE COURSE POINTANT VERS LE HAUT",NULL},
/* 1CC99 */ { "VOITURE DE COURSE POINTANT VERS LA DROITE",NULL},
/* 1CC9A */ { "VOITURE DE COURSE POINTANT VERS LE BAS",NULL},
/* 1CC9B */ { "VOITURE DE COURSE HORIZONTALE",NULL},
/* 1CC9C */ { "VOITURE DE COURSE VERTICALE",NULL},
/* 1CC9D */ { "GO-KART VERTICAL",NULL},
/* 1CC9E */ { "TANK POINTANT VERS LA GAUCHE",NULL},
/* 1CC9F */ { "TANK POINTANT VERS LA DROITE",NULL},
/* 1CCA0 */ { "PROPULSEUR DE FUSÉE POINTANT VERS LA GAUCHE",NULL},
/* 1CCA1 */ { "PROPULSEUR DE FUSÉE POINTANT VERS LA DROITE",NULL},
/* 1CCA2 */ { "VÉHICULE DE MONTAGNES RUSSES POINTANT VERS LA GAUCHE",NULL},
/* 1CCA3 */ { "VÉHICULE DE MONTAGNES RUSSES POINTANT VERS LA DROITE",NULL},
/* 1CCA4 */ { "MOITIÉ GAUCHE DE SOUCOUPE VOLANTE",NULL},
/* 1CCA5 */ { "MOITIÉ DROITE DE SOUCOUPE VOLANTE",NULL},
/* 1CCA6 */ { "VISAGE AVEC YEUX OUVERTS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCA7 */ { "VISAGE AVEC YEUX OUVERTS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCA8 */ { "VISAGE AVEC YEUX FERMÉS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCA9 */ { "VISAGE AVEC YEUX FERMÉS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCAA */ { "VISAGE SOURIANT DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCAB */ { "VISAGE SOURIANT DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCAC */ { "VISAGE NEUTRE DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCAD */ { "VISAGE NEUTRE DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCAE */ { "VISAGE AVEC BOUCHE OUVERTE DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCAF */ { "VISAGE AVEC BOUCHE OUVERTE DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCB0 */ { "VISAGE FRONCÉ DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCB1 */ { "VISAGE FRONCÉ DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCB2 */ { "TÉLÉVISION DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCB3 */ { "TÉLÉVISION DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCB4 */ { "TÉLÉVISION DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCB5 */ { "TÉLÉVISION DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCB6 */ { "MICRO-ORDINATEUR DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCB7 */ { "MICRO-ORDINATEUR DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCB8 */ { "MICRO-ORDINATEUR DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCB9 */ { "MICRO-ORDINATEUR DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCBA */ { "ROI DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCBB */ { "ROI DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCBC */ { "ROI DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCBD */ { "ROI DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCBE */ { "DAME DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCBF */ { "DAME DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCC0 */ { "DAME DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCC1 */ { "DAME DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCC2 */ { "TOUR DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCC3 */ { "TOUR DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCC4 */ { "TOUR DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCC5 */ { "TOUR DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCC6 */ { "FOU DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCC7 */ { "FOU DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCC8 */ { "FOU DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCC9 */ { "FOU DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCCA */ { "CAVALIER DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCCB */ { "CAVALIER DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCCC */ { "CAVALIER DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCCD */ { "CAVALIER DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCCE */ { "PION DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCCF */ { "PION DU JEU D'ÉCHECS DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCD0 */ { "PION DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCD1 */ { "PION DU JEU D'ÉCHECS DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCD2 */ { "CAVALIER DEBOUT DU QUADRANT SUPÉRIEUR GAUCHE",NULL},
/* 1CCD3 */ { "CAVALIER DEBOUT DU QUADRANT SUPÉRIEUR DROIT",NULL},
/* 1CCD4 */ { "CAVALIER DEBOUT DU QUADRANT INFÉRIEUR GAUCHE",NULL},
/* 1CCD5 */ { "CAVALIER DEBOUT DU QUADRANT INFÉRIEUR DROIT",NULL},
/* 1CCD6 */ { "LETTRE MAJUSCULE LATINE A ÉVIDÉ","	# <police> 0041 lettre majuscule latine a"},
/* 1CCD7 */ { "LETTRE MAJUSCULE LATINE B ÉVIDÉ","	# <police> 0042 lettre majuscule latine b"},
/* 1CCD8 */ { "LETTRE MAJUSCULE LATINE C ÉVIDÉ","	# <police> 0043 lettre majuscule latine c"},
/* 1CCD9 */ { "LETTRE MAJUSCULE LATINE D ÉVIDÉ","	# <police> 0044 lettre majuscule latine d"},
/* 1CCDA */ { "LETTRE MAJUSCULE LATINE E ÉVIDÉ","	# <police> 0045 lettre majuscule latine e"},
/* 1CCDB */ { "LETTRE MAJUSCULE LATINE F ÉVIDÉ","	# <police> 0046 lettre majuscule latine f"},
/* 1CCDC */ { "LETTRE MAJUSCULE LATINE G ÉVIDÉ","	# <police> 0047 lettre majuscule latine g"},
/* 1CCDD */ { "LETTRE MAJUSCULE LATINE H ÉVIDÉ","	# <police> 0048 lettre majuscule latine h"},
/* 1CCDE */ { "LETTRE MAJUSCULE LATINE I ÉVIDÉ","	# <police> 0049 lettre majuscule latine i"},
/* 1CCDF */ { "LETTRE MAJUSCULE LATINE J ÉVIDÉ","	# <police> 004A lettre majuscule latine j"},
/* 1CCE0 */ { "LETTRE MAJUSCULE LATINE K ÉVIDÉ","	# <police> 004B lettre majuscule latine k"},
/* 1CCE1 */ { "LETTRE MAJUSCULE LATINE L ÉVIDÉ","	# <police> 004C lettre majuscule latine l"},
/* 1CCE2 */ { "LETTRE MAJUSCULE LATINE M ÉVIDÉ","	# <police> 004D lettre majuscule latine m"},
/* 1CCE3 */ { "LETTRE MAJUSCULE LATINE N ÉVIDÉ","	# <police> 004E lettre majuscule latine n"},
/* 1CCE4 */ { "LETTRE MAJUSCULE LATINE O ÉVIDÉ","	# <police> 004F lettre majuscule latine o"},
/* 1CCE5 */ { "LETTRE MAJUSCULE LATINE P ÉVIDÉ","	# <police> 0050 lettre majuscule latine p"},
/* 1CCE6 */ { "LETTRE MAJUSCULE LATINE Q ÉVIDÉ","	# <police> 0051 lettre majuscule latine q"},
/* 1CCE7 */ { "LETTRE MAJUSCULE LATINE R ÉVIDÉ","	# <police> 0052 lettre majuscule latine r"},
/* 1CCE8 */ { "LETTRE MAJUSCULE LATINE S ÉVIDÉ","	# <police> 0053 lettre majuscule latine s"},
/* 1CCE9 */ { "LETTRE MAJUSCULE LATINE T ÉVIDÉ","	# <police> 0054 lettre majuscule latine t"},
/* 1CCEA */ { "LETTRE MAJUSCULE LATINE U ÉVIDÉ","	# <police> 0055 lettre majuscule latine u"},
/* 1CCEB */ { "LETTRE MAJUSCULE LATINE V ÉVIDÉ","	# <police> 0056 lettre majuscule latine v"},
/* 1CCEC */ { "LETTRE MAJUSCULE LATINE W ÉVIDÉ","	# <police> 0057 lettre majuscule latine w"},
/* 1CCED */ { "LETTRE MAJUSCULE LATINE X ÉVIDÉ","	# <police> 0058 lettre majuscule latine x"},
/* 1CCEE */ { "LETTRE MAJUSCULE LATINE Y ÉVIDÉ","	# <police> 0059 lettre majuscule latine y"},
/* 1CCEF */ { "LETTRE MAJUSCULE LATINE Z ÉVIDÉ","	# <police> 005A lettre majuscule latine z"},
/* 1CCF0 */ { "CHIFFRE ZÉRO ÉVIDÉ","	# <police> 0030 chiffre zéro"},
/* 1CCF1 */ { "CHIFFRE UN ÉVIDÉ","	# <police> 0031 chiffre un"},
/* 1CCF2 */ { "CHIFFRE DEUX ÉVIDÉ","	# <police> 0032 chiffre deux"},
/* 1CCF3 */ { "CHIFFRE TROIS ÉVIDÉ","	# <police> 0033 chiffre trois"},
/* 1CCF4 */ { "CHIFFRE QUATRE ÉVIDÉ","	# <police> 0034 chiffre quatre"},
/* 1CCF5 */ { "CHIFFRE CINQ ÉVIDÉ","	# <police> 0035 chiffre cinq"},
/* 1CCF6 */ { "CHIFFRE SIX ÉVIDÉ","	# <police> 0036 chiffre six"},
/* 1CCF7 */ { "CHIFFRE SEPT ÉVIDÉ","	# <police> 0037 chiffre sept"},
/* 1CCF8 */ { "CHIFFRE HUIT ÉVIDÉ","	# <police> 0038 chiffre huit"},
/* 1CCF9 */ { "CHIFFRE NEUF ÉVIDÉ","	# <police> 0039 chiffre neuf"},
/* 1CCFA */ { "SYMBOLE SERPENT","	x (serpent - 1F40D)"},
/* 1CCFB */ { "SYMBOLE SOUCOUPE VOLANTE","	x (soucoupe volante - 1F6F8)"},
/* 1CCFC */ { "SYMBOLE NEZ","	x (nez - 1F443)"},
/* 1CCFD */ { NULL,NULL},
/* 1CCFE */ { NULL,NULL},
/* 1CCFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_CD[] = {
/* 1CD00 */ { "HUITIÈME DE PAVÉ-3",NULL},
/* 1CD01 */ { "HUITIÈME DE PAVÉ-23",NULL},
/* 1CD02 */ { "HUITIÈME DE PAVÉ-123",NULL},
/* 1CD03 */ { "HUITIÈME DE PAVÉ-4",NULL},
/* 1CD04 */ { "HUITIÈME DE PAVÉ-14",NULL},
/* 1CD05 */ { "HUITIÈME DE PAVÉ-124",NULL},
/* 1CD06 */ { "HUITIÈME DE PAVÉ-34",NULL},
/* 1CD07 */ { "HUITIÈME DE PAVÉ-134",NULL},
/* 1CD08 */ { "HUITIÈME DE PAVÉ-234",NULL},
/* 1CD09 */ { "HUITIÈME DE PAVÉ-5",NULL},
/* 1CD0A */ { "HUITIÈME DE PAVÉ-15",NULL},
/* 1CD0B */ { "HUITIÈME DE PAVÉ-25",NULL},
/* 1CD0C */ { "HUITIÈME DE PAVÉ-125",NULL},
/* 1CD0D */ { "HUITIÈME DE PAVÉ-135",NULL},
/* 1CD0E */ { "HUITIÈME DE PAVÉ-235",NULL},
/* 1CD0F */ { "HUITIÈME DE PAVÉ-1235",NULL},
/* 1CD10 */ { "HUITIÈME DE PAVÉ-45",NULL},
/* 1CD11 */ { "HUITIÈME DE PAVÉ-145",NULL},
/* 1CD12 */ { "HUITIÈME DE PAVÉ-245",NULL},
/* 1CD13 */ { "HUITIÈME DE PAVÉ-1245",NULL},
/* 1CD14 */ { "HUITIÈME DE PAVÉ-345",NULL},
/* 1CD15 */ { "HUITIÈME DE PAVÉ-1345",NULL},
/* 1CD16 */ { "HUITIÈME DE PAVÉ-2345",NULL},
/* 1CD17 */ { "HUITIÈME DE PAVÉ-12345",NULL},
/* 1CD18 */ { "HUITIÈME DE PAVÉ-6",NULL},
/* 1CD19 */ { "HUITIÈME DE PAVÉ-16",NULL},
/* 1CD1A */ { "HUITIÈME DE PAVÉ-26",NULL},
/* 1CD1B */ { "HUITIÈME DE PAVÉ-126",NULL},
/* 1CD1C */ { "HUITIÈME DE PAVÉ-36",NULL},
/* 1CD1D */ { "HUITIÈME DE PAVÉ-136",NULL},
/* 1CD1E */ { "HUITIÈME DE PAVÉ-236",NULL},
/* 1CD1F */ { "HUITIÈME DE PAVÉ-1236",NULL},
/* 1CD20 */ { "HUITIÈME DE PAVÉ-146",NULL},
/* 1CD21 */ { "HUITIÈME DE PAVÉ-246",NULL},
/* 1CD22 */ { "HUITIÈME DE PAVÉ-1246",NULL},
/* 1CD23 */ { "HUITIÈME DE PAVÉ-346",NULL},
/* 1CD24 */ { "HUITIÈME DE PAVÉ-1346",NULL},
/* 1CD25 */ { "HUITIÈME DE PAVÉ-2346",NULL},
/* 1CD26 */ { "HUITIÈME DE PAVÉ-12346",NULL},
/* 1CD27 */ { "HUITIÈME DE PAVÉ-56",NULL},
/* 1CD28 */ { "HUITIÈME DE PAVÉ-156",NULL},
/* 1CD29 */ { "HUITIÈME DE PAVÉ-256",NULL},
/* 1CD2A */ { "HUITIÈME DE PAVÉ-1256",NULL},
/* 1CD2B */ { "HUITIÈME DE PAVÉ-356",NULL},
/* 1CD2C */ { "HUITIÈME DE PAVÉ-1356",NULL},
/* 1CD2D */ { "HUITIÈME DE PAVÉ-2356",NULL},
/* 1CD2E */ { "HUITIÈME DE PAVÉ-12356",NULL},
/* 1CD2F */ { "HUITIÈME DE PAVÉ-456",NULL},
/* 1CD30 */ { "HUITIÈME DE PAVÉ-1456",NULL},
/* 1CD31 */ { "HUITIÈME DE PAVÉ-2456",NULL},
/* 1CD32 */ { "HUITIÈME DE PAVÉ-12456",NULL},
/* 1CD33 */ { "HUITIÈME DE PAVÉ-3456",NULL},
/* 1CD34 */ { "HUITIÈME DE PAVÉ-13456",NULL},
/* 1CD35 */ { "HUITIÈME DE PAVÉ-23456",NULL},
/* 1CD36 */ { "HUITIÈME DE PAVÉ-17",NULL},
/* 1CD37 */ { "HUITIÈME DE PAVÉ-27",NULL},
/* 1CD38 */ { "HUITIÈME DE PAVÉ-127",NULL},
/* 1CD39 */ { "HUITIÈME DE PAVÉ-37",NULL},
/* 1CD3A */ { "HUITIÈME DE PAVÉ-137",NULL},
/* 1CD3B */ { "HUITIÈME DE PAVÉ-237",NULL},
/* 1CD3C */ { "HUITIÈME DE PAVÉ-1237",NULL},
/* 1CD3D */ { "HUITIÈME DE PAVÉ-47",NULL},
/* 1CD3E */ { "HUITIÈME DE PAVÉ-147",NULL},
/* 1CD3F */ { "HUITIÈME DE PAVÉ-247",NULL},
/* 1CD40 */ { "HUITIÈME DE PAVÉ-1247",NULL},
/* 1CD41 */ { "HUITIÈME DE PAVÉ-347",NULL},
/* 1CD42 */ { "HUITIÈME DE PAVÉ-1347",NULL},
/* 1CD43 */ { "HUITIÈME DE PAVÉ-2347",NULL},
/* 1CD44 */ { "HUITIÈME DE PAVÉ-12347",NULL},
/* 1CD45 */ { "HUITIÈME DE PAVÉ-157",NULL},
/* 1CD46 */ { "HUITIÈME DE PAVÉ-257",NULL},
/* 1CD47 */ { "HUITIÈME DE PAVÉ-1257",NULL},
/* 1CD48 */ { "HUITIÈME DE PAVÉ-357",NULL},
/* 1CD49 */ { "HUITIÈME DE PAVÉ-2357",NULL},
/* 1CD4A */ { "HUITIÈME DE PAVÉ-12357",NULL},
/* 1CD4B */ { "HUITIÈME DE PAVÉ-457",NULL},
/* 1CD4C */ { "HUITIÈME DE PAVÉ-1457",NULL},
/* 1CD4D */ { "HUITIÈME DE PAVÉ-12457",NULL},
/* 1CD4E */ { "HUITIÈME DE PAVÉ-3457",NULL},
/* 1CD4F */ { "HUITIÈME DE PAVÉ-13457",NULL},
/* 1CD50 */ { "HUITIÈME DE PAVÉ-23457",NULL},
/* 1CD51 */ { "HUITIÈME DE PAVÉ-67",NULL},
/* 1CD52 */ { "HUITIÈME DE PAVÉ-167",NULL},
/* 1CD53 */ { "HUITIÈME DE PAVÉ-267",NULL},
/* 1CD54 */ { "HUITIÈME DE PAVÉ-1267",NULL},
/* 1CD55 */ { "HUITIÈME DE PAVÉ-367",NULL},
/* 1CD56 */ { "HUITIÈME DE PAVÉ-1367",NULL},
/* 1CD57 */ { "HUITIÈME DE PAVÉ-2367",NULL},
/* 1CD58 */ { "HUITIÈME DE PAVÉ-12367",NULL},
/* 1CD59 */ { "HUITIÈME DE PAVÉ-467",NULL},
/* 1CD5A */ { "HUITIÈME DE PAVÉ-1467",NULL},
/* 1CD5B */ { "HUITIÈME DE PAVÉ-2467",NULL},
/* 1CD5C */ { "HUITIÈME DE PAVÉ-12467",NULL},
/* 1CD5D */ { "HUITIÈME DE PAVÉ-3467",NULL},
/* 1CD5E */ { "HUITIÈME DE PAVÉ-13467",NULL},
/* 1CD5F */ { "HUITIÈME DE PAVÉ-23467",NULL},
/* 1CD60 */ { "HUITIÈME DE PAVÉ-123467",NULL},
/* 1CD61 */ { "HUITIÈME DE PAVÉ-567",NULL},
/* 1CD62 */ { "HUITIÈME DE PAVÉ-1567",NULL},
/* 1CD63 */ { "HUITIÈME DE PAVÉ-2567",NULL},
/* 1CD64 */ { "HUITIÈME DE PAVÉ-12567",NULL},
/* 1CD65 */ { "HUITIÈME DE PAVÉ-3567",NULL},
/* 1CD66 */ { "HUITIÈME DE PAVÉ-13567",NULL},
/* 1CD67 */ { "HUITIÈME DE PAVÉ-23567",NULL},
/* 1CD68 */ { "HUITIÈME DE PAVÉ-123567",NULL},
/* 1CD69 */ { "HUITIÈME DE PAVÉ-4567",NULL},
/* 1CD6A */ { "HUITIÈME DE PAVÉ-14567",NULL},
/* 1CD6B */ { "HUITIÈME DE PAVÉ-24567",NULL},
/* 1CD6C */ { "HUITIÈME DE PAVÉ-124567",NULL},
/* 1CD6D */ { "HUITIÈME DE PAVÉ-34567",NULL},
/* 1CD6E */ { "HUITIÈME DE PAVÉ-134567",NULL},
/* 1CD6F */ { "HUITIÈME DE PAVÉ-234567",NULL},
/* 1CD70 */ { "HUITIÈME DE PAVÉ-1234567",NULL},
/* 1CD71 */ { "HUITIÈME DE PAVÉ-18",NULL},
/* 1CD72 */ { "HUITIÈME DE PAVÉ-28",NULL},
/* 1CD73 */ { "HUITIÈME DE PAVÉ-128",NULL},
/* 1CD74 */ { "HUITIÈME DE PAVÉ-38",NULL},
/* 1CD75 */ { "HUITIÈME DE PAVÉ-138",NULL},
/* 1CD76 */ { "HUITIÈME DE PAVÉ-238",NULL},
/* 1CD77 */ { "HUITIÈME DE PAVÉ-1238",NULL},
/* 1CD78 */ { "HUITIÈME DE PAVÉ-48",NULL},
/* 1CD79 */ { "HUITIÈME DE PAVÉ-148",NULL},
/* 1CD7A */ { "HUITIÈME DE PAVÉ-248",NULL},
/* 1CD7B */ { "HUITIÈME DE PAVÉ-1248",NULL},
/* 1CD7C */ { "HUITIÈME DE PAVÉ-348",NULL},
/* 1CD7D */ { "HUITIÈME DE PAVÉ-1348",NULL},
/* 1CD7E */ { "HUITIÈME DE PAVÉ-2348",NULL},
/* 1CD7F */ { "HUITIÈME DE PAVÉ-12348",NULL},
/* 1CD80 */ { "HUITIÈME DE PAVÉ-58",NULL},
/* 1CD81 */ { "HUITIÈME DE PAVÉ-158",NULL},
/* 1CD82 */ { "HUITIÈME DE PAVÉ-258",NULL},
/* 1CD83 */ { "HUITIÈME DE PAVÉ-1258",NULL},
/* 1CD84 */ { "HUITIÈME DE PAVÉ-358",NULL},
/* 1CD85 */ { "HUITIÈME DE PAVÉ-1358",NULL},
/* 1CD86 */ { "HUITIÈME DE PAVÉ-2358",NULL},
/* 1CD87 */ { "HUITIÈME DE PAVÉ-12358",NULL},
/* 1CD88 */ { "HUITIÈME DE PAVÉ-458",NULL},
/* 1CD89 */ { "HUITIÈME DE PAVÉ-1458",NULL},
/* 1CD8A */ { "HUITIÈME DE PAVÉ-2458",NULL},
/* 1CD8B */ { "HUITIÈME DE PAVÉ-12458",NULL},
/* 1CD8C */ { "HUITIÈME DE PAVÉ-3458",NULL},
/* 1CD8D */ { "HUITIÈME DE PAVÉ-13458",NULL},
/* 1CD8E */ { "HUITIÈME DE PAVÉ-23458",NULL},
/* 1CD8F */ { "HUITIÈME DE PAVÉ-123458",NULL},
/* 1CD90 */ { "HUITIÈME DE PAVÉ-168",NULL},
/* 1CD91 */ { "HUITIÈME DE PAVÉ-268",NULL},
/* 1CD92 */ { "HUITIÈME DE PAVÉ-1268",NULL},
/* 1CD93 */ { "HUITIÈME DE PAVÉ-368",NULL},
/* 1CD94 */ { "HUITIÈME DE PAVÉ-2368",NULL},
/* 1CD95 */ { "HUITIÈME DE PAVÉ-12368",NULL},
/* 1CD96 */ { "HUITIÈME DE PAVÉ-468",NULL},
/* 1CD97 */ { "HUITIÈME DE PAVÉ-1468",NULL},
/* 1CD98 */ { "HUITIÈME DE PAVÉ-12468",NULL},
/* 1CD99 */ { "HUITIÈME DE PAVÉ-3468",NULL},
/* 1CD9A */ { "HUITIÈME DE PAVÉ-13468",NULL},
/* 1CD9B */ { "HUITIÈME DE PAVÉ-23468",NULL},
/* 1CD9C */ { "HUITIÈME DE PAVÉ-568",NULL},
/* 1CD9D */ { "HUITIÈME DE PAVÉ-1568",NULL},
/* 1CD9E */ { "HUITIÈME DE PAVÉ-2568",NULL},
/* 1CD9F */ { "HUITIÈME DE PAVÉ-12568",NULL},
/* 1CDA0 */ { "HUITIÈME DE PAVÉ-3568",NULL},
/* 1CDA1 */ { "HUITIÈME DE PAVÉ-13568",NULL},
/* 1CDA2 */ { "HUITIÈME DE PAVÉ-23568",NULL},
/* 1CDA3 */ { "HUITIÈME DE PAVÉ-123568",NULL},
/* 1CDA4 */ { "HUITIÈME DE PAVÉ-4568",NULL},
/* 1CDA5 */ { "HUITIÈME DE PAVÉ-14568",NULL},
/* 1CDA6 */ { "HUITIÈME DE PAVÉ-24568",NULL},
/* 1CDA7 */ { "HUITIÈME DE PAVÉ-124568",NULL},
/* 1CDA8 */ { "HUITIÈME DE PAVÉ-34568",NULL},
/* 1CDA9 */ { "HUITIÈME DE PAVÉ-134568",NULL},
/* 1CDAA */ { "HUITIÈME DE PAVÉ-234568",NULL},
/* 1CDAB */ { "HUITIÈME DE PAVÉ-1234568",NULL},
/* 1CDAC */ { "HUITIÈME DE PAVÉ-178",NULL},
/* 1CDAD */ { "HUITIÈME DE PAVÉ-278",NULL},
/* 1CDAE */ { "HUITIÈME DE PAVÉ-1278",NULL},
/* 1CDAF */ { "HUITIÈME DE PAVÉ-378",NULL},
/* 1CDB0 */ { "HUITIÈME DE PAVÉ-1378",NULL},
/* 1CDB1 */ { "HUITIÈME DE PAVÉ-2378",NULL},
/* 1CDB2 */ { "HUITIÈME DE PAVÉ-12378",NULL},
/* 1CDB3 */ { "HUITIÈME DE PAVÉ-478",NULL},
/* 1CDB4 */ { "HUITIÈME DE PAVÉ-1478",NULL},
/* 1CDB5 */ { "HUITIÈME DE PAVÉ-2478",NULL},
/* 1CDB6 */ { "HUITIÈME DE PAVÉ-12478",NULL},
/* 1CDB7 */ { "HUITIÈME DE PAVÉ-3478","	x (remplissage horizontal épais - 1FB97)"},
/* 1CDB8 */ { "HUITIÈME DE PAVÉ-13478",NULL},
/* 1CDB9 */ { "HUITIÈME DE PAVÉ-23478",NULL},
/* 1CDBA */ { "HUITIÈME DE PAVÉ-123478",NULL},
/* 1CDBB */ { "HUITIÈME DE PAVÉ-578",NULL},
/* 1CDBC */ { "HUITIÈME DE PAVÉ-1578",NULL},
/* 1CDBD */ { "HUITIÈME DE PAVÉ-2578",NULL},
/* 1CDBE */ { "HUITIÈME DE PAVÉ-12578",NULL},
/* 1CDBF */ { "HUITIÈME DE PAVÉ-3578",NULL},
/* 1CDC0 */ { "HUITIÈME DE PAVÉ-13578",NULL},
/* 1CDC1 */ { "HUITIÈME DE PAVÉ-23578",NULL},
/* 1CDC2 */ { "HUITIÈME DE PAVÉ-123578",NULL},
/* 1CDC3 */ { "HUITIÈME DE PAVÉ-4578",NULL},
/* 1CDC4 */ { "HUITIÈME DE PAVÉ-14578",NULL},
/* 1CDC5 */ { "HUITIÈME DE PAVÉ-24578",NULL},
/* 1CDC6 */ { "HUITIÈME DE PAVÉ-124578",NULL},
/* 1CDC7 */ { "HUITIÈME DE PAVÉ-34578",NULL},
/* 1CDC8 */ { "HUITIÈME DE PAVÉ-134578",NULL},
/* 1CDC9 */ { "HUITIÈME DE PAVÉ-234578",NULL},
/* 1CDCA */ { "HUITIÈME DE PAVÉ-1234578",NULL},
/* 1CDCB */ { "HUITIÈME DE PAVÉ-678",NULL},
/* 1CDCC */ { "HUITIÈME DE PAVÉ-1678",NULL},
/* 1CDCD */ { "HUITIÈME DE PAVÉ-2678",NULL},
/* 1CDCE */ { "HUITIÈME DE PAVÉ-12678",NULL},
/* 1CDCF */ { "HUITIÈME DE PAVÉ-3678",NULL},
/* 1CDD0 */ { "HUITIÈME DE PAVÉ-13678",NULL},
/* 1CDD1 */ { "HUITIÈME DE PAVÉ-23678",NULL},
/* 1CDD2 */ { "HUITIÈME DE PAVÉ-123678",NULL},
/* 1CDD3 */ { "HUITIÈME DE PAVÉ-4678",NULL},
/* 1CDD4 */ { "HUITIÈME DE PAVÉ-14678",NULL},
/* 1CDD5 */ { "HUITIÈME DE PAVÉ-24678",NULL},
/* 1CDD6 */ { "HUITIÈME DE PAVÉ-124678",NULL},
/* 1CDD7 */ { "HUITIÈME DE PAVÉ-34678",NULL},
/* 1CDD8 */ { "HUITIÈME DE PAVÉ-134678",NULL},
/* 1CDD9 */ { "HUITIÈME DE PAVÉ-234678",NULL},
/* 1CDDA */ { "HUITIÈME DE PAVÉ-1234678",NULL},
/* 1CDDB */ { "HUITIÈME DE PAVÉ-15678",NULL},
/* 1CDDC */ { "HUITIÈME DE PAVÉ-25678",NULL},
/* 1CDDD */ { "HUITIÈME DE PAVÉ-125678",NULL},
/* 1CDDE */ { "HUITIÈME DE PAVÉ-35678",NULL},
/* 1CDDF */ { "HUITIÈME DE PAVÉ-235678",NULL},
/* 1CDE0 */ { "HUITIÈME DE PAVÉ-1235678",NULL},
/* 1CDE1 */ { "HUITIÈME DE PAVÉ-45678",NULL},
/* 1CDE2 */ { "HUITIÈME DE PAVÉ-145678",NULL},
/* 1CDE3 */ { "HUITIÈME DE PAVÉ-1245678",NULL},
/* 1CDE4 */ { "HUITIÈME DE PAVÉ-1345678",NULL},
/* 1CDE5 */ { "HUITIÈME DE PAVÉ-2345678",NULL},
/* 1CDE6 */ { "MOITIÉ SUPÉRIEURE D'UNE PERSONNE DEBOUT",NULL},
/* 1CDE7 */ { "MOITIÉ INFÉRIEURE D'UNE PERSONNE DEBOUT",NULL},
/* 1CDE8 */ { "MOITIÉ SUPÉRIEURE D'UN COUREUR ORIENTÉ À DROITE IMAGE-1",NULL},
/* 1CDE9 */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ À DROITE IMAGE-1",NULL},
/* 1CDEA */ { "MOITIÉ SUPÉRIEURE D'UN COUREUR ORIENTÉ À DROITE IMAGE-2",NULL},
/* 1CDEB */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ À DROITE IMAGE-2",NULL},
/* 1CDEC */ { "MOITIÉ SUPÉRIEURE D'UN COUREUR ORIENTÉ À GAUCHE IMAGE-1",NULL},
/* 1CDED */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ À GAUCHE IMAGE-1",NULL},
/* 1CDEE */ { "MOITIÉ SUPÉRIEURE D'UN COUREUR ORIENTÉ À GAUCHE IMAGE-2",NULL},
/* 1CDEF */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ À GAUCHE IMAGE-2",NULL},
/* 1CDF0 */ { "MOITIÉ SUPÉRIEURE D'UN COUREUR ORIENTÉ VERS L'AVANT",NULL},
/* 1CDF1 */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ VERS L'AVANT IMAGE-1",NULL},
/* 1CDF2 */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ VERS L'AVANT IMAGE-2",NULL},
/* 1CDF3 */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ VERS L'AVANT IMAGE-3",NULL},
/* 1CDF4 */ { "MOITIÉ INFÉRIEURE D'UN COUREUR ORIENTÉ VERS L'AVANT IMAGE-4",NULL},
/* 1CDF5 */ { "ALUNISSEUR",NULL},
/* 1CDF6 */ { "MOITIÉ SUPÉRIEURE D'UN ROBOT AGITÉ IMAGE-1",NULL},
/* 1CDF7 */ { "MOITIÉ SUPÉRIEURE D'UN ROBOT AGITÉ IMAGE-2",NULL},
/* 1CDF8 */ { "AVION POINTANT VERS LE BAS",NULL},
/* 1CDF9 */ { "AVION POINTANT VERS LA GAUCHE",NULL},
/* 1CDFA */ { "PETIT AVION ORIENTÉ POINTANT VERS LE HAUT",NULL},
/* 1CDFB */ { "GRENOUILLE POINTANT VERS LE HAUT",NULL},
/* 1CDFC */ { "GRENOUILLE POINTANT VERS LE BAS",NULL},
/* 1CDFD */ { "EXPLOSION IMAGE-1",NULL},
/* 1CDFE */ { "EXPLOSION IMAGE-2",NULL},
/* 1CDFF */ { "EXPLOSION IMAGE-3",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_CE[] = {
/* 1CE00 */ { "MOITIÉ DROITE ET MOITIÉ GAUCHE DE CERCLE BLANC",NULL},
/* 1CE01 */ { "MOITIÉ INFÉRIEURE ET MOITIÉ SUPÉRIEURE DE CERCLE BLANC",NULL},
/* 1CE02 */ { "EXPLOSION À L'HORIZON",NULL},
/* 1CE03 */ { "MOITIÉ SUPÉRIEURE DE CARRÉ BLANC ÉPAIS",NULL},
/* 1CE04 */ { "MOITIÉ INFÉRIEURE DE CARRÉ BLANC ÉPAIS",NULL},
/* 1CE05 */ { "CARRÉ BLANC ÉPAIS CONTENANT UN TRÈS PETIT CARRÉ NOIR",NULL},
/* 1CE06 */ { "RECTANGLE BLANC VERTICAL AVEC BARRE HORIZONTALE",NULL},
/* 1CE07 */ { "PETIT TRIANGLE NOIR SUPÉRIEUR GAUCHE POINTANT VERS LA GAUCHE",NULL},
/* 1CE08 */ { "ENTONNOIR",NULL},
/* 1CE09 */ { "DOUBLE DIAGONALE DU COIN INFÉRIEUR GAUCHE AU CENTRE DU MILIEU PUIS AU COIN INFÉRIEUR DROIT",NULL},
/* 1CE0A */ { "DOUBLE DIAGONALE DU COIN SUPÉRIEUR GAUCHE AU CENTRE DU MILIEU PUIS AU COIN SUPÉRIEUR DROIT",NULL},
/* 1CE0B */ { "MOITIÉ GAUCHE D'UNE ELLIPSE BLANCHE",NULL},
/* 1CE0C */ { "MOITIÉ DROITE D'UNE ELLIPSE BLANCHE",NULL},
/* 1CE0D */ { "MOITIÉ GAUCHE DE LIGNE HORIZONTALE TRIPLEMENT TIRETÉE",NULL},
/* 1CE0E */ { "MOITIÉ DROITE DE LIGNE HORIZONTALE TRIPLEMENT TIRETÉE",NULL},
/* 1CE0F */ { "LIGNE HORIZONTALE AVEC REPÈRE",NULL},
/* 1CE10 */ { "MOITIÉ GAUCHE DE LIGNE HORIZONTALE AVEC TROIS REPÈRES",NULL},
/* 1CE11 */ { "MOITIÉ DROITE DE LIGNE HORIZONTALE AVEC TROIS REPÈRES",NULL},
/* 1CE12 */ { "LIGNE HORIZONTALE AVEC TROIS REPÈRES",NULL},
/* 1CE13 */ { "MOITIÉ INFÉRIEURE DE LIGNE VERTICALE AVEC TROIS REPÈRES",NULL},
/* 1CE14 */ { "MOITIÉ SUPÉRIEURE DE LIGNE VERTICALE AVEC TROIS REPÈRES",NULL},
/* 1CE15 */ { "LIGNE VERTICALE AVEC TROIS REPÈRES",NULL},
/* 1CE16 */ { "FILET FIN VERTICAL ET SUPÉRIEUR DROIT",NULL},
/* 1CE17 */ { "FILET FIN VERTICAL ET INFÉRIEUR DROIT",NULL},
/* 1CE18 */ { "FILET FIN VERTICAL ET SUPÉRIEUR GAUCHE",NULL},
/* 1CE19 */ { "FILET FIN VERTICAL ET INFÉRIEUR GAUCHE",NULL},
/* 1CE1A */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE SUPÉRIEURE GAUCHE",NULL},
/* 1CE1B */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE COIN SUPÉRIEUR GAUCHE",NULL},
/* 1CE1C */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TERMINAISON SUPÉRIEURE",NULL},
/* 1CE1D */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE ANGLE INTÉRIEUR SUPÉRIEUR GAUCHE",NULL},
/* 1CE1E */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE BRAS GAUCHE",NULL},
/* 1CE1F */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TRAVERSE",NULL},
/* 1CE20 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TRAVERSE AVEC HAMPE INFÉRIEURE",NULL},
/* 1CE21 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DEMI-SOMMET SUPÉRIEUR DE M",NULL},
/* 1CE22 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DIAGONALE INFÉRIEURE GAUCHE",NULL},
/* 1CE23 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TERMINAISON SUPÉRIEURE COURTE",NULL},
/* 1CE24 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE SUPÉRIEURE DROITE",NULL},
/* 1CE25 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE BRAS DROIT",NULL},
/* 1CE26 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE ANGLE INTÉRIEUR SUPÉRIEUR DROIT",NULL},
/* 1CE27 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE COIN SUPÉRIEUR DROIT",NULL},
/* 1CE28 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE AVEC TRAVERSE DROITE",NULL},
/* 1CE29 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE",NULL},
/* 1CE2A */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DIAGONALES SUPÉRIEURE DROITE ET INFÉRIEURE DROITE",NULL},
/* 1CE2B */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DIAGONALE SUPÉRIEURE DROITE",NULL},
/* 1CE2C */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DIAGONALE INFÉRIEURE DROITE",NULL},
/* 1CE2D */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TERMINAISON INFÉRIEURE COURTE",NULL},
/* 1CE2E */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE INFÉRIEURE GAUCHE ET SUPÉRIEURE GAUCHE",NULL},
/* 1CE2F */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CENTRE DE K",NULL},
/* 1CE30 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DEMI-SOMMET INFÉRIEUR DE M",NULL},
/* 1CE31 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DEMI-SOMMET SUPÉRIEUR DE W",NULL},
/* 1CE32 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CENTRE DE X",NULL},
/* 1CE33 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CENTRE DE Y",NULL},
/* 1CE34 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CENTRE DE Z AVEC TRAVERSE",NULL},
/* 1CE35 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE SUPÉRIEURE GAUCHE ÉLEVÉE",NULL},
/* 1CE36 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE AVEC TRAVERSE GAUCHE",NULL},
/* 1CE37 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE INFÉRIEURE DROITE ET SUPÉRIEURE DROITE",NULL},
/* 1CE38 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DIAGONALES SUPÉRIEURE GAUCHE ET INFÉRIEURE GAUCHE",NULL},
/* 1CE39 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE AVEC POINT DE JONCTION GAUCHE",NULL},
/* 1CE3A */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE AVEC TRAVERSE",NULL},
/* 1CE3B */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DIAGONALE SUPÉRIEURE GAUCHE",NULL},
/* 1CE3C */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TERMINAISON INFÉRIEURE",NULL},
/* 1CE3D */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE COIN INFÉRIEUR GAUCHE",NULL},
/* 1CE3E */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE INFÉRIEURE GAUCHE",NULL},
/* 1CE3F */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE ANGLE INTÉRIEUR INFÉRIEUR GAUCHE",NULL},
/* 1CE40 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE TRAVERSE AVEC HAMPE SUPÉRIEURE",NULL},
/* 1CE41 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE SOMMET DE V",NULL},
/* 1CE42 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE DEMI-SOMMET INFÉRIEUR DE W",NULL},
/* 1CE43 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE INFÉRIEURE DROITE",NULL},
/* 1CE44 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE COIN INFÉRIEUR DROIT",NULL},
/* 1CE45 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE CROSSE INFÉRIEURE DROITE AVEC QUEUE",NULL},
/* 1CE46 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE ANGLE INTÉRIEUR INFÉRIEUR DROIT",NULL},
/* 1CE47 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-45",NULL},
/* 1CE48 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-2345",NULL},
/* 1CE49 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-4",NULL},
/* 1CE4A */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-34",NULL},
/* 1CE4B */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-234",NULL},
/* 1CE4C */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-1234",NULL},
/* 1CE4D */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-3",NULL},
/* 1CE4E */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-23",NULL},
/* 1CE4F */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-2",NULL},
/* 1CE50 */ { "GRAND ÉLÉMENT TYPOGRAPHIQUE HAMPE-12",NULL},
/* 1CE51 */ { "SIXIÈME DE PAVÉ ISOLÉ-1",NULL},
/* 1CE52 */ { "SIXIÈME DE PAVÉ ISOLÉ-2",NULL},
/* 1CE53 */ { "SIXIÈME DE PAVÉ ISOLÉ-12",NULL},
/* 1CE54 */ { "SIXIÈME DE PAVÉ ISOLÉ-3",NULL},
/* 1CE55 */ { "SIXIÈME DE PAVÉ ISOLÉ-13",NULL},
/* 1CE56 */ { "SIXIÈME DE PAVÉ ISOLÉ-23",NULL},
/* 1CE57 */ { "SIXIÈME DE PAVÉ ISOLÉ-123",NULL},
/* 1CE58 */ { "SIXIÈME DE PAVÉ ISOLÉ-4",NULL},
/* 1CE59 */ { "SIXIÈME DE PAVÉ ISOLÉ-14",NULL},
/* 1CE5A */ { "SIXIÈME DE PAVÉ ISOLÉ-24",NULL},
/* 1CE5B */ { "SIXIÈME DE PAVÉ ISOLÉ-124",NULL},
/* 1CE5C */ { "SIXIÈME DE PAVÉ ISOLÉ-34",NULL},
/* 1CE5D */ { "SIXIÈME DE PAVÉ ISOLÉ-134",NULL},
/* 1CE5E */ { "SIXIÈME DE PAVÉ ISOLÉ-234",NULL},
/* 1CE5F */ { "SIXIÈME DE PAVÉ ISOLÉ-1234",NULL},
/* 1CE60 */ { "SIXIÈME DE PAVÉ ISOLÉ-5",NULL},
/* 1CE61 */ { "SIXIÈME DE PAVÉ ISOLÉ-15",NULL},
/* 1CE62 */ { "SIXIÈME DE PAVÉ ISOLÉ-25",NULL},
/* 1CE63 */ { "SIXIÈME DE PAVÉ ISOLÉ-125",NULL},
/* 1CE64 */ { "SIXIÈME DE PAVÉ ISOLÉ-35",NULL},
/* 1CE65 */ { "SIXIÈME DE PAVÉ ISOLÉ-135",NULL},
/* 1CE66 */ { "SIXIÈME DE PAVÉ ISOLÉ-235",NULL},
/* 1CE67 */ { "SIXIÈME DE PAVÉ ISOLÉ-1235",NULL},
/* 1CE68 */ { "SIXIÈME DE PAVÉ ISOLÉ-45",NULL},
/* 1CE69 */ { "SIXIÈME DE PAVÉ ISOLÉ-145",NULL},
/* 1CE6A */ { "SIXIÈME DE PAVÉ ISOLÉ-245",NULL},
/* 1CE6B */ { "SIXIÈME DE PAVÉ ISOLÉ-1245",NULL},
/* 1CE6C */ { "SIXIÈME DE PAVÉ ISOLÉ-345",NULL},
/* 1CE6D */ { "SIXIÈME DE PAVÉ ISOLÉ-1345",NULL},
/* 1CE6E */ { "SIXIÈME DE PAVÉ ISOLÉ-2345",NULL},
/* 1CE6F */ { "SIXIÈME DE PAVÉ ISOLÉ-12345",NULL},
/* 1CE70 */ { "SIXIÈME DE PAVÉ ISOLÉ-6",NULL},
/* 1CE71 */ { "SIXIÈME DE PAVÉ ISOLÉ-16",NULL},
/* 1CE72 */ { "SIXIÈME DE PAVÉ ISOLÉ-26",NULL},
/* 1CE73 */ { "SIXIÈME DE PAVÉ ISOLÉ-126",NULL},
/* 1CE74 */ { "SIXIÈME DE PAVÉ ISOLÉ-36",NULL},
/* 1CE75 */ { "SIXIÈME DE PAVÉ ISOLÉ-136",NULL},
/* 1CE76 */ { "SIXIÈME DE PAVÉ ISOLÉ-236",NULL},
/* 1CE77 */ { "SIXIÈME DE PAVÉ ISOLÉ-1236",NULL},
/* 1CE78 */ { "SIXIÈME DE PAVÉ ISOLÉ-46",NULL},
/* 1CE79 */ { "SIXIÈME DE PAVÉ ISOLÉ-146",NULL},
/* 1CE7A */ { "SIXIÈME DE PAVÉ ISOLÉ-246",NULL},
/* 1CE7B */ { "SIXIÈME DE PAVÉ ISOLÉ-1246",NULL},
/* 1CE7C */ { "SIXIÈME DE PAVÉ ISOLÉ-346",NULL},
/* 1CE7D */ { "SIXIÈME DE PAVÉ ISOLÉ-1346",NULL},
/* 1CE7E */ { "SIXIÈME DE PAVÉ ISOLÉ-2346",NULL},
/* 1CE7F */ { "SIXIÈME DE PAVÉ ISOLÉ-12346",NULL},
/* 1CE80 */ { "SIXIÈME DE PAVÉ ISOLÉ-56",NULL},
/* 1CE81 */ { "SIXIÈME DE PAVÉ ISOLÉ-156",NULL},
/* 1CE82 */ { "SIXIÈME DE PAVÉ ISOLÉ-256",NULL},
/* 1CE83 */ { "SIXIÈME DE PAVÉ ISOLÉ-1256",NULL},
/* 1CE84 */ { "SIXIÈME DE PAVÉ ISOLÉ-356",NULL},
/* 1CE85 */ { "SIXIÈME DE PAVÉ ISOLÉ-1356",NULL},
/* 1CE86 */ { "SIXIÈME DE PAVÉ ISOLÉ-2356",NULL},
/* 1CE87 */ { "SIXIÈME DE PAVÉ ISOLÉ-12356",NULL},
/* 1CE88 */ { "SIXIÈME DE PAVÉ ISOLÉ-456",NULL},
/* 1CE89 */ { "SIXIÈME DE PAVÉ ISOLÉ-1456",NULL},
/* 1CE8A */ { "SIXIÈME DE PAVÉ ISOLÉ-2456",NULL},
/* 1CE8B */ { "SIXIÈME DE PAVÉ ISOLÉ-12456",NULL},
/* 1CE8C */ { "SIXIÈME DE PAVÉ ISOLÉ-3456",NULL},
/* 1CE8D */ { "SIXIÈME DE PAVÉ ISOLÉ-13456",NULL},
/* 1CE8E */ { "SIXIÈME DE PAVÉ ISOLÉ-23456",NULL},
/* 1CE8F */ { "SIXIÈME DE PAVÉ ISOLÉ-123456",NULL},
/* 1CE90 */ { "UN SEIZIÈME DE PAVÉ SUPÉRIEUR GAUCHE",NULL},
/* 1CE91 */ { "UN SEIZIÈME DE PAVÉ CENTRE GAUCHE SUPÉRIEUR",NULL},
/* 1CE92 */ { "UN SEIZIÈME DE PAVÉ CENTRE DROIT SUPÉRIEUR",NULL},
/* 1CE93 */ { "UN SEIZIÈME DE PAVÉ SUPÉRIEUR DROIT",NULL},
/* 1CE94 */ { "UN SEIZIÈME DE PAVÉ MILIEU SUPÉRIEUR GAUCHE",NULL},
/* 1CE95 */ { "UN SEIZIÈME DE PAVÉ CENTRE DU MILIEU SUPÉRIEUR GAUCHE",NULL},
/* 1CE96 */ { "UN SEIZIÈME DE PAVÉ CENTRE DU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1CE97 */ { "UN SEIZIÈME DE PAVÉ MILIEU SUPÉRIEUR DROIT",NULL},
/* 1CE98 */ { "UN SEIZIÈME DE PAVÉ MILIEU INFÉRIEUR GAUCHE",NULL},
/* 1CE99 */ { "UN SEIZIÈME DE PAVÉ CENTRE DU MILIEU INFÉRIEUR GAUCHE",NULL},
/* 1CE9A */ { "UN SEIZIÈME DE PAVÉ CENTRE DU MILIEU INFÉRIEUR DROIT",NULL},
/* 1CE9B */ { "UN SEIZIÈME DE PAVÉ MILIEU INFÉRIEUR DROIT",NULL},
/* 1CE9C */ { "UN SEIZIÈME DE PAVÉ INFÉRIEUR GAUCHE",NULL},
/* 1CE9D */ { "UN SEIZIÈME DE PAVÉ CENTRE GAUCHE INFÉRIEUR",NULL},
/* 1CE9E */ { "UN SEIZIÈME DE PAVÉ CENTRE DROIT INFÉRIEUR",NULL},
/* 1CE9F */ { "UN SEIZIÈME DE PAVÉ INFÉRIEUR DROIT",NULL},
/* 1CEA0 */ { "MOITIÉ DROITE DU QUART INFÉRIEUR DE PAVÉ",NULL},
/* 1CEA1 */ { "TROIS QUARTS DROITS DU QUART INFÉRIEUR DE PAVÉ",NULL},
/* 1CEA2 */ { "TROIS QUARTS GAUCHES DU QUART INFÉRIEUR DE PAVÉ",NULL},
/* 1CEA3 */ { "MOITIÉ GAUCHE DU QUART INFÉRIEUR DE PAVÉ",NULL},
/* 1CEA4 */ { "MOITIÉ INFÉRIEURE DU QUART GAUCHE DE PAVÉ",NULL},
/* 1CEA5 */ { "TROIS QUARTS INFÉRIEURS DU QUART GAUCHE DE PAVÉ",NULL},
/* 1CEA6 */ { "TROIS QUARTS SUPÉRIEURS DU QUART GAUCHE DE PAVÉ",NULL},
/* 1CEA7 */ { "MOITIÉ SUPÉRIEURS DU QUART GAUCHE DE PAVÉ",NULL},
/* 1CEA8 */ { "MOITIÉ GAUCHE DU QUART SUPÉRIEUR DE PAVÉ",NULL},
/* 1CEA9 */ { "TROIS QUARTS GAUCHES DU QUART SUPÉRIEUR DE PAVÉ",NULL},
/* 1CEAA */ { "TROIS QUARTS DROITS DU QUART SUPÉRIEUR DE PAVÉ",NULL},
/* 1CEAB */ { "MOITIÉ DROITE DU QUART SUPÉRIEUR DE PAVÉ",NULL},
/* 1CEAC */ { "MOITIÉ SUPÉRIEURS DU QUART DROIT DE PAVÉ",NULL},
/* 1CEAD */ { "TROIS QUARTS SUPÉRIEURS DU QUART DROIT DE PAVÉ",NULL},
/* 1CEAE */ { "TROIS QUARTS INFÉRIEURS DU QUART DROIT DE PAVÉ",NULL},
/* 1CEAF */ { "MOITIÉ INFÉRIEURE DU QUART DROIT DE PAVÉ",NULL},
/* 1CEB0 */ { "LIGNE EN ZIGZAG HORIZONTALE",NULL},
/* 1CEB1 */ { "SERRURE",NULL},
/* 1CEB2 */ { "VIEIL ORDINATEUR PERSONNEL AVEC MONITEUR EN ORIENTATION PORTRAIT",NULL},
/* 1CEB3 */ { "SYMBOLE EN FORME DE TRIANGLE NOIR POINTANT VERS LA DROITE",NULL},
/* 1CEB4 */ { NULL,NULL},
/* 1CEB5 */ { NULL,NULL},
/* 1CEB6 */ { NULL,NULL},
/* 1CEB7 */ { NULL,NULL},
/* 1CEB8 */ { NULL,NULL},
/* 1CEB9 */ { NULL,NULL},
/* 1CEBA */ { "SYMBOLE FRAGILE","	x (verre à vin - 1F377)"},
/* 1CEBB */ { "SYMBOLE IMMEUBLE DE BUREAUX","	x (immeuble de bureaux - 1F3E2)"},
/* 1CEBC */ { "SYMBOLE ARBRE","	x (arbre caducifolié - 1F333)"},
/* 1CEBD */ { "SYMBOLE POMME","	x (pomme rouge - 1F34E)\n"
	"	x (pomme verte - 1F34F)"},
/* 1CEBE */ { "SYMBOLE CERISE","	x (cerises - 1F352)"},
/* 1CEBF */ { "SYMBOLE FRAISE","	x (fraise - 1F353)"},
/* 1CEC0 */ { "HÉBÉ",NULL},
/* 1CEC1 */ { "IRIS",NULL},
/* 1CEC2 */ { "FLORE",NULL},
/* 1CEC3 */ { "MÉTIS",NULL},
/* 1CEC4 */ { "PARTHÉNOPE","	x (parthénope forme deux - 1F77A)"},
/* 1CEC5 */ { "VICTORIA",NULL},
/* 1CEC6 */ { "ÉGÉRIE",NULL},
/* 1CEC7 */ { "IRÈNE",NULL},
/* 1CEC8 */ { "EUNOMIE",NULL},
/* 1CEC9 */ { "PSYCHÉ",NULL},
/* 1CECA */ { "THÉTIS",NULL},
/* 1CECB */ { "MELPOMÈNE",NULL},
/* 1CECC */ { "FORTUNE",NULL},
/* 1CECD */ { "SYMBOLE ASTRONOMIQUE POUR L'ASTÉROÏDE PROSERPINE","	x (proserpine - 2BD8)"},
/* 1CECE */ { "BELLONE",NULL},
/* 1CECF */ { "AMPHITRITE",NULL},
/* 1CED0 */ { "LEUCOTHÉE",NULL},
/* 1CED1 */ { NULL,NULL},
/* 1CED2 */ { NULL,NULL},
/* 1CED3 */ { NULL,NULL},
/* 1CED4 */ { NULL,NULL},
/* 1CED5 */ { NULL,NULL},
/* 1CED6 */ { NULL,NULL},
/* 1CED7 */ { NULL,NULL},
/* 1CED8 */ { NULL,NULL},
/* 1CED9 */ { NULL,NULL},
/* 1CEDA */ { NULL,NULL},
/* 1CEDB */ { NULL,NULL},
/* 1CEDC */ { NULL,NULL},
/* 1CEDD */ { NULL,NULL},
/* 1CEDE */ { NULL,NULL},
/* 1CEDF */ { NULL,NULL},
/* 1CEE0 */ { "FIGURE GÉOMANTIQUE POPULUS","	= Le Peuple"},
/* 1CEE1 */ { "FIGURE GÉOMANTIQUE TRISTITIA","	= La Tristesse"},
/* 1CEE2 */ { "FIGURE GÉOMANTIQUE ALBUS","	= Le Blanc"},
/* 1CEE3 */ { "FIGURE GÉOMANTIQUE FORTUNA MAJOR","	= La Fortune majeure"},
/* 1CEE4 */ { "FIGURE GÉOMANTIQUE RUBEUS","	= Le Rouge"},
/* 1CEE5 */ { "FIGURE GÉOMANTIQUE ACQUISITIO","	= Le Gain"},
/* 1CEE6 */ { "FIGURE GÉOMANTIQUE CONJUNCTIO","	= La Conjonction"},
/* 1CEE7 */ { "FIGURE GÉOMANTIQUE CAPUT DRACONIS","	= La Tête du dragon"},
/* 1CEE8 */ { "FIGURE GÉOMANTIQUE LAETITIA","	= La Joie"},
/* 1CEE9 */ { "FIGURE GÉOMANTIQUE CARCER","	= La Prison"},
/* 1CEEA */ { "FIGURE GÉOMANTIQUE AMISSIO","	= La Perte"},
/* 1CEEB */ { "FIGURE GÉOMANTIQUE PUELLA","	= La Jeune Fille"},
/* 1CEEC */ { "FIGURE GÉOMANTIQUE FORTUNA MINOR","	= La Fortune mineure"},
/* 1CEED */ { "FIGURE GÉOMANTIQUE PUER","	= Le Jeune Garçon"},
/* 1CEEE */ { "FIGURE GÉOMANTIQUE CAUDA DRACONIS","	= La Queue du dragon"},
/* 1CEEF */ { "FIGURE GÉOMANTIQUE VIA","	= La Voie"},
/* 1CEF0 */ { "CERCLE BLANC MODÉRÉMENT PETIT AVEC BARRE HORIZONTALE","	* on utilise la forme en exposant pour désigner l'état standard (en chimie)\n"
	"	x (cercle avec barre horizontale - 29B5)"},
/* 1CEF1 */ { NULL,NULL},
/* 1CEF2 */ { NULL,NULL},
/* 1CEF3 */ { NULL,NULL},
/* 1CEF4 */ { NULL,NULL},
/* 1CEF5 */ { NULL,NULL},
/* 1CEF6 */ { NULL,NULL},
/* 1CEF7 */ { NULL,NULL},
/* 1CEF8 */ { NULL,NULL},
/* 1CEF9 */ { NULL,NULL},
/* 1CEFA */ { NULL,NULL},
/* 1CEFB */ { NULL,NULL},
/* 1CEFC */ { NULL,NULL},
/* 1CEFD */ { NULL,NULL},
/* 1CEFE */ { NULL,NULL},
/* 1CEFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_CF[] = {
/* 1CF00 */ { "DIACRITIQUE ZNAMENNY GORAZDO NIZKO S KRYJEM À GAUCHE",NULL},
/* 1CF01 */ { "DIACRITIQUE ZNAMENNY NIZKO S KRYJEM À GAUCHE",NULL},
/* 1CF02 */ { "DIACRITIQUE ZNAMENNY TSATA À GAUCHE",NULL},
/* 1CF03 */ { "DIACRITIQUE ZNAMENNY GORAZDO NIZKO À GAUCHE",NULL},
/* 1CF04 */ { "DIACRITIQUE ZNAMENNY NIZKO À GAUCHE",NULL},
/* 1CF05 */ { "DIACRITIQUE ZNAMENNY SREDNÉ À GAUCHE",NULL},
/* 1CF06 */ { "DIACRITIQUE ZNAMENNY MALO POVYCHÉ À GAUCHE",NULL},
/* 1CF07 */ { "DIACRITIQUE ZNAMENNY POVYCHÉ À GAUCHE",NULL},
/* 1CF08 */ { "DIACRITIQUE ZNAMENNY VYSOKO À GAUCHE",NULL},
/* 1CF09 */ { "DIACRITIQUE ZNAMENNY MALO POVYCHÉ S KHOKHLOM À GAUCHE",NULL},
/* 1CF0A */ { "DIACRITIQUE ZNAMENNY POVYCHÉ S KHOKHLOM À GAUCHE",NULL},
/* 1CF0B */ { "DIACRITIQUE ZNAMENNY VYSOKO S KHOKHLOM À GAUCHE",NULL},
/* 1CF0C */ { "DIACRITIQUE ZNAMENNY GORAZDO NIZKO S KRYJEM À DROITE",NULL},
/* 1CF0D */ { "DIACRITIQUE ZNAMENNY NIZKO S KRYJEM À DROITE",NULL},
/* 1CF0E */ { "DIACRITIQUE ZNAMENNY TSATA À DROITE",NULL},
/* 1CF0F */ { "DIACRITIQUE ZNAMENNY GORAZDO NIZKO À DROITE",NULL},
/* 1CF10 */ { "DIACRITIQUE ZNAMENNY NIZKO À DROITE",NULL},
/* 1CF11 */ { "DIACRITIQUE ZNAMENNY SREDNÉ À DROITE",NULL},
/* 1CF12 */ { "DIACRITIQUE ZNAMENNY MALO POVYCHÉ À DROITE",NULL},
/* 1CF13 */ { "DIACRITIQUE ZNAMENNY POVYCHÉ À DROITE",NULL},
/* 1CF14 */ { "DIACRITIQUE ZNAMENNY VYSOKO À DROITE",NULL},
/* 1CF15 */ { "DIACRITIQUE ZNAMENNY MALO POVYCHÉ S KHOKHLOM À DROITE",NULL},
/* 1CF16 */ { "DIACRITIQUE ZNAMENNY POVYCHÉ S KHOKHLOM À DROITE",NULL},
/* 1CF17 */ { "DIACRITIQUE ZNAMENNY VYSOKO S KHOKHLOM À DROITE",NULL},
/* 1CF18 */ { "DIACRITIQUE ZNAMENNY TSATA S KRYJEM",NULL},
/* 1CF19 */ { "DIACRITIQUE ZNAMENNY MALO POVYCHÉ S KRYJEM",NULL},
/* 1CF1A */ { "DIACRITIQUE ZNAMENNY STRANNO MALO POVYCHÉ",NULL},
/* 1CF1B */ { "DIACRITIQUE ZNAMENNY POVYCHÉ S KRYJEM",NULL},
/* 1CF1C */ { "DIACRITIQUE ZNAMENNY POVYCHÉ STRANNO",NULL},
/* 1CF1D */ { "DIACRITIQUE ZNAMENNY VYSOKO S KRYJEM",NULL},
/* 1CF1E */ { "DIACRITIQUE ZNAMENNY MALO POVYCHÉ STRANNO",NULL},
/* 1CF1F */ { "DIACRITIQUE ZNAMENNY GORAZDO VYSOKO",NULL},
/* 1CF20 */ { "DIACRITIQUE ZNAMENNY ZÉLO",NULL},
/* 1CF21 */ { "DIACRITIQUE ZNAMENNY ON",NULL},
/* 1CF22 */ { "DIACRITIQUE ZNAMENNY RAVNO",NULL},
/* 1CF23 */ { "DIACRITIQUE ZNAMENNY TIKHAYA",NULL},
/* 1CF24 */ { "DIACRITIQUE ZNAMENNY BORZAYA",NULL},
/* 1CF25 */ { "DIACRITIQUE ZNAMENNY OUDARKA",NULL},
/* 1CF26 */ { "DIACRITIQUE ZNAMENNY PODVERTKA",NULL},
/* 1CF27 */ { "DIACRITIQUE ZNAMENNY LOMKA",NULL},
/* 1CF28 */ { "DIACRITIQUE ZNAMENNY KOUPNAYA",NULL},
/* 1CF29 */ { "DIACRITIQUE ZNAMENNY KATCHKA",NULL},
/* 1CF2A */ { "DIACRITIQUE ZNAMENNY ZÉVOK",NULL},
/* 1CF2B */ { "DIACRITIQUE ZNAMENNY SKOBA",NULL},
/* 1CF2C */ { "DIACRITIQUE ZNAMENNY RAZSÉKA",NULL},
/* 1CF2D */ { "DIACRITIQUE ZNAMENNY KRYJ À GAUCHE",NULL},
/* 1CF2E */ { NULL,NULL},
/* 1CF2F */ { NULL,NULL},
/* 1CF30 */ { "DIACRITIQUE ZNAMENNY DE GAMME TONALE MRATCHNO",NULL},
/* 1CF31 */ { "DIACRITIQUE ZNAMENNY DE GAMME TONALE SVETLO",NULL},
/* 1CF32 */ { "DIACRITIQUE ZNAMENNY DE GAMME TONALE TRESVETLO",NULL},
/* 1CF33 */ { "DIACRITIQUE ZNAMENNY ZADERJKA","	= ottyajka"},
/* 1CF34 */ { "DIACRITIQUE ZNAMENNY DÉMESTVENNY ZADERJKA",NULL},
/* 1CF35 */ { "DIACRITIQUE ZNAMENNY OTSETCHKA",NULL},
/* 1CF36 */ { "DIACRITIQUE ZNAMENNY PODTCHACHIÉ",NULL},
/* 1CF37 */ { "DIACRITIQUE ZNAMENNY PODTCHACHIÉ À BARRE VERTICALE",NULL},
/* 1CF38 */ { "DIACRITIQUE ZNAMENNY TCHACHKA",NULL},
/* 1CF39 */ { "DIACRITIQUE ZNAMENNY TCHACHKA POLNAYA",NULL},
/* 1CF3A */ { "DIACRITIQUE ZNAMENNY OBLATCHKO",NULL},
/* 1CF3B */ { "DIACRITIQUE ZNAMENNY SOROTCHYA NOJKA","	= sokolik"},
/* 1CF3C */ { "DIACRITIQUE ZNAMENNY TOTCHKA",NULL},
/* 1CF3D */ { "DIACRITIQUE ZNAMENNY DVOÉTOTCHIÉ",NULL},
/* 1CF3E */ { "DIACRITIQUE ZNAMENNY OMET VERTICAL D'ATTACHE",NULL},
/* 1CF3F */ { "DIACRITIQUE ZNAMENNY OMET INCURVÉ",NULL},
/* 1CF40 */ { "DIACRITIQUE ZNAMENNY KRYJ",NULL},
/* 1CF41 */ { "DIACRITIQUE ZNAMENNY INDICATEUR DE GAMME TONALE INFÉRIEURE",NULL},
/* 1CF42 */ { "MODIFICATEUR DE PRIZNAK ZNAMENNY NIVEAU 2",NULL},
/* 1CF43 */ { "MODIFICATEUR DE PRIZNAK ZNAMENNY NIVEAU 3",NULL},
/* 1CF44 */ { "MODIFICATEUR DE PRIZNAK ZNAMENNY CHANGEMENT DE DIRECTION",NULL},
/* 1CF45 */ { "MODIFICATEUR DE PRIZNAK ZNAMENNY KRYJ",NULL},
/* 1CF46 */ { "MODIFICATEUR DE PRIZNAK ZNAMENNY ROG",NULL},
/* 1CF47 */ { NULL,NULL},
/* 1CF48 */ { NULL,NULL},
/* 1CF49 */ { NULL,NULL},
/* 1CF4A */ { NULL,NULL},
/* 1CF4B */ { NULL,NULL},
/* 1CF4C */ { NULL,NULL},
/* 1CF4D */ { NULL,NULL},
/* 1CF4E */ { NULL,NULL},
/* 1CF4F */ { NULL,NULL},
/* 1CF50 */ { "NEUME ZNAMENNY KRYOUK",NULL},
/* 1CF51 */ { "NEUME ZNAMENNY KRYOUK TIKHY",NULL},
/* 1CF52 */ { "NEUME ZNAMENNY PARAKLIT",NULL},
/* 1CF53 */ { "NEUME ZNAMENNY DVA V TCHELNOU",NULL},
/* 1CF54 */ { "NEUME ZNAMENNY KLYOUTCH","	= kryouk klyoutchévoy"},
/* 1CF55 */ { "NEUME ZNAMENNY ZANOJEK",NULL},
/* 1CF56 */ { "NEUME ZNAMENNY STOPITSA",NULL},
/* 1CF57 */ { "NEUME ZNAMENNY STOPITSA S OTCHKOM",NULL},
/* 1CF58 */ { "NEUME ZNAMENNY PÉRÉVODKA",NULL},
/* 1CF59 */ { "NEUME ZNAMENNY PÉRÉVODKA NÉPOSTOYANNAYA",NULL},
/* 1CF5A */ { "NEUME ZNAMENNY STOPITSA AVEC SOROTCHYA NOJKA","	* n'est pas un caractère décomposable"},
/* 1CF5B */ { "NEUME ZNAMENNY TCHELYOUSTKA",NULL},
/* 1CF5C */ { "NEUME ZNAMENNY PALKA",NULL},
/* 1CF5D */ { "NEUME ZNAMENNY ZAPYATAYA",NULL},
/* 1CF5E */ { "NEUME ZNAMENNY GOLOUBTCHIK BORZY",NULL},
/* 1CF5F */ { "NEUME ZNAMENNY GOLOUBTCHIK TIKHY",NULL},
/* 1CF60 */ { "NEUME ZNAMENNY GOLOUBTCHIK MRATCHNY",NULL},
/* 1CF61 */ { "NEUME ZNAMENNY GOLOUBTCHIK SVETLY",NULL},
/* 1CF62 */ { "NEUME ZNAMENNY GOLOUBTCHIK TRESVETLY","	= goloubtchik népostoyanny"},
/* 1CF63 */ { "NEUME ZNAMENNY VRAKHIYA PROSTAYA",NULL},
/* 1CF64 */ { "NEUME ZNAMENNY VRAKHIYA MRATCHNAYA",NULL},
/* 1CF65 */ { "NEUME ZNAMENNY VRAKHIYA SVETLAYA",NULL},
/* 1CF66 */ { "NEUME ZNAMENNY VRAKHIYA TRESVETLAYA","	= vrakhia népostoyannaya"},
/* 1CF67 */ { "NEUME ZNAMENNY VRAKHIYA KLYOUTCHÉVAYA PROSTAYA",NULL},
/* 1CF68 */ { "NEUME ZNAMENNY VRAKHIYA KLYOUTCHÉVAYA MRATCHNAYA",NULL},
/* 1CF69 */ { "NEUME ZNAMENNY VRAKHIYA KLYOUTCHÉVAYA SVETLAYA",NULL},
/* 1CF6A */ { "NEUME ZNAMENNY VRAKHIYA KLYOUTCHÉVAYA TRESVETLAYA","	= vrakhia klyoutchévaya népostoyannaya"},
/* 1CF6B */ { "NEUME ZNAMENNY DOUBLE ZAPYATAYA",NULL},
/* 1CF6C */ { "NEUME ZNAMENNY TCHÉLYOUSTKA RÉFLÉCHI",NULL},
/* 1CF6D */ { "NEUME ZNAMENNY DERBITSA",NULL},
/* 1CF6E */ { "NEUME ZNAMENNY KHAMILO",NULL},
/* 1CF6F */ { "NEUME ZNAMENNY TCHACHKA",NULL},
/* 1CF70 */ { "NEUME ZNAMENNY PODTCHACHIÉ",NULL},
/* 1CF71 */ { "NEUME ZNAMENNY SKAMEYTSA MRATCHNAYA",NULL},
/* 1CF72 */ { "NEUME ZNAMENNY SKAMEYTSA SVETLAYA",NULL},
/* 1CF73 */ { "NEUME ZNAMENNY SKAMEYTSA TRESVETLAYA",NULL},
/* 1CF74 */ { "NEUME ZNAMENNY SKAMEYTSA TIKHAYA",NULL},
/* 1CF75 */ { "NEUME ZNAMENNY DÉMESTVENNY KLYOUTCH","	= skameytsa klyoutchévaya"},
/* 1CF76 */ { "NEUME ZNAMENNY SKAMEYTSA KLYOUTCHÉVAYA SVETLAYA",NULL},
/* 1CF77 */ { "NEUME ZNAMENNY SKAMEYTSA KLYOUTCHÉNÉPOSTOYANNAYA",NULL},
/* 1CF78 */ { "NEUME ZNAMENNY SKAMEYTSA KLYOUTCHÉVAYA TIKHAYA",NULL},
/* 1CF79 */ { "NEUME ZNAMENNY SKAMEYTSA DVOÉTCHELNAYA PROSTAYA",NULL},
/* 1CF7A */ { "NEUME ZNAMENNY SKAMEYTSA DVOÉTCHELNAYA SVETLAYA",NULL},
/* 1CF7B */ { "NEUME ZNAMENNY SKAMEYTSA DVOÉTCHELNAYA NÉPOSTOYANNAYA",NULL},
/* 1CF7C */ { "NEUME ZNAMENNY SKAMEYTSA DVOÉTCHELNAYA KLYOUTCHÉVAYA",NULL},
/* 1CF7D */ { "NEUME ZNAMENNY SLOJITIÉ",NULL},
/* 1CF7E */ { "NEUME ZNAMENNY SLOJITIÉ S ZAPYATOY",NULL},
/* 1CF7F */ { "NEUME ZNAMENNY SLOJITIÉ ZAKRYTOÉ",NULL},
/* 1CF80 */ { "NEUME ZNAMENNY SLOJITIÉ S KRYJEM",NULL},
/* 1CF81 */ { "NEUME ZNAMENNY KRYJ",NULL},
/* 1CF82 */ { "NEUME ZNAMENNY ROG",NULL},
/* 1CF83 */ { "NEUME ZNAMENNY FITA",NULL},
/* 1CF84 */ { "NEUME ZNAMENNY KOBYLA",NULL},
/* 1CF85 */ { "NEUME ZNAMENNY ZMEYTSA","	= litso"},
/* 1CF86 */ { "NEUME ZNAMENNY STATYA",NULL},
/* 1CF87 */ { "NEUME ZNAMENNY STATYA S ZAPYATOY",NULL},
/* 1CF88 */ { "NEUME ZNAMENNY STATYA S KRYJEM",NULL},
/* 1CF89 */ { "NEUME ZNAMENNY STATYA S ZAPYATOY I KRYJEM",NULL},
/* 1CF8A */ { "NEUME ZNAMENNY STATYA S KRYJEM I ZAPYATOY",NULL},
/* 1CF8B */ { "NEUME ZNAMENNY STATYA ZAKRYTAYA",NULL},
/* 1CF8C */ { "NEUME ZNAMENNY STATYA ZAKRYTAYA S ZAPYATOY",NULL},
/* 1CF8D */ { "NEUME ZNAMENNY STATYA S ROGOM",NULL},
/* 1CF8E */ { "NEUME ZNAMENNY STATYA S DVOUMYA ZAPYATYMI",NULL},
/* 1CF8F */ { "NEUME ZNAMENNY STATYA S ZAPYATOY I PODTCHAJIEM",NULL},
/* 1CF90 */ { "NEUME ZNAMENNY POLKULIZMY","	* n'est pas un caractère décomposable"},
/* 1CF91 */ { "NEUME ZNAMENNY STATYA NEPOSTOYANNAYA",NULL},
/* 1CF92 */ { "NEUME ZNAMENNY STRELA PROSTAYA",NULL},
/* 1CF93 */ { "NEUME ZNAMENNY STRELA MRATCHNOTIKHAYA",NULL},
/* 1CF94 */ { "NEUME ZNAMENNY STRELA KRYJÉVAYA","	= strela poloukryjévaya"},
/* 1CF95 */ { "NEUME ZNAMENNY STRELA POLOUPOVODNAYA",NULL},
/* 1CF96 */ { "NEUME ZNAMENNY STRELA POVODNAYA",NULL},
/* 1CF97 */ { "NEUME ZNAMENNY STRELA NÉPOSTOYANNAYA",NULL},
/* 1CF98 */ { "NEUME ZNAMENNY STRELA KLYOUTCHÉPOVODNAYA",NULL},
/* 1CF99 */ { "NEUME ZNAMENNY STRELA KLYOUTCHÉNÉPOSTOYANNAYA",NULL},
/* 1CF9A */ { "NEUME ZNAMENNY STRELA TIKHAYA POUTNAYA",NULL},
/* 1CF9B */ { "NEUME ZNAMENNY STRELA DVOÉTCHELNAYA",NULL},
/* 1CF9C */ { "NEUME ZNAMENNY STRELA DVOÉTCHELNOKRYJÉVAYA",NULL},
/* 1CF9D */ { "NEUME ZNAMENNY STRELA DVOÉTCHELNOPOVODNAYA",NULL},
/* 1CF9E */ { "NEUME ZNAMENNY STRELA DVOÉTCHELNAYA KLYOUTCHÉVAYA",NULL},
/* 1CF9F */ { "NEUME ZNAMENNY STRELA DVOÉTCHELNOPOVODNAYA KLYOUTCHÉVAYA",NULL},
/* 1CFA0 */ { "NEUME ZNAMENNY STRELA GROMNAYA AVEC ZAPYATAYA SIMPLE",NULL},
/* 1CFA1 */ { "NEUME ZNAMENNY STRELA GROMOPOVODNAYA AVEC ZAPYATAYA SIMPLE",NULL},
/* 1CFA2 */ { "NEUME ZNAMENNY STRELA GROMNAYA",NULL},
/* 1CFA3 */ { "NEUME ZNAMENNY STRELA GROMOPOVODNAYA",NULL},
/* 1CFA4 */ { "NEUME ZNAMENNY STRELA GROMOPOVODNAYA AVEC ZAPYATAYA DOUBLE",NULL},
/* 1CFA5 */ { "NEUME ZNAMENNY STRELA GROMOKRYJÉVAYA",NULL},
/* 1CFA6 */ { "NEUME ZNAMENNY STRELA GROMOKRYJÉVAYA POVODNAYA","	= strela gromomratchnaya s kryjem"},
/* 1CFA7 */ { "NEUME ZNAMENNY METCHIK",NULL},
/* 1CFA8 */ { "NEUME ZNAMENNY METCHIK POVODNY",NULL},
/* 1CFA9 */ { "NEUME ZNAMENNY METCHIK KLYOUTCHÉVOY",NULL},
/* 1CFAA */ { "NEUME ZNAMENNY METCHIK KLYOUTCHÉPOVODNY",NULL},
/* 1CFAB */ { "NEUME ZNAMENNY METCHIK KLYOUTCHÉNÉPOSTOYANNY",NULL},
/* 1CFAC */ { "NEUME ZNAMENNY STRELA TRYASOGLASNAYA",NULL},
/* 1CFAD */ { "NEUME ZNAMENNY STRELA TRYASOPOVODNAYA",NULL},
/* 1CFAE */ { "NEUME ZNAMENNY STRELA TRYASOSTRELNAYA",NULL},
/* 1CFAF */ { "NEUME ZNAMENNY OSOKA",NULL},
/* 1CFB0 */ { "NEUME ZNAMENNY OSOKA SVETLAYA",NULL},
/* 1CFB1 */ { "NEUME ZNAMENNY OSOKA TRESVETLAYA","	= osoka nepostoyannaya"},
/* 1CFB2 */ { "NEUME ZNAMENNY OSOKA KRYOUKOVAYA SVETLAYA",NULL},
/* 1CFB3 */ { "NEUME ZNAMENNY OSOKA KLYOUTCHÉVAYA SVETLAYA",NULL},
/* 1CFB4 */ { "NEUME ZNAMENNY OSOKA KLYOUTCHÉVAYA NÉPOSTOYANNAYA",NULL},
/* 1CFB5 */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA",NULL},
/* 1CFB6 */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA POVODNAYA",NULL},
/* 1CFB7 */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMNAYA AVEC ZAPYATAYA SIMPLE",NULL},
/* 1CFB8 */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMOPOVODNAYA AVEC ZAPYATAYA SIMPLE",NULL},
/* 1CFB9 */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMNAYA",NULL},
/* 1CFBA */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMOPOVODNAYA",NULL},
/* 1CFBB */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMOPOVODNAYA AVEC ZAPYATAYA DOUBLE",NULL},
/* 1CFBC */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMOKRYJÉVAYA",NULL},
/* 1CFBD */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA GROMOKRYJÉVAYA POVODNAYA","	= strela kryoukovaya gromomratchnaya s kryjem"},
/* 1CFBE */ { "NEUME ZNAMENNY STRELA KRYOUKOVAYA TRYASKA",NULL},
/* 1CFBF */ { "NEUME ZNAMENNY KOUFISMA",NULL},
/* 1CFC0 */ { "NEUME ZNAMENNY OBLAKO",NULL},
/* 1CFC1 */ { "NEUME ZNAMENNY DOUDA",NULL},
/* 1CFC2 */ { "NEUME ZNAMENNY NEMKA",NULL},
/* 1CFC3 */ { "NEUME ZNAMENNY PAOUK",NULL},
/* 1CFC4 */ { NULL,NULL},
/* 1CFC5 */ { NULL,NULL},
/* 1CFC6 */ { NULL,NULL},
/* 1CFC7 */ { NULL,NULL},
/* 1CFC8 */ { NULL,NULL},
/* 1CFC9 */ { NULL,NULL},
/* 1CFCA */ { NULL,NULL},
/* 1CFCB */ { NULL,NULL},
/* 1CFCC */ { NULL,NULL},
/* 1CFCD */ { NULL,NULL},
/* 1CFCE */ { NULL,NULL},
/* 1CFCF */ { NULL,NULL},
/* 1CFD0 */ { NULL,NULL},
/* 1CFD1 */ { NULL,NULL},
/* 1CFD2 */ { NULL,NULL},
/* 1CFD3 */ { NULL,NULL},
/* 1CFD4 */ { NULL,NULL},
/* 1CFD5 */ { NULL,NULL},
/* 1CFD6 */ { NULL,NULL},
/* 1CFD7 */ { NULL,NULL},
/* 1CFD8 */ { NULL,NULL},
/* 1CFD9 */ { NULL,NULL},
/* 1CFDA */ { NULL,NULL},
/* 1CFDB */ { NULL,NULL},
/* 1CFDC */ { NULL,NULL},
/* 1CFDD */ { NULL,NULL},
/* 1CFDE */ { NULL,NULL},
/* 1CFDF */ { NULL,NULL},
/* 1CFE0 */ { NULL,NULL},
/* 1CFE1 */ { NULL,NULL},
/* 1CFE2 */ { NULL,NULL},
/* 1CFE3 */ { NULL,NULL},
/* 1CFE4 */ { NULL,NULL},
/* 1CFE5 */ { NULL,NULL},
/* 1CFE6 */ { NULL,NULL},
/* 1CFE7 */ { NULL,NULL},
/* 1CFE8 */ { NULL,NULL},
/* 1CFE9 */ { NULL,NULL},
/* 1CFEA */ { NULL,NULL},
/* 1CFEB */ { NULL,NULL},
/* 1CFEC */ { NULL,NULL},
/* 1CFED */ { NULL,NULL},
/* 1CFEE */ { NULL,NULL},
/* 1CFEF */ { NULL,NULL},
/* 1CFF0 */ { NULL,NULL},
/* 1CFF1 */ { NULL,NULL},
/* 1CFF2 */ { NULL,NULL},
/* 1CFF3 */ { NULL,NULL},
/* 1CFF4 */ { NULL,NULL},
/* 1CFF5 */ { NULL,NULL},
/* 1CFF6 */ { NULL,NULL},
/* 1CFF7 */ { NULL,NULL},
/* 1CFF8 */ { NULL,NULL},
/* 1CFF9 */ { NULL,NULL},
/* 1CFFA */ { NULL,NULL},
/* 1CFFB */ { NULL,NULL},
/* 1CFFC */ { NULL,NULL},
/* 1CFFD */ { NULL,NULL},
/* 1CFFE */ { NULL,NULL},
/* 1CFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D0[] = {
/* 1D000 */ { "SYMBOLE MUSICAL BYZANTIN PSILI",NULL},
/* 1D001 */ { "SYMBOLE MUSICAL BYZANTIN DASEIA",NULL},
/* 1D002 */ { "SYMBOLE MUSICAL BYZANTIN PÉRISPOMÉNÊ",NULL},
/* 1D003 */ { "SYMBOLE MUSICAL BYZANTIN OXEIA EKFONITIKON","	= seconde ascendante"},
/* 1D004 */ { "SYMBOLE MUSICAL BYZANTIN OXEIA DIPLI",NULL},
/* 1D005 */ { "SYMBOLE MUSICAL BYZANTIN VAREIA EKFONITIKON","	= bareia, seconde descendante"},
/* 1D006 */ { "SYMBOLE MUSICAL BYZANTIN VAREIA DIPLI",NULL},
/* 1D007 */ { "SYMBOLE MUSICAL BYZANTIN KATHISTI",NULL},
/* 1D008 */ { "SYMBOLE MUSICAL BYZANTIN SYRMATIKI",NULL},
/* 1D009 */ { "SYMBOLE MUSICAL BYZANTIN PARAKLITIKI",NULL},
/* 1D00A */ { "SYMBOLE MUSICAL BYZANTIN YPOKRISIS",NULL},
/* 1D00B */ { "SYMBOLE MUSICAL BYZANTIN YPOKRISIS DIPLI",NULL},
/* 1D00C */ { "SYMBOLE MUSICAL BYZANTIN KREMASTI",NULL},
/* 1D00D */ { "SYMBOLE MUSICAL BYZANTIN APESO EKFONITIKON",NULL},
/* 1D00E */ { "SYMBOLE MUSICAL BYZANTIN EXO EKFONITIKON",NULL},
/* 1D00F */ { "SYMBOLE MUSICAL BYZANTIN TELEIA",NULL},
/* 1D010 */ { "SYMBOLE MUSICAL BYZANTIN KENTIMATA",NULL},
/* 1D011 */ { "SYMBOLE MUSICAL BYZANTIN APOSTROFOS",NULL},
/* 1D012 */ { "SYMBOLE MUSICAL BYZANTIN APOSTROFOS DIPLI",NULL},
/* 1D013 */ { "SYMBOLE MUSICAL BYZANTIN SYNEVMA",NULL},
/* 1D014 */ { "SYMBOLE MUSICAL BYZANTIN THITA",NULL},
/* 1D015 */ { "SYMBOLE MUSICAL BYZANTIN OLIGON ARKHAION",NULL},
/* 1D016 */ { "SYMBOLE MUSICAL BYZANTIN GORGON ARKHAION",NULL},
/* 1D017 */ { "SYMBOLE MUSICAL BYZANTIN PSILON",NULL},
/* 1D018 */ { "SYMBOLE MUSICAL BYZANTIN KHAMILON",NULL},
/* 1D019 */ { "SYMBOLE MUSICAL BYZANTIN VATHY",NULL},
/* 1D01A */ { "SYMBOLE MUSICAL BYZANTIN ISON ARKHAION",NULL},
/* 1D01B */ { "SYMBOLE MUSICAL BYZANTIN KENTIMA ARKHAION",NULL},
/* 1D01C */ { "SYMBOLE MUSICAL BYZANTIN KENTIMATA ARKHAION",NULL},
/* 1D01D */ { "SYMBOLE MUSICAL BYZANTIN SAXIMATA",NULL},
/* 1D01E */ { "SYMBOLE MUSICAL BYZANTIN PARIKHON",NULL},
/* 1D01F */ { "SYMBOLE MUSICAL BYZANTIN STAVROS APODEXIA",NULL},
/* 1D020 */ { "SYMBOLE MUSICAL BYZANTIN OXEIAI ARKHAION",NULL},
/* 1D021 */ { "SYMBOLE MUSICAL BYZANTIN VAREIAI ARKHAION",NULL},
/* 1D022 */ { "SYMBOLE MUSICAL BYZANTIN APODERMA ARKHAION",NULL},
/* 1D023 */ { "SYMBOLE MUSICAL BYZANTIN APOTHEMA",NULL},
/* 1D024 */ { "SYMBOLE MUSICAL BYZANTIN KLASMA",NULL},
/* 1D025 */ { "SYMBOLE MUSICAL BYZANTIN REVMA",NULL},
/* 1D026 */ { "SYMBOLE MUSICAL BYZANTIN PIASMA ARKHAION",NULL},
/* 1D027 */ { "SYMBOLE MUSICAL BYZANTIN TINAGMA",NULL},
/* 1D028 */ { "SYMBOLE MUSICAL BYZANTIN ANATRIKHISMA",NULL},
/* 1D029 */ { "SYMBOLE MUSICAL BYZANTIN SEISMA",NULL},
/* 1D02A */ { "SYMBOLE MUSICAL BYZANTIN SYNAGMA ARKHAION",NULL},
/* 1D02B */ { "SYMBOLE MUSICAL BYZANTIN SYNAGMA META STAVROU",NULL},
/* 1D02C */ { "SYMBOLE MUSICAL BYZANTIN OYRANISMA ARKHAION",NULL},
/* 1D02D */ { "SYMBOLE MUSICAL BYZANTIN THEMA",NULL},
/* 1D02E */ { "SYMBOLE MUSICAL BYZANTIN LEMOI",NULL},
/* 1D02F */ { "SYMBOLE MUSICAL BYZANTIN DYO",NULL},
/* 1D030 */ { "SYMBOLE MUSICAL BYZANTIN TRIA",NULL},
/* 1D031 */ { "SYMBOLE MUSICAL BYZANTIN TESSERA",NULL},
/* 1D032 */ { "SYMBOLE MUSICAL BYZANTIN KRATIMATA",NULL},
/* 1D033 */ { "SYMBOLE MUSICAL BYZANTIN APESO EXO NEO",NULL},
/* 1D034 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA ARKHAION",NULL},
/* 1D035 */ { "SYMBOLE MUSICAL BYZANTIN IMIFTHORA",NULL},
/* 1D036 */ { "SYMBOLE MUSICAL BYZANTIN TROMIKON ARKHAION",NULL},
/* 1D037 */ { "SYMBOLE MUSICAL BYZANTIN KATAVA TROMIKON",NULL},
/* 1D038 */ { "SYMBOLE MUSICAL BYZANTIN PELASTON",NULL},
/* 1D039 */ { "SYMBOLE MUSICAL BYZANTIN PSIFISTON",NULL},
/* 1D03A */ { "SYMBOLE MUSICAL BYZANTIN KONTEVMA",NULL},
/* 1D03B */ { "SYMBOLE MUSICAL BYZANTIN KHOREVMA ARKHAION",NULL},
/* 1D03C */ { "SYMBOLE MUSICAL BYZANTIN RAPISMA",NULL},
/* 1D03D */ { "SYMBOLE MUSICAL BYZANTIN PARAKALESMA ARKHAION",NULL},
/* 1D03E */ { "SYMBOLE MUSICAL BYZANTIN PARAKLITIKI ARKHAION",NULL},
/* 1D03F */ { "SYMBOLE MUSICAL BYZANTIN IKHADIN",NULL},
/* 1D040 */ { "SYMBOLE MUSICAL BYZANTIN NANA",NULL},
/* 1D041 */ { "SYMBOLE MUSICAL BYZANTIN PETASMA",NULL},
/* 1D042 */ { "SYMBOLE MUSICAL BYZANTIN KONTEVMA ALLO",NULL},
/* 1D043 */ { "SYMBOLE MUSICAL BYZANTIN TROMIKON ALLO",NULL},
/* 1D044 */ { "SYMBOLE MUSICAL BYZANTIN STRAGGISMATA",NULL},
/* 1D045 */ { "SYMBOLE MUSICAL BYZANTIN GRONTHISMATA",NULL},
/* 1D046 */ { "SYMBOLE MUSICAL BYZANTIN ISON NEO",NULL},
/* 1D047 */ { "SYMBOLE MUSICAL BYZANTIN OLIGON NEO",NULL},
/* 1D048 */ { "SYMBOLE MUSICAL BYZANTIN OXEIA NEO",NULL},
/* 1D049 */ { "SYMBOLE MUSICAL BYZANTIN PETASTI",NULL},
/* 1D04A */ { "SYMBOLE MUSICAL BYZANTIN KOUFISMA",NULL},
/* 1D04B */ { "SYMBOLE MUSICAL BYZANTIN PETASTOKOUFISMA",NULL},
/* 1D04C */ { "SYMBOLE MUSICAL BYZANTIN KRATIMOKOUFISMA",NULL},
/* 1D04D */ { "SYMBOLE MUSICAL BYZANTIN PELASTON NEO",NULL},
/* 1D04E */ { "SYMBOLE MUSICAL BYZANTIN KENTIMATA NEO ANO",NULL},
/* 1D04F */ { "SYMBOLE MUSICAL BYZANTIN KENTIMA NEO ANO",NULL},
/* 1D050 */ { "SYMBOLE MUSICAL BYZANTIN YPSILI",NULL},
/* 1D051 */ { "SYMBOLE MUSICAL BYZANTIN APOSTROFOS NEO",NULL},
/* 1D052 */ { "SYMBOLE MUSICAL BYZANTIN APOSTROFOI SYNDESMOS NEO",NULL},
/* 1D053 */ { "SYMBOLE MUSICAL BYZANTIN YPORROI",NULL},
/* 1D054 */ { "SYMBOLE MUSICAL BYZANTIN KRATIMOYPORROON",NULL},
/* 1D055 */ { "SYMBOLE MUSICAL BYZANTIN ELAFRON",NULL},
/* 1D056 */ { "SYMBOLE MUSICAL BYZANTIN KHAMILI",NULL},
/* 1D057 */ { "SYMBOLE MUSICAL BYZANTIN MIKRON ISON",NULL},
/* 1D058 */ { "SYMBOLE MUSICAL BYZANTIN VAREIA NEO",NULL},
/* 1D059 */ { "SYMBOLE MUSICAL BYZANTIN PIASMA NEO",NULL},
/* 1D05A */ { "SYMBOLE MUSICAL BYZANTIN PSIFISTON NEO",NULL},
/* 1D05B */ { "SYMBOLE MUSICAL BYZANTIN OMALON",NULL},
/* 1D05C */ { "SYMBOLE MUSICAL BYZANTIN ANTIKENOMA",NULL},
/* 1D05D */ { "SYMBOLE MUSICAL BYZANTIN LYGISMA",NULL},
/* 1D05E */ { "SYMBOLE MUSICAL BYZANTIN PARAKLITIKI NEO",NULL},
/* 1D05F */ { "SYMBOLE MUSICAL BYZANTIN PARAKALESMA NEO",NULL},
/* 1D060 */ { "SYMBOLE MUSICAL BYZANTIN ETERON PARAKALESMA",NULL},
/* 1D061 */ { "SYMBOLE MUSICAL BYZANTIN KYLISMA",NULL},
/* 1D062 */ { "SYMBOLE MUSICAL BYZANTIN ANTIKENOKYLISMA",NULL},
/* 1D063 */ { "SYMBOLE MUSICAL BYZANTIN TROMIKON NEO",NULL},
/* 1D064 */ { "SYMBOLE MUSICAL BYZANTIN EKSTREPTON",NULL},
/* 1D065 */ { "SYMBOLE MUSICAL BYZANTIN SYNAGMA NEO",NULL},
/* 1D066 */ { "SYMBOLE MUSICAL BYZANTIN SYRMA",NULL},
/* 1D067 */ { "SYMBOLE MUSICAL BYZANTIN KHOREVMA NEO",NULL},
/* 1D068 */ { "SYMBOLE MUSICAL BYZANTIN EPEGERMA",NULL},
/* 1D069 */ { "SYMBOLE MUSICAL BYZANTIN SEISMA NEO",NULL},
/* 1D06A */ { "SYMBOLE MUSICAL BYZANTIN XIRON KLASMA",NULL},
/* 1D06B */ { "SYMBOLE MUSICAL BYZANTIN TROMIKOPSIFISTON",NULL},
/* 1D06C */ { "SYMBOLE MUSICAL BYZANTIN PSIFISTOLYGISMA",NULL},
/* 1D06D */ { "SYMBOLE MUSICAL BYZANTIN TROMIKOLYGISMA",NULL},
/* 1D06E */ { "SYMBOLE MUSICAL BYZANTIN TROMIKOPARAKALESMA",NULL},
/* 1D06F */ { "SYMBOLE MUSICAL BYZANTIN PSIFISTOPARAKALESMA",NULL},
/* 1D070 */ { "SYMBOLE MUSICAL BYZANTIN TROMIKOSYNAGMA",NULL},
/* 1D071 */ { "SYMBOLE MUSICAL BYZANTIN PSIFISTOSYNAGMA",NULL},
/* 1D072 */ { "SYMBOLE MUSICAL BYZANTIN GORGOSYNTHETON",NULL},
/* 1D073 */ { "SYMBOLE MUSICAL BYZANTIN ARGOSYNTHETON",NULL},
/* 1D074 */ { "SYMBOLE MUSICAL BYZANTIN ETERON ARGOSYNTHETON",NULL},
/* 1D075 */ { "SYMBOLE MUSICAL BYZANTIN OYRANISMA NEO",NULL},
/* 1D076 */ { "SYMBOLE MUSICAL BYZANTIN THEMATISMOS ESO",NULL},
/* 1D077 */ { "SYMBOLE MUSICAL BYZANTIN THEMATISMOS EXO",NULL},
/* 1D078 */ { "SYMBOLE MUSICAL BYZANTIN THEMA APLOUN",NULL},
/* 1D079 */ { "SYMBOLE MUSICAL BYZANTIN THES KAI APOTHES",NULL},
/* 1D07A */ { "SYMBOLE MUSICAL BYZANTIN KATAVASMA",NULL},
/* 1D07B */ { "SYMBOLE MUSICAL BYZANTIN ENDOFONON",NULL},
/* 1D07C */ { "SYMBOLE MUSICAL BYZANTIN YFEN KATO",NULL},
/* 1D07D */ { "SYMBOLE MUSICAL BYZANTIN YFEN ANO",NULL},
/* 1D07E */ { "SYMBOLE MUSICAL BYZANTIN STAVROS",NULL},
/* 1D07F */ { "SYMBOLE MUSICAL BYZANTIN KLASMA ANO",NULL},
/* 1D080 */ { "SYMBOLE MUSICAL BYZANTIN DIPLI ARKHAION",NULL},
/* 1D081 */ { "SYMBOLE MUSICAL BYZANTIN KRATIMA ARKHAION",NULL},
/* 1D082 */ { "SYMBOLE MUSICAL BYZANTIN KRATIMA ALLO",NULL},
/* 1D083 */ { "SYMBOLE MUSICAL BYZANTIN KRATIMA NEO",NULL},
/* 1D084 */ { "SYMBOLE MUSICAL BYZANTIN APODERMA NEO",NULL},
/* 1D085 */ { "SYMBOLE MUSICAL BYZANTIN APLI",NULL},
/* 1D086 */ { "SYMBOLE MUSICAL BYZANTIN DIPLI",NULL},
/* 1D087 */ { "SYMBOLE MUSICAL BYZANTIN TRIPLI",NULL},
/* 1D088 */ { "SYMBOLE MUSICAL BYZANTIN TETRAPLI",NULL},
/* 1D089 */ { "SYMBOLE MUSICAL BYZANTIN KORONIS",NULL},
/* 1D08A */ { "SYMBOLE MUSICAL BYZANTIN LEIMMA ENOS KHRONOU",NULL},
/* 1D08B */ { "SYMBOLE MUSICAL BYZANTIN LEIMMA DYO KHRONON",NULL},
/* 1D08C */ { "SYMBOLE MUSICAL BYZANTIN LEIMMA TRION KHRONON",NULL},
/* 1D08D */ { "SYMBOLE MUSICAL BYZANTIN LEIMMA TESSARON KHRONON",NULL},
/* 1D08E */ { "SYMBOLE MUSICAL BYZANTIN LEIMMA IMISEOS KHRONOU",NULL},
/* 1D08F */ { "SYMBOLE MUSICAL BYZANTIN GORGON NEO ANO",NULL},
/* 1D090 */ { "SYMBOLE MUSICAL BYZANTIN GORGON PARESTIGMENON ARISTERA",NULL},
/* 1D091 */ { "SYMBOLE MUSICAL BYZANTIN GORGON PARESTIGMENON DEXIA",NULL},
/* 1D092 */ { "SYMBOLE MUSICAL BYZANTIN DIGORGON",NULL},
/* 1D093 */ { "SYMBOLE MUSICAL BYZANTIN DIGORGON PARESTIGMENON ARISTERA KATO",NULL},
/* 1D094 */ { "SYMBOLE MUSICAL BYZANTIN DIGORGON PARESTIGMENON ARISTERA ANO",NULL},
/* 1D095 */ { "SYMBOLE MUSICAL BYZANTIN DIGORGON PARESTIGMENON DEXIA",NULL},
/* 1D096 */ { "SYMBOLE MUSICAL BYZANTIN TRIGORGON",NULL},
/* 1D097 */ { "SYMBOLE MUSICAL BYZANTIN ARGON",NULL},
/* 1D098 */ { "SYMBOLE MUSICAL BYZANTIN IMIDIARGON","	* nommé diargon par certains experts"},
/* 1D099 */ { "SYMBOLE MUSICAL BYZANTIN DIARGON","	* nommé triargon par certains experts"},
/* 1D09A */ { "SYMBOLE MUSICAL BYZANTIN AGOGI POLI ARGI",NULL},
/* 1D09B */ { "SYMBOLE MUSICAL BYZANTIN AGOGI ARGOTERI",NULL},
/* 1D09C */ { "SYMBOLE MUSICAL BYZANTIN AGOGI ARGI",NULL},
/* 1D09D */ { "SYMBOLE MUSICAL BYZANTIN AGOGI METRIA",NULL},
/* 1D09E */ { "SYMBOLE MUSICAL BYZANTIN AGOGI MESI",NULL},
/* 1D09F */ { "SYMBOLE MUSICAL BYZANTIN AGOGI GORGI",NULL},
/* 1D0A0 */ { "SYMBOLE MUSICAL BYZANTIN AGOGI GORGOTERI",NULL},
/* 1D0A1 */ { "SYMBOLE MUSICAL BYZANTIN AGOGI POLI GORGI",NULL},
/* 1D0A2 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA PROTOS IKHOS",NULL},
/* 1D0A3 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA ALLI PROTOS IKHOS",NULL},
/* 1D0A4 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA DEYTEROS IKHOS",NULL},
/* 1D0A5 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA ALLI DEYTEROS IKHOS",NULL},
/* 1D0A6 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA TRITOS IKHOS",NULL},
/* 1D0A7 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA TRIFONIAS",NULL},
/* 1D0A8 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA TETARTOS IKHOS",NULL},
/* 1D0A9 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA TETARTOS LEGETOS IKHOS",NULL},
/* 1D0AA */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA LEGETOS IKHOS",NULL},
/* 1D0AB */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA PLAGIOS IKHOS",NULL},
/* 1D0AC */ { "SYMBOLE MUSICAL BYZANTIN ISAKIA TELOUS IKHIMATOS",NULL},
/* 1D0AD */ { "SYMBOLE MUSICAL BYZANTIN APOSTROFOI TELOUS IKHIMATOS",NULL},
/* 1D0AE */ { "SYMBOLE MUSICAL BYZANTIN FANEROSIS TETRAFONIAS",NULL},
/* 1D0AF */ { "SYMBOLE MUSICAL BYZANTIN FANEROSIS MONOFONIAS",NULL},
/* 1D0B0 */ { "SYMBOLE MUSICAL BYZANTIN FANEROSIS DIFONIAS",NULL},
/* 1D0B1 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA VARYS IKHOS",NULL},
/* 1D0B2 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA PROTOVARYS IKHOS",NULL},
/* 1D0B3 */ { "SYMBOLE MUSICAL BYZANTIN MARTYRIA PLAGIOS TETARTOS IKHOS",NULL},
/* 1D0B4 */ { "SYMBOLE MUSICAL BYZANTIN GORTHMIKON N APLOUN","	* utilisé dans les formules d'intonation à la place du nu devant les phonèmes a, i, o, u\n"
	"	x (lettre minuscule grecque nu - 03BD)"},
/* 1D0B5 */ { "SYMBOLE MUSICAL BYZANTIN GORTHMIKON N DIPLOUN","	* utilisé dans les formules d'intonation à la place du nu devant le phonème e\n"
	"	x (lettre minuscule grecque nu - 03BD)"},
/* 1D0B6 */ { "SYMBOLE MUSICAL BYZANTIN ENARXIS KAI FTHORA VOU",NULL},
/* 1D0B7 */ { "SYMBOLE MUSICAL BYZANTIN IMIFONON",NULL},
/* 1D0B8 */ { "SYMBOLE MUSICAL BYZANTIN IMIFTHORON",NULL},
/* 1D0B9 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA ARKHAION DEYTEROU IKHOU",NULL},
/* 1D0BA */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI PA",NULL},
/* 1D0BB */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI NANA",NULL},
/* 1D0BC */ { "SYMBOLE MUSICAL BYZANTIN FTHORA NAOS IKHOS",NULL},
/* 1D0BD */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI DI",NULL},
/* 1D0BE */ { "SYMBOLE MUSICAL BYZANTIN FTHORA SKLIRON DIATONON DI",NULL},
/* 1D0BF */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI KE",NULL},
/* 1D0C0 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI ZO",NULL},
/* 1D0C1 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI NI KATO",NULL},
/* 1D0C2 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA DIATONIKI NI ANO",NULL},
/* 1D0C3 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA MALAKON KHROMA DIFONIAS",NULL},
/* 1D0C4 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA MALAKON KHROMA MONOFONIAS",NULL},
/* 1D0C5 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA SKLIRON KHROMA VASIS",NULL},
/* 1D0C6 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA SKLIRON KHROMA SYNAFI",NULL},
/* 1D0C7 */ { "SYMBOLE MUSICAL BYZANTIN FTHORA NENANO",NULL},
/* 1D0C8 */ { "SYMBOLE MUSICAL BYZANTIN KHROA ZYGOS",NULL},
/* 1D0C9 */ { "SYMBOLE MUSICAL BYZANTIN KHROA KLITON",NULL},
/* 1D0CA */ { "SYMBOLE MUSICAL BYZANTIN KHROA SPATHI",NULL},
/* 1D0CB */ { "SYMBOLE MUSICAL BYZANTIN FTHORA I YFESIS TETARTIMORION",NULL},
/* 1D0CC */ { "SYMBOLE MUSICAL BYZANTIN FTHORA ENARMONIOS ANTIFONIA",NULL},
/* 1D0CD */ { "SYMBOLE MUSICAL BYZANTIN YFESIS TRITIMORION",NULL},
/* 1D0CE */ { "SYMBOLE MUSICAL BYZANTIN DIESIS TRITIMORION",NULL},
/* 1D0CF */ { "SYMBOLE MUSICAL BYZANTIN DIESIS TETARTIMORION",NULL},
/* 1D0D0 */ { "SYMBOLE MUSICAL BYZANTIN DIESIS APLI DYO DODEKATA",NULL},
/* 1D0D1 */ { "SYMBOLE MUSICAL BYZANTIN DIESIS MONOGRAMMOS TESSERA DODEKATA",NULL},
/* 1D0D2 */ { "SYMBOLE MUSICAL BYZANTIN DIESIS DIGRAMMOS EX DODEKATA",NULL},
/* 1D0D3 */ { "SYMBOLE MUSICAL BYZANTIN DIESIS TRIGRAMMOS OKTO DODEKATA",NULL},
/* 1D0D4 */ { "SYMBOLE MUSICAL BYZANTIN YFESIS APLI DYO DODEKATA",NULL},
/* 1D0D5 */ { "SYMBOLE MUSICAL BYZANTIN YFESIS MONOGRAMMOS TESSERA DODEKATA",NULL},
/* 1D0D6 */ { "SYMBOLE MUSICAL BYZANTIN YFESIS DIGRAMMOS EX DODEKATA",NULL},
/* 1D0D7 */ { "SYMBOLE MUSICAL BYZANTIN YFESIS TRIGRAMMOS OKTO DODEKATA",NULL},
/* 1D0D8 */ { "SYMBOLE MUSICAL BYZANTIN GENIKI DIESIS",NULL},
/* 1D0D9 */ { "SYMBOLE MUSICAL BYZANTIN GENIKI YFESIS",NULL},
/* 1D0DA */ { "SYMBOLE MUSICAL BYZANTIN DIASTOLI APLI MIKRI","	x (symbole musical barre de mesure courte - 1D105)"},
/* 1D0DB */ { "SYMBOLE MUSICAL BYZANTIN DIASTOLI APLI MEGALI","	x (symbole musical barre de mesure simple - 1D100)"},
/* 1D0DC */ { "SYMBOLE MUSICAL BYZANTIN DIASTOLI DIPLI",NULL},
/* 1D0DD */ { "SYMBOLE MUSICAL BYZANTIN DIASTOLI THESEOS",NULL},
/* 1D0DE */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS THESEOS",NULL},
/* 1D0DF */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS THESEOS DISIMOU",NULL},
/* 1D0E0 */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS THESEOS TRISIMOU",NULL},
/* 1D0E1 */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS THESEOS TETRASIMOU",NULL},
/* 1D0E2 */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS ARSEOS",NULL},
/* 1D0E3 */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS ARSEOS DISIMOU",NULL},
/* 1D0E4 */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS ARSEOS TRISIMOU",NULL},
/* 1D0E5 */ { "SYMBOLE MUSICAL BYZANTIN SIMANSIS ARSEOS TETRASIMOU",NULL},
/* 1D0E6 */ { "SYMBOLE MUSICAL BYZANTIN DIGRAMMA GG",NULL},
/* 1D0E7 */ { "SYMBOLE MUSICAL BYZANTIN DIFTOGGOS OU","	x (lettre minuscule latine ou - 0223)"},
/* 1D0E8 */ { "SYMBOLE MUSICAL BYZANTIN STIGMA","	x (lettre minuscule grecque stigma - 03DB)"},
/* 1D0E9 */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO PA",NULL},
/* 1D0EA */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO VOU",NULL},
/* 1D0EB */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO GA",NULL},
/* 1D0EC */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO DI",NULL},
/* 1D0ED */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO KE",NULL},
/* 1D0EE */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO ZO",NULL},
/* 1D0EF */ { "SYMBOLE MUSICAL BYZANTIN ARKTIKO NI",NULL},
/* 1D0F0 */ { "SYMBOLE MUSICAL BYZANTIN KENTIMATA NEO MESO",NULL},
/* 1D0F1 */ { "SYMBOLE MUSICAL BYZANTIN KENTIMA NEO MESO",NULL},
/* 1D0F2 */ { "SYMBOLE MUSICAL BYZANTIN KENTIMATA NEO KATO",NULL},
/* 1D0F3 */ { "SYMBOLE MUSICAL BYZANTIN KENTIMA NEO KATO",NULL},
/* 1D0F4 */ { "SYMBOLE MUSICAL BYZANTIN KLASMA KATO",NULL},
/* 1D0F5 */ { "SYMBOLE MUSICAL BYZANTIN GORGON NEO KATO",NULL},
/* 1D0F6 */ { NULL,NULL},
/* 1D0F7 */ { NULL,NULL},
/* 1D0F8 */ { NULL,NULL},
/* 1D0F9 */ { NULL,NULL},
/* 1D0FA */ { NULL,NULL},
/* 1D0FB */ { NULL,NULL},
/* 1D0FC */ { NULL,NULL},
/* 1D0FD */ { NULL,NULL},
/* 1D0FE */ { NULL,NULL},
/* 1D0FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D1[] = {
/* 1D100 */ { "SYMBOLE MUSICAL BARRE DE MESURE SIMPLE",NULL},
/* 1D101 */ { "SYMBOLE MUSICAL BARRE DE MESURE DOUBLE",NULL},
/* 1D102 */ { "SYMBOLE MUSICAL BARRE DE MESURE FINALE",NULL},
/* 1D103 */ { "SYMBOLE MUSICAL BARRE DE MESURE FINALE INVERSÉE",NULL},
/* 1D104 */ { "SYMBOLE MUSICAL BARRE DE MESURE À TRAITS DISCONTINUS",NULL},
/* 1D105 */ { "SYMBOLE MUSICAL BARRE DE MESURE COURTE",NULL},
/* 1D106 */ { "SYMBOLE MUSICAL REPRISE DE LA SUITE",NULL},
/* 1D107 */ { "SYMBOLE MUSICAL REPRISE DU DÉBUT",NULL},
/* 1D108 */ { "SYMBOLE MUSICAL POINTS DE REPRISE",NULL},
/* 1D109 */ { "SYMBOLE MUSICAL DAL SEGNO",NULL},
/* 1D10A */ { "SYMBOLE MUSICAL DA CAPO",NULL},
/* 1D10B */ { "SYMBOLE MUSICAL RENVOI","	= segno"},
/* 1D10C */ { "SYMBOLE MUSICAL CODA",NULL},
/* 1D10D */ { "SYMBOLE MUSICAL FIGURE RÉPÉTÉE-1",NULL},
/* 1D10E */ { "SYMBOLE MUSICAL FIGURE RÉPÉTÉE-2",NULL},
/* 1D10F */ { "SYMBOLE MUSICAL FIGURE RÉPÉTÉE-3",NULL},
/* 1D110 */ { "SYMBOLE MUSICAL POINT D'ORGUE",NULL},
/* 1D111 */ { "SYMBOLE MUSICAL POINT D'ORGUE SOUSCRIT",NULL},
/* 1D112 */ { "SYMBOLE MUSICAL RESPIRATION",NULL},
/* 1D113 */ { "SYMBOLE MUSICAL CÉSURE",NULL},
/* 1D114 */ { "SYMBOLE MUSICAL ACCOLADE",NULL},
/* 1D115 */ { "SYMBOLE MUSICAL ACCOLADE DROITE","	= accolade de partition"},
/* 1D116 */ { "SYMBOLE MUSICAL PORTÉE D'UNE LIGNE",NULL},
/* 1D117 */ { "SYMBOLE MUSICAL PORTÉE DE DEUX LIGNES",NULL},
/* 1D118 */ { "SYMBOLE MUSICAL PORTÉE DE TROIS LIGNES",NULL},
/* 1D119 */ { "SYMBOLE MUSICAL PORTÉE DE QUATRE LIGNES",NULL},
/* 1D11A */ { "SYMBOLE MUSICAL PORTÉE DE CINQ LIGNES",NULL},
/* 1D11B */ { "SYMBOLE MUSICAL PORTÉE DE SIX LIGNES",NULL},
/* 1D11C */ { "SYMBOLE MUSICAL TOUCHE À SIX CORDES",NULL},
/* 1D11D */ { "SYMBOLE MUSICAL TOUCHE À QUATRE CORDES",NULL},
/* 1D11E */ { "SYMBOLE MUSICAL CLÉ DE SOL","	x (partition musicale - 1F3BC)"},
/* 1D11F */ { "SYMBOLE MUSICAL CLÉ DE SOL OCTAVIANTE SUPÉRIEURE",NULL},
/* 1D120 */ { "SYMBOLE MUSICAL CLÉ DE SOL OCTAVIANTE INFÉRIEURE",NULL},
/* 1D121 */ { "SYMBOLE MUSICAL CLÉ D'UT",NULL},
/* 1D122 */ { "SYMBOLE MUSICAL CLÉ DE FA",NULL},
/* 1D123 */ { "SYMBOLE MUSICAL CLÉ DE FA OCTAVIANTE SUPÉRIEURE",NULL},
/* 1D124 */ { "SYMBOLE MUSICAL CLÉ DE FA OCTAVIANTE INFÉRIEURE",NULL},
/* 1D125 */ { "SYMBOLE MUSICAL CLÉ DE PERCUSSION-1",NULL},
/* 1D126 */ { "SYMBOLE MUSICAL CLÉ DE PERCUSSION-2",NULL},
/* 1D127 */ { NULL,NULL},
/* 1D128 */ { NULL,NULL},
/* 1D129 */ { "SYMBOLE MUSICAL BÂTON DE MESURE","	* sert à représenter une pause sur plusieurs mesures\n"
	"	x (symbole musical bâton de pause - 1D13A)"},
/* 1D12A */ { "SYMBOLE MUSICAL DOUBLE DIÈSE",NULL},
/* 1D12B */ { "SYMBOLE MUSICAL DOUBLE BÉMOL",NULL},
/* 1D12C */ { "SYMBOLE MUSICAL BÉMOL ÉLEVÉ",NULL},
/* 1D12D */ { "SYMBOLE MUSICAL BÉMOL ABAISSÉ",NULL},
/* 1D12E */ { "SYMBOLE MUSICAL BÉCARRE ÉLEVÉ",NULL},
/* 1D12F */ { "SYMBOLE MUSICAL BÉCARRE ABAISSÉ",NULL},
/* 1D130 */ { "SYMBOLE MUSICAL DIÈSE ÉLEVÉ",NULL},
/* 1D131 */ { "SYMBOLE MUSICAL DIÈSE ABAISSÉ",NULL},
/* 1D132 */ { "SYMBOLE MUSICAL QUART DE DIÈSE ÉLEVÉ",NULL},
/* 1D133 */ { "SYMBOLE MUSICAL QUART DE BÉMOL ABAISSÉ",NULL},
/* 1D134 */ { "SYMBOLE MUSICAL MESURE À QUATRE-QUATRE",NULL},
/* 1D135 */ { "SYMBOLE MUSICAL MESURE À DEUX-DEUX",NULL},
/* 1D136 */ { "SYMBOLE MUSICAL OTTAVA ALTA",NULL},
/* 1D137 */ { "SYMBOLE MUSICAL OTTAVA BASSA",NULL},
/* 1D138 */ { "SYMBOLE MUSICAL QUINDICESIMA ALTA",NULL},
/* 1D139 */ { "SYMBOLE MUSICAL QUINDICESIMA BASSA",NULL},
/* 1D13A */ { "SYMBOLE MUSICAL BÂTON DE PAUSE","	* surmonté d'un nombre, le bâton de pause indique un nombre égal de mesures en silence consécutives à compter\n"
	"	x (symbole musical bâton de mesure - 1D129)"},
/* 1D13B */ { "SYMBOLE MUSICAL PAUSE",NULL},
/* 1D13C */ { "SYMBOLE MUSICAL DEMI-PAUSE",NULL},
/* 1D13D */ { "SYMBOLE MUSICAL SOUPIR",NULL},
/* 1D13E */ { "SYMBOLE MUSICAL DEMI-SOUPIR",NULL},
/* 1D13F */ { "SYMBOLE MUSICAL QUART DE SOUPIR",NULL},
/* 1D140 */ { "SYMBOLE MUSICAL HUITIÈME DE SOUPIR",NULL},
/* 1D141 */ { "SYMBOLE MUSICAL SEIZIÈME DE SOUPIR",NULL},
/* 1D142 */ { "SYMBOLE MUSICAL TRENTE-DEUXIÈME DE SOUPIR",NULL},
/* 1D143 */ { "SYMBOLE MUSICAL TÊTE DE NOTE X",NULL},
/* 1D144 */ { "SYMBOLE MUSICAL TÊTE DE NOTE PLUS",NULL},
/* 1D145 */ { "SYMBOLE MUSICAL TÊTE DE NOTE X CERCLÉ",NULL},
/* 1D146 */ { "SYMBOLE MUSICAL TÊTE DE NOTE CARRÉE BLANCHE",NULL},
/* 1D147 */ { "SYMBOLE MUSICAL TÊTE DE NOTE CARRÉE NOIRE",NULL},
/* 1D148 */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE BLANC MONTANT",NULL},
/* 1D149 */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE NOIR MONTANT",NULL},
/* 1D14A */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE BLANC COUCHÉ À GAUCHE",NULL},
/* 1D14B */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE NOIR COUCHÉ À GAUCHE",NULL},
/* 1D14C */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE BLANC COUCHÉ À DROITE",NULL},
/* 1D14D */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE NOIR COUCHÉ À DROITE",NULL},
/* 1D14E */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE BLANC DESCENDANT",NULL},
/* 1D14F */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE NOIR DESCENDANT",NULL},
/* 1D150 */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE BLANC MONTANT PAR LA DROITE",NULL},
/* 1D151 */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE NOIR MONTANT PAR LA DROITE",NULL},
/* 1D152 */ { "SYMBOLE MUSICAL TÊTE DE NOTE LUNULE BLANCHE",NULL},
/* 1D153 */ { "SYMBOLE MUSICAL TÊTE DE NOTE LUNULE NOIRE",NULL},
/* 1D154 */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE BLANC ARRONDI DESCENDANT",NULL},
/* 1D155 */ { "SYMBOLE MUSICAL TÊTE DE NOTE TRIANGLE NOIR ARRONDI DESCENDANT",NULL},
/* 1D156 */ { "SYMBOLE MUSICAL TÊTE DE NOTE PARENTHÈSES",NULL},
/* 1D157 */ { "SYMBOLE MUSICAL TÊTE DE NOTE ÉVIDÉE",NULL},
/* 1D158 */ { "SYMBOLE MUSICAL TÊTE DE NOTE NOIRE",NULL},
/* 1D159 */ { "SYMBOLE MUSICAL TÊTE DE NOTE NULLE",NULL},
/* 1D15A */ { "SYMBOLE MUSICAL TÊTE DE NOTE BLOC BLANC",NULL},
/* 1D15B */ { "SYMBOLE MUSICAL TÊTE DE NOTE BLOC NOIR",NULL},
/* 1D15C */ { "SYMBOLE MUSICAL CARRÉE","	= double ronde"},
/* 1D15D */ { "SYMBOLE MUSICAL RONDE",NULL},
/* 1D15E */ { "SYMBOLE MUSICAL BLANCHE","	: 1D157 1D165"},
/* 1D15F */ { "SYMBOLE MUSICAL NOIRE","	x (note noire - 2669)\n"
	"	: 1D158 1D165"},
/* 1D160 */ { "SYMBOLE MUSICAL CROCHE","	x (note croche - 266A)\n"
	"	: 1D15F 1D16E"},
/* 1D161 */ { "SYMBOLE MUSICAL DOUBLE CROCHE","	: 1D15F 1D16F"},
/* 1D162 */ { "SYMBOLE MUSICAL TRIPLE CROCHE","	: 1D15F 1D170"},
/* 1D163 */ { "SYMBOLE MUSICAL QUADRUPLE CROCHE","	: 1D15F 1D171"},
/* 1D164 */ { "SYMBOLE MUSICAL QUINTUPLE CROCHE","	: 1D15F 1D172"},
/* 1D165 */ { "DIACRITIQUE MUSICAL HAMPE",NULL},
/* 1D166 */ { "DIACRITIQUE MUSICAL HAMPE SPRECHGESANG","	= hampe chant parlé"},
/* 1D167 */ { "DIACRITIQUE MUSICAL TRÉMOLO-1",NULL},
/* 1D168 */ { "DIACRITIQUE MUSICAL TRÉMOLO-2",NULL},
/* 1D169 */ { "DIACRITIQUE MUSICAL TRÉMOLO-3",NULL},
/* 1D16A */ { "SYMBOLE MUSICAL TRÉMOLO-TRILLE-1",NULL},
/* 1D16B */ { "SYMBOLE MUSICAL TRÉMOLO-TRILLE-2",NULL},
/* 1D16C */ { "SYMBOLE MUSICAL TRÉMOLO-TRILLE-3",NULL},
/* 1D16D */ { "DIACRITIQUE MUSICAL POINT D'AUGMENTATION",NULL},
/* 1D16E */ { "DIACRITIQUE MUSICAL CROCHET-1",NULL},
/* 1D16F */ { "DIACRITIQUE MUSICAL CROCHET-2",NULL},
/* 1D170 */ { "DIACRITIQUE MUSICAL CROCHET-3",NULL},
/* 1D171 */ { "DIACRITIQUE MUSICAL CROCHET-4",NULL},
/* 1D172 */ { "DIACRITIQUE MUSICAL CROCHET-5",NULL},
/* 1D173 */ { "SYMBOLE MUSICAL DÉBUT DE RAME","	= début de poutre, début de barre de valeur"},
/* 1D174 */ { "SYMBOLE MUSICAL FIN DE RAME",NULL},
/* 1D175 */ { "SYMBOLE MUSICAL DÉBUT DE TENUE","	= début de liaison de prolongation"},
/* 1D176 */ { "SYMBOLE MUSICAL FIN DE TENUE",NULL},
/* 1D177 */ { "SYMBOLE MUSICAL DÉBUT DE COULÉ","	= début de liaison d'expression"},
/* 1D178 */ { "SYMBOLE MUSICAL FIN DE COULÉ",NULL},
/* 1D179 */ { "SYMBOLE MUSICAL DÉBUT DE PHRASÉ",NULL},
/* 1D17A */ { "SYMBOLE MUSICAL FIN DE PHRASÉ",NULL},
/* 1D17B */ { "DIACRITIQUE MUSICAL ACCENT",NULL},
/* 1D17C */ { "DIACRITIQUE MUSICAL DÉTACHÉ","	= staccato"},
/* 1D17D */ { "DIACRITIQUE MUSICAL APPUYÉ","	= accent agogique, tenuto"},
/* 1D17E */ { "DIACRITIQUE MUSICAL TRÈS DÉTACHÉ","	= staccatissimo"},
/* 1D17F */ { "DIACRITIQUE MUSICAL MARQUÉ","	= marcato"},
/* 1D180 */ { "DIACRITIQUE MUSICAL MARQUÉ-DÉTACHÉ","	= marcato-staccato"},
/* 1D181 */ { "DIACRITIQUE MUSICAL ACCENT-DÉTACHÉ",NULL},
/* 1D182 */ { "DIACRITIQUE MUSICAL LOURÉ",NULL},
/* 1D183 */ { "SYMBOLE MUSICAL ARPÉGÉ MONTANT","	= arpègement monté"},
/* 1D184 */ { "SYMBOLE MUSICAL ARPÉGÉ DESCENDANT","	= arpègement descendu"},
/* 1D185 */ { "DIACRITIQUE MUSICAL DOINK","	* utilisé dans les partitions de jazz"},
/* 1D186 */ { "DIACRITIQUE MUSICAL RIP","	* utilisé dans les partitions de jazz"},
/* 1D187 */ { "DIACRITIQUE MUSICAL FLIP","	* utilisé dans les partitions de jazz"},
/* 1D188 */ { "DIACRITIQUE MUSICAL SMEAR","	* utilisé dans les partitions de jazz"},
/* 1D189 */ { "DIACRITIQUE MUSICAL BEND","	* utilisé dans les partitions de jazz"},
/* 1D18A */ { "DIACRITIQUE MUSICAL ARTICULATION DOUBLE","	= double coup de langue"},
/* 1D18B */ { "DIACRITIQUE MUSICAL ARTICULATION TRIPLE","	= triple coup de langue"},
/* 1D18C */ { "SYMBOLE MUSICAL RINFORZANDO",NULL},
/* 1D18D */ { "SYMBOLE MUSICAL SUBITO",NULL},
/* 1D18E */ { "SYMBOLE MUSICAL Z",NULL},
/* 1D18F */ { "SYMBOLE MUSICAL PIANO",NULL},
/* 1D190 */ { "SYMBOLE MUSICAL MEZZO",NULL},
/* 1D191 */ { "SYMBOLE MUSICAL FORTE",NULL},
/* 1D192 */ { "SYMBOLE MUSICAL CRESCENDO",NULL},
/* 1D193 */ { "SYMBOLE MUSICAL DECRESCENDO",NULL},
/* 1D194 */ { "SYMBOLE MUSICAL APPOGGIATURE BRÈVE","	= petite note barrée, agrément barré, port de voix bref"},
/* 1D195 */ { "SYMBOLE MUSICAL APPOGGIATURE LONGUE","	= petite note, agrément, port de voix"},
/* 1D196 */ { "SYMBOLE MUSICAL TRILLE",NULL},
/* 1D197 */ { "SYMBOLE MUSICAL GRUPPETTO","	= groupe, doublé, double-cadence, tour de gosier"},
/* 1D198 */ { "SYMBOLE MUSICAL GRUPPETTO RENVERSÉ",NULL},
/* 1D199 */ { "SYMBOLE MUSICAL GRUPPETTO BARRÉ",NULL},
/* 1D19A */ { "SYMBOLE MUSICAL GRUPPETTO ÉRIGÉ",NULL},
/* 1D19B */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 1",NULL},
/* 1D19C */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 2",NULL},
/* 1D19D */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 3",NULL},
/* 1D19E */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 4",NULL},
/* 1D19F */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 5",NULL},
/* 1D1A0 */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 6",NULL},
/* 1D1A1 */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 7",NULL},
/* 1D1A2 */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 8",NULL},
/* 1D1A3 */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 9",NULL},
/* 1D1A4 */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 10",NULL},
/* 1D1A5 */ { "SYMBOLE MUSICAL TRAIT D'ORNEMENT NUMÉRO 11",NULL},
/* 1D1A6 */ { "SYMBOLE MUSICAL HAUPTSTIMME","	= partie principale"},
/* 1D1A7 */ { "SYMBOLE MUSICAL NEBENSTIMME","	= partie secondaire"},
/* 1D1A8 */ { "SYMBOLE MUSICAL FIN DE STIMME","	= fin de démarcation"},
/* 1D1A9 */ { "SYMBOLE MUSICAL DEGRÉ BARRÉ",NULL},
/* 1D1AA */ { "DIACRITIQUE MUSICAL ARCHET TIRÉ",NULL},
/* 1D1AB */ { "DIACRITIQUE MUSICAL ARCHET POUSSÉ",NULL},
/* 1D1AC */ { "DIACRITIQUE MUSICAL DIPHONIQUE","	= harmonique"},
/* 1D1AD */ { "DIACRITIQUE MUSICAL PIZZICATO BARTÓK",NULL},
/* 1D1AE */ { "SYMBOLE MUSICAL PÉDALE APPUYÉE",NULL},
/* 1D1AF */ { "SYMBOLE MUSICAL PÉDALE LEVÉE",NULL},
/* 1D1B0 */ { "SYMBOLE MUSICAL DEMI-PÉDALE",NULL},
/* 1D1B1 */ { "SYMBOLE MUSICAL GLISSANDO ASCENDANT",NULL},
/* 1D1B2 */ { "SYMBOLE MUSICAL GLISSANDO DESCENDANT",NULL},
/* 1D1B3 */ { "SYMBOLE MUSICAL AVEC LES ONGLES",NULL},
/* 1D1B4 */ { "SYMBOLE MUSICAL ÉTOUFFER",NULL},
/* 1D1B5 */ { "SYMBOLE MUSICAL TOUT ÉTOUFFER",NULL},
/* 1D1B6 */ { "SYMBOLE MUSICAL MAXIME",NULL},
/* 1D1B7 */ { "SYMBOLE MUSICAL LONGUE","	= virga"},
/* 1D1B8 */ { "SYMBOLE MUSICAL BRÈVE","	= punctum carré"},
/* 1D1B9 */ { "SYMBOLE MUSICAL SEMI-BRÈVE",NULL},
/* 1D1BA */ { "SYMBOLE MUSICAL SEMI-BRÈVE NOIRE","	= punctum losangé"},
/* 1D1BB */ { "SYMBOLE MUSICAL MINIME","	: 1D1B9 1D165"},
/* 1D1BC */ { "SYMBOLE MUSICAL SEMI-MINIME NOIRE","	= minime (avant 1450)\n"
	"	: 1D1BA 1D165"},
/* 1D1BD */ { "SYMBOLE MUSICAL SEMI-MINIME","	: 1D1BB 1D16E"},
/* 1D1BE */ { "SYMBOLE MUSICAL FUSE","	= semi-minime (avant 1450)\n"
	"	: 1D1BC 1D16E"},
/* 1D1BF */ { "SYMBOLE MUSICAL FUSE BLANCHE","	: 1D1BB 1D16F"},
/* 1D1C0 */ { "SYMBOLE MUSICAL SEMI-FUSE","	: 1D1BC 1D16F"},
/* 1D1C1 */ { "SYMBOLE MUSICAL SILENCE DE LONGUE PARFAITE",NULL},
/* 1D1C2 */ { "SYMBOLE MUSICAL SILENCE DE LONGUE IMPARFAITE",NULL},
/* 1D1C3 */ { "SYMBOLE MUSICAL SILENCE DE BRÈVE",NULL},
/* 1D1C4 */ { "SYMBOLE MUSICAL SILENCE DE SEMI-BRÈVE",NULL},
/* 1D1C5 */ { "SYMBOLE MUSICAL SILENCE DE MINIME",NULL},
/* 1D1C6 */ { "SYMBOLE MUSICAL SILENCE DE SEMI-MINIME",NULL},
/* 1D1C7 */ { "SYMBOLE MUSICAL TEMPS PARFAIT PROLATION MAJEURE","	= tempus perfectum cum prolatione perfecta"},
/* 1D1C8 */ { "SYMBOLE MUSICAL TEMPS PARFAIT PROLATION MINEURE","	= tempus perfectum cum prolatione imperfecta"},
/* 1D1C9 */ { "SYMBOLE MUSICAL TEMPS PARFAIT PROLATION MAJEURE DIMINUTION-1","	= tempus perfectum cum prolatione perfecta diminution-1"},
/* 1D1CA */ { "SYMBOLE MUSICAL TEMPS IMPARFAIT PROLATION MAJEURE","	= tempus imperfectum cum prolatione perfecta"},
/* 1D1CB */ { "SYMBOLE MUSICAL TEMPS IMPARFAIT PROLATION MINEURE","	= tempus imperfectum cum prolatione imperfecta"},
/* 1D1CC */ { "SYMBOLE MUSICAL TEMPS IMPARFAIT PROLATION MINEURE DIMINUTION-1","	= tempus imperfectum cum prolatione imperfecta diminution-1"},
/* 1D1CD */ { "SYMBOLE MUSICAL TEMPS IMPARFAIT PROLATION MINEURE DIMINUTION-2","	= tempus imperfectum cum prolatione imperfecta diminution-2"},
/* 1D1CE */ { "SYMBOLE MUSICAL TEMPS IMPARFAIT PROLATION MINEURE DIMINUTION-3","	= tempus imperfectum cum prolatione imperfecta diminution-3"},
/* 1D1CF */ { "SYMBOLE MUSICAL CROIX",NULL},
/* 1D1D0 */ { "SYMBOLE MUSICAL GRÉGORIEN CLÉ DE DO",NULL},
/* 1D1D1 */ { "SYMBOLE MUSICAL GRÉGORIEN CLÉ DE FA",NULL},
/* 1D1D2 */ { "SYMBOLE MUSICAL B CARRÉ",NULL},
/* 1D1D3 */ { "SYMBOLE MUSICAL VIRGA",NULL},
/* 1D1D4 */ { "SYMBOLE MUSICAL PODATUS","	= pes"},
/* 1D1D5 */ { "SYMBOLE MUSICAL CLIVIS",NULL},
/* 1D1D6 */ { "SYMBOLE MUSICAL SCANDICUS",NULL},
/* 1D1D7 */ { "SYMBOLE MUSICAL CLIMACUS","	= subpunctus"},
/* 1D1D8 */ { "SYMBOLE MUSICAL TORCULUS","	= pes flexus"},
/* 1D1D9 */ { "SYMBOLE MUSICAL PORRECTUS","	= flexus resupinus"},
/* 1D1DA */ { "SYMBOLE MUSICAL PORRECTUS FLEXUS",NULL},
/* 1D1DB */ { "SYMBOLE MUSICAL SCANDICUS FLEXUS",NULL},
/* 1D1DC */ { "SYMBOLE MUSICAL TORCULUS RESUPINUS",NULL},
/* 1D1DD */ { "SYMBOLE MUSICAL PES SUBPUNCTIS",NULL},
/* 1D1DE */ { "SYMBOLE MUSICAL KIÉVIEN CLÉ D'UT","	* clé de Tsefaut (ut ou fa)"},
/* 1D1DF */ { "SYMBOLE MUSICAL KIÉVIEN FIN DE MORCEAU",NULL},
/* 1D1E0 */ { "SYMBOLE MUSICAL KIÉVIEN NOTE FINALE","	* la note nominale se trouve entre les deux rectangles"},
/* 1D1E1 */ { "SYMBOLE MUSICAL KIÉVIEN SIGNE DE RÉCITATIF","	* la note nominale se trouve entre les deux rectangles"},
/* 1D1E2 */ { "SYMBOLE MUSICAL KIÉVIEN RONDE","	* la note nominale se trouve entre les deux losanges"},
/* 1D1E3 */ { "SYMBOLE MUSICAL KIÉVIEN BLANCHE",NULL},
/* 1D1E4 */ { "SYMBOLE MUSICAL KIÉVIEN NOIRE HAMPE EN BAS",NULL},
/* 1D1E5 */ { "SYMBOLE MUSICAL KIÉVIEN NOIRE HAMPE EN HAUT",NULL},
/* 1D1E6 */ { "SYMBOLE MUSICAL KIÉVIEN CROCHE HAMPE EN BAS","	* la note nominale se trouve sur le losange du haut"},
/* 1D1E7 */ { "SYMBOLE MUSICAL KIÉVIEN CROCHE HAMPE EN HAUT",NULL},
/* 1D1E8 */ { "SYMBOLE MUSICAL KIÉVIEN BÉMOL",NULL},
/* 1D1E9 */ { "SYMBOLE MUSICAL SORI",NULL},
/* 1D1EA */ { "SYMBOLE MUSICAL KORON",NULL},
/* 1D1EB */ { NULL,NULL},
/* 1D1EC */ { NULL,NULL},
/* 1D1ED */ { NULL,NULL},
/* 1D1EE */ { NULL,NULL},
/* 1D1EF */ { NULL,NULL},
/* 1D1F0 */ { NULL,NULL},
/* 1D1F1 */ { NULL,NULL},
/* 1D1F2 */ { NULL,NULL},
/* 1D1F3 */ { NULL,NULL},
/* 1D1F4 */ { NULL,NULL},
/* 1D1F5 */ { NULL,NULL},
/* 1D1F6 */ { NULL,NULL},
/* 1D1F7 */ { NULL,NULL},
/* 1D1F8 */ { NULL,NULL},
/* 1D1F9 */ { NULL,NULL},
/* 1D1FA */ { NULL,NULL},
/* 1D1FB */ { NULL,NULL},
/* 1D1FC */ { NULL,NULL},
/* 1D1FD */ { NULL,NULL},
/* 1D1FE */ { NULL,NULL},
/* 1D1FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D2[] = {
/* 1D200 */ { "SYMBOLE NOTATION GRECQUE VOCALE 1","	* mi1 vocal"},
/* 1D201 */ { "SYMBOLE NOTATION GRECQUE VOCALE 2","	* premier dièse du mi1 vocal"},
/* 1D202 */ { "SYMBOLE NOTATION GRECQUE VOCALE 3","	= symbole notation grecque instrumentale 3\n"
	"	* second dièse du mi1 vocal ou instrumental"},
/* 1D203 */ { "SYMBOLE NOTATION GRECQUE VOCALE 4","	* fa1 vocal"},
/* 1D204 */ { "SYMBOLE NOTATION GRECQUE VOCALE 5","	* premier dièse du fa1 vocal"},
/* 1D205 */ { "SYMBOLE NOTATION GRECQUE VOCALE 6","	= symbole notation grecque instrumentale 21\n"
	"	* second dièse du fa1 vocal\n"
	"	* second dièse du ré2 instrumental"},
/* 1D206 */ { "SYMBOLE NOTATION GRECQUE VOCALE 7","	= symbole notation grecque instrumentale 9\n"
	"	* sol1 vocal\n"
	"	* deuxième dièse du sol1 instrumental"},
/* 1D207 */ { "SYMBOLE NOTATION GRECQUE VOCALE 8","	* premier dièse du sol1 vocal"},
/* 1D208 */ { "SYMBOLE NOTATION GRECQUE VOCALE 9","	= symbole notation grecque instrumentale 44\n"
	"	* second dièse du sol1 vocal\n"
	"	* premier dièse du mi3 instrumental"},
/* 1D209 */ { "SYMBOLE NOTATION GRECQUE VOCALE 10","	* la1 vocal\n"
	"	* il s'agit d'une modification de 039F et non d'un 03D8"},
/* 1D20A */ { "SYMBOLE NOTATION GRECQUE VOCALE 11","	* premier dièse du la1 vocal"},
/* 1D20B */ { "SYMBOLE NOTATION GRECQUE VOCALE 12","	* second dièse du la1 vocal"},
/* 1D20C */ { "SYMBOLE NOTATION GRECQUE VOCALE 13","	* si1 vocal"},
/* 1D20D */ { "SYMBOLE NOTATION GRECQUE VOCALE 14","	= symbole notation grecque instrumentale 41\n"
	"	* premier dièse du si1 vocal\n"
	"	* premier dièse du ré3 instrumental\n"
	"	x (lettre majuscule latine v - 0056)"},
/* 1D20E */ { "SYMBOLE NOTATION GRECQUE VOCALE 15","	= symbole notation grecque instrumentale 35\n"
	"	* second dièse du si1 vocal\n"
	"	* premier dièse du si2 instrumental"},
/* 1D20F */ { "SYMBOLE NOTATION GRECQUE VOCALE 16","	* do2 vocal c\n"
	"	* contrairement à 1D23B, ce caractère possède une variante de glyphe qui ressemble à une ligne horizontale"},
/* 1D210 */ { "SYMBOLE NOTATION GRECQUE VOCALE 17","	* premier dièse du do2 vocal"},
/* 1D211 */ { "SYMBOLE NOTATION GRECQUE VOCALE 18","	= symbole notation grecque instrumentale 15\n"
	"	* second dièse du do2 vocal\n"
	"	* second dièse du si1 instrumental"},
/* 1D212 */ { "SYMBOLE NOTATION GRECQUE VOCALE 19","	* ré2 vocal"},
/* 1D213 */ { "SYMBOLE NOTATION GRECQUE VOCALE 20","	= symbole notation grecque instrumentale 28\n"
	"	* premier dièse du ré1 vocal\n"
	"	* sol2 instrumental\n"
	"	* il s'agit d'une modification de 0395 et non d'un 0046"},
/* 1D214 */ { "SYMBOLE NOTATION GRECQUE VOCALE 21","	* second dièse du ré2 vocal"},
/* 1D215 */ { "SYMBOLE NOTATION GRECQUE VOCALE 22","	* mi2 vocal"},
/* 1D216 */ { "SYMBOLE NOTATION GRECQUE VOCALE 23","	* premier dièse du mi2 vocal\n"
	"	* il s'agit d'une modification de 0392, donc pas d'un 0052"},
/* 1D217 */ { "SYMBOLE NOTATION GRECQUE VOCALE 24","	* second dièse du mi2 vocal"},
/* 1D218 */ { "SYMBOLE NOTATION GRECQUE VOCALE 50","	* premier dièse du sol3 vocal"},
/* 1D219 */ { "SYMBOLE NOTATION GRECQUE VOCALE 51","	* second dièse du sol3 vocal"},
/* 1D21A */ { "SYMBOLE NOTATION GRECQUE VOCALE 52","	* la3 vocal"},
/* 1D21B */ { "SYMBOLE NOTATION GRECQUE VOCALE 53","	* premier dièse du la3 vocal"},
/* 1D21C */ { "SYMBOLE NOTATION GRECQUE VOCALE 54","	= symbole notation grecque instrumentale 20\n"
	"	* second dièse du la3 vocal\n"
	"	* premier dièse du ré2 instrumental"},
/* 1D21D */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 1","	* mi1 instrumental"},
/* 1D21E */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 2","	* premier dièse du mi1 instrumental"},
/* 1D21F */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 4","	* fa1 instrumental"},
/* 1D220 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 5","	* premier dièse du fa1 instrumental"},
/* 1D221 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 7","	* sol1 instrumental"},
/* 1D222 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 8","	* premier dièse sol1 instrumental"},
/* 1D223 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 11","	* premier dièse du la1 instrumental"},
/* 1D224 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 12","	* second dièse du la1 instrumental"},
/* 1D225 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 13","	* si1 instrumental"},
/* 1D226 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 14","	* premier dièse du si1 instrumental"},
/* 1D227 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 17","	* premier dièse du do2 instrumental"},
/* 1D228 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 18","	* second dièse du do2 instrumental"},
/* 1D229 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 19","	* ré2 instrumental"},
/* 1D22A */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 23","	* premier dièse du mi2 instrumental"},
/* 1D22B */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 24","	* second dièse du mi2 instrumental"},
/* 1D22C */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 25","	* fa2 instrumental"},
/* 1D22D */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 26","	* premier dièse du fa2 instrumental"},
/* 1D22E */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 27","	* second dièse du fa2 instrumental"},
/* 1D22F */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 29","	* premier dièse du sol2 instrumental"},
/* 1D230 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 30","	* second dièse du sol2 instrumental"},
/* 1D231 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 32","	* premier dièse du la2 instrumental"},
/* 1D232 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 36","	* second dièse du si2 instrumental"},
/* 1D233 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 37","	* do3 instrumental"},
/* 1D234 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 38","	* premier dièse du do3 instrumental"},
/* 1D235 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 39","	* second dièse du do3 instrumental"},
/* 1D236 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 40","	* ré3 instrumental"},
/* 1D237 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 42","	* second dièse du ré3 instrumental"},
/* 1D238 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 43","	* mi3 instrumental"},
/* 1D239 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 45","	* second dièse du mi3 instrumental"},
/* 1D23A */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 47","	* premier dièse du fa3 instrumental\n"
	"	* similaire mais pas identique à 002F"},
/* 1D23B */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 48","	* second dièse du fa3 instrumental\n"
	"	* similaire mais pas identique à 005C"},
/* 1D23C */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 49","	* sol3 instrumental"},
/* 1D23D */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 50","	* premier dièse du sol3 instrumental"},
/* 1D23E */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 51","	* second dièse di sol3 instrumental"},
/* 1D23F */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 52","	* la3 instrumental"},
/* 1D240 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 53","	* premier dièse du la3 instrumental"},
/* 1D241 */ { "SYMBOLE NOTATION GRECQUE INSTRUMENTALE 54","	* second dièse du la3 instrumental"},
/* 1D242 */ { "DIACRITIQUE MUSICAL GREC TRISÈME","	x (trisème longue-brève métrique - 23D7)"},
/* 1D243 */ { "DIACRITIQUE MUSICAL GREC TÉTRASÈME","	x (tétrasème métrique - 23D8)"},
/* 1D244 */ { "DIACRITIQUE MUSICAL GREC PENTASÈME","	x (pentasème métrique - 23D9)"},
/* 1D245 */ { "LEIMMA MUSICAL GREC",NULL},
/* 1D246 */ { NULL,NULL},
/* 1D247 */ { NULL,NULL},
/* 1D248 */ { NULL,NULL},
/* 1D249 */ { NULL,NULL},
/* 1D24A */ { NULL,NULL},
/* 1D24B */ { NULL,NULL},
/* 1D24C */ { NULL,NULL},
/* 1D24D */ { NULL,NULL},
/* 1D24E */ { NULL,NULL},
/* 1D24F */ { NULL,NULL},
/* 1D250 */ { NULL,NULL},
/* 1D251 */ { NULL,NULL},
/* 1D252 */ { NULL,NULL},
/* 1D253 */ { NULL,NULL},
/* 1D254 */ { NULL,NULL},
/* 1D255 */ { NULL,NULL},
/* 1D256 */ { NULL,NULL},
/* 1D257 */ { NULL,NULL},
/* 1D258 */ { NULL,NULL},
/* 1D259 */ { NULL,NULL},
/* 1D25A */ { NULL,NULL},
/* 1D25B */ { NULL,NULL},
/* 1D25C */ { NULL,NULL},
/* 1D25D */ { NULL,NULL},
/* 1D25E */ { NULL,NULL},
/* 1D25F */ { NULL,NULL},
/* 1D260 */ { NULL,NULL},
/* 1D261 */ { NULL,NULL},
/* 1D262 */ { NULL,NULL},
/* 1D263 */ { NULL,NULL},
/* 1D264 */ { NULL,NULL},
/* 1D265 */ { NULL,NULL},
/* 1D266 */ { NULL,NULL},
/* 1D267 */ { NULL,NULL},
/* 1D268 */ { NULL,NULL},
/* 1D269 */ { NULL,NULL},
/* 1D26A */ { NULL,NULL},
/* 1D26B */ { NULL,NULL},
/* 1D26C */ { NULL,NULL},
/* 1D26D */ { NULL,NULL},
/* 1D26E */ { NULL,NULL},
/* 1D26F */ { NULL,NULL},
/* 1D270 */ { NULL,NULL},
/* 1D271 */ { NULL,NULL},
/* 1D272 */ { NULL,NULL},
/* 1D273 */ { NULL,NULL},
/* 1D274 */ { NULL,NULL},
/* 1D275 */ { NULL,NULL},
/* 1D276 */ { NULL,NULL},
/* 1D277 */ { NULL,NULL},
/* 1D278 */ { NULL,NULL},
/* 1D279 */ { NULL,NULL},
/* 1D27A */ { NULL,NULL},
/* 1D27B */ { NULL,NULL},
/* 1D27C */ { NULL,NULL},
/* 1D27D */ { NULL,NULL},
/* 1D27E */ { NULL,NULL},
/* 1D27F */ { NULL,NULL},
/* 1D280 */ { NULL,NULL},
/* 1D281 */ { NULL,NULL},
/* 1D282 */ { NULL,NULL},
/* 1D283 */ { NULL,NULL},
/* 1D284 */ { NULL,NULL},
/* 1D285 */ { NULL,NULL},
/* 1D286 */ { NULL,NULL},
/* 1D287 */ { NULL,NULL},
/* 1D288 */ { NULL,NULL},
/* 1D289 */ { NULL,NULL},
/* 1D28A */ { NULL,NULL},
/* 1D28B */ { NULL,NULL},
/* 1D28C */ { NULL,NULL},
/* 1D28D */ { NULL,NULL},
/* 1D28E */ { NULL,NULL},
/* 1D28F */ { NULL,NULL},
/* 1D290 */ { NULL,NULL},
/* 1D291 */ { NULL,NULL},
/* 1D292 */ { NULL,NULL},
/* 1D293 */ { NULL,NULL},
/* 1D294 */ { NULL,NULL},
/* 1D295 */ { NULL,NULL},
/* 1D296 */ { NULL,NULL},
/* 1D297 */ { NULL,NULL},
/* 1D298 */ { NULL,NULL},
/* 1D299 */ { NULL,NULL},
/* 1D29A */ { NULL,NULL},
/* 1D29B */ { NULL,NULL},
/* 1D29C */ { NULL,NULL},
/* 1D29D */ { NULL,NULL},
/* 1D29E */ { NULL,NULL},
/* 1D29F */ { NULL,NULL},
/* 1D2A0 */ { NULL,NULL},
/* 1D2A1 */ { NULL,NULL},
/* 1D2A2 */ { NULL,NULL},
/* 1D2A3 */ { NULL,NULL},
/* 1D2A4 */ { NULL,NULL},
/* 1D2A5 */ { NULL,NULL},
/* 1D2A6 */ { NULL,NULL},
/* 1D2A7 */ { NULL,NULL},
/* 1D2A8 */ { NULL,NULL},
/* 1D2A9 */ { NULL,NULL},
/* 1D2AA */ { NULL,NULL},
/* 1D2AB */ { NULL,NULL},
/* 1D2AC */ { NULL,NULL},
/* 1D2AD */ { NULL,NULL},
/* 1D2AE */ { NULL,NULL},
/* 1D2AF */ { NULL,NULL},
/* 1D2B0 */ { NULL,NULL},
/* 1D2B1 */ { NULL,NULL},
/* 1D2B2 */ { NULL,NULL},
/* 1D2B3 */ { NULL,NULL},
/* 1D2B4 */ { NULL,NULL},
/* 1D2B5 */ { NULL,NULL},
/* 1D2B6 */ { NULL,NULL},
/* 1D2B7 */ { NULL,NULL},
/* 1D2B8 */ { NULL,NULL},
/* 1D2B9 */ { NULL,NULL},
/* 1D2BA */ { NULL,NULL},
/* 1D2BB */ { NULL,NULL},
/* 1D2BC */ { NULL,NULL},
/* 1D2BD */ { NULL,NULL},
/* 1D2BE */ { NULL,NULL},
/* 1D2BF */ { NULL,NULL},
/* 1D2C0 */ { "CHIFFRE DE KAKTOVIK ZÉRO",NULL},
/* 1D2C1 */ { "CHIFFRE DE KAKTOVIK UN",NULL},
/* 1D2C2 */ { "CHIFFRE DE KAKTOVIK DEUX",NULL},
/* 1D2C3 */ { "CHIFFRE DE KAKTOVIK TROIS",NULL},
/* 1D2C4 */ { "CHIFFRE DE KAKTOVIK QUATRE",NULL},
/* 1D2C5 */ { "CHIFFRE DE KAKTOVIK CINQ",NULL},
/* 1D2C6 */ { "CHIFFRE DE KAKTOVIK SIX",NULL},
/* 1D2C7 */ { "CHIFFRE DE KAKTOVIK SEPT",NULL},
/* 1D2C8 */ { "CHIFFRE DE KAKTOVIK HUIT",NULL},
/* 1D2C9 */ { "CHIFFRE DE KAKTOVIK NEUF",NULL},
/* 1D2CA */ { "CHIFFRE DE KAKTOVIK DIX",NULL},
/* 1D2CB */ { "CHIFFRE DE KAKTOVIK ONZE",NULL},
/* 1D2CC */ { "CHIFFRE DE KAKTOVIK DOUZE",NULL},
/* 1D2CD */ { "CHIFFRE DE KAKTOVIK TREIZE",NULL},
/* 1D2CE */ { "CHIFFRE DE KAKTOVIK QUATORZE",NULL},
/* 1D2CF */ { "CHIFFRE DE KAKTOVIK QUINZE",NULL},
/* 1D2D0 */ { "CHIFFRE DE KAKTOVIK SEIZE",NULL},
/* 1D2D1 */ { "CHIFFRE DE KAKTOVIK DIX-SEPT",NULL},
/* 1D2D2 */ { "CHIFFRE DE KAKTOVIK DIX-HUIT",NULL},
/* 1D2D3 */ { "CHIFFRE DE KAKTOVIK DIX-NEUF",NULL},
/* 1D2D4 */ { NULL,NULL},
/* 1D2D5 */ { NULL,NULL},
/* 1D2D6 */ { NULL,NULL},
/* 1D2D7 */ { NULL,NULL},
/* 1D2D8 */ { NULL,NULL},
/* 1D2D9 */ { NULL,NULL},
/* 1D2DA */ { NULL,NULL},
/* 1D2DB */ { NULL,NULL},
/* 1D2DC */ { NULL,NULL},
/* 1D2DD */ { NULL,NULL},
/* 1D2DE */ { NULL,NULL},
/* 1D2DF */ { NULL,NULL},
/* 1D2E0 */ { "CHIFFRE MAYA ZÉRO",NULL},
/* 1D2E1 */ { "CHIFFRE MAYA UN",NULL},
/* 1D2E2 */ { "CHIFFRE MAYA DEUX",NULL},
/* 1D2E3 */ { "CHIFFRE MAYA TROIS",NULL},
/* 1D2E4 */ { "CHIFFRE MAYA QUATRE",NULL},
/* 1D2E5 */ { "CHIFFRE MAYA CINQ",NULL},
/* 1D2E6 */ { "CHIFFRE MAYA SIX",NULL},
/* 1D2E7 */ { "CHIFFRE MAYA SEPT",NULL},
/* 1D2E8 */ { "CHIFFRE MAYA HUIT",NULL},
/* 1D2E9 */ { "CHIFFRE MAYA NEUF",NULL},
/* 1D2EA */ { "CHIFFRE MAYA DIX",NULL},
/* 1D2EB */ { "CHIFFRE MAYA ONZE",NULL},
/* 1D2EC */ { "CHIFFRE MAYA DOUZE",NULL},
/* 1D2ED */ { "CHIFFRE MAYA TREIZE",NULL},
/* 1D2EE */ { "CHIFFRE MAYA QUATORZE",NULL},
/* 1D2EF */ { "CHIFFRE MAYA QUINZE",NULL},
/* 1D2F0 */ { "CHIFFRE MAYA SEIZE",NULL},
/* 1D2F1 */ { "CHIFFRE MAYA DIX-SEPT",NULL},
/* 1D2F2 */ { "CHIFFRE MAYA DIX-HUIT",NULL},
/* 1D2F3 */ { "CHIFFRE MAYA DIX-NEUF",NULL},
/* 1D2F4 */ { NULL,NULL},
/* 1D2F5 */ { NULL,NULL},
/* 1D2F6 */ { NULL,NULL},
/* 1D2F7 */ { NULL,NULL},
/* 1D2F8 */ { NULL,NULL},
/* 1D2F9 */ { NULL,NULL},
/* 1D2FA */ { NULL,NULL},
/* 1D2FB */ { NULL,NULL},
/* 1D2FC */ { NULL,NULL},
/* 1D2FD */ { NULL,NULL},
/* 1D2FE */ { NULL,NULL},
/* 1D2FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D3[] = {
/* 1D300 */ { "MONOGRAMME DE L'HOMME","	= ren, jen\n"
	"	* le nom formel de ce caractère en anglais est erroné\n"
	"	x (monogramme du yang - 268A)\n"
	"	x (monogramme du yin - 268B)"},
/* 1D301 */ { "DIGRAMME DE L'HOMME CÉLESTE","	= tian ren, t'ien jen"},
/* 1D302 */ { "DIGRAMME DE L'HOMME TERRESTRE","	= di ren, ti jen"},
/* 1D303 */ { "DIGRAMME DU CIEL HUMAIN","	= ren tian, jen t'ien"},
/* 1D304 */ { "DIGRAMME DE LA TERRE HUMAINE","	= ren di, jen ti"},
/* 1D305 */ { "DIGRAMME DE L'HOMME HUMAIN","	= ren ren, jen jen"},
/* 1D306 */ { "TÉTRAGRAMME DU MILIEU",NULL},
/* 1D307 */ { "TÉTRAGRAMME DU CYCLE COMPLET",NULL},
/* 1D308 */ { "TÉTRAGRAMME DE LA DIFFICULTÉ INITIALE",NULL},
/* 1D309 */ { "TÉTRAGRAMME DE L'OBSTACLE",NULL},
/* 1D30A */ { "TÉTRAGRAMME DU GARDER PETIT",NULL},
/* 1D30B */ { "TÉTRAGRAMME DU CONTRAIRE","	* contraires mutuellement dépendants"},
/* 1D30C */ { "TÉTRAGRAMME DE L'ASCENSION",NULL},
/* 1D30D */ { "TÉTRAGRAMME DE L'OPPOSITION",NULL},
/* 1D30E */ { "TÉTRAGRAMME DU BOURGEONNEMENT","	* base de la prolifération, de la croissance"},
/* 1D30F */ { "TÉTRAGRAMME DU DÉFAUT","	* légère déformation initiale"},
/* 1D310 */ { "TÉTRAGRAMME DE LA DIVERGENCE","	* variété, inégalité"},
/* 1D311 */ { "TÉTRAGRAMME DE LA JUVÉNILITÉ","	* noviciat, puérilité"},
/* 1D312 */ { "TÉTRAGRAMME DE L'AUGMENTATION",NULL},
/* 1D313 */ { "TÉTRAGRAMME DE LA PÉNÉTRATION","	* pointe, perspicacité, zèle, concentration, etc."},
/* 1D314 */ { "TÉTRAGRAMME DE L'ATTEINTE","	* portée, influence et compréhension grandissantes"},
/* 1D315 */ { "TÉTRAGRAMME DU CONTACT",NULL},
/* 1D316 */ { "TÉTRAGRAMME DE LA RETENUE","	* souplesse, réticence et même faiblesse si elle aboutit à une plus grande force ultérieure"},
/* 1D317 */ { "TÉTRAGRAMME DE L'ATTENTE","	* attente du moment opportun"},
/* 1D318 */ { "TÉTRAGRAMME DE LA SUITE",NULL},
/* 1D319 */ { "TÉTRAGRAMME DE L'AVANCÉE","	* émergence, prolifération"},
/* 1D31A */ { "TÉTRAGRAMME DE LA DÉLIVRANCE","	* influence générative qui délivre"},
/* 1D31B */ { "TÉTRAGRAMME DE LA RÉSISTANCE","	* force intérieure"},
/* 1D31C */ { "TÉTRAGRAMME DE L'APLANISSEMENT","	* blessure, nivellement, soulagement, sérénité"},
/* 1D31D */ { "TÉTRAGRAMME DU PLAISIR","	* joie excessive"},
/* 1D31E */ { "TÉTRAGRAMME DE LA RIVALITÉ","	* impartialité, équilibre des forces, concurrence"},
/* 1D31F */ { "TÉTRAGRAMME DE L'EFFORT SUR SOI",NULL},
/* 1D320 */ { "TÉTRAGRAMME DU DEVOIR","	* obligations, service juste et impartial"},
/* 1D321 */ { "TÉTRAGRAMME DU CHANGEMENT","	* rénovation"},
/* 1D322 */ { "TÉTRAGRAMME DE LA DÉCISION","	* acte décidé, ton ferme, appel aux armes"},
/* 1D323 */ { "TÉTRAGRAMME DU FERME COURAGE",NULL},
/* 1D324 */ { "TÉTRAGRAMME DU DÉPART PRÉPARÉ","	* faire ses bagages, prévoyance"},
/* 1D325 */ { "TÉTRAGRAMME DE LA LÉGION","	* foule, multitude, unité militaire"},
/* 1D326 */ { "TÉTRAGRAMME DE LA PROXIMITÉ","	* densité, contiguïté, intégration, accord"},
/* 1D327 */ { "TÉTRAGRAMME DE LA PARENTÉ","	* respect et loyauté envers la famille"},
/* 1D328 */ { "TÉTRAGRAMME DE LA COLLECTE","	* rassembler, ramasser ses forces et attendre ; percevoir des impôts, encaisser"},
/* 1D329 */ { "TÉTRAGRAMME DE LA FORCE",NULL},
/* 1D32A */ { "TÉTRAGRAMME DE LA PURETÉ",NULL},
/* 1D32B */ { "TÉTRAGRAMME DE L'ABONDANCE","	* plénitude, fécondité, prospérité"},
/* 1D32C */ { "TÉTRAGRAMME DE LA DEMEURE","	* cadre protecteur"},
/* 1D32D */ { "TÉTRAGRAMME DE LA NORME","	* loi ou modèle"},
/* 1D32E */ { "TÉTRAGRAMME DE LA RÉPONSE","	* réaction, juste et inévitable réponse, conforme à la Nature, union harmonieuse"},
/* 1D32F */ { "TÉTRAGRAMME DE LA VENUE AU DEVANT",NULL},
/* 1D330 */ { "TÉTRAGRAMME DE LA RENCONTRE FORTUITE",NULL},
/* 1D331 */ { "TÉTRAGRAMME DU FOURNEAU","	* poêle"},
/* 1D332 */ { "TÉTRAGRAMME DE LA GRANDEUR",NULL},
/* 1D333 */ { "TÉTRAGRAMME DE L'ENFLEMENT","	* élargissement, gonflement, enflure"},
/* 1D334 */ { "TÉTRAGRAMME DU DESSIN OU DU MOTIF","	* culture (relations sociétales), conduite (motif comportemental), présage (dessin céleste)"},
/* 1D335 */ { "TÉTRAGRAMME DU RITUEL",NULL},
/* 1D336 */ { "TÉTRAGRAMME DE LA RETRAITE","	* fuite (dangereuse) ou retrait (opportun)"},
/* 1D337 */ { "TÉTRAGRAMME DE L'IMMENSITÉ VIDE",NULL},
/* 1D338 */ { "TÉTRAGRAMME DE LA CONSTANCE",NULL},
/* 1D339 */ { "TÉTRAGRAMME DE LA MESURE","	* règle, loi, évaluation d'une grandeur, modération"},
/* 1D33A */ { "TÉTRAGRAMME DE L'ÉTERNITÉ",NULL},
/* 1D33B */ { "TÉTRAGRAMME DE L'UNITÉ","	* solidarité"},
/* 1D33C */ { "TÉTRAGRAMME DE LA DIMINUTION",NULL},
/* 1D33D */ { "TÉTRAGRAMME DE LA BOUCHE FERMÉE","	* taciturne, renfermé"},
/* 1D33E */ { "TÉTRAGRAMME DE LA CIRCONSPECTION","	* prudence qui entraîne le repli sur soi"},
/* 1D33F */ { "TÉTRAGRAMME DU MOISSONNAGE","	* réunion et entrée dans un état de repos"},
/* 1D340 */ { "TÉTRAGRAMME DE L'ENTASSEMENT",NULL},
/* 1D341 */ { "TÉTRAGRAMME DE L'ACCUMULATION",NULL},
/* 1D342 */ { "TÉTRAGRAMME DE L'EMBELLISSEMENT",NULL},
/* 1D343 */ { "TÉTRAGRAMME DU DOUTE",NULL},
/* 1D344 */ { "TÉTRAGRAMME DE L'OBSERVATION",NULL},
/* 1D345 */ { "TÉTRAGRAMME DE L'ENGLOUTISSEMENT","	* immersion, naufrage, sombrer"},
/* 1D346 */ { "TÉTRAGRAMME DE L'INTÉRIEUR",NULL},
/* 1D347 */ { "TÉTRAGRAMME DU DÉPART","	* désespoir"},
/* 1D348 */ { "TÉTRAGRAMME DE L'OBSCURCISSEMENT",NULL},
/* 1D349 */ { "TÉTRAGRAMME DE L'ATTÉNUATION","	* affaiblissement de la lumière"},
/* 1D34A */ { "TÉTRAGRAMME DE L'ÉPUISEMENT",NULL},
/* 1D34B */ { "TÉTRAGRAMME DE LA RUPTURE",NULL},
/* 1D34C */ { "TÉTRAGRAMME DE L'ARRÊT","	* suspension"},
/* 1D34D */ { "TÉTRAGRAMME DE LA DURETÉ",NULL},
/* 1D34E */ { "TÉTRAGRAMME DE L'ACHÈVEMENT","	* désolation complète, la fermeture imminente du cycle, derniers jours de la lutte"},
/* 1D34F */ { "TÉTRAGRAMME DE LA FERMETURE",NULL},
/* 1D350 */ { "TÉTRAGRAMME DE L'ÉCHEC",NULL},
/* 1D351 */ { "TÉTRAGRAMME DE L'EXASPÉRATION","	* irritation, manque, extrémité, intensité"},
/* 1D352 */ { "TÉTRAGRAMME DE LA DOCILITÉ",NULL},
/* 1D353 */ { "TÉTRAGRAMME DE L'IMMINENCE",NULL},
/* 1D354 */ { "TÉTRAGRAMME DES DIFFICULTÉS",NULL},
/* 1D355 */ { "TÉTRAGRAMME DE LA PERSÉVÉRANCE",NULL},
/* 1D356 */ { "TÉTRAGRAMME DU NOURRISSEMENT","	* nourrir pendant l'hiver, début de la renaissance"},
/* 1D357 */ { NULL,NULL},
/* 1D358 */ { NULL,NULL},
/* 1D359 */ { NULL,NULL},
/* 1D35A */ { NULL,NULL},
/* 1D35B */ { NULL,NULL},
/* 1D35C */ { NULL,NULL},
/* 1D35D */ { NULL,NULL},
/* 1D35E */ { NULL,NULL},
/* 1D35F */ { NULL,NULL},
/* 1D360 */ { "CHIFFRE-BÂTONNET UNE UNITÉ",NULL},
/* 1D361 */ { "CHIFFRE-BÂTONNET DEUX UNITÉS",NULL},
/* 1D362 */ { "CHIFFRE-BÂTONNET TROIS UNITÉS",NULL},
/* 1D363 */ { "CHIFFRE-BÂTONNET QUATRE UNITÉS",NULL},
/* 1D364 */ { "CHIFFRE-BÂTONNET CINQ UNITÉS",NULL},
/* 1D365 */ { "CHIFFRE-BÂTONNET SIX UNITÉS",NULL},
/* 1D366 */ { "CHIFFRE-BÂTONNET SEPT UNITÉS",NULL},
/* 1D367 */ { "CHIFFRE-BÂTONNET HUIT UNITÉS",NULL},
/* 1D368 */ { "CHIFFRE-BÂTONNET NEUF UNITÉS",NULL},
/* 1D369 */ { "CHIFFRE-BÂTONNET UNE DIZAINE",NULL},
/* 1D36A */ { "CHIFFRE-BÂTONNET DEUX DIZAINES",NULL},
/* 1D36B */ { "CHIFFRE-BÂTONNET TROIS DIZAINES",NULL},
/* 1D36C */ { "CHIFFRE-BÂTONNET QUATRE DIZAINES",NULL},
/* 1D36D */ { "CHIFFRE-BÂTONNET CINQ DIZAINES",NULL},
/* 1D36E */ { "CHIFFRE-BÂTONNET SIX DIZAINES",NULL},
/* 1D36F */ { "CHIFFRE-BÂTONNET SEPT DIZAINES",NULL},
/* 1D370 */ { "CHIFFRE-BÂTONNET HUIT DIZAINES",NULL},
/* 1D371 */ { "CHIFFRE-BÂTONNET NEUF DIZAINES",NULL},
/* 1D372 */ { "MARQUE DE DÉNOMBREMENT IDÉOGRAPHIQUE UN",NULL},
/* 1D373 */ { "MARQUE DE DÉNOMBREMENT IDÉOGRAPHIQUE DEUX",NULL},
/* 1D374 */ { "MARQUE DE DÉNOMBREMENT IDÉOGRAPHIQUE TROIS",NULL},
/* 1D375 */ { "MARQUE DE DÉNOMBREMENT IDÉOGRAPHIQUE QUATRE",NULL},
/* 1D376 */ { "MARQUE DE DÉNOMBREMENT IDÉOGRAPHIQUE CINQ","	x 6B63"},
/* 1D377 */ { "MARQUE DE DÉNOMBREMENT UN",NULL},
/* 1D378 */ { "MARQUE DE DÉNOMBREMENT CINQ",NULL},
/* 1D379 */ { NULL,NULL},
/* 1D37A */ { NULL,NULL},
/* 1D37B */ { NULL,NULL},
/* 1D37C */ { NULL,NULL},
/* 1D37D */ { NULL,NULL},
/* 1D37E */ { NULL,NULL},
/* 1D37F */ { NULL,NULL},
/* 1D380 */ { NULL,NULL},
/* 1D381 */ { NULL,NULL},
/* 1D382 */ { NULL,NULL},
/* 1D383 */ { NULL,NULL},
/* 1D384 */ { NULL,NULL},
/* 1D385 */ { NULL,NULL},
/* 1D386 */ { NULL,NULL},
/* 1D387 */ { NULL,NULL},
/* 1D388 */ { NULL,NULL},
/* 1D389 */ { NULL,NULL},
/* 1D38A */ { NULL,NULL},
/* 1D38B */ { NULL,NULL},
/* 1D38C */ { NULL,NULL},
/* 1D38D */ { NULL,NULL},
/* 1D38E */ { NULL,NULL},
/* 1D38F */ { NULL,NULL},
/* 1D390 */ { NULL,NULL},
/* 1D391 */ { NULL,NULL},
/* 1D392 */ { NULL,NULL},
/* 1D393 */ { NULL,NULL},
/* 1D394 */ { NULL,NULL},
/* 1D395 */ { NULL,NULL},
/* 1D396 */ { NULL,NULL},
/* 1D397 */ { NULL,NULL},
/* 1D398 */ { NULL,NULL},
/* 1D399 */ { NULL,NULL},
/* 1D39A */ { NULL,NULL},
/* 1D39B */ { NULL,NULL},
/* 1D39C */ { NULL,NULL},
/* 1D39D */ { NULL,NULL},
/* 1D39E */ { NULL,NULL},
/* 1D39F */ { NULL,NULL},
/* 1D3A0 */ { NULL,NULL},
/* 1D3A1 */ { NULL,NULL},
/* 1D3A2 */ { NULL,NULL},
/* 1D3A3 */ { NULL,NULL},
/* 1D3A4 */ { NULL,NULL},
/* 1D3A5 */ { NULL,NULL},
/* 1D3A6 */ { NULL,NULL},
/* 1D3A7 */ { NULL,NULL},
/* 1D3A8 */ { NULL,NULL},
/* 1D3A9 */ { NULL,NULL},
/* 1D3AA */ { NULL,NULL},
/* 1D3AB */ { NULL,NULL},
/* 1D3AC */ { NULL,NULL},
/* 1D3AD */ { NULL,NULL},
/* 1D3AE */ { NULL,NULL},
/* 1D3AF */ { NULL,NULL},
/* 1D3B0 */ { NULL,NULL},
/* 1D3B1 */ { NULL,NULL},
/* 1D3B2 */ { NULL,NULL},
/* 1D3B3 */ { NULL,NULL},
/* 1D3B4 */ { NULL,NULL},
/* 1D3B5 */ { NULL,NULL},
/* 1D3B6 */ { NULL,NULL},
/* 1D3B7 */ { NULL,NULL},
/* 1D3B8 */ { NULL,NULL},
/* 1D3B9 */ { NULL,NULL},
/* 1D3BA */ { NULL,NULL},
/* 1D3BB */ { NULL,NULL},
/* 1D3BC */ { NULL,NULL},
/* 1D3BD */ { NULL,NULL},
/* 1D3BE */ { NULL,NULL},
/* 1D3BF */ { NULL,NULL},
/* 1D3C0 */ { NULL,NULL},
/* 1D3C1 */ { NULL,NULL},
/* 1D3C2 */ { NULL,NULL},
/* 1D3C3 */ { NULL,NULL},
/* 1D3C4 */ { NULL,NULL},
/* 1D3C5 */ { NULL,NULL},
/* 1D3C6 */ { NULL,NULL},
/* 1D3C7 */ { NULL,NULL},
/* 1D3C8 */ { NULL,NULL},
/* 1D3C9 */ { NULL,NULL},
/* 1D3CA */ { NULL,NULL},
/* 1D3CB */ { NULL,NULL},
/* 1D3CC */ { NULL,NULL},
/* 1D3CD */ { NULL,NULL},
/* 1D3CE */ { NULL,NULL},
/* 1D3CF */ { NULL,NULL},
/* 1D3D0 */ { NULL,NULL},
/* 1D3D1 */ { NULL,NULL},
/* 1D3D2 */ { NULL,NULL},
/* 1D3D3 */ { NULL,NULL},
/* 1D3D4 */ { NULL,NULL},
/* 1D3D5 */ { NULL,NULL},
/* 1D3D6 */ { NULL,NULL},
/* 1D3D7 */ { NULL,NULL},
/* 1D3D8 */ { NULL,NULL},
/* 1D3D9 */ { NULL,NULL},
/* 1D3DA */ { NULL,NULL},
/* 1D3DB */ { NULL,NULL},
/* 1D3DC */ { NULL,NULL},
/* 1D3DD */ { NULL,NULL},
/* 1D3DE */ { NULL,NULL},
/* 1D3DF */ { NULL,NULL},
/* 1D3E0 */ { NULL,NULL},
/* 1D3E1 */ { NULL,NULL},
/* 1D3E2 */ { NULL,NULL},
/* 1D3E3 */ { NULL,NULL},
/* 1D3E4 */ { NULL,NULL},
/* 1D3E5 */ { NULL,NULL},
/* 1D3E6 */ { NULL,NULL},
/* 1D3E7 */ { NULL,NULL},
/* 1D3E8 */ { NULL,NULL},
/* 1D3E9 */ { NULL,NULL},
/* 1D3EA */ { NULL,NULL},
/* 1D3EB */ { NULL,NULL},
/* 1D3EC */ { NULL,NULL},
/* 1D3ED */ { NULL,NULL},
/* 1D3EE */ { NULL,NULL},
/* 1D3EF */ { NULL,NULL},
/* 1D3F0 */ { NULL,NULL},
/* 1D3F1 */ { NULL,NULL},
/* 1D3F2 */ { NULL,NULL},
/* 1D3F3 */ { NULL,NULL},
/* 1D3F4 */ { NULL,NULL},
/* 1D3F5 */ { NULL,NULL},
/* 1D3F6 */ { NULL,NULL},
/* 1D3F7 */ { NULL,NULL},
/* 1D3F8 */ { NULL,NULL},
/* 1D3F9 */ { NULL,NULL},
/* 1D3FA */ { NULL,NULL},
/* 1D3FB */ { NULL,NULL},
/* 1D3FC */ { NULL,NULL},
/* 1D3FD */ { NULL,NULL},
/* 1D3FE */ { NULL,NULL},
/* 1D3FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D4[] = {
/* 1D400 */ { "MAJUSCULE MATHÉMATIQUE GRASSE A","	# <police> 0041 lettre majuscule latine a"},
/* 1D401 */ { "MAJUSCULE MATHÉMATIQUE GRASSE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D402 */ { "MAJUSCULE MATHÉMATIQUE GRASSE C","	# <police> 0043 lettre majuscule latine c"},
/* 1D403 */ { "MAJUSCULE MATHÉMATIQUE GRASSE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D404 */ { "MAJUSCULE MATHÉMATIQUE GRASSE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D405 */ { "MAJUSCULE MATHÉMATIQUE GRASSE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D406 */ { "MAJUSCULE MATHÉMATIQUE GRASSE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D407 */ { "MAJUSCULE MATHÉMATIQUE GRASSE H","	# <police> 0048 lettre majuscule latine h"},
/* 1D408 */ { "MAJUSCULE MATHÉMATIQUE GRASSE I","	# <police> 0049 lettre majuscule latine i"},
/* 1D409 */ { "MAJUSCULE MATHÉMATIQUE GRASSE J","	# <police> 004A lettre majuscule latine j"},
/* 1D40A */ { "MAJUSCULE MATHÉMATIQUE GRASSE K","	# <police> 004B lettre majuscule latine k"},
/* 1D40B */ { "MAJUSCULE MATHÉMATIQUE GRASSE L","	# <police> 004C lettre majuscule latine l"},
/* 1D40C */ { "MAJUSCULE MATHÉMATIQUE GRASSE M","	# <police> 004D lettre majuscule latine m"},
/* 1D40D */ { "MAJUSCULE MATHÉMATIQUE GRASSE N","	# <police> 004E lettre majuscule latine n"},
/* 1D40E */ { "MAJUSCULE MATHÉMATIQUE GRASSE O","	# <police> 004F lettre majuscule latine o"},
/* 1D40F */ { "MAJUSCULE MATHÉMATIQUE GRASSE P","	# <police> 0050 lettre majuscule latine p"},
/* 1D410 */ { "MAJUSCULE MATHÉMATIQUE GRASSE Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D411 */ { "MAJUSCULE MATHÉMATIQUE GRASSE R","	# <police> 0052 lettre majuscule latine r"},
/* 1D412 */ { "MAJUSCULE MATHÉMATIQUE GRASSE S","	# <police> 0053 lettre majuscule latine s"},
/* 1D413 */ { "MAJUSCULE MATHÉMATIQUE GRASSE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D414 */ { "MAJUSCULE MATHÉMATIQUE GRASSE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D415 */ { "MAJUSCULE MATHÉMATIQUE GRASSE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D416 */ { "MAJUSCULE MATHÉMATIQUE GRASSE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D417 */ { "MAJUSCULE MATHÉMATIQUE GRASSE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D418 */ { "MAJUSCULE MATHÉMATIQUE GRASSE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D419 */ { "MAJUSCULE MATHÉMATIQUE GRASSE Z","	# <police> 005A lettre majuscule latine z"},
/* 1D41A */ { "MINUSCULE MATHÉMATIQUE GRASSE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D41B */ { "MINUSCULE MATHÉMATIQUE GRASSE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D41C */ { "MINUSCULE MATHÉMATIQUE GRASSE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D41D */ { "MINUSCULE MATHÉMATIQUE GRASSE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D41E */ { "MINUSCULE MATHÉMATIQUE GRASSE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D41F */ { "MINUSCULE MATHÉMATIQUE GRASSE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D420 */ { "MINUSCULE MATHÉMATIQUE GRASSE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D421 */ { "MINUSCULE MATHÉMATIQUE GRASSE H","	# <police> 0068 lettre minuscule latine h"},
/* 1D422 */ { "MINUSCULE MATHÉMATIQUE GRASSE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D423 */ { "MINUSCULE MATHÉMATIQUE GRASSE J","	# <police> 006A lettre minuscule latine j"},
/* 1D424 */ { "MINUSCULE MATHÉMATIQUE GRASSE K","	# <police> 006B lettre minuscule latine k"},
/* 1D425 */ { "MINUSCULE MATHÉMATIQUE GRASSE L","	# <police> 006C lettre minuscule latine l"},
/* 1D426 */ { "MINUSCULE MATHÉMATIQUE GRASSE M","	# <police> 006D lettre minuscule latine m"},
/* 1D427 */ { "MINUSCULE MATHÉMATIQUE GRASSE N","	# <police> 006E lettre minuscule latine n"},
/* 1D428 */ { "MINUSCULE MATHÉMATIQUE GRASSE O","	# <police> 006F lettre minuscule latine o"},
/* 1D429 */ { "MINUSCULE MATHÉMATIQUE GRASSE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D42A */ { "MINUSCULE MATHÉMATIQUE GRASSE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D42B */ { "MINUSCULE MATHÉMATIQUE GRASSE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D42C */ { "MINUSCULE MATHÉMATIQUE GRASSE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D42D */ { "MINUSCULE MATHÉMATIQUE GRASSE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D42E */ { "MINUSCULE MATHÉMATIQUE GRASSE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D42F */ { "MINUSCULE MATHÉMATIQUE GRASSE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D430 */ { "MINUSCULE MATHÉMATIQUE GRASSE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D431 */ { "MINUSCULE MATHÉMATIQUE GRASSE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D432 */ { "MINUSCULE MATHÉMATIQUE GRASSE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D433 */ { "MINUSCULE MATHÉMATIQUE GRASSE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D434 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE A","	# <police> 0041 lettre majuscule latine a"},
/* 1D435 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D436 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE C","	# <police> 0043 lettre majuscule latine c"},
/* 1D437 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D438 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D439 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D43A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D43B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE H","	# <police> 0048 lettre majuscule latine h"},
/* 1D43C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE I","	# <police> 0049 lettre majuscule latine i"},
/* 1D43D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE J","	# <police> 004A lettre majuscule latine j"},
/* 1D43E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE K","	# <police> 004B lettre majuscule latine k"},
/* 1D43F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE L","	# <police> 004C lettre majuscule latine l"},
/* 1D440 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE M","	# <police> 004D lettre majuscule latine m"},
/* 1D441 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE N","	# <police> 004E lettre majuscule latine n"},
/* 1D442 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE O","	# <police> 004F lettre majuscule latine o"},
/* 1D443 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE P","	# <police> 0050 lettre majuscule latine p"},
/* 1D444 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D445 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE R","	# <police> 0052 lettre majuscule latine r"},
/* 1D446 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE S","	# <police> 0053 lettre majuscule latine s"},
/* 1D447 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D448 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D449 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D44A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D44B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D44C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D44D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE Z","	# <police> 005A lettre majuscule latine z"},
/* 1D44E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D44F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D450 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D451 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D452 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D453 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D454 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D455 */ { NULL,"	x (constante de planck - 210E)"},
/* 1D456 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D457 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE J","	# <police> 006A lettre minuscule latine j"},
/* 1D458 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE K","	# <police> 006B lettre minuscule latine k"},
/* 1D459 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE L","	# <police> 006C lettre minuscule latine l"},
/* 1D45A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE M","	# <police> 006D lettre minuscule latine m"},
/* 1D45B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE N","	# <police> 006E lettre minuscule latine n"},
/* 1D45C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE O","	# <police> 006F lettre minuscule latine o"},
/* 1D45D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D45E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D45F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D460 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D461 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D462 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D463 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D464 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D465 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D466 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D467 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D468 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE A","	# <police> 0041 lettre majuscule latine a"},
/* 1D469 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D46A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE C","	# <police> 0043 lettre majuscule latine c"},
/* 1D46B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D46C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D46D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D46E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D46F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE H","	# <police> 0048 lettre majuscule latine h"},
/* 1D470 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE I","	# <police> 0049 lettre majuscule latine i"},
/* 1D471 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE J","	# <police> 004A lettre majuscule latine j"},
/* 1D472 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE K","	# <police> 004B lettre majuscule latine k"},
/* 1D473 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE L","	# <police> 004C lettre majuscule latine l"},
/* 1D474 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE M","	# <police> 004D lettre majuscule latine m"},
/* 1D475 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE N","	# <police> 004E lettre majuscule latine n"},
/* 1D476 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE O","	# <police> 004F lettre majuscule latine o"},
/* 1D477 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE P","	# <police> 0050 lettre majuscule latine p"},
/* 1D478 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D479 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE R","	# <police> 0052 lettre majuscule latine r"},
/* 1D47A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE S","	# <police> 0053 lettre majuscule latine s"},
/* 1D47B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D47C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D47D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D47E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D47F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D480 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D481 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE Z","	# <police> 005A lettre majuscule latine z"},
/* 1D482 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D483 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D484 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D485 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D486 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D487 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D488 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D489 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE H","	# <police> 0068 lettre minuscule latine h"},
/* 1D48A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D48B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE J","	# <police> 006A lettre minuscule latine j"},
/* 1D48C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE K","	# <police> 006B lettre minuscule latine k"},
/* 1D48D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE L","	# <police> 006C lettre minuscule latine l"},
/* 1D48E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE M","	# <police> 006D lettre minuscule latine m"},
/* 1D48F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE N","	# <police> 006E lettre minuscule latine n"},
/* 1D490 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE O","	# <police> 006F lettre minuscule latine o"},
/* 1D491 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D492 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D493 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D494 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D495 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D496 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D497 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D498 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D499 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D49A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D49B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D49C */ { "MAJUSCULE MATHÉMATIQUE A DE RONDE","	~ 1D49C FE00 écriture chancelière\n"
	"	~ 1D49C FE01 écriture anglaise\n"
	"	# <police> 0041 lettre majuscule latine a"},
/* 1D49D */ { NULL,"	x (majuscule b de ronde - 212C)"},
/* 1D49E */ { "MAJUSCULE MATHÉMATIQUE C DE RONDE","	~ 1D49E FE00 écriture chancelière\n"
	"	~ 1D49E FE01 écriture anglaise\n"
	"	# <police> 0043 lettre majuscule latine c"},
/* 1D49F */ { "MAJUSCULE MATHÉMATIQUE D DE RONDE","	~ 1D49F FE00 écriture chancelière\n"
	"	~ 1D49F FE01 écriture anglaise\n"
	"	# <police> 0044 lettre majuscule latine d"},
/* 1D4A0 */ { NULL,"	x (majuscule e de ronde - 2130)"},
/* 1D4A1 */ { NULL,"	x (majuscule f de ronde - 2131)"},
/* 1D4A2 */ { "MAJUSCULE MATHÉMATIQUE G DE RONDE","	~ 1D4A2 FE00 écriture chancelière\n"
	"	~ 1D4A2 FE01 écriture anglaise\n"
	"	# <police> 0047 lettre majuscule latine g"},
/* 1D4A3 */ { NULL,"	x (majuscule h de ronde - 210B)"},
/* 1D4A4 */ { NULL,"	x (majuscule i de ronde - 2110)"},
/* 1D4A5 */ { "MAJUSCULE MATHÉMATIQUE J DE RONDE","	~ 1D4A5 FE00 écriture chancelière\n"
	"	~ 1D4A5 FE01 écriture anglaise\n"
	"	# <police> 004A lettre majuscule latine j"},
/* 1D4A6 */ { "MAJUSCULE MATHÉMATIQUE K DE RONDE","	~ 1D4A6 FE00 écriture chancelière\n"
	"	~ 1D4A6 FE01 écriture anglaise\n"
	"	# <police> 004B lettre majuscule latine k"},
/* 1D4A7 */ { NULL,"	x (majuscule l de ronde - 2112)"},
/* 1D4A8 */ { NULL,"	x (majuscule m de ronde - 2133)"},
/* 1D4A9 */ { "MAJUSCULE MATHÉMATIQUE N DE RONDE","	~ 1D4A9 FE00 écriture chancelière\n"
	"	~ 1D4A9 FE01 écriture anglaise\n"
	"	# <police> 004E lettre majuscule latine n"},
/* 1D4AA */ { "MAJUSCULE MATHÉMATIQUE O DE RONDE","	~ 1D4AA FE00 écriture chancelière\n"
	"	~ 1D4AA FE01 écriture anglaise\n"
	"	# <police> 004F lettre majuscule latine o"},
/* 1D4AB */ { "MAJUSCULE MATHÉMATIQUE P DE RONDE","	= ensemble des parties d'un ensemble\n"
	"	~ 1D4AB FE00 écriture chancelière\n"
	"	~ 1D4AB FE01 écriture anglaise\n"
	"	# <police> 0050 lettre majuscule latine p"},
/* 1D4AC */ { "MAJUSCULE MATHÉMATIQUE Q DE RONDE","	~ 1D4AC FE00 écriture chancelière\n"
	"	~ 1D4AC FE01 écriture anglaise\n"
	"	# <police> 0051 lettre majuscule latine q"},
/* 1D4AD */ { NULL,"	x (majuscule r de ronde - 211B)"},
/* 1D4AE */ { "MAJUSCULE MATHÉMATIQUE S DE RONDE","	~ 1D4AE FE00 écriture chancelière\n"
	"	~ 1D4AE FE01 écriture anglaise\n"
	"	# <police> 0053 lettre majuscule latine s"},
/* 1D4AF */ { "MAJUSCULE MATHÉMATIQUE T DE RONDE","	~ 1D4AF FE00 écriture chancelière\n"
	"	~ 1D4AF FE01 écriture anglaise\n"
	"	# <police> 0054 lettre majuscule latine t"},
/* 1D4B0 */ { "MAJUSCULE MATHÉMATIQUE U DE RONDE","	~ 1D4B0 FE00 écriture chancelière\n"
	"	~ 1D4B0 FE01 écriture anglaise\n"
	"	# <police> 0055 lettre majuscule latine u"},
/* 1D4B1 */ { "MAJUSCULE MATHÉMATIQUE V DE RONDE","	~ 1D4B1 FE00 écriture chancelière\n"
	"	~ 1D4B1 FE01 écriture anglaise\n"
	"	# <police> 0056 lettre majuscule latine v"},
/* 1D4B2 */ { "MAJUSCULE MATHÉMATIQUE W DE RONDE","	~ 1D4B2 FE00 écriture chancelière\n"
	"	~ 1D4B2 FE01 écriture anglaise\n"
	"	# <police> 0057 lettre majuscule latine w"},
/* 1D4B3 */ { "MAJUSCULE MATHÉMATIQUE X DE RONDE","	~ 1D4B3 FE00 écriture chancelière\n"
	"	~ 1D4B3 FE01 écriture anglaise\n"
	"	# <police> 0058 lettre majuscule latine x"},
/* 1D4B4 */ { "MAJUSCULE MATHÉMATIQUE Y DE RONDE","	~ 1D4B4 FE00 écriture chancelière\n"
	"	~ 1D4B4 FE01 écriture anglaise\n"
	"	# <police> 0059 lettre majuscule latine y"},
/* 1D4B5 */ { "MAJUSCULE MATHÉMATIQUE Z DE RONDE","	~ 1D4B5 FE00 écriture chancelière\n"
	"	~ 1D4B5 FE01 écriture anglaise\n"
	"	# <police> 005A lettre majuscule latine z"},
/* 1D4B6 */ { "MINUSCULE MATHÉMATIQUE A DE RONDE","	# <police> 0061 lettre minuscule latine a"},
/* 1D4B7 */ { "MINUSCULE MATHÉMATIQUE B DE RONDE","	# <police> 0062 lettre minuscule latine b"},
/* 1D4B8 */ { "MINUSCULE MATHÉMATIQUE C DE RONDE","	# <police> 0063 lettre minuscule latine c"},
/* 1D4B9 */ { "MINUSCULE MATHÉMATIQUE D DE RONDE","	# <police> 0064 lettre minuscule latine d"},
/* 1D4BA */ { NULL,"	x (minuscule e de ronde - 212F)"},
/* 1D4BB */ { "MINUSCULE MATHÉMATIQUE F DE RONDE","	# <police> 0066 lettre minuscule latine f"},
/* 1D4BC */ { NULL,"	x (minuscule g de ronde - 210A)"},
/* 1D4BD */ { "MINUSCULE MATHÉMATIQUE G DE RONDE","	# <police> 0068 lettre minuscule latine h"},
/* 1D4BE */ { "MINUSCULE MATHÉMATIQUE I DE RONDE","	# <police> 0069 lettre minuscule latine i"},
/* 1D4BF */ { "MINUSCULE MATHÉMATIQUE J DE RONDE","	# <police> 006A lettre minuscule latine j"},
/* 1D4C0 */ { "MINUSCULE MATHÉMATIQUE K DE RONDE","	# <police> 006B lettre minuscule latine k"},
/* 1D4C1 */ { "MINUSCULE MATHÉMATIQUE L DE RONDE","	x (minuscule l de ronde - 2113)\n"
	"	# <police> 006C lettre minuscule latine l"},
/* 1D4C2 */ { "MINUSCULE MATHÉMATIQUE M DE RONDE","	# <police> 006D lettre minuscule latine m"},
/* 1D4C3 */ { "MINUSCULE MATHÉMATIQUE N DE RONDE","	# <police> 006E lettre minuscule latine n"},
/* 1D4C4 */ { NULL,"	x (minuscule o de ronde - 2134)"},
/* 1D4C5 */ { "MINUSCULE MATHÉMATIQUE P DE RONDE","	# <police> 0070 lettre minuscule latine p"},
/* 1D4C6 */ { "MINUSCULE MATHÉMATIQUE Q DE RONDE","	# <police> 0071 lettre minuscule latine q"},
/* 1D4C7 */ { "MINUSCULE MATHÉMATIQUE R DE RONDE","	# <police> 0072 lettre minuscule latine r"},
/* 1D4C8 */ { "MINUSCULE MATHÉMATIQUE S DE RONDE","	# <police> 0073 lettre minuscule latine s"},
/* 1D4C9 */ { "MINUSCULE MATHÉMATIQUE T DE RONDE","	# <police> 0074 lettre minuscule latine t"},
/* 1D4CA */ { "MINUSCULE MATHÉMATIQUE U DE RONDE","	# <police> 0075 lettre minuscule latine u"},
/* 1D4CB */ { "MINUSCULE MATHÉMATIQUE V DE RONDE","	# <police> 0076 lettre minuscule latine v"},
/* 1D4CC */ { "MINUSCULE MATHÉMATIQUE W DE RONDE","	# <police> 0077 lettre minuscule latine w"},
/* 1D4CD */ { "MINUSCULE MATHÉMATIQUE X DE RONDE","	# <police> 0078 lettre minuscule latine x"},
/* 1D4CE */ { "MINUSCULE MATHÉMATIQUE Y DE RONDE","	# <police> 0079 lettre minuscule latine y"},
/* 1D4CF */ { "MINUSCULE MATHÉMATIQUE Z DE RONDE","	# <police> 007A lettre minuscule latine z"},
/* 1D4D0 */ { "MAJUSCULE MATHÉMATIQUE GRASSE A DE RONDE","	# <police> 0041 lettre majuscule latine a"},
/* 1D4D1 */ { "MAJUSCULE MATHÉMATIQUE GRASSE B DE RONDE","	# <police> 0042 lettre majuscule latine b"},
/* 1D4D2 */ { "MAJUSCULE MATHÉMATIQUE GRASSE C DE RONDE","	# <police> 0043 lettre majuscule latine c"},
/* 1D4D3 */ { "MAJUSCULE MATHÉMATIQUE GRASSE D DE RONDE","	# <police> 0044 lettre majuscule latine d"},
/* 1D4D4 */ { "MAJUSCULE MATHÉMATIQUE GRASSE E DE RONDE","	# <police> 0045 lettre majuscule latine e"},
/* 1D4D5 */ { "MAJUSCULE MATHÉMATIQUE GRASSE F DE RONDE","	# <police> 0046 lettre majuscule latine f"},
/* 1D4D6 */ { "MAJUSCULE MATHÉMATIQUE GRASSE G DE RONDE","	# <police> 0047 lettre majuscule latine g"},
/* 1D4D7 */ { "MAJUSCULE MATHÉMATIQUE GRASSE H DE RONDE","	# <police> 0048 lettre majuscule latine h"},
/* 1D4D8 */ { "MAJUSCULE MATHÉMATIQUE GRASSE I DE RONDE","	# <police> 0049 lettre majuscule latine i"},
/* 1D4D9 */ { "MAJUSCULE MATHÉMATIQUE GRASSE J DE RONDE","	# <police> 004A lettre majuscule latine j"},
/* 1D4DA */ { "MAJUSCULE MATHÉMATIQUE GRASSE K DE RONDE","	# <police> 004B lettre majuscule latine k"},
/* 1D4DB */ { "MAJUSCULE MATHÉMATIQUE GRASSE L DE RONDE","	# <police> 004C lettre majuscule latine l"},
/* 1D4DC */ { "MAJUSCULE MATHÉMATIQUE GRASSE M DE RONDE","	# <police> 004D lettre majuscule latine m"},
/* 1D4DD */ { "MAJUSCULE MATHÉMATIQUE GRASSE N DE RONDE","	# <police> 004E lettre majuscule latine n"},
/* 1D4DE */ { "MAJUSCULE MATHÉMATIQUE GRASSE O DE RONDE","	# <police> 004F lettre majuscule latine o"},
/* 1D4DF */ { "MAJUSCULE MATHÉMATIQUE GRASSE P DE RONDE","	# <police> 0050 lettre majuscule latine p"},
/* 1D4E0 */ { "MAJUSCULE MATHÉMATIQUE GRASSE Q DE RONDE","	# <police> 0051 lettre majuscule latine q"},
/* 1D4E1 */ { "MAJUSCULE MATHÉMATIQUE GRASSE R DE RONDE","	# <police> 0052 lettre majuscule latine r"},
/* 1D4E2 */ { "MAJUSCULE MATHÉMATIQUE GRASSE S DE RONDE","	# <police> 0053 lettre majuscule latine s"},
/* 1D4E3 */ { "MAJUSCULE MATHÉMATIQUE GRASSE T DE RONDE","	# <police> 0054 lettre majuscule latine t"},
/* 1D4E4 */ { "MAJUSCULE MATHÉMATIQUE GRASSE U DE RONDE","	# <police> 0055 lettre majuscule latine u"},
/* 1D4E5 */ { "MAJUSCULE MATHÉMATIQUE GRASSE V DE RONDE","	# <police> 0056 lettre majuscule latine v"},
/* 1D4E6 */ { "MAJUSCULE MATHÉMATIQUE GRASSE W DE RONDE","	# <police> 0057 lettre majuscule latine w"},
/* 1D4E7 */ { "MAJUSCULE MATHÉMATIQUE GRASSE X DE RONDE","	# <police> 0058 lettre majuscule latine x"},
/* 1D4E8 */ { "MAJUSCULE MATHÉMATIQUE GRASSE Y DE RONDE","	# <police> 0059 lettre majuscule latine y"},
/* 1D4E9 */ { "MAJUSCULE MATHÉMATIQUE GRASSE Z DE RONDE","	# <police> 005A lettre majuscule latine z"},
/* 1D4EA */ { "MINUSCULE MATHÉMATIQUE GRASSE A DE RONDE","	# <police> 0061 lettre minuscule latine a"},
/* 1D4EB */ { "MINUSCULE MATHÉMATIQUE GRASSE B DE RONDE","	# <police> 0062 lettre minuscule latine b"},
/* 1D4EC */ { "MINUSCULE MATHÉMATIQUE GRASSE C DE RONDE","	# <police> 0063 lettre minuscule latine c"},
/* 1D4ED */ { "MINUSCULE MATHÉMATIQUE GRASSE D DE RONDE","	# <police> 0064 lettre minuscule latine d"},
/* 1D4EE */ { "MINUSCULE MATHÉMATIQUE GRASSE E DE RONDE","	# <police> 0065 lettre minuscule latine e"},
/* 1D4EF */ { "MINUSCULE MATHÉMATIQUE GRASSE F DE RONDE","	# <police> 0066 lettre minuscule latine f"},
/* 1D4F0 */ { "MINUSCULE MATHÉMATIQUE GRASSE G DE RONDE","	# <police> 0067 lettre minuscule latine g"},
/* 1D4F1 */ { "MINUSCULE MATHÉMATIQUE GRASSE H DE RONDE","	# <police> 0068 lettre minuscule latine h"},
/* 1D4F2 */ { "MINUSCULE MATHÉMATIQUE GRASSE I DE RONDE","	# <police> 0069 lettre minuscule latine i"},
/* 1D4F3 */ { "MINUSCULE MATHÉMATIQUE GRASSE J DE RONDE","	# <police> 006A lettre minuscule latine j"},
/* 1D4F4 */ { "MINUSCULE MATHÉMATIQUE GRASSE K DE RONDE","	# <police> 006B lettre minuscule latine k"},
/* 1D4F5 */ { "MINUSCULE MATHÉMATIQUE GRASSE L DE RONDE","	# <police> 006C lettre minuscule latine l"},
/* 1D4F6 */ { "MINUSCULE MATHÉMATIQUE GRASSE M DE RONDE","	# <police> 006D lettre minuscule latine m"},
/* 1D4F7 */ { "MINUSCULE MATHÉMATIQUE GRASSE N DE RONDE","	# <police> 006E lettre minuscule latine n"},
/* 1D4F8 */ { "MINUSCULE MATHÉMATIQUE GRASSE O DE RONDE","	# <police> 006F lettre minuscule latine o"},
/* 1D4F9 */ { "MINUSCULE MATHÉMATIQUE GRASSE P DE RONDE","	# <police> 0070 lettre minuscule latine p"},
/* 1D4FA */ { "MINUSCULE MATHÉMATIQUE GRASSE Q DE RONDE","	# <police> 0071 lettre minuscule latine q"},
/* 1D4FB */ { "MINUSCULE MATHÉMATIQUE GRASSE R DE RONDE","	# <police> 0072 lettre minuscule latine r"},
/* 1D4FC */ { "MINUSCULE MATHÉMATIQUE GRASSE S DE RONDE","	# <police> 0073 lettre minuscule latine s"},
/* 1D4FD */ { "MINUSCULE MATHÉMATIQUE GRASSE T DE RONDE","	# <police> 0074 lettre minuscule latine t"},
/* 1D4FE */ { "MINUSCULE MATHÉMATIQUE GRASSE U DE RONDE","	# <police> 0075 lettre minuscule latine u"},
/* 1D4FF */ { "MINUSCULE MATHÉMATIQUE GRASSE V DE RONDE","	# <police> 0076 lettre minuscule latine v"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D5[] = {
/* 1D500 */ { "MINUSCULE MATHÉMATIQUE GRASSE W DE RONDE","	# <police> 0077 lettre minuscule latine w"},
/* 1D501 */ { "MINUSCULE MATHÉMATIQUE GRASSE X DE RONDE","	# <police> 0078 lettre minuscule latine x"},
/* 1D502 */ { "MINUSCULE MATHÉMATIQUE GRASSE Y DE RONDE","	# <police> 0079 lettre minuscule latine y"},
/* 1D503 */ { "MINUSCULE MATHÉMATIQUE GRASSE Z DE RONDE","	# <police> 007A lettre minuscule latine z"},
/* 1D504 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE A","	# <police> 0041 lettre majuscule latine a"},
/* 1D505 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D506 */ { NULL,"	x (majuscule c gothique - 212D)"},
/* 1D507 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D508 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D509 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D50A */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D50B */ { NULL,"	x (majuscule h gothique - 210C)"},
/* 1D50C */ { NULL,"	x (majuscule i gothique - 2111)"},
/* 1D50D */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE J","	# <police> 004A lettre majuscule latine j"},
/* 1D50E */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE K","	# <police> 004B lettre majuscule latine k"},
/* 1D50F */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE L","	# <police> 004C lettre majuscule latine l"},
/* 1D510 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE M","	= texte majoritaire du Nouveau Testament\n"
	"	# <police> 004D lettre majuscule latine m"},
/* 1D511 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE N","	# <police> 004E lettre majuscule latine n"},
/* 1D512 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE O","	# <police> 004F lettre majuscule latine o"},
/* 1D513 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE P","	# <police> 0050 lettre majuscule latine p"},
/* 1D514 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D515 */ { NULL,"	x (majuscule r gothique - 211C)"},
/* 1D516 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE S","	= Septante, grec de l'Ancien Testament\n"
	"	# <police> 0053 lettre majuscule latine s"},
/* 1D517 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D518 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D519 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D51A */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D51B */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D51C */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D51D */ { NULL,"	x (majuscule z gothique - 2128)"},
/* 1D51E */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D51F */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D520 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D521 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D522 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D523 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D524 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D525 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE H","	# <police> 0068 lettre minuscule latine h"},
/* 1D526 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D527 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE J","	# <police> 006A lettre minuscule latine j"},
/* 1D528 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE K","	# <police> 006B lettre minuscule latine k"},
/* 1D529 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE L","	# <police> 006C lettre minuscule latine l"},
/* 1D52A */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE M","	# <police> 006D lettre minuscule latine m"},
/* 1D52B */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE N","	# <police> 006E lettre minuscule latine n"},
/* 1D52C */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE O","	# <police> 006F lettre minuscule latine o"},
/* 1D52D */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D52E */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D52F */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D530 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D531 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D532 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D533 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D534 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D535 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D536 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D537 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D538 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE A","	* il existe une variante de glyphe avec la partie ajourée à gauche\n"
	"	# <police> 0041 lettre majuscule latine a"},
/* 1D539 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D53A */ { NULL,"	x (majuscule c ajouré - 2102)"},
/* 1D53B */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D53C */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D53D */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D53E */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D53F */ { NULL,"	x (majuscule h ajouré - 210D)"},
/* 1D540 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE I","	# <police> 0049 lettre majuscule latine i"},
/* 1D541 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE J","	# <police> 004A lettre majuscule latine j"},
/* 1D542 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE K","	# <police> 004B lettre majuscule latine k"},
/* 1D543 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE L","	# <police> 004C lettre majuscule latine l"},
/* 1D544 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE M","	# <police> 004D lettre majuscule latine m"},
/* 1D545 */ { NULL,"	x (majuscule n ajouré - 2115)"},
/* 1D546 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE O","	# <police> 004F lettre majuscule latine o"},
/* 1D547 */ { NULL,"	x (majuscule p ajouré - 2119)"},
/* 1D548 */ { NULL,"	x (majuscule q ajouré - 211A)"},
/* 1D549 */ { NULL,"	x (majuscule r ajouré - 211D)"},
/* 1D54A */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE S","	# <police> 0053 lettre majuscule latine s"},
/* 1D54B */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D54C */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D54D */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D54E */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D54F */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D550 */ { "MAJUSCULE MATHÉMATIQUE AJOURÉE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D551 */ { NULL,"	x (majuscule z ajouré - 2124)"},
/* 1D552 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D553 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D554 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D555 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D556 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D557 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D558 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D559 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE H","	# <police> 0068 lettre minuscule latine h"},
/* 1D55A */ { "MINUSCULE MATHÉMATIQUE AJOURÉE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D55B */ { "MINUSCULE MATHÉMATIQUE AJOURÉE J","	# <police> 006A lettre minuscule latine j"},
/* 1D55C */ { "MINUSCULE MATHÉMATIQUE AJOURÉE K","	# <police> 006B lettre minuscule latine k"},
/* 1D55D */ { "MINUSCULE MATHÉMATIQUE AJOURÉE L","	# <police> 006C lettre minuscule latine l"},
/* 1D55E */ { "MINUSCULE MATHÉMATIQUE AJOURÉE M","	# <police> 006D lettre minuscule latine m"},
/* 1D55F */ { "MINUSCULE MATHÉMATIQUE AJOURÉE N","	# <police> 006E lettre minuscule latine n"},
/* 1D560 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE O","	# <police> 006F lettre minuscule latine o"},
/* 1D561 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D562 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D563 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D564 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D565 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D566 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D567 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D568 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D569 */ { "MINUSCULE MATHÉMATIQUE AJOURÉE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D56A */ { "MINUSCULE MATHÉMATIQUE AJOURÉE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D56B */ { "MINUSCULE MATHÉMATIQUE AJOURÉE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D56C */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE A","	# <police> 0041 lettre majuscule latine a"},
/* 1D56D */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D56E */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE C","	# <police> 0043 lettre majuscule latine c"},
/* 1D56F */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D570 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D571 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D572 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D573 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE H","	# <police> 0048 lettre majuscule latine h"},
/* 1D574 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE I","	# <police> 0049 lettre majuscule latine i"},
/* 1D575 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE J","	# <police> 004A lettre majuscule latine j"},
/* 1D576 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE K","	# <police> 004B lettre majuscule latine k"},
/* 1D577 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE L","	# <police> 004C lettre majuscule latine l"},
/* 1D578 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE M","	# <police> 004D lettre majuscule latine m"},
/* 1D579 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE N","	# <police> 004E lettre majuscule latine n"},
/* 1D57A */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE O","	# <police> 004F lettre majuscule latine o"},
/* 1D57B */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE P","	# <police> 0050 lettre majuscule latine p"},
/* 1D57C */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D57D */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE R","	# <police> 0052 lettre majuscule latine r"},
/* 1D57E */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE S","	# <police> 0053 lettre majuscule latine s"},
/* 1D57F */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D580 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D581 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D582 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D583 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D584 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D585 */ { "MAJUSCULE MATHÉMATIQUE GOTHIQUE GRASSE Z","	# <police> 005A lettre majuscule latine z"},
/* 1D586 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D587 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D588 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D589 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D58A */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D58B */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D58C */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D58D */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE H","	# <police> 0068 lettre minuscule latine h"},
/* 1D58E */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D58F */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE J","	# <police> 006A lettre minuscule latine j"},
/* 1D590 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE K","	# <police> 006B lettre minuscule latine k"},
/* 1D591 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE L","	# <police> 006C lettre minuscule latine l"},
/* 1D592 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE M","	# <police> 006D lettre minuscule latine m"},
/* 1D593 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE N","	# <police> 006E lettre minuscule latine n"},
/* 1D594 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE O","	# <police> 006F lettre minuscule latine o"},
/* 1D595 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D596 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D597 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D598 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D599 */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D59A */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D59B */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D59C */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D59D */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D59E */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D59F */ { "MINUSCULE MATHÉMATIQUE GOTHIQUE GRASSE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D5A0 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT A","	# <police> 0041 lettre majuscule latine a"},
/* 1D5A1 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT B","	# <police> 0042 lettre majuscule latine b"},
/* 1D5A2 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT C","	# <police> 0043 lettre majuscule latine c"},
/* 1D5A3 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT D","	# <police> 0044 lettre majuscule latine d"},
/* 1D5A4 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT E","	# <police> 0045 lettre majuscule latine e"},
/* 1D5A5 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT F","	# <police> 0046 lettre majuscule latine f"},
/* 1D5A6 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT G","	# <police> 0047 lettre majuscule latine g"},
/* 1D5A7 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT H","	# <police> 0048 lettre majuscule latine h"},
/* 1D5A8 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT I","	# <police> 0049 lettre majuscule latine i"},
/* 1D5A9 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT J","	# <police> 004A lettre majuscule latine j"},
/* 1D5AA */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT K","	# <police> 004B lettre majuscule latine k"},
/* 1D5AB */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT L","	# <police> 004C lettre majuscule latine l"},
/* 1D5AC */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT M","	# <police> 004D lettre majuscule latine m"},
/* 1D5AD */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT N","	# <police> 004E lettre majuscule latine n"},
/* 1D5AE */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT O","	# <police> 004F lettre majuscule latine o"},
/* 1D5AF */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT P","	# <police> 0050 lettre majuscule latine p"},
/* 1D5B0 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D5B1 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT R","	# <police> 0052 lettre majuscule latine r"},
/* 1D5B2 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT S","	# <police> 0053 lettre majuscule latine s"},
/* 1D5B3 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT T","	# <police> 0054 lettre majuscule latine t"},
/* 1D5B4 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT U","	# <police> 0055 lettre majuscule latine u"},
/* 1D5B5 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT V","	# <police> 0056 lettre majuscule latine v"},
/* 1D5B6 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT W","	# <police> 0057 lettre majuscule latine w"},
/* 1D5B7 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT X","	# <police> 0058 lettre majuscule latine x"},
/* 1D5B8 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D5B9 */ { "MAJUSCULE MATHÉMATIQUE SANS EMPATTEMENT Z","	# <police> 005A lettre majuscule latine z"},
/* 1D5BA */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT A","	# <police> 0061 lettre minuscule latine a"},
/* 1D5BB */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT B","	# <police> 0062 lettre minuscule latine b"},
/* 1D5BC */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT C","	# <police> 0063 lettre minuscule latine c"},
/* 1D5BD */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT D","	# <police> 0064 lettre minuscule latine d"},
/* 1D5BE */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT E","	# <police> 0065 lettre minuscule latine e"},
/* 1D5BF */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT F","	# <police> 0066 lettre minuscule latine f"},
/* 1D5C0 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT G","	# <police> 0067 lettre minuscule latine g"},
/* 1D5C1 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT H","	# <police> 0068 lettre minuscule latine h"},
/* 1D5C2 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT I","	# <police> 0069 lettre minuscule latine i"},
/* 1D5C3 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT J","	# <police> 006A lettre minuscule latine j"},
/* 1D5C4 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT K","	# <police> 006B lettre minuscule latine k"},
/* 1D5C5 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT L","	# <police> 006C lettre minuscule latine l"},
/* 1D5C6 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT M","	# <police> 006D lettre minuscule latine m"},
/* 1D5C7 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT N","	# <police> 006E lettre minuscule latine n"},
/* 1D5C8 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT O","	# <police> 006F lettre minuscule latine o"},
/* 1D5C9 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT P","	# <police> 0070 lettre minuscule latine p"},
/* 1D5CA */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D5CB */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT R","	# <police> 0072 lettre minuscule latine r"},
/* 1D5CC */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT S","	# <police> 0073 lettre minuscule latine s"},
/* 1D5CD */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT T","	# <police> 0074 lettre minuscule latine t"},
/* 1D5CE */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT U","	# <police> 0075 lettre minuscule latine u"},
/* 1D5CF */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT V","	# <police> 0076 lettre minuscule latine v"},
/* 1D5D0 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT W","	# <police> 0077 lettre minuscule latine w"},
/* 1D5D1 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT X","	# <police> 0078 lettre minuscule latine x"},
/* 1D5D2 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D5D3 */ { "MINUSCULE MATHÉMATIQUE SANS EMPATTEMENT Z","	# <police> 007A lettre minuscule latine z"},
/* 1D5D4 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT A","	# <police> 0041 lettre majuscule latine a"},
/* 1D5D5 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT B","	# <police> 0042 lettre majuscule latine b"},
/* 1D5D6 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT C","	# <police> 0043 lettre majuscule latine c"},
/* 1D5D7 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT D","	# <police> 0044 lettre majuscule latine d"},
/* 1D5D8 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT E","	# <police> 0045 lettre majuscule latine e"},
/* 1D5D9 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT F","	# <police> 0046 lettre majuscule latine f"},
/* 1D5DA */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT G","	# <police> 0047 lettre majuscule latine g"},
/* 1D5DB */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT H","	# <police> 0048 lettre majuscule latine h"},
/* 1D5DC */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT I","	# <police> 0049 lettre majuscule latine i"},
/* 1D5DD */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT J","	# <police> 004A lettre majuscule latine j"},
/* 1D5DE */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT K","	# <police> 004B lettre majuscule latine k"},
/* 1D5DF */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT L","	# <police> 004C lettre majuscule latine l"},
/* 1D5E0 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT M","	# <police> 004D lettre majuscule latine m"},
/* 1D5E1 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT N","	# <police> 004E lettre majuscule latine n"},
/* 1D5E2 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT O","	# <police> 004F lettre majuscule latine o"},
/* 1D5E3 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT P","	# <police> 0050 lettre majuscule latine p"},
/* 1D5E4 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D5E5 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT R","	# <police> 0052 lettre majuscule latine r"},
/* 1D5E6 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT S","	# <police> 0053 lettre majuscule latine s"},
/* 1D5E7 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT T","	# <police> 0054 lettre majuscule latine t"},
/* 1D5E8 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT U","	# <police> 0055 lettre majuscule latine u"},
/* 1D5E9 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT V","	# <police> 0056 lettre majuscule latine v"},
/* 1D5EA */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT W","	# <police> 0057 lettre majuscule latine w"},
/* 1D5EB */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT X","	# <police> 0058 lettre majuscule latine x"},
/* 1D5EC */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D5ED */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT Z","	# <police> 005A lettre majuscule latine z"},
/* 1D5EE */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT A","	# <police> 0061 lettre minuscule latine a"},
/* 1D5EF */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT B","	# <police> 0062 lettre minuscule latine b"},
/* 1D5F0 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT C","	# <police> 0063 lettre minuscule latine c"},
/* 1D5F1 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT D","	# <police> 0064 lettre minuscule latine d"},
/* 1D5F2 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT E","	# <police> 0065 lettre minuscule latine e"},
/* 1D5F3 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT F","	# <police> 0066 lettre minuscule latine f"},
/* 1D5F4 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT G","	# <police> 0067 lettre minuscule latine g"},
/* 1D5F5 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT H","	# <police> 0068 lettre minuscule latine h"},
/* 1D5F6 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT I","	# <police> 0069 lettre minuscule latine i"},
/* 1D5F7 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT J","	# <police> 006A lettre minuscule latine j"},
/* 1D5F8 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT K","	# <police> 006B lettre minuscule latine k"},
/* 1D5F9 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT L","	# <police> 006C lettre minuscule latine l"},
/* 1D5FA */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT M","	# <police> 006D lettre minuscule latine m"},
/* 1D5FB */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT N","	# <police> 006E lettre minuscule latine n"},
/* 1D5FC */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT O","	# <police> 006F lettre minuscule latine o"},
/* 1D5FD */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT P","	# <police> 0070 lettre minuscule latine p"},
/* 1D5FE */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D5FF */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT R","	# <police> 0072 lettre minuscule latine r"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D6[] = {
/* 1D600 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT S","	# <police> 0073 lettre minuscule latine s"},
/* 1D601 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT T","	# <police> 0074 lettre minuscule latine t"},
/* 1D602 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT U","	# <police> 0075 lettre minuscule latine u"},
/* 1D603 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT V","	# <police> 0076 lettre minuscule latine v"},
/* 1D604 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT W","	# <police> 0077 lettre minuscule latine w"},
/* 1D605 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT X","	# <police> 0078 lettre minuscule latine x"},
/* 1D606 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D607 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT Z","	# <police> 007A lettre minuscule latine z"},
/* 1D608 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT A","	# <police> 0041 lettre majuscule latine a"},
/* 1D609 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT B","	# <police> 0042 lettre majuscule latine b"},
/* 1D60A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT C","	# <police> 0043 lettre majuscule latine c"},
/* 1D60B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT D","	# <police> 0044 lettre majuscule latine d"},
/* 1D60C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT E","	# <police> 0045 lettre majuscule latine e"},
/* 1D60D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT F","	# <police> 0046 lettre majuscule latine f"},
/* 1D60E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT G","	# <police> 0047 lettre majuscule latine g"},
/* 1D60F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT H","	# <police> 0048 lettre majuscule latine h"},
/* 1D610 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT I","	# <police> 0049 lettre majuscule latine i"},
/* 1D611 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT J","	# <police> 004A lettre majuscule latine j"},
/* 1D612 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT K","	# <police> 004B lettre majuscule latine k"},
/* 1D613 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT L","	# <police> 004C lettre majuscule latine l"},
/* 1D614 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT M","	# <police> 004D lettre majuscule latine m"},
/* 1D615 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT N","	# <police> 004E lettre majuscule latine n"},
/* 1D616 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT O","	# <police> 004F lettre majuscule latine o"},
/* 1D617 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT P","	# <police> 0050 lettre majuscule latine p"},
/* 1D618 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D619 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT R","	# <police> 0052 lettre majuscule latine r"},
/* 1D61A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT S","	# <police> 0053 lettre majuscule latine s"},
/* 1D61B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT T","	# <police> 0054 lettre majuscule latine t"},
/* 1D61C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT U","	# <police> 0055 lettre majuscule latine u"},
/* 1D61D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT V","	# <police> 0056 lettre majuscule latine v"},
/* 1D61E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT W","	# <police> 0057 lettre majuscule latine w"},
/* 1D61F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT X","	# <police> 0058 lettre majuscule latine x"},
/* 1D620 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D621 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT Z","	# <police> 005A lettre majuscule latine z"},
/* 1D622 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT A","	# <police> 0061 lettre minuscule latine a"},
/* 1D623 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT B","	# <police> 0062 lettre minuscule latine b"},
/* 1D624 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT C","	# <police> 0063 lettre minuscule latine c"},
/* 1D625 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT D","	# <police> 0064 lettre minuscule latine d"},
/* 1D626 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT E","	# <police> 0065 lettre minuscule latine e"},
/* 1D627 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT F","	# <police> 0066 lettre minuscule latine f"},
/* 1D628 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT G","	# <police> 0067 lettre minuscule latine g"},
/* 1D629 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT H","	# <police> 0068 lettre minuscule latine h"},
/* 1D62A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT I","	# <police> 0069 lettre minuscule latine i"},
/* 1D62B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT J","	# <police> 006A lettre minuscule latine j"},
/* 1D62C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT K","	# <police> 006B lettre minuscule latine k"},
/* 1D62D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT L","	# <police> 006C lettre minuscule latine l"},
/* 1D62E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT M","	# <police> 006D lettre minuscule latine m"},
/* 1D62F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT N","	# <police> 006E lettre minuscule latine n"},
/* 1D630 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT O","	# <police> 006F lettre minuscule latine o"},
/* 1D631 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT P","	# <police> 0070 lettre minuscule latine p"},
/* 1D632 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D633 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT R","	# <police> 0072 lettre minuscule latine r"},
/* 1D634 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT S","	# <police> 0073 lettre minuscule latine s"},
/* 1D635 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT T","	# <police> 0074 lettre minuscule latine t"},
/* 1D636 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT U","	# <police> 0075 lettre minuscule latine u"},
/* 1D637 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT V","	# <police> 0076 lettre minuscule latine v"},
/* 1D638 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT W","	# <police> 0077 lettre minuscule latine w"},
/* 1D639 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT X","	# <police> 0078 lettre minuscule latine x"},
/* 1D63A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D63B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SANS EMPATTEMENT Z","	# <police> 007A lettre minuscule latine z"},
/* 1D63C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT A","	# <police> 0041 lettre majuscule latine a"},
/* 1D63D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT B","	# <police> 0042 lettre majuscule latine b"},
/* 1D63E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT C","	# <police> 0043 lettre majuscule latine c"},
/* 1D63F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT D","	# <police> 0044 lettre majuscule latine d"},
/* 1D640 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT E","	# <police> 0045 lettre majuscule latine e"},
/* 1D641 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT F","	# <police> 0046 lettre majuscule latine f"},
/* 1D642 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT G","	# <police> 0047 lettre majuscule latine g"},
/* 1D643 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT H","	# <police> 0048 lettre majuscule latine h"},
/* 1D644 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT I","	# <police> 0049 lettre majuscule latine i"},
/* 1D645 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT J","	# <police> 004A lettre majuscule latine j"},
/* 1D646 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT K","	# <police> 004B lettre majuscule latine k"},
/* 1D647 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT L","	# <police> 004C lettre majuscule latine l"},
/* 1D648 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT M","	# <police> 004D lettre majuscule latine m"},
/* 1D649 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT N","	# <police> 004E lettre majuscule latine n"},
/* 1D64A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT O","	# <police> 004F lettre majuscule latine o"},
/* 1D64B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT P","	# <police> 0050 lettre majuscule latine p"},
/* 1D64C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D64D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT R","	# <police> 0052 lettre majuscule latine r"},
/* 1D64E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT S","	# <police> 0053 lettre majuscule latine s"},
/* 1D64F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT T","	# <police> 0054 lettre majuscule latine t"},
/* 1D650 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT U","	# <police> 0055 lettre majuscule latine u"},
/* 1D651 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT V","	# <police> 0056 lettre majuscule latine v"},
/* 1D652 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT W","	# <police> 0057 lettre majuscule latine w"},
/* 1D653 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT X","	# <police> 0058 lettre majuscule latine x"},
/* 1D654 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D655 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT Z","	# <police> 005A lettre majuscule latine z"},
/* 1D656 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT A","	# <police> 0061 lettre minuscule latine a"},
/* 1D657 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT B","	# <police> 0062 lettre minuscule latine b"},
/* 1D658 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT C","	# <police> 0063 lettre minuscule latine c"},
/* 1D659 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT D","	# <police> 0064 lettre minuscule latine d"},
/* 1D65A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT E","	# <police> 0065 lettre minuscule latine e"},
/* 1D65B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT F","	# <police> 0066 lettre minuscule latine f"},
/* 1D65C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT G","	# <police> 0067 lettre minuscule latine g"},
/* 1D65D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT H","	# <police> 0068 lettre minuscule latine h"},
/* 1D65E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT I","	# <police> 0069 lettre minuscule latine i"},
/* 1D65F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT J","	# <police> 006A lettre minuscule latine j"},
/* 1D660 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT K","	# <police> 006B lettre minuscule latine k"},
/* 1D661 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT L","	# <police> 006C lettre minuscule latine l"},
/* 1D662 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT M","	# <police> 006D lettre minuscule latine m"},
/* 1D663 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT N","	# <police> 006E lettre minuscule latine n"},
/* 1D664 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT O","	# <police> 006F lettre minuscule latine o"},
/* 1D665 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT P","	# <police> 0070 lettre minuscule latine p"},
/* 1D666 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D667 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT R","	# <police> 0072 lettre minuscule latine r"},
/* 1D668 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT S","	# <police> 0073 lettre minuscule latine s"},
/* 1D669 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT T","	# <police> 0074 lettre minuscule latine t"},
/* 1D66A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT U","	# <police> 0075 lettre minuscule latine u"},
/* 1D66B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT V","	# <police> 0076 lettre minuscule latine v"},
/* 1D66C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT W","	# <police> 0077 lettre minuscule latine w"},
/* 1D66D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT X","	# <police> 0078 lettre minuscule latine x"},
/* 1D66E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D66F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT Z","	# <police> 007A lettre minuscule latine z"},
/* 1D670 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE A","	# <police> 0041 lettre majuscule latine a"},
/* 1D671 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE B","	# <police> 0042 lettre majuscule latine b"},
/* 1D672 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE C","	# <police> 0043 lettre majuscule latine c"},
/* 1D673 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE D","	# <police> 0044 lettre majuscule latine d"},
/* 1D674 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE E","	# <police> 0045 lettre majuscule latine e"},
/* 1D675 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE F","	# <police> 0046 lettre majuscule latine f"},
/* 1D676 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE G","	# <police> 0047 lettre majuscule latine g"},
/* 1D677 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE H","	# <police> 0048 lettre majuscule latine h"},
/* 1D678 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE I","	# <police> 0049 lettre majuscule latine i"},
/* 1D679 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE J","	# <police> 004A lettre majuscule latine j"},
/* 1D67A */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE K","	# <police> 004B lettre majuscule latine k"},
/* 1D67B */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE L","	# <police> 004C lettre majuscule latine l"},
/* 1D67C */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE M","	# <police> 004D lettre majuscule latine m"},
/* 1D67D */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE N","	# <police> 004E lettre majuscule latine n"},
/* 1D67E */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE O","	# <police> 004F lettre majuscule latine o"},
/* 1D67F */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE P","	# <police> 0050 lettre majuscule latine p"},
/* 1D680 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE Q","	# <police> 0051 lettre majuscule latine q"},
/* 1D681 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE R","	# <police> 0052 lettre majuscule latine r"},
/* 1D682 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE S","	# <police> 0053 lettre majuscule latine s"},
/* 1D683 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE T","	# <police> 0054 lettre majuscule latine t"},
/* 1D684 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE U","	# <police> 0055 lettre majuscule latine u"},
/* 1D685 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE V","	# <police> 0056 lettre majuscule latine v"},
/* 1D686 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE W","	# <police> 0057 lettre majuscule latine w"},
/* 1D687 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE X","	# <police> 0058 lettre majuscule latine x"},
/* 1D688 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE Y","	# <police> 0059 lettre majuscule latine y"},
/* 1D689 */ { "MAJUSCULE MATHÉMATIQUE À CHASSE FIXE Z","	# <police> 005A lettre majuscule latine z"},
/* 1D68A */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE A","	# <police> 0061 lettre minuscule latine a"},
/* 1D68B */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE B","	# <police> 0062 lettre minuscule latine b"},
/* 1D68C */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE C","	# <police> 0063 lettre minuscule latine c"},
/* 1D68D */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE D","	# <police> 0064 lettre minuscule latine d"},
/* 1D68E */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE E","	# <police> 0065 lettre minuscule latine e"},
/* 1D68F */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE F","	# <police> 0066 lettre minuscule latine f"},
/* 1D690 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE G","	# <police> 0067 lettre minuscule latine g"},
/* 1D691 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE H","	# <police> 0068 lettre minuscule latine h"},
/* 1D692 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE I","	# <police> 0069 lettre minuscule latine i"},
/* 1D693 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE J","	# <police> 006A lettre minuscule latine j"},
/* 1D694 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE K","	# <police> 006B lettre minuscule latine k"},
/* 1D695 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE L","	# <police> 006C lettre minuscule latine l"},
/* 1D696 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE M","	# <police> 006D lettre minuscule latine m"},
/* 1D697 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE N","	# <police> 006E lettre minuscule latine n"},
/* 1D698 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE O","	# <police> 006F lettre minuscule latine o"},
/* 1D699 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE P","	# <police> 0070 lettre minuscule latine p"},
/* 1D69A */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE Q","	# <police> 0071 lettre minuscule latine q"},
/* 1D69B */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE R","	# <police> 0072 lettre minuscule latine r"},
/* 1D69C */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE S","	# <police> 0073 lettre minuscule latine s"},
/* 1D69D */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE T","	# <police> 0074 lettre minuscule latine t"},
/* 1D69E */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE U","	# <police> 0075 lettre minuscule latine u"},
/* 1D69F */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE V","	# <police> 0076 lettre minuscule latine v"},
/* 1D6A0 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE W","	# <police> 0077 lettre minuscule latine w"},
/* 1D6A1 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE X","	# <police> 0078 lettre minuscule latine x"},
/* 1D6A2 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE Y","	# <police> 0079 lettre minuscule latine y"},
/* 1D6A3 */ { "MINUSCULE MATHÉMATIQUE À CHASSE FIXE Z","	# <police> 007A lettre minuscule latine z"},
/* 1D6A4 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE I SANS POINT","	= \\imath\n"
	"	x (lettre minuscule latine i sans point - 0131)\n"
	"	x (minuscule mathématique italique i - 1D456)\n"
	"	# <police> 0131 lettre minuscule latine i sans point"},
/* 1D6A5 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE J SANS POINT","	= \\jmath\n"
	"	x (lettre minuscule latine j sans point - 0237)\n"
	"	x (minuscule mathématique italique j - 1D457)\n"
	"	# <police> 0237 lettre minuscule latine j sans point"},
/* 1D6A6 */ { NULL,NULL},
/* 1D6A7 */ { NULL,NULL},
/* 1D6A8 */ { "MAJUSCULE MATHÉMATIQUE GRASSE ALPHA","	# <police> 0391 lettre majuscule grecque alpha"},
/* 1D6A9 */ { "MAJUSCULE MATHÉMATIQUE GRASSE BÊTA","	# <police> 0392 lettre majuscule grecque bêta"},
/* 1D6AA */ { "MAJUSCULE MATHÉMATIQUE GRASSE GAMMA","	# <police> 0393 lettre majuscule grecque gamma"},
/* 1D6AB */ { "MAJUSCULE MATHÉMATIQUE GRASSE DELTA","	# <police> 0394 lettre majuscule grecque delta"},
/* 1D6AC */ { "MAJUSCULE MATHÉMATIQUE GRASSE EPSILON","	# <police> 0395 lettre majuscule grecque epsilon"},
/* 1D6AD */ { "MAJUSCULE MATHÉMATIQUE GRASSE DZÊTA","	# <police> 0396 lettre majuscule grecque dzêta"},
/* 1D6AE */ { "MAJUSCULE MATHÉMATIQUE GRASSE ÊTA","	# <police> 0397 lettre majuscule grecque êta"},
/* 1D6AF */ { "MAJUSCULE MATHÉMATIQUE GRASSE THÊTA","	# <police> 0398 lettre majuscule grecque thêta"},
/* 1D6B0 */ { "MAJUSCULE MATHÉMATIQUE GRASSE IOTA","	# <police> 0399 lettre majuscule grecque iota"},
/* 1D6B1 */ { "MAJUSCULE MATHÉMATIQUE GRASSE KAPPA","	# <police> 039A lettre majuscule grecque kappa"},
/* 1D6B2 */ { "MAJUSCULE MATHÉMATIQUE GRASSE LAMBDA","	# <police> 039B lettre majuscule grecque lambda"},
/* 1D6B3 */ { "MAJUSCULE MATHÉMATIQUE GRASSE MU","	# <police> 039C lettre majuscule grecque mu"},
/* 1D6B4 */ { "MAJUSCULE MATHÉMATIQUE GRASSE NU","	# <police> 039D lettre majuscule grecque nu"},
/* 1D6B5 */ { "MAJUSCULE MATHÉMATIQUE GRASSE XI","	# <police> 039E lettre majuscule grecque xi"},
/* 1D6B6 */ { "MAJUSCULE MATHÉMATIQUE GRASSE OMICRON","	# <police> 039F lettre majuscule grecque omicron"},
/* 1D6B7 */ { "MAJUSCULE MATHÉMATIQUE GRASSE PI","	# <police> 03A0 lettre majuscule grecque pi"},
/* 1D6B8 */ { "MAJUSCULE MATHÉMATIQUE GRASSE RHÔ","	# <police> 03A1 lettre majuscule grecque rhô"},
/* 1D6B9 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SYMBOLE THÊTA","	# <police> 03F4 symbole grec thêta majuscule"},
/* 1D6BA */ { "MAJUSCULE MATHÉMATIQUE GRASSE SIGMA","	# <police> 03A3 lettre majuscule grecque sigma"},
/* 1D6BB */ { "MAJUSCULE MATHÉMATIQUE GRASSE TAU","	# <police> 03A4 lettre majuscule grecque tau"},
/* 1D6BC */ { "MAJUSCULE MATHÉMATIQUE GRASSE UPSILON","	# <police> 03A5 lettre majuscule grecque upsilon"},
/* 1D6BD */ { "MAJUSCULE MATHÉMATIQUE GRASSE PHI","	# <police> 03A6 lettre majuscule grecque phi"},
/* 1D6BE */ { "MAJUSCULE MATHÉMATIQUE GRASSE KHI","	# <police> 03A7 lettre majuscule grecque khi"},
/* 1D6BF */ { "MAJUSCULE MATHÉMATIQUE GRASSE PSI","	# <police> 03A8 lettre majuscule grecque psi"},
/* 1D6C0 */ { "MAJUSCULE MATHÉMATIQUE GRASSE OMÉGA","	# <police> 03A9 lettre majuscule grecque oméga"},
/* 1D6C1 */ { "SYMBOLE MATHÉMATIQUE GRAS NABLA","	# <police> 2207 nabla"},
/* 1D6C2 */ { "MINUSCULE MATHÉMATIQUE GRASSE ALPHA","	# <police> 03B1 lettre minuscule grecque alpha"},
/* 1D6C3 */ { "MINUSCULE MATHÉMATIQUE GRASSE BÊTA","	# <police> 03B2 lettre minuscule grecque bêta"},
/* 1D6C4 */ { "MINUSCULE MATHÉMATIQUE GRASSE GAMMA","	# <police> 03B3 lettre minuscule grecque gamma"},
/* 1D6C5 */ { "MINUSCULE MATHÉMATIQUE GRASSE DELTA","	# <police> 03B4 lettre minuscule grecque delta"},
/* 1D6C6 */ { "MINUSCULE MATHÉMATIQUE GRASSE EPSILON","	# <police> 03B5 lettre minuscule grecque epsilon"},
/* 1D6C7 */ { "MINUSCULE MATHÉMATIQUE GRASSE DZÊTA","	# <police> 03B6 lettre minuscule grecque dzêta"},
/* 1D6C8 */ { "MINUSCULE MATHÉMATIQUE GRASSE ÊTA","	# <police> 03B7 lettre minuscule grecque êta"},
/* 1D6C9 */ { "MINUSCULE MATHÉMATIQUE GRASSE THÊTA","	# <police> 03B8 lettre minuscule grecque thêta"},
/* 1D6CA */ { "MINUSCULE MATHÉMATIQUE GRASSE IOTA","	# <police> 03B9 lettre minuscule grecque iota"},
/* 1D6CB */ { "MINUSCULE MATHÉMATIQUE GRASSE KAPPA","	# <police> 03BA lettre minuscule grecque kappa"},
/* 1D6CC */ { "MINUSCULE MATHÉMATIQUE GRASSE LAMBDA","	# <police> 03BB lettre minuscule grecque lambda"},
/* 1D6CD */ { "MINUSCULE MATHÉMATIQUE GRASSE MU","	# <police> 03BC lettre minuscule grecque mu"},
/* 1D6CE */ { "MINUSCULE MATHÉMATIQUE GRASSE NU","	# <police> 03BD lettre minuscule grecque nu"},
/* 1D6CF */ { "MINUSCULE MATHÉMATIQUE GRASSE XI","	# <police> 03BE lettre minuscule grecque xi"},
/* 1D6D0 */ { "MINUSCULE MATHÉMATIQUE GRASSE OMICRON","	# <police> 03BF lettre minuscule grecque omicron"},
/* 1D6D1 */ { "MINUSCULE MATHÉMATIQUE GRASSE PI","	# <police> 03C0 lettre minuscule grecque pi"},
/* 1D6D2 */ { "MINUSCULE MATHÉMATIQUE GRASSE RHÔ","	# <police> 03C1 lettre minuscule grecque rhô"},
/* 1D6D3 */ { "MINUSCULE MATHÉMATIQUE GRASSE SIGMA FINAL","	# <police> 03C2 lettre minuscule grecque sigma final"},
/* 1D6D4 */ { "MINUSCULE MATHÉMATIQUE GRASSE SIGMA","	# <police> 03C3 lettre minuscule grecque sigma"},
/* 1D6D5 */ { "MINUSCULE MATHÉMATIQUE GRASSE TAU","	# <police> 03C4 lettre minuscule grecque tau"},
/* 1D6D6 */ { "MINUSCULE MATHÉMATIQUE GRASSE UPSILON","	# <police> 03C5 lettre minuscule grecque upsilon"},
/* 1D6D7 */ { "MINUSCULE MATHÉMATIQUE GRASSE PHI","	# <police> 03C6 lettre minuscule grecque phi"},
/* 1D6D8 */ { "MINUSCULE MATHÉMATIQUE GRASSE KHI","	# <police> 03C7 lettre minuscule grecque khi"},
/* 1D6D9 */ { "MINUSCULE MATHÉMATIQUE GRASSE PSI","	# <police> 03C8 lettre minuscule grecque psi"},
/* 1D6DA */ { "MINUSCULE MATHÉMATIQUE GRASSE OMÉGA","	# <police> 03C9 lettre minuscule grecque oméga"},
/* 1D6DB */ { "SYMBOLE MATHÉMATIQUE GRAS DÉRIVÉE PARTIELLE","	# <police> 2202 dérivée partielle"},
/* 1D6DC */ { "SYMBOLE MATHÉMATIQUE GRAS EPSILON","	# <police> 03F5 symbole grec epsilon lunaire"},
/* 1D6DD */ { "SYMBOLE MATHÉMATIQUE GRAS THÊTA","	# <police> 03D1 symbole grec thêta"},
/* 1D6DE */ { "SYMBOLE MATHÉMATIQUE GRAS KAPPA","	# <police> 03F0 symbole grec kappa"},
/* 1D6DF */ { "SYMBOLE MATHÉMATIQUE GRAS PHI","	# <police> 03D5 symbole grec phi"},
/* 1D6E0 */ { "SYMBOLE MATHÉMATIQUE GRAS RHÔ","	# <police> 03F1 symbole grec rhô"},
/* 1D6E1 */ { "SYMBOLE MATHÉMATIQUE GRAS PI DORIQUE","	# <police> 03D6 symbole grec pi"},
/* 1D6E2 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE ALPHA","	# <police> 0391 lettre majuscule grecque alpha"},
/* 1D6E3 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE BÊTA","	# <police> 0392 lettre majuscule grecque bêta"},
/* 1D6E4 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GAMMA","	# <police> 0393 lettre majuscule grecque gamma"},
/* 1D6E5 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE DELTA","	# <police> 0394 lettre majuscule grecque delta"},
/* 1D6E6 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE EPSILON","	# <police> 0395 lettre majuscule grecque epsilon"},
/* 1D6E7 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE DZÊTA","	# <police> 0396 lettre majuscule grecque dzêta"},
/* 1D6E8 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE ÊTA","	# <police> 0397 lettre majuscule grecque êta"},
/* 1D6E9 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE THÊTA","	# <police> 0398 lettre majuscule grecque thêta"},
/* 1D6EA */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE IOTA","	# <police> 0399 lettre majuscule grecque iota"},
/* 1D6EB */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE KAPPA","	# <police> 039A lettre majuscule grecque kappa"},
/* 1D6EC */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE LAMBDA","	# <police> 039B lettre majuscule grecque lambda"},
/* 1D6ED */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE MU","	# <police> 039C lettre majuscule grecque mu"},
/* 1D6EE */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE NU","	# <police> 039D lettre majuscule grecque nu"},
/* 1D6EF */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE XI","	# <police> 039E lettre majuscule grecque xi"},
/* 1D6F0 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE OMICRON","	# <police> 039F lettre majuscule grecque omicron"},
/* 1D6F1 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE PI","	# <police> 03A0 lettre majuscule grecque pi"},
/* 1D6F2 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE RHÔ","	# <police> 03A1 lettre majuscule grecque rhô"},
/* 1D6F3 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SYMBOLE THÊTA","	# <police> 03F4 symbole grec thêta majuscule"},
/* 1D6F4 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE SIGMA","	# <police> 03A3 lettre majuscule grecque sigma"},
/* 1D6F5 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE TAU","	# <police> 03A4 lettre majuscule grecque tau"},
/* 1D6F6 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE UPSILON","	# <police> 03A5 lettre majuscule grecque upsilon"},
/* 1D6F7 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE PHI","	# <police> 03A6 lettre majuscule grecque phi"},
/* 1D6F8 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE KHI","	# <police> 03A7 lettre majuscule grecque khi"},
/* 1D6F9 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE PSI","	# <police> 03A8 lettre majuscule grecque psi"},
/* 1D6FA */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE OMÉGA","	# <police> 03A9 lettre majuscule grecque oméga"},
/* 1D6FB */ { "SYMBOLE MATHÉMATIQUE ITALIQUE NABLA","	# <police> 2207 nabla"},
/* 1D6FC */ { "MINUSCULE MATHÉMATIQUE ITALIQUE ALPHA","	# <police> 03B1 lettre minuscule grecque alpha"},
/* 1D6FD */ { "MINUSCULE MATHÉMATIQUE ITALIQUE BÊTA","	# <police> 03B2 lettre minuscule grecque bêta"},
/* 1D6FE */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GAMMA","	# <police> 03B3 lettre minuscule grecque gamma"},
/* 1D6FF */ { "MINUSCULE MATHÉMATIQUE ITALIQUE DELTA","	# <police> 03B4 lettre minuscule grecque delta"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D7[] = {
/* 1D700 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE EPSILON","	# <police> 03B5 lettre minuscule grecque epsilon"},
/* 1D701 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE DZÊTA","	# <police> 03B6 lettre minuscule grecque dzêta"},
/* 1D702 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE ÊTA","	# <police> 03B7 lettre minuscule grecque êta"},
/* 1D703 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE THÊTA","	# <police> 03B8 lettre minuscule grecque thêta"},
/* 1D704 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE IOTA","	# <police> 03B9 lettre minuscule grecque iota"},
/* 1D705 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE KAPPA","	# <police> 03BA lettre minuscule grecque kappa"},
/* 1D706 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE LAMBDA","	# <police> 03BB lettre minuscule grecque lambda"},
/* 1D707 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE MU","	# <police> 03BC lettre minuscule grecque mu"},
/* 1D708 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE NU","	# <police> 03BD lettre minuscule grecque nu"},
/* 1D709 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE XI","	# <police> 03BE lettre minuscule grecque xi"},
/* 1D70A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE OMICRON","	# <police> 03BF lettre minuscule grecque omicron"},
/* 1D70B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE PI","	# <police> 03C0 lettre minuscule grecque pi"},
/* 1D70C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE RHÔ","	# <police> 03C1 lettre minuscule grecque rhô"},
/* 1D70D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SIGMA FINAL","	# <police> 03C2 lettre minuscule grecque sigma final"},
/* 1D70E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE SIGMA","	# <police> 03C3 lettre minuscule grecque sigma"},
/* 1D70F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE TAU","	# <police> 03C4 lettre minuscule grecque tau"},
/* 1D710 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE UPSILON","	# <police> 03C5 lettre minuscule grecque upsilon"},
/* 1D711 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE PHI","	# <police> 03C6 lettre minuscule grecque phi"},
/* 1D712 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE KHI","	# <police> 03C7 lettre minuscule grecque khi"},
/* 1D713 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE PSI","	# <police> 03C8 lettre minuscule grecque psi"},
/* 1D714 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE OMÉGA","	# <police> 03C9 lettre minuscule grecque oméga"},
/* 1D715 */ { "SYMBOLE MATHÉMATIQUE ITALIQUE DÉRIVÉE PARTIELLE","	# <police> 2202 dérivée partielle"},
/* 1D716 */ { "SYMBOLE MATHÉMATIQUE ITALIQUE EPSILON","	# <police> 03F5 symbole grec epsilon lunaire"},
/* 1D717 */ { "SYMBOLE MATHÉMATIQUE ITALIQUE THÊTA","	# <police> 03D1 symbole grec thêta"},
/* 1D718 */ { "SYMBOLE MATHÉMATIQUE ITALIQUE KAPPA","	# <police> 03F0 symbole grec kappa"},
/* 1D719 */ { "SYMBOLE MATHÉMATIQUE ITALIQUE PHI","	# <police> 03D5 symbole grec phi"},
/* 1D71A */ { "SYMBOLE MATHÉMATIQUE ITALIQUE RHÔ","	# <police> 03F1 symbole grec rhô"},
/* 1D71B */ { "SYMBOLE MATHÉMATIQUE ITALIQUE PI DORIQUE","	# <police> 03D6 symbole grec pi"},
/* 1D71C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE ALPHA","	# <police> 0391 lettre majuscule grecque alpha"},
/* 1D71D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE BÊTA","	# <police> 0392 lettre majuscule grecque bêta"},
/* 1D71E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE GAMMA","	# <police> 0393 lettre majuscule grecque gamma"},
/* 1D71F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE DELTA","	# <police> 0394 lettre majuscule grecque delta"},
/* 1D720 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE EPSILON","	# <police> 0395 lettre majuscule grecque epsilon"},
/* 1D721 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE DZÊTA","	# <police> 0396 lettre majuscule grecque dzêta"},
/* 1D722 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE ÊTA","	# <police> 0397 lettre majuscule grecque êta"},
/* 1D723 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE THÊTA","	# <police> 0398 lettre majuscule grecque thêta"},
/* 1D724 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE IOTA","	# <police> 0399 lettre majuscule grecque iota"},
/* 1D725 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE KAPPA","	# <police> 039A lettre majuscule grecque kappa"},
/* 1D726 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE LAMBDA","	# <police> 039B lettre majuscule grecque lambda"},
/* 1D727 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE MU","	# <police> 039C lettre majuscule grecque mu"},
/* 1D728 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE NU","	# <police> 039D lettre majuscule grecque nu"},
/* 1D729 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE XI","	# <police> 039E lettre majuscule grecque xi"},
/* 1D72A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE OMICRON","	# <police> 039F lettre majuscule grecque omicron"},
/* 1D72B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE PI","	# <police> 03A0 lettre majuscule grecque pi"},
/* 1D72C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE RHÔ","	# <police> 03A1 lettre majuscule grecque rhô"},
/* 1D72D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SYMBOLE THÊTA","	# <police> 03F4 symbole grec thêta majuscule"},
/* 1D72E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SIGMA","	# <police> 03A3 lettre majuscule grecque sigma"},
/* 1D72F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE TAU","	# <police> 03A4 lettre majuscule grecque tau"},
/* 1D730 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE UPSILON","	# <police> 03A5 lettre majuscule grecque upsilon"},
/* 1D731 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE PHI","	# <police> 03A6 lettre majuscule grecque phi"},
/* 1D732 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE KHI","	# <police> 03A7 lettre majuscule grecque khi"},
/* 1D733 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE PSI","	# <police> 03A8 lettre majuscule grecque psi"},
/* 1D734 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE OMÉGA","	# <police> 03A9 lettre majuscule grecque oméga"},
/* 1D735 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE NABLA","	# <police> 2207 nabla"},
/* 1D736 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE ALPHA","	# <police> 03B1 lettre minuscule grecque alpha"},
/* 1D737 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE BÊTA","	# <police> 03B2 lettre minuscule grecque bêta"},
/* 1D738 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE GAMMA","	# <police> 03B3 lettre minuscule grecque gamma"},
/* 1D739 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE DELTA","	# <police> 03B4 lettre minuscule grecque delta"},
/* 1D73A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE EPSILON","	# <police> 03B5 lettre minuscule grecque epsilon"},
/* 1D73B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE DZÊTA","	# <police> 03B6 lettre minuscule grecque dzêta"},
/* 1D73C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE ÊTA","	# <police> 03B7 lettre minuscule grecque êta"},
/* 1D73D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE THÊTA","	# <police> 03B8 lettre minuscule grecque thêta"},
/* 1D73E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE IOTA","	# <police> 03B9 lettre minuscule grecque iota"},
/* 1D73F */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE KAPPA","	# <police> 03BA lettre minuscule grecque kappa"},
/* 1D740 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE LAMBDA","	# <police> 03BB lettre minuscule grecque lambda"},
/* 1D741 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE MU","	# <police> 03BC lettre minuscule grecque mu"},
/* 1D742 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE NU","	# <police> 03BD lettre minuscule grecque nu"},
/* 1D743 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE XI","	# <police> 03BE lettre minuscule grecque xi"},
/* 1D744 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE OMICRON","	# <police> 03BF lettre minuscule grecque omicron"},
/* 1D745 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE PI","	# <police> 03C0 lettre minuscule grecque pi"},
/* 1D746 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE RHÔ","	# <police> 03C1 lettre minuscule grecque rhô"},
/* 1D747 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SIGMA FINAL","	# <police> 03C2 lettre minuscule grecque sigma final"},
/* 1D748 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SIGMA","	# <police> 03C3 lettre minuscule grecque sigma"},
/* 1D749 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE TAU","	# <police> 03C4 lettre minuscule grecque tau"},
/* 1D74A */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE UPSILON","	# <police> 03C5 lettre minuscule grecque upsilon"},
/* 1D74B */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE PHI","	# <police> 03C6 lettre minuscule grecque phi"},
/* 1D74C */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE KHI","	# <police> 03C7 lettre minuscule grecque khi"},
/* 1D74D */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE PSI","	# <police> 03C8 lettre minuscule grecque psi"},
/* 1D74E */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE OMÉGA","	# <police> 03C9 lettre minuscule grecque oméga"},
/* 1D74F */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE DÉRIVÉE PARTIELLE","	# <police> 2202 dérivée partielle"},
/* 1D750 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE EPSILON","	# <police> 03F5 symbole grec epsilon lunaire"},
/* 1D751 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE THÊTA","	# <police> 03D1 symbole grec thêta"},
/* 1D752 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE KAPPA","	# <police> 03F0 symbole grec kappa"},
/* 1D753 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE PHI","	# <police> 03D5 symbole grec phi"},
/* 1D754 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE RHÔ","	# <police> 03F1 symbole grec rhô"},
/* 1D755 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE PI DORIQUE","	# <police> 03D6 symbole grec pi"},
/* 1D756 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT ALPHA","	# <police> 0391 lettre majuscule grecque alpha"},
/* 1D757 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT BÊTA","	# <police> 0392 lettre majuscule grecque bêta"},
/* 1D758 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT GAMMA","	# <police> 0393 lettre majuscule grecque gamma"},
/* 1D759 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT DELTA","	# <police> 0394 lettre majuscule grecque delta"},
/* 1D75A */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT EPSILON","	# <police> 0395 lettre majuscule grecque epsilon"},
/* 1D75B */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT DZÊTA","	# <police> 0396 lettre majuscule grecque dzêta"},
/* 1D75C */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT ÊTA","	# <police> 0397 lettre majuscule grecque êta"},
/* 1D75D */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT THÊTA","	# <police> 0398 lettre majuscule grecque thêta"},
/* 1D75E */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT IOTA","	# <police> 0399 lettre majuscule grecque iota"},
/* 1D75F */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT KAPPA","	# <police> 039A lettre majuscule grecque kappa"},
/* 1D760 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT LAMBDA","	# <police> 039B lettre majuscule grecque lambda"},
/* 1D761 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT MU","	# <police> 039C lettre majuscule grecque mu"},
/* 1D762 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT NU","	# <police> 039D lettre majuscule grecque nu"},
/* 1D763 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT XI","	# <police> 039E lettre majuscule grecque xi"},
/* 1D764 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT OMICRON","	# <police> 039F lettre majuscule grecque omicron"},
/* 1D765 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT PI","	# <police> 03A0 lettre majuscule grecque pi"},
/* 1D766 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT RHÔ","	# <police> 03A1 lettre majuscule grecque rhô"},
/* 1D767 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT SYMBOLE THÊTA","	# <police> 03F4 symbole grec thêta majuscule"},
/* 1D768 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT SIGMA","	# <police> 03A3 lettre majuscule grecque sigma"},
/* 1D769 */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT TAU","	# <police> 03A4 lettre majuscule grecque tau"},
/* 1D76A */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT UPSILON","	# <police> 03A5 lettre majuscule grecque upsilon"},
/* 1D76B */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT PHI","	# <police> 03A6 lettre majuscule grecque phi"},
/* 1D76C */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT KHI","	# <police> 03A7 lettre majuscule grecque khi"},
/* 1D76D */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT PSI","	# <police> 03A8 lettre majuscule grecque psi"},
/* 1D76E */ { "MAJUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT OMÉGA","	# <police> 03A9 lettre majuscule grecque oméga"},
/* 1D76F */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT NABLA","	# <police> 2207 nabla"},
/* 1D770 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT ALPHA","	# <police> 03B1 lettre minuscule grecque alpha"},
/* 1D771 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT BÊTA","	# <police> 03B2 lettre minuscule grecque bêta"},
/* 1D772 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT GAMMA","	# <police> 03B3 lettre minuscule grecque gamma"},
/* 1D773 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT DELTA","	# <police> 03B4 lettre minuscule grecque delta"},
/* 1D774 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT EPSILON","	# <police> 03B5 lettre minuscule grecque epsilon"},
/* 1D775 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT DZÊTA","	# <police> 03B6 lettre minuscule grecque dzêta"},
/* 1D776 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT ÊTA","	# <police> 03B7 lettre minuscule grecque êta"},
/* 1D777 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT THÊTA","	# <police> 03B8 lettre minuscule grecque thêta"},
/* 1D778 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT IOTA","	# <police> 03B9 lettre minuscule grecque iota"},
/* 1D779 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT KAPPA","	# <police> 03BA lettre minuscule grecque kappa"},
/* 1D77A */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT LAMBDA","	# <police> 03BB lettre minuscule grecque lambda"},
/* 1D77B */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT MU","	# <police> 03BC lettre minuscule grecque mu"},
/* 1D77C */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT NU","	# <police> 03BD lettre minuscule grecque nu"},
/* 1D77D */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT XI","	# <police> 03BE lettre minuscule grecque xi"},
/* 1D77E */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT OMICRON","	# <police> 03BF lettre minuscule grecque omicron"},
/* 1D77F */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT PI","	# <police> 03C0 lettre minuscule grecque pi"},
/* 1D780 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT RHÔ","	# <police> 03C1 lettre minuscule grecque rhô"},
/* 1D781 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT SIGMA FINAL","	# <police> 03C2 lettre minuscule grecque sigma final"},
/* 1D782 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT SIGMA","	# <police> 03C3 lettre minuscule grecque sigma"},
/* 1D783 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT TAU","	# <police> 03C4 lettre minuscule grecque tau"},
/* 1D784 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT UPSILON","	# <police> 03C5 lettre minuscule grecque upsilon"},
/* 1D785 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT PHI","	# <police> 03C6 lettre minuscule grecque phi"},
/* 1D786 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT KHI","	# <police> 03C7 lettre minuscule grecque khi"},
/* 1D787 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT PSI","	# <police> 03C8 lettre minuscule grecque psi"},
/* 1D788 */ { "MINUSCULE MATHÉMATIQUE GRASSE SANS EMPATTEMENT OMÉGA","	# <police> 03C9 lettre minuscule grecque oméga"},
/* 1D789 */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT DÉRIVÉE PARTIELLE","	# <police> 2202 dérivée partielle"},
/* 1D78A */ { "EPSILON MATHÉMATIQUE GRAS SANS EMPATTEMENT","	# <police> 03F5 symbole grec epsilon lunaire"},
/* 1D78B */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT THÊTA","	# <police> 03D1 symbole grec thêta"},
/* 1D78C */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT KAPPA","	# <police> 03F0 symbole grec kappa"},
/* 1D78D */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT PHI","	# <police> 03D5 symbole grec phi"},
/* 1D78E */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT RHÔ","	# <police> 03F1 symbole grec rhô"},
/* 1D78F */ { "SYMBOLE MATHÉMATIQUE GRAS SANS EMPATTEMENT PI DORIQUE","	# <police> 03D6 symbole grec pi"},
/* 1D790 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT ALPHA","	# <police> 0391 lettre majuscule grecque alpha"},
/* 1D791 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT BÊTA","	# <police> 0392 lettre majuscule grecque bêta"},
/* 1D792 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT GAMMA","	# <police> 0393 lettre majuscule grecque gamma"},
/* 1D793 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT DELTA","	# <police> 0394 lettre majuscule grecque delta"},
/* 1D794 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT EPSILON","	# <police> 0395 lettre majuscule grecque epsilon"},
/* 1D795 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT DZÊTA","	# <police> 0396 lettre majuscule grecque dzêta"},
/* 1D796 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT ÊTA","	# <police> 0397 lettre majuscule grecque êta"},
/* 1D797 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT THÊTA","	# <police> 0398 lettre majuscule grecque thêta"},
/* 1D798 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT IOTA","	# <police> 0399 lettre majuscule grecque iota"},
/* 1D799 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT KAPPA","	# <police> 039A lettre majuscule grecque kappa"},
/* 1D79A */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT LAMBDA","	# <police> 039B lettre majuscule grecque lambda"},
/* 1D79B */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT MU","	# <police> 039C lettre majuscule grecque mu"},
/* 1D79C */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT NU","	# <police> 039D lettre majuscule grecque nu"},
/* 1D79D */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT XI","	# <police> 039E lettre majuscule grecque xi"},
/* 1D79E */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT OMICRON","	# <police> 039F lettre majuscule grecque omicron"},
/* 1D79F */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT PI","	# <police> 03A0 lettre majuscule grecque pi"},
/* 1D7A0 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT RHÔ","	# <police> 03A1 lettre majuscule grecque rhô"},
/* 1D7A1 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT SYMBOLE THÊTA","	# <police> 03F4 symbole grec thêta majuscule"},
/* 1D7A2 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT SIGMA","	# <police> 03A3 lettre majuscule grecque sigma"},
/* 1D7A3 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT TAU","	# <police> 03A4 lettre majuscule grecque tau"},
/* 1D7A4 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT UPSILON","	# <police> 03A5 lettre majuscule grecque upsilon"},
/* 1D7A5 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT PHI","	# <police> 03A6 lettre majuscule grecque phi"},
/* 1D7A6 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT KHI","	# <police> 03A7 lettre majuscule grecque khi"},
/* 1D7A7 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT PSI","	# <police> 03A8 lettre majuscule grecque psi"},
/* 1D7A8 */ { "MAJUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT OMÉGA","	# <police> 03A9 lettre majuscule grecque oméga"},
/* 1D7A9 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT NABLA","	# <police> 2207 nabla"},
/* 1D7AA */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT ALPHA","	# <police> 03B1 lettre minuscule grecque alpha"},
/* 1D7AB */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT BÊTA","	# <police> 03B2 lettre minuscule grecque bêta"},
/* 1D7AC */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT GAMMA","	# <police> 03B3 lettre minuscule grecque gamma"},
/* 1D7AD */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT DELTA","	# <police> 03B4 lettre minuscule grecque delta"},
/* 1D7AE */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT EPSILON","	# <police> 03B5 lettre minuscule grecque epsilon"},
/* 1D7AF */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT DZÊTA","	# <police> 03B6 lettre minuscule grecque dzêta"},
/* 1D7B0 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT ÊTA","	# <police> 03B7 lettre minuscule grecque êta"},
/* 1D7B1 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT THÊTA","	# <police> 03B8 lettre minuscule grecque thêta"},
/* 1D7B2 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT IOTA","	# <police> 03B9 lettre minuscule grecque iota"},
/* 1D7B3 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT KAPPA","	# <police> 03BA lettre minuscule grecque kappa"},
/* 1D7B4 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT LAMBDA","	# <police> 03BB lettre minuscule grecque lambda"},
/* 1D7B5 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT MU","	# <police> 03BC lettre minuscule grecque mu"},
/* 1D7B6 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT NU","	# <police> 03BD lettre minuscule grecque nu"},
/* 1D7B7 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT XI","	# <police> 03BE lettre minuscule grecque xi"},
/* 1D7B8 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT OMICRON","	# <police> 03BF lettre minuscule grecque omicron"},
/* 1D7B9 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT PI","	# <police> 03C0 lettre minuscule grecque pi"},
/* 1D7BA */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT RHÔ","	# <police> 03C1 lettre minuscule grecque rhô"},
/* 1D7BB */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT SIGMA FINAL","	# <police> 03C2 lettre minuscule grecque sigma final"},
/* 1D7BC */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT SIGMA","	# <police> 03C3 lettre minuscule grecque sigma"},
/* 1D7BD */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT TAU","	# <police> 03C4 lettre minuscule grecque tau"},
/* 1D7BE */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT UPSILON","	# <police> 03C5 lettre minuscule grecque upsilon"},
/* 1D7BF */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT PHI","	# <police> 03C6 lettre minuscule grecque phi"},
/* 1D7C0 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT KHI","	# <police> 03C7 lettre minuscule grecque khi"},
/* 1D7C1 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT PSI","	# <police> 03C8 lettre minuscule grecque psi"},
/* 1D7C2 */ { "MINUSCULE MATHÉMATIQUE ITALIQUE GRASSE SANS EMPATTEMENT OMÉGA","	# <police> 03C9 lettre minuscule grecque oméga"},
/* 1D7C3 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT DÉRIVÉE PARTIELLE","	# <police> 2202 dérivée partielle"},
/* 1D7C4 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT EPSILON","	# <police> 03F5 symbole grec epsilon lunaire"},
/* 1D7C5 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT THÊTA","	# <police> 03D1 symbole grec thêta"},
/* 1D7C6 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT KAPPA","	# <police> 03F0 symbole grec kappa"},
/* 1D7C7 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT PHI","	# <police> 03D5 symbole grec phi"},
/* 1D7C8 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT RHÔ","	# <police> 03F1 symbole grec rhô"},
/* 1D7C9 */ { "SYMBOLE MATHÉMATIQUE GRAS ITALIQUE SANS EMPATTEMENT PI DORIQUE","	# <police> 03D6 symbole grec pi"},
/* 1D7CA */ { "MAJUSCULE MATHÉMATIQUE GRASSE DIGAMMA","	# <police> 03DC lettre grecque digamma"},
/* 1D7CB */ { "MINUSCULE MATHÉMATIQUE GRASSE DIGAMMA","	# <police> 03DD lettre minuscule grecque digamma"},
/* 1D7CC */ { NULL,NULL},
/* 1D7CD */ { NULL,NULL},
/* 1D7CE */ { "CHIFFRE MATHÉMATIQUE GRAS ZÉRO","	# <police> 0030 chiffre zéro"},
/* 1D7CF */ { "CHIFFRE MATHÉMATIQUE GRAS UN","	# <police> 0031 chiffre un"},
/* 1D7D0 */ { "CHIFFRE MATHÉMATIQUE GRAS DEUX","	# <police> 0032 chiffre deux"},
/* 1D7D1 */ { "CHIFFRE MATHÉMATIQUE GRAS TROIS","	# <police> 0033 chiffre trois"},
/* 1D7D2 */ { "CHIFFRE MATHÉMATIQUE GRAS QUATRE","	# <police> 0034 chiffre quatre"},
/* 1D7D3 */ { "CHIFFRE MATHÉMATIQUE GRAS CINQ","	# <police> 0035 chiffre cinq"},
/* 1D7D4 */ { "CHIFFRE MATHÉMATIQUE GRAS SIX","	# <police> 0036 chiffre six"},
/* 1D7D5 */ { "CHIFFRE MATHÉMATIQUE GRAS SEPT","	# <police> 0037 chiffre sept"},
/* 1D7D6 */ { "CHIFFRE MATHÉMATIQUE GRAS HUIT","	# <police> 0038 chiffre huit"},
/* 1D7D7 */ { "CHIFFRE MATHÉMATIQUE GRAS NEUF","	# <police> 0039 chiffre neuf"},
/* 1D7D8 */ { "CHIFFRE MATHÉMATIQUE AJOURÉ ZÉRO","	# <police> 0030 chiffre zéro"},
/* 1D7D9 */ { "CHIFFRE MATHÉMATIQUE AJOURÉ UN","	# <police> 0031 chiffre un"},
/* 1D7DA */ { "CHIFFRE MATHÉMATIQUE AJOURÉ DEUX","	# <police> 0032 chiffre deux"},
/* 1D7DB */ { "CHIFFRE MATHÉMATIQUE AJOURÉ TROIS","	# <police> 0033 chiffre trois"},
/* 1D7DC */ { "CHIFFRE MATHÉMATIQUE AJOURÉ QUATRE","	# <police> 0034 chiffre quatre"},
/* 1D7DD */ { "CHIFFRE MATHÉMATIQUE AJOURÉ CINQ","	# <police> 0035 chiffre cinq"},
/* 1D7DE */ { "CHIFFRE MATHÉMATIQUE AJOURÉ SIX","	# <police> 0036 chiffre six"},
/* 1D7DF */ { "CHIFFRE MATHÉMATIQUE AJOURÉ SEPT","	# <police> 0037 chiffre sept"},
/* 1D7E0 */ { "CHIFFRE MATHÉMATIQUE AJOURÉ HUIT","	# <police> 0038 chiffre huit"},
/* 1D7E1 */ { "CHIFFRE MATHÉMATIQUE AJOURÉ NEUF","	# <police> 0039 chiffre neuf"},
/* 1D7E2 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT ZÉRO","	# <police> 0030 chiffre zéro"},
/* 1D7E3 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT UN","	# <police> 0031 chiffre un"},
/* 1D7E4 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT DEUX","	# <police> 0032 chiffre deux"},
/* 1D7E5 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT TROIS","	# <police> 0033 chiffre trois"},
/* 1D7E6 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT QUATRE","	# <police> 0034 chiffre quatre"},
/* 1D7E7 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT CINQ","	# <police> 0035 chiffre cinq"},
/* 1D7E8 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT SIX","	# <police> 0036 chiffre six"},
/* 1D7E9 */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT SEPT","	# <police> 0037 chiffre sept"},
/* 1D7EA */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT HUIT","	# <police> 0038 chiffre huit"},
/* 1D7EB */ { "CHIFFRE MATHÉMATIQUE SANS EMPATTEMENT NEUF","	# <police> 0039 chiffre neuf"},
/* 1D7EC */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT ZÉRO","	# <police> 0030 chiffre zéro"},
/* 1D7ED */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT UN","	# <police> 0031 chiffre un"},
/* 1D7EE */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT DEUX","	# <police> 0032 chiffre deux"},
/* 1D7EF */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT TROIS","	# <police> 0033 chiffre trois"},
/* 1D7F0 */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT QUATRE","	# <police> 0034 chiffre quatre"},
/* 1D7F1 */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT CINQ","	# <police> 0035 chiffre cinq"},
/* 1D7F2 */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT SIX","	# <police> 0036 chiffre six"},
/* 1D7F3 */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT SEPT","	# <police> 0037 chiffre sept"},
/* 1D7F4 */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT HUIT","	# <police> 0038 chiffre huit"},
/* 1D7F5 */ { "CHIFFRE MATHÉMATIQUE GRAS SANS EMPATTEMENT NEUF","	# <police> 0039 chiffre neuf"},
/* 1D7F6 */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE ZÉRO","	# <police> 0030 chiffre zéro"},
/* 1D7F7 */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE UN","	# <police> 0031 chiffre un"},
/* 1D7F8 */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE DEUX","	# <police> 0032 chiffre deux"},
/* 1D7F9 */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE TROIS","	# <police> 0033 chiffre trois"},
/* 1D7FA */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE QUATRE","	# <police> 0034 chiffre quatre"},
/* 1D7FB */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE CINQ","	# <police> 0035 chiffre cinq"},
/* 1D7FC */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE SIX","	# <police> 0036 chiffre six"},
/* 1D7FD */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE SEPT","	# <police> 0037 chiffre sept"},
/* 1D7FE */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE HUIT","	# <police> 0038 chiffre huit"},
/* 1D7FF */ { "CHIFFRE MATHÉMATIQUE À CHASSE FIXE NEUF","	# <police> 0039 chiffre neuf"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D8[] = {
/* 1D800 */ { "SIGNWRITING MAIN-POING INDEX",NULL},
/* 1D801 */ { "SIGNWRITING MAIN-CERCLE INDEX",NULL},
/* 1D802 */ { "SIGNWRITING MAIN-COUPE INDEX",NULL},
/* 1D803 */ { "SIGNWRITING MAIN-OVALE INDEX",NULL},
/* 1D804 */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX",NULL},
/* 1D805 */ { "SIGNWRITING MAIN-ANGLE INDEX",NULL},
/* 1D806 */ { "SIGNWRITING MAIN-POING INDEX COUDÉ",NULL},
/* 1D807 */ { "SIGNWRITING MAIN-CERCLE INDEX COUDÉ",NULL},
/* 1D808 */ { "SIGNWRITING MAIN-POING POUCE DESSOUS INDEX COUDÉ",NULL},
/* 1D809 */ { "SIGNWRITING MAIN-POING INDEX JOINTURE EN SAILLIE",NULL},
/* 1D80A */ { "SIGNWRITING MAIN-POING INDEX EN COUPE",NULL},
/* 1D80B */ { "SIGNWRITING MAIN-POING INDEX EN CHARNIÈRE",NULL},
/* 1D80C */ { "SIGNWRITING MAIN-POING INDEX EN CHARNIÈRE FAIBLE",NULL},
/* 1D80D */ { "SIGNWRITING MAIN-CERCLE INDEX EN CHARNIÈRE",NULL},
/* 1D80E */ { "SIGNWRITING MAIN-POING INDEX MAJEUR",NULL},
/* 1D80F */ { "SIGNWRITING MAIN-CERCLE INDEX MAJEUR",NULL},
/* 1D810 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR COUDÉS",NULL},
/* 1D811 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR JOINTURES EN SAILLIE",NULL},
/* 1D812 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR EN CHARNIÈRE",NULL},
/* 1D813 */ { "SIGNWRITING MAIN-POING INDEX EN HAUT MAJEUR EN CHARNIÈRE",NULL},
/* 1D814 */ { "SIGNWRITING MAIN-POING INDEX EN CHARNIÈRE MAJEUR EN HAUT",NULL},
/* 1D815 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS",NULL},
/* 1D816 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS INDEX COUDÉ",NULL},
/* 1D817 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS MAJEUR COUDÉ",NULL},
/* 1D818 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS EN COUPE",NULL},
/* 1D819 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS EN CHARNIÈRE",NULL},
/* 1D81A */ { "SIGNWRITING MAIN-POING INDEX MAJEUR CROISÉS",NULL},
/* 1D81B */ { "SIGNWRITING MAIN-CERCLE INDEX MAJEUR CROISÉS",NULL},
/* 1D81C */ { "SIGNWRITING MAIN-POING MAJEUR COUDÉ SUR INDEX",NULL},
/* 1D81D */ { "SIGNWRITING MAIN-POING INDEX SUR MAJEUR",NULL},
/* 1D81E */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE",NULL},
/* 1D81F */ { "SIGNWRITING MAIN-CERCLE INDEX MAJEUR POUCE",NULL},
/* 1D820 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR DROITS POUCE COUDÉ",NULL},
/* 1D821 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR COUDÉS POUCE DROIT",NULL},
/* 1D822 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE COUDÉS",NULL},
/* 1D823 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR EN CHARNIÈRE ÉCARTÉS POUCE CÔTÉ",NULL},
/* 1D824 */ { "SIGNWRITING MAIN-POING INDEX EN HAUT MAJEUR EN CHARNIÈRE POUCE CÔTÉ",NULL},
/* 1D825 */ { "SIGNWRITING MAIN-POING INDEX EN HAUT MAJEUR EN CHARNIÈRE POUCE LIÉ",NULL},
/* 1D826 */ { "SIGNWRITING MAIN-POING INDEX EN CHARNIÈRE MAJEUR EN HAUT POUCE CÔTÉ",NULL},
/* 1D827 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR EN HAUT ÉCARTÉS POUCE EN AVANT",NULL},
/* 1D828 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE EN COUPE",NULL},
/* 1D829 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE EN CERCLE",NULL},
/* 1D82A */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE EN ARC",NULL},
/* 1D82B */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE EN CHARNIÈRE",NULL},
/* 1D82C */ { "SIGNWRITING MAIN-POING POUCE ENTRE INDEX MAJEUR DROITS",NULL},
/* 1D82D */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS POUCE CÔTÉ",NULL},
/* 1D82E */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS POUCE CÔTÉ LIÉ",NULL},
/* 1D82F */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS POUCE CÔTÉ COUDÉ",NULL},
/* 1D830 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN ARC INDEX EN HAUT",NULL},
/* 1D831 */ { "SIGNWRITING MAIN-POING INDEX POUCE EN ARC MAJEUR EN HAUT",NULL},
/* 1D832 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS EN CHARNIÈRE POUCE CÔTÉ",NULL},
/* 1D833 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR CROISÉS POUCE CÔTÉ",NULL},
/* 1D834 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS POUCE EN AVANT",NULL},
/* 1D835 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR LIÉS EN COUPE POUCE EN AVANT",NULL},
/* 1D836 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN COUPE INDEX EN HAUT",NULL},
/* 1D837 */ { "SIGNWRITING MAIN-POING INDEX POUCE EN COUPE MAJEUR EN HAUT",NULL},
/* 1D838 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN CERCLE INDEX EN HAUT",NULL},
/* 1D839 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN CERCLE INDEX EN CHARNIÈRE",NULL},
/* 1D83A */ { "SIGNWRITING MAIN-POING INDEX POUCE EN ANGLE DEHORS MAJEUR EN HAUT",NULL},
/* 1D83B */ { "SIGNWRITING MAIN-POING INDEX POUCE EN ANGLE DEDANS MAJEUR EN HAUT",NULL},
/* 1D83C */ { "SIGNWRITING MAIN-POING INDEX POUCE EN CERCLE MAJEUR EN HAUT",NULL},
/* 1D83D */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE LIÉS EN CHARNIÈRE",NULL},
/* 1D83E */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE EN ANGLE DEHORS",NULL},
/* 1D83F */ { "SIGNWRITING MAIN-POING INDEX MAJEUR POUCE EN ANGLE",NULL},
/* 1D840 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN ANGLE DEHORS INDEX EN HAUT",NULL},
/* 1D841 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN ANGLE DEHORS INDEX CROISÉ",NULL},
/* 1D842 */ { "SIGNWRITING MAIN-POING MAJEUR POUCE EN ANGLE INDEX EN HAUT",NULL},
/* 1D843 */ { "SIGNWRITING MAIN-POING INDEX POUCE EN ARC MAJEUR EN CHARNIÈRE",NULL},
/* 1D844 */ { "SIGNWRITING MAIN-PLAT QUATRE DOIGTS",NULL},
/* 1D845 */ { "SIGNWRITING MAIN-PLAT QUATRE DOIGTS COUDÉS",NULL},
/* 1D846 */ { "SIGNWRITING MAIN-PLAT QUATRE DOIGTS EN CHARNIÈRE",NULL},
/* 1D847 */ { "SIGNWRITING MAIN-PLAT QUATRE DOIGTS LIÉS",NULL},
/* 1D848 */ { "SIGNWRITING MAIN-PLAT QUATRE DOIGTS LIÉS FENTE",NULL},
/* 1D849 */ { "SIGNWRITING MAIN-GRIFFE QUATRE DOIGTS LIÉS",NULL},
/* 1D84A */ { "SIGNWRITING MAIN-POING QUATRE DOIGTS LIÉS COUDÉS",NULL},
/* 1D84B */ { "SIGNWRITING MAIN-CHARNIÈRE QUATRE DOIGTS LIÉS",NULL},
/* 1D84C */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS",NULL},
/* 1D84D */ { "SIGNWRITING MAIN-PLAT TALON CINQ DOIGTS ÉCARTÉS",NULL},
/* 1D84E */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS QUATRE COUDÉS",NULL},
/* 1D84F */ { "SIGNWRITING MAIN-PLAT TALON CINQ DOIGTS ÉCARTÉS QUATRE COUDÉS",NULL},
/* 1D850 */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS COUDÉS",NULL},
/* 1D851 */ { "SIGNWRITING MAIN-PLAT TALON CINQ DOIGTS ÉCARTÉS COUDÉS",NULL},
/* 1D852 */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS POUCE EN AVANT",NULL},
/* 1D853 */ { "SIGNWRITING MAIN-COUPE CINQ DOIGTS ÉCARTÉS",NULL},
/* 1D854 */ { "SIGNWRITING MAIN-COUPE CINQ DOIGTS ÉCARTÉS OUVERTE",NULL},
/* 1D855 */ { "SIGNWRITING MAIN-CHARNIÈRE CINQ DOIGTS ÉCARTÉS OUVERTE",NULL},
/* 1D856 */ { "SIGNWRITING MAIN-OVALE CINQ DOIGTS ÉCARTÉS",NULL},
/* 1D857 */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS EN CHARNIÈRE",NULL},
/* 1D858 */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS EN CHARNIÈRE POUCE CÔTÉ",NULL},
/* 1D859 */ { "SIGNWRITING MAIN-PLAT CINQ DOIGTS ÉCARTÉS EN CHARNIÈRE SANS POUCE",NULL},
/* 1D85A */ { "SIGNWRITING MAIN-PLAT",NULL},
/* 1D85B */ { "SIGNWRITING MAIN-PLAT ORIENTATIONS INTERMÉDIAIRES DE LA PAUME",NULL},
/* 1D85C */ { "SIGNWRITING MAIN-PLAT TALON",NULL},
/* 1D85D */ { "SIGNWRITING MAIN-PLAT POUCE CÔTÉ",NULL},
/* 1D85E */ { "SIGNWRITING MAIN-PLAT TALON POUCE CÔTÉ",NULL},
/* 1D85F */ { "SIGNWRITING MAIN-PLAT POUCE COUDÉ",NULL},
/* 1D860 */ { "SIGNWRITING MAIN-PLAT POUCE EN AVANT",NULL},
/* 1D861 */ { "SIGNWRITING MAIN-PLAT FENTE INDEX POUCE CÔTÉ",NULL},
/* 1D862 */ { "SIGNWRITING MAIN-PLAT FENTE CENTRE",NULL},
/* 1D863 */ { "SIGNWRITING MAIN-PLAT FENTE CENTRE POUCE CÔTÉ",NULL},
/* 1D864 */ { "SIGNWRITING MAIN-PLAT FENTE CENTRE POUCE CÔTÉ COUDÉ",NULL},
/* 1D865 */ { "SIGNWRITING MAIN-PLAT FENTE AURICULAIRE",NULL},
/* 1D866 */ { "SIGNWRITING MAIN-GRIFFE",NULL},
/* 1D867 */ { "SIGNWRITING MAIN-GRIFFE POUCE CÔTÉ",NULL},
/* 1D868 */ { "SIGNWRITING MAIN-GRIFFE SANS POUCE",NULL},
/* 1D869 */ { "SIGNWRITING MAIN-GRIFFE POURCE EN AVANT",NULL},
/* 1D86A */ { "SIGNWRITING MAIN-ARC TORSADE",NULL},
/* 1D86B */ { "SIGNWRITING MAIN-ARC",NULL},
/* 1D86C */ { "SIGNWRITING MAIN-COUPE OUVERTE",NULL},
/* 1D86D */ { "SIGNWRITING MAIN-COUPE",NULL},
/* 1D86E */ { "SIGNWRITING MAIN-COUPE OUVERTE POUCE CÔTÉ",NULL},
/* 1D86F */ { "SIGNWRITING MAIN-COUPE POUCE CÔTÉ",NULL},
/* 1D870 */ { "SIGNWRITING MAIN-COUPE OUVERTE SANS POUCE",NULL},
/* 1D871 */ { "SIGNWRITING MAIN-COUPE SANS POUCE",NULL},
/* 1D872 */ { "SIGNWRITING MAIN-COUPE OUVERTE POUCE EN AVANT",NULL},
/* 1D873 */ { "SIGNWRITING MAIN-COUPE POUCE EN AVANT",NULL},
/* 1D874 */ { "SIGNWRITING MAIN-TORSADE OUVERTE",NULL},
/* 1D875 */ { "SIGNWRITING MAIN-TORSADE",NULL},
/* 1D876 */ { "SIGNWRITING MAIN-CERCLE",NULL},
/* 1D877 */ { "SIGNWRITING MAIN-OVALE",NULL},
/* 1D878 */ { "SIGNWRITING MAIN-OVALE POUCE CÔTÉ",NULL},
/* 1D879 */ { "SIGNWRITING MAIN-OVALE SANS POUCE",NULL},
/* 1D87A */ { "SIGNWRITING MAIN-OVALE POUCE EN AVANT",NULL},
/* 1D87B */ { "SIGNWRITING MAIN-CHARNIÈRE OUVERTE",NULL},
/* 1D87C */ { "SIGNWRITING MAIN-CHARNIÈRE OUVERTE POUCE EN AVANT",NULL},
/* 1D87D */ { "SIGNWRITING MAIN-CHARNIÈRE",NULL},
/* 1D87E */ { "SIGNWRITING MAIN-CHARNIÈRE PETITE",NULL},
/* 1D87F */ { "SIGNWRITING MAIN-CHARNIÈRE OUVERTE POUCE CÔTÉ",NULL},
/* 1D880 */ { "SIGNWRITING MAIN-CHARNIÈRE POUCE CÔTÉ",NULL},
/* 1D881 */ { "SIGNWRITING MAIN-CHARNIÈRE OUVERTE SANS POUCE",NULL},
/* 1D882 */ { "SIGNWRITING MAIN-CHARNIÈRE SANS POUCE",NULL},
/* 1D883 */ { "SIGNWRITING MAIN-CHARNIÈRE POUCE CÔTÉ TOUCHANT INDEX",NULL},
/* 1D884 */ { "SIGNWRITING MAIN-CHARNIÈRE POUCE ENTRE MAJEUR ANNULAIRE",NULL},
/* 1D885 */ { "SIGNWRITING MAIN-ANGLE",NULL},
/* 1D886 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR ANNULAIRE",NULL},
/* 1D887 */ { "SIGNWRITING MAIN-CERCLE INDEX MAJEUR ANNULAIRE",NULL},
/* 1D888 */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX MAJEUR ANNULAIRE",NULL},
/* 1D889 */ { "SIGNWRITING MAIN-ANGLE INDEX MAJEUR ANNULAIRE",NULL},
/* 1D88A */ { "SIGNWRITING MAIN-CHARNIÈRE AURICULAIRE",NULL},
/* 1D88B */ { "SIGNWRITING MAIN-POING INDEX MAJEUR ANNULAIRE COUDÉS",NULL},
/* 1D88C */ { "SIGNWRITING MAIN-POING INDEX MAJEUR ANNULAIRE LIÉS",NULL},
/* 1D88D */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX MAJEUR ANNULAIRE LIÉS",NULL},
/* 1D88E */ { "SIGNWRITING MAIN-POING AURICULAIRE EN BAS",NULL},
/* 1D88F */ { "SIGNWRITING MAIN-POING AURICULAIRE EN BAS ONDULATION DROITE",NULL},
/* 1D890 */ { "SIGNWRITING MAIN-POING AURICULAIRE EN BAS ONDULATION INCURVÉE",NULL},
/* 1D891 */ { "SIGNWRITING MAIN-POING AURICULAIRE EN BAS AUTRES EN CERCLE",NULL},
/* 1D892 */ { "SIGNWRITING MAIN-POING AURICULAIRE EN HAUT",NULL},
/* 1D893 */ { "SIGNWRITING MAIN-POING POUCE DESSOUS AURICULAIRE EN HAUT",NULL},
/* 1D894 */ { "SIGNWRITING MAIN-CERCLE AURICULAIRE EN HAUT",NULL},
/* 1D895 */ { "SIGNWRITING MAIN-OVALE AURICULAIRE EN HAUT",NULL},
/* 1D896 */ { "SIGNWRITING MAIN-ANGLE AURICULAIRE EN HAUT",NULL},
/* 1D897 */ { "SIGNWRITING MAIN-POING AURICULAIRE JOINTURE EN SAILLIE",NULL},
/* 1D898 */ { "SIGNWRITING MAIN-POING AURICULAIRE COUDÉ",NULL},
/* 1D899 */ { "SIGNWRITING MAIN-POING AURICULAIRE TOUCHE POUCE",NULL},
/* 1D89A */ { "SIGNWRITING MAIN-POING AURICULAIRE POUCE",NULL},
/* 1D89B */ { "SIGNWRITING MAIN-CHARNIÈRE AURICULAIRE POUCE",NULL},
/* 1D89C */ { "SIGNWRITING MAIN-POING AURICULAIRE INDEX POUCE",NULL},
/* 1D89D */ { "SIGNWRITING MAIN-CHARNIÈRE AURICULAIRE INDEX POUCE",NULL},
/* 1D89E */ { "SIGNWRITING MAIN-ANGLE AURICULAIRE INDEX POUCE INDEX POUCE DEHORS",NULL},
/* 1D89F */ { "SIGNWRITING MAIN-ANGLE AURICULAIRE INDEX POUCE INDEX POUCE",NULL},
/* 1D8A0 */ { "SIGNWRITING MAIN-POING AURICULAIRE INDEX",NULL},
/* 1D8A1 */ { "SIGNWRITING MAIN-CERCLE AURICULAIRE INDEX",NULL},
/* 1D8A2 */ { "SIGNWRITING MAIN-CHARNIÈRE AURICULAIRE INDEX",NULL},
/* 1D8A3 */ { "SIGNWRITING MAIN-ANGLE AURICULAIRE INDEX",NULL},
/* 1D8A4 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR AURICULAIRE",NULL},
/* 1D8A5 */ { "SIGNWRITING MAIN-CERCLE INDEX MAJEUR AURICULAIRE",NULL},
/* 1D8A6 */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX MAJEUR AURICULAIRE",NULL},
/* 1D8A7 */ { "SIGNWRITING MAIN-CHARNIÈRE ANNULAIRE",NULL},
/* 1D8A8 */ { "SIGNWRITING MAIN-ANGLE INDEX MAJEUR AURICULAIRE",NULL},
/* 1D8A9 */ { "SIGNWRITING MAIN-POING INDEX MAJEUR CROISÉS AURICULAIRE",NULL},
/* 1D8AA */ { "SIGNWRITING MAIN-CERCLE INDEX MAJEUR CROISÉS AURICULAIRE",NULL},
/* 1D8AB */ { "SIGNWRITING MAIN-POING ANNULAIRE EN BAS",NULL},
/* 1D8AC */ { "SIGNWRITING MAIN-CHARNIÈRE ANNULAIRE EN BAS INDEX POUCE ARC MAJEUR",NULL},
/* 1D8AD */ { "SIGNWRITING MAIN-ANGLE ANNULAIRE EN BAS MAJEUR POUCE INDEX CROISÉ",NULL},
/* 1D8AE */ { "SIGNWRITING MAIN-POING ANNULAIRE EN HAUT",NULL},
/* 1D8AF */ { "SIGNWRITING MAIN-POING ANNULAIRE JOINTURE EN SAILLIE",NULL},
/* 1D8B0 */ { "SIGNWRITING MAIN-POING ANNULAIRE AURICULAIRE",NULL},
/* 1D8B1 */ { "SIGNWRITING MAIN-CERCLE ANNULAIRE AURICULAIRE",NULL},
/* 1D8B2 */ { "SIGNWRITING MAIN-OVALE ANNULAIRE AURICULAIRE",NULL},
/* 1D8B3 */ { "SIGNWRITING MAIN-ANGLE ANNULAIRE AURICULAIRE",NULL},
/* 1D8B4 */ { "SIGNWRITING MAIN-POING ANNULAIRE MAJEUR",NULL},
/* 1D8B5 */ { "SIGNWRITING MAIN-POING ANNULAIRE MAJEUR LIÉS",NULL},
/* 1D8B6 */ { "SIGNWRITING MAIN-POING ANNULAIRE MAJEUR JOINTURES EN SAILLIE",NULL},
/* 1D8B7 */ { "SIGNWRITING MAIN-POING ANNULAIRE INDEX",NULL},
/* 1D8B8 */ { "SIGNWRITING MAIN-POING ANNULAIRE POUCE",NULL},
/* 1D8B9 */ { "SIGNWRITING MAIN-ARC ANNULAIRE POUCE",NULL},
/* 1D8BA */ { "SIGNWRITING MAIN-POING INDEX ANNULAIRE AURICULAIRE",NULL},
/* 1D8BB */ { "SIGNWRITING MAIN-CERCLE INDEX ANNULAIRE AURICULAIRE",NULL},
/* 1D8BC */ { "SIGNWRITING MAIN-TORSADE INDEX ANNULAIRE AURICULAIRE DESSUS",NULL},
/* 1D8BD */ { "SIGNWRITING MAIN-ARC INDEX ANNULAIRE AURICULAIRE DEHORS",NULL},
/* 1D8BE */ { "SIGNWRITING MAIN-ARC INDEX ANNULAIRE AURICULAIRE DEDANS",NULL},
/* 1D8BF */ { "SIGNWRITING MAIN-ARC INDEX ANNULAIRE AURICULAIRE DESSOUS",NULL},
/* 1D8C0 */ { "SIGNWRITING MAIN-COUPE INDEX ANNULAIRE AURICULAIRE",NULL},
/* 1D8C1 */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX ANNULAIRE AURICULAIRE",NULL},
/* 1D8C2 */ { "SIGNWRITING MAIN-ANGLE INDEX ANNULAIRE AURICULAIRE DEHORS",NULL},
/* 1D8C3 */ { "SIGNWRITING MAIN-ANGLE INDEX ANNULAIRE AURICULAIRE",NULL},
/* 1D8C4 */ { "SIGNWRITING MAIN-POING MAJEUR EN BAS",NULL},
/* 1D8C5 */ { "SIGNWRITING MAIN-CHARNIÈRE MAJEUR",NULL},
/* 1D8C6 */ { "SIGNWRITING MAIN-POING MAJEUR EN HAUT",NULL},
/* 1D8C7 */ { "SIGNWRITING MAIN-CERCLE MAJEUR EN HAUT",NULL},
/* 1D8C8 */ { "SIGNWRITING MAIN-POING MAJEUR JOINTURE EN SAILLIE",NULL},
/* 1D8C9 */ { "SIGNWRITING MAIN-POING MAJEUR EN HAUT POUCE CÔTÉ",NULL},
/* 1D8CA */ { "SIGNWRITING MAIN-ARC MAJEUR POUCE",NULL},
/* 1D8CB */ { "SIGNWRITING MAIN-POING MAJEUR POUCE AURICULAIRE",NULL},
/* 1D8CC */ { "SIGNWRITING MAIN-POING MAJEUR AURICULAIRE",NULL},
/* 1D8CD */ { "SIGNWRITING MAIN-POING MAJEUR ANNULAIRE AURICULAIRE",NULL},
/* 1D8CE */ { "SIGNWRITING MAIN-CERCLE MAJEUR ANNULAIRE AURICULAIRE",NULL},
/* 1D8CF */ { "SIGNWRITING MAIN-TORSADE MAJEUR ANNULAIRE AURICULAIRE DESSUS",NULL},
/* 1D8D0 */ { "SIGNWRITING MAIN-COUPE MAJEUR ANNULAIRE AURICULAIRE",NULL},
/* 1D8D1 */ { "SIGNWRITING MAIN-CHARNIÈRE MAJEUR ANNULAIRE AURICULAIRE",NULL},
/* 1D8D2 */ { "SIGNWRITING MAIN-ANGLE MAJEUR ANNULAIRE AURICULAIRE DEHORS",NULL},
/* 1D8D3 */ { "SIGNWRITING MAIN-ANGLE MAJEUR ANNULAIRE AURICULAIRE DEDANS",NULL},
/* 1D8D4 */ { "SIGNWRITING MAIN-ANGLE MAJEUR ANNULAIRE AURICULAIRE",NULL},
/* 1D8D5 */ { "SIGNWRITING MAIN-CERCLE MAJEUR ANNULAIRE AURICULAIRE COUDÉS",NULL},
/* 1D8D6 */ { "SIGNWRITING MAIN-GRIFFE MAJEUR ANNULAIRE AURICULAIRE LIÉS",NULL},
/* 1D8D7 */ { "SIGNWRITING MAIN-GRIFFE MAJEUR ANNULAIRE AURICULAIRE LIÉS CÔTÉ",NULL},
/* 1D8D8 */ { "SIGNWRITING MAIN-ARC MAJEUR ANNULAIRE AURICULAIRE LIÉS DEHORS",NULL},
/* 1D8D9 */ { "SIGNWRITING MAIN-ARC MAJEUR ANNULAIRE AURICULAIRE LIÉS DEDANS",NULL},
/* 1D8DA */ { "SIGNWRITING MAIN-ARC MAJEUR ANNULAIRE AURICULAIRE LIÉS",NULL},
/* 1D8DB */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX EN CHARNIÈRE",NULL},
/* 1D8DC */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ",NULL},
/* 1D8DD */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX POUCE CÔTÉ",NULL},
/* 1D8DE */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ POUCE EN DIAGONALE",NULL},
/* 1D8DF */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ POUCE LIÉ",NULL},
/* 1D8E0 */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ POUCE COUDÉ",NULL},
/* 1D8E1 */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ INDEX COUDÉ",NULL},
/* 1D8E2 */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ TOUS DEUX COUDÉS",NULL},
/* 1D8E3 */ { "SIGNWRITING MAIN-POING INDEX POUCE CÔTÉ INDEX EN CHARNIÈRE",NULL},
/* 1D8E4 */ { "SIGNWRITING MAIN-POING INDEX POUCE EN AVANT INDEX DROIT",NULL},
/* 1D8E5 */ { "SIGNWRITING MAIN-POING INDEX POUCE EN AVANT INDEX COUDÉ",NULL},
/* 1D8E6 */ { "SIGNWRITING MAIN-POING INDEX POUCE ARC",NULL},
/* 1D8E7 */ { "SIGNWRITING MAIN-POING INDEX POUCE TORSADE",NULL},
/* 1D8E8 */ { "SIGNWRITING MAIN-POING INDEX POUCE COURBE POUCE DEDANS",NULL},
/* 1D8E9 */ { "SIGNWRITING MAIN-GRIFFE INDEX POUCE COURBE POUCE DEDANS",NULL},
/* 1D8EA */ { "SIGNWRITING MAIN-POING INDEX POUCE COURBE POUCE DESSOUS",NULL},
/* 1D8EB */ { "SIGNWRITING MAIN-POING INDEX POUCE CERCLE",NULL},
/* 1D8EC */ { "SIGNWRITING MAIN-COUPE INDEX POUCE",NULL},
/* 1D8ED */ { "SIGNWRITING MAIN-COUPE INDEX POUCE OUVERTE",NULL},
/* 1D8EE */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX POUCE OUVERTE",NULL},
/* 1D8EF */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX POUCE GRANDE",NULL},
/* 1D8F0 */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX POUCE",NULL},
/* 1D8F1 */ { "SIGNWRITING MAIN-CHARNIÈRE INDEX POUCE PETITE",NULL},
/* 1D8F2 */ { "SIGNWRITING MAIN-ANGLE INDEX POUCE DEHORS",NULL},
/* 1D8F3 */ { "SIGNWRITING MAIN-ANGLE INDEX POUCE DEDANS",NULL},
/* 1D8F4 */ { "SIGNWRITING MAIN-ANGLE INDEX POUCE",NULL},
/* 1D8F5 */ { "SIGNWRITING MAIN-POING POUCE",NULL},
/* 1D8F6 */ { "SIGNWRITING MAIN-POING POUCE TALON",NULL},
/* 1D8F7 */ { "SIGNWRITING MAIN-POING POUCE CÔTÉ EN DIAGONALE",NULL},
/* 1D8F8 */ { "SIGNWRITING MAIN-POING POUCE CÔTÉ LIÉ",NULL},
/* 1D8F9 */ { "SIGNWRITING MAIN-POING POUCE CÔTÉ COUDÉ",NULL},
/* 1D8FA */ { "SIGNWRITING MAIN-POING POUCE EN AVANT",NULL},
/* 1D8FB */ { "SIGNWRITING MAIN-POING POUCE ENTRE INDEX MAJEUR",NULL},
/* 1D8FC */ { "SIGNWRITING MAIN-POING POUCE ENTRE MAJEUR AURICULAIRE",NULL},
/* 1D8FD */ { "SIGNWRITING MAIN-POING POUCE ENTRE ANNULAIRE AURICULAIRE",NULL},
/* 1D8FE */ { "SIGNWRITING MAIN-POING POUCE SOUS DEUX DOIGTS",NULL},
/* 1D8FF */ { "SIGNWRITING MAIN-POING POUCE SUR DEUX DOIGTS",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_D9[] = {
/* 1D900 */ { "SIGNWRITING MAIN-POING POUCE SOUS TROIS DOIGTS",NULL},
/* 1D901 */ { "SIGNWRITING MAIN-POING POUCE SOUS QUATRE DOIGTS",NULL},
/* 1D902 */ { "SIGNWRITING MAIN-POING POUCE SUR QUATRE JOINTURES EN SAILLIE",NULL},
/* 1D903 */ { "SIGNWRITING MAIN-POING",NULL},
/* 1D904 */ { "SIGNWRITING MAIN-POING TALON",NULL},
/* 1D905 */ { "SIGNWRITING TOUCHER SIMPLE",NULL},
/* 1D906 */ { "SIGNWRITING TOUCHER MULTIPLE",NULL},
/* 1D907 */ { "SIGNWRITING TOUCHER ENTRE-DEUX",NULL},
/* 1D908 */ { "SIGNWRITING SAISIR SIMPLE",NULL},
/* 1D909 */ { "SIGNWRITING SAISIR MULTIPLE",NULL},
/* 1D90A */ { "SIGNWRITING SAISIR ENTRE-DEUX",NULL},
/* 1D90B */ { "SIGNWRITING FRAPPER SIMPLE",NULL},
/* 1D90C */ { "SIGNWRITING FRAPPER MULTIPLE",NULL},
/* 1D90D */ { "SIGNWRITING FRAPPER ENTRE-DEUX",NULL},
/* 1D90E */ { "SIGNWRITING EFFLEURER SIMPLE",NULL},
/* 1D90F */ { "SIGNWRITING EFFLEURER MULTIPLE",NULL},
/* 1D910 */ { "SIGNWRITING EFFLEURER ENTRE-DEUX",NULL},
/* 1D911 */ { "SIGNWRITING FROTTER SIMPLE",NULL},
/* 1D912 */ { "SIGNWRITING FROTTER MULTIPLE",NULL},
/* 1D913 */ { "SIGNWRITING FROTTER ENTRE-DEUX",NULL},
/* 1D914 */ { "SIGNWRITING SYMBOLES DE SURFACE",NULL},
/* 1D915 */ { "SIGNWRITING SURFACE ENTRE-DEUX",NULL},
/* 1D916 */ { "SIGNWRITING REPLI GRAND SIMPLE",NULL},
/* 1D917 */ { "SIGNWRITING REPLI PETIT SIMPLE",NULL},
/* 1D918 */ { "SIGNWRITING REPLI GRAND MULTIPLE",NULL},
/* 1D919 */ { "SIGNWRITING REPLI PETIT MULTIPLE",NULL},
/* 1D91A */ { "SIGNWRITING REPLI SÉQUENTIEL",NULL},
/* 1D91B */ { "SIGNWRITING DÉTENTE GRANDE SIMPLE",NULL},
/* 1D91C */ { "SIGNWRITING DÉTENTE PETITE SIMPLE",NULL},
/* 1D91D */ { "SIGNWRITING DÉTENTE GRANDE MULTIPLE",NULL},
/* 1D91E */ { "SIGNWRITING DÉTENTE PETITE MULTIPLE",NULL},
/* 1D91F */ { "SIGNWRITING DÉTENTE SÉQUENTIELLE",NULL},
/* 1D920 */ { "SIGNWRITING REPLI DÉTENTE EN ALTERNANCE",NULL},
/* 1D921 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE HAUT BAS GRAND",NULL},
/* 1D922 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE HAUT BAS PETIT",NULL},
/* 1D923 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE HAUT SÉQUENTIEL",NULL},
/* 1D924 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE BAS SÉQUENTIEL",NULL},
/* 1D925 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE HAUT BAS ALTERNÉ GRAND",NULL},
/* 1D926 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE HAUT BAS ALTERNÉ PETIT",NULL},
/* 1D927 */ { "SIGNWRITING MOUVEMENT-CHARNIÈRE D'UN CÔTÉ À L'AUTRE CISEAUX",NULL},
/* 1D928 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CONTACT DU DOIGT",NULL},
/* 1D929 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CONTACT DU DOIGT",NULL},
/* 1D92A */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL SIMPLE RECTILIGNE PETIT",NULL},
/* 1D92B */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL SIMPLE RECTILIGNE MOYEN",NULL},
/* 1D92C */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL SIMPLE RECTILIGNE GRAND",NULL},
/* 1D92D */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL SIMPLE RECTILIGNE PLUS GRAND",NULL},
/* 1D92E */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL SIMPLE FLEXION DU POIGNET",NULL},
/* 1D92F */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL DOUBLE RECTILIGNE",NULL},
/* 1D930 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL DOUBLE FLEXION DU POIGNET",NULL},
/* 1D931 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL DOUBLE ALTERNÉ",NULL},
/* 1D932 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL DOUBLE FLEXION ALTERNÉE DU POIGNET",NULL},
/* 1D933 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CROISÉ",NULL},
/* 1D934 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL TRIPLE RECTILIGNE",NULL},
/* 1D935 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL TRIPLE FLEXION DU POIGNET",NULL},
/* 1D936 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL TRIPLE ALTERNÉ",NULL},
/* 1D937 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL TRIPLE FLEXION ALTERNÉE DU POIGNET",NULL},
/* 1D938 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COUDE PETIT",NULL},
/* 1D939 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COUDE MOYEN",NULL},
/* 1D93A */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COUDE GRAND",NULL},
/* 1D93B */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ANGLE PETIT",NULL},
/* 1D93C */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ANGLE MOYEN",NULL},
/* 1D93D */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ANGLE GRAND",NULL},
/* 1D93E */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ANGLE ROTATION",NULL},
/* 1D93F */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COCHE PETIT",NULL},
/* 1D940 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COCHE MOYEN",NULL},
/* 1D941 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COCHE GRAND",NULL},
/* 1D942 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOÎTE PETIT",NULL},
/* 1D943 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOÎTE MOYEN",NULL},
/* 1D944 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOÎTE GRAND",NULL},
/* 1D945 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ZIGZAG PETIT",NULL},
/* 1D946 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ZIGZAG MOYEN",NULL},
/* 1D947 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ZIGZAG GRAND",NULL},
/* 1D948 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL PICS PETIT",NULL},
/* 1D949 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL PICS MOYEN",NULL},
/* 1D94A */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL PICS GRAND",NULL},
/* 1D94B */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL ROTATION-PLAN VERTICAL SIMPLE",NULL},
/* 1D94C */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL ROTATION-PLAN VERTICAL DOUBLE",NULL},
/* 1D94D */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL ROTATION-PLAN VERTICAL ALTERNÉE",NULL},
/* 1D94E */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL ROTATION-PLAN HORIZONTAL SIMPLE",NULL},
/* 1D94F */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL ROTATION-PLAN HORIZONTAL DOUBLE",NULL},
/* 1D950 */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL ROTATION-PLAN HORIZONTAL ALTERNÉE",NULL},
/* 1D951 */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL SECOUÉ",NULL},
/* 1D952 */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL BRAS SPIRALE SIMPLE",NULL},
/* 1D953 */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL BRAS SPIRALE DOUBLE",NULL},
/* 1D954 */ { "SIGNWRITING DÉPLACEMENT-PLAN VERTICAL BRAS SPIRALE TRIPLE",NULL},
/* 1D955 */ { "SIGNWRITING MOUVEMENT-DIAGONALE AU LOIN PETIT",NULL},
/* 1D956 */ { "SIGNWRITING MOUVEMENT-DIAGONALE AU LOIN MOYEN",NULL},
/* 1D957 */ { "SIGNWRITING MOUVEMENT-DIAGONALE AU LOIN GRAND",NULL},
/* 1D958 */ { "SIGNWRITING MOUVEMENT-DIAGONALE AU LOIN PLUS GRAND",NULL},
/* 1D959 */ { "SIGNWRITING MOUVEMENT-DIAGONALE EN DIRECTION DE PETIT",NULL},
/* 1D95A */ { "SIGNWRITING MOUVEMENT-DIAGONALE EN DIRECTION DE MOYEN",NULL},
/* 1D95B */ { "SIGNWRITING MOUVEMENT-DIAGONALE EN DIRECTION DE GRAND",NULL},
/* 1D95C */ { "SIGNWRITING MOUVEMENT-DIAGONALE EN DIRECTION DE PLUS GRAND",NULL},
/* 1D95D */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX AU LOIN PETIT",NULL},
/* 1D95E */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX AU LOIN MOYEN",NULL},
/* 1D95F */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX AU LOIN GRAND",NULL},
/* 1D960 */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX AU LOIN PLUS GRAND",NULL},
/* 1D961 */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX EN DIRECTION DE PETIT",NULL},
/* 1D962 */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX EN DIRECTION DE MOYEN",NULL},
/* 1D963 */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX EN DIRECTION DE GRAND",NULL},
/* 1D964 */ { "SIGNWRITING MOUVEMENT-DIAGONALE ENTRE-DEUX EN DIRECTION DE PLUS GRAND",NULL},
/* 1D965 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL SIMPLE RECTILIGNE PETIT",NULL},
/* 1D966 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL SIMPLE RECTILIGNE MOYEN",NULL},
/* 1D967 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL SIMPLE RECTILIGNE GRAND",NULL},
/* 1D968 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL SIMPLE RECTILIGNE PLUS GRAND",NULL},
/* 1D969 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL SIMPLE FLEXION DU POIGNET",NULL},
/* 1D96A */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL DOUBLE RECTILIGNE",NULL},
/* 1D96B */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL DOUBLE FLEXION DU POIGNET",NULL},
/* 1D96C */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL DOUBLE ALTERNÉ",NULL},
/* 1D96D */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL DOUBLE FLEXION ALTERNÉE DU POIGNET",NULL},
/* 1D96E */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CROISÉ",NULL},
/* 1D96F */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL TRIPLE RECTILIGNE",NULL},
/* 1D970 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL TRIPLE FLEXION DU POIGNET",NULL},
/* 1D971 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL TRIPLE ALTERNÉ",NULL},
/* 1D972 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL TRIPLE FLEXION ALTERNÉE DU POIGNET",NULL},
/* 1D973 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COUDE",NULL},
/* 1D974 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ANGLE PETIT",NULL},
/* 1D975 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ANGLE MOYEN",NULL},
/* 1D976 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ANGLE GRAND",NULL},
/* 1D977 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COCHE",NULL},
/* 1D978 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOÎTE PETIT",NULL},
/* 1D979 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOÎTE MOYEN",NULL},
/* 1D97A */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOÎTE GRAND",NULL},
/* 1D97B */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ZIGZAG PETIT",NULL},
/* 1D97C */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ZIGZAG MOYEN",NULL},
/* 1D97D */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ZIGZAG GRAND",NULL},
/* 1D97E */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL PICS PETIT",NULL},
/* 1D97F */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL PICS MOYEN",NULL},
/* 1D980 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL PICS GRAND",NULL},
/* 1D981 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL ROTATION-PLAN HORIZONTAL SIMPLE",NULL},
/* 1D982 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL ROTATION-PLAN HORIZONTAL DOUBLE",NULL},
/* 1D983 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL ROTATION-PLAN HORIZONTAL ALTERNÉE",NULL},
/* 1D984 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL ROTATION-PLAN VERTICAL SIMPLE",NULL},
/* 1D985 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL ROTATION-PLAN VERTICAL DOUBLE",NULL},
/* 1D986 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL ROTATION-PLAN VERTICAL ALTERNÉE",NULL},
/* 1D987 */ { "SIGNWRITING DÉPLACEMENT-PLAN HORIZONTAL SECOUÉ",NULL},
/* 1D988 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE QUARTIER PETIT",NULL},
/* 1D989 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE QUARTIER MOYEN",NULL},
/* 1D98A */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE QUARTIER GRAND",NULL},
/* 1D98B */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE QUARTIER PLUS GRAND",NULL},
/* 1D98C */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE DEMI-CERCLE PETIT",NULL},
/* 1D98D */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE DEMI-CERCLE MOYEN",NULL},
/* 1D98E */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE DEMI-CERCLE GRAND",NULL},
/* 1D98F */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE DEMI-CERCLE PLUS GRAND",NULL},
/* 1D990 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE TROIS QUARTS DE CERCLE PETIT",NULL},
/* 1D991 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE TROIS QUARTS DE CERCLE MOYEN",NULL},
/* 1D992 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOSSE PETIT",NULL},
/* 1D993 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOSSE MOYEN",NULL},
/* 1D994 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOSSE GRAND",NULL},
/* 1D995 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOUCLE PETIT",NULL},
/* 1D996 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOUCLE MOYEN",NULL},
/* 1D997 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOUCLE GRAND",NULL},
/* 1D998 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOUCLE PETIT DOUBLE",NULL},
/* 1D999 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION COURBE DOUBLE PETIT",NULL},
/* 1D99A */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION COURBE DOUBLE MOYEN",NULL},
/* 1D99B */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION COURBE DOUBLE GRAND",NULL},
/* 1D99C */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION COURBE TRIPLE PETIT",NULL},
/* 1D99D */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION COURBE TRIPLE MOYEN",NULL},
/* 1D99E */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION COURBE TRIPLE GRAND",NULL},
/* 1D99F */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE PUIS RECTILIGNE",NULL},
/* 1D9A0 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CROIX INCURVÉE PETIT",NULL},
/* 1D9A1 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CROIX INCURVÉE MOYEN",NULL},
/* 1D9A2 */ { "SIGNWRITING ROTATION-PLAN VERTICAL SIMPLE",NULL},
/* 1D9A3 */ { "SIGNWRITING ROTATION-PLAN VERTICAL DOUBLE",NULL},
/* 1D9A4 */ { "SIGNWRITING ROTATION-PLAN VERTICAL ALTERNÉE",NULL},
/* 1D9A5 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL SECOUÉ",NULL},
/* 1D9A6 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE HEURTANT MUR FRONTAL",NULL},
/* 1D9A7 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOSSE HEURTANT MUR FRONTAL",NULL},
/* 1D9A8 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOUCLE HEURTANT MUR FRONTAL",NULL},
/* 1D9A9 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION HEURTANT MUR FRONTAL",NULL},
/* 1D9AA */ { "SIGNWRITING ROTATION-PLAN VERTICAL SIMPLE HEURTANT MUR FRONTAL",NULL},
/* 1D9AB */ { "SIGNWRITING ROTATION-PLAN VERTICAL DOUBLE HEURTANT MUR FRONTAL",NULL},
/* 1D9AC */ { "SIGNWRITING ROTATION-PLAN VERTICAL ALTERNÉE HEURTANT MUR FRONTAL",NULL},
/* 1D9AD */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL COURBE HEURTANT POITRINE",NULL},
/* 1D9AE */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOSSE HEURTANT POITRINE",NULL},
/* 1D9AF */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL BOUCLE HEURTANT POITRINE",NULL},
/* 1D9B0 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION HEURTANT POITRINE",NULL},
/* 1D9B1 */ { "SIGNWRITING ROTATION-PLAN VERTICAL SIMPLE HEURTANT POITRINE",NULL},
/* 1D9B2 */ { "SIGNWRITING ROTATION-PLAN VERTICAL DOUBLE HEURTANT POITRINE",NULL},
/* 1D9B3 */ { "SIGNWRITING ROTATION-PLAN VERTICAL ALTERNÉE HEURTANT POITRINE",NULL},
/* 1D9B4 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION PARCOURS DIAGONAL PETIT",NULL},
/* 1D9B5 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION PARCOURS DIAGONAL MOYEN",NULL},
/* 1D9B6 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL ONDULATION PARCOURS DIAGONAL GRAND",NULL},
/* 1D9B7 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE HEURTANT PLAFOND PETIT",NULL},
/* 1D9B8 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE HEURTANT PLAFOND GRAND",NULL},
/* 1D9B9 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT PLAFOND PETIT DOUBLE",NULL},
/* 1D9BA */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT PLAFOND GRAND DOUBLE",NULL},
/* 1D9BB */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT PLAFOND PETIT TRIPLE",NULL},
/* 1D9BC */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT PLAFOND GRAND TRIPLE",NULL},
/* 1D9BD */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT PLAFOND PETIT SIMPLE",NULL},
/* 1D9BE */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT PLAFOND GRAND SIMPLE",NULL},
/* 1D9BF */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT PLAFOND PETIT DOUBLE",NULL},
/* 1D9C0 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT PLAFOND GRAND DOUBLE",NULL},
/* 1D9C1 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION HEURTANT PLAFOND PETIT",NULL},
/* 1D9C2 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION HEURTANT PLAFOND GRAND",NULL},
/* 1D9C3 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL SIMPLE HEURTANT PLAFOND",NULL},
/* 1D9C4 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL DOUBLE HEURTANT PLAFOND",NULL},
/* 1D9C5 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL ALTERNÉE HEURTANT PLAFOND",NULL},
/* 1D9C6 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE HEURTANT SOL PETIT",NULL},
/* 1D9C7 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE HEURTANT SOL GRAND",NULL},
/* 1D9C8 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT SOL PETIT DOUBLE",NULL},
/* 1D9C9 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT SOL GRAND DOUBLE",NULL},
/* 1D9CA */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT SOL PETIT TRIPLE",NULL},
/* 1D9CB */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE HEURTANT SOL GRAND TRIPLE",NULL},
/* 1D9CC */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT SOL PETIT SIMPLE",NULL},
/* 1D9CD */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT SOL GRAND SIMPLE",NULL},
/* 1D9CE */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT SOL PETIT DOUBLE",NULL},
/* 1D9CF */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE HEURTANT SOL GRAND DOUBLE",NULL},
/* 1D9D0 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION HEURTANT SOL PETIT",NULL},
/* 1D9D1 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION HEURTANT SOL GRAND",NULL},
/* 1D9D2 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL SIMPLE HEURTANT SOL",NULL},
/* 1D9D3 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL DOUBLE HEURTANT SOL",NULL},
/* 1D9D4 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL ALTERNÉE HEURTANT SOL",NULL},
/* 1D9D5 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE PETIT",NULL},
/* 1D9D6 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE MOYEN",NULL},
/* 1D9D7 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE GRAND",NULL},
/* 1D9D8 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE PLUS GRAND",NULL},
/* 1D9D9 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL COURBE COMBINÉ",NULL},
/* 1D9DA */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOSSE PETIT",NULL},
/* 1D9DB */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL BOUCLE PETIT",NULL},
/* 1D9DC */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION SERPENT",NULL},
/* 1D9DD */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION PETIT",NULL},
/* 1D9DE */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL ONDULATION GRAND",NULL},
/* 1D9DF */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL SIMPLE",NULL},
/* 1D9E0 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL DOUBLE",NULL},
/* 1D9E1 */ { "SIGNWRITING ROTATION-PLAN HORIZONTAL ALTERNÉE",NULL},
/* 1D9E2 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL SECOUÉ PARALLÈLE",NULL},
/* 1D9E3 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLE DU BRAS PETIT SIMPLE",NULL},
/* 1D9E4 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLE DU BRAS MOYEN SIMPLE",NULL},
/* 1D9E5 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLE DU BRAS PETIT DOUBLE",NULL},
/* 1D9E6 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLE DU BRAS MOYEN DOUBLE",NULL},
/* 1D9E7 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU BRAS HEURTANT MUR PETIT SIMPLE",NULL},
/* 1D9E8 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU BRAS HEURTANT MUR MOYEN SIMPLE",NULL},
/* 1D9E9 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU BRAS HEURTANT MUR GRAND SIMPLE",NULL},
/* 1D9EA */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU BRAS HEURTANT MUR PETIT DOUBLE",NULL},
/* 1D9EB */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU BRAS HEURTANT MUR MOYEN DOUBLE",NULL},
/* 1D9EC */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU BRAS HEURTANT MUR GRAND DOUBLE",NULL},
/* 1D9ED */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLE DU POIGNET DEVANT SIMPLE",NULL},
/* 1D9EE */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLE DU POIGNET DEVANT DOUBLE",NULL},
/* 1D9EF */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU POIGNET HEURTANT MUR SIMPLE",NULL},
/* 1D9F0 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLE DU POIGNET HEURTANT MUR DOUBLE",NULL},
/* 1D9F1 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLES DES DOIGTS SIMPLE",NULL},
/* 1D9F2 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL CERCLES DES DOIGTS DOUBLE",NULL},
/* 1D9F3 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLES DES DOIGTS HEURTANT MUR SIMPLE",NULL},
/* 1D9F4 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL CERCLES DES DOIGTS HEURTANT MUR DOUBLE",NULL},
/* 1D9F5 */ { "SIGNWRITING DYNAMIQUE POINTE DE FLÈCHE PETITE",NULL},
/* 1D9F6 */ { "SIGNWRITING DYNAMIQUE POINTE DE FLÈCHE GRANDE",NULL},
/* 1D9F7 */ { "SIGNWRITING DYNAMIQUE RAPIDE",NULL},
/* 1D9F8 */ { "SIGNWRITING DYNAMIQUE LENT",NULL},
/* 1D9F9 */ { "SIGNWRITING DYNAMIQUE TENDU",NULL},
/* 1D9FA */ { "SIGNWRITING DYNAMIQUE DÉTENDU",NULL},
/* 1D9FB */ { "SIGNWRITING DYNAMIQUE SIMULTANÉ",NULL},
/* 1D9FC */ { "SIGNWRITING DYNAMIQUE SIMULTANÉ ALTERNANT",NULL},
/* 1D9FD */ { "SIGNWRITING DYNAMIQUE ALTERNANT NON SIMULTANÉ",NULL},
/* 1D9FE */ { "SIGNWRITING DYNAMIQUE GRADUEL",NULL},
/* 1D9FF */ { "SIGNWRITING TÊTE",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_DA[] = {
/* 1DA00 */ { "SIGNWRITING TÊTE BORD",NULL},
/* 1DA01 */ { "SIGNWRITING TÊTE MOUVEMENT-PLAN VERTICAL RECTILIGNE",NULL},
/* 1DA02 */ { "SIGNWRITING TÊTE MOUVEMENT-PLAN VERTICAL INCLINÉ",NULL},
/* 1DA03 */ { "SIGNWRITING TÊTE MOUVEMENT-PLAN HORIZONTAL RECTILIGNE",NULL},
/* 1DA04 */ { "SIGNWRITING TÊTE MOUVEMENT-PLAN VERTICAL INCURVÉ",NULL},
/* 1DA05 */ { "SIGNWRITING TÊTE MOUVEMENT-PLAN HORIZONTAL INCURVÉ",NULL},
/* 1DA06 */ { "SIGNWRITING TÊTE MOUVEMENT CERCLE",NULL},
/* 1DA07 */ { "SIGNWRITING DIRECTION DU VISAGE POSITION NEZ EN AVANT INCLINAISON",NULL},
/* 1DA08 */ { "SIGNWRITING DIRECTION DU VISAGE POSITION NEZ EN HAUT OU EN BAS",NULL},
/* 1DA09 */ { "SIGNWRITING DIRECTION DU VISAGE POSITION NEZ EN HAUT OU EN BAS INCLINAISON",NULL},
/* 1DA0A */ { "SIGNWRITING SOURCILS DROITS EN HAUT",NULL},
/* 1DA0B */ { "SIGNWRITING SOURCILS DROITS NEUTRES",NULL},
/* 1DA0C */ { "SIGNWRITING SOURCILS DROITS EN BAS",NULL},
/* 1DA0D */ { "SIGNWRITING SOURCILS RÊVEURS NEUTRES EN BAS",NULL},
/* 1DA0E */ { "SIGNWRITING SOURCILS RÊVEURS EN BAS NEUTRES",NULL},
/* 1DA0F */ { "SIGNWRITING SOURCILS RÊVEURS EN HAUT NEUTRES",NULL},
/* 1DA10 */ { "SIGNWRITING SOURCILS RÊVEURS NEUTRES EN HAUT",NULL},
/* 1DA11 */ { "SIGNWRITING FRONT NEUTRE",NULL},
/* 1DA12 */ { "SIGNWRITING FRONT CONTACT",NULL},
/* 1DA13 */ { "SIGNWRITING FRONT FROISSÉ",NULL},
/* 1DA14 */ { "SIGNWRITING YEUX OUVERTS",NULL},
/* 1DA15 */ { "SIGNWRITING YEUX PLISSÉS",NULL},
/* 1DA16 */ { "SIGNWRITING YEUX FERMÉS",NULL},
/* 1DA17 */ { "SIGNWRITING ŒIL BATTEMENT DE PAUPIÈRES SIMPLE",NULL},
/* 1DA18 */ { "SIGNWRITING ŒIL BATTEMENT DE PAUPIÈRES MULTIPLE",NULL},
/* 1DA19 */ { "SIGNWRITING YEUX À DEMI OUVERTS",NULL},
/* 1DA1A */ { "SIGNWRITING YEUX GRANDS OUVERTS",NULL},
/* 1DA1B */ { "SIGNWRITING YEUX À DEMI FERMÉS",NULL},
/* 1DA1C */ { "SIGNWRITING YEUX MOUVEMENT D'ÉLARGISSEMENT",NULL},
/* 1DA1D */ { "SIGNWRITING ŒIL CLIGNEMENT","	* clignement appuyé"},
/* 1DA1E */ { "SIGNWRITING CILS EN HAUT",NULL},
/* 1DA1F */ { "SIGNWRITING CILS EN BAS",NULL},
/* 1DA20 */ { "SIGNWRITING CILS BATTEMENT",NULL},
/* 1DA21 */ { "SIGNWRITING REGARD-PLAN VERTICAL RECTILIGNE",NULL},
/* 1DA22 */ { "SIGNWRITING REGARD-PLAN VERTICAL RECTILIGNE DOUBLE",NULL},
/* 1DA23 */ { "SIGNWRITING REGARD-PLAN VERTICAL RECTILIGNE ALTERNANT",NULL},
/* 1DA24 */ { "SIGNWRITING REGARD-PLAN HORIZONTAL RECTILIGNE",NULL},
/* 1DA25 */ { "SIGNWRITING REGARD-PLAN HORIZONTAL RECTILIGNE DOUBLE",NULL},
/* 1DA26 */ { "SIGNWRITING REGARD-PLAN HORIZONTAL RECTILIGNE ALTERNANT",NULL},
/* 1DA27 */ { "SIGNWRITING REGARD-PLAN VERTICAL COURBE",NULL},
/* 1DA28 */ { "SIGNWRITING REGARD-PLAN HORIZONTAL COURBE",NULL},
/* 1DA29 */ { "SIGNWRITING REGARD-PLAN VERTICAL TOURNOYANT",NULL},
/* 1DA2A */ { "SIGNWRITING JOUES GONFLÉES",NULL},
/* 1DA2B */ { "SIGNWRITING JOUES NEUTRES",NULL},
/* 1DA2C */ { "SIGNWRITING JOUES ASPIRÉES",NULL},
/* 1DA2D */ { "SIGNWRITING JOUES TENDUES HAUT",NULL},
/* 1DA2E */ { "SIGNWRITING JOUES TENDUES MILIEU",NULL},
/* 1DA2F */ { "SIGNWRITING JOUES TENDUES BAS",NULL},
/* 1DA30 */ { "SIGNWRITING OREILLES",NULL},
/* 1DA31 */ { "SIGNWRITING NEZ NEUTRE",NULL},
/* 1DA32 */ { "SIGNWRITING NEZ CONTACT",NULL},
/* 1DA33 */ { "SIGNWRITING NEZ PLISSEMENTS",NULL},
/* 1DA34 */ { "SIGNWRITING NEZ TORTILLEMENTS",NULL},
/* 1DA35 */ { "SIGNWRITING AIR EXPIRATION",NULL},
/* 1DA36 */ { "SIGNWRITING AIR ASPIRATION",NULL},
/* 1DA37 */ { "SIGNWRITING AIR EXPIRÉ PETITES ROTATIONS",NULL},
/* 1DA38 */ { "SIGNWRITING AIR ASPIRÉ PETITES ROTATIONS",NULL},
/* 1DA39 */ { "SIGNWRITING RESPIRATION INHALATION",NULL},
/* 1DA3A */ { "SIGNWRITING RESPIRATION EXHALATION",NULL},
/* 1DA3B */ { "SIGNWRITING BOUCHE FERMÉE NEUTRE",NULL},
/* 1DA3C */ { "SIGNWRITING BOUCHE FERMÉE EN AVANT",NULL},
/* 1DA3D */ { "SIGNWRITING BOUCHE FERMÉE CONTACT",NULL},
/* 1DA3E */ { "SIGNWRITING BOUCHE SOURIRE",NULL},
/* 1DA3F */ { "SIGNWRITING BOUCHE SOURIRE PLISSÉ",NULL},
/* 1DA40 */ { "SIGNWRITING BOUCHE SOURIRE OUVERT",NULL},
/* 1DA41 */ { "SIGNWRITING BOUCHE FRONCÉE",NULL},
/* 1DA42 */ { "SIGNWRITING BOUCHE FRONCÉE PLISSÉE",NULL},
/* 1DA43 */ { "SIGNWRITING BOUCHE FRONCÉE OUVERTE",NULL},
/* 1DA44 */ { "SIGNWRITING BOUCHE OUVERTE CERCLE",NULL},
/* 1DA45 */ { "SIGNWRITING BOUCHE OUVERTE EN AVANT",NULL},
/* 1DA46 */ { "SIGNWRITING BOUCHE OUVERTE PLISSÉE",NULL},
/* 1DA47 */ { "SIGNWRITING BOUCHE OUVERTE OVALE",NULL},
/* 1DA48 */ { "SIGNWRITING BOUCHE OUVERTE OVALE PLISSÉE",NULL},
/* 1DA49 */ { "SIGNWRITING BOUCHE OUVERTE OVALE BÂILLEMENT",NULL},
/* 1DA4A */ { "SIGNWRITING BOUCHE OUVERTE RECTANGLE",NULL},
/* 1DA4B */ { "SIGNWRITING BOUCHE OUVERTE RECTANGLE PLISSÉE",NULL},
/* 1DA4C */ { "SIGNWRITING BOUCHE OUVERTE RECTANGLE BÂILLEMENT",NULL},
/* 1DA4D */ { "SIGNWRITING BOUCHE BAISER",NULL},
/* 1DA4E */ { "SIGNWRITING BOUCHE BAISER EN AVANT",NULL},
/* 1DA4F */ { "SIGNWRITING BOUCHE BAISER PLISSÉ",NULL},
/* 1DA50 */ { "SIGNWRITING BOUCHE TENDUE",NULL},
/* 1DA51 */ { "SIGNWRITING BOUCHE TENDUE EN AVANT",NULL},
/* 1DA52 */ { "SIGNWRITING BOUCHE TENDUE ASPIRÉE",NULL},
/* 1DA53 */ { "SIGNWRITING LÈVRES PRESSÉES L'UNE CONTRE L'AUTRE",NULL},
/* 1DA54 */ { "SIGNWRITING LÈVRE INFÉRIEURE SUR LÈVRE SUPÉRIEURE",NULL},
/* 1DA55 */ { "SIGNWRITING LÈVRE SUPÉRIEURE SUR LÈVRE INFÉRIEURE",NULL},
/* 1DA56 */ { "SIGNWRITING BOUCHE COINS",NULL},
/* 1DA57 */ { "SIGNWRITING BOUCHE RIDES SIMPLES",NULL},
/* 1DA58 */ { "SIGNWRITING BOUCHE RIDES DOUBLES",NULL},
/* 1DA59 */ { "SIGNWRITING LANGUE POINTANT LOIN DEHORS",NULL},
/* 1DA5A */ { "SIGNWRITING LANGUE LÉCHANT LÈVRES",NULL},
/* 1DA5B */ { "SIGNWRITING LANGUE BOUT ENTRE LÈVRES",NULL},
/* 1DA5C */ { "SIGNWRITING LANGUE BOUT TOUCHANT INTÉRIEUR BOUCHE",NULL},
/* 1DA5D */ { "SIGNWRITING LANGUE DANS BOUCHE DÉTENDUE",NULL},
/* 1DA5E */ { "SIGNWRITING LANGUE BOUGE CONTRE JOUE",NULL},
/* 1DA5F */ { "SIGNWRITING LANGUE CENTRE POINTANT DEHORS",NULL},
/* 1DA60 */ { "SIGNWRITING LANGUE CENTRE DANS BOUCHE",NULL},
/* 1DA61 */ { "SIGNWRITING DENTS",NULL},
/* 1DA62 */ { "SIGNWRITING DENTS MOUVEMENT",NULL},
/* 1DA63 */ { "SIGNWRITING DENTS SUR LANGUE",NULL},
/* 1DA64 */ { "SIGNWRITING DENTS SUR LANGUE MOUVEMENT",NULL},
/* 1DA65 */ { "SIGNWRITING DENTS SUR LÈVRES",NULL},
/* 1DA66 */ { "SIGNWRITING DENTS SUR LÈVRES MOUVEMENT",NULL},
/* 1DA67 */ { "SIGNWRITING DENTS MORDENT LÈVRES",NULL},
/* 1DA68 */ { "SIGNWRITING MOUVEMENT-PLAN VERTICAL MÂCHOIRE",NULL},
/* 1DA69 */ { "SIGNWRITING MOUVEMENT-PLAN HORIZONTAL MÂCHOIRE",NULL},
/* 1DA6A */ { "SIGNWRITING COU",NULL},
/* 1DA6B */ { "SIGNWRITING CHEVEUX",NULL},
/* 1DA6C */ { "SIGNWRITING EXCITATION",NULL},
/* 1DA6D */ { "SIGNWRITING ÉPAULE HANCHE COLONNE VERTÉBRALE",NULL},
/* 1DA6E */ { "SIGNWRITING ÉPAULE HANCHE POSITIONS",NULL},
/* 1DA6F */ { "SIGNWRITING PLAN VERTICAL ÉPAULE HANCHE MOUVEMENT",NULL},
/* 1DA70 */ { "SIGNWRITING PLAN HORIZONTAL ÉPAULE HANCHE MOUVEMENT",NULL},
/* 1DA71 */ { "SIGNWRITING ÉPAULE INCLINAISON EN PARTANT DE LA TAILLE",NULL},
/* 1DA72 */ { "SIGNWRITING TORSE-PLAN HORIZONTAL ÉTIREMENT RECTILIGNE",NULL},
/* 1DA73 */ { "SIGNWRITING TORSE-PLAN HORIZONTAL COUDE INCURVÉ",NULL},
/* 1DA74 */ { "SIGNWRITING TORSE-PLAN VERTICAL TORSION",NULL},
/* 1DA75 */ { "SIGNWRITING HAUT DU CORPS INCLINAISON EN PARTANT DES ARTICULATIONS DE LA HANCHE",NULL},
/* 1DA76 */ { "SIGNWRITING MEMBRE COMBINAISON",NULL},
/* 1DA77 */ { "SIGNWRITING MEMBRE LONGUEUR-1",NULL},
/* 1DA78 */ { "SIGNWRITING MEMBRE LONGUEUR-2",NULL},
/* 1DA79 */ { "SIGNWRITING MEMBRE LONGUEUR-3",NULL},
/* 1DA7A */ { "SIGNWRITING MEMBRE LONGUEUR-4",NULL},
/* 1DA7B */ { "SIGNWRITING MEMBRE LONGUEUR-5",NULL},
/* 1DA7C */ { "SIGNWRITING MEMBRE LONGUEUR-6",NULL},
/* 1DA7D */ { "SIGNWRITING MEMBRE LONGUEUR-7",NULL},
/* 1DA7E */ { "SIGNWRITING DOIGT",NULL},
/* 1DA7F */ { "SIGNWRITING POSITIONNEMENT-PLAN VERTICAL ESPACE",NULL},
/* 1DA80 */ { "SIGNWRITING POSITIONNEMENT-PLAN HORIZONTAL ESPACE",NULL},
/* 1DA81 */ { "SIGNWRITING POSITIONNEMENT HAUTEUR",NULL},
/* 1DA82 */ { "SIGNWRITING POSITIONNEMENT LARGEUR",NULL},
/* 1DA83 */ { "SIGNWRITING POSITIONNEMENT PROFONDEUR",NULL},
/* 1DA84 */ { "SIGNWRITING POSITIONNEMENT TÊTE COU",NULL},
/* 1DA85 */ { "SIGNWRITING POSITIONNEMENT TORSE",NULL},
/* 1DA86 */ { "SIGNWRITING POSITIONNEMENT MEMBRES DOIGTS",NULL},
/* 1DA87 */ { "SIGNWRITING VIRGULE",NULL},
/* 1DA88 */ { "SIGNWRITING POINT",NULL},
/* 1DA89 */ { "SIGNWRITING POINT-VIRGULE",NULL},
/* 1DA8A */ { "SIGNWRITING DEUX-POINTS",NULL},
/* 1DA8B */ { "SIGNWRITING PARENTHÈSE","	* on ajoute 1DAA4 pour fermer la parenthèse"},
/* 1DA8C */ { NULL,NULL},
/* 1DA8D */ { NULL,NULL},
/* 1DA8E */ { NULL,NULL},
/* 1DA8F */ { NULL,NULL},
/* 1DA90 */ { NULL,NULL},
/* 1DA91 */ { NULL,NULL},
/* 1DA92 */ { NULL,NULL},
/* 1DA93 */ { NULL,NULL},
/* 1DA94 */ { NULL,NULL},
/* 1DA95 */ { NULL,NULL},
/* 1DA96 */ { NULL,NULL},
/* 1DA97 */ { NULL,NULL},
/* 1DA98 */ { NULL,NULL},
/* 1DA99 */ { NULL,NULL},
/* 1DA9A */ { NULL,NULL},
/* 1DA9B */ { "SIGNWRITING MODIFICATEUR DE REMPLISSAGE-2",NULL},
/* 1DA9C */ { "SIGNWRITING MODIFICATEUR DE REMPLISSAGE-3",NULL},
/* 1DA9D */ { "SIGNWRITING MODIFICATEUR DE REMPLISSAGE-4",NULL},
/* 1DA9E */ { "SIGNWRITING MODIFICATEUR DE REMPLISSAGE-5",NULL},
/* 1DA9F */ { "SIGNWRITING MODIFICATEUR DE REMPLISSAGE-6",NULL},
/* 1DAA0 */ { NULL,NULL},
/* 1DAA1 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-2",NULL},
/* 1DAA2 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-3",NULL},
/* 1DAA3 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-4",NULL},
/* 1DAA4 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-5",NULL},
/* 1DAA5 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-6",NULL},
/* 1DAA6 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-7",NULL},
/* 1DAA7 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-8",NULL},
/* 1DAA8 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-9",NULL},
/* 1DAA9 */ { "SIGNWRITING MODIFICATEUR DE ROTATION-10",NULL},
/* 1DAAA */ { "SIGNWRITING MODIFICATEUR DE ROTATION-11",NULL},
/* 1DAAB */ { "SIGNWRITING MODIFICATEUR DE ROTATION-12",NULL},
/* 1DAAC */ { "SIGNWRITING MODIFICATEUR DE ROTATION-13",NULL},
/* 1DAAD */ { "SIGNWRITING MODIFICATEUR DE ROTATION-14",NULL},
/* 1DAAE */ { "SIGNWRITING MODIFICATEUR DE ROTATION-15",NULL},
/* 1DAAF */ { "SIGNWRITING MODIFICATEUR DE ROTATION-16",NULL},
/* 1DAB0 */ { NULL,NULL},
/* 1DAB1 */ { NULL,NULL},
/* 1DAB2 */ { NULL,NULL},
/* 1DAB3 */ { NULL,NULL},
/* 1DAB4 */ { NULL,NULL},
/* 1DAB5 */ { NULL,NULL},
/* 1DAB6 */ { NULL,NULL},
/* 1DAB7 */ { NULL,NULL},
/* 1DAB8 */ { NULL,NULL},
/* 1DAB9 */ { NULL,NULL},
/* 1DABA */ { NULL,NULL},
/* 1DABB */ { NULL,NULL},
/* 1DABC */ { NULL,NULL},
/* 1DABD */ { NULL,NULL},
/* 1DABE */ { NULL,NULL},
/* 1DABF */ { NULL,NULL},
/* 1DAC0 */ { NULL,NULL},
/* 1DAC1 */ { NULL,NULL},
/* 1DAC2 */ { NULL,NULL},
/* 1DAC3 */ { NULL,NULL},
/* 1DAC4 */ { NULL,NULL},
/* 1DAC5 */ { NULL,NULL},
/* 1DAC6 */ { NULL,NULL},
/* 1DAC7 */ { NULL,NULL},
/* 1DAC8 */ { NULL,NULL},
/* 1DAC9 */ { NULL,NULL},
/* 1DACA */ { NULL,NULL},
/* 1DACB */ { NULL,NULL},
/* 1DACC */ { NULL,NULL},
/* 1DACD */ { NULL,NULL},
/* 1DACE */ { NULL,NULL},
/* 1DACF */ { NULL,NULL},
/* 1DAD0 */ { NULL,NULL},
/* 1DAD1 */ { NULL,NULL},
/* 1DAD2 */ { NULL,NULL},
/* 1DAD3 */ { NULL,NULL},
/* 1DAD4 */ { NULL,NULL},
/* 1DAD5 */ { NULL,NULL},
/* 1DAD6 */ { NULL,NULL},
/* 1DAD7 */ { NULL,NULL},
/* 1DAD8 */ { NULL,NULL},
/* 1DAD9 */ { NULL,NULL},
/* 1DADA */ { NULL,NULL},
/* 1DADB */ { NULL,NULL},
/* 1DADC */ { NULL,NULL},
/* 1DADD */ { NULL,NULL},
/* 1DADE */ { NULL,NULL},
/* 1DADF */ { NULL,NULL},
/* 1DAE0 */ { NULL,NULL},
/* 1DAE1 */ { NULL,NULL},
/* 1DAE2 */ { NULL,NULL},
/* 1DAE3 */ { NULL,NULL},
/* 1DAE4 */ { NULL,NULL},
/* 1DAE5 */ { NULL,NULL},
/* 1DAE6 */ { NULL,NULL},
/* 1DAE7 */ { NULL,NULL},
/* 1DAE8 */ { NULL,NULL},
/* 1DAE9 */ { NULL,NULL},
/* 1DAEA */ { NULL,NULL},
/* 1DAEB */ { NULL,NULL},
/* 1DAEC */ { NULL,NULL},
/* 1DAED */ { NULL,NULL},
/* 1DAEE */ { NULL,NULL},
/* 1DAEF */ { NULL,NULL},
/* 1DAF0 */ { NULL,NULL},
/* 1DAF1 */ { NULL,NULL},
/* 1DAF2 */ { NULL,NULL},
/* 1DAF3 */ { NULL,NULL},
/* 1DAF4 */ { NULL,NULL},
/* 1DAF5 */ { NULL,NULL},
/* 1DAF6 */ { NULL,NULL},
/* 1DAF7 */ { NULL,NULL},
/* 1DAF8 */ { NULL,NULL},
/* 1DAF9 */ { NULL,NULL},
/* 1DAFA */ { NULL,NULL},
/* 1DAFB */ { NULL,NULL},
/* 1DAFC */ { NULL,NULL},
/* 1DAFD */ { NULL,NULL},
/* 1DAFE */ { NULL,NULL},
/* 1DAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_DF[] = {
/* 1DF00 */ { "LETTRE MINUSCULE LATINE DIGRAMME FENG AVEC TRILLE","	x (lettre minuscule latine digramme feng - 02A9)"},
/* 1DF01 */ { "LETTRE MINUSCULE LATINE G CURSIF RÉFLÉCHI",NULL},
/* 1DF02 */ { "LETTRE LATINE PETITE CAPITALE G CULBUTÉ","	x (lettre minuscule latine g culbuté - 1D77)"},
/* 1DF03 */ { "LETTRE MINUSCULE LATINE K RÉFLÉCHI",NULL},
/* 1DF04 */ { "LETTRE LATINE PETITE CAPITALE L SANGLÉ","	x (lettre majuscule latine l sanglé - A7AD)"},
/* 1DF05 */ { "LETTRE MINUSCULE LATINE LEJ HAMEÇON RÉTROFLEXE",NULL},
/* 1DF06 */ { "LETTRE MINUSCULE LATINE Y SANGLÉ CULBUTÉ",NULL},
/* 1DF07 */ { "LETTRE MINUSCULE LATINE ENG RÉFLÉCHI",NULL},
/* 1DF08 */ { "LETTRE MINUSCULE LATINE R CULBUTÉ À LONG FÛT HAMEÇON RÉTROFLEXE",NULL},
/* 1DF09 */ { "LETTRE MINUSCULE LATINE T CROSSE ET HAMEÇON RÉTROFLEXE","	x (lettre minuscule latine t crosse - 01AD)"},
/* 1DF0A */ { "LETTRE LATINE CLIC RÉTROFLEXE AVEC HAMEÇON RÉTROFLEXE","	x (lettre modificative point d'exclamation haut - A71D)\n"
	"	x (lettre modificative clic rétroflexe avec hameçon rétroflexe - 107B9)"},
/* 1DF0B */ { "LETTRE MINUSCULE LATINE ECH DOUBLE BARRE","	x (intégrale avec deux barres horizontales - 2A0E)"},
/* 1DF0C */ { "LETTRE MINUSCULE LATINE ECH BOUCLÉ DOUBLE BARRE",NULL},
/* 1DF0D */ { "LETTRE MINUSCULE LATINE T BOUCLÉ CULBUTÉ",NULL},
/* 1DF0E */ { "LETTRE LATINE COUP DE GLOTTE BOUCLÉ RÉFLÉCHI",NULL},
/* 1DF0F */ { "LETTRE LATINE C BOUCLÉ ÉTIRÉ",NULL},
/* 1DF10 */ { "LETTRE LATINE PETITE CAPITALE K CULBUTÉ","	x (lettre minuscule latine k culbuté - 029E)\n"
	"	x (lettre majuscule latine k culbuté - A7B0)"},
/* 1DF11 */ { "LETTRE MINUSCULE LATINE L HAMEÇON",NULL},
/* 1DF12 */ { "LETTRE MINUSCULE LATINE DIGRAMME DEJ HAMEÇON PALATAL",NULL},
/* 1DF13 */ { "LETTRE MINUSCULE LATINE L SANGLÉ HAMEÇON PALATAL",NULL},
/* 1DF14 */ { "LETTRE MINUSCULE LATINE ENG HAMEÇON PALATAL",NULL},
/* 1DF15 */ { "LETTRE MINUSCULE LATINE R CULBUTÉ HAMEÇON PALATAL",NULL},
/* 1DF16 */ { "LETTRE MINUSCULE LATINE R SANS OBIT HAMEÇON PALATAL",NULL},
/* 1DF17 */ { "LETTRE MINUSCULE LATINE DIGRAMME TECH HAMEÇON PALATAL",NULL},
/* 1DF18 */ { "LETTRE MINUSCULE LATINE EJ HAMEÇON PALATAL",NULL},
/* 1DF19 */ { "LETTRE MINUSCULE LATINE DIGRAMME DEJ HAMEÇON RÉTROFLEXE",NULL},
/* 1DF1A */ { "LETTRE MINUSCULE LATINE I BARRÉ HAMEÇON RÉTROFLEXE",NULL},
/* 1DF1B */ { "LETTRE MINUSCULE LATINE O HAMEÇON RÉTROFLEXE",NULL},
/* 1DF1C */ { "LETTRE MINUSCULE LATINE DIGRAMME TECH HAMEÇON RÉTROFLEXE",NULL},
/* 1DF1D */ { "LETTRE MINUSCULE LATINE C HAMEÇON RÉTROFLEXE",NULL},
/* 1DF1E */ { "LETTRE MINUSCULE LATINE S BOUCLÉ",NULL},
/* 1DF1F */ { NULL,NULL},
/* 1DF20 */ { NULL,NULL},
/* 1DF21 */ { NULL,NULL},
/* 1DF22 */ { NULL,NULL},
/* 1DF23 */ { NULL,NULL},
/* 1DF24 */ { NULL,NULL},
/* 1DF25 */ { "LETTRE MINUSCULE LATINE D CROSSE À GAUCHE À MI-HAUTEUR",NULL},
/* 1DF26 */ { "LETTRE MINUSCULE LATINE L CROSSE À GAUCHE À MI-HAUTEUR",NULL},
/* 1DF27 */ { "LETTRE MINUSCULE LATINE N CROSSE À GAUCHE À MI-HAUTEUR",NULL},
/* 1DF28 */ { "LETTRE MINUSCULE LATINE R CROSSE À GAUCHE À MI-HAUTEUR",NULL},
/* 1DF29 */ { "LETTRE MINUSCULE LATINE S CROSSE À GAUCHE À MI-HAUTEUR",NULL},
/* 1DF2A */ { "LETTRE MINUSCULE LATINE T CROSSE À GAUCHE À MI-HAUTEUR",NULL},
/* 1DF2B */ { NULL,NULL},
/* 1DF2C */ { NULL,NULL},
/* 1DF2D */ { NULL,NULL},
/* 1DF2E */ { NULL,NULL},
/* 1DF2F */ { NULL,NULL},
/* 1DF30 */ { NULL,NULL},
/* 1DF31 */ { NULL,NULL},
/* 1DF32 */ { NULL,NULL},
/* 1DF33 */ { NULL,NULL},
/* 1DF34 */ { NULL,NULL},
/* 1DF35 */ { NULL,NULL},
/* 1DF36 */ { NULL,NULL},
/* 1DF37 */ { NULL,NULL},
/* 1DF38 */ { NULL,NULL},
/* 1DF39 */ { NULL,NULL},
/* 1DF3A */ { NULL,NULL},
/* 1DF3B */ { NULL,NULL},
/* 1DF3C */ { NULL,NULL},
/* 1DF3D */ { NULL,NULL},
/* 1DF3E */ { NULL,NULL},
/* 1DF3F */ { NULL,NULL},
/* 1DF40 */ { NULL,NULL},
/* 1DF41 */ { NULL,NULL},
/* 1DF42 */ { NULL,NULL},
/* 1DF43 */ { NULL,NULL},
/* 1DF44 */ { NULL,NULL},
/* 1DF45 */ { NULL,NULL},
/* 1DF46 */ { NULL,NULL},
/* 1DF47 */ { NULL,NULL},
/* 1DF48 */ { NULL,NULL},
/* 1DF49 */ { NULL,NULL},
/* 1DF4A */ { NULL,NULL},
/* 1DF4B */ { NULL,NULL},
/* 1DF4C */ { NULL,NULL},
/* 1DF4D */ { NULL,NULL},
/* 1DF4E */ { NULL,NULL},
/* 1DF4F */ { NULL,NULL},
/* 1DF50 */ { NULL,NULL},
/* 1DF51 */ { NULL,NULL},
/* 1DF52 */ { NULL,NULL},
/* 1DF53 */ { NULL,NULL},
/* 1DF54 */ { NULL,NULL},
/* 1DF55 */ { NULL,NULL},
/* 1DF56 */ { NULL,NULL},
/* 1DF57 */ { NULL,NULL},
/* 1DF58 */ { NULL,NULL},
/* 1DF59 */ { NULL,NULL},
/* 1DF5A */ { NULL,NULL},
/* 1DF5B */ { NULL,NULL},
/* 1DF5C */ { NULL,NULL},
/* 1DF5D */ { NULL,NULL},
/* 1DF5E */ { NULL,NULL},
/* 1DF5F */ { NULL,NULL},
/* 1DF60 */ { NULL,NULL},
/* 1DF61 */ { NULL,NULL},
/* 1DF62 */ { NULL,NULL},
/* 1DF63 */ { NULL,NULL},
/* 1DF64 */ { NULL,NULL},
/* 1DF65 */ { NULL,NULL},
/* 1DF66 */ { NULL,NULL},
/* 1DF67 */ { NULL,NULL},
/* 1DF68 */ { NULL,NULL},
/* 1DF69 */ { NULL,NULL},
/* 1DF6A */ { NULL,NULL},
/* 1DF6B */ { NULL,NULL},
/* 1DF6C */ { NULL,NULL},
/* 1DF6D */ { NULL,NULL},
/* 1DF6E */ { NULL,NULL},
/* 1DF6F */ { NULL,NULL},
/* 1DF70 */ { NULL,NULL},
/* 1DF71 */ { NULL,NULL},
/* 1DF72 */ { NULL,NULL},
/* 1DF73 */ { NULL,NULL},
/* 1DF74 */ { NULL,NULL},
/* 1DF75 */ { NULL,NULL},
/* 1DF76 */ { NULL,NULL},
/* 1DF77 */ { NULL,NULL},
/* 1DF78 */ { NULL,NULL},
/* 1DF79 */ { NULL,NULL},
/* 1DF7A */ { NULL,NULL},
/* 1DF7B */ { NULL,NULL},
/* 1DF7C */ { NULL,NULL},
/* 1DF7D */ { NULL,NULL},
/* 1DF7E */ { NULL,NULL},
/* 1DF7F */ { NULL,NULL},
/* 1DF80 */ { NULL,NULL},
/* 1DF81 */ { NULL,NULL},
/* 1DF82 */ { NULL,NULL},
/* 1DF83 */ { NULL,NULL},
/* 1DF84 */ { NULL,NULL},
/* 1DF85 */ { NULL,NULL},
/* 1DF86 */ { NULL,NULL},
/* 1DF87 */ { NULL,NULL},
/* 1DF88 */ { NULL,NULL},
/* 1DF89 */ { NULL,NULL},
/* 1DF8A */ { NULL,NULL},
/* 1DF8B */ { NULL,NULL},
/* 1DF8C */ { NULL,NULL},
/* 1DF8D */ { NULL,NULL},
/* 1DF8E */ { NULL,NULL},
/* 1DF8F */ { NULL,NULL},
/* 1DF90 */ { NULL,NULL},
/* 1DF91 */ { NULL,NULL},
/* 1DF92 */ { NULL,NULL},
/* 1DF93 */ { NULL,NULL},
/* 1DF94 */ { NULL,NULL},
/* 1DF95 */ { NULL,NULL},
/* 1DF96 */ { NULL,NULL},
/* 1DF97 */ { NULL,NULL},
/* 1DF98 */ { NULL,NULL},
/* 1DF99 */ { NULL,NULL},
/* 1DF9A */ { NULL,NULL},
/* 1DF9B */ { NULL,NULL},
/* 1DF9C */ { NULL,NULL},
/* 1DF9D */ { NULL,NULL},
/* 1DF9E */ { NULL,NULL},
/* 1DF9F */ { NULL,NULL},
/* 1DFA0 */ { NULL,NULL},
/* 1DFA1 */ { NULL,NULL},
/* 1DFA2 */ { NULL,NULL},
/* 1DFA3 */ { NULL,NULL},
/* 1DFA4 */ { NULL,NULL},
/* 1DFA5 */ { NULL,NULL},
/* 1DFA6 */ { NULL,NULL},
/* 1DFA7 */ { NULL,NULL},
/* 1DFA8 */ { NULL,NULL},
/* 1DFA9 */ { NULL,NULL},
/* 1DFAA */ { NULL,NULL},
/* 1DFAB */ { NULL,NULL},
/* 1DFAC */ { NULL,NULL},
/* 1DFAD */ { NULL,NULL},
/* 1DFAE */ { NULL,NULL},
/* 1DFAF */ { NULL,NULL},
/* 1DFB0 */ { NULL,NULL},
/* 1DFB1 */ { NULL,NULL},
/* 1DFB2 */ { NULL,NULL},
/* 1DFB3 */ { NULL,NULL},
/* 1DFB4 */ { NULL,NULL},
/* 1DFB5 */ { NULL,NULL},
/* 1DFB6 */ { NULL,NULL},
/* 1DFB7 */ { NULL,NULL},
/* 1DFB8 */ { NULL,NULL},
/* 1DFB9 */ { NULL,NULL},
/* 1DFBA */ { NULL,NULL},
/* 1DFBB */ { NULL,NULL},
/* 1DFBC */ { NULL,NULL},
/* 1DFBD */ { NULL,NULL},
/* 1DFBE */ { NULL,NULL},
/* 1DFBF */ { NULL,NULL},
/* 1DFC0 */ { NULL,NULL},
/* 1DFC1 */ { NULL,NULL},
/* 1DFC2 */ { NULL,NULL},
/* 1DFC3 */ { NULL,NULL},
/* 1DFC4 */ { NULL,NULL},
/* 1DFC5 */ { NULL,NULL},
/* 1DFC6 */ { NULL,NULL},
/* 1DFC7 */ { NULL,NULL},
/* 1DFC8 */ { NULL,NULL},
/* 1DFC9 */ { NULL,NULL},
/* 1DFCA */ { NULL,NULL},
/* 1DFCB */ { NULL,NULL},
/* 1DFCC */ { NULL,NULL},
/* 1DFCD */ { NULL,NULL},
/* 1DFCE */ { NULL,NULL},
/* 1DFCF */ { NULL,NULL},
/* 1DFD0 */ { NULL,NULL},
/* 1DFD1 */ { NULL,NULL},
/* 1DFD2 */ { NULL,NULL},
/* 1DFD3 */ { NULL,NULL},
/* 1DFD4 */ { NULL,NULL},
/* 1DFD5 */ { NULL,NULL},
/* 1DFD6 */ { NULL,NULL},
/* 1DFD7 */ { NULL,NULL},
/* 1DFD8 */ { NULL,NULL},
/* 1DFD9 */ { NULL,NULL},
/* 1DFDA */ { NULL,NULL},
/* 1DFDB */ { NULL,NULL},
/* 1DFDC */ { NULL,NULL},
/* 1DFDD */ { NULL,NULL},
/* 1DFDE */ { NULL,NULL},
/* 1DFDF */ { NULL,NULL},
/* 1DFE0 */ { NULL,NULL},
/* 1DFE1 */ { NULL,NULL},
/* 1DFE2 */ { NULL,NULL},
/* 1DFE3 */ { NULL,NULL},
/* 1DFE4 */ { NULL,NULL},
/* 1DFE5 */ { NULL,NULL},
/* 1DFE6 */ { NULL,NULL},
/* 1DFE7 */ { NULL,NULL},
/* 1DFE8 */ { NULL,NULL},
/* 1DFE9 */ { NULL,NULL},
/* 1DFEA */ { NULL,NULL},
/* 1DFEB */ { NULL,NULL},
/* 1DFEC */ { NULL,NULL},
/* 1DFED */ { NULL,NULL},
/* 1DFEE */ { NULL,NULL},
/* 1DFEF */ { NULL,NULL},
/* 1DFF0 */ { NULL,NULL},
/* 1DFF1 */ { NULL,NULL},
/* 1DFF2 */ { NULL,NULL},
/* 1DFF3 */ { NULL,NULL},
/* 1DFF4 */ { NULL,NULL},
/* 1DFF5 */ { NULL,NULL},
/* 1DFF6 */ { NULL,NULL},
/* 1DFF7 */ { NULL,NULL},
/* 1DFF8 */ { NULL,NULL},
/* 1DFF9 */ { NULL,NULL},
/* 1DFFA */ { NULL,NULL},
/* 1DFFB */ { NULL,NULL},
/* 1DFFC */ { NULL,NULL},
/* 1DFFD */ { NULL,NULL},
/* 1DFFE */ { NULL,NULL},
/* 1DFFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E0[] = {
/* 1E000 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE AZ",NULL},
/* 1E001 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE BOUKI",NULL},
/* 1E002 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE VÉDI",NULL},
/* 1E003 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE GLAGOL",NULL},
/* 1E004 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE DOBRO",NULL},
/* 1E005 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE IEST",NULL},
/* 1E006 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE JIVÉTÉ",NULL},
/* 1E007 */ { NULL,NULL},
/* 1E008 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE ZEMLIA",NULL},
/* 1E009 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE IJÉ",NULL},
/* 1E00A */ { "DIACRITIQUE LETTRE GLAGOLITIQUE IJÉ INITIAL",NULL},
/* 1E00B */ { "DIACRITIQUE LETTRE GLAGOLITIQUE I",NULL},
/* 1E00C */ { "DIACRITIQUE LETTRE GLAGOLITIQUE DIERV",NULL},
/* 1E00D */ { "DIACRITIQUE LETTRE GLAGOLITIQUE KAKO",NULL},
/* 1E00E */ { "DIACRITIQUE LETTRE GLAGOLITIQUE LIOUDIÉ",NULL},
/* 1E00F */ { "DIACRITIQUE LETTRE GLAGOLITIQUE MYSLÉTÉ",NULL},
/* 1E010 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE NACH",NULL},
/* 1E011 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE ON",NULL},
/* 1E012 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE POKOÏ",NULL},
/* 1E013 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE RTSY",NULL},
/* 1E014 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE SLOVO",NULL},
/* 1E015 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE TVERDO",NULL},
/* 1E016 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE OUK",NULL},
/* 1E017 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE FERT",NULL},
/* 1E018 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE KHER",NULL},
/* 1E019 */ { NULL,NULL},
/* 1E01A */ { NULL,NULL},
/* 1E01B */ { "DIACRITIQUE LETTRE GLAGOLITIQUE CHTA",NULL},
/* 1E01C */ { "DIACRITIQUE LETTRE GLAGOLITIQUE TSI",NULL},
/* 1E01D */ { "DIACRITIQUE LETTRE GLAGOLITIQUE TCHERV",NULL},
/* 1E01E */ { "DIACRITIQUE LETTRE GLAGOLITIQUE CHA",NULL},
/* 1E01F */ { "DIACRITIQUE LETTRE GLAGOLITIQUE YÉROU",NULL},
/* 1E020 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE YER",NULL},
/* 1E021 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE IAT",NULL},
/* 1E022 */ { NULL,NULL},
/* 1E023 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE IOU",NULL},
/* 1E024 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE PETIT IOUSSE",NULL},
/* 1E025 */ { NULL,NULL},
/* 1E026 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE IO",NULL},
/* 1E027 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE PETIT IOUSSE YODISÉ",NULL},
/* 1E028 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE GRAND IOUSSE",NULL},
/* 1E029 */ { "DIACRITIQUE LETTRE GLAGOLITIQUE GRAND IOUSSE YODISÉ",NULL},
/* 1E02A */ { "DIACRITIQUE LETTRE GLAGOLITIQUE FITA",NULL},
/* 1E02B */ { NULL,NULL},
/* 1E02C */ { NULL,NULL},
/* 1E02D */ { NULL,NULL},
/* 1E02E */ { NULL,NULL},
/* 1E02F */ { NULL,NULL},
/* 1E030 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE A","	# <exp> 0430"},
/* 1E031 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE BÉ","	# <exp> 0431"},
/* 1E032 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE VÉ","	# <exp> 0432"},
/* 1E033 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE GUÉ","	# <exp> 0433"},
/* 1E034 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE DÉ","	# <exp> 0434"},
/* 1E035 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE IÉ","	# <exp> 0435"},
/* 1E036 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE JÉ","	# <exp> 0436"},
/* 1E037 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE ZÉ","	# <exp> 0437"},
/* 1E038 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE I","	# <exp> 0438"},
/* 1E039 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE KA","	# <exp> 043A"},
/* 1E03A */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE ELLE","	# <exp> 043B"},
/* 1E03B */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE EMME","	# <exp> 043C"},
/* 1E03C */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE O","	# <exp> 043E"},
/* 1E03D */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE PÉ","	# <exp> 043F"},
/* 1E03E */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE ERRE","	# <exp> 0440"},
/* 1E03F */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE ESSE","	# <exp> 0441"},
/* 1E040 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE TÉ","	# <exp> 0442"},
/* 1E041 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE OU","	# <exp> 0443"},
/* 1E042 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE EFFE","	# <exp> 0444"},
/* 1E043 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE KHA","	# <exp> 0445"},
/* 1E044 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE TSÉ","	# <exp> 0446"},
/* 1E045 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE TCHÉ","	# <exp> 0447"},
/* 1E046 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE CHA","	# <exp> 0448"},
/* 1E047 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE YÉROU","	# <exp> 044B"},
/* 1E048 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE É","	# <exp> 044D"},
/* 1E049 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE IOU","	# <exp> 044E"},
/* 1E04A */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE DZZÉ","	# <exp> A689"},
/* 1E04B */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE SCHWA","	# <exp> 04D9"},
/* 1E04C */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE I BIÉLORUSSE-UKRAINIEN","	# <exp> 0456"},
/* 1E04D */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE YÉ","	# <exp> 0458"},
/* 1E04E */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE O BARRÉ","	# <exp> 04E9"},
/* 1E04F */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE OU DROIT","	# <exp> 04AF"},
/* 1E050 */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE PALOTCHKA","	# <exp> 04CF"},
/* 1E051 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE A","	# <souscrite> 0430"},
/* 1E052 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE BÉ","	# <souscrite> 0431"},
/* 1E053 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE VÉ","	# <souscrite> 0432"},
/* 1E054 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE GUÉ","	# <souscrite> 0433"},
/* 1E055 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE DÉ","	# <souscrite> 0434"},
/* 1E056 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE IÉ","	# <souscrite> 0435"},
/* 1E057 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE JÉ","	# <souscrite> 0436"},
/* 1E058 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE ZÉ","	# <souscrite> 0437"},
/* 1E059 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE I","	# <souscrite> 0438"},
/* 1E05A */ { "INDICE LETTRE MINUSCULE CYRILLIQUE KA","	# <souscrite> 043A"},
/* 1E05B */ { "INDICE LETTRE MINUSCULE CYRILLIQUE ELLE","	# <souscrite> 043B"},
/* 1E05C */ { "INDICE LETTRE MINUSCULE CYRILLIQUE O","	# <souscrite> 043E"},
/* 1E05D */ { "INDICE LETTRE MINUSCULE CYRILLIQUE PÉ","	# <souscrite> 043F"},
/* 1E05E */ { "INDICE LETTRE MINUSCULE CYRILLIQUE ESSE","	# <souscrite> 0441"},
/* 1E05F */ { "INDICE LETTRE MINUSCULE CYRILLIQUE OU","	# <souscrite> 0443"},
/* 1E060 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE EFFE","	# <souscrite> 0444"},
/* 1E061 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE KHA","	# <souscrite> 0445"},
/* 1E062 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE TSÉ","	# <souscrite> 0446"},
/* 1E063 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE TCHÉ","	# <souscrite> 0447"},
/* 1E064 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE CHA","	# <souscrite> 0448"},
/* 1E065 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE SIGNE DUR","	# <souscrite> 044A"},
/* 1E066 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE YÉROU","	# <souscrite> 044B"},
/* 1E067 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE GUÉ HAMPÉ","	# <souscrite> 0491"},
/* 1E068 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE I BIÉLORUSSE-UKRAINIEN","	# <souscrite> 0456"},
/* 1E069 */ { "INDICE LETTRE MINUSCULE CYRILLIQUE DZÉ","	# <souscrite> 0455"},
/* 1E06A */ { "INDICE LETTRE MINUSCULE CYRILLIQUE DJÉ","	# <souscrite> 045F"},
/* 1E06B */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE ESSE CRAMPON","	# <exp> 04AB"},
/* 1E06C */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE YÉROU À YER POSTÉRIEUR","	# <exp> A651"},
/* 1E06D */ { "LETTRE MODIFICATIVE CYRILLIQUE MINUSCULE OU DROIT BARRÉ","	# <exp> 04B1"},
/* 1E06E */ { NULL,NULL},
/* 1E06F */ { NULL,NULL},
/* 1E070 */ { NULL,NULL},
/* 1E071 */ { NULL,NULL},
/* 1E072 */ { NULL,NULL},
/* 1E073 */ { NULL,NULL},
/* 1E074 */ { NULL,NULL},
/* 1E075 */ { NULL,NULL},
/* 1E076 */ { NULL,NULL},
/* 1E077 */ { NULL,NULL},
/* 1E078 */ { NULL,NULL},
/* 1E079 */ { NULL,NULL},
/* 1E07A */ { NULL,NULL},
/* 1E07B */ { NULL,NULL},
/* 1E07C */ { NULL,NULL},
/* 1E07D */ { NULL,NULL},
/* 1E07E */ { NULL,NULL},
/* 1E07F */ { NULL,NULL},
/* 1E080 */ { NULL,NULL},
/* 1E081 */ { NULL,NULL},
/* 1E082 */ { NULL,NULL},
/* 1E083 */ { NULL,NULL},
/* 1E084 */ { NULL,NULL},
/* 1E085 */ { NULL,NULL},
/* 1E086 */ { NULL,NULL},
/* 1E087 */ { NULL,NULL},
/* 1E088 */ { NULL,NULL},
/* 1E089 */ { NULL,NULL},
/* 1E08A */ { NULL,NULL},
/* 1E08B */ { NULL,NULL},
/* 1E08C */ { NULL,NULL},
/* 1E08D */ { NULL,NULL},
/* 1E08E */ { NULL,NULL},
/* 1E08F */ { "DIACRITIQUE LETTRE MINUSCULE CYRILLIQUE I BIÉLORUSSE-UKRAINIEN",NULL},
/* 1E090 */ { NULL,NULL},
/* 1E091 */ { NULL,NULL},
/* 1E092 */ { NULL,NULL},
/* 1E093 */ { NULL,NULL},
/* 1E094 */ { NULL,NULL},
/* 1E095 */ { NULL,NULL},
/* 1E096 */ { NULL,NULL},
/* 1E097 */ { NULL,NULL},
/* 1E098 */ { NULL,NULL},
/* 1E099 */ { NULL,NULL},
/* 1E09A */ { NULL,NULL},
/* 1E09B */ { NULL,NULL},
/* 1E09C */ { NULL,NULL},
/* 1E09D */ { NULL,NULL},
/* 1E09E */ { NULL,NULL},
/* 1E09F */ { NULL,NULL},
/* 1E0A0 */ { NULL,NULL},
/* 1E0A1 */ { NULL,NULL},
/* 1E0A2 */ { NULL,NULL},
/* 1E0A3 */ { NULL,NULL},
/* 1E0A4 */ { NULL,NULL},
/* 1E0A5 */ { NULL,NULL},
/* 1E0A6 */ { NULL,NULL},
/* 1E0A7 */ { NULL,NULL},
/* 1E0A8 */ { NULL,NULL},
/* 1E0A9 */ { NULL,NULL},
/* 1E0AA */ { NULL,NULL},
/* 1E0AB */ { NULL,NULL},
/* 1E0AC */ { NULL,NULL},
/* 1E0AD */ { NULL,NULL},
/* 1E0AE */ { NULL,NULL},
/* 1E0AF */ { NULL,NULL},
/* 1E0B0 */ { NULL,NULL},
/* 1E0B1 */ { NULL,NULL},
/* 1E0B2 */ { NULL,NULL},
/* 1E0B3 */ { NULL,NULL},
/* 1E0B4 */ { NULL,NULL},
/* 1E0B5 */ { NULL,NULL},
/* 1E0B6 */ { NULL,NULL},
/* 1E0B7 */ { NULL,NULL},
/* 1E0B8 */ { NULL,NULL},
/* 1E0B9 */ { NULL,NULL},
/* 1E0BA */ { NULL,NULL},
/* 1E0BB */ { NULL,NULL},
/* 1E0BC */ { NULL,NULL},
/* 1E0BD */ { NULL,NULL},
/* 1E0BE */ { NULL,NULL},
/* 1E0BF */ { NULL,NULL},
/* 1E0C0 */ { NULL,NULL},
/* 1E0C1 */ { NULL,NULL},
/* 1E0C2 */ { NULL,NULL},
/* 1E0C3 */ { NULL,NULL},
/* 1E0C4 */ { NULL,NULL},
/* 1E0C5 */ { NULL,NULL},
/* 1E0C6 */ { NULL,NULL},
/* 1E0C7 */ { NULL,NULL},
/* 1E0C8 */ { NULL,NULL},
/* 1E0C9 */ { NULL,NULL},
/* 1E0CA */ { NULL,NULL},
/* 1E0CB */ { NULL,NULL},
/* 1E0CC */ { NULL,NULL},
/* 1E0CD */ { NULL,NULL},
/* 1E0CE */ { NULL,NULL},
/* 1E0CF */ { NULL,NULL},
/* 1E0D0 */ { NULL,NULL},
/* 1E0D1 */ { NULL,NULL},
/* 1E0D2 */ { NULL,NULL},
/* 1E0D3 */ { NULL,NULL},
/* 1E0D4 */ { NULL,NULL},
/* 1E0D5 */ { NULL,NULL},
/* 1E0D6 */ { NULL,NULL},
/* 1E0D7 */ { NULL,NULL},
/* 1E0D8 */ { NULL,NULL},
/* 1E0D9 */ { NULL,NULL},
/* 1E0DA */ { NULL,NULL},
/* 1E0DB */ { NULL,NULL},
/* 1E0DC */ { NULL,NULL},
/* 1E0DD */ { NULL,NULL},
/* 1E0DE */ { NULL,NULL},
/* 1E0DF */ { NULL,NULL},
/* 1E0E0 */ { NULL,NULL},
/* 1E0E1 */ { NULL,NULL},
/* 1E0E2 */ { NULL,NULL},
/* 1E0E3 */ { NULL,NULL},
/* 1E0E4 */ { NULL,NULL},
/* 1E0E5 */ { NULL,NULL},
/* 1E0E6 */ { NULL,NULL},
/* 1E0E7 */ { NULL,NULL},
/* 1E0E8 */ { NULL,NULL},
/* 1E0E9 */ { NULL,NULL},
/* 1E0EA */ { NULL,NULL},
/* 1E0EB */ { NULL,NULL},
/* 1E0EC */ { NULL,NULL},
/* 1E0ED */ { NULL,NULL},
/* 1E0EE */ { NULL,NULL},
/* 1E0EF */ { NULL,NULL},
/* 1E0F0 */ { NULL,NULL},
/* 1E0F1 */ { NULL,NULL},
/* 1E0F2 */ { NULL,NULL},
/* 1E0F3 */ { NULL,NULL},
/* 1E0F4 */ { NULL,NULL},
/* 1E0F5 */ { NULL,NULL},
/* 1E0F6 */ { NULL,NULL},
/* 1E0F7 */ { NULL,NULL},
/* 1E0F8 */ { NULL,NULL},
/* 1E0F9 */ { NULL,NULL},
/* 1E0FA */ { NULL,NULL},
/* 1E0FB */ { NULL,NULL},
/* 1E0FC */ { NULL,NULL},
/* 1E0FD */ { NULL,NULL},
/* 1E0FE */ { NULL,NULL},
/* 1E0FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E1[] = {
/* 1E100 */ { "LETTRE NYIAKENG PUACHUE HMONG MA","	x (lettre hébraïque mém - 05DE)"},
/* 1E101 */ { "LETTRE NYIAKENG PUACHUE HMONG TSA",NULL},
/* 1E102 */ { "LETTRE NYIAKENG PUACHUE HMONG NTA",NULL},
/* 1E103 */ { "LETTRE NYIAKENG PUACHUE HMONG TA","	x (lettre hébraïque tèt - 05D8)"},
/* 1E104 */ { "LETTRE NYIAKENG PUACHUE HMONG HA",NULL},
/* 1E105 */ { "LETTRE NYIAKENG PUACHUE HMONG NA",NULL},
/* 1E106 */ { "LETTRE NYIAKENG PUACHUE HMONG XA",NULL},
/* 1E107 */ { "LETTRE NYIAKENG PUACHUE HMONG NKA",NULL},
/* 1E108 */ { "LETTRE NYIAKENG PUACHUE HMONG TCHA",NULL},
/* 1E109 */ { "LETTRE NYIAKENG PUACHUE HMONG LA",NULL},
/* 1E10A */ { "LETTRE NYIAKENG PUACHUE HMONG SA","	x (lettre hébraïque chine - 05E9)"},
/* 1E10B */ { "LETTRE NYIAKENG PUACHUE HMONG ZA",NULL},
/* 1E10C */ { "LETTRE NYIAKENG PUACHUE HMONG NCA",NULL},
/* 1E10D */ { "LETTRE NYIAKENG PUACHUE HMONG NTSA",NULL},
/* 1E10E */ { "LETTRE NYIAKENG PUACHUE HMONG KA","	x (lettre hébraïque kaf - 05DB)"},
/* 1E10F */ { "LETTRE NYIAKENG PUACHUE HMONG DA",NULL},
/* 1E110 */ { "LETTRE NYIAKENG PUACHUE HMONG ÑA",NULL},
/* 1E111 */ { "LETTRE NYIAKENG PUACHUE HMONG NRA",NULL},
/* 1E112 */ { "LETTRE NYIAKENG PUACHUE HMONG VA",NULL},
/* 1E113 */ { "LETTRE NYIAKENG PUACHUE HMONG NTXA",NULL},
/* 1E114 */ { "LETTRE NYIAKENG PUACHUE HMONG TXA",NULL},
/* 1E115 */ { "LETTRE NYIAKENG PUACHUE HMONG FA",NULL},
/* 1E116 */ { "LETTRE NYIAKENG PUACHUE HMONG RA",NULL},
/* 1E117 */ { "LETTRE NYIAKENG PUACHUE HMONG QA","	x (lettre hébraïque qouf - 05E7)"},
/* 1E118 */ { "LETTRE NYIAKENG PUACHUE HMONG YA",NULL},
/* 1E119 */ { "LETTRE NYIAKENG PUACHUE HMONG NQA",NULL},
/* 1E11A */ { "LETTRE NYIAKENG PUACHUE HMONG PA","	x (lettre hébraïque pé - 05E4)"},
/* 1E11B */ { "LETTRE NYIAKENG PUACHUE HMONG XYA",NULL},
/* 1E11C */ { "LETTRE NYIAKENG PUACHUE HMONG NPA",NULL},
/* 1E11D */ { "LETTRE NYIAKENG PUACHUE HMONG DLA",NULL},
/* 1E11E */ { "LETTRE NYIAKENG PUACHUE HMONG NPLA",NULL},
/* 1E11F */ { "LETTRE NYIAKENG PUACHUE HMONG HAH","	* utilisée également pour une voyelle o"},
/* 1E120 */ { "LETTRE NYIAKENG PUACHUE HMONG MLA",NULL},
/* 1E121 */ { "LETTRE NYIAKENG PUACHUE HMONG PLA",NULL},
/* 1E122 */ { "LETTRE NYIAKENG PUACHUE HMONG GA",NULL},
/* 1E123 */ { "LETTRE NYIAKENG PUACHUE HMONG RRA","	* utilisée également pour une diphtongue aï"},
/* 1E124 */ { "LETTRE NYIAKENG PUACHUE HMONG A",NULL},
/* 1E125 */ { "LETTRE NYIAKENG PUACHUE HMONG Â",NULL},
/* 1E126 */ { "LETTRE NYIAKENG PUACHUE HMONG I",NULL},
/* 1E127 */ { "LETTRE NYIAKENG PUACHUE HMONG OU",NULL},
/* 1E128 */ { "LETTRE NYIAKENG PUACHUE HMONG O",NULL},
/* 1E129 */ { "LETTRE NYIAKENG PUACHUE HMONG Ô",NULL},
/* 1E12A */ { "LETTRE NYIAKENG PUACHUE HMONG É",NULL},
/* 1E12B */ { "LETTRE NYIAKENG PUACHUE HMONG ÉÉ",NULL},
/* 1E12C */ { "LETTRE NYIAKENG PUACHUE HMONG W",NULL},
/* 1E12D */ { NULL,NULL},
/* 1E12E */ { NULL,NULL},
/* 1E12F */ { NULL,NULL},
/* 1E130 */ { "TON B NYIAKENG PUACHUE HMONG","	= som thwb\n"
	"	* ton haut APR -b"},
/* 1E131 */ { "TON M NYIAKENG PUACHUE HMONG","	= som thwm\n"
	"	* ton bas glottalisé APR -m"},
/* 1E132 */ { "TON J NYIAKENG PUACHUE HMONG","	= som thwj\n"
	"	* ton haut descendant APR -j"},
/* 1E133 */ { "TON V NYIAKENG PUACHUE HMONG","	= som thwv\n"
	"	* ton moyen montant APR -v"},
/* 1E134 */ { "TON S NYIAKENG PUACHUE HMONG","	= som thws\n"
	"	* ton bas APR -s"},
/* 1E135 */ { "TON G NYIAKENG PUACHUE HMONG","	= som thwg\n"
	"	* ton descendant soufflé APR -g"},
/* 1E136 */ { "TON D NYIAKENG PUACHUE HMONG","	= som thwd\n"
	"	* ton bas montant APR -d"},
/* 1E137 */ { "SIGNE NYIAKENG PUACHUE HMONG POUR PERSONNE","	= oov"},
/* 1E138 */ { "SIGNE NYIAKENG PUACHUE HMONG POUR CHOSE","	= pes"},
/* 1E139 */ { "SIGNE NYIAKENG PUACHUE HMONG POUR PLACE","	= khab theeb"},
/* 1E13A */ { "SIGNE NYIAKENG PUACHUE HMONG POUR ANIMAL","	= khuam luas"},
/* 1E13B */ { "SIGNE NYIAKENG PUACHUE HMONG POUR INVERTÉBRÉ","	= poos"},
/* 1E13C */ { "SIGNE NYIAKENG PUACHUE HMONG XW XW","	* indique la répétition d'un mot court ou d'une syllabe\n"
	"	* lorsqu'il est précédé d'une espace, il indique la répétition d'une phrase ou d'un syntagme\n"
	"	x (caractère thaï maïyamok - 0E46)\n"
	"	x (ko la laotien - 0EC6)"},
/* 1E13D */ { "ALLONGE DE SYLLABE NYIAKENG PUACHUE HMONG","	= khu saim"},
/* 1E13E */ { NULL,NULL},
/* 1E13F */ { NULL,NULL},
/* 1E140 */ { "CHIFFRE NYIAKENG PUACHUE HMONG ZÉRO",NULL},
/* 1E141 */ { "CHIFFRE NYIAKENG PUACHUE HMONG UN",NULL},
/* 1E142 */ { "CHIFFRE NYIAKENG PUACHUE HMONG DEUX",NULL},
/* 1E143 */ { "CHIFFRE NYIAKENG PUACHUE HMONG TROIS",NULL},
/* 1E144 */ { "CHIFFRE NYIAKENG PUACHUE HMONG QUATRE",NULL},
/* 1E145 */ { "CHIFFRE NYIAKENG PUACHUE HMONG CINQ",NULL},
/* 1E146 */ { "CHIFFRE NYIAKENG PUACHUE HMONG SIX",NULL},
/* 1E147 */ { "CHIFFRE NYIAKENG PUACHUE HMONG SEPT",NULL},
/* 1E148 */ { "CHIFFRE NYIAKENG PUACHUE HMONG HUIT",NULL},
/* 1E149 */ { "CHIFFRE NYIAKENG PUACHUE HMONG NEUF",NULL},
/* 1E14A */ { NULL,NULL},
/* 1E14B */ { NULL,NULL},
/* 1E14C */ { NULL,NULL},
/* 1E14D */ { NULL,NULL},
/* 1E14E */ { "LOGOGRAMME NYIAKENG PUACHUE HMONG ÑADJ","	* utilisé pour représenter le mot pour l'argent ou la monnaie"},
/* 1E14F */ { "TCHA CERCLÉ NYIAKENG PUACHUE HMONG","	* utilisé pour indiquer la propriété\n"
	"	x (lettre nyiakeng puachue hmong tcha - 1E108)"},
/* 1E150 */ { NULL,NULL},
/* 1E151 */ { NULL,NULL},
/* 1E152 */ { NULL,NULL},
/* 1E153 */ { NULL,NULL},
/* 1E154 */ { NULL,NULL},
/* 1E155 */ { NULL,NULL},
/* 1E156 */ { NULL,NULL},
/* 1E157 */ { NULL,NULL},
/* 1E158 */ { NULL,NULL},
/* 1E159 */ { NULL,NULL},
/* 1E15A */ { NULL,NULL},
/* 1E15B */ { NULL,NULL},
/* 1E15C */ { NULL,NULL},
/* 1E15D */ { NULL,NULL},
/* 1E15E */ { NULL,NULL},
/* 1E15F */ { NULL,NULL},
/* 1E160 */ { NULL,NULL},
/* 1E161 */ { NULL,NULL},
/* 1E162 */ { NULL,NULL},
/* 1E163 */ { NULL,NULL},
/* 1E164 */ { NULL,NULL},
/* 1E165 */ { NULL,NULL},
/* 1E166 */ { NULL,NULL},
/* 1E167 */ { NULL,NULL},
/* 1E168 */ { NULL,NULL},
/* 1E169 */ { NULL,NULL},
/* 1E16A */ { NULL,NULL},
/* 1E16B */ { NULL,NULL},
/* 1E16C */ { NULL,NULL},
/* 1E16D */ { NULL,NULL},
/* 1E16E */ { NULL,NULL},
/* 1E16F */ { NULL,NULL},
/* 1E170 */ { NULL,NULL},
/* 1E171 */ { NULL,NULL},
/* 1E172 */ { NULL,NULL},
/* 1E173 */ { NULL,NULL},
/* 1E174 */ { NULL,NULL},
/* 1E175 */ { NULL,NULL},
/* 1E176 */ { NULL,NULL},
/* 1E177 */ { NULL,NULL},
/* 1E178 */ { NULL,NULL},
/* 1E179 */ { NULL,NULL},
/* 1E17A */ { NULL,NULL},
/* 1E17B */ { NULL,NULL},
/* 1E17C */ { NULL,NULL},
/* 1E17D */ { NULL,NULL},
/* 1E17E */ { NULL,NULL},
/* 1E17F */ { NULL,NULL},
/* 1E180 */ { NULL,NULL},
/* 1E181 */ { NULL,NULL},
/* 1E182 */ { NULL,NULL},
/* 1E183 */ { NULL,NULL},
/* 1E184 */ { NULL,NULL},
/* 1E185 */ { NULL,NULL},
/* 1E186 */ { NULL,NULL},
/* 1E187 */ { NULL,NULL},
/* 1E188 */ { NULL,NULL},
/* 1E189 */ { NULL,NULL},
/* 1E18A */ { NULL,NULL},
/* 1E18B */ { NULL,NULL},
/* 1E18C */ { NULL,NULL},
/* 1E18D */ { NULL,NULL},
/* 1E18E */ { NULL,NULL},
/* 1E18F */ { NULL,NULL},
/* 1E190 */ { NULL,NULL},
/* 1E191 */ { NULL,NULL},
/* 1E192 */ { NULL,NULL},
/* 1E193 */ { NULL,NULL},
/* 1E194 */ { NULL,NULL},
/* 1E195 */ { NULL,NULL},
/* 1E196 */ { NULL,NULL},
/* 1E197 */ { NULL,NULL},
/* 1E198 */ { NULL,NULL},
/* 1E199 */ { NULL,NULL},
/* 1E19A */ { NULL,NULL},
/* 1E19B */ { NULL,NULL},
/* 1E19C */ { NULL,NULL},
/* 1E19D */ { NULL,NULL},
/* 1E19E */ { NULL,NULL},
/* 1E19F */ { NULL,NULL},
/* 1E1A0 */ { NULL,NULL},
/* 1E1A1 */ { NULL,NULL},
/* 1E1A2 */ { NULL,NULL},
/* 1E1A3 */ { NULL,NULL},
/* 1E1A4 */ { NULL,NULL},
/* 1E1A5 */ { NULL,NULL},
/* 1E1A6 */ { NULL,NULL},
/* 1E1A7 */ { NULL,NULL},
/* 1E1A8 */ { NULL,NULL},
/* 1E1A9 */ { NULL,NULL},
/* 1E1AA */ { NULL,NULL},
/* 1E1AB */ { NULL,NULL},
/* 1E1AC */ { NULL,NULL},
/* 1E1AD */ { NULL,NULL},
/* 1E1AE */ { NULL,NULL},
/* 1E1AF */ { NULL,NULL},
/* 1E1B0 */ { NULL,NULL},
/* 1E1B1 */ { NULL,NULL},
/* 1E1B2 */ { NULL,NULL},
/* 1E1B3 */ { NULL,NULL},
/* 1E1B4 */ { NULL,NULL},
/* 1E1B5 */ { NULL,NULL},
/* 1E1B6 */ { NULL,NULL},
/* 1E1B7 */ { NULL,NULL},
/* 1E1B8 */ { NULL,NULL},
/* 1E1B9 */ { NULL,NULL},
/* 1E1BA */ { NULL,NULL},
/* 1E1BB */ { NULL,NULL},
/* 1E1BC */ { NULL,NULL},
/* 1E1BD */ { NULL,NULL},
/* 1E1BE */ { NULL,NULL},
/* 1E1BF */ { NULL,NULL},
/* 1E1C0 */ { NULL,NULL},
/* 1E1C1 */ { NULL,NULL},
/* 1E1C2 */ { NULL,NULL},
/* 1E1C3 */ { NULL,NULL},
/* 1E1C4 */ { NULL,NULL},
/* 1E1C5 */ { NULL,NULL},
/* 1E1C6 */ { NULL,NULL},
/* 1E1C7 */ { NULL,NULL},
/* 1E1C8 */ { NULL,NULL},
/* 1E1C9 */ { NULL,NULL},
/* 1E1CA */ { NULL,NULL},
/* 1E1CB */ { NULL,NULL},
/* 1E1CC */ { NULL,NULL},
/* 1E1CD */ { NULL,NULL},
/* 1E1CE */ { NULL,NULL},
/* 1E1CF */ { NULL,NULL},
/* 1E1D0 */ { NULL,NULL},
/* 1E1D1 */ { NULL,NULL},
/* 1E1D2 */ { NULL,NULL},
/* 1E1D3 */ { NULL,NULL},
/* 1E1D4 */ { NULL,NULL},
/* 1E1D5 */ { NULL,NULL},
/* 1E1D6 */ { NULL,NULL},
/* 1E1D7 */ { NULL,NULL},
/* 1E1D8 */ { NULL,NULL},
/* 1E1D9 */ { NULL,NULL},
/* 1E1DA */ { NULL,NULL},
/* 1E1DB */ { NULL,NULL},
/* 1E1DC */ { NULL,NULL},
/* 1E1DD */ { NULL,NULL},
/* 1E1DE */ { NULL,NULL},
/* 1E1DF */ { NULL,NULL},
/* 1E1E0 */ { NULL,NULL},
/* 1E1E1 */ { NULL,NULL},
/* 1E1E2 */ { NULL,NULL},
/* 1E1E3 */ { NULL,NULL},
/* 1E1E4 */ { NULL,NULL},
/* 1E1E5 */ { NULL,NULL},
/* 1E1E6 */ { NULL,NULL},
/* 1E1E7 */ { NULL,NULL},
/* 1E1E8 */ { NULL,NULL},
/* 1E1E9 */ { NULL,NULL},
/* 1E1EA */ { NULL,NULL},
/* 1E1EB */ { NULL,NULL},
/* 1E1EC */ { NULL,NULL},
/* 1E1ED */ { NULL,NULL},
/* 1E1EE */ { NULL,NULL},
/* 1E1EF */ { NULL,NULL},
/* 1E1F0 */ { NULL,NULL},
/* 1E1F1 */ { NULL,NULL},
/* 1E1F2 */ { NULL,NULL},
/* 1E1F3 */ { NULL,NULL},
/* 1E1F4 */ { NULL,NULL},
/* 1E1F5 */ { NULL,NULL},
/* 1E1F6 */ { NULL,NULL},
/* 1E1F7 */ { NULL,NULL},
/* 1E1F8 */ { NULL,NULL},
/* 1E1F9 */ { NULL,NULL},
/* 1E1FA */ { NULL,NULL},
/* 1E1FB */ { NULL,NULL},
/* 1E1FC */ { NULL,NULL},
/* 1E1FD */ { NULL,NULL},
/* 1E1FE */ { NULL,NULL},
/* 1E1FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E2[] = {
/* 1E200 */ { NULL,NULL},
/* 1E201 */ { NULL,NULL},
/* 1E202 */ { NULL,NULL},
/* 1E203 */ { NULL,NULL},
/* 1E204 */ { NULL,NULL},
/* 1E205 */ { NULL,NULL},
/* 1E206 */ { NULL,NULL},
/* 1E207 */ { NULL,NULL},
/* 1E208 */ { NULL,NULL},
/* 1E209 */ { NULL,NULL},
/* 1E20A */ { NULL,NULL},
/* 1E20B */ { NULL,NULL},
/* 1E20C */ { NULL,NULL},
/* 1E20D */ { NULL,NULL},
/* 1E20E */ { NULL,NULL},
/* 1E20F */ { NULL,NULL},
/* 1E210 */ { NULL,NULL},
/* 1E211 */ { NULL,NULL},
/* 1E212 */ { NULL,NULL},
/* 1E213 */ { NULL,NULL},
/* 1E214 */ { NULL,NULL},
/* 1E215 */ { NULL,NULL},
/* 1E216 */ { NULL,NULL},
/* 1E217 */ { NULL,NULL},
/* 1E218 */ { NULL,NULL},
/* 1E219 */ { NULL,NULL},
/* 1E21A */ { NULL,NULL},
/* 1E21B */ { NULL,NULL},
/* 1E21C */ { NULL,NULL},
/* 1E21D */ { NULL,NULL},
/* 1E21E */ { NULL,NULL},
/* 1E21F */ { NULL,NULL},
/* 1E220 */ { NULL,NULL},
/* 1E221 */ { NULL,NULL},
/* 1E222 */ { NULL,NULL},
/* 1E223 */ { NULL,NULL},
/* 1E224 */ { NULL,NULL},
/* 1E225 */ { NULL,NULL},
/* 1E226 */ { NULL,NULL},
/* 1E227 */ { NULL,NULL},
/* 1E228 */ { NULL,NULL},
/* 1E229 */ { NULL,NULL},
/* 1E22A */ { NULL,NULL},
/* 1E22B */ { NULL,NULL},
/* 1E22C */ { NULL,NULL},
/* 1E22D */ { NULL,NULL},
/* 1E22E */ { NULL,NULL},
/* 1E22F */ { NULL,NULL},
/* 1E230 */ { NULL,NULL},
/* 1E231 */ { NULL,NULL},
/* 1E232 */ { NULL,NULL},
/* 1E233 */ { NULL,NULL},
/* 1E234 */ { NULL,NULL},
/* 1E235 */ { NULL,NULL},
/* 1E236 */ { NULL,NULL},
/* 1E237 */ { NULL,NULL},
/* 1E238 */ { NULL,NULL},
/* 1E239 */ { NULL,NULL},
/* 1E23A */ { NULL,NULL},
/* 1E23B */ { NULL,NULL},
/* 1E23C */ { NULL,NULL},
/* 1E23D */ { NULL,NULL},
/* 1E23E */ { NULL,NULL},
/* 1E23F */ { NULL,NULL},
/* 1E240 */ { NULL,NULL},
/* 1E241 */ { NULL,NULL},
/* 1E242 */ { NULL,NULL},
/* 1E243 */ { NULL,NULL},
/* 1E244 */ { NULL,NULL},
/* 1E245 */ { NULL,NULL},
/* 1E246 */ { NULL,NULL},
/* 1E247 */ { NULL,NULL},
/* 1E248 */ { NULL,NULL},
/* 1E249 */ { NULL,NULL},
/* 1E24A */ { NULL,NULL},
/* 1E24B */ { NULL,NULL},
/* 1E24C */ { NULL,NULL},
/* 1E24D */ { NULL,NULL},
/* 1E24E */ { NULL,NULL},
/* 1E24F */ { NULL,NULL},
/* 1E250 */ { NULL,NULL},
/* 1E251 */ { NULL,NULL},
/* 1E252 */ { NULL,NULL},
/* 1E253 */ { NULL,NULL},
/* 1E254 */ { NULL,NULL},
/* 1E255 */ { NULL,NULL},
/* 1E256 */ { NULL,NULL},
/* 1E257 */ { NULL,NULL},
/* 1E258 */ { NULL,NULL},
/* 1E259 */ { NULL,NULL},
/* 1E25A */ { NULL,NULL},
/* 1E25B */ { NULL,NULL},
/* 1E25C */ { NULL,NULL},
/* 1E25D */ { NULL,NULL},
/* 1E25E */ { NULL,NULL},
/* 1E25F */ { NULL,NULL},
/* 1E260 */ { NULL,NULL},
/* 1E261 */ { NULL,NULL},
/* 1E262 */ { NULL,NULL},
/* 1E263 */ { NULL,NULL},
/* 1E264 */ { NULL,NULL},
/* 1E265 */ { NULL,NULL},
/* 1E266 */ { NULL,NULL},
/* 1E267 */ { NULL,NULL},
/* 1E268 */ { NULL,NULL},
/* 1E269 */ { NULL,NULL},
/* 1E26A */ { NULL,NULL},
/* 1E26B */ { NULL,NULL},
/* 1E26C */ { NULL,NULL},
/* 1E26D */ { NULL,NULL},
/* 1E26E */ { NULL,NULL},
/* 1E26F */ { NULL,NULL},
/* 1E270 */ { NULL,NULL},
/* 1E271 */ { NULL,NULL},
/* 1E272 */ { NULL,NULL},
/* 1E273 */ { NULL,NULL},
/* 1E274 */ { NULL,NULL},
/* 1E275 */ { NULL,NULL},
/* 1E276 */ { NULL,NULL},
/* 1E277 */ { NULL,NULL},
/* 1E278 */ { NULL,NULL},
/* 1E279 */ { NULL,NULL},
/* 1E27A */ { NULL,NULL},
/* 1E27B */ { NULL,NULL},
/* 1E27C */ { NULL,NULL},
/* 1E27D */ { NULL,NULL},
/* 1E27E */ { NULL,NULL},
/* 1E27F */ { NULL,NULL},
/* 1E280 */ { NULL,NULL},
/* 1E281 */ { NULL,NULL},
/* 1E282 */ { NULL,NULL},
/* 1E283 */ { NULL,NULL},
/* 1E284 */ { NULL,NULL},
/* 1E285 */ { NULL,NULL},
/* 1E286 */ { NULL,NULL},
/* 1E287 */ { NULL,NULL},
/* 1E288 */ { NULL,NULL},
/* 1E289 */ { NULL,NULL},
/* 1E28A */ { NULL,NULL},
/* 1E28B */ { NULL,NULL},
/* 1E28C */ { NULL,NULL},
/* 1E28D */ { NULL,NULL},
/* 1E28E */ { NULL,NULL},
/* 1E28F */ { NULL,NULL},
/* 1E290 */ { "LETTRE TOTO PA",NULL},
/* 1E291 */ { "LETTRE TOTO BA",NULL},
/* 1E292 */ { "LETTRE TOTO TA",NULL},
/* 1E293 */ { "LETTRE TOTO DA",NULL},
/* 1E294 */ { "LETTRE TOTO KA",NULL},
/* 1E295 */ { "LETTRE TOTO GA",NULL},
/* 1E296 */ { "LETTRE TOTO MA",NULL},
/* 1E297 */ { "LETTRE TOTO NA",NULL},
/* 1E298 */ { "LETTRE TOTO NGA",NULL},
/* 1E299 */ { "LETTRE TOTO SA",NULL},
/* 1E29A */ { "LETTRE TOTO TCHHA",NULL},
/* 1E29B */ { "LETTRE TOTO YA",NULL},
/* 1E29C */ { "LETTRE TOTO WA",NULL},
/* 1E29D */ { "LETTRE TOTO DJA",NULL},
/* 1E29E */ { "LETTRE TOTO HA",NULL},
/* 1E29F */ { "LETTRE TOTO RA",NULL},
/* 1E2A0 */ { "LETTRE TOTO LA",NULL},
/* 1E2A1 */ { "LETTRE TOTO I",NULL},
/* 1E2A2 */ { "LETTRE TOTO I SOUFFLÉ",NULL},
/* 1E2A3 */ { "LETTRE TOTO IOU",NULL},
/* 1E2A4 */ { "LETTRE TOTO IOU SOUFFLÉ",NULL},
/* 1E2A5 */ { "LETTRE TOTO OU",NULL},
/* 1E2A6 */ { "LETTRE TOTO É",NULL},
/* 1E2A7 */ { "LETTRE TOTO É SOUFFLÉ",NULL},
/* 1E2A8 */ { "LETTRE TOTO EO",NULL},
/* 1E2A9 */ { "LETTRE TOTO EO SOUFFLÉ",NULL},
/* 1E2AA */ { "LETTRE TOTO O",NULL},
/* 1E2AB */ { "LETTRE TOTO Æ",NULL},
/* 1E2AC */ { "LETTRE TOTO Æ SOUFFLÉ",NULL},
/* 1E2AD */ { "LETTRE TOTO A",NULL},
/* 1E2AE */ { "DIACRITIQUE TOTO TON ASCENDANT",NULL},
/* 1E2AF */ { NULL,NULL},
/* 1E2B0 */ { NULL,NULL},
/* 1E2B1 */ { NULL,NULL},
/* 1E2B2 */ { NULL,NULL},
/* 1E2B3 */ { NULL,NULL},
/* 1E2B4 */ { NULL,NULL},
/* 1E2B5 */ { NULL,NULL},
/* 1E2B6 */ { NULL,NULL},
/* 1E2B7 */ { NULL,NULL},
/* 1E2B8 */ { NULL,NULL},
/* 1E2B9 */ { NULL,NULL},
/* 1E2BA */ { NULL,NULL},
/* 1E2BB */ { NULL,NULL},
/* 1E2BC */ { NULL,NULL},
/* 1E2BD */ { NULL,NULL},
/* 1E2BE */ { NULL,NULL},
/* 1E2BF */ { NULL,NULL},
/* 1E2C0 */ { "LETTRE WANTCHO Â",NULL},
/* 1E2C1 */ { "LETTRE WANTCHO A",NULL},
/* 1E2C2 */ { "LETTRE WANTCHO BA",NULL},
/* 1E2C3 */ { "LETTRE WANTCHO TCHA",NULL},
/* 1E2C4 */ { "LETTRE WANTCHO DA",NULL},
/* 1E2C5 */ { "LETTRE WANTCHO GA",NULL},
/* 1E2C6 */ { "LETTRE WANTCHO YA",NULL},
/* 1E2C7 */ { "LETTRE WANTCHO PHA","	= lettre wantcho p'a"},
/* 1E2C8 */ { "LETTRE WANTCHO LA",NULL},
/* 1E2C9 */ { "LETTRE WANTCHO NA",NULL},
/* 1E2CA */ { "LETTRE WANTCHO PA",NULL},
/* 1E2CB */ { "LETTRE WANTCHO TA",NULL},
/* 1E2CC */ { "LETTRE WANTCHO THA",NULL},
/* 1E2CD */ { "LETTRE WANTCHO FA",NULL},
/* 1E2CE */ { "LETTRE WANTCHO SA",NULL},
/* 1E2CF */ { "LETTRE WANTCHO ÇA",NULL},
/* 1E2D0 */ { "LETTRE WANTCHO DJA",NULL},
/* 1E2D1 */ { "LETTRE WANTCHO ZA",NULL},
/* 1E2D2 */ { "LETTRE WANTCHO WA",NULL},
/* 1E2D3 */ { "LETTRE WANTCHO VA",NULL},
/* 1E2D4 */ { "LETTRE WANTCHO KA",NULL},
/* 1E2D5 */ { "LETTRE WANTCHO O",NULL},
/* 1E2D6 */ { "LETTRE WANTCHO AOU",NULL},
/* 1E2D7 */ { "LETTRE WANTCHO RA",NULL},
/* 1E2D8 */ { "LETTRE WANTCHO MA",NULL},
/* 1E2D9 */ { "LETTRE WANTCHO KHA",NULL},
/* 1E2DA */ { "LETTRE WANTCHO HA",NULL},
/* 1E2DB */ { "LETTRE WANTCHO É",NULL},
/* 1E2DC */ { "LETTRE WANTCHO I",NULL},
/* 1E2DD */ { "LETTRE WANTCHO NGA",NULL},
/* 1E2DE */ { "LETTRE WANTCHO OU",NULL},
/* 1E2DF */ { "LETTRE WANTCHO LLHA",NULL},
/* 1E2E0 */ { "LETTRE WANTCHO TSA",NULL},
/* 1E2E1 */ { "LETTRE WANTCHO TRA",NULL},
/* 1E2E2 */ { "LETTRE WANTCHO ONG",NULL},
/* 1E2E3 */ { "LETTRE WANTCHO ÂNG",NULL},
/* 1E2E4 */ { "LETTRE WANTCHO ANG",NULL},
/* 1E2E5 */ { "LETTRE WANTCHO ING",NULL},
/* 1E2E6 */ { "LETTRE WANTCHO ON",NULL},
/* 1E2E7 */ { "LETTRE WANTCHO EN",NULL},
/* 1E2E8 */ { "LETTRE WANTCHO ÂN",NULL},
/* 1E2E9 */ { "LETTRE WANTCHO ÑA",NULL},
/* 1E2EA */ { "LETTRE WANTCHO UN",NULL},
/* 1E2EB */ { "LETTRE WANTCHO YIH",NULL},
/* 1E2EC */ { "TON WANTCHO TOUP",NULL},
/* 1E2ED */ { "TON WANTCHO TOUPNI",NULL},
/* 1E2EE */ { "TON WANTCHO KOÏ",NULL},
/* 1E2EF */ { "TON WANTCHO KOÏNI",NULL},
/* 1E2F0 */ { "CHIFFRE WANTCHO ZÉRO",NULL},
/* 1E2F1 */ { "CHIFFRE WANTCHO UN",NULL},
/* 1E2F2 */ { "CHIFFRE WANTCHO DEUX",NULL},
/* 1E2F3 */ { "CHIFFRE WANTCHO TROIS",NULL},
/* 1E2F4 */ { "CHIFFRE WANTCHO QUATRE",NULL},
/* 1E2F5 */ { "CHIFFRE WANTCHO CINQ",NULL},
/* 1E2F6 */ { "CHIFFRE WANTCHO SIX",NULL},
/* 1E2F7 */ { "CHIFFRE WANTCHO SEPT",NULL},
/* 1E2F8 */ { "CHIFFRE WANTCHO HUIT",NULL},
/* 1E2F9 */ { "CHIFFRE WANTCHO NEUF",NULL},
/* 1E2FA */ { NULL,NULL},
/* 1E2FB */ { NULL,NULL},
/* 1E2FC */ { NULL,NULL},
/* 1E2FD */ { NULL,NULL},
/* 1E2FE */ { NULL,NULL},
/* 1E2FF */ { "SYMBOLE WANTCHO NGOUN","	= roupie\n"
	"	x (symbole roupie indienne - 20B9)"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E4[] = {
/* 1E400 */ { NULL,NULL},
/* 1E401 */ { NULL,NULL},
/* 1E402 */ { NULL,NULL},
/* 1E403 */ { NULL,NULL},
/* 1E404 */ { NULL,NULL},
/* 1E405 */ { NULL,NULL},
/* 1E406 */ { NULL,NULL},
/* 1E407 */ { NULL,NULL},
/* 1E408 */ { NULL,NULL},
/* 1E409 */ { NULL,NULL},
/* 1E40A */ { NULL,NULL},
/* 1E40B */ { NULL,NULL},
/* 1E40C */ { NULL,NULL},
/* 1E40D */ { NULL,NULL},
/* 1E40E */ { NULL,NULL},
/* 1E40F */ { NULL,NULL},
/* 1E410 */ { NULL,NULL},
/* 1E411 */ { NULL,NULL},
/* 1E412 */ { NULL,NULL},
/* 1E413 */ { NULL,NULL},
/* 1E414 */ { NULL,NULL},
/* 1E415 */ { NULL,NULL},
/* 1E416 */ { NULL,NULL},
/* 1E417 */ { NULL,NULL},
/* 1E418 */ { NULL,NULL},
/* 1E419 */ { NULL,NULL},
/* 1E41A */ { NULL,NULL},
/* 1E41B */ { NULL,NULL},
/* 1E41C */ { NULL,NULL},
/* 1E41D */ { NULL,NULL},
/* 1E41E */ { NULL,NULL},
/* 1E41F */ { NULL,NULL},
/* 1E420 */ { NULL,NULL},
/* 1E421 */ { NULL,NULL},
/* 1E422 */ { NULL,NULL},
/* 1E423 */ { NULL,NULL},
/* 1E424 */ { NULL,NULL},
/* 1E425 */ { NULL,NULL},
/* 1E426 */ { NULL,NULL},
/* 1E427 */ { NULL,NULL},
/* 1E428 */ { NULL,NULL},
/* 1E429 */ { NULL,NULL},
/* 1E42A */ { NULL,NULL},
/* 1E42B */ { NULL,NULL},
/* 1E42C */ { NULL,NULL},
/* 1E42D */ { NULL,NULL},
/* 1E42E */ { NULL,NULL},
/* 1E42F */ { NULL,NULL},
/* 1E430 */ { NULL,NULL},
/* 1E431 */ { NULL,NULL},
/* 1E432 */ { NULL,NULL},
/* 1E433 */ { NULL,NULL},
/* 1E434 */ { NULL,NULL},
/* 1E435 */ { NULL,NULL},
/* 1E436 */ { NULL,NULL},
/* 1E437 */ { NULL,NULL},
/* 1E438 */ { NULL,NULL},
/* 1E439 */ { NULL,NULL},
/* 1E43A */ { NULL,NULL},
/* 1E43B */ { NULL,NULL},
/* 1E43C */ { NULL,NULL},
/* 1E43D */ { NULL,NULL},
/* 1E43E */ { NULL,NULL},
/* 1E43F */ { NULL,NULL},
/* 1E440 */ { NULL,NULL},
/* 1E441 */ { NULL,NULL},
/* 1E442 */ { NULL,NULL},
/* 1E443 */ { NULL,NULL},
/* 1E444 */ { NULL,NULL},
/* 1E445 */ { NULL,NULL},
/* 1E446 */ { NULL,NULL},
/* 1E447 */ { NULL,NULL},
/* 1E448 */ { NULL,NULL},
/* 1E449 */ { NULL,NULL},
/* 1E44A */ { NULL,NULL},
/* 1E44B */ { NULL,NULL},
/* 1E44C */ { NULL,NULL},
/* 1E44D */ { NULL,NULL},
/* 1E44E */ { NULL,NULL},
/* 1E44F */ { NULL,NULL},
/* 1E450 */ { NULL,NULL},
/* 1E451 */ { NULL,NULL},
/* 1E452 */ { NULL,NULL},
/* 1E453 */ { NULL,NULL},
/* 1E454 */ { NULL,NULL},
/* 1E455 */ { NULL,NULL},
/* 1E456 */ { NULL,NULL},
/* 1E457 */ { NULL,NULL},
/* 1E458 */ { NULL,NULL},
/* 1E459 */ { NULL,NULL},
/* 1E45A */ { NULL,NULL},
/* 1E45B */ { NULL,NULL},
/* 1E45C */ { NULL,NULL},
/* 1E45D */ { NULL,NULL},
/* 1E45E */ { NULL,NULL},
/* 1E45F */ { NULL,NULL},
/* 1E460 */ { NULL,NULL},
/* 1E461 */ { NULL,NULL},
/* 1E462 */ { NULL,NULL},
/* 1E463 */ { NULL,NULL},
/* 1E464 */ { NULL,NULL},
/* 1E465 */ { NULL,NULL},
/* 1E466 */ { NULL,NULL},
/* 1E467 */ { NULL,NULL},
/* 1E468 */ { NULL,NULL},
/* 1E469 */ { NULL,NULL},
/* 1E46A */ { NULL,NULL},
/* 1E46B */ { NULL,NULL},
/* 1E46C */ { NULL,NULL},
/* 1E46D */ { NULL,NULL},
/* 1E46E */ { NULL,NULL},
/* 1E46F */ { NULL,NULL},
/* 1E470 */ { NULL,NULL},
/* 1E471 */ { NULL,NULL},
/* 1E472 */ { NULL,NULL},
/* 1E473 */ { NULL,NULL},
/* 1E474 */ { NULL,NULL},
/* 1E475 */ { NULL,NULL},
/* 1E476 */ { NULL,NULL},
/* 1E477 */ { NULL,NULL},
/* 1E478 */ { NULL,NULL},
/* 1E479 */ { NULL,NULL},
/* 1E47A */ { NULL,NULL},
/* 1E47B */ { NULL,NULL},
/* 1E47C */ { NULL,NULL},
/* 1E47D */ { NULL,NULL},
/* 1E47E */ { NULL,NULL},
/* 1E47F */ { NULL,NULL},
/* 1E480 */ { NULL,NULL},
/* 1E481 */ { NULL,NULL},
/* 1E482 */ { NULL,NULL},
/* 1E483 */ { NULL,NULL},
/* 1E484 */ { NULL,NULL},
/* 1E485 */ { NULL,NULL},
/* 1E486 */ { NULL,NULL},
/* 1E487 */ { NULL,NULL},
/* 1E488 */ { NULL,NULL},
/* 1E489 */ { NULL,NULL},
/* 1E48A */ { NULL,NULL},
/* 1E48B */ { NULL,NULL},
/* 1E48C */ { NULL,NULL},
/* 1E48D */ { NULL,NULL},
/* 1E48E */ { NULL,NULL},
/* 1E48F */ { NULL,NULL},
/* 1E490 */ { NULL,NULL},
/* 1E491 */ { NULL,NULL},
/* 1E492 */ { NULL,NULL},
/* 1E493 */ { NULL,NULL},
/* 1E494 */ { NULL,NULL},
/* 1E495 */ { NULL,NULL},
/* 1E496 */ { NULL,NULL},
/* 1E497 */ { NULL,NULL},
/* 1E498 */ { NULL,NULL},
/* 1E499 */ { NULL,NULL},
/* 1E49A */ { NULL,NULL},
/* 1E49B */ { NULL,NULL},
/* 1E49C */ { NULL,NULL},
/* 1E49D */ { NULL,NULL},
/* 1E49E */ { NULL,NULL},
/* 1E49F */ { NULL,NULL},
/* 1E4A0 */ { NULL,NULL},
/* 1E4A1 */ { NULL,NULL},
/* 1E4A2 */ { NULL,NULL},
/* 1E4A3 */ { NULL,NULL},
/* 1E4A4 */ { NULL,NULL},
/* 1E4A5 */ { NULL,NULL},
/* 1E4A6 */ { NULL,NULL},
/* 1E4A7 */ { NULL,NULL},
/* 1E4A8 */ { NULL,NULL},
/* 1E4A9 */ { NULL,NULL},
/* 1E4AA */ { NULL,NULL},
/* 1E4AB */ { NULL,NULL},
/* 1E4AC */ { NULL,NULL},
/* 1E4AD */ { NULL,NULL},
/* 1E4AE */ { NULL,NULL},
/* 1E4AF */ { NULL,NULL},
/* 1E4B0 */ { NULL,NULL},
/* 1E4B1 */ { NULL,NULL},
/* 1E4B2 */ { NULL,NULL},
/* 1E4B3 */ { NULL,NULL},
/* 1E4B4 */ { NULL,NULL},
/* 1E4B5 */ { NULL,NULL},
/* 1E4B6 */ { NULL,NULL},
/* 1E4B7 */ { NULL,NULL},
/* 1E4B8 */ { NULL,NULL},
/* 1E4B9 */ { NULL,NULL},
/* 1E4BA */ { NULL,NULL},
/* 1E4BB */ { NULL,NULL},
/* 1E4BC */ { NULL,NULL},
/* 1E4BD */ { NULL,NULL},
/* 1E4BE */ { NULL,NULL},
/* 1E4BF */ { NULL,NULL},
/* 1E4C0 */ { NULL,NULL},
/* 1E4C1 */ { NULL,NULL},
/* 1E4C2 */ { NULL,NULL},
/* 1E4C3 */ { NULL,NULL},
/* 1E4C4 */ { NULL,NULL},
/* 1E4C5 */ { NULL,NULL},
/* 1E4C6 */ { NULL,NULL},
/* 1E4C7 */ { NULL,NULL},
/* 1E4C8 */ { NULL,NULL},
/* 1E4C9 */ { NULL,NULL},
/* 1E4CA */ { NULL,NULL},
/* 1E4CB */ { NULL,NULL},
/* 1E4CC */ { NULL,NULL},
/* 1E4CD */ { NULL,NULL},
/* 1E4CE */ { NULL,NULL},
/* 1E4CF */ { NULL,NULL},
/* 1E4D0 */ { "LETTRE NAG MUNDARI O",NULL},
/* 1E4D1 */ { "LETTRE NAG MUNDARI OP",NULL},
/* 1E4D2 */ { "LETTRE NAG MUNDARI OL",NULL},
/* 1E4D3 */ { "LETTRE NAG MUNDARI OY",NULL},
/* 1E4D4 */ { "LETTRE NAG MUNDARI ONG",NULL},
/* 1E4D5 */ { "LETTRE NAG MUNDARI A",NULL},
/* 1E4D6 */ { "LETTRE NAG MUNDARI AJ",NULL},
/* 1E4D7 */ { "LETTRE NAG MUNDARI AB",NULL},
/* 1E4D8 */ { "LETTRE NAG MUNDARI ANY",NULL},
/* 1E4D9 */ { "LETTRE NAG MUNDARI AH",NULL},
/* 1E4DA */ { "LETTRE NAG MUNDARI I",NULL},
/* 1E4DB */ { "LETTRE NAG MUNDARI IS",NULL},
/* 1E4DC */ { "LETTRE NAG MUNDARI IDD",NULL},
/* 1E4DD */ { "LETTRE NAG MUNDARI IT",NULL},
/* 1E4DE */ { "LETTRE NAG MUNDARI IH",NULL},
/* 1E4DF */ { "LETTRE NAG MUNDARI U",NULL},
/* 1E4E0 */ { "LETTRE NAG MUNDARI UC",NULL},
/* 1E4E1 */ { "LETTRE NAG MUNDARI UD",NULL},
/* 1E4E2 */ { "LETTRE NAG MUNDARI UK",NULL},
/* 1E4E3 */ { "LETTRE NAG MUNDARI UR",NULL},
/* 1E4E4 */ { "LETTRE NAG MUNDARI E",NULL},
/* 1E4E5 */ { "LETTRE NAG MUNDARI ENN",NULL},
/* 1E4E6 */ { "LETTRE NAG MUNDARI EG",NULL},
/* 1E4E7 */ { "LETTRE NAG MUNDARI EM",NULL},
/* 1E4E8 */ { "LETTRE NAG MUNDARI EN",NULL},
/* 1E4E9 */ { "LETTRE NAG MUNDARI ETT",NULL},
/* 1E4EA */ { "LETTRE NAG MUNDARI ELL",NULL},
/* 1E4EB */ { "SIGNE NAG MUNDARI OJOD","	* précède des lettres modifiées telles que AB ou UD\n"
	"	* peut indiquer une gémination consonantique"},
/* 1E4EC */ { "SIGNE NAG MUNDARI MUHOR","	* nasalisation de la voyelle"},
/* 1E4ED */ { "SIGNE NAG MUNDARI TOYOR","	* indique une voyelle longue"},
/* 1E4EE */ { "SIGNE NAG MUNDARI IKIR","	* indique qu'une voyelle est précédée du son « w »"},
/* 1E4EF */ { "SIGNE NAG MUNDARI SUTUH","	* principalement utilisé pour la translittération étroite de langues voisines"},
/* 1E4F0 */ { "CHIFFRE NAG MUNDARI ZÉRO",NULL},
/* 1E4F1 */ { "CHIFFRE NAG MUNDARI UN",NULL},
/* 1E4F2 */ { "CHIFFRE NAG MUNDARI DEUX",NULL},
/* 1E4F3 */ { "CHIFFRE NAG MUNDARI TROIS",NULL},
/* 1E4F4 */ { "CHIFFRE NAG MUNDARI QUATRE",NULL},
/* 1E4F5 */ { "CHIFFRE NAG MUNDARI CINQ",NULL},
/* 1E4F6 */ { "CHIFFRE NAG MUNDARI SIX",NULL},
/* 1E4F7 */ { "CHIFFRE NAG MUNDARI SEPT",NULL},
/* 1E4F8 */ { "CHIFFRE NAG MUNDARI HUIT",NULL},
/* 1E4F9 */ { "CHIFFRE NAG MUNDARI NEUF",NULL},
/* 1E4FA */ { NULL,NULL},
/* 1E4FB */ { NULL,NULL},
/* 1E4FC */ { NULL,NULL},
/* 1E4FD */ { NULL,NULL},
/* 1E4FE */ { NULL,NULL},
/* 1E4FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E5[] = {
/* 1E500 */ { NULL,NULL},
/* 1E501 */ { NULL,NULL},
/* 1E502 */ { NULL,NULL},
/* 1E503 */ { NULL,NULL},
/* 1E504 */ { NULL,NULL},
/* 1E505 */ { NULL,NULL},
/* 1E506 */ { NULL,NULL},
/* 1E507 */ { NULL,NULL},
/* 1E508 */ { NULL,NULL},
/* 1E509 */ { NULL,NULL},
/* 1E50A */ { NULL,NULL},
/* 1E50B */ { NULL,NULL},
/* 1E50C */ { NULL,NULL},
/* 1E50D */ { NULL,NULL},
/* 1E50E */ { NULL,NULL},
/* 1E50F */ { NULL,NULL},
/* 1E510 */ { NULL,NULL},
/* 1E511 */ { NULL,NULL},
/* 1E512 */ { NULL,NULL},
/* 1E513 */ { NULL,NULL},
/* 1E514 */ { NULL,NULL},
/* 1E515 */ { NULL,NULL},
/* 1E516 */ { NULL,NULL},
/* 1E517 */ { NULL,NULL},
/* 1E518 */ { NULL,NULL},
/* 1E519 */ { NULL,NULL},
/* 1E51A */ { NULL,NULL},
/* 1E51B */ { NULL,NULL},
/* 1E51C */ { NULL,NULL},
/* 1E51D */ { NULL,NULL},
/* 1E51E */ { NULL,NULL},
/* 1E51F */ { NULL,NULL},
/* 1E520 */ { NULL,NULL},
/* 1E521 */ { NULL,NULL},
/* 1E522 */ { NULL,NULL},
/* 1E523 */ { NULL,NULL},
/* 1E524 */ { NULL,NULL},
/* 1E525 */ { NULL,NULL},
/* 1E526 */ { NULL,NULL},
/* 1E527 */ { NULL,NULL},
/* 1E528 */ { NULL,NULL},
/* 1E529 */ { NULL,NULL},
/* 1E52A */ { NULL,NULL},
/* 1E52B */ { NULL,NULL},
/* 1E52C */ { NULL,NULL},
/* 1E52D */ { NULL,NULL},
/* 1E52E */ { NULL,NULL},
/* 1E52F */ { NULL,NULL},
/* 1E530 */ { NULL,NULL},
/* 1E531 */ { NULL,NULL},
/* 1E532 */ { NULL,NULL},
/* 1E533 */ { NULL,NULL},
/* 1E534 */ { NULL,NULL},
/* 1E535 */ { NULL,NULL},
/* 1E536 */ { NULL,NULL},
/* 1E537 */ { NULL,NULL},
/* 1E538 */ { NULL,NULL},
/* 1E539 */ { NULL,NULL},
/* 1E53A */ { NULL,NULL},
/* 1E53B */ { NULL,NULL},
/* 1E53C */ { NULL,NULL},
/* 1E53D */ { NULL,NULL},
/* 1E53E */ { NULL,NULL},
/* 1E53F */ { NULL,NULL},
/* 1E540 */ { NULL,NULL},
/* 1E541 */ { NULL,NULL},
/* 1E542 */ { NULL,NULL},
/* 1E543 */ { NULL,NULL},
/* 1E544 */ { NULL,NULL},
/* 1E545 */ { NULL,NULL},
/* 1E546 */ { NULL,NULL},
/* 1E547 */ { NULL,NULL},
/* 1E548 */ { NULL,NULL},
/* 1E549 */ { NULL,NULL},
/* 1E54A */ { NULL,NULL},
/* 1E54B */ { NULL,NULL},
/* 1E54C */ { NULL,NULL},
/* 1E54D */ { NULL,NULL},
/* 1E54E */ { NULL,NULL},
/* 1E54F */ { NULL,NULL},
/* 1E550 */ { NULL,NULL},
/* 1E551 */ { NULL,NULL},
/* 1E552 */ { NULL,NULL},
/* 1E553 */ { NULL,NULL},
/* 1E554 */ { NULL,NULL},
/* 1E555 */ { NULL,NULL},
/* 1E556 */ { NULL,NULL},
/* 1E557 */ { NULL,NULL},
/* 1E558 */ { NULL,NULL},
/* 1E559 */ { NULL,NULL},
/* 1E55A */ { NULL,NULL},
/* 1E55B */ { NULL,NULL},
/* 1E55C */ { NULL,NULL},
/* 1E55D */ { NULL,NULL},
/* 1E55E */ { NULL,NULL},
/* 1E55F */ { NULL,NULL},
/* 1E560 */ { NULL,NULL},
/* 1E561 */ { NULL,NULL},
/* 1E562 */ { NULL,NULL},
/* 1E563 */ { NULL,NULL},
/* 1E564 */ { NULL,NULL},
/* 1E565 */ { NULL,NULL},
/* 1E566 */ { NULL,NULL},
/* 1E567 */ { NULL,NULL},
/* 1E568 */ { NULL,NULL},
/* 1E569 */ { NULL,NULL},
/* 1E56A */ { NULL,NULL},
/* 1E56B */ { NULL,NULL},
/* 1E56C */ { NULL,NULL},
/* 1E56D */ { NULL,NULL},
/* 1E56E */ { NULL,NULL},
/* 1E56F */ { NULL,NULL},
/* 1E570 */ { NULL,NULL},
/* 1E571 */ { NULL,NULL},
/* 1E572 */ { NULL,NULL},
/* 1E573 */ { NULL,NULL},
/* 1E574 */ { NULL,NULL},
/* 1E575 */ { NULL,NULL},
/* 1E576 */ { NULL,NULL},
/* 1E577 */ { NULL,NULL},
/* 1E578 */ { NULL,NULL},
/* 1E579 */ { NULL,NULL},
/* 1E57A */ { NULL,NULL},
/* 1E57B */ { NULL,NULL},
/* 1E57C */ { NULL,NULL},
/* 1E57D */ { NULL,NULL},
/* 1E57E */ { NULL,NULL},
/* 1E57F */ { NULL,NULL},
/* 1E580 */ { NULL,NULL},
/* 1E581 */ { NULL,NULL},
/* 1E582 */ { NULL,NULL},
/* 1E583 */ { NULL,NULL},
/* 1E584 */ { NULL,NULL},
/* 1E585 */ { NULL,NULL},
/* 1E586 */ { NULL,NULL},
/* 1E587 */ { NULL,NULL},
/* 1E588 */ { NULL,NULL},
/* 1E589 */ { NULL,NULL},
/* 1E58A */ { NULL,NULL},
/* 1E58B */ { NULL,NULL},
/* 1E58C */ { NULL,NULL},
/* 1E58D */ { NULL,NULL},
/* 1E58E */ { NULL,NULL},
/* 1E58F */ { NULL,NULL},
/* 1E590 */ { NULL,NULL},
/* 1E591 */ { NULL,NULL},
/* 1E592 */ { NULL,NULL},
/* 1E593 */ { NULL,NULL},
/* 1E594 */ { NULL,NULL},
/* 1E595 */ { NULL,NULL},
/* 1E596 */ { NULL,NULL},
/* 1E597 */ { NULL,NULL},
/* 1E598 */ { NULL,NULL},
/* 1E599 */ { NULL,NULL},
/* 1E59A */ { NULL,NULL},
/* 1E59B */ { NULL,NULL},
/* 1E59C */ { NULL,NULL},
/* 1E59D */ { NULL,NULL},
/* 1E59E */ { NULL,NULL},
/* 1E59F */ { NULL,NULL},
/* 1E5A0 */ { NULL,NULL},
/* 1E5A1 */ { NULL,NULL},
/* 1E5A2 */ { NULL,NULL},
/* 1E5A3 */ { NULL,NULL},
/* 1E5A4 */ { NULL,NULL},
/* 1E5A5 */ { NULL,NULL},
/* 1E5A6 */ { NULL,NULL},
/* 1E5A7 */ { NULL,NULL},
/* 1E5A8 */ { NULL,NULL},
/* 1E5A9 */ { NULL,NULL},
/* 1E5AA */ { NULL,NULL},
/* 1E5AB */ { NULL,NULL},
/* 1E5AC */ { NULL,NULL},
/* 1E5AD */ { NULL,NULL},
/* 1E5AE */ { NULL,NULL},
/* 1E5AF */ { NULL,NULL},
/* 1E5B0 */ { NULL,NULL},
/* 1E5B1 */ { NULL,NULL},
/* 1E5B2 */ { NULL,NULL},
/* 1E5B3 */ { NULL,NULL},
/* 1E5B4 */ { NULL,NULL},
/* 1E5B5 */ { NULL,NULL},
/* 1E5B6 */ { NULL,NULL},
/* 1E5B7 */ { NULL,NULL},
/* 1E5B8 */ { NULL,NULL},
/* 1E5B9 */ { NULL,NULL},
/* 1E5BA */ { NULL,NULL},
/* 1E5BB */ { NULL,NULL},
/* 1E5BC */ { NULL,NULL},
/* 1E5BD */ { NULL,NULL},
/* 1E5BE */ { NULL,NULL},
/* 1E5BF */ { NULL,NULL},
/* 1E5C0 */ { NULL,NULL},
/* 1E5C1 */ { NULL,NULL},
/* 1E5C2 */ { NULL,NULL},
/* 1E5C3 */ { NULL,NULL},
/* 1E5C4 */ { NULL,NULL},
/* 1E5C5 */ { NULL,NULL},
/* 1E5C6 */ { NULL,NULL},
/* 1E5C7 */ { NULL,NULL},
/* 1E5C8 */ { NULL,NULL},
/* 1E5C9 */ { NULL,NULL},
/* 1E5CA */ { NULL,NULL},
/* 1E5CB */ { NULL,NULL},
/* 1E5CC */ { NULL,NULL},
/* 1E5CD */ { NULL,NULL},
/* 1E5CE */ { NULL,NULL},
/* 1E5CF */ { NULL,NULL},
/* 1E5D0 */ { "LETTRE OL ONAL O",NULL},
/* 1E5D1 */ { "LETTRE OL ONAL OM",NULL},
/* 1E5D2 */ { "LETTRE OL ONAL ONG",NULL},
/* 1E5D3 */ { "LETTRE OL ONAL ORR",NULL},
/* 1E5D4 */ { "LETTRE OL ONAL Ô",NULL},
/* 1E5D5 */ { "LETTRE OL ONAL OY",NULL},
/* 1E5D6 */ { "LETTRE OL ONAL A",NULL},
/* 1E5D7 */ { "LETTRE OL ONAL AD",NULL},
/* 1E5D8 */ { "LETTRE OL ONAL AB",NULL},
/* 1E5D9 */ { "LETTRE OL ONAL AH",NULL},
/* 1E5DA */ { "LETTRE OL ONAL AL",NULL},
/* 1E5DB */ { "LETTRE OL ONAL AW",NULL},
/* 1E5DC */ { "LETTRE OL ONAL I",NULL},
/* 1E5DD */ { "LETTRE OL ONAL IT",NULL},
/* 1E5DE */ { "LETTRE OL ONAL IP",NULL},
/* 1E5DF */ { "LETTRE OL ONAL ITT",NULL},
/* 1E5E0 */ { "LETTRE OL ONAL ID",NULL},
/* 1E5E1 */ { "LETTRE OL ONAL IN",NULL},
/* 1E5E2 */ { "LETTRE OL ONAL OU",NULL},
/* 1E5E3 */ { "LETTRE OL ONAL OUK",NULL},
/* 1E5E4 */ { "LETTRE OL ONAL OUDD",NULL},
/* 1E5E5 */ { "LETTRE OL ONAL OUDJ",NULL},
/* 1E5E6 */ { "LETTRE OL ONAL OUNY",NULL},
/* 1E5E7 */ { "LETTRE OL ONAL OUR",NULL},
/* 1E5E8 */ { "LETTRE OL ONAL É",NULL},
/* 1E5E9 */ { "LETTRE OL ONAL ES",NULL},
/* 1E5EA */ { "LETTRE OL ONAL EH",NULL},
/* 1E5EB */ { "LETTRE OL ONAL EC",NULL},
/* 1E5EC */ { "LETTRE OL ONAL ENN",NULL},
/* 1E5ED */ { "LETTRE OL ONAL EG",NULL},
/* 1E5EE */ { "SIGNE OL ONAL MOU",NULL},
/* 1E5EF */ { "SIGNE OL ONAL IKIR",NULL},
/* 1E5F0 */ { "SIGNE OL ONAL HODDOND",NULL},
/* 1E5F1 */ { "CHIFFRE OL ONAL ZÉRO",NULL},
/* 1E5F2 */ { "CHIFFRE OL ONAL UN",NULL},
/* 1E5F3 */ { "CHIFFRE OL ONAL DEUX",NULL},
/* 1E5F4 */ { "CHIFFRE OL ONAL TROIS",NULL},
/* 1E5F5 */ { "CHIFFRE OL ONAL QUATRE",NULL},
/* 1E5F6 */ { "CHIFFRE OL ONAL CINQ",NULL},
/* 1E5F7 */ { "CHIFFRE OL ONAL SIX",NULL},
/* 1E5F8 */ { "CHIFFRE OL ONAL SEPT",NULL},
/* 1E5F9 */ { "CHIFFRE OL ONAL HUIT",NULL},
/* 1E5FA */ { "CHIFFRE OL ONAL NEUF",NULL},
/* 1E5FB */ { NULL,NULL},
/* 1E5FC */ { NULL,NULL},
/* 1E5FD */ { NULL,NULL},
/* 1E5FE */ { NULL,NULL},
/* 1E5FF */ { "SIGNE D'ABRÉVIATION OL ONAL",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E6[] = {
/* 1E600 */ { NULL,NULL},
/* 1E601 */ { NULL,NULL},
/* 1E602 */ { NULL,NULL},
/* 1E603 */ { NULL,NULL},
/* 1E604 */ { NULL,NULL},
/* 1E605 */ { NULL,NULL},
/* 1E606 */ { NULL,NULL},
/* 1E607 */ { NULL,NULL},
/* 1E608 */ { NULL,NULL},
/* 1E609 */ { NULL,NULL},
/* 1E60A */ { NULL,NULL},
/* 1E60B */ { NULL,NULL},
/* 1E60C */ { NULL,NULL},
/* 1E60D */ { NULL,NULL},
/* 1E60E */ { NULL,NULL},
/* 1E60F */ { NULL,NULL},
/* 1E610 */ { NULL,NULL},
/* 1E611 */ { NULL,NULL},
/* 1E612 */ { NULL,NULL},
/* 1E613 */ { NULL,NULL},
/* 1E614 */ { NULL,NULL},
/* 1E615 */ { NULL,NULL},
/* 1E616 */ { NULL,NULL},
/* 1E617 */ { NULL,NULL},
/* 1E618 */ { NULL,NULL},
/* 1E619 */ { NULL,NULL},
/* 1E61A */ { NULL,NULL},
/* 1E61B */ { NULL,NULL},
/* 1E61C */ { NULL,NULL},
/* 1E61D */ { NULL,NULL},
/* 1E61E */ { NULL,NULL},
/* 1E61F */ { NULL,NULL},
/* 1E620 */ { NULL,NULL},
/* 1E621 */ { NULL,NULL},
/* 1E622 */ { NULL,NULL},
/* 1E623 */ { NULL,NULL},
/* 1E624 */ { NULL,NULL},
/* 1E625 */ { NULL,NULL},
/* 1E626 */ { NULL,NULL},
/* 1E627 */ { NULL,NULL},
/* 1E628 */ { NULL,NULL},
/* 1E629 */ { NULL,NULL},
/* 1E62A */ { NULL,NULL},
/* 1E62B */ { NULL,NULL},
/* 1E62C */ { NULL,NULL},
/* 1E62D */ { NULL,NULL},
/* 1E62E */ { NULL,NULL},
/* 1E62F */ { NULL,NULL},
/* 1E630 */ { NULL,NULL},
/* 1E631 */ { NULL,NULL},
/* 1E632 */ { NULL,NULL},
/* 1E633 */ { NULL,NULL},
/* 1E634 */ { NULL,NULL},
/* 1E635 */ { NULL,NULL},
/* 1E636 */ { NULL,NULL},
/* 1E637 */ { NULL,NULL},
/* 1E638 */ { NULL,NULL},
/* 1E639 */ { NULL,NULL},
/* 1E63A */ { NULL,NULL},
/* 1E63B */ { NULL,NULL},
/* 1E63C */ { NULL,NULL},
/* 1E63D */ { NULL,NULL},
/* 1E63E */ { NULL,NULL},
/* 1E63F */ { NULL,NULL},
/* 1E640 */ { NULL,NULL},
/* 1E641 */ { NULL,NULL},
/* 1E642 */ { NULL,NULL},
/* 1E643 */ { NULL,NULL},
/* 1E644 */ { NULL,NULL},
/* 1E645 */ { NULL,NULL},
/* 1E646 */ { NULL,NULL},
/* 1E647 */ { NULL,NULL},
/* 1E648 */ { NULL,NULL},
/* 1E649 */ { NULL,NULL},
/* 1E64A */ { NULL,NULL},
/* 1E64B */ { NULL,NULL},
/* 1E64C */ { NULL,NULL},
/* 1E64D */ { NULL,NULL},
/* 1E64E */ { NULL,NULL},
/* 1E64F */ { NULL,NULL},
/* 1E650 */ { NULL,NULL},
/* 1E651 */ { NULL,NULL},
/* 1E652 */ { NULL,NULL},
/* 1E653 */ { NULL,NULL},
/* 1E654 */ { NULL,NULL},
/* 1E655 */ { NULL,NULL},
/* 1E656 */ { NULL,NULL},
/* 1E657 */ { NULL,NULL},
/* 1E658 */ { NULL,NULL},
/* 1E659 */ { NULL,NULL},
/* 1E65A */ { NULL,NULL},
/* 1E65B */ { NULL,NULL},
/* 1E65C */ { NULL,NULL},
/* 1E65D */ { NULL,NULL},
/* 1E65E */ { NULL,NULL},
/* 1E65F */ { NULL,NULL},
/* 1E660 */ { NULL,NULL},
/* 1E661 */ { NULL,NULL},
/* 1E662 */ { NULL,NULL},
/* 1E663 */ { NULL,NULL},
/* 1E664 */ { NULL,NULL},
/* 1E665 */ { NULL,NULL},
/* 1E666 */ { NULL,NULL},
/* 1E667 */ { NULL,NULL},
/* 1E668 */ { NULL,NULL},
/* 1E669 */ { NULL,NULL},
/* 1E66A */ { NULL,NULL},
/* 1E66B */ { NULL,NULL},
/* 1E66C */ { NULL,NULL},
/* 1E66D */ { NULL,NULL},
/* 1E66E */ { NULL,NULL},
/* 1E66F */ { NULL,NULL},
/* 1E670 */ { NULL,NULL},
/* 1E671 */ { NULL,NULL},
/* 1E672 */ { NULL,NULL},
/* 1E673 */ { NULL,NULL},
/* 1E674 */ { NULL,NULL},
/* 1E675 */ { NULL,NULL},
/* 1E676 */ { NULL,NULL},
/* 1E677 */ { NULL,NULL},
/* 1E678 */ { NULL,NULL},
/* 1E679 */ { NULL,NULL},
/* 1E67A */ { NULL,NULL},
/* 1E67B */ { NULL,NULL},
/* 1E67C */ { NULL,NULL},
/* 1E67D */ { NULL,NULL},
/* 1E67E */ { NULL,NULL},
/* 1E67F */ { NULL,NULL},
/* 1E680 */ { NULL,NULL},
/* 1E681 */ { NULL,NULL},
/* 1E682 */ { NULL,NULL},
/* 1E683 */ { NULL,NULL},
/* 1E684 */ { NULL,NULL},
/* 1E685 */ { NULL,NULL},
/* 1E686 */ { NULL,NULL},
/* 1E687 */ { NULL,NULL},
/* 1E688 */ { NULL,NULL},
/* 1E689 */ { NULL,NULL},
/* 1E68A */ { NULL,NULL},
/* 1E68B */ { NULL,NULL},
/* 1E68C */ { NULL,NULL},
/* 1E68D */ { NULL,NULL},
/* 1E68E */ { NULL,NULL},
/* 1E68F */ { NULL,NULL},
/* 1E690 */ { NULL,NULL},
/* 1E691 */ { NULL,NULL},
/* 1E692 */ { NULL,NULL},
/* 1E693 */ { NULL,NULL},
/* 1E694 */ { NULL,NULL},
/* 1E695 */ { NULL,NULL},
/* 1E696 */ { NULL,NULL},
/* 1E697 */ { NULL,NULL},
/* 1E698 */ { NULL,NULL},
/* 1E699 */ { NULL,NULL},
/* 1E69A */ { NULL,NULL},
/* 1E69B */ { NULL,NULL},
/* 1E69C */ { NULL,NULL},
/* 1E69D */ { NULL,NULL},
/* 1E69E */ { NULL,NULL},
/* 1E69F */ { NULL,NULL},
/* 1E6A0 */ { NULL,NULL},
/* 1E6A1 */ { NULL,NULL},
/* 1E6A2 */ { NULL,NULL},
/* 1E6A3 */ { NULL,NULL},
/* 1E6A4 */ { NULL,NULL},
/* 1E6A5 */ { NULL,NULL},
/* 1E6A6 */ { NULL,NULL},
/* 1E6A7 */ { NULL,NULL},
/* 1E6A8 */ { NULL,NULL},
/* 1E6A9 */ { NULL,NULL},
/* 1E6AA */ { NULL,NULL},
/* 1E6AB */ { NULL,NULL},
/* 1E6AC */ { NULL,NULL},
/* 1E6AD */ { NULL,NULL},
/* 1E6AE */ { NULL,NULL},
/* 1E6AF */ { NULL,NULL},
/* 1E6B0 */ { NULL,NULL},
/* 1E6B1 */ { NULL,NULL},
/* 1E6B2 */ { NULL,NULL},
/* 1E6B3 */ { NULL,NULL},
/* 1E6B4 */ { NULL,NULL},
/* 1E6B5 */ { NULL,NULL},
/* 1E6B6 */ { NULL,NULL},
/* 1E6B7 */ { NULL,NULL},
/* 1E6B8 */ { NULL,NULL},
/* 1E6B9 */ { NULL,NULL},
/* 1E6BA */ { NULL,NULL},
/* 1E6BB */ { NULL,NULL},
/* 1E6BC */ { NULL,NULL},
/* 1E6BD */ { NULL,NULL},
/* 1E6BE */ { NULL,NULL},
/* 1E6BF */ { NULL,NULL},
/* 1E6C0 */ { "LETTRE TAÏ-YO KO BAS",NULL},
/* 1E6C1 */ { "LETTRE TAÏ-YO KO HAUT",NULL},
/* 1E6C2 */ { "LETTRE TAÏ-YO KHO BAS",NULL},
/* 1E6C3 */ { "LETTRE TAÏ-YO KHO HAUT",NULL},
/* 1E6C4 */ { "LETTRE TAÏ-YO GO",NULL},
/* 1E6C5 */ { "LETTRE TAÏ-YO NGO",NULL},
/* 1E6C6 */ { "LETTRE TAÏ-YO TCHO",NULL},
/* 1E6C7 */ { "LETTRE TAÏ-YO XO BAS",NULL},
/* 1E6C8 */ { "LETTRE TAÏ-YO XO HAUT",NULL},
/* 1E6C9 */ { "LETTRE TAÏ-YO ÑO BAS",NULL},
/* 1E6CA */ { "LETTRE TAÏ-YO ÑO HAUT",NULL},
/* 1E6CB */ { "LETTRE TAÏ-YO DO",NULL},
/* 1E6CC */ { "LETTRE TAÏ-YO TO BAS",NULL},
/* 1E6CD */ { "LETTRE TAÏ-YO TO HAUT",NULL},
/* 1E6CE */ { "LETTRE TAÏ-YO THO",NULL},
/* 1E6CF */ { "LETTRE TAÏ-YO NO",NULL},
/* 1E6D0 */ { "LETTRE TAÏ-YO BO",NULL},
/* 1E6D1 */ { "LETTRE TAÏ-YO PO BAS",NULL},
/* 1E6D2 */ { "LETTRE TAÏ-YO PO HAUT",NULL},
/* 1E6D3 */ { "LETTRE TAÏ-YO PHO","	= p'o"},
/* 1E6D4 */ { "LETTRE TAÏ-YO FO BAS",NULL},
/* 1E6D5 */ { "LETTRE TAÏ-YO FO HAUT",NULL},
/* 1E6D6 */ { "LETTRE TAÏ-YO MO",NULL},
/* 1E6D7 */ { "LETTRE TAÏ-YO YO",NULL},
/* 1E6D8 */ { "LETTRE TAÏ-YO LO",NULL},
/* 1E6D9 */ { "LETTRE TAÏ-YO VO",NULL},
/* 1E6DA */ { "LETTRE TAÏ-YO HO BAS",NULL},
/* 1E6DB */ { "LETTRE TAÏ-YO HO HAUT",NULL},
/* 1E6DC */ { "LETTRE TAÏ-YO QO",NULL},
/* 1E6DD */ { "LETTRE TAÏ-YO KVO BAS",NULL},
/* 1E6DE */ { "LETTRE TAÏ-YO KVO HAUT",NULL},
/* 1E6DF */ { NULL,NULL},
/* 1E6E0 */ { "LETTRE TAÏ-YO Â",NULL},
/* 1E6E1 */ { "LETTRE TAÏ-YO I",NULL},
/* 1E6E2 */ { "LETTRE TAÏ-YO U",NULL},
/* 1E6E3 */ { "SIGNE TAÏ-YO U",NULL},
/* 1E6E4 */ { "LETTRE TAÏ-YO OU",NULL},
/* 1E6E5 */ { "LETTRE TAÏ-YO Æ",NULL},
/* 1E6E6 */ { "SIGNE TAÏ-YO AOU",NULL},
/* 1E6E7 */ { "LETTRE TAÏ-YO O",NULL},
/* 1E6E8 */ { "LETTRE TAÏ-YO É",NULL},
/* 1E6E9 */ { "LETTRE TAÏ-YO IA",NULL},
/* 1E6EA */ { "LETTRE TAÏ-YO UA",NULL},
/* 1E6EB */ { "LETTRE TAÏ-YO OUA",NULL},
/* 1E6EC */ { "LETTRE TAÏ-YO Ô",NULL},
/* 1E6ED */ { "LETTRE TAÏ-YO AU",NULL},
/* 1E6EE */ { "SIGNE TAÏ-YO AÏ",NULL},
/* 1E6EF */ { "SIGNE TAÏ-YO ANG",NULL},
/* 1E6F0 */ { "LETTRE TAÏ-YO AN",NULL},
/* 1E6F1 */ { "LETTRE TAÏ-YO AM",NULL},
/* 1E6F2 */ { "LETTRE TAÏ-YO AK",NULL},
/* 1E6F3 */ { "LETTRE TAÏ-YO AT",NULL},
/* 1E6F4 */ { "LETTRE TAÏ-YO AP",NULL},
/* 1E6F5 */ { "SIGNE TAÏ-YO OM",NULL},
/* 1E6F6 */ { NULL,NULL},
/* 1E6F7 */ { NULL,NULL},
/* 1E6F8 */ { NULL,NULL},
/* 1E6F9 */ { NULL,NULL},
/* 1E6FA */ { NULL,NULL},
/* 1E6FB */ { NULL,NULL},
/* 1E6FC */ { NULL,NULL},
/* 1E6FD */ { NULL,NULL},
/* 1E6FE */ { "SYMBOLE TAÏ-YO MUANG",NULL},
/* 1E6FF */ { "XAM LAI TAÏ-YO",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E7[] = {
/* 1E700 */ { NULL,NULL},
/* 1E701 */ { NULL,NULL},
/* 1E702 */ { NULL,NULL},
/* 1E703 */ { NULL,NULL},
/* 1E704 */ { NULL,NULL},
/* 1E705 */ { NULL,NULL},
/* 1E706 */ { NULL,NULL},
/* 1E707 */ { NULL,NULL},
/* 1E708 */ { NULL,NULL},
/* 1E709 */ { NULL,NULL},
/* 1E70A */ { NULL,NULL},
/* 1E70B */ { NULL,NULL},
/* 1E70C */ { NULL,NULL},
/* 1E70D */ { NULL,NULL},
/* 1E70E */ { NULL,NULL},
/* 1E70F */ { NULL,NULL},
/* 1E710 */ { NULL,NULL},
/* 1E711 */ { NULL,NULL},
/* 1E712 */ { NULL,NULL},
/* 1E713 */ { NULL,NULL},
/* 1E714 */ { NULL,NULL},
/* 1E715 */ { NULL,NULL},
/* 1E716 */ { NULL,NULL},
/* 1E717 */ { NULL,NULL},
/* 1E718 */ { NULL,NULL},
/* 1E719 */ { NULL,NULL},
/* 1E71A */ { NULL,NULL},
/* 1E71B */ { NULL,NULL},
/* 1E71C */ { NULL,NULL},
/* 1E71D */ { NULL,NULL},
/* 1E71E */ { NULL,NULL},
/* 1E71F */ { NULL,NULL},
/* 1E720 */ { NULL,NULL},
/* 1E721 */ { NULL,NULL},
/* 1E722 */ { NULL,NULL},
/* 1E723 */ { NULL,NULL},
/* 1E724 */ { NULL,NULL},
/* 1E725 */ { NULL,NULL},
/* 1E726 */ { NULL,NULL},
/* 1E727 */ { NULL,NULL},
/* 1E728 */ { NULL,NULL},
/* 1E729 */ { NULL,NULL},
/* 1E72A */ { NULL,NULL},
/* 1E72B */ { NULL,NULL},
/* 1E72C */ { NULL,NULL},
/* 1E72D */ { NULL,NULL},
/* 1E72E */ { NULL,NULL},
/* 1E72F */ { NULL,NULL},
/* 1E730 */ { NULL,NULL},
/* 1E731 */ { NULL,NULL},
/* 1E732 */ { NULL,NULL},
/* 1E733 */ { NULL,NULL},
/* 1E734 */ { NULL,NULL},
/* 1E735 */ { NULL,NULL},
/* 1E736 */ { NULL,NULL},
/* 1E737 */ { NULL,NULL},
/* 1E738 */ { NULL,NULL},
/* 1E739 */ { NULL,NULL},
/* 1E73A */ { NULL,NULL},
/* 1E73B */ { NULL,NULL},
/* 1E73C */ { NULL,NULL},
/* 1E73D */ { NULL,NULL},
/* 1E73E */ { NULL,NULL},
/* 1E73F */ { NULL,NULL},
/* 1E740 */ { NULL,NULL},
/* 1E741 */ { NULL,NULL},
/* 1E742 */ { NULL,NULL},
/* 1E743 */ { NULL,NULL},
/* 1E744 */ { NULL,NULL},
/* 1E745 */ { NULL,NULL},
/* 1E746 */ { NULL,NULL},
/* 1E747 */ { NULL,NULL},
/* 1E748 */ { NULL,NULL},
/* 1E749 */ { NULL,NULL},
/* 1E74A */ { NULL,NULL},
/* 1E74B */ { NULL,NULL},
/* 1E74C */ { NULL,NULL},
/* 1E74D */ { NULL,NULL},
/* 1E74E */ { NULL,NULL},
/* 1E74F */ { NULL,NULL},
/* 1E750 */ { NULL,NULL},
/* 1E751 */ { NULL,NULL},
/* 1E752 */ { NULL,NULL},
/* 1E753 */ { NULL,NULL},
/* 1E754 */ { NULL,NULL},
/* 1E755 */ { NULL,NULL},
/* 1E756 */ { NULL,NULL},
/* 1E757 */ { NULL,NULL},
/* 1E758 */ { NULL,NULL},
/* 1E759 */ { NULL,NULL},
/* 1E75A */ { NULL,NULL},
/* 1E75B */ { NULL,NULL},
/* 1E75C */ { NULL,NULL},
/* 1E75D */ { NULL,NULL},
/* 1E75E */ { NULL,NULL},
/* 1E75F */ { NULL,NULL},
/* 1E760 */ { NULL,NULL},
/* 1E761 */ { NULL,NULL},
/* 1E762 */ { NULL,NULL},
/* 1E763 */ { NULL,NULL},
/* 1E764 */ { NULL,NULL},
/* 1E765 */ { NULL,NULL},
/* 1E766 */ { NULL,NULL},
/* 1E767 */ { NULL,NULL},
/* 1E768 */ { NULL,NULL},
/* 1E769 */ { NULL,NULL},
/* 1E76A */ { NULL,NULL},
/* 1E76B */ { NULL,NULL},
/* 1E76C */ { NULL,NULL},
/* 1E76D */ { NULL,NULL},
/* 1E76E */ { NULL,NULL},
/* 1E76F */ { NULL,NULL},
/* 1E770 */ { NULL,NULL},
/* 1E771 */ { NULL,NULL},
/* 1E772 */ { NULL,NULL},
/* 1E773 */ { NULL,NULL},
/* 1E774 */ { NULL,NULL},
/* 1E775 */ { NULL,NULL},
/* 1E776 */ { NULL,NULL},
/* 1E777 */ { NULL,NULL},
/* 1E778 */ { NULL,NULL},
/* 1E779 */ { NULL,NULL},
/* 1E77A */ { NULL,NULL},
/* 1E77B */ { NULL,NULL},
/* 1E77C */ { NULL,NULL},
/* 1E77D */ { NULL,NULL},
/* 1E77E */ { NULL,NULL},
/* 1E77F */ { NULL,NULL},
/* 1E780 */ { NULL,NULL},
/* 1E781 */ { NULL,NULL},
/* 1E782 */ { NULL,NULL},
/* 1E783 */ { NULL,NULL},
/* 1E784 */ { NULL,NULL},
/* 1E785 */ { NULL,NULL},
/* 1E786 */ { NULL,NULL},
/* 1E787 */ { NULL,NULL},
/* 1E788 */ { NULL,NULL},
/* 1E789 */ { NULL,NULL},
/* 1E78A */ { NULL,NULL},
/* 1E78B */ { NULL,NULL},
/* 1E78C */ { NULL,NULL},
/* 1E78D */ { NULL,NULL},
/* 1E78E */ { NULL,NULL},
/* 1E78F */ { NULL,NULL},
/* 1E790 */ { NULL,NULL},
/* 1E791 */ { NULL,NULL},
/* 1E792 */ { NULL,NULL},
/* 1E793 */ { NULL,NULL},
/* 1E794 */ { NULL,NULL},
/* 1E795 */ { NULL,NULL},
/* 1E796 */ { NULL,NULL},
/* 1E797 */ { NULL,NULL},
/* 1E798 */ { NULL,NULL},
/* 1E799 */ { NULL,NULL},
/* 1E79A */ { NULL,NULL},
/* 1E79B */ { NULL,NULL},
/* 1E79C */ { NULL,NULL},
/* 1E79D */ { NULL,NULL},
/* 1E79E */ { NULL,NULL},
/* 1E79F */ { NULL,NULL},
/* 1E7A0 */ { NULL,NULL},
/* 1E7A1 */ { NULL,NULL},
/* 1E7A2 */ { NULL,NULL},
/* 1E7A3 */ { NULL,NULL},
/* 1E7A4 */ { NULL,NULL},
/* 1E7A5 */ { NULL,NULL},
/* 1E7A6 */ { NULL,NULL},
/* 1E7A7 */ { NULL,NULL},
/* 1E7A8 */ { NULL,NULL},
/* 1E7A9 */ { NULL,NULL},
/* 1E7AA */ { NULL,NULL},
/* 1E7AB */ { NULL,NULL},
/* 1E7AC */ { NULL,NULL},
/* 1E7AD */ { NULL,NULL},
/* 1E7AE */ { NULL,NULL},
/* 1E7AF */ { NULL,NULL},
/* 1E7B0 */ { NULL,NULL},
/* 1E7B1 */ { NULL,NULL},
/* 1E7B2 */ { NULL,NULL},
/* 1E7B3 */ { NULL,NULL},
/* 1E7B4 */ { NULL,NULL},
/* 1E7B5 */ { NULL,NULL},
/* 1E7B6 */ { NULL,NULL},
/* 1E7B7 */ { NULL,NULL},
/* 1E7B8 */ { NULL,NULL},
/* 1E7B9 */ { NULL,NULL},
/* 1E7BA */ { NULL,NULL},
/* 1E7BB */ { NULL,NULL},
/* 1E7BC */ { NULL,NULL},
/* 1E7BD */ { NULL,NULL},
/* 1E7BE */ { NULL,NULL},
/* 1E7BF */ { NULL,NULL},
/* 1E7C0 */ { NULL,NULL},
/* 1E7C1 */ { NULL,NULL},
/* 1E7C2 */ { NULL,NULL},
/* 1E7C3 */ { NULL,NULL},
/* 1E7C4 */ { NULL,NULL},
/* 1E7C5 */ { NULL,NULL},
/* 1E7C6 */ { NULL,NULL},
/* 1E7C7 */ { NULL,NULL},
/* 1E7C8 */ { NULL,NULL},
/* 1E7C9 */ { NULL,NULL},
/* 1E7CA */ { NULL,NULL},
/* 1E7CB */ { NULL,NULL},
/* 1E7CC */ { NULL,NULL},
/* 1E7CD */ { NULL,NULL},
/* 1E7CE */ { NULL,NULL},
/* 1E7CF */ { NULL,NULL},
/* 1E7D0 */ { NULL,NULL},
/* 1E7D1 */ { NULL,NULL},
/* 1E7D2 */ { NULL,NULL},
/* 1E7D3 */ { NULL,NULL},
/* 1E7D4 */ { NULL,NULL},
/* 1E7D5 */ { NULL,NULL},
/* 1E7D6 */ { NULL,NULL},
/* 1E7D7 */ { NULL,NULL},
/* 1E7D8 */ { NULL,NULL},
/* 1E7D9 */ { NULL,NULL},
/* 1E7DA */ { NULL,NULL},
/* 1E7DB */ { NULL,NULL},
/* 1E7DC */ { NULL,NULL},
/* 1E7DD */ { NULL,NULL},
/* 1E7DE */ { NULL,NULL},
/* 1E7DF */ { NULL,NULL},
/* 1E7E0 */ { "SYLLABE ÉTHIOPIENNE HHYÄ","	x (syllabe éthiopienne xyä - 2DD0)"},
/* 1E7E1 */ { "SYLLABE ÉTHIOPIENNE HHYOU","	x (syllabe éthiopienne xyou - 2DD1)"},
/* 1E7E2 */ { "SYLLABE ÉTHIOPIENNE HHYI","	x (syllabe éthiopienne xyi - 2DD2)"},
/* 1E7E3 */ { "SYLLABE ÉTHIOPIENNE HHYA","	x (syllabe éthiopienne xya - 2DD3)"},
/* 1E7E4 */ { "SYLLABE ÉTHIOPIENNE HHYÉ","	x (syllabe éthiopienne xyé - 2DD4)"},
/* 1E7E5 */ { "SYLLABE ÉTHIOPIENNE HHYE","	x (syllabe éthiopienne xye - 2DD5)"},
/* 1E7E6 */ { "SYLLABE ÉTHIOPIENNE HHYO","	x (syllabe éthiopienne xyo - 2DD6)"},
/* 1E7E7 */ { NULL,NULL},
/* 1E7E8 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ HHWÄ","	x (syllabe éthiopienne kxwä - 12C0)"},
/* 1E7E9 */ { "SYLLABE ÉTHIOPIENNE HHWI","	x (syllabe éthiopienne kxwi - 12C2)"},
/* 1E7EA */ { "SYLLABE ÉTHIOPIENNE HHWÉ","	x (syllabe éthiopienne kxwé - 12C4)"},
/* 1E7EB */ { "SYLLABE ÉTHIOPIENNE HHWE","	x (syllabe éthiopienne kxwe - 12C5)"},
/* 1E7EC */ { NULL,NULL},
/* 1E7ED */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ MWI","	x (syllabe éthiopienne mwi - 1381)"},
/* 1E7EE */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ MWÉ","	x (syllabe éthiopienne mwé - 1382)"},
/* 1E7EF */ { NULL,NULL},
/* 1E7F0 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ QWI","	x (syllabe éthiopienne qwi - 124A)"},
/* 1E7F1 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ QWÉ","	x (syllabe éthiopienne qwé - 124C)"},
/* 1E7F2 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ QWE","	x (syllabe éthiopienne qwe - 124D)"},
/* 1E7F3 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ BWI","	x (syllabe éthiopienne bwi - 1385)"},
/* 1E7F4 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ BWÉ","	x (syllabe éthiopienne bwé - 1386)"},
/* 1E7F5 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ KWI","	x (syllabe éthiopienne kwi - 12B2)"},
/* 1E7F6 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ KWÉ","	x (syllabe éthiopienne kwé - 12B4)"},
/* 1E7F7 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ KWE","	x (syllabe éthiopienne kwe - 12B5)"},
/* 1E7F8 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ GWI","	x (syllabe éthiopienne gwi - 1312)"},
/* 1E7F9 */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ GWÉ","	x (syllabe éthiopienne gwé - 1314)"},
/* 1E7FA */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ GWE","	x (syllabe éthiopienne gwe - 1315)"},
/* 1E7FB */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ FWI","	x (syllabe éthiopienne fwi - 1389)"},
/* 1E7FC */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ FWÉ","	x (syllabe éthiopienne fwé - 138A)"},
/* 1E7FD */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ PWI","	x (syllabe éthiopienne pwi - 138D)"},
/* 1E7FE */ { "SYLLABE ÉTHIOPIENNE GOURAGÉ PWÉ","	x (syllabe éthiopienne pwé - 138E)"},
/* 1E7FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E8[] = {
/* 1E800 */ { "SYLLABE MENDÉ KIKAKUI M001 KI",NULL},
/* 1E801 */ { "SYLLABE MENDÉ KIKAKUI M002 KA",NULL},
/* 1E802 */ { "SYLLABE MENDÉ KIKAKUI M003 KU",NULL},
/* 1E803 */ { "SYLLABE MENDÉ KIKAKUI M065 KEE",NULL},
/* 1E804 */ { "SYLLABE MENDÉ KIKAKUI M095 KE",NULL},
/* 1E805 */ { "SYLLABE MENDÉ KIKAKUI M076 KOO",NULL},
/* 1E806 */ { "SYLLABE MENDÉ KIKAKUI M048 KO",NULL},
/* 1E807 */ { "SYLLABE MENDÉ KIKAKUI M179 KUA","	* équivalent de M177 de Dalby"},
/* 1E808 */ { "SYLLABE MENDÉ KIKAKUI M004 WI",NULL},
/* 1E809 */ { "SYLLABE MENDÉ KIKAKUI M005 WA",NULL},
/* 1E80A */ { "SYLLABE MENDÉ KIKAKUI M006 WU",NULL},
/* 1E80B */ { "SYLLABE MENDÉ KIKAKUI M126 WEE",NULL},
/* 1E80C */ { "SYLLABE MENDÉ KIKAKUI M118 WE",NULL},
/* 1E80D */ { "SYLLABE MENDÉ KIKAKUI M114 WOO",NULL},
/* 1E80E */ { "SYLLABE MENDÉ KIKAKUI M045 WO",NULL},
/* 1E80F */ { "SYLLABE MENDÉ KIKAKUI M194 WUI",NULL},
/* 1E810 */ { "SYLLABE MENDÉ KIKAKUI M143 WEI",NULL},
/* 1E811 */ { "SYLLABE MENDÉ KIKAKUI M061 WVI",NULL},
/* 1E812 */ { "SYLLABE MENDÉ KIKAKUI M049 WVA",NULL},
/* 1E813 */ { "SYLLABE MENDÉ KIKAKUI M139 WVE",NULL},
/* 1E814 */ { "SYLLABE MENDÉ KIKAKUI M007 MIN",NULL},
/* 1E815 */ { "SYLLABE MENDÉ KIKAKUI M008 MAN",NULL},
/* 1E816 */ { "SYLLABE MENDÉ KIKAKUI M009 MUN",NULL},
/* 1E817 */ { "SYLLABE MENDÉ KIKAKUI M059 MEN",NULL},
/* 1E818 */ { "SYLLABE MENDÉ KIKAKUI M094 MON",NULL},
/* 1E819 */ { "SYLLABE MENDÉ KIKAKUI M154 MUAN",NULL},
/* 1E81A */ { "SYLLABE MENDÉ KIKAKUI M189 MUEN",NULL},
/* 1E81B */ { "SYLLABE MENDÉ KIKAKUI M010 BI",NULL},
/* 1E81C */ { "SYLLABE MENDÉ KIKAKUI M011 BA",NULL},
/* 1E81D */ { "SYLLABE MENDÉ KIKAKUI M012 BU",NULL},
/* 1E81E */ { "SYLLABE MENDÉ KIKAKUI M150 BEE",NULL},
/* 1E81F */ { "SYLLABE MENDÉ KIKAKUI M097 BE",NULL},
/* 1E820 */ { "SYLLABE MENDÉ KIKAKUI M103 BOO",NULL},
/* 1E821 */ { "SYLLABE MENDÉ KIKAKUI M138 BO",NULL},
/* 1E822 */ { "SYLLABE MENDÉ KIKAKUI M013 I",NULL},
/* 1E823 */ { "SYLLABE MENDÉ KIKAKUI M014 A",NULL},
/* 1E824 */ { "SYLLABE MENDÉ KIKAKUI M015 U",NULL},
/* 1E825 */ { "SYLLABE MENDÉ KIKAKUI M163 EE",NULL},
/* 1E826 */ { "SYLLABE MENDÉ KIKAKUI M100 E",NULL},
/* 1E827 */ { "SYLLABE MENDÉ KIKAKUI M165 OO",NULL},
/* 1E828 */ { "SYLLABE MENDÉ KIKAKUI M147 O",NULL},
/* 1E829 */ { "SYLLABE MENDÉ KIKAKUI M137 EI",NULL},
/* 1E82A */ { "SYLLABE MENDÉ KIKAKUI M131 IN",NULL},
/* 1E82B */ { "SYLLABE MENDÉ KIKAKUI M135 IN","	* s'utilise pour la particule de négation"},
/* 1E82C */ { "SYLLABE MENDÉ KIKAKUI M195 AN","	* M195 (HO) de Dalby a une forme et une valeur différentes"},
/* 1E82D */ { "SYLLABE MENDÉ KIKAKUI M178 EN","	* équivalent de M182 de Dalby"},
/* 1E82E */ { "SYLLABE MENDÉ KIKAKUI M019 SI",NULL},
/* 1E82F */ { "SYLLABE MENDÉ KIKAKUI M020 SA",NULL},
/* 1E830 */ { "SYLLABE MENDÉ KIKAKUI M021 SU",NULL},
/* 1E831 */ { "SYLLABE MENDÉ KIKAKUI M162 SEE",NULL},
/* 1E832 */ { "SYLLABE MENDÉ KIKAKUI M116 SE",NULL},
/* 1E833 */ { "SYLLABE MENDÉ KIKAKUI M136 SOO",NULL},
/* 1E834 */ { "SYLLABE MENDÉ KIKAKUI M079 SO",NULL},
/* 1E835 */ { "SYLLABE MENDÉ KIKAKUI M196 SIA","	* ni dans Dalby ni dans Mansaray"},
/* 1E836 */ { "SYLLABE MENDÉ KIKAKUI M025 LI","	* équivalent de M022 de Dalby et Mansaray"},
/* 1E837 */ { "SYLLABE MENDÉ KIKAKUI M026 LA","	* équivalent de M023 de Dalby et Mansaray"},
/* 1E838 */ { "SYLLABE MENDÉ KIKAKUI M027 LU","	* équivalent de M024 de Dalby et Mansaray"},
/* 1E839 */ { "SYLLABE MENDÉ KIKAKUI M084 LEE",NULL},
/* 1E83A */ { "SYLLABE MENDÉ KIKAKUI M073 LE",NULL},
/* 1E83B */ { "SYLLABE MENDÉ KIKAKUI M054 LOO",NULL},
/* 1E83C */ { "SYLLABE MENDÉ KIKAKUI M153 LO",NULL},
/* 1E83D */ { "SYLLABE MENDÉ KIKAKUI M110 LE LONG",NULL},
/* 1E83E */ { "SYLLABE MENDÉ KIKAKUI M016 DI",NULL},
/* 1E83F */ { "SYLLABE MENDÉ KIKAKUI M017 DA",NULL},
/* 1E840 */ { "SYLLABE MENDÉ KIKAKUI M018 DU",NULL},
/* 1E841 */ { "SYLLABE MENDÉ KIKAKUI M089 DEE",NULL},
/* 1E842 */ { "SYLLABE MENDÉ KIKAKUI M180 DOO","	* équivalent de M178 de Dalby"},
/* 1E843 */ { "SYLLABE MENDÉ KIKAKUI M181 DO","	* équivalent de M179 de Dalby"},
/* 1E844 */ { "SYLLABE MENDÉ KIKAKUI M022 TI","	* équivalent de M025 de Dalby et Mansaray"},
/* 1E845 */ { "SYLLABE MENDÉ KIKAKUI M023 TA","	* équivalent de M026 de Dalby et Mansaray"},
/* 1E846 */ { "SYLLABE MENDÉ KIKAKUI M024 TU","	* équivalent de M027 de Dalby et Mansaray"},
/* 1E847 */ { "SYLLABE MENDÉ KIKAKUI M091 TEE",NULL},
/* 1E848 */ { "SYLLABE MENDÉ KIKAKUI M055 TE",NULL},
/* 1E849 */ { "SYLLABE MENDÉ KIKAKUI M104 TOO",NULL},
/* 1E84A */ { "SYLLABE MENDÉ KIKAKUI M069 TO",NULL},
/* 1E84B */ { "SYLLABE MENDÉ KIKAKUI M028 JI","	* équivalent de M034 de Mansaray"},
/* 1E84C */ { "SYLLABE MENDÉ KIKAKUI M029 JA","	* équivalent de M035 de Mansaray"},
/* 1E84D */ { "SYLLABE MENDÉ KIKAKUI M030 JU","	* équivalent de M036 de Mansaray"},
/* 1E84E */ { "SYLLABE MENDÉ KIKAKUI M157 JEE",NULL},
/* 1E84F */ { "SYLLABE MENDÉ KIKAKUI M113 JE",NULL},
/* 1E850 */ { "SYLLABE MENDÉ KIKAKUI M160 JOO",NULL},
/* 1E851 */ { "SYLLABE MENDÉ KIKAKUI M063 JO",NULL},
/* 1E852 */ { "SYLLABE MENDÉ KIKAKUI M175 JO LONG",NULL},
/* 1E853 */ { "SYLLABE MENDÉ KIKAKUI M031 YI",NULL},
/* 1E854 */ { "SYLLABE MENDÉ KIKAKUI M032 YA",NULL},
/* 1E855 */ { "SYLLABE MENDÉ KIKAKUI M033 YU",NULL},
/* 1E856 */ { "SYLLABE MENDÉ KIKAKUI M109 YEE",NULL},
/* 1E857 */ { "SYLLABE MENDÉ KIKAKUI M080 YE",NULL},
/* 1E858 */ { "SYLLABE MENDÉ KIKAKUI M141 YOO",NULL},
/* 1E859 */ { "SYLLABE MENDÉ KIKAKUI M121 YO",NULL},
/* 1E85A */ { "SYLLABE MENDÉ KIKAKUI M034 FI","	* équivalent de M028 de Mansaray"},
/* 1E85B */ { "SYLLABE MENDÉ KIKAKUI M035 FA","	* équivalent de M029 de Mansaray"},
/* 1E85C */ { "SYLLABE MENDÉ KIKAKUI M036 FU","	* équivalent de M030 de Mansaray"},
/* 1E85D */ { "SYLLABE MENDÉ KIKAKUI M078 FEE",NULL},
/* 1E85E */ { "SYLLABE MENDÉ KIKAKUI M075 FE",NULL},
/* 1E85F */ { "SYLLABE MENDÉ KIKAKUI M133 FOO",NULL},
/* 1E860 */ { "SYLLABE MENDÉ KIKAKUI M088 FO",NULL},
/* 1E861 */ { "SYLLABE MENDÉ KIKAKUI M197 FUA","	* ni dans Dalby ni dans Mansaray"},
/* 1E862 */ { "SYLLABE MENDÉ KIKAKUI M101 FAN",NULL},
/* 1E863 */ { "SYLLABE MENDÉ KIKAKUI M037 NIN",NULL},
/* 1E864 */ { "SYLLABE MENDÉ KIKAKUI M038 NAN",NULL},
/* 1E865 */ { "SYLLABE MENDÉ KIKAKUI M039 NUN",NULL},
/* 1E866 */ { "SYLLABE MENDÉ KIKAKUI M117 NEN",NULL},
/* 1E867 */ { "SYLLABE MENDÉ KIKAKUI M169 NON",NULL},
/* 1E868 */ { "SYLLABE MENDÉ KIKAKUI M176 HI",NULL},
/* 1E869 */ { "SYLLABE MENDÉ KIKAKUI M041 HA",NULL},
/* 1E86A */ { "SYLLABE MENDÉ KIKAKUI M186 HU",NULL},
/* 1E86B */ { "SYLLABE MENDÉ KIKAKUI M040 HEE",NULL},
/* 1E86C */ { "SYLLABE MENDÉ KIKAKUI M096 HE",NULL},
/* 1E86D */ { "SYLLABE MENDÉ KIKAKUI M042 HOO",NULL},
/* 1E86E */ { "SYLLABE MENDÉ KIKAKUI M140 HO",NULL},
/* 1E86F */ { "SYLLABE MENDÉ KIKAKUI M083 HEEI",NULL},
/* 1E870 */ { "SYLLABE MENDÉ KIKAKUI M128 HOOU",NULL},
/* 1E871 */ { "SYLLABE MENDÉ KIKAKUI M053 HIN",NULL},
/* 1E872 */ { "SYLLABE MENDÉ KIKAKUI M130 HAN",NULL},
/* 1E873 */ { "SYLLABE MENDÉ KIKAKUI M087 HUN",NULL},
/* 1E874 */ { "SYLLABE MENDÉ KIKAKUI M052 HEN",NULL},
/* 1E875 */ { "SYLLABE MENDÉ KIKAKUI M193 HON","	* M193 (NGGÊ) de Dalby a une forme et une valeur différentes"},
/* 1E876 */ { "SYLLABE MENDÉ KIKAKUI M046 HUAN",NULL},
/* 1E877 */ { "SYLLABE MENDÉ KIKAKUI M090 NGGI",NULL},
/* 1E878 */ { "SYLLABE MENDÉ KIKAKUI M043 NGGA",NULL},
/* 1E879 */ { "SYLLABE MENDÉ KIKAKUI M082 NGGU",NULL},
/* 1E87A */ { "SYLLABE MENDÉ KIKAKUI M115 NGGEE",NULL},
/* 1E87B */ { "SYLLABE MENDÉ KIKAKUI M146 NGGE",NULL},
/* 1E87C */ { "SYLLABE MENDÉ KIKAKUI M156 NGGOO",NULL},
/* 1E87D */ { "SYLLABE MENDÉ KIKAKUI M120 NGGO",NULL},
/* 1E87E */ { "SYLLABE MENDÉ KIKAKUI M159 NGGAA",NULL},
/* 1E87F */ { "SYLLABE MENDÉ KIKAKUI M127 NGGUA",NULL},
/* 1E880 */ { "SYLLABE MENDÉ KIKAKUI M086 NGGE LONG",NULL},
/* 1E881 */ { "SYLLABE MENDÉ KIKAKUI M106 NGGOO LONG",NULL},
/* 1E882 */ { "SYLLABE MENDÉ KIKAKUI M183 NGGO LONG",NULL},
/* 1E883 */ { "SYLLABE MENDÉ KIKAKUI M155 GI",NULL},
/* 1E884 */ { "SYLLABE MENDÉ KIKAKUI M111 GA",NULL},
/* 1E885 */ { "SYLLABE MENDÉ KIKAKUI M168 GU",NULL},
/* 1E886 */ { "SYLLABE MENDÉ KIKAKUI M190 GEE",NULL},
/* 1E887 */ { "SYLLABE MENDÉ KIKAKUI M166 GUEI",NULL},
/* 1E888 */ { "SYLLABE MENDÉ KIKAKUI M167 GUAN",NULL},
/* 1E889 */ { "SYLLABE MENDÉ KIKAKUI M184 NGEN",NULL},
/* 1E88A */ { "SYLLABE MENDÉ KIKAKUI M057 NGON",NULL},
/* 1E88B */ { "SYLLABE MENDÉ KIKAKUI M177 NGUAN","	* équivalent de M181 de Dalby"},
/* 1E88C */ { "SYLLABE MENDÉ KIKAKUI M068 PI",NULL},
/* 1E88D */ { "SYLLABE MENDÉ KIKAKUI M099 PA",NULL},
/* 1E88E */ { "SYLLABE MENDÉ KIKAKUI M050 PU",NULL},
/* 1E88F */ { "SYLLABE MENDÉ KIKAKUI M081 PEE",NULL},
/* 1E890 */ { "SYLLABE MENDÉ KIKAKUI M051 PE",NULL},
/* 1E891 */ { "SYLLABE MENDÉ KIKAKUI M102 POO",NULL},
/* 1E892 */ { "SYLLABE MENDÉ KIKAKUI M066 PO",NULL},
/* 1E893 */ { "SYLLABE MENDÉ KIKAKUI M145 MBI",NULL},
/* 1E894 */ { "SYLLABE MENDÉ KIKAKUI M062 MBA",NULL},
/* 1E895 */ { "SYLLABE MENDÉ KIKAKUI M122 MBU",NULL},
/* 1E896 */ { "SYLLABE MENDÉ KIKAKUI M047 MBEE",NULL},
/* 1E897 */ { "SYLLABE MENDÉ KIKAKUI M188 MBEE",NULL},
/* 1E898 */ { "SYLLABE MENDÉ KIKAKUI M072 MBE",NULL},
/* 1E899 */ { "SYLLABE MENDÉ KIKAKUI M172 MBO","	* le nom formel de ce caractère en anglais est erroné"},
/* 1E89A */ { "SYLLABE MENDÉ KIKAKUI M174 MBOO","	* le nom formel de ce caractère en anglais est erroné"},
/* 1E89B */ { "SYLLABE MENDÉ KIKAKUI M187 MBUU",NULL},
/* 1E89C */ { "SYLLABE MENDÉ KIKAKUI M161 MBE LONG",NULL},
/* 1E89D */ { "SYLLABE MENDÉ KIKAKUI M105 MBOO LONG",NULL},
/* 1E89E */ { "SYLLABE MENDÉ KIKAKUI M142 MBO LONG",NULL},
/* 1E89F */ { "SYLLABE MENDÉ KIKAKUI M132 KPI",NULL},
/* 1E8A0 */ { "SYLLABE MENDÉ KIKAKUI M092 KPA",NULL},
/* 1E8A1 */ { "SYLLABE MENDÉ KIKAKUI M074 KPU",NULL},
/* 1E8A2 */ { "SYLLABE MENDÉ KIKAKUI M044 KPEE",NULL},
/* 1E8A3 */ { "SYLLABE MENDÉ KIKAKUI M108 KPE",NULL},
/* 1E8A4 */ { "SYLLABE MENDÉ KIKAKUI M112 KPOO",NULL},
/* 1E8A5 */ { "SYLLABE MENDÉ KIKAKUI M158 KPO",NULL},
/* 1E8A6 */ { "SYLLABE MENDÉ KIKAKUI M124 GBI",NULL},
/* 1E8A7 */ { "SYLLABE MENDÉ KIKAKUI M056 GBA",NULL},
/* 1E8A8 */ { "SYLLABE MENDÉ KIKAKUI M148 GBU",NULL},
/* 1E8A9 */ { "SYLLABE MENDÉ KIKAKUI M093 GBEE",NULL},
/* 1E8AA */ { "SYLLABE MENDÉ KIKAKUI M107 GBE",NULL},
/* 1E8AB */ { "SYLLABE MENDÉ KIKAKUI M071 GBOO",NULL},
/* 1E8AC */ { "SYLLABE MENDÉ KIKAKUI M070 GBO",NULL},
/* 1E8AD */ { "SYLLABE MENDÉ KIKAKUI M171 RA",NULL},
/* 1E8AE */ { "SYLLABE MENDÉ KIKAKUI M123 NDI",NULL},
/* 1E8AF */ { "SYLLABE MENDÉ KIKAKUI M129 NDA",NULL},
/* 1E8B0 */ { "SYLLABE MENDÉ KIKAKUI M125 NDU",NULL},
/* 1E8B1 */ { "SYLLABE MENDÉ KIKAKUI M191 NDEE",NULL},
/* 1E8B2 */ { "SYLLABE MENDÉ KIKAKUI M119 NDE",NULL},
/* 1E8B3 */ { "SYLLABE MENDÉ KIKAKUI M067 NDOO",NULL},
/* 1E8B4 */ { "SYLLABE MENDÉ KIKAKUI M064 NDO",NULL},
/* 1E8B5 */ { "SYLLABE MENDÉ KIKAKUI M152 NJA",NULL},
/* 1E8B6 */ { "SYLLABE MENDÉ KIKAKUI M192 NJU",NULL},
/* 1E8B7 */ { "SYLLABE MENDÉ KIKAKUI M149 NJEE",NULL},
/* 1E8B8 */ { "SYLLABE MENDÉ KIKAKUI M134 NJOO",NULL},
/* 1E8B9 */ { "SYLLABE MENDÉ KIKAKUI M182 VI","	* équivalent de M180 de Dalby"},
/* 1E8BA */ { "SYLLABE MENDÉ KIKAKUI M185 VA",NULL},
/* 1E8BB */ { "SYLLABE MENDÉ KIKAKUI M151 VU",NULL},
/* 1E8BC */ { "SYLLABE MENDÉ KIKAKUI M173 VEE",NULL},
/* 1E8BD */ { "SYLLABE MENDÉ KIKAKUI M085 VE",NULL},
/* 1E8BE */ { "SYLLABE MENDÉ KIKAKUI M144 VOO",NULL},
/* 1E8BF */ { "SYLLABE MENDÉ KIKAKUI M077 VO",NULL},
/* 1E8C0 */ { "SYLLABE MENDÉ KIKAKUI M164 NYIN",NULL},
/* 1E8C1 */ { "SYLLABE MENDÉ KIKAKUI M058 NYAN",NULL},
/* 1E8C2 */ { "SYLLABE MENDÉ KIKAKUI M170 NYUN",NULL},
/* 1E8C3 */ { "SYLLABE MENDÉ KIKAKUI M098 NYEN",NULL},
/* 1E8C4 */ { "SYLLABE MENDÉ KIKAKUI M060 NYON",NULL},
/* 1E8C5 */ { NULL,NULL},
/* 1E8C6 */ { NULL,NULL},
/* 1E8C7 */ { "CHIFFRE MENDÉ KIKAKUI UN",NULL},
/* 1E8C8 */ { "CHIFFRE MENDÉ KIKAKUI DEUX",NULL},
/* 1E8C9 */ { "CHIFFRE MENDÉ KIKAKUI TROIS",NULL},
/* 1E8CA */ { "CHIFFRE MENDÉ KIKAKUI QUATRE",NULL},
/* 1E8CB */ { "CHIFFRE MENDÉ KIKAKUI CINQ",NULL},
/* 1E8CC */ { "CHIFFRE MENDÉ KIKAKUI SIX",NULL},
/* 1E8CD */ { "CHIFFRE MENDÉ KIKAKUI SEPT",NULL},
/* 1E8CE */ { "CHIFFRE MENDÉ KIKAKUI HUIT",NULL},
/* 1E8CF */ { "CHIFFRE MENDÉ KIKAKUI NEUF",NULL},
/* 1E8D0 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI DIX","	* s'utilise pour former les numéraux de la deuxième dizaine, excepté dix : onze, douze, ..., dix-neuf"},
/* 1E8D1 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI DIZAINES",NULL},
/* 1E8D2 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI CENTAINES",NULL},
/* 1E8D3 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI MILLIERS",NULL},
/* 1E8D4 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI DIZAINES DE MILLIERS",NULL},
/* 1E8D5 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI CENTAINES DE MILLIERS",NULL},
/* 1E8D6 */ { "DIACRITIQUE NOMBRE MENDÉ KIKAKUI MILLIONS",NULL},
/* 1E8D7 */ { NULL,NULL},
/* 1E8D8 */ { NULL,NULL},
/* 1E8D9 */ { NULL,NULL},
/* 1E8DA */ { NULL,NULL},
/* 1E8DB */ { NULL,NULL},
/* 1E8DC */ { NULL,NULL},
/* 1E8DD */ { NULL,NULL},
/* 1E8DE */ { NULL,NULL},
/* 1E8DF */ { NULL,NULL},
/* 1E8E0 */ { NULL,NULL},
/* 1E8E1 */ { NULL,NULL},
/* 1E8E2 */ { NULL,NULL},
/* 1E8E3 */ { NULL,NULL},
/* 1E8E4 */ { NULL,NULL},
/* 1E8E5 */ { NULL,NULL},
/* 1E8E6 */ { NULL,NULL},
/* 1E8E7 */ { NULL,NULL},
/* 1E8E8 */ { NULL,NULL},
/* 1E8E9 */ { NULL,NULL},
/* 1E8EA */ { NULL,NULL},
/* 1E8EB */ { NULL,NULL},
/* 1E8EC */ { NULL,NULL},
/* 1E8ED */ { NULL,NULL},
/* 1E8EE */ { NULL,NULL},
/* 1E8EF */ { NULL,NULL},
/* 1E8F0 */ { NULL,NULL},
/* 1E8F1 */ { NULL,NULL},
/* 1E8F2 */ { NULL,NULL},
/* 1E8F3 */ { NULL,NULL},
/* 1E8F4 */ { NULL,NULL},
/* 1E8F5 */ { NULL,NULL},
/* 1E8F6 */ { NULL,NULL},
/* 1E8F7 */ { NULL,NULL},
/* 1E8F8 */ { NULL,NULL},
/* 1E8F9 */ { NULL,NULL},
/* 1E8FA */ { NULL,NULL},
/* 1E8FB */ { NULL,NULL},
/* 1E8FC */ { NULL,NULL},
/* 1E8FD */ { NULL,NULL},
/* 1E8FE */ { NULL,NULL},
/* 1E8FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_E9[] = {
/* 1E900 */ { "LETTRE MAJUSCULE ADLAM ALIF","	= a"},
/* 1E901 */ { "LETTRE MAJUSCULE ADLAM DÂLI","	= da"},
/* 1E902 */ { "LETTRE MAJUSCULE ADLAM LÂM","	= la"},
/* 1E903 */ { "LETTRE MAJUSCULE ADLAM MÎM","	= ma"},
/* 1E904 */ { "LETTRE MAJUSCULE ADLAM BA",NULL},
/* 1E905 */ { "LETTRE MAJUSCULE ADLAM SINGNIYHÉ","	= sa"},
/* 1E906 */ { "LETTRE MAJUSCULE ADLAM PÊ","	= pa"},
/* 1E907 */ { "LETTRE MAJUSCULE ADLAM BHÊ","	= bha"},
/* 1E908 */ { "LETTRE MAJUSCULE ADLAM RA",NULL},
/* 1E909 */ { "LETTRE MAJUSCULE ADLAM Ê",NULL},
/* 1E90A */ { "LETTRE MAJUSCULE ADLAM FA",NULL},
/* 1E90B */ { "LETTRE MAJUSCULE ADLAM I",NULL},
/* 1E90C */ { "LETTRE MAJUSCULE ADLAM O",NULL},
/* 1E90D */ { "LETTRE MAJUSCULE ADLAM DHA",NULL},
/* 1E90E */ { "LETTRE MAJUSCULE ADLAM YHÊ","	= yha"},
/* 1E90F */ { "LETTRE MAJUSCULE ADLAM WAW","	= wa"},
/* 1E910 */ { "LETTRE MAJUSCULE ADLAM NOUN","	= na"},
/* 1E911 */ { "LETTRE MAJUSCULE ADLAM KAF","	= ka"},
/* 1E912 */ { "LETTRE MAJUSCULE ADLAM YA",NULL},
/* 1E913 */ { "LETTRE MAJUSCULE ADLAM OU",NULL},
/* 1E914 */ { "LETTRE MAJUSCULE ADLAM DJÎM","	= ja"},
/* 1E915 */ { "LETTRE MAJUSCULE ADLAM TCHI","	= tcha"},
/* 1E916 */ { "LETTRE MAJUSCULE ADLAM HA",NULL},
/* 1E917 */ { "LETTRE MAJUSCULE ADLAM QÂF","	= qa"},
/* 1E918 */ { "LETTRE MAJUSCULE ADLAM GA",NULL},
/* 1E919 */ { "LETTRE MAJUSCULE ADLAM GNA",NULL},
/* 1E91A */ { "LETTRE MAJUSCULE ADLAM TOU","	= ta"},
/* 1E91B */ { "LETTRE MAJUSCULE ADLAM NHA",NULL},
/* 1E91C */ { "LETTRE MAJUSCULE ADLAM VA",NULL},
/* 1E91D */ { "LETTRE MAJUSCULE ADLAM KHA",NULL},
/* 1E91E */ { "LETTRE MAJUSCULE ADLAM GBÊ","	= gba"},
/* 1E91F */ { "LETTRE MAJUSCULE ADLAM ZAL","	= za"},
/* 1E920 */ { "LETTRE MAJUSCULE ADLAM KPO","	= kpa"},
/* 1E921 */ { "LETTRE MAJUSCULE ADLAM CHA",NULL},
/* 1E922 */ { "LETTRE MINUSCULE ADLAM ALIF",NULL},
/* 1E923 */ { "LETTRE MINUSCULE ADLAM DÂLI",NULL},
/* 1E924 */ { "LETTRE MINUSCULE ADLAM LÂM",NULL},
/* 1E925 */ { "LETTRE MINUSCULE ADLAM MÎM",NULL},
/* 1E926 */ { "LETTRE MINUSCULE ADLAM BA",NULL},
/* 1E927 */ { "LETTRE MINUSCULE ADLAM SINGNIYHÉ",NULL},
/* 1E928 */ { "LETTRE MINUSCULE ADLAM PÊ",NULL},
/* 1E929 */ { "LETTRE MINUSCULE ADLAM BHÊ",NULL},
/* 1E92A */ { "LETTRE MINUSCULE ADLAM RA",NULL},
/* 1E92B */ { "LETTRE MINUSCULE ADLAM Ê",NULL},
/* 1E92C */ { "LETTRE MINUSCULE ADLAM FA",NULL},
/* 1E92D */ { "LETTRE MINUSCULE ADLAM I",NULL},
/* 1E92E */ { "LETTRE MINUSCULE ADLAM O",NULL},
/* 1E92F */ { "LETTRE MINUSCULE ADLAM DHA",NULL},
/* 1E930 */ { "LETTRE MINUSCULE ADLAM YHÊ",NULL},
/* 1E931 */ { "LETTRE MINUSCULE ADLAM WAW",NULL},
/* 1E932 */ { "LETTRE MINUSCULE ADLAM NOUN",NULL},
/* 1E933 */ { "LETTRE MINUSCULE ADLAM KAF",NULL},
/* 1E934 */ { "LETTRE MINUSCULE ADLAM YA",NULL},
/* 1E935 */ { "LETTRE MINUSCULE ADLAM OU",NULL},
/* 1E936 */ { "LETTRE MINUSCULE ADLAM DJÎM",NULL},
/* 1E937 */ { "LETTRE MINUSCULE ADLAM TCHI",NULL},
/* 1E938 */ { "LETTRE MINUSCULE ADLAM HA",NULL},
/* 1E939 */ { "LETTRE MINUSCULE ADLAM QÂF",NULL},
/* 1E93A */ { "LETTRE MINUSCULE ADLAM GA",NULL},
/* 1E93B */ { "LETTRE MINUSCULE ADLAM GNA",NULL},
/* 1E93C */ { "LETTRE MINUSCULE ADLAM TOU",NULL},
/* 1E93D */ { "LETTRE MINUSCULE ADLAM NHA",NULL},
/* 1E93E */ { "LETTRE MINUSCULE ADLAM VA",NULL},
/* 1E93F */ { "LETTRE MINUSCULE ADLAM KHA",NULL},
/* 1E940 */ { "LETTRE MINUSCULE ADLAM GBÊ",NULL},
/* 1E941 */ { "LETTRE MINUSCULE ADLAM ZAL",NULL},
/* 1E942 */ { "LETTRE MINUSCULE ADLAM KPO",NULL},
/* 1E943 */ { "LETTRE MINUSCULE ADLAM CHA",NULL},
/* 1E944 */ { "DIACRITIQUE ADLAM ALLONGE D'ALIF",NULL},
/* 1E945 */ { "DIACRITIQUE ADLAM ALLONGE DE VOYELLE",NULL},
/* 1E946 */ { "DIACRITIQUE ADLAM DE GÉMINATION",NULL},
/* 1E947 */ { "DIACRITIQUE ADLAM HAMZA",NULL},
/* 1E948 */ { "DIACRITIQUE ADLAM MODIFICATEUR DE CONSONNE",NULL},
/* 1E949 */ { "DIACRITIQUE ADLAM MODIFICATEUR DE CONSONNE GÉMINÉE",NULL},
/* 1E94A */ { "DIACRITIQUE ADLAM NOUKTA","	* se nomme « hôrtobbheré » quand il est suscrit, « lestobbheré » quand il est souscrit"},
/* 1E94B */ { "MARQUE ADLAM DE NASALISATION","	* indique que la consonne nasale précédente prénasalise la consonne suivante"},
/* 1E94C */ { NULL,NULL},
/* 1E94D */ { NULL,NULL},
/* 1E94E */ { NULL,NULL},
/* 1E94F */ { NULL,NULL},
/* 1E950 */ { "CHIFFRE ADLAM ZÉRO",NULL},
/* 1E951 */ { "CHIFFRE ADLAM UN",NULL},
/* 1E952 */ { "CHIFFRE ADLAM DEUX",NULL},
/* 1E953 */ { "CHIFFRE ADLAM TROIS",NULL},
/* 1E954 */ { "CHIFFRE ADLAM QUATRE",NULL},
/* 1E955 */ { "CHIFFRE ADLAM CINQ",NULL},
/* 1E956 */ { "CHIFFRE ADLAM SIX",NULL},
/* 1E957 */ { "CHIFFRE ADLAM SEPT",NULL},
/* 1E958 */ { "CHIFFRE ADLAM HUIT",NULL},
/* 1E959 */ { "CHIFFRE ADLAM NEUF",NULL},
/* 1E95A */ { NULL,NULL},
/* 1E95B */ { NULL,NULL},
/* 1E95C */ { NULL,NULL},
/* 1E95D */ { NULL,NULL},
/* 1E95E */ { "POINT D'EXCLAMATION INITIAL ADLAM",NULL},
/* 1E95F */ { "POINT D'INTERROGATION INITIAL ADLAM",NULL},
/* 1E960 */ { NULL,NULL},
/* 1E961 */ { NULL,NULL},
/* 1E962 */ { NULL,NULL},
/* 1E963 */ { NULL,NULL},
/* 1E964 */ { NULL,NULL},
/* 1E965 */ { NULL,NULL},
/* 1E966 */ { NULL,NULL},
/* 1E967 */ { NULL,NULL},
/* 1E968 */ { NULL,NULL},
/* 1E969 */ { NULL,NULL},
/* 1E96A */ { NULL,NULL},
/* 1E96B */ { NULL,NULL},
/* 1E96C */ { NULL,NULL},
/* 1E96D */ { NULL,NULL},
/* 1E96E */ { NULL,NULL},
/* 1E96F */ { NULL,NULL},
/* 1E970 */ { NULL,NULL},
/* 1E971 */ { NULL,NULL},
/* 1E972 */ { NULL,NULL},
/* 1E973 */ { NULL,NULL},
/* 1E974 */ { NULL,NULL},
/* 1E975 */ { NULL,NULL},
/* 1E976 */ { NULL,NULL},
/* 1E977 */ { NULL,NULL},
/* 1E978 */ { NULL,NULL},
/* 1E979 */ { NULL,NULL},
/* 1E97A */ { NULL,NULL},
/* 1E97B */ { NULL,NULL},
/* 1E97C */ { NULL,NULL},
/* 1E97D */ { NULL,NULL},
/* 1E97E */ { NULL,NULL},
/* 1E97F */ { NULL,NULL},
/* 1E980 */ { NULL,NULL},
/* 1E981 */ { NULL,NULL},
/* 1E982 */ { NULL,NULL},
/* 1E983 */ { NULL,NULL},
/* 1E984 */ { NULL,NULL},
/* 1E985 */ { NULL,NULL},
/* 1E986 */ { NULL,NULL},
/* 1E987 */ { NULL,NULL},
/* 1E988 */ { NULL,NULL},
/* 1E989 */ { NULL,NULL},
/* 1E98A */ { NULL,NULL},
/* 1E98B */ { NULL,NULL},
/* 1E98C */ { NULL,NULL},
/* 1E98D */ { NULL,NULL},
/* 1E98E */ { NULL,NULL},
/* 1E98F */ { NULL,NULL},
/* 1E990 */ { NULL,NULL},
/* 1E991 */ { NULL,NULL},
/* 1E992 */ { NULL,NULL},
/* 1E993 */ { NULL,NULL},
/* 1E994 */ { NULL,NULL},
/* 1E995 */ { NULL,NULL},
/* 1E996 */ { NULL,NULL},
/* 1E997 */ { NULL,NULL},
/* 1E998 */ { NULL,NULL},
/* 1E999 */ { NULL,NULL},
/* 1E99A */ { NULL,NULL},
/* 1E99B */ { NULL,NULL},
/* 1E99C */ { NULL,NULL},
/* 1E99D */ { NULL,NULL},
/* 1E99E */ { NULL,NULL},
/* 1E99F */ { NULL,NULL},
/* 1E9A0 */ { NULL,NULL},
/* 1E9A1 */ { NULL,NULL},
/* 1E9A2 */ { NULL,NULL},
/* 1E9A3 */ { NULL,NULL},
/* 1E9A4 */ { NULL,NULL},
/* 1E9A5 */ { NULL,NULL},
/* 1E9A6 */ { NULL,NULL},
/* 1E9A7 */ { NULL,NULL},
/* 1E9A8 */ { NULL,NULL},
/* 1E9A9 */ { NULL,NULL},
/* 1E9AA */ { NULL,NULL},
/* 1E9AB */ { NULL,NULL},
/* 1E9AC */ { NULL,NULL},
/* 1E9AD */ { NULL,NULL},
/* 1E9AE */ { NULL,NULL},
/* 1E9AF */ { NULL,NULL},
/* 1E9B0 */ { NULL,NULL},
/* 1E9B1 */ { NULL,NULL},
/* 1E9B2 */ { NULL,NULL},
/* 1E9B3 */ { NULL,NULL},
/* 1E9B4 */ { NULL,NULL},
/* 1E9B5 */ { NULL,NULL},
/* 1E9B6 */ { NULL,NULL},
/* 1E9B7 */ { NULL,NULL},
/* 1E9B8 */ { NULL,NULL},
/* 1E9B9 */ { NULL,NULL},
/* 1E9BA */ { NULL,NULL},
/* 1E9BB */ { NULL,NULL},
/* 1E9BC */ { NULL,NULL},
/* 1E9BD */ { NULL,NULL},
/* 1E9BE */ { NULL,NULL},
/* 1E9BF */ { NULL,NULL},
/* 1E9C0 */ { NULL,NULL},
/* 1E9C1 */ { NULL,NULL},
/* 1E9C2 */ { NULL,NULL},
/* 1E9C3 */ { NULL,NULL},
/* 1E9C4 */ { NULL,NULL},
/* 1E9C5 */ { NULL,NULL},
/* 1E9C6 */ { NULL,NULL},
/* 1E9C7 */ { NULL,NULL},
/* 1E9C8 */ { NULL,NULL},
/* 1E9C9 */ { NULL,NULL},
/* 1E9CA */ { NULL,NULL},
/* 1E9CB */ { NULL,NULL},
/* 1E9CC */ { NULL,NULL},
/* 1E9CD */ { NULL,NULL},
/* 1E9CE */ { NULL,NULL},
/* 1E9CF */ { NULL,NULL},
/* 1E9D0 */ { NULL,NULL},
/* 1E9D1 */ { NULL,NULL},
/* 1E9D2 */ { NULL,NULL},
/* 1E9D3 */ { NULL,NULL},
/* 1E9D4 */ { NULL,NULL},
/* 1E9D5 */ { NULL,NULL},
/* 1E9D6 */ { NULL,NULL},
/* 1E9D7 */ { NULL,NULL},
/* 1E9D8 */ { NULL,NULL},
/* 1E9D9 */ { NULL,NULL},
/* 1E9DA */ { NULL,NULL},
/* 1E9DB */ { NULL,NULL},
/* 1E9DC */ { NULL,NULL},
/* 1E9DD */ { NULL,NULL},
/* 1E9DE */ { NULL,NULL},
/* 1E9DF */ { NULL,NULL},
/* 1E9E0 */ { NULL,NULL},
/* 1E9E1 */ { NULL,NULL},
/* 1E9E2 */ { NULL,NULL},
/* 1E9E3 */ { NULL,NULL},
/* 1E9E4 */ { NULL,NULL},
/* 1E9E5 */ { NULL,NULL},
/* 1E9E6 */ { NULL,NULL},
/* 1E9E7 */ { NULL,NULL},
/* 1E9E8 */ { NULL,NULL},
/* 1E9E9 */ { NULL,NULL},
/* 1E9EA */ { NULL,NULL},
/* 1E9EB */ { NULL,NULL},
/* 1E9EC */ { NULL,NULL},
/* 1E9ED */ { NULL,NULL},
/* 1E9EE */ { NULL,NULL},
/* 1E9EF */ { NULL,NULL},
/* 1E9F0 */ { NULL,NULL},
/* 1E9F1 */ { NULL,NULL},
/* 1E9F2 */ { NULL,NULL},
/* 1E9F3 */ { NULL,NULL},
/* 1E9F4 */ { NULL,NULL},
/* 1E9F5 */ { NULL,NULL},
/* 1E9F6 */ { NULL,NULL},
/* 1E9F7 */ { NULL,NULL},
/* 1E9F8 */ { NULL,NULL},
/* 1E9F9 */ { NULL,NULL},
/* 1E9FA */ { NULL,NULL},
/* 1E9FB */ { NULL,NULL},
/* 1E9FC */ { NULL,NULL},
/* 1E9FD */ { NULL,NULL},
/* 1E9FE */ { NULL,NULL},
/* 1E9FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_EC[] = {
/* 1EC00 */ { NULL,NULL},
/* 1EC01 */ { NULL,NULL},
/* 1EC02 */ { NULL,NULL},
/* 1EC03 */ { NULL,NULL},
/* 1EC04 */ { NULL,NULL},
/* 1EC05 */ { NULL,NULL},
/* 1EC06 */ { NULL,NULL},
/* 1EC07 */ { NULL,NULL},
/* 1EC08 */ { NULL,NULL},
/* 1EC09 */ { NULL,NULL},
/* 1EC0A */ { NULL,NULL},
/* 1EC0B */ { NULL,NULL},
/* 1EC0C */ { NULL,NULL},
/* 1EC0D */ { NULL,NULL},
/* 1EC0E */ { NULL,NULL},
/* 1EC0F */ { NULL,NULL},
/* 1EC10 */ { NULL,NULL},
/* 1EC11 */ { NULL,NULL},
/* 1EC12 */ { NULL,NULL},
/* 1EC13 */ { NULL,NULL},
/* 1EC14 */ { NULL,NULL},
/* 1EC15 */ { NULL,NULL},
/* 1EC16 */ { NULL,NULL},
/* 1EC17 */ { NULL,NULL},
/* 1EC18 */ { NULL,NULL},
/* 1EC19 */ { NULL,NULL},
/* 1EC1A */ { NULL,NULL},
/* 1EC1B */ { NULL,NULL},
/* 1EC1C */ { NULL,NULL},
/* 1EC1D */ { NULL,NULL},
/* 1EC1E */ { NULL,NULL},
/* 1EC1F */ { NULL,NULL},
/* 1EC20 */ { NULL,NULL},
/* 1EC21 */ { NULL,NULL},
/* 1EC22 */ { NULL,NULL},
/* 1EC23 */ { NULL,NULL},
/* 1EC24 */ { NULL,NULL},
/* 1EC25 */ { NULL,NULL},
/* 1EC26 */ { NULL,NULL},
/* 1EC27 */ { NULL,NULL},
/* 1EC28 */ { NULL,NULL},
/* 1EC29 */ { NULL,NULL},
/* 1EC2A */ { NULL,NULL},
/* 1EC2B */ { NULL,NULL},
/* 1EC2C */ { NULL,NULL},
/* 1EC2D */ { NULL,NULL},
/* 1EC2E */ { NULL,NULL},
/* 1EC2F */ { NULL,NULL},
/* 1EC30 */ { NULL,NULL},
/* 1EC31 */ { NULL,NULL},
/* 1EC32 */ { NULL,NULL},
/* 1EC33 */ { NULL,NULL},
/* 1EC34 */ { NULL,NULL},
/* 1EC35 */ { NULL,NULL},
/* 1EC36 */ { NULL,NULL},
/* 1EC37 */ { NULL,NULL},
/* 1EC38 */ { NULL,NULL},
/* 1EC39 */ { NULL,NULL},
/* 1EC3A */ { NULL,NULL},
/* 1EC3B */ { NULL,NULL},
/* 1EC3C */ { NULL,NULL},
/* 1EC3D */ { NULL,NULL},
/* 1EC3E */ { NULL,NULL},
/* 1EC3F */ { NULL,NULL},
/* 1EC40 */ { NULL,NULL},
/* 1EC41 */ { NULL,NULL},
/* 1EC42 */ { NULL,NULL},
/* 1EC43 */ { NULL,NULL},
/* 1EC44 */ { NULL,NULL},
/* 1EC45 */ { NULL,NULL},
/* 1EC46 */ { NULL,NULL},
/* 1EC47 */ { NULL,NULL},
/* 1EC48 */ { NULL,NULL},
/* 1EC49 */ { NULL,NULL},
/* 1EC4A */ { NULL,NULL},
/* 1EC4B */ { NULL,NULL},
/* 1EC4C */ { NULL,NULL},
/* 1EC4D */ { NULL,NULL},
/* 1EC4E */ { NULL,NULL},
/* 1EC4F */ { NULL,NULL},
/* 1EC50 */ { NULL,NULL},
/* 1EC51 */ { NULL,NULL},
/* 1EC52 */ { NULL,NULL},
/* 1EC53 */ { NULL,NULL},
/* 1EC54 */ { NULL,NULL},
/* 1EC55 */ { NULL,NULL},
/* 1EC56 */ { NULL,NULL},
/* 1EC57 */ { NULL,NULL},
/* 1EC58 */ { NULL,NULL},
/* 1EC59 */ { NULL,NULL},
/* 1EC5A */ { NULL,NULL},
/* 1EC5B */ { NULL,NULL},
/* 1EC5C */ { NULL,NULL},
/* 1EC5D */ { NULL,NULL},
/* 1EC5E */ { NULL,NULL},
/* 1EC5F */ { NULL,NULL},
/* 1EC60 */ { NULL,NULL},
/* 1EC61 */ { NULL,NULL},
/* 1EC62 */ { NULL,NULL},
/* 1EC63 */ { NULL,NULL},
/* 1EC64 */ { NULL,NULL},
/* 1EC65 */ { NULL,NULL},
/* 1EC66 */ { NULL,NULL},
/* 1EC67 */ { NULL,NULL},
/* 1EC68 */ { NULL,NULL},
/* 1EC69 */ { NULL,NULL},
/* 1EC6A */ { NULL,NULL},
/* 1EC6B */ { NULL,NULL},
/* 1EC6C */ { NULL,NULL},
/* 1EC6D */ { NULL,NULL},
/* 1EC6E */ { NULL,NULL},
/* 1EC6F */ { NULL,NULL},
/* 1EC70 */ { NULL,NULL},
/* 1EC71 */ { "NOMBRE SIYAQ INDIEN UN",NULL},
/* 1EC72 */ { "NOMBRE SIYAQ INDIEN DEUX",NULL},
/* 1EC73 */ { "NOMBRE SIYAQ INDIEN TROIS",NULL},
/* 1EC74 */ { "NOMBRE SIYAQ INDIEN QUATRE",NULL},
/* 1EC75 */ { "NOMBRE SIYAQ INDIEN CINQ",NULL},
/* 1EC76 */ { "NOMBRE SIYAQ INDIEN SIX",NULL},
/* 1EC77 */ { "NOMBRE SIYAQ INDIEN SEPT",NULL},
/* 1EC78 */ { "NOMBRE SIYAQ INDIEN HUIT",NULL},
/* 1EC79 */ { "NOMBRE SIYAQ INDIEN NEUF",NULL},
/* 1EC7A */ { "NOMBRE SIYAQ INDIEN DIX",NULL},
/* 1EC7B */ { "NOMBRE SIYAQ INDIEN VINGT",NULL},
/* 1EC7C */ { "NOMBRE SIYAQ INDIEN TRENTE",NULL},
/* 1EC7D */ { "NOMBRE SIYAQ INDIEN QUARANTE",NULL},
/* 1EC7E */ { "NOMBRE SIYAQ INDIEN CINQUANTE",NULL},
/* 1EC7F */ { "NOMBRE SIYAQ INDIEN SOIXANTE",NULL},
/* 1EC80 */ { "NOMBRE SIYAQ INDIEN SOIXANTE-DIX","	= nombre siyaq indien septante"},
/* 1EC81 */ { "NOMBRE SIYAQ INDIEN QUATRE-VINGTS","	= nombre siyaq indien huitante"},
/* 1EC82 */ { "NOMBRE SIYAQ INDIEN QUATRE-VINGT-DIX","	= nombre siyaq indien nonante"},
/* 1EC83 */ { "NOMBRE SIYAQ INDIEN CENT",NULL},
/* 1EC84 */ { "NOMBRE SIYAQ INDIEN DEUX CENTS",NULL},
/* 1EC85 */ { "NOMBRE SIYAQ INDIEN TROIS CENTS",NULL},
/* 1EC86 */ { "NOMBRE SIYAQ INDIEN QUATRE CENTS",NULL},
/* 1EC87 */ { "NOMBRE SIYAQ INDIEN CINQ CENTS",NULL},
/* 1EC88 */ { "NOMBRE SIYAQ INDIEN SIX CENTS",NULL},
/* 1EC89 */ { "NOMBRE SIYAQ INDIEN SEPT CENTS",NULL},
/* 1EC8A */ { "NOMBRE SIYAQ INDIEN HUIT CENTS",NULL},
/* 1EC8B */ { "NOMBRE SIYAQ INDIEN NEUF CENTS",NULL},
/* 1EC8C */ { "NOMBRE SIYAQ INDIEN MILLE",NULL},
/* 1EC8D */ { "NOMBRE SIYAQ INDIEN DEUX MILLE",NULL},
/* 1EC8E */ { "NOMBRE SIYAQ INDIEN TROIS MILLE",NULL},
/* 1EC8F */ { "NOMBRE SIYAQ INDIEN QUATRE MILLE",NULL},
/* 1EC90 */ { "NOMBRE SIYAQ INDIEN CINQ MILLE",NULL},
/* 1EC91 */ { "NOMBRE SIYAQ INDIEN SIX MILLE",NULL},
/* 1EC92 */ { "NOMBRE SIYAQ INDIEN SEPT MILLE",NULL},
/* 1EC93 */ { "NOMBRE SIYAQ INDIEN HUIT MILLE",NULL},
/* 1EC94 */ { "NOMBRE SIYAQ INDIEN NEUF MILLE",NULL},
/* 1EC95 */ { "NOMBRE SIYAQ INDIEN DIX MILLE",NULL},
/* 1EC96 */ { "NOMBRE SIYAQ INDIEN VINGT MILLE",NULL},
/* 1EC97 */ { "NOMBRE SIYAQ INDIEN TRENTE MILLE",NULL},
/* 1EC98 */ { "NOMBRE SIYAQ INDIEN QUARANTE MILLE",NULL},
/* 1EC99 */ { "NOMBRE SIYAQ INDIEN CINQUANTE MILLE",NULL},
/* 1EC9A */ { "NOMBRE SIYAQ INDIEN SOIXANTE MILLE",NULL},
/* 1EC9B */ { "NOMBRE SIYAQ INDIEN SOIXANTE-DIX MILLE","	= nombre siyaq indien septante mille"},
/* 1EC9C */ { "NOMBRE SIYAQ INDIEN QUATRE-VINGT MILLE","	= nombre siyaq indien huitante mille"},
/* 1EC9D */ { "NOMBRE SIYAQ INDIEN QUATRE-VINGT-DIX MILLE","	= nombre siyaq indien nonante mille"},
/* 1EC9E */ { "NOMBRE SIYAQ INDIEN LAKH","	= 1 lakh\n"
	"	= 100.000"},
/* 1EC9F */ { "NOMBRE SIYAQ INDIEN LAKHAN","	= 2 lakhs\n"
	"	= 200.000"},
/* 1ECA0 */ { "SIGNE SIYAQ INDIEN LAKH","	* utilisé comme un signe pour indiquer d'autres valeurs de lakh"},
/* 1ECA1 */ { "NOMBRE SIYAQ INDIEN KAROR","	= 1 crore\n"
	"	= 10 millions\n"
	"	= 100 lakhs\n"
	"	* utilisé comme un signe pour indiquer les crores"},
/* 1ECA2 */ { "NOMBRE SIYAQ INDIEN KARORAN","	= 2 crores\n"
	"	= 20 millions\n"
	"	= 200 lakhs"},
/* 1ECA3 */ { "NOMBRE SIYAQ INDIEN UN PRÉFIXÉ",NULL},
/* 1ECA4 */ { "NOMBRE SIYAQ INDIEN DEUX PRÉFIXÉ",NULL},
/* 1ECA5 */ { "NOMBRE SIYAQ INDIEN TROIS PRÉFIXÉ",NULL},
/* 1ECA6 */ { "NOMBRE SIYAQ INDIEN QUATRE PRÉFIXÉ",NULL},
/* 1ECA7 */ { "NOMBRE SIYAQ INDIEN CINQ PRÉFIXÉ",NULL},
/* 1ECA8 */ { "NOMBRE SIYAQ INDIEN SIX PRÉFIXÉ",NULL},
/* 1ECA9 */ { "NOMBRE SIYAQ INDIEN SEPT PRÉFIXÉ",NULL},
/* 1ECAA */ { "NOMBRE SIYAQ INDIEN HUIT PRÉFIXÉ",NULL},
/* 1ECAB */ { "NOMBRE SIYAQ INDIEN NEUF PRÉFIXÉ",NULL},
/* 1ECAC */ { "MARQUE DE RÉSERVATION SIYAQ INDIENNE",NULL},
/* 1ECAD */ { "FRACTION SIYAQ INDIENNE UN QUART",NULL},
/* 1ECAE */ { "FRACTION SIYAQ INDIENNE UN DEMI",NULL},
/* 1ECAF */ { "FRACTION SIYAQ INDIENNE TROIS QUARTS",NULL},
/* 1ECB0 */ { "SYMBOLE SIYAQ INDIEN ROUPIE",NULL},
/* 1ECB1 */ { "NOMBRE SIYAQ INDIEN VARIANTE DE UN",NULL},
/* 1ECB2 */ { "NOMBRE SIYAQ INDIEN VARIANTE DE DEUX",NULL},
/* 1ECB3 */ { "NOMBRE SIYAQ INDIEN VARIANTE DE DIX MILLE",NULL},
/* 1ECB4 */ { "SIGNE SIYAQ INDIEN VARIANTE DE LAKH",NULL},
/* 1ECB5 */ { NULL,NULL},
/* 1ECB6 */ { NULL,NULL},
/* 1ECB7 */ { NULL,NULL},
/* 1ECB8 */ { NULL,NULL},
/* 1ECB9 */ { NULL,NULL},
/* 1ECBA */ { NULL,NULL},
/* 1ECBB */ { NULL,NULL},
/* 1ECBC */ { NULL,NULL},
/* 1ECBD */ { NULL,NULL},
/* 1ECBE */ { NULL,NULL},
/* 1ECBF */ { NULL,NULL},
/* 1ECC0 */ { NULL,NULL},
/* 1ECC1 */ { NULL,NULL},
/* 1ECC2 */ { NULL,NULL},
/* 1ECC3 */ { NULL,NULL},
/* 1ECC4 */ { NULL,NULL},
/* 1ECC5 */ { NULL,NULL},
/* 1ECC6 */ { NULL,NULL},
/* 1ECC7 */ { NULL,NULL},
/* 1ECC8 */ { NULL,NULL},
/* 1ECC9 */ { NULL,NULL},
/* 1ECCA */ { NULL,NULL},
/* 1ECCB */ { NULL,NULL},
/* 1ECCC */ { NULL,NULL},
/* 1ECCD */ { NULL,NULL},
/* 1ECCE */ { NULL,NULL},
/* 1ECCF */ { NULL,NULL},
/* 1ECD0 */ { NULL,NULL},
/* 1ECD1 */ { NULL,NULL},
/* 1ECD2 */ { NULL,NULL},
/* 1ECD3 */ { NULL,NULL},
/* 1ECD4 */ { NULL,NULL},
/* 1ECD5 */ { NULL,NULL},
/* 1ECD6 */ { NULL,NULL},
/* 1ECD7 */ { NULL,NULL},
/* 1ECD8 */ { NULL,NULL},
/* 1ECD9 */ { NULL,NULL},
/* 1ECDA */ { NULL,NULL},
/* 1ECDB */ { NULL,NULL},
/* 1ECDC */ { NULL,NULL},
/* 1ECDD */ { NULL,NULL},
/* 1ECDE */ { NULL,NULL},
/* 1ECDF */ { NULL,NULL},
/* 1ECE0 */ { NULL,NULL},
/* 1ECE1 */ { NULL,NULL},
/* 1ECE2 */ { NULL,NULL},
/* 1ECE3 */ { NULL,NULL},
/* 1ECE4 */ { NULL,NULL},
/* 1ECE5 */ { NULL,NULL},
/* 1ECE6 */ { NULL,NULL},
/* 1ECE7 */ { NULL,NULL},
/* 1ECE8 */ { NULL,NULL},
/* 1ECE9 */ { NULL,NULL},
/* 1ECEA */ { NULL,NULL},
/* 1ECEB */ { NULL,NULL},
/* 1ECEC */ { NULL,NULL},
/* 1ECED */ { NULL,NULL},
/* 1ECEE */ { NULL,NULL},
/* 1ECEF */ { NULL,NULL},
/* 1ECF0 */ { NULL,NULL},
/* 1ECF1 */ { NULL,NULL},
/* 1ECF2 */ { NULL,NULL},
/* 1ECF3 */ { NULL,NULL},
/* 1ECF4 */ { NULL,NULL},
/* 1ECF5 */ { NULL,NULL},
/* 1ECF6 */ { NULL,NULL},
/* 1ECF7 */ { NULL,NULL},
/* 1ECF8 */ { NULL,NULL},
/* 1ECF9 */ { NULL,NULL},
/* 1ECFA */ { NULL,NULL},
/* 1ECFB */ { NULL,NULL},
/* 1ECFC */ { NULL,NULL},
/* 1ECFD */ { NULL,NULL},
/* 1ECFE */ { NULL,NULL},
/* 1ECFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_ED[] = {
/* 1ED00 */ { NULL,NULL},
/* 1ED01 */ { "NOMBRE SIYAQ OTTOMAN UN",NULL},
/* 1ED02 */ { "NOMBRE SIYAQ OTTOMAN DEUX",NULL},
/* 1ED03 */ { "NOMBRE SIYAQ OTTOMAN TROIS",NULL},
/* 1ED04 */ { "NOMBRE SIYAQ OTTOMAN QUATRE",NULL},
/* 1ED05 */ { "NOMBRE SIYAQ OTTOMAN CINQ",NULL},
/* 1ED06 */ { "NOMBRE SIYAQ OTTOMAN SIX",NULL},
/* 1ED07 */ { "NOMBRE SIYAQ OTTOMAN SEPT",NULL},
/* 1ED08 */ { "NOMBRE SIYAQ OTTOMAN HUIT",NULL},
/* 1ED09 */ { "NOMBRE SIYAQ OTTOMAN NEUF",NULL},
/* 1ED0A */ { "NOMBRE SIYAQ OTTOMAN DIX",NULL},
/* 1ED0B */ { "NOMBRE SIYAQ OTTOMAN VINGT",NULL},
/* 1ED0C */ { "NOMBRE SIYAQ OTTOMAN TRENTE",NULL},
/* 1ED0D */ { "NOMBRE SIYAQ OTTOMAN QUARANTE",NULL},
/* 1ED0E */ { "NOMBRE SIYAQ OTTOMAN CINQUANTE",NULL},
/* 1ED0F */ { "NOMBRE SIYAQ OTTOMAN SOIXANTE",NULL},
/* 1ED10 */ { "NOMBRE SIYAQ OTTOMAN SOIXANTE-DIX","	= nombre siyaq ottoman septante"},
/* 1ED11 */ { "NOMBRE SIYAQ OTTOMAN QUATRE-VINGTS","	= nombre siyaq ottoman huitante"},
/* 1ED12 */ { "NOMBRE SIYAQ OTTOMAN QUATRE-VINGT-DIX","	= nombre siyaq ottoman nonante"},
/* 1ED13 */ { "NOMBRE SIYAQ OTTOMAN CENT",NULL},
/* 1ED14 */ { "NOMBRE SIYAQ OTTOMAN DEUX CENTS",NULL},
/* 1ED15 */ { "NOMBRE SIYAQ OTTOMAN TROIS CENTS",NULL},
/* 1ED16 */ { "NOMBRE SIYAQ OTTOMAN QUATRE CENTS",NULL},
/* 1ED17 */ { "NOMBRE SIYAQ OTTOMAN CINQ CENTS",NULL},
/* 1ED18 */ { "NOMBRE SIYAQ OTTOMAN SIX CENTS",NULL},
/* 1ED19 */ { "NOMBRE SIYAQ OTTOMAN SEPT CENTS",NULL},
/* 1ED1A */ { "NOMBRE SIYAQ OTTOMAN HUIT CENTS",NULL},
/* 1ED1B */ { "NOMBRE SIYAQ OTTOMAN NEUF CENTS",NULL},
/* 1ED1C */ { "NOMBRE SIYAQ OTTOMAN MILLE","	= multiplicateur mille"},
/* 1ED1D */ { "NOMBRE SIYAQ OTTOMAN DEUX MILLE",NULL},
/* 1ED1E */ { "NOMBRE SIYAQ OTTOMAN TROIS MILLE",NULL},
/* 1ED1F */ { "NOMBRE SIYAQ OTTOMAN QUATRE MILLE",NULL},
/* 1ED20 */ { "NOMBRE SIYAQ OTTOMAN CINQ MILLE",NULL},
/* 1ED21 */ { "NOMBRE SIYAQ OTTOMAN SIX MILLE",NULL},
/* 1ED22 */ { "NOMBRE SIYAQ OTTOMAN SEPT MILLE",NULL},
/* 1ED23 */ { "NOMBRE SIYAQ OTTOMAN HUIT MILLE",NULL},
/* 1ED24 */ { "NOMBRE SIYAQ OTTOMAN NEUF MILLE",NULL},
/* 1ED25 */ { "NOMBRE SIYAQ OTTOMAN DIX MILLE",NULL},
/* 1ED26 */ { "NOMBRE SIYAQ OTTOMAN VINGT MILLE",NULL},
/* 1ED27 */ { "NOMBRE SIYAQ OTTOMAN TRENTE MILLE",NULL},
/* 1ED28 */ { "NOMBRE SIYAQ OTTOMAN QUARANTE MILLE",NULL},
/* 1ED29 */ { "NOMBRE SIYAQ OTTOMAN CINQUANTE MILLE",NULL},
/* 1ED2A */ { "NOMBRE SIYAQ OTTOMAN SOIXANTE MILLE",NULL},
/* 1ED2B */ { "NOMBRE SIYAQ OTTOMAN SOIXANTE-DIX MILLE","	= nombre siyaq ottoman septante mille"},
/* 1ED2C */ { "NOMBRE SIYAQ OTTOMAN QUATRE-VINGT MILLE","	= nombre siyaq ottoman huitante mille"},
/* 1ED2D */ { "NOMBRE SIYAQ OTTOMAN QUATRE-VINGT-DIX MILLE","	= nombre siyaq ottoman nonante mille"},
/* 1ED2E */ { "MARRATAN SIYAQ OTTOMAN","	= meretten, merre\n"
	"	* utilisé avec mille pour représenter les millions"},
/* 1ED2F */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE DEUX",NULL},
/* 1ED30 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE TROIS",NULL},
/* 1ED31 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE QUATRE",NULL},
/* 1ED32 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE CINQ",NULL},
/* 1ED33 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE SIX",NULL},
/* 1ED34 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE SEPT",NULL},
/* 1ED35 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE HUIT",NULL},
/* 1ED36 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE NEUF",NULL},
/* 1ED37 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE DIX",NULL},
/* 1ED38 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE QUATRE CENTS",NULL},
/* 1ED39 */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE SIX CENTS",NULL},
/* 1ED3A */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE DEUX MILLE",NULL},
/* 1ED3B */ { "NOMBRE SIYAQ OTTOMAN VARIANTE DE DIX MILLE",NULL},
/* 1ED3C */ { "FRACTION SIYAQ OTTOMANE UN DEMI",NULL},
/* 1ED3D */ { "FRACTION SIYAQ OTTOMANE UN SIXIÈME",NULL},
/* 1ED3E */ { NULL,NULL},
/* 1ED3F */ { NULL,NULL},
/* 1ED40 */ { NULL,NULL},
/* 1ED41 */ { NULL,NULL},
/* 1ED42 */ { NULL,NULL},
/* 1ED43 */ { NULL,NULL},
/* 1ED44 */ { NULL,NULL},
/* 1ED45 */ { NULL,NULL},
/* 1ED46 */ { NULL,NULL},
/* 1ED47 */ { NULL,NULL},
/* 1ED48 */ { NULL,NULL},
/* 1ED49 */ { NULL,NULL},
/* 1ED4A */ { NULL,NULL},
/* 1ED4B */ { NULL,NULL},
/* 1ED4C */ { NULL,NULL},
/* 1ED4D */ { NULL,NULL},
/* 1ED4E */ { NULL,NULL},
/* 1ED4F */ { NULL,NULL},
/* 1ED50 */ { NULL,NULL},
/* 1ED51 */ { NULL,NULL},
/* 1ED52 */ { NULL,NULL},
/* 1ED53 */ { NULL,NULL},
/* 1ED54 */ { NULL,NULL},
/* 1ED55 */ { NULL,NULL},
/* 1ED56 */ { NULL,NULL},
/* 1ED57 */ { NULL,NULL},
/* 1ED58 */ { NULL,NULL},
/* 1ED59 */ { NULL,NULL},
/* 1ED5A */ { NULL,NULL},
/* 1ED5B */ { NULL,NULL},
/* 1ED5C */ { NULL,NULL},
/* 1ED5D */ { NULL,NULL},
/* 1ED5E */ { NULL,NULL},
/* 1ED5F */ { NULL,NULL},
/* 1ED60 */ { NULL,NULL},
/* 1ED61 */ { NULL,NULL},
/* 1ED62 */ { NULL,NULL},
/* 1ED63 */ { NULL,NULL},
/* 1ED64 */ { NULL,NULL},
/* 1ED65 */ { NULL,NULL},
/* 1ED66 */ { NULL,NULL},
/* 1ED67 */ { NULL,NULL},
/* 1ED68 */ { NULL,NULL},
/* 1ED69 */ { NULL,NULL},
/* 1ED6A */ { NULL,NULL},
/* 1ED6B */ { NULL,NULL},
/* 1ED6C */ { NULL,NULL},
/* 1ED6D */ { NULL,NULL},
/* 1ED6E */ { NULL,NULL},
/* 1ED6F */ { NULL,NULL},
/* 1ED70 */ { NULL,NULL},
/* 1ED71 */ { NULL,NULL},
/* 1ED72 */ { NULL,NULL},
/* 1ED73 */ { NULL,NULL},
/* 1ED74 */ { NULL,NULL},
/* 1ED75 */ { NULL,NULL},
/* 1ED76 */ { NULL,NULL},
/* 1ED77 */ { NULL,NULL},
/* 1ED78 */ { NULL,NULL},
/* 1ED79 */ { NULL,NULL},
/* 1ED7A */ { NULL,NULL},
/* 1ED7B */ { NULL,NULL},
/* 1ED7C */ { NULL,NULL},
/* 1ED7D */ { NULL,NULL},
/* 1ED7E */ { NULL,NULL},
/* 1ED7F */ { NULL,NULL},
/* 1ED80 */ { NULL,NULL},
/* 1ED81 */ { NULL,NULL},
/* 1ED82 */ { NULL,NULL},
/* 1ED83 */ { NULL,NULL},
/* 1ED84 */ { NULL,NULL},
/* 1ED85 */ { NULL,NULL},
/* 1ED86 */ { NULL,NULL},
/* 1ED87 */ { NULL,NULL},
/* 1ED88 */ { NULL,NULL},
/* 1ED89 */ { NULL,NULL},
/* 1ED8A */ { NULL,NULL},
/* 1ED8B */ { NULL,NULL},
/* 1ED8C */ { NULL,NULL},
/* 1ED8D */ { NULL,NULL},
/* 1ED8E */ { NULL,NULL},
/* 1ED8F */ { NULL,NULL},
/* 1ED90 */ { NULL,NULL},
/* 1ED91 */ { NULL,NULL},
/* 1ED92 */ { NULL,NULL},
/* 1ED93 */ { NULL,NULL},
/* 1ED94 */ { NULL,NULL},
/* 1ED95 */ { NULL,NULL},
/* 1ED96 */ { NULL,NULL},
/* 1ED97 */ { NULL,NULL},
/* 1ED98 */ { NULL,NULL},
/* 1ED99 */ { NULL,NULL},
/* 1ED9A */ { NULL,NULL},
/* 1ED9B */ { NULL,NULL},
/* 1ED9C */ { NULL,NULL},
/* 1ED9D */ { NULL,NULL},
/* 1ED9E */ { NULL,NULL},
/* 1ED9F */ { NULL,NULL},
/* 1EDA0 */ { NULL,NULL},
/* 1EDA1 */ { NULL,NULL},
/* 1EDA2 */ { NULL,NULL},
/* 1EDA3 */ { NULL,NULL},
/* 1EDA4 */ { NULL,NULL},
/* 1EDA5 */ { NULL,NULL},
/* 1EDA6 */ { NULL,NULL},
/* 1EDA7 */ { NULL,NULL},
/* 1EDA8 */ { NULL,NULL},
/* 1EDA9 */ { NULL,NULL},
/* 1EDAA */ { NULL,NULL},
/* 1EDAB */ { NULL,NULL},
/* 1EDAC */ { NULL,NULL},
/* 1EDAD */ { NULL,NULL},
/* 1EDAE */ { NULL,NULL},
/* 1EDAF */ { NULL,NULL},
/* 1EDB0 */ { NULL,NULL},
/* 1EDB1 */ { NULL,NULL},
/* 1EDB2 */ { NULL,NULL},
/* 1EDB3 */ { NULL,NULL},
/* 1EDB4 */ { NULL,NULL},
/* 1EDB5 */ { NULL,NULL},
/* 1EDB6 */ { NULL,NULL},
/* 1EDB7 */ { NULL,NULL},
/* 1EDB8 */ { NULL,NULL},
/* 1EDB9 */ { NULL,NULL},
/* 1EDBA */ { NULL,NULL},
/* 1EDBB */ { NULL,NULL},
/* 1EDBC */ { NULL,NULL},
/* 1EDBD */ { NULL,NULL},
/* 1EDBE */ { NULL,NULL},
/* 1EDBF */ { NULL,NULL},
/* 1EDC0 */ { NULL,NULL},
/* 1EDC1 */ { NULL,NULL},
/* 1EDC2 */ { NULL,NULL},
/* 1EDC3 */ { NULL,NULL},
/* 1EDC4 */ { NULL,NULL},
/* 1EDC5 */ { NULL,NULL},
/* 1EDC6 */ { NULL,NULL},
/* 1EDC7 */ { NULL,NULL},
/* 1EDC8 */ { NULL,NULL},
/* 1EDC9 */ { NULL,NULL},
/* 1EDCA */ { NULL,NULL},
/* 1EDCB */ { NULL,NULL},
/* 1EDCC */ { NULL,NULL},
/* 1EDCD */ { NULL,NULL},
/* 1EDCE */ { NULL,NULL},
/* 1EDCF */ { NULL,NULL},
/* 1EDD0 */ { NULL,NULL},
/* 1EDD1 */ { NULL,NULL},
/* 1EDD2 */ { NULL,NULL},
/* 1EDD3 */ { NULL,NULL},
/* 1EDD4 */ { NULL,NULL},
/* 1EDD5 */ { NULL,NULL},
/* 1EDD6 */ { NULL,NULL},
/* 1EDD7 */ { NULL,NULL},
/* 1EDD8 */ { NULL,NULL},
/* 1EDD9 */ { NULL,NULL},
/* 1EDDA */ { NULL,NULL},
/* 1EDDB */ { NULL,NULL},
/* 1EDDC */ { NULL,NULL},
/* 1EDDD */ { NULL,NULL},
/* 1EDDE */ { NULL,NULL},
/* 1EDDF */ { NULL,NULL},
/* 1EDE0 */ { NULL,NULL},
/* 1EDE1 */ { NULL,NULL},
/* 1EDE2 */ { NULL,NULL},
/* 1EDE3 */ { NULL,NULL},
/* 1EDE4 */ { NULL,NULL},
/* 1EDE5 */ { NULL,NULL},
/* 1EDE6 */ { NULL,NULL},
/* 1EDE7 */ { NULL,NULL},
/* 1EDE8 */ { NULL,NULL},
/* 1EDE9 */ { NULL,NULL},
/* 1EDEA */ { NULL,NULL},
/* 1EDEB */ { NULL,NULL},
/* 1EDEC */ { NULL,NULL},
/* 1EDED */ { NULL,NULL},
/* 1EDEE */ { NULL,NULL},
/* 1EDEF */ { NULL,NULL},
/* 1EDF0 */ { NULL,NULL},
/* 1EDF1 */ { NULL,NULL},
/* 1EDF2 */ { NULL,NULL},
/* 1EDF3 */ { NULL,NULL},
/* 1EDF4 */ { NULL,NULL},
/* 1EDF5 */ { NULL,NULL},
/* 1EDF6 */ { NULL,NULL},
/* 1EDF7 */ { NULL,NULL},
/* 1EDF8 */ { NULL,NULL},
/* 1EDF9 */ { NULL,NULL},
/* 1EDFA */ { NULL,NULL},
/* 1EDFB */ { NULL,NULL},
/* 1EDFC */ { NULL,NULL},
/* 1EDFD */ { NULL,NULL},
/* 1EDFE */ { NULL,NULL},
/* 1EDFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_EE[] = {
/* 1EE00 */ { "SYMBOLE MATHÉMATIQUE ARABE ALIF","	x (lettre arabe alif isolé - FE8D)\n"
	"	# <police> 0627 lettre arabe alif"},
/* 1EE01 */ { "SYMBOLE MATHÉMATIQUE ARABE BA'","	x (lettre arabe ba' isolé - FE8F)\n"
	"	# <police> 0628 lettre arabe ba'"},
/* 1EE02 */ { "SYMBOLE MATHÉMATIQUE ARABE DJÎM","	x (lettre arabe djîm isolé - FE9D)\n"
	"	# <police> 062C lettre arabe djîm"},
/* 1EE03 */ { "SYMBOLE MATHÉMATIQUE ARABE DAL","	x (lettre arabe dal isolé - FEA9)\n"
	"	# <police> 062F lettre arabe dal"},
/* 1EE04 */ { NULL,NULL},
/* 1EE05 */ { "SYMBOLE MATHÉMATIQUE ARABE WAW","	x (lettre arabe waw isolé - FEED)\n"
	"	# <police> 0648 lettre arabe waw"},
/* 1EE06 */ { "SYMBOLE MATHÉMATIQUE ARABE ZAÏN","	x (lettre arabe zaïn isolé - FEAF)\n"
	"	# <police> 0632 lettre arabe zaïn"},
/* 1EE07 */ { "SYMBOLE MATHÉMATIQUE ARABE HA'","	x (lettre arabe ha' isolé - FEA1)\n"
	"	# <police> 062D lettre arabe ha'"},
/* 1EE08 */ { "SYMBOLE MATHÉMATIQUE ARABE TA'","	x (lettre arabe ta' isolé - FEC1)\n"
	"	# <police> 0637 lettre arabe ta'"},
/* 1EE09 */ { "SYMBOLE MATHÉMATIQUE ARABE YA'","	x (lettre arabe ya' isolé - FEF1)\n"
	"	# <police> 064A lettre arabe ya'"},
/* 1EE0A */ { "SYMBOLE MATHÉMATIQUE ARABE KAF","	x (lettre arabe kaf isolé - FED9)\n"
	"	# <police> 0643 lettre arabe kaf"},
/* 1EE0B */ { "SYMBOLE MATHÉMATIQUE ARABE LAM","	x (lettre arabe lam isolé - FEDD)\n"
	"	# <police> 0644 lettre arabe lam"},
/* 1EE0C */ { "SYMBOLE MATHÉMATIQUE ARABE MÎM","	x (lettre arabe mîm isolé - FEE1)\n"
	"	# <police> 0645 lettre arabe mîm"},
/* 1EE0D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN","	x (lettre arabe noûn isolé - FEE5)\n"
	"	# <police> 0646 lettre arabe noûn"},
/* 1EE0E */ { "SYMBOLE MATHÉMATIQUE ARABE SÎN","	x (lettre arabe sîn isolé - FEB1)\n"
	"	# <police> 0633 lettre arabe sîn"},
/* 1EE0F */ { "SYMBOLE MATHÉMATIQUE ARABE 'AÏN","	x (lettre arabe 'aïn isolé - FEC9)\n"
	"	# <police> 0639 lettre arabe 'aïn"},
/* 1EE10 */ { "SYMBOLE MATHÉMATIQUE ARABE FA'","	x (lettre arabe fa' isolé - FED1)\n"
	"	# <police> 0641 lettre arabe fa'"},
/* 1EE11 */ { "SYMBOLE MATHÉMATIQUE ARABE ÇAD","	x (lettre arabe çad isolé - FEB9)\n"
	"	# <police> 0635 lettre arabe çad"},
/* 1EE12 */ { "SYMBOLE MATHÉMATIQUE ARABE QAF","	x (lettre arabe qaf isolé - FED5)\n"
	"	# <police> 0642 lettre arabe qaf"},
/* 1EE13 */ { "SYMBOLE MATHÉMATIQUE ARABE RA'","	x (lettre arabe ra' isolé - FEAD)\n"
	"	# <police> 0631 lettre arabe ra'"},
/* 1EE14 */ { "SYMBOLE MATHÉMATIQUE ARABE CHÎN","	x (lettre arabe chîn isolé - FEB5)\n"
	"	# <police> 0634 lettre arabe chîn"},
/* 1EE15 */ { "SYMBOLE MATHÉMATIQUE ARABE TÉ'","	x (lettre arabe té' isolé - FE95)\n"
	"	# <police> 062A lettre arabe té'"},
/* 1EE16 */ { "SYMBOLE MATHÉMATIQUE ARABE THÉ","	x (lettre arabe thé' isolé - FE99)\n"
	"	# <police> 062B lettre arabe thé'"},
/* 1EE17 */ { "SYMBOLE MATHÉMATIQUE ARABE KHA'","	x (lettre arabe kha' isolé - FEA5)\n"
	"	# <police> 062E lettre arabe kha'"},
/* 1EE18 */ { "SYMBOLE MATHÉMATIQUE ARABE DHAL","	x (lettre arabe dhal isolé - FEAB)\n"
	"	# <police> 0630 lettre arabe dhal"},
/* 1EE19 */ { "SYMBOLE MATHÉMATIQUE ARABE DAD","	x (lettre arabe dad isolé - FEBD)\n"
	"	# <police> 0636 lettre arabe dad"},
/* 1EE1A */ { "SYMBOLE MATHÉMATIQUE ARABE ZZA'","	x (lettre arabe zza' isolé - FEC5)\n"
	"	# <police> 0638 lettre arabe zza'"},
/* 1EE1B */ { "SYMBOLE MATHÉMATIQUE ARABE GHAÏN","	x (lettre arabe ghaïn isolé - FECD)\n"
	"	# <police> 063A lettre arabe ghaïn"},
/* 1EE1C */ { "SYMBOLE MATHÉMATIQUE ARABE BA' SANS POINT","	x (lettre arabe ba' sans point - 066E)\n"
	"	# <police> 066E lettre arabe ba' sans point"},
/* 1EE1D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN SANS POINT","	x (lettre arabe noûn ghounna isolé - FB9E)\n"
	"	# <police> 06BA lettre arabe noûn ghounna"},
/* 1EE1E */ { "SYMBOLE MATHÉMATIQUE ARABE FA' SANS POINT","	x (lettre arabe fa' sans point - 06A1)\n"
	"	# <police> 06A1 lettre arabe fa' sans point"},
/* 1EE1F */ { "SYMBOLE MATHÉMATIQUE ARABE QAF SANS POINT","	x (lettre arabe qaf sans point - 066F)\n"
	"	# <police> 066F lettre arabe qaf sans point"},
/* 1EE20 */ { NULL,NULL},
/* 1EE21 */ { "SYMBOLE MATHÉMATIQUE ARABE BA' INITIAL","	x (lettre arabe ba' initial - FE91)\n"
	"	# <police> 0628 lettre arabe ba'"},
/* 1EE22 */ { "SYMBOLE MATHÉMATIQUE ARABE DJÎM INITIAL","	x (lettre arabe djîm initial - FE9F)\n"
	"	# <police> 062C lettre arabe djîm"},
/* 1EE23 */ { NULL,NULL},
/* 1EE24 */ { "SYMBOLE MATHÉMATIQUE ARABE HÉ' INITIAL","	x (lettre arabe hé' initial - FEEB)\n"
	"	# <police> 0647 lettre arabe hé'"},
/* 1EE25 */ { NULL,NULL},
/* 1EE26 */ { NULL,NULL},
/* 1EE27 */ { "SYMBOLE MATHÉMATIQUE ARABE HA' INITIAL","	x (lettre arabe ha' initial - FEA3)\n"
	"	# <police> 062D lettre arabe ha'"},
/* 1EE28 */ { NULL,NULL},
/* 1EE29 */ { "SYMBOLE MATHÉMATIQUE ARABE YA' INITIAL","	x (lettre arabe ya' initial - FEF3)\n"
	"	# <police> 064A lettre arabe ya'"},
/* 1EE2A */ { "SYMBOLE MATHÉMATIQUE ARABE KAF INITIAL","	x (lettre arabe kaf initial - FEDB)\n"
	"	# <police> 0643 lettre arabe kaf"},
/* 1EE2B */ { "SYMBOLE MATHÉMATIQUE ARABE LAM INITIAL","	x (lettre arabe lam initial - FEDF)\n"
	"	# <police> 0644 lettre arabe lam"},
/* 1EE2C */ { "SYMBOLE MATHÉMATIQUE ARABE MÎM INITIAL","	x (lettre arabe mîm initial - FEE3)\n"
	"	# <police> 0645 lettre arabe mîm"},
/* 1EE2D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN INITIAL","	x (lettre arabe noûn initial - FEE7)\n"
	"	# <police> 0646 lettre arabe noûn"},
/* 1EE2E */ { "SYMBOLE MATHÉMATIQUE ARABE SÎN INITIAL","	x (lettre arabe sîn initial - FEB3)\n"
	"	# <police> 0633 lettre arabe sîn"},
/* 1EE2F */ { "SYMBOLE MATHÉMATIQUE ARABE 'AÏN INITIAL","	x (lettre arabe 'aïn initial - FECB)\n"
	"	# <police> 0639 lettre arabe 'aïn"},
/* 1EE30 */ { "SYMBOLE MATHÉMATIQUE ARABE FA' INITIAL","	x (lettre arabe fa' initial - FED3)\n"
	"	# <police> 0641 lettre arabe fa'"},
/* 1EE31 */ { "SYMBOLE MATHÉMATIQUE ARABE ÇAD INITIAL","	x (lettre arabe çad initial - FEBB)\n"
	"	# <police> 0635 lettre arabe çad"},
/* 1EE32 */ { "SYMBOLE MATHÉMATIQUE ARABE QAF INITIAL","	x (lettre arabe qaf initial - FED7)\n"
	"	# <police> 0642 lettre arabe qaf"},
/* 1EE33 */ { NULL,NULL},
/* 1EE34 */ { "SYMBOLE MATHÉMATIQUE ARABE CHÎN INITIAL","	x (lettre arabe chîn initial - FEB7)\n"
	"	# <police> 0634 lettre arabe chîn"},
/* 1EE35 */ { "SYMBOLE MATHÉMATIQUE ARABE TÉ' INITIAL","	x (lettre arabe té' initial - FE97)\n"
	"	# <police> 062A lettre arabe té'"},
/* 1EE36 */ { "SYMBOLE MATHÉMATIQUE ARABE THÉ' INITIAL","	x (lettre arabe thé' initial - FE9B)\n"
	"	# <police> 062B lettre arabe thé'"},
/* 1EE37 */ { "SYMBOLE MATHÉMATIQUE ARABE KHA' INITIAL","	x (lettre arabe kha' initial - FEA7)\n"
	"	# <police> 062E lettre arabe kha'"},
/* 1EE38 */ { NULL,NULL},
/* 1EE39 */ { "SYMBOLE MATHÉMATIQUE ARABE DAD INITIAL","	x (lettre arabe dad initial - FEBF)\n"
	"	# <police> 0636 lettre arabe dad"},
/* 1EE3A */ { NULL,NULL},
/* 1EE3B */ { "SYMBOLE MATHÉMATIQUE ARABE GHAÏN INITIAL","	x (lettre arabe ghaïn initial - FECF)\n"
	"	# <police> 063A lettre arabe ghaïn"},
/* 1EE3C */ { NULL,NULL},
/* 1EE3D */ { NULL,NULL},
/* 1EE3E */ { NULL,NULL},
/* 1EE3F */ { NULL,NULL},
/* 1EE40 */ { NULL,NULL},
/* 1EE41 */ { NULL,NULL},
/* 1EE42 */ { "SYMBOLE MATHÉMATIQUE ARABE DJÎM À QUEUE","	# <police> 062C lettre arabe djîm"},
/* 1EE43 */ { NULL,NULL},
/* 1EE44 */ { NULL,NULL},
/* 1EE45 */ { NULL,NULL},
/* 1EE46 */ { NULL,NULL},
/* 1EE47 */ { "SYMBOLE MATHÉMATIQUE ARABE HA' À QUEUE","	# <police> 062D lettre arabe ha'"},
/* 1EE48 */ { NULL,NULL},
/* 1EE49 */ { "SYMBOLE MATHÉMATIQUE ARABE YA' À QUEUE","	# <police> 064A lettre arabe ya'"},
/* 1EE4A */ { NULL,NULL},
/* 1EE4B */ { "SYMBOLE MATHÉMATIQUE ARABE LAM À QUEUE","	# <police> 0644 lettre arabe lam"},
/* 1EE4C */ { NULL,NULL},
/* 1EE4D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN À QUEUE","	# <police> 0646 lettre arabe noûn"},
/* 1EE4E */ { "SYMBOLE MATHÉMATIQUE ARABE SÎN À QUEUE","	# <police> 0633 lettre arabe sîn"},
/* 1EE4F */ { "SYMBOLE MATHÉMATIQUE ARABE 'AÏN À QUEUE","	# <police> 0639 lettre arabe 'aïn"},
/* 1EE50 */ { NULL,NULL},
/* 1EE51 */ { "SYMBOLE MATHÉMATIQUE ARABE ÇAD À QUEUE","	# <police> 0635 lettre arabe çad"},
/* 1EE52 */ { "SYMBOLE MATHÉMATIQUE ARABE QAF À QUEUE","	# <police> 0642 lettre arabe qaf"},
/* 1EE53 */ { NULL,NULL},
/* 1EE54 */ { "SYMBOLE MATHÉMATIQUE ARABE CHÎN À QUEUE","	# <police> 0634 lettre arabe chîn"},
/* 1EE55 */ { NULL,NULL},
/* 1EE56 */ { NULL,NULL},
/* 1EE57 */ { "SYMBOLE MATHÉMATIQUE ARABE KHA' À QUEUE","	# <police> 062E lettre arabe kha'"},
/* 1EE58 */ { NULL,NULL},
/* 1EE59 */ { "SYMBOLE MATHÉMATIQUE ARABE DAD À QUEUE","	# <police> 0636 lettre arabe dad"},
/* 1EE5A */ { NULL,NULL},
/* 1EE5B */ { "SYMBOLE MATHÉMATIQUE ARABE GHAÏN À QUEUE","	# <police> 063A lettre arabe ghaïn"},
/* 1EE5C */ { NULL,NULL},
/* 1EE5D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN SANS POINT À QUEUE","	# <police> 06BA lettre arabe noûn ghounna"},
/* 1EE5E */ { NULL,NULL},
/* 1EE5F */ { "SYMBOLE MATHÉMATIQUE ARABE QAF SANS POINT À QUEUE","	# <police> 066F lettre arabe qaf sans point"},
/* 1EE60 */ { NULL,NULL},
/* 1EE61 */ { "SYMBOLE MATHÉMATIQUE ARABE BA' ÉTIRÉ","	# <police> 0628 lettre arabe ba'"},
/* 1EE62 */ { "SYMBOLE MATHÉMATIQUE ARABE DJÎM ÉTIRÉ","	# <police> 062C lettre arabe djîm"},
/* 1EE63 */ { NULL,NULL},
/* 1EE64 */ { "SYMBOLE MATHÉMATIQUE ARABE HÉ' ÉTIRÉ","	# <police> 0647 lettre arabe hé'"},
/* 1EE65 */ { NULL,NULL},
/* 1EE66 */ { NULL,NULL},
/* 1EE67 */ { "SYMBOLE MATHÉMATIQUE ARABE HA' ÉTIRÉ","	# <police> 062D lettre arabe ha'"},
/* 1EE68 */ { "SYMBOLE MATHÉMATIQUE ARABE TA' ÉTIRÉ","	# <police> 0637 lettre arabe ta'"},
/* 1EE69 */ { "SYMBOLE MATHÉMATIQUE ARABE YA' ÉTIRÉ","	# <police> 064A lettre arabe ya'"},
/* 1EE6A */ { "SYMBOLE MATHÉMATIQUE ARABE KAF ÉTIRÉ","	# <police> 0643 lettre arabe kaf"},
/* 1EE6B */ { NULL,NULL},
/* 1EE6C */ { "SYMBOLE MATHÉMATIQUE ARABE MÎM ÉTIRÉ","	# <police> 0645 lettre arabe mîm"},
/* 1EE6D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN ÉTIRÉ","	# <police> 0646 lettre arabe noûn"},
/* 1EE6E */ { "SYMBOLE MATHÉMATIQUE ARABE SÎN ÉTIRÉ","	# <police> 0633 lettre arabe sîn"},
/* 1EE6F */ { "SYMBOLE MATHÉMATIQUE ARABE 'AÏN ÉTIRÉ","	# <police> 0639 lettre arabe 'aïn"},
/* 1EE70 */ { "SYMBOLE MATHÉMATIQUE ARABE FA' ÉTIRÉ","	# <police> 0641 lettre arabe fa'"},
/* 1EE71 */ { "SYMBOLE MATHÉMATIQUE ARABE ÇAD ÉTIRÉ","	# <police> 0635 lettre arabe çad"},
/* 1EE72 */ { "SYMBOLE MATHÉMATIQUE ARABE QAF ÉTIRÉ","	# <police> 0642 lettre arabe qaf"},
/* 1EE73 */ { NULL,NULL},
/* 1EE74 */ { "SYMBOLE MATHÉMATIQUE ARABE CHÎN ÉTIRÉ","	# <police> 0634 lettre arabe chîn"},
/* 1EE75 */ { "SYMBOLE MATHÉMATIQUE ARABE TÉ' ÉTIRÉ","	# <police> 062A lettre arabe té'"},
/* 1EE76 */ { "SYMBOLE MATHÉMATIQUE ARABE THÉ' ÉTIRÉ","	# <police> 062B lettre arabe thé'"},
/* 1EE77 */ { "SYMBOLE MATHÉMATIQUE ARABE KHA' ÉTIRÉ","	# <police> 062E lettre arabe kha'"},
/* 1EE78 */ { NULL,NULL},
/* 1EE79 */ { "SYMBOLE MATHÉMATIQUE ARABE DAD ÉTIRÉ","	# <police> 0636 lettre arabe dad"},
/* 1EE7A */ { "SYMBOLE MATHÉMATIQUE ARABE ZZA' ÉTIRÉ","	# <police> 0638 lettre arabe zza'"},
/* 1EE7B */ { "SYMBOLE MATHÉMATIQUE ARABE GHAÏN ÉTIRÉ","	# <police> 063A lettre arabe ghaïn"},
/* 1EE7C */ { "SYMBOLE MATHÉMATIQUE ARABE BA' SANS POINT ÉTIRÉ","	# <police> 066E lettre arabe ba' sans point"},
/* 1EE7D */ { NULL,NULL},
/* 1EE7E */ { "SYMBOLE MATHÉMATIQUE ARABE FA' SANS POINT ÉTIRÉ","	# <police> 06A1 lettre arabe fa' sans point"},
/* 1EE7F */ { NULL,NULL},
/* 1EE80 */ { "SYMBOLE MATHÉMATIQUE ARABE ALIF BOUCLÉ","	# <police> 0627 lettre arabe alif"},
/* 1EE81 */ { "SYMBOLE MATHÉMATIQUE ARABE BA' BOUCLÉ","	# <police> 0628 lettre arabe ba'"},
/* 1EE82 */ { "SYMBOLE MATHÉMATIQUE ARABE DJÎM BOUCLÉ","	# <police> 062C lettre arabe djîm"},
/* 1EE83 */ { "SYMBOLE MATHÉMATIQUE ARABE DAL BOUCLÉ","	# <police> 062F lettre arabe dal"},
/* 1EE84 */ { "SYMBOLE MATHÉMATIQUE ARABE HÉ' BOUCLÉ","	# <police> 0647 lettre arabe hé'"},
/* 1EE85 */ { "SYMBOLE MATHÉMATIQUE ARABE WAW BOUCLÉ","	# <police> 0648 lettre arabe waw"},
/* 1EE86 */ { "SYMBOLE MATHÉMATIQUE ARABE ZAÏN BOUCLÉ","	# <police> 0632 lettre arabe zaïn"},
/* 1EE87 */ { "SYMBOLE MATHÉMATIQUE ARABE HA' BOUCLÉ","	# <police> 062D lettre arabe ha'"},
/* 1EE88 */ { "SYMBOLE MATHÉMATIQUE ARABE TA' BOUCLÉ","	# <police> 0637 lettre arabe ta'"},
/* 1EE89 */ { "SYMBOLE MATHÉMATIQUE ARABE YA' BOUCLÉ","	# <police> 064A lettre arabe ya'"},
/* 1EE8A */ { NULL,NULL},
/* 1EE8B */ { "SYMBOLE MATHÉMATIQUE ARABE LAM BOUCLÉ","	# <police> 0644 lettre arabe lam"},
/* 1EE8C */ { "SYMBOLE MATHÉMATIQUE ARABE MÎM BOUCLÉ","	# <police> 0645 lettre arabe mîm"},
/* 1EE8D */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN BOUCLÉ","	# <police> 0646 lettre arabe noûn"},
/* 1EE8E */ { "SYMBOLE MATHÉMATIQUE ARABE SÏN BOUCLÉ","	# <police> 0633 lettre arabe sîn"},
/* 1EE8F */ { "SYMBOLE MATHÉMATIQUE ARABE 'AÏN BOUCLÉ","	# <police> 0639 lettre arabe 'aïn"},
/* 1EE90 */ { "SYMBOLE MATHÉMATIQUE ARABE FA' BOUCLÉ","	# <police> 0641 lettre arabe fa'"},
/* 1EE91 */ { "SYMBOLE MATHÉMATIQUE ARABE ÇAD BOUCLÉ","	# <police> 0635 lettre arabe çad"},
/* 1EE92 */ { "SYMBOLE MATHÉMATIQUE ARABE QAF BOUCLÉ","	# <police> 0642 lettre arabe qaf"},
/* 1EE93 */ { "SYMBOLE MATHÉMATIQUE ARABE RA' BOUCLÉ","	# <police> 0631 lettre arabe ra'"},
/* 1EE94 */ { "SYMBOLE MATHÉMATIQUE ARABE CHÎN BOUCLÉ","	# <police> 0634 lettre arabe chîn"},
/* 1EE95 */ { "SYMBOLE MATHÉMATIQUE ARABE TÉ' BOUCLÉ","	# <police> 062A lettre arabe té'"},
/* 1EE96 */ { "SYMBOLE MATHÉMATIQUE ARABE THÉ' BOUCLÉ","	# <police> 062B lettre arabe thé'"},
/* 1EE97 */ { "SYMBOLE MATHÉMATIQUE ARABE KHA' BOUCLÉ","	# <police> 062E lettre arabe kha'"},
/* 1EE98 */ { "SYMBOLE MATHÉMATIQUE ARABE DHAL BOUCLÉ","	# <police> 0630 lettre arabe dhal"},
/* 1EE99 */ { "SYMBOLE MATHÉMATIQUE ARABE DAD BOUCLÉ","	# <police> 0636 lettre arabe dad"},
/* 1EE9A */ { "SYMBOLE MATHÉMATIQUE ARABE ZZA' BOUCLÉ","	# <police> 0638 lettre arabe zza'"},
/* 1EE9B */ { "SYMBOLE MATHÉMATIQUE ARABE GHAÏN BOUCLÉ","	# <police> 063A lettre arabe ghaïn"},
/* 1EE9C */ { NULL,NULL},
/* 1EE9D */ { NULL,NULL},
/* 1EE9E */ { NULL,NULL},
/* 1EE9F */ { NULL,NULL},
/* 1EEA0 */ { NULL,NULL},
/* 1EEA1 */ { "SYMBOLE MATHÉMATIQUE ARABE BA' AJOURÉ","	# <police> 0628 lettre arabe ba'"},
/* 1EEA2 */ { "SYMBOLE MATHÉMATIQUE ARABE DJÎM AJOURÉ","	# <police> 062C lettre arabe djîm"},
/* 1EEA3 */ { "SYMBOLE MATHÉMATIQUE ARABE DAL AJOURÉ","	# <police> 062F lettre arabe dal"},
/* 1EEA4 */ { NULL,NULL},
/* 1EEA5 */ { "SYMBOLE MATHÉMATIQUE ARABE WAW AJOURÉ","	# <police> 0648 lettre arabe waw"},
/* 1EEA6 */ { "SYMBOLE MATHÉMATIQUE ARABE ZAÏN AJOURÉ","	# <police> 0632 lettre arabe zaïn"},
/* 1EEA7 */ { "SYMBOLE MATHÉMATIQUE ARABE HA' AJOURÉ","	# <police> 062D lettre arabe ha'"},
/* 1EEA8 */ { "SYMBOLE MATHÉMATIQUE ARABE TA' AJOURÉ","	# <police> 0637 lettre arabe ta'"},
/* 1EEA9 */ { "SYMBOLE MATHÉMATIQUE ARABE YA' AJOURÉ","	# <police> 064A lettre arabe ya'"},
/* 1EEAA */ { NULL,NULL},
/* 1EEAB */ { "SYMBOLE MATHÉMATIQUE ARABE LAM AJOURÉ","	# <police> 0644 lettre arabe lam"},
/* 1EEAC */ { "SYMBOLE MATHÉMATIQUE ARABE MÎM AJOURÉ","	# <police> 0645 lettre arabe mîm"},
/* 1EEAD */ { "SYMBOLE MATHÉMATIQUE ARABE NOÛN AJOURÉ","	# <police> 0646 lettre arabe noûn"},
/* 1EEAE */ { "SYMBOLE MATHÉMATIQUE ARABE SÎN AJOURÉ","	# <police> 0633 lettre arabe sîn"},
/* 1EEAF */ { "SYMBOLE MATHÉMATIQUE ARABE 'AÏN AJOURÉ","	# <police> 0639 lettre arabe 'aïn"},
/* 1EEB0 */ { "SYMBOLE MATHÉMATIQUE ARABE FA' AJOURÉ","	# <police> 0641 lettre arabe fa'"},
/* 1EEB1 */ { "SYMBOLE MATHÉMATIQUE ARABE ÇAD AJOURÉ","	# <police> 0635 lettre arabe çad"},
/* 1EEB2 */ { "SYMBOLE MATHÉMATIQUE ARABE QAF AJOURÉ","	# <police> 0642 lettre arabe qaf"},
/* 1EEB3 */ { "SYMBOLE MATHÉMATIQUE ARABE RA' AJOURÉ","	# <police> 0631 lettre arabe ra'"},
/* 1EEB4 */ { "SYMBOLE MATHÉMATIQUE ARABE CHÎN AJOURÉ","	# <police> 0634 lettre arabe chîn"},
/* 1EEB5 */ { "SYMBOLE MATHÉMATIQUE ARABE TÉ' AJOURÉ","	# <police> 062A lettre arabe té'"},
/* 1EEB6 */ { "SYMBOLE MATHÉMATIQUE ARABE THÉ' AJOURÉ","	# <police> 062B lettre arabe thé'"},
/* 1EEB7 */ { "SYMBOLE MATHÉMATIQUE ARABE KHA' AJOURÉ","	# <police> 062E lettre arabe kha'"},
/* 1EEB8 */ { "SYMBOLE MATHÉMATIQUE ARABE DHAL AJOURÉ","	# <police> 0630 lettre arabe dhal"},
/* 1EEB9 */ { "SYMBOLE MATHÉMATIQUE ARABE DAD AJOURÉ","	# <police> 0636 lettre arabe dad"},
/* 1EEBA */ { "SYMBOLE MATHÉMATIQUE ARABE ZZA' AJOURÉ","	# <police> 0638 lettre arabe zza'"},
/* 1EEBB */ { "SYMBOLE MATHÉMATIQUE ARABE GHAÏN AJOURÉ","	# <police> 063A lettre arabe ghaïn"},
/* 1EEBC */ { NULL,NULL},
/* 1EEBD */ { NULL,NULL},
/* 1EEBE */ { NULL,NULL},
/* 1EEBF */ { NULL,NULL},
/* 1EEC0 */ { NULL,NULL},
/* 1EEC1 */ { NULL,NULL},
/* 1EEC2 */ { NULL,NULL},
/* 1EEC3 */ { NULL,NULL},
/* 1EEC4 */ { NULL,NULL},
/* 1EEC5 */ { NULL,NULL},
/* 1EEC6 */ { NULL,NULL},
/* 1EEC7 */ { NULL,NULL},
/* 1EEC8 */ { NULL,NULL},
/* 1EEC9 */ { NULL,NULL},
/* 1EECA */ { NULL,NULL},
/* 1EECB */ { NULL,NULL},
/* 1EECC */ { NULL,NULL},
/* 1EECD */ { NULL,NULL},
/* 1EECE */ { NULL,NULL},
/* 1EECF */ { NULL,NULL},
/* 1EED0 */ { NULL,NULL},
/* 1EED1 */ { NULL,NULL},
/* 1EED2 */ { NULL,NULL},
/* 1EED3 */ { NULL,NULL},
/* 1EED4 */ { NULL,NULL},
/* 1EED5 */ { NULL,NULL},
/* 1EED6 */ { NULL,NULL},
/* 1EED7 */ { NULL,NULL},
/* 1EED8 */ { NULL,NULL},
/* 1EED9 */ { NULL,NULL},
/* 1EEDA */ { NULL,NULL},
/* 1EEDB */ { NULL,NULL},
/* 1EEDC */ { NULL,NULL},
/* 1EEDD */ { NULL,NULL},
/* 1EEDE */ { NULL,NULL},
/* 1EEDF */ { NULL,NULL},
/* 1EEE0 */ { NULL,NULL},
/* 1EEE1 */ { NULL,NULL},
/* 1EEE2 */ { NULL,NULL},
/* 1EEE3 */ { NULL,NULL},
/* 1EEE4 */ { NULL,NULL},
/* 1EEE5 */ { NULL,NULL},
/* 1EEE6 */ { NULL,NULL},
/* 1EEE7 */ { NULL,NULL},
/* 1EEE8 */ { NULL,NULL},
/* 1EEE9 */ { NULL,NULL},
/* 1EEEA */ { NULL,NULL},
/* 1EEEB */ { NULL,NULL},
/* 1EEEC */ { NULL,NULL},
/* 1EEED */ { NULL,NULL},
/* 1EEEE */ { NULL,NULL},
/* 1EEEF */ { NULL,NULL},
/* 1EEF0 */ { "SYMBOLE MATHÉMATIQUE ARABE OPÉRATEUR MÎM HA' TATOUÏL","	* utilisé en mathématique arabe pour indiquer la sommation\n"
	"	* s'étire au tatouïl\n"
	"	x (sommation de la famille - 2211)"},
/* 1EEF1 */ { "SYMBOLE MATHÉMATIQUE ARABE OPÉRATEUR HA' DAL","	* utilisé en mathématique perse pour indiquer les limites\n"
	"	* s'étire entre le hāʾ et le dāl"},
/* 1EEF2 */ { NULL,NULL},
/* 1EEF3 */ { NULL,NULL},
/* 1EEF4 */ { NULL,NULL},
/* 1EEF5 */ { NULL,NULL},
/* 1EEF6 */ { NULL,NULL},
/* 1EEF7 */ { NULL,NULL},
/* 1EEF8 */ { NULL,NULL},
/* 1EEF9 */ { NULL,NULL},
/* 1EEFA */ { NULL,NULL},
/* 1EEFB */ { NULL,NULL},
/* 1EEFC */ { NULL,NULL},
/* 1EEFD */ { NULL,NULL},
/* 1EEFE */ { NULL,NULL},
/* 1EEFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F0[] = {
/* 1F000 */ { "TUILE DE MAJONG VENT D'EST",NULL},
/* 1F001 */ { "TUILE DE MAJONG VENT DU SUD",NULL},
/* 1F002 */ { "TUILE DE MAJONG VENT D'OUEST",NULL},
/* 1F003 */ { "TUILE DE MAJONG VENT DU NORD",NULL},
/* 1F004 */ { "TUILE DE MAJONG DRAGON ROUGE","	= hongzhong"},
/* 1F005 */ { "TUILE DE MAJONG DRAGON VERT","	= qingfa"},
/* 1F006 */ { "TUILE DE MAJONG DRAGON BLANC","	= baiban"},
/* 1F007 */ { "TUILE DE MAJONG UN DE CARACTÈRE","	= wan"},
/* 1F008 */ { "TUILE DE MAJONG DEUX DE CARACTÈRE",NULL},
/* 1F009 */ { "TUILE DE MAJONG TROIS DE CARACTÈRE",NULL},
/* 1F00A */ { "TUILE DE MAJONG QUATRE DE CARACTÈRE",NULL},
/* 1F00B */ { "TUILE DE MAJONG CINQ DE CARACTÈRE",NULL},
/* 1F00C */ { "TUILE DE MAJONG SIX DE CARACTÈRE",NULL},
/* 1F00D */ { "TUILE DE MAJONG SEPT DE CARACTÈRE",NULL},
/* 1F00E */ { "TUILE DE MAJONG HUIT DE CARACTÈRE",NULL},
/* 1F00F */ { "TUILE DE MAJONG NEUF DE CARACTÈRE",NULL},
/* 1F010 */ { "TUILE DE MAJONG UN DE BAMBOU","	= tiao"},
/* 1F011 */ { "TUILE DE MAJONG DEUX DE BAMBOU",NULL},
/* 1F012 */ { "TUILE DE MAJONG TROIS DE BAMBOU",NULL},
/* 1F013 */ { "TUILE DE MAJONG QUATRE DE BAMBOU",NULL},
/* 1F014 */ { "TUILE DE MAJONG CINQ DE BAMBOU",NULL},
/* 1F015 */ { "TUILE DE MAJONG SIX DE BAMBOU",NULL},
/* 1F016 */ { "TUILE DE MAJONG SEPT DE BAMBOU",NULL},
/* 1F017 */ { "TUILE DE MAJONG HUIT DE BAMBOU",NULL},
/* 1F018 */ { "TUILE DE MAJONG NEUF DE BAMBOU",NULL},
/* 1F019 */ { "TUILE DE MAJONG UN DE CERCLE","	= bing"},
/* 1F01A */ { "TUILE DE MAJONG DEUX DE CERCLE",NULL},
/* 1F01B */ { "TUILE DE MAJONG TROIS DE CERCLE",NULL},
/* 1F01C */ { "TUILE DE MAJONG QUATRE DE CERCLE",NULL},
/* 1F01D */ { "TUILE DE MAJONG CINQ DE CERCLE",NULL},
/* 1F01E */ { "TUILE DE MAJONG SIX DE CERCLE",NULL},
/* 1F01F */ { "TUILE DE MAJONG SEPT DE CERCLE",NULL},
/* 1F020 */ { "TUILE DE MAJONG HUIT DE CERCLE",NULL},
/* 1F021 */ { "TUILE DE MAJONG NEUF DE CERCLE",NULL},
/* 1F022 */ { "TUILE DE MAJONG FLEUR DE PRUNIER","	= mei"},
/* 1F023 */ { "TUILE DE MAJONG ORCHIDÉE","	= lan"},
/* 1F024 */ { "TUILE DE MAJONG FLEUR DE BAMBOU","	= zhou"},
/* 1F025 */ { "TUILE DE MAJONG CHRYSANTHÈME","	= jou"},
/* 1F026 */ { "TUILE DE MAJONG PRINTEMPS",NULL},
/* 1F027 */ { "TUILE DE MAJONG ÉTÉ",NULL},
/* 1F028 */ { "TUILE DE MAJONG AUTOMNE",NULL},
/* 1F029 */ { "TUILE DE MAJONG HIVER",NULL},
/* 1F02A */ { "TUILE DE MAJONG JOKER","	= baida"},
/* 1F02B */ { "DOS DE TUILE DE MAJONG",NULL},
/* 1F02C */ { NULL,NULL},
/* 1F02D */ { NULL,NULL},
/* 1F02E */ { NULL,NULL},
/* 1F02F */ { NULL,NULL},
/* 1F030 */ { "DOS DE DOMINO HORIZONTAL",NULL},
/* 1F031 */ { "DOMINO HORIZONTAL-00-00",NULL},
/* 1F032 */ { "DOMINO HORIZONTAL-00-01",NULL},
/* 1F033 */ { "DOMINO HORIZONTAL-00-02",NULL},
/* 1F034 */ { "DOMINO HORIZONTAL-00-03",NULL},
/* 1F035 */ { "DOMINO HORIZONTAL-00-04",NULL},
/* 1F036 */ { "DOMINO HORIZONTAL-00-05",NULL},
/* 1F037 */ { "DOMINO HORIZONTAL-00-06",NULL},
/* 1F038 */ { "DOMINO HORIZONTAL-01-00",NULL},
/* 1F039 */ { "DOMINO HORIZONTAL-01-01",NULL},
/* 1F03A */ { "DOMINO HORIZONTAL-01-02",NULL},
/* 1F03B */ { "DOMINO HORIZONTAL-01-03",NULL},
/* 1F03C */ { "DOMINO HORIZONTAL-01-04",NULL},
/* 1F03D */ { "DOMINO HORIZONTAL-01-05",NULL},
/* 1F03E */ { "DOMINO HORIZONTAL-01-06",NULL},
/* 1F03F */ { "DOMINO HORIZONTAL-02-00",NULL},
/* 1F040 */ { "DOMINO HORIZONTAL-02-01",NULL},
/* 1F041 */ { "DOMINO HORIZONTAL-02-02",NULL},
/* 1F042 */ { "DOMINO HORIZONTAL-02-03",NULL},
/* 1F043 */ { "DOMINO HORIZONTAL-02-04",NULL},
/* 1F044 */ { "DOMINO HORIZONTAL-02-05",NULL},
/* 1F045 */ { "DOMINO HORIZONTAL-02-06",NULL},
/* 1F046 */ { "DOMINO HORIZONTAL-03-00",NULL},
/* 1F047 */ { "DOMINO HORIZONTAL-03-01",NULL},
/* 1F048 */ { "DOMINO HORIZONTAL-03-02",NULL},
/* 1F049 */ { "DOMINO HORIZONTAL-03-03",NULL},
/* 1F04A */ { "DOMINO HORIZONTAL-03-04",NULL},
/* 1F04B */ { "DOMINO HORIZONTAL-03-05",NULL},
/* 1F04C */ { "DOMINO HORIZONTAL-03-06",NULL},
/* 1F04D */ { "DOMINO HORIZONTAL-04-00",NULL},
/* 1F04E */ { "DOMINO HORIZONTAL-04-01",NULL},
/* 1F04F */ { "DOMINO HORIZONTAL-04-02",NULL},
/* 1F050 */ { "DOMINO HORIZONTAL-04-03",NULL},
/* 1F051 */ { "DOMINO HORIZONTAL-04-04",NULL},
/* 1F052 */ { "DOMINO HORIZONTAL-04-05",NULL},
/* 1F053 */ { "DOMINO HORIZONTAL-04-06",NULL},
/* 1F054 */ { "DOMINO HORIZONTAL-05-00",NULL},
/* 1F055 */ { "DOMINO HORIZONTAL-05-01",NULL},
/* 1F056 */ { "DOMINO HORIZONTAL-05-02",NULL},
/* 1F057 */ { "DOMINO HORIZONTAL-05-03",NULL},
/* 1F058 */ { "DOMINO HORIZONTAL-05-04",NULL},
/* 1F059 */ { "DOMINO HORIZONTAL-05-05",NULL},
/* 1F05A */ { "DOMINO HORIZONTAL-05-06",NULL},
/* 1F05B */ { "DOMINO HORIZONTAL-06-00",NULL},
/* 1F05C */ { "DOMINO HORIZONTAL-06-01",NULL},
/* 1F05D */ { "DOMINO HORIZONTAL-06-02",NULL},
/* 1F05E */ { "DOMINO HORIZONTAL-06-03",NULL},
/* 1F05F */ { "DOMINO HORIZONTAL-06-04",NULL},
/* 1F060 */ { "DOMINO HORIZONTAL-06-05",NULL},
/* 1F061 */ { "DOMINO HORIZONTAL-06-06",NULL},
/* 1F062 */ { "DOS DE DOMINO VERTICAL",NULL},
/* 1F063 */ { "DOMINO VERTICAL-00-00",NULL},
/* 1F064 */ { "DOMINO VERTICAL-00-01",NULL},
/* 1F065 */ { "DOMINO VERTICAL-00-02",NULL},
/* 1F066 */ { "DOMINO VERTICAL-00-03",NULL},
/* 1F067 */ { "DOMINO VERTICAL-00-04",NULL},
/* 1F068 */ { "DOMINO VERTICAL-00-05",NULL},
/* 1F069 */ { "DOMINO VERTICAL-00-06",NULL},
/* 1F06A */ { "DOMINO VERTICAL-01-00",NULL},
/* 1F06B */ { "DOMINO VERTICAL-01-01",NULL},
/* 1F06C */ { "DOMINO VERTICAL-01-02",NULL},
/* 1F06D */ { "DOMINO VERTICAL-01-03",NULL},
/* 1F06E */ { "DOMINO VERTICAL-01-04",NULL},
/* 1F06F */ { "DOMINO VERTICAL-01-05",NULL},
/* 1F070 */ { "DOMINO VERTICAL-01-06",NULL},
/* 1F071 */ { "DOMINO VERTICAL-02-00",NULL},
/* 1F072 */ { "DOMINO VERTICAL-02-01",NULL},
/* 1F073 */ { "DOMINO VERTICAL-02-02",NULL},
/* 1F074 */ { "DOMINO VERTICAL-02-03",NULL},
/* 1F075 */ { "DOMINO VERTICAL-02-04",NULL},
/* 1F076 */ { "DOMINO VERTICAL-02-05",NULL},
/* 1F077 */ { "DOMINO VERTICAL-02-06",NULL},
/* 1F078 */ { "DOMINO VERTICAL-03-00",NULL},
/* 1F079 */ { "DOMINO VERTICAL-03-01",NULL},
/* 1F07A */ { "DOMINO VERTICAL-03-02",NULL},
/* 1F07B */ { "DOMINO VERTICAL-03-03",NULL},
/* 1F07C */ { "DOMINO VERTICAL-03-04",NULL},
/* 1F07D */ { "DOMINO VERTICAL-03-05",NULL},
/* 1F07E */ { "DOMINO VERTICAL-03-06",NULL},
/* 1F07F */ { "DOMINO VERTICAL-04-00",NULL},
/* 1F080 */ { "DOMINO VERTICAL-04-01",NULL},
/* 1F081 */ { "DOMINO VERTICAL-04-02",NULL},
/* 1F082 */ { "DOMINO VERTICAL-04-03",NULL},
/* 1F083 */ { "DOMINO VERTICAL-04-04",NULL},
/* 1F084 */ { "DOMINO VERTICAL-04-05",NULL},
/* 1F085 */ { "DOMINO VERTICAL-04-06",NULL},
/* 1F086 */ { "DOMINO VERTICAL-05-00",NULL},
/* 1F087 */ { "DOMINO VERTICAL-05-01",NULL},
/* 1F088 */ { "DOMINO VERTICAL-05-02",NULL},
/* 1F089 */ { "DOMINO VERTICAL-05-03",NULL},
/* 1F08A */ { "DOMINO VERTICAL-05-04",NULL},
/* 1F08B */ { "DOMINO VERTICAL-05-05",NULL},
/* 1F08C */ { "DOMINO VERTICAL-05-06",NULL},
/* 1F08D */ { "DOMINO VERTICAL-06-00",NULL},
/* 1F08E */ { "DOMINO VERTICAL-06-01",NULL},
/* 1F08F */ { "DOMINO VERTICAL-06-02",NULL},
/* 1F090 */ { "DOMINO VERTICAL-06-03",NULL},
/* 1F091 */ { "DOMINO VERTICAL-06-04",NULL},
/* 1F092 */ { "DOMINO VERTICAL-06-05",NULL},
/* 1F093 */ { "DOMINO VERTICAL-06-06",NULL},
/* 1F094 */ { NULL,NULL},
/* 1F095 */ { NULL,NULL},
/* 1F096 */ { NULL,NULL},
/* 1F097 */ { NULL,NULL},
/* 1F098 */ { NULL,NULL},
/* 1F099 */ { NULL,NULL},
/* 1F09A */ { NULL,NULL},
/* 1F09B */ { NULL,NULL},
/* 1F09C */ { NULL,NULL},
/* 1F09D */ { NULL,NULL},
/* 1F09E */ { NULL,NULL},
/* 1F09F */ { NULL,NULL},
/* 1F0A0 */ { "DOS DE CARTE À JOUER",NULL},
/* 1F0A1 */ { "CARTE À JOUER AS DE PIQUE",NULL},
/* 1F0A2 */ { "CARTE À JOUER DEUX DE PIQUE",NULL},
/* 1F0A3 */ { "CARTE À JOUER TROIS DE PIQUE",NULL},
/* 1F0A4 */ { "CARTE À JOUER QUATRE DE PIQUE",NULL},
/* 1F0A5 */ { "CARTE À JOUER CINQ DE PIQUE",NULL},
/* 1F0A6 */ { "CARTE À JOUER SIX DE PIQUE",NULL},
/* 1F0A7 */ { "CARTE À JOUER SEPT DE PIQUE",NULL},
/* 1F0A8 */ { "CARTE À JOUER HUIT DE PIQUE",NULL},
/* 1F0A9 */ { "CARTE À JOUER NEUF DE PIQUE",NULL},
/* 1F0AA */ { "CARTE À JOUER DIX DE PIQUE",NULL},
/* 1F0AB */ { "CARTE À JOUER VALET DE PIQUE","	= valet, Bube, Unter, Page, fante"},
/* 1F0AC */ { "CARTE À JOUER CHEVALIER DE PIQUE","	= chevalier, Ober, Ritter, cavall, cavaliere"},
/* 1F0AD */ { "CARTE À JOUER DAME DE PIQUE","	= dame, Dame, Königin, regina"},
/* 1F0AE */ { "CARTE À JOUER ROI DE PIQUE","	= roi, König, re"},
/* 1F0AF */ { NULL,NULL},
/* 1F0B0 */ { NULL,NULL},
/* 1F0B1 */ { "CARTE À JOUER AS DE CŒUR",NULL},
/* 1F0B2 */ { "CARTE À JOUER DEUX DE CŒUR",NULL},
/* 1F0B3 */ { "CARTE À JOUER TROIS DE CŒUR",NULL},
/* 1F0B4 */ { "CARTE À JOUER QUATRE DE CŒUR",NULL},
/* 1F0B5 */ { "CARTE À JOUER CINQ DE CŒUR",NULL},
/* 1F0B6 */ { "CARTE À JOUER SIX DE CŒUR",NULL},
/* 1F0B7 */ { "CARTE À JOUER SEPT DE CŒUR",NULL},
/* 1F0B8 */ { "CARTE À JOUER HUIT DE CŒUR",NULL},
/* 1F0B9 */ { "CARTE À JOUER NEUF DE CŒUR",NULL},
/* 1F0BA */ { "CARTE À JOUER DIX DE CŒUR",NULL},
/* 1F0BB */ { "CARTE À JOUER VALET DE CŒUR",NULL},
/* 1F0BC */ { "CARTE À JOUER CHEVALIER DE CŒUR",NULL},
/* 1F0BD */ { "CARTE À JOUER DAME DE CŒUR",NULL},
/* 1F0BE */ { "CARTE À JOUER ROI DE CŒUR",NULL},
/* 1F0BF */ { "CARTE À JOUER JOKER ROUGE","	* s'utilise pour le troisième joker"},
/* 1F0C0 */ { NULL,NULL},
/* 1F0C1 */ { "CARTE À JOUER AS DE CARREAU",NULL},
/* 1F0C2 */ { "CARTE À JOUER DEUX DE CARREAU",NULL},
/* 1F0C3 */ { "CARTE À JOUER TROIS DE CARREAU",NULL},
/* 1F0C4 */ { "CARTE À JOUER QUATRE DE CARREAU",NULL},
/* 1F0C5 */ { "CARTE À JOUER CINQ DE CARREAU",NULL},
/* 1F0C6 */ { "CARTE À JOUER SIX DE CARREAU",NULL},
/* 1F0C7 */ { "CARTE À JOUER SEPT DE CARREAU",NULL},
/* 1F0C8 */ { "CARTE À JOUER HUIT DE CARREAU",NULL},
/* 1F0C9 */ { "CARTE À JOUER NEUF DE CARREAU",NULL},
/* 1F0CA */ { "CARTE À JOUER DIX DE CARREAU",NULL},
/* 1F0CB */ { "CARTE À JOUER VALET DE CARREAU",NULL},
/* 1F0CC */ { "CARTE À JOUER CHEVALIER DE CARREAU",NULL},
/* 1F0CD */ { "CARTE À JOUER DAME DE CARREAU",NULL},
/* 1F0CE */ { "CARTE À JOUER ROI DE CARREAU",NULL},
/* 1F0CF */ { "CARTE À JOUER JOKER NOIR",NULL},
/* 1F0D0 */ { NULL,NULL},
/* 1F0D1 */ { "CARTE À JOUER AS DE TRÈFLE",NULL},
/* 1F0D2 */ { "CARTE À JOUER DEUX DE TRÈFLE",NULL},
/* 1F0D3 */ { "CARTE À JOUER TROIS DE TRÈFLE",NULL},
/* 1F0D4 */ { "CARTE À JOUER QUATRE DE TRÈFLE",NULL},
/* 1F0D5 */ { "CARTE À JOUER CINQ DE TRÈFLE",NULL},
/* 1F0D6 */ { "CARTE À JOUER SIX DE TRÈFLE",NULL},
/* 1F0D7 */ { "CARTE À JOUER SEPT DE TRÈFLE",NULL},
/* 1F0D8 */ { "CARTE À JOUER HUIT DE TRÈFLE",NULL},
/* 1F0D9 */ { "CARTE À JOUER NEUF DE TRÈFLE",NULL},
/* 1F0DA */ { "CARTE À JOUER DIX DE TRÈFLE",NULL},
/* 1F0DB */ { "CARTE À JOUER VALET DE TRÈFLE",NULL},
/* 1F0DC */ { "CARTE À JOUER CHEVALIER DE TRÈFLE",NULL},
/* 1F0DD */ { "CARTE À JOUER DAME DE TRÈFLE",NULL},
/* 1F0DE */ { "CARTE À JOUER ROI DE TRÈFLE",NULL},
/* 1F0DF */ { "CARTE À JOUER JOKER BLANC","	* peut aussi être rouge"},
/* 1F0E0 */ { "CARTE À JOUER FOU",NULL},
/* 1F0E1 */ { "CARTE À JOUER ATOUT-1","	* individuel"},
/* 1F0E2 */ { "CARTE À JOUER ATOUT-2","	* enfance"},
/* 1F0E3 */ { "CARTE À JOUER ATOUT-3","	* jeunesse"},
/* 1F0E4 */ { "CARTE À JOUER ATOUT-4","	* âge mûr"},
/* 1F0E5 */ { "CARTE À JOUER ATOUT-5","	* âge avancé"},
/* 1F0E6 */ { "CARTE À JOUER ATOUT-6","	* matin"},
/* 1F0E7 */ { "CARTE À JOUER ATOUT-7","	* après-midi"},
/* 1F0E8 */ { "CARTE À JOUER ATOUT-8","	* soir"},
/* 1F0E9 */ { "CARTE À JOUER ATOUT-9","	* nuit"},
/* 1F0EA */ { "CARTE À JOUER ATOUT-10","	* terre et air"},
/* 1F0EB */ { "CARTE À JOUER ATOUT-11","	* eau et feu"},
/* 1F0EC */ { "CARTE À JOUER ATOUT-12","	* danse"},
/* 1F0ED */ { "CARTE À JOUER ATOUT-13","	* emplettes"},
/* 1F0EE */ { "CARTE À JOUER ATOUT-14","	* plein air"},
/* 1F0EF */ { "CARTE À JOUER ATOUT-15","	* arts graphiques"},
/* 1F0F0 */ { "CARTE À JOUER ATOUT-16","	* printemps"},
/* 1F0F1 */ { "CARTE À JOUER ATOUT-17","	* été"},
/* 1F0F2 */ { "CARTE À JOUER ATOUT-18","	* automne"},
/* 1F0F3 */ { "CARTE À JOUER ATOUT-19","	* hiver"},
/* 1F0F4 */ { "CARTE À JOUER ATOUT-20","	* le jeu"},
/* 1F0F5 */ { "CARTE À JOUER ATOUT-21","	* collectif"},
/* 1F0F6 */ { NULL,NULL},
/* 1F0F7 */ { NULL,NULL},
/* 1F0F8 */ { NULL,NULL},
/* 1F0F9 */ { NULL,NULL},
/* 1F0FA */ { NULL,NULL},
/* 1F0FB */ { NULL,NULL},
/* 1F0FC */ { NULL,NULL},
/* 1F0FD */ { NULL,NULL},
/* 1F0FE */ { NULL,NULL},
/* 1F0FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F1[] = {
/* 1F100 */ { "CHIFFRE ZÉRO POINT","	# 0030 002E"},
/* 1F101 */ { "CHIFFRE ZÉRO VIRGULE","	# 0030 002C"},
/* 1F102 */ { "CHIFFRE UN VIRGULE","	# 0031 002C"},
/* 1F103 */ { "CHIFFRE DEUX VIRGULE","	# 0032 002C"},
/* 1F104 */ { "CHIFFRE TROIS VIRGULE","	# 0033 002C"},
/* 1F105 */ { "CHIFFRE QUATRE VIRGULE","	# 0034 002C"},
/* 1F106 */ { "CHIFFRE CINQ VIRGULE","	# 0035 002C"},
/* 1F107 */ { "CHIFFRE SIX VIRGULE","	# 0036 002C"},
/* 1F108 */ { "CHIFFRE SEPT VIRGULE","	# 0037 002C"},
/* 1F109 */ { "CHIFFRE HUIT VIRGULE","	# 0038 002C"},
/* 1F10A */ { "CHIFFRE NEUF VIRGULE","	# 0039 002C"},
/* 1F10B */ { "VIGNETTE CHIFFRE ZÉRO SANS EMPATTEMENT CERCLÉ",NULL},
/* 1F10C */ { "VIGNETTE CHIFFRE ZÉRO SANS EMPATTEMENT CERCLÉ NOIR AU BLANC",NULL},
/* 1F10D */ { "ZÉRO À BARRE OBLIQUE CERCLÉ","	= aucuns droits réservés"},
/* 1F10E */ { "FLÈCHE SENS ANTIHORAIRE CERCLÉE","	= partage selon les conditions initiales"},
/* 1F10F */ { "SYMBOLE DOLLAR CERCLÉ SUPERPOSÉ D'UNE BARRE OBLIQUE INVERSÉE","	= pas d'utilisation commerciale"},
/* 1F110 */ { "LETTRE MAJUSCULE LATINE A ENTRE PARENTHÈSES","	# 0028 0041 0029"},
/* 1F111 */ { "LETTRE MAJUSCULE LATINE B ENTRE PARENTHÈSES","	# 0028 0042 0029"},
/* 1F112 */ { "LETTRE MAJUSCULE LATINE C ENTRE PARENTHÈSES","	# 0028 0043 0029"},
/* 1F113 */ { "LETTRE MAJUSCULE LATINE D ENTRE PARENTHÈSES","	# 0028 0044 0029"},
/* 1F114 */ { "LETTRE MAJUSCULE LATINE E ENTRE PARENTHÈSES","	# 0028 0045 0029"},
/* 1F115 */ { "LETTRE MAJUSCULE LATINE F ENTRE PARENTHÈSES","	# 0028 0046 0029"},
/* 1F116 */ { "LETTRE MAJUSCULE LATINE G ENTRE PARENTHÈSES","	# 0028 0047 0029"},
/* 1F117 */ { "LETTRE MAJUSCULE LATINE H ENTRE PARENTHÈSES","	# 0028 0048 0029"},
/* 1F118 */ { "LETTRE MAJUSCULE LATINE I ENTRE PARENTHÈSES","	# 0028 0049 0029"},
/* 1F119 */ { "LETTRE MAJUSCULE LATINE J ENTRE PARENTHÈSES","	# 0028 004A 0029"},
/* 1F11A */ { "LETTRE MAJUSCULE LATINE K ENTRE PARENTHÈSES","	# 0028 004B 0029"},
/* 1F11B */ { "LETTRE MAJUSCULE LATINE L ENTRE PARENTHÈSES","	# 0028 004C 0029"},
/* 1F11C */ { "LETTRE MAJUSCULE LATINE M ENTRE PARENTHÈSES","	# 0028 004D 0029"},
/* 1F11D */ { "LETTRE MAJUSCULE LATINE N ENTRE PARENTHÈSES","	# 0028 004E 0029"},
/* 1F11E */ { "LETTRE MAJUSCULE LATINE O ENTRE PARENTHÈSES","	# 0028 004F 0029"},
/* 1F11F */ { "LETTRE MAJUSCULE LATINE P ENTRE PARENTHÈSES","	# 0028 0050 0029"},
/* 1F120 */ { "LETTRE MAJUSCULE LATINE Q ENTRE PARENTHÈSES","	# 0028 0051 0029"},
/* 1F121 */ { "LETTRE MAJUSCULE LATINE R ENTRE PARENTHÈSES","	# 0028 0052 0029"},
/* 1F122 */ { "LETTRE MAJUSCULE LATINE S ENTRE PARENTHÈSES","	# 0028 0053 0029"},
/* 1F123 */ { "LETTRE MAJUSCULE LATINE T ENTRE PARENTHÈSES","	# 0028 0054 0029"},
/* 1F124 */ { "LETTRE MAJUSCULE LATINE U ENTRE PARENTHÈSES","	# 0028 0055 0029"},
/* 1F125 */ { "LETTRE MAJUSCULE LATINE V ENTRE PARENTHÈSES","	# 0028 0056 0029"},
/* 1F126 */ { "LETTRE MAJUSCULE LATINE W ENTRE PARENTHÈSES","	# 0028 0057 0029"},
/* 1F127 */ { "LETTRE MAJUSCULE LATINE X ENTRE PARENTHÈSES","	# 0028 0058 0029"},
/* 1F128 */ { "LETTRE MAJUSCULE LATINE Y ENTRE PARENTHÈSES","	# 0028 0059 0029"},
/* 1F129 */ { "LETTRE MAJUSCULE LATINE Z ENTRE PARENTHÈSES","	# 0028 005A 0029"},
/* 1F12A */ { "LETTRE MAJUSCULE LATINE S ENTRE CROCHETS EN ÉCAILLE","	* sert à noter les résultats de baseball\n"
	"	# 3014 0053 3015"},
/* 1F12B */ { "LETTRE MAJUSCULE LATINE ITALIQUE C CERCLÉE","	= disque compact\n"
	"	# <cerclée> 0043"},
/* 1F12C */ { "LETTRE MAJUSCULE LATINE ITALIQUE R CERCLÉE","	= enregistrement\n"
	"	# <cerclée> 0052"},
/* 1F12D */ { "CD CERCLÉ","	x (cd disposé en carré - 33C5)\n"
	"	# <cerclée> 0043 0044"},
/* 1F12E */ { "WZ CERCLÉ","	* du terme allemand « Warenzeichen »\n"
	"	* signale un terme utilisé comme marque de commerce sans en avoir le statut légal\n"
	"	* la décomposition est irrégulière, car le glyphe habituel présente un W majuscule et un z minuscule\n"
	"	x (symbole marque de commerce - 2122)\n"
	"	# <cerclée> 0057 005A"},
/* 1F12F */ { "SYMBOLE COPYLEFT","	x (symbole copyright - 00A9)\n"
	"	x (chiffre romain cent réfléchi - 2183)"},
/* 1F130 */ { "LETTRE MAJUSCULE LATINE A ENCADRÉE","	= Anreisetag (jour d'arrivée)\n"
	"	# <enCarré> 0041"},
/* 1F131 */ { "LETTRE MAJUSCULE LATINE B ENCADRÉE","	= banque\n"
	"	= ARIB STD-B24 : service de télédiffusion en compression stéréo mode b\n"
	"	# <enCarré> 0042"},
/* 1F132 */ { "LETTRE MAJUSCULE LATINE C ENCADRÉE","	# <enCarré> 0043"},
/* 1F133 */ { "LETTRE MAJUSCULE LATINE D ENCADRÉE","	# <enCarré> 0044"},
/* 1F134 */ { "LETTRE MAJUSCULE LATINE E ENCADRÉE","	# <enCarré> 0045"},
/* 1F135 */ { "LETTRE MAJUSCULE LATINE F ENCADRÉE","	# <enCarré> 0046"},
/* 1F136 */ { "LETTRE MAJUSCULE LATINE G ENCADRÉE","	# <enCarré> 0047"},
/* 1F137 */ { "LETTRE MAJUSCULE LATINE H ENCADRÉE","	# <enCarré> 0048"},
/* 1F138 */ { "LETTRE MAJUSCULE LATINE I ENCADRÉE","	# <enCarré> 0049"},
/* 1F139 */ { "LETTRE MAJUSCULE LATINE J ENCADRÉE","	# <enCarré> 004A"},
/* 1F13A */ { "LETTRE MAJUSCULE LATINE K ENCADRÉE","	# <enCarré> 004B"},
/* 1F13B */ { "LETTRE MAJUSCULE LATINE L ENCADRÉE","	# <enCarré> 004C"},
/* 1F13C */ { "LETTRE MAJUSCULE LATINE M ENCADRÉE","	# <enCarré> 004D"},
/* 1F13D */ { "LETTRE MAJUSCULE LATINE N ENCADRÉE","	= ARIB STD-B24 : news (informations)\n"
	"	# <enCarré> 004E"},
/* 1F13E */ { "LETTRE MAJUSCULE LATINE O ENCADRÉE","	# <enCarré> 004F"},
/* 1F13F */ { "LETTRE MAJUSCULE LATINE P ENCADRÉE","	= ARIB STD-B24 : télédiffusion progressive\n"
	"	# <enCarré> 0050"},
/* 1F140 */ { "LETTRE MAJUSCULE LATINE Q ENCADRÉE","	# <enCarré> 0051"},
/* 1F141 */ { "LETTRE MAJUSCULE LATINE R ENCADRÉE","	# <enCarré> 0052"},
/* 1F142 */ { "LETTRE MAJUSCULE LATINE S ENCADRÉE","	= ARIB STD-B24 : service de télédiffusion en stéréo\n"
	"	# <enCarré> 0053"},
/* 1F143 */ { "LETTRE MAJUSCULE LATINE T ENCADRÉE","	= bureau de tabac\n"
	"	# <enCarré> 0054"},
/* 1F144 */ { "LETTRE MAJUSCULE LATINE U ENCADRÉE","	# <enCarré> 0055"},
/* 1F145 */ { "LETTRE MAJUSCULE LATINE V ENCADRÉE","	# <enCarré> 0056"},
/* 1F146 */ { "LETTRE MAJUSCULE LATINE W ENCADRÉE","	= ARIB STD-B24 : service de télédiffusion au format large 16:9 (wide format)\n"
	"	# <enCarré> 0057"},
/* 1F147 */ { "LETTRE MAJUSCULE LATINE X ENCADRÉE","	# <enCarré> 0058"},
/* 1F148 */ { "LETTRE MAJUSCULE LATINE Y ENCADRÉE","	# <enCarré> 0059"},
/* 1F149 */ { "LETTRE MAJUSCULE LATINE Z ENCADRÉE","	# <enCarré> 005A"},
/* 1F14A */ { "HV ENCADRÉ","	= HDTV\n"
	"	# <enCarré> 0048 0056"},
/* 1F14B */ { "MV ENCADRÉ","	= multi-view (télévision à vues multiples)\n"
	"	# <enCarré> 004D 0056"},
/* 1F14C */ { "SD ENCADRÉ","	= SDTV\n"
	"	# <enCarré> 0053 0044"},
/* 1F14D */ { "SS ENCADRÉ","	= surround stereo\n"
	"	# <enCarré> 0053 0053"},
/* 1F14E */ { "PPV ENCADRÉ","	= pay-per-view (service à péage)\n"
	"	# <enCarré> 0050 0050 0056"},
/* 1F14F */ { "WC ENCADRÉ","	= water closet (toilettes publiques)\n"
	"	x (w-c - 1F6BE)\n"
	"	# <enCarré> 0057 0043"},
/* 1F150 */ { "LETTRE MAJUSCULE LATINE A CERCLÉE NOIR AU BLANC","	= aéroport"},
/* 1F151 */ { "LETTRE MAJUSCULE LATINE B CERCLÉE NOIR AU BLANC",NULL},
/* 1F152 */ { "LETTRE MAJUSCULE LATINE C CERCLÉE NOIR AU BLANC",NULL},
/* 1F153 */ { "LETTRE MAJUSCULE LATINE D CERCLÉE NOIR AU BLANC",NULL},
/* 1F154 */ { "LETTRE MAJUSCULE LATINE E CERCLÉE NOIR AU BLANC",NULL},
/* 1F155 */ { "LETTRE MAJUSCULE LATINE F CERCLÉE NOIR AU BLANC","	= ferry"},
/* 1F156 */ { "LETTRE MAJUSCULE LATINE G CERCLÉE NOIR AU BLANC",NULL},
/* 1F157 */ { "LETTRE MAJUSCULE LATINE H CERCLÉE NOIR AU BLANC","	= ARIB STD-B24 : hôtel"},
/* 1F158 */ { "LETTRE MAJUSCULE LATINE I CERCLÉE NOIR AU BLANC",NULL},
/* 1F159 */ { "LETTRE MAJUSCULE LATINE J CERCLÉE NOIR AU BLANC",NULL},
/* 1F15A */ { "LETTRE MAJUSCULE LATINE K CERCLÉE NOIR AU BLANC","	= Kurort (spa)\n"
	"	x (sources chaudes - 2668)"},
/* 1F15B */ { "LETTRE MAJUSCULE LATINE L CERCLÉE NOIR AU BLANC","	= light rail (transport en commun léger sur rail)\n"
	"	x (train léger - 1F688)"},
/* 1F15C */ { "LETTRE MAJUSCULE LATINE M CERCLÉE NOIR AU BLANC","	= métro\n"
	"	x (métro - 1F687)"},
/* 1F15D */ { "LETTRE MAJUSCULE LATINE N CERCLÉE NOIR AU BLANC",NULL},
/* 1F15E */ { "LETTRE MAJUSCULE LATINE O CERCLÉE NOIR AU BLANC",NULL},
/* 1F15F */ { "LETTRE MAJUSCULE LATINE P CERCLÉE NOIR AU BLANC","	= ARIB STD-B24 : parking space (aire de stationnement)"},
/* 1F160 */ { "LETTRE MAJUSCULE LATINE Q CERCLÉE NOIR AU BLANC",NULL},
/* 1F161 */ { "LETTRE MAJUSCULE LATINE R CERCLÉE NOIR AU BLANC","	= Raststätte (aire de repos)"},
/* 1F162 */ { "LETTRE MAJUSCULE LATINE S CERCLÉE NOIR AU BLANC","	= Stadtbahn (chemin de fer métropolitain)"},
/* 1F163 */ { "LETTRE MAJUSCULE LATINE T CERCLÉE NOIR AU BLANC","	= Tankstelle (station-service)\n"
	"	x (pompe à essence - 26FD)"},
/* 1F164 */ { "LETTRE MAJUSCULE LATINE U CERCLÉE NOIR AU BLANC","	= underground rail (métro)\n"
	"	x (métro - 1F687)"},
/* 1F165 */ { "LETTRE MAJUSCULE LATINE V CERCLÉE NOIR AU BLANC",NULL},
/* 1F166 */ { "LETTRE MAJUSCULE LATINE W CERCLÉE NOIR AU BLANC",NULL},
/* 1F167 */ { "LETTRE MAJUSCULE LATINE X CERCLÉE NOIR AU BLANC",NULL},
/* 1F168 */ { "LETTRE MAJUSCULE LATINE Y CERCLÉE NOIR AU BLANC",NULL},
/* 1F169 */ { "LETTRE MAJUSCULE LATINE Z CERCLÉE NOIR AU BLANC",NULL},
/* 1F16A */ { "SYMBOLE MC ÉLEVÉ","	= marque de commerce\n"
	"	* utilisé au Canada\n"
	"	x (symbole marque de commerce - 2122)\n"
	"	# <exp> 004D 0043"},
/* 1F16B */ { "SYMBOLE MD ÉLEVÉ","	= marque déposée\n"
	"	* utilisé au Canada\n"
	"	x (symbole marque déposée - 00AE)\n"
	"	# <exp> 004D 0044"},
/* 1F16C */ { "SYMBOLE MR ÉLEVÉ","	= marca registrada\n"
	"	* utilisé principalement dans les communautés hispanophones et lusophones pour indiquer une marque déposée\n"
	"	x (symbole marque déposée - 00AE)\n"
	"	# <exp> 004D 0052"},
/* 1F16D */ { "CC CERCLÉ","	= licence Creative Commons\n"
	"	x (égal cerclé - 229C)"},
/* 1F16E */ { "C CERCLÉ SUPERPOSÉ D'UNE BARRE OBLIQUE INVERSÉE","	= domaine public"},
/* 1F16F */ { "SILHOUETTE HUMAINE CERCLÉE","	= attribution, paternité"},
/* 1F170 */ { "LETTRE MAJUSCULE LATINE A ENCADRÉE NOIR AU BLANC","	= groupe sanguin A"},
/* 1F171 */ { "LETTRE MAJUSCULE LATINE B ENCADRÉE NOIR AU BLANC","	= groupe sanguin B"},
/* 1F172 */ { "LETTRE MAJUSCULE LATINE C ENCADRÉE NOIR AU BLANC","	= centre, centre-ville"},
/* 1F173 */ { "LETTRE MAJUSCULE LATINE D ENCADRÉE NOIR AU BLANC",NULL},
/* 1F174 */ { "LETTRE MAJUSCULE LATINE E ENCADRÉE NOIR AU BLANC",NULL},
/* 1F175 */ { "LETTRE MAJUSCULE LATINE F ENCADRÉE NOIR AU BLANC","	= Feuerwache (sapeurs-pompiers)"},
/* 1F176 */ { "LETTRE MAJUSCULE LATINE G ENCADRÉE NOIR AU BLANC",NULL},
/* 1F177 */ { "LETTRE MAJUSCULE LATINE H ENCADRÉE NOIR AU BLANC","	= Haltestelle (arrêt de bus)\n"
	"	x (arrêt d'autobus - 1F68F)"},
/* 1F178 */ { "LETTRE MAJUSCULE LATINE I ENCADRÉE NOIR AU BLANC",NULL},
/* 1F179 */ { "LETTRE MAJUSCULE LATINE J ENCADRÉE NOIR AU BLANC","	= ARIB STD-B24 : jonction"},
/* 1F17A */ { "LETTRE MAJUSCULE LATINE K ENCADRÉE NOIR AU BLANC",NULL},
/* 1F17B */ { "LETTRE MAJUSCULE LATINE L ENCADRÉE NOIR AU BLANC","	= ARIB STD-B24 : leisure center (centre de loisirs)"},
/* 1F17C */ { "LETTRE MAJUSCULE LATINE M ENCADRÉE NOIR AU BLANC","	= ARIB STD-B24 : musée, centre culturel"},
/* 1F17D */ { "LETTRE MAJUSCULE LATINE N ENCADRÉE NOIR AU BLANC",NULL},
/* 1F17E */ { "LETTRE MAJUSCULE LATINE O ENCADRÉE NOIR AU BLANC","	= groupe sanguin O"},
/* 1F17F */ { "LETTRE MAJUSCULE LATINE P ENCADRÉE NOIR AU BLANC","	= ARIB STD-B24 : parking space empty-full (aire de stationnement)"},
/* 1F180 */ { "LETTRE MAJUSCULE LATINE Q ENCADRÉE NOIR AU BLANC",NULL},
/* 1F181 */ { "LETTRE MAJUSCULE LATINE R ENCADRÉE NOIR AU BLANC",NULL},
/* 1F182 */ { "LETTRE MAJUSCULE LATINE S ENCADRÉE NOIR AU BLANC",NULL},
/* 1F183 */ { "LETTRE MAJUSCULE LATINE T ENCADRÉE NOIR AU BLANC",NULL},
/* 1F184 */ { "LETTRE MAJUSCULE LATINE U ENCADRÉE NOIR AU BLANC",NULL},
/* 1F185 */ { "LETTRE MAJUSCULE LATINE V ENCADRÉE NOIR AU BLANC",NULL},
/* 1F186 */ { "LETTRE MAJUSCULE LATINE W ENCADRÉE NOIR AU BLANC",NULL},
/* 1F187 */ { "LETTRE MAJUSCULE LATINE X ENCADRÉE NOIR AU BLANC",NULL},
/* 1F188 */ { "LETTRE MAJUSCULE LATINE Y ENCADRÉE NOIR AU BLANC",NULL},
/* 1F189 */ { "LETTRE MAJUSCULE LATINE Z ENCADRÉE NOIR AU BLANC",NULL},
/* 1F18A */ { "LETTRE MAJUSCULE LATINE P AVEC CROIX ENCADRÉE NOIR AU BLANC","	= parking space closed (aire de stationnement fermée)"},
/* 1F18B */ { "IC ENCADRÉ NOIR AU BLANC","	= échangeur d'autoroute, bretelle"},
/* 1F18C */ { "PA ENCADRÉ NOIR AU BLANC","	= parking area (aire de stationnement)"},
/* 1F18D */ { "SA ENCADRÉ NOIR AU BLANC","	= service area (aire de services)"},
/* 1F18E */ { "AB ENCADRÉ NOIR AU BLANC","	= groupe sanguin AB"},
/* 1F18F */ { "WC ENCADRÉ NOIR AU BLANC","	= water closet (toilettes publiques)\n"
	"	x (w-c - 1F6BE)"},
/* 1F190 */ { "DJ DISPOSÉ EN CARRÉ","	= disk jockey (animateur de discothèque)\n"
	"	# <enCarré> 0044 004A"},
/* 1F191 */ { "CL ENCADRÉ","	= clear (effacer)"},
/* 1F192 */ { "COOL ENCADRÉ",NULL},
/* 1F193 */ { "FREE ENCADRÉ","	= dispensé d'affranchissement"},
/* 1F194 */ { "ID ENCADRÉ","	= identification"},
/* 1F195 */ { "NEW ENCADRÉ",NULL},
/* 1F196 */ { "NG ENCADRÉ","	= no good (pas bon)"},
/* 1F197 */ { "OK ENCADRÉ",NULL},
/* 1F198 */ { "SOS ENCADRÉ","	= recherche de personne disparue"},
/* 1F199 */ { "UP ET POINT D'EXCLAMATION ENCADRÉS",NULL},
/* 1F19A */ { "VS ENCADRÉ","	= versus"},
/* 1F19B */ { "TROIS D ENCADRÉ",NULL},
/* 1F19C */ { "SECOND ÉCRAN ENCADRÉ",NULL},
/* 1F19D */ { "DEUX K ENCADRÉ",NULL},
/* 1F19E */ { "QUATRE K ENCADRÉ",NULL},
/* 1F19F */ { "HUIT K ENCADRÉ",NULL},
/* 1F1A0 */ { "CINQ POINT UN ENCADRÉ","	* désigne le son ambiophonique 5.1"},
/* 1F1A1 */ { "SEPT POINT UN ENCADRÉ","	* désigne le son ambiophonique 7.1"},
/* 1F1A2 */ { "VINGT-DEUX POINT DEUX ENCADRÉ","	* désigne le son ambiophonique 22.2"},
/* 1F1A3 */ { "SOIXANTE P ENCADRÉ","	* désigne une fréquence d'images de 60 Hz avec balayage progressif"},
/* 1F1A4 */ { "CENT VINGT P ENCADRÉ","	* désigne une fréquence d'images de 120 Hz avec balayage progressif"},
/* 1F1A5 */ { "LETTRE MINUSCULE LATINE D ENCADRÉE","	= data (données)"},
/* 1F1A6 */ { "HC ENCADRÉ","	= hybrid cast"},
/* 1F1A7 */ { "HDR ENCADRÉ","	= high dynamic range (imagerie à grande gamme dynamique)"},
/* 1F1A8 */ { "HI RES ENCADRÉ","	= high resolution (haute résolution)"},
/* 1F1A9 */ { "LOSSLESS ENCADRÉ",NULL},
/* 1F1AA */ { "SHV ENCADRÉ","	= super high vision"},
/* 1F1AB */ { "UHD ENCADRÉ","	= ultra-high definition (ultra haute définition)"},
/* 1F1AC */ { "VOD ENCADRÉ","	= video on demand (vidéo à la demande)"},
/* 1F1AD */ { "SYMBOLE DE TOPOGRAPHIE DE CIRCUIT INTÉGRÉ","	* signale la protection de la propriété intellectuelle pour les configurations des circuits électroniques (topographies) incorporés dans des produits de circuits intégrés ou des schémas de montage ; en anglais, ces configurations sont appelées « mask work » du fait que les multiples couches gravées dans les circuits intégrés sont créées en utilisant un masque photographique\n"
	"	x (symbole copyright - 00A9)\n"
	"	x (lettre majuscule latine m cerclée - 24C2)"},
/* 1F1AE */ { NULL,NULL},
/* 1F1AF */ { NULL,NULL},
/* 1F1B0 */ { NULL,NULL},
/* 1F1B1 */ { NULL,NULL},
/* 1F1B2 */ { NULL,NULL},
/* 1F1B3 */ { NULL,NULL},
/* 1F1B4 */ { NULL,NULL},
/* 1F1B5 */ { NULL,NULL},
/* 1F1B6 */ { NULL,NULL},
/* 1F1B7 */ { NULL,NULL},
/* 1F1B8 */ { NULL,NULL},
/* 1F1B9 */ { NULL,NULL},
/* 1F1BA */ { NULL,NULL},
/* 1F1BB */ { NULL,NULL},
/* 1F1BC */ { NULL,NULL},
/* 1F1BD */ { NULL,NULL},
/* 1F1BE */ { NULL,NULL},
/* 1F1BF */ { NULL,NULL},
/* 1F1C0 */ { NULL,NULL},
/* 1F1C1 */ { NULL,NULL},
/* 1F1C2 */ { NULL,NULL},
/* 1F1C3 */ { NULL,NULL},
/* 1F1C4 */ { NULL,NULL},
/* 1F1C5 */ { NULL,NULL},
/* 1F1C6 */ { NULL,NULL},
/* 1F1C7 */ { NULL,NULL},
/* 1F1C8 */ { NULL,NULL},
/* 1F1C9 */ { NULL,NULL},
/* 1F1CA */ { NULL,NULL},
/* 1F1CB */ { NULL,NULL},
/* 1F1CC */ { NULL,NULL},
/* 1F1CD */ { NULL,NULL},
/* 1F1CE */ { NULL,NULL},
/* 1F1CF */ { NULL,NULL},
/* 1F1D0 */ { NULL,NULL},
/* 1F1D1 */ { NULL,NULL},
/* 1F1D2 */ { NULL,NULL},
/* 1F1D3 */ { NULL,NULL},
/* 1F1D4 */ { NULL,NULL},
/* 1F1D5 */ { NULL,NULL},
/* 1F1D6 */ { NULL,NULL},
/* 1F1D7 */ { NULL,NULL},
/* 1F1D8 */ { NULL,NULL},
/* 1F1D9 */ { NULL,NULL},
/* 1F1DA */ { NULL,NULL},
/* 1F1DB */ { NULL,NULL},
/* 1F1DC */ { NULL,NULL},
/* 1F1DD */ { NULL,NULL},
/* 1F1DE */ { NULL,NULL},
/* 1F1DF */ { NULL,NULL},
/* 1F1E0 */ { NULL,NULL},
/* 1F1E1 */ { NULL,NULL},
/* 1F1E2 */ { NULL,NULL},
/* 1F1E3 */ { NULL,NULL},
/* 1F1E4 */ { NULL,NULL},
/* 1F1E5 */ { NULL,NULL},
/* 1F1E6 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE A",NULL},
/* 1F1E7 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE B",NULL},
/* 1F1E8 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE C",NULL},
/* 1F1E9 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE D",NULL},
/* 1F1EA */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE E",NULL},
/* 1F1EB */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE F",NULL},
/* 1F1EC */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE G",NULL},
/* 1F1ED */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE H",NULL},
/* 1F1EE */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE I",NULL},
/* 1F1EF */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE J",NULL},
/* 1F1F0 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE K",NULL},
/* 1F1F1 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE L",NULL},
/* 1F1F2 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE M",NULL},
/* 1F1F3 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE N",NULL},
/* 1F1F4 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE O",NULL},
/* 1F1F5 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE P",NULL},
/* 1F1F6 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE Q",NULL},
/* 1F1F7 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE R",NULL},
/* 1F1F8 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE S",NULL},
/* 1F1F9 */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE T",NULL},
/* 1F1FA */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE U",NULL},
/* 1F1FB */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE V",NULL},
/* 1F1FC */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE W",NULL},
/* 1F1FD */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE X",NULL},
/* 1F1FE */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE Y",NULL},
/* 1F1FF */ { "SYMBOLE INDICATEUR RÉGIONAL LETTRE Z",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F2[] = {
/* 1F200 */ { "HIRAGANA HOKA DISPOSÉ EN CARRÉ","	= et autres\n"
	"	# <enCarré> 307B 304B"},
/* 1F201 */ { "KATAKANA KOKO ENCADRÉ","	= symbole ici\n"
	"	# <enCarré> 30B3 30B3"},
/* 1F202 */ { "KATAKANA SA ENCADRÉ","	= symbole de service\n"
	"	x (katakana cerclé sa - 32DA)\n"
	"	# <enCarré> 30B5"},
/* 1F203 */ { NULL,NULL},
/* 1F204 */ { NULL,NULL},
/* 1F205 */ { NULL,NULL},
/* 1F206 */ { NULL,NULL},
/* 1F207 */ { NULL,NULL},
/* 1F208 */ { NULL,NULL},
/* 1F209 */ { NULL,NULL},
/* 1F20A */ { NULL,NULL},
/* 1F20B */ { NULL,NULL},
/* 1F20C */ { NULL,NULL},
/* 1F20D */ { NULL,NULL},
/* 1F20E */ { NULL,NULL},
/* 1F20F */ { NULL,NULL},
/* 1F210 */ { "IDÉOGRAMME UNIFIÉ CJC-624B ENCADRÉ","	= service de télédiffusion avec interprétation en langue des signes\n"
	"	# <enCarré> 624B"},
/* 1F211 */ { "IDÉOGRAMME UNIFIÉ CJC-5B57 ENCADRÉ","	= télédiffusion à sous-titres pour sourds et malentendants\n"
	"	# <enCarré> 5B57"},
/* 1F212 */ { "IDÉOGRAMME UNIFIÉ CJC-53CC ENCADRÉ","	= télévision interactive, service de télédiffusion à deux sens\n"
	"	# <enCarré> 53CC"},
/* 1F213 */ { "KATAKANA DE ENCADRÉ","	= service de télédiffusion de données lié à un programme principal\n"
	"	# <enCarré> 30C7"},
/* 1F214 */ { "IDÉOGRAMME UNIFIÉ CJC-4E8C ENCADRÉ","	= service de télédiffusion bilingue\n"
	"	= second but\n"
	"	# <enCarré> 4E8C"},
/* 1F215 */ { "IDÉOGRAMME UNIFIÉ CJC-591A ENCADRÉ","	= service de télédiffusion sonore-multiplex\n"
	"	# <enCarré> 591A"},
/* 1F216 */ { "IDÉOGRAMME UNIFIÉ CJC-89E3 ENCADRÉ","	= télédiffusion de commentaires\n"
	"	# <enCarré> 89E3"},
/* 1F217 */ { "IDÉOGRAMME UNIFIÉ CJC-5929 ENCADRÉ","	= prévisions météorologiques\n"
	"	# <enCarré> 5929"},
/* 1F218 */ { "IDÉOGRAMME UNIFIÉ CJC-4EA4 ENCADRÉ","	= informations routières\n"
	"	# <enCarré> 4EA4"},
/* 1F219 */ { "IDÉOGRAMME UNIFIÉ CJC-6620 ENCADRÉ","	= film dramatique\n"
	"	# <enCarré> 6620"},
/* 1F21A */ { "IDÉOGRAMME UNIFIÉ CJC-7121 ENCADRÉ","	= service de télédiffusion gratuite\n"
	"	= non-existence\n"
	"	# <enCarré> 7121"},
/* 1F21B */ { "IDÉOGRAMME UNIFIÉ CJC-6599 ENCADRÉ","	= service de télédiffusion payante\n"
	"	# <enCarré> 6599"},
/* 1F21C */ { "IDÉOGRAMME UNIFIÉ CJC-524D ENCADRÉ","	= la première partie\n"
	"	# <enCarré> 524D"},
/* 1F21D */ { "IDÉOGRAMME UNIFIÉ CJC-5F8C ENCADRÉ","	= la dernière partie\n"
	"	# <enCarré> 5F8C"},
/* 1F21E */ { "IDÉOGRAMME UNIFIÉ CJC-518D ENCADRÉ","	= retransmettre\n"
	"	# <enCarré> 518D"},
/* 1F21F */ { "IDÉOGRAMME UNIFIÉ CJC-65B0 ENCADRÉ","	= nouvelles séries de programmes\n"
	"	# <enCarré> 65B0"},
/* 1F220 */ { "IDÉOGRAMME UNIFIÉ CJC-521D ENCADRÉ","	= premier programme diffusé\n"
	"	# <enCarré> 521D"},
/* 1F221 */ { "IDÉOGRAMME UNIFIÉ CJC-7D42 ENCADRÉ","	= le dernier épisode\n"
	"	# <enCarré> 7D42"},
/* 1F222 */ { "IDÉOGRAMME UNIFIÉ CJC-751F ENCADRÉ","	= télédiffusion en direct\n"
	"	# <enCarré> 751F"},
/* 1F223 */ { "IDÉOGRAMME UNIFIÉ CJC-8CA9 ENCADRÉ","	= commande par correspondance\n"
	"	# <enCarré> 8CA9"},
/* 1F224 */ { "IDÉOGRAMME UNIFIÉ CJC-58F0 ENCADRÉ","	= acteurs de voix\n"
	"	# <enCarré> 58F0"},
/* 1F225 */ { "IDÉOGRAMME UNIFIÉ CJC-5439 ENCADRÉ","	= version doublée\n"
	"	# <enCarré> 5439"},
/* 1F226 */ { "IDÉOGRAMME UNIFIÉ CJC-6F14 ENCADRÉ","	= interprété par\n"
	"	# <enCarré> 6F14"},
/* 1F227 */ { "IDÉOGRAMME UNIFIÉ CJC-6295 ENCADRÉ","	= lanceur\n"
	"	# <enCarré> 6295"},
/* 1F228 */ { "IDÉOGRAMME UNIFIÉ CJC-6355 ENCADRÉ","	= receveur\n"
	"	# <enCarré> 6355"},
/* 1F229 */ { "IDÉOGRAMME UNIFIÉ CJC-4E00 ENCADRÉ","	= première base\n"
	"	# <enCarré> 4E00"},
/* 1F22A */ { "IDÉOGRAMME UNIFIÉ CJC-4E09 ENCADRÉ","	= troisième base\n"
	"	# <enCarré> 4E09"},
/* 1F22B */ { "IDÉOGRAMME UNIFIÉ CJC-904A ENCADRÉ","	= arrêt court\n"
	"	# <enCarré> 904A"},
/* 1F22C */ { "IDÉOGRAMME UNIFIÉ CJC-5DE6 ENCADRÉ","	= champ gauche\n"
	"	# <enCarré> 5DE6"},
/* 1F22D */ { "IDÉOGRAMME UNIFIÉ CJC-4E2D ENCADRÉ","	= champ central\n"
	"	# <enCarré> 4E2D"},
/* 1F22E */ { "IDÉOGRAMME UNIFIÉ CJC-53F3 ENCADRÉ","	= champ droit\n"
	"	# <enCarré> 53F3"},
/* 1F22F */ { "IDÉOGRAMME UNIFIÉ CJC-6307 ENCADRÉ","	= frappeur désigné\n"
	"	= symbole « réservé »\n"
	"	# <enCarré> 6307"},
/* 1F230 */ { "IDÉOGRAMME UNIFIÉ CJC-8D70 ENCADRÉ","	= coureur\n"
	"	# <enCarré> 8D70"},
/* 1F231 */ { "IDÉOGRAMME UNIFIÉ CJC-6253 ENCADRÉ","	= batteur\n"
	"	# <enCarré> 6253"},
/* 1F232 */ { "IDÉOGRAMME UNIFIÉ CJC-7981 ENCADRÉ","	= symbole « interdit »\n"
	"	# <enCarré> 7981"},
/* 1F233 */ { "IDÉOGRAMME UNIFIÉ CJC-7A7A ENCADRÉ","	= symbole « vide »\n"
	"	# <enCarré> 7A7A"},
/* 1F234 */ { "IDÉOGRAMME UNIFIÉ CJC-5408 ENCADRÉ","	= symbole « signé »\n"
	"	# <enCarré> 5408"},
/* 1F235 */ { "IDÉOGRAMME UNIFIÉ CJC-6E80 ENCADRÉ","	= symbole « plein »\n"
	"	# <enCarré> 6E80"},
/* 1F236 */ { "IDÉOGRAMME UNIFIÉ CJC-6709 ENCADRÉ","	= symbole « existence »\n"
	"	x (idéogramme avoir cerclé - 3292)\n"
	"	# <enCarré> 6709"},
/* 1F237 */ { "IDÉOGRAMME UNIFIÉ CJC-6708 ENCADRÉ","	= symbole « mensuel »\n"
	"	x (idéogramme lune cerclé - 328A)\n"
	"	# <enCarré> 6708"},
/* 1F238 */ { "IDÉOGRAMME UNIFIÉ CJC-7533 ENCADRÉ","	= symbole « application »\n"
	"	# <enCarré> 7533"},
/* 1F239 */ { "IDÉOGRAMME UNIFIÉ CJC-5272 ENCADRÉ","	= symbole « rabais »\n"
	"	# <enCarré> 5272"},
/* 1F23A */ { "IDÉOGRAMME UNIFIÉ CJC-55B6 ENCADRÉ","	= symbole « en affaires »\n"
	"	# <enCarré> 55B6"},
/* 1F23B */ { "IDÉOGRAMME UNIFIÉ CJC-914D ENCADRÉ","	= ARIB STD-B62 : diffusion de programmes par câble\n"
	"	# <enCarré> 914D"},
/* 1F23C */ { NULL,NULL},
/* 1F23D */ { NULL,NULL},
/* 1F23E */ { NULL,NULL},
/* 1F23F */ { NULL,NULL},
/* 1F240 */ { "IDÉOGRAMME UNIFIÉ CJC-672C ENTRE CROCHETS EN ÉCAILLE","	= coup de circuit (baseball)\n"
	"	# 3014 672C 3015"},
/* 1F241 */ { "IDÉOGRAMME UNIFIÉ CJC-4E09 ENTRE CROCHETS EN ÉCAILLE","	= triple\n"
	"	# 3014 4E09 3015"},
/* 1F242 */ { "IDÉOGRAMME UNIFIÉ CJC-4E8C ENTRE CROCHETS EN ÉCAILLE","	= double\n"
	"	# 3014 4E8C 3015"},
/* 1F243 */ { "IDÉOGRAMME UNIFIÉ CJC-5B89 ENTRE CROCHETS EN ÉCAILLE","	= sauf\n"
	"	# 3014 5B89 3015"},
/* 1F244 */ { "IDÉOGRAMME UNIFIÉ CJC-70B9 ENTRE CROCHETS EN ÉCAILLE","	= point\n"
	"	# 3014 70B9 3015"},
/* 1F245 */ { "IDÉOGRAMME UNIFIÉ CJC-6253 ENTRE CROCHETS EN ÉCAILLE","	= coup sûr\n"
	"	# 3014 6253 3015"},
/* 1F246 */ { "IDÉOGRAMME UNIFIÉ CJC-76D7 ENTRE CROCHETS EN ÉCAILLE","	= vol\n"
	"	# 3014 76D7 3015"},
/* 1F247 */ { "IDÉOGRAMME UNIFIÉ CJC-52DD ENTRE CROCHETS EN ÉCAILLE","	= victoire\n"
	"	# 3014 52DD 3015"},
/* 1F248 */ { "IDÉOGRAMME UNIFIÉ CJC-6557 ENTRE CROCHETS EN ÉCAILLE","	= défaite\n"
	"	# 3014 6557 3015"},
/* 1F249 */ { NULL,NULL},
/* 1F24A */ { NULL,NULL},
/* 1F24B */ { NULL,NULL},
/* 1F24C */ { NULL,NULL},
/* 1F24D */ { NULL,NULL},
/* 1F24E */ { NULL,NULL},
/* 1F24F */ { NULL,NULL},
/* 1F250 */ { "IDÉOGRAMME CERCLÉ AVANTAGER","	= symbole « avantage »\n"
	"	# <cerclée> 5F97"},
/* 1F251 */ { "IDÉOGRAMME CERCLÉ ACCEPTER","	= symbole « acceptation »\n"
	"	# <cerclée> 53EF"},
/* 1F252 */ { NULL,NULL},
/* 1F253 */ { NULL,NULL},
/* 1F254 */ { NULL,NULL},
/* 1F255 */ { NULL,NULL},
/* 1F256 */ { NULL,NULL},
/* 1F257 */ { NULL,NULL},
/* 1F258 */ { NULL,NULL},
/* 1F259 */ { NULL,NULL},
/* 1F25A */ { NULL,NULL},
/* 1F25B */ { NULL,NULL},
/* 1F25C */ { NULL,NULL},
/* 1F25D */ { NULL,NULL},
/* 1F25E */ { NULL,NULL},
/* 1F25F */ { NULL,NULL},
/* 1F260 */ { "SYMBOLE ARRONDI POUR FU","	* la bonne fortune\n"
	"	x 798F"},
/* 1F261 */ { "SYMBOLE ARRONDI POUR LU","	* la prospérité\n"
	"	x 797F\n"
	"	x 7984"},
/* 1F262 */ { "SYMBOLE ARRONDI POUR SHOU","	* la longévité\n"
	"	x 58FD\n"
	"	x 5BFF"},
/* 1F263 */ { "SYMBOLE ARRONDI POUR XI","	* le bonheur\n"
	"	x 559C"},
/* 1F264 */ { "SYMBOLE ARRONDI POUR SHUANGXI","	* le double bonheur, l'amour et le mariage\n"
	"	x 56CD"},
/* 1F265 */ { "SYMBOLE ARRONDI POUR CAI","	* la santé\n"
	"	x 8CA1\n"
	"	x 8D22"},
/* 1F266 */ { NULL,NULL},
/* 1F267 */ { NULL,NULL},
/* 1F268 */ { NULL,NULL},
/* 1F269 */ { NULL,NULL},
/* 1F26A */ { NULL,NULL},
/* 1F26B */ { NULL,NULL},
/* 1F26C */ { NULL,NULL},
/* 1F26D */ { NULL,NULL},
/* 1F26E */ { NULL,NULL},
/* 1F26F */ { NULL,NULL},
/* 1F270 */ { NULL,NULL},
/* 1F271 */ { NULL,NULL},
/* 1F272 */ { NULL,NULL},
/* 1F273 */ { NULL,NULL},
/* 1F274 */ { NULL,NULL},
/* 1F275 */ { NULL,NULL},
/* 1F276 */ { NULL,NULL},
/* 1F277 */ { NULL,NULL},
/* 1F278 */ { NULL,NULL},
/* 1F279 */ { NULL,NULL},
/* 1F27A */ { NULL,NULL},
/* 1F27B */ { NULL,NULL},
/* 1F27C */ { NULL,NULL},
/* 1F27D */ { NULL,NULL},
/* 1F27E */ { NULL,NULL},
/* 1F27F */ { NULL,NULL},
/* 1F280 */ { NULL,NULL},
/* 1F281 */ { NULL,NULL},
/* 1F282 */ { NULL,NULL},
/* 1F283 */ { NULL,NULL},
/* 1F284 */ { NULL,NULL},
/* 1F285 */ { NULL,NULL},
/* 1F286 */ { NULL,NULL},
/* 1F287 */ { NULL,NULL},
/* 1F288 */ { NULL,NULL},
/* 1F289 */ { NULL,NULL},
/* 1F28A */ { NULL,NULL},
/* 1F28B */ { NULL,NULL},
/* 1F28C */ { NULL,NULL},
/* 1F28D */ { NULL,NULL},
/* 1F28E */ { NULL,NULL},
/* 1F28F */ { NULL,NULL},
/* 1F290 */ { NULL,NULL},
/* 1F291 */ { NULL,NULL},
/* 1F292 */ { NULL,NULL},
/* 1F293 */ { NULL,NULL},
/* 1F294 */ { NULL,NULL},
/* 1F295 */ { NULL,NULL},
/* 1F296 */ { NULL,NULL},
/* 1F297 */ { NULL,NULL},
/* 1F298 */ { NULL,NULL},
/* 1F299 */ { NULL,NULL},
/* 1F29A */ { NULL,NULL},
/* 1F29B */ { NULL,NULL},
/* 1F29C */ { NULL,NULL},
/* 1F29D */ { NULL,NULL},
/* 1F29E */ { NULL,NULL},
/* 1F29F */ { NULL,NULL},
/* 1F2A0 */ { NULL,NULL},
/* 1F2A1 */ { NULL,NULL},
/* 1F2A2 */ { NULL,NULL},
/* 1F2A3 */ { NULL,NULL},
/* 1F2A4 */ { NULL,NULL},
/* 1F2A5 */ { NULL,NULL},
/* 1F2A6 */ { NULL,NULL},
/* 1F2A7 */ { NULL,NULL},
/* 1F2A8 */ { NULL,NULL},
/* 1F2A9 */ { NULL,NULL},
/* 1F2AA */ { NULL,NULL},
/* 1F2AB */ { NULL,NULL},
/* 1F2AC */ { NULL,NULL},
/* 1F2AD */ { NULL,NULL},
/* 1F2AE */ { NULL,NULL},
/* 1F2AF */ { NULL,NULL},
/* 1F2B0 */ { NULL,NULL},
/* 1F2B1 */ { NULL,NULL},
/* 1F2B2 */ { NULL,NULL},
/* 1F2B3 */ { NULL,NULL},
/* 1F2B4 */ { NULL,NULL},
/* 1F2B5 */ { NULL,NULL},
/* 1F2B6 */ { NULL,NULL},
/* 1F2B7 */ { NULL,NULL},
/* 1F2B8 */ { NULL,NULL},
/* 1F2B9 */ { NULL,NULL},
/* 1F2BA */ { NULL,NULL},
/* 1F2BB */ { NULL,NULL},
/* 1F2BC */ { NULL,NULL},
/* 1F2BD */ { NULL,NULL},
/* 1F2BE */ { NULL,NULL},
/* 1F2BF */ { NULL,NULL},
/* 1F2C0 */ { NULL,NULL},
/* 1F2C1 */ { NULL,NULL},
/* 1F2C2 */ { NULL,NULL},
/* 1F2C3 */ { NULL,NULL},
/* 1F2C4 */ { NULL,NULL},
/* 1F2C5 */ { NULL,NULL},
/* 1F2C6 */ { NULL,NULL},
/* 1F2C7 */ { NULL,NULL},
/* 1F2C8 */ { NULL,NULL},
/* 1F2C9 */ { NULL,NULL},
/* 1F2CA */ { NULL,NULL},
/* 1F2CB */ { NULL,NULL},
/* 1F2CC */ { NULL,NULL},
/* 1F2CD */ { NULL,NULL},
/* 1F2CE */ { NULL,NULL},
/* 1F2CF */ { NULL,NULL},
/* 1F2D0 */ { NULL,NULL},
/* 1F2D1 */ { NULL,NULL},
/* 1F2D2 */ { NULL,NULL},
/* 1F2D3 */ { NULL,NULL},
/* 1F2D4 */ { NULL,NULL},
/* 1F2D5 */ { NULL,NULL},
/* 1F2D6 */ { NULL,NULL},
/* 1F2D7 */ { NULL,NULL},
/* 1F2D8 */ { NULL,NULL},
/* 1F2D9 */ { NULL,NULL},
/* 1F2DA */ { NULL,NULL},
/* 1F2DB */ { NULL,NULL},
/* 1F2DC */ { NULL,NULL},
/* 1F2DD */ { NULL,NULL},
/* 1F2DE */ { NULL,NULL},
/* 1F2DF */ { NULL,NULL},
/* 1F2E0 */ { NULL,NULL},
/* 1F2E1 */ { NULL,NULL},
/* 1F2E2 */ { NULL,NULL},
/* 1F2E3 */ { NULL,NULL},
/* 1F2E4 */ { NULL,NULL},
/* 1F2E5 */ { NULL,NULL},
/* 1F2E6 */ { NULL,NULL},
/* 1F2E7 */ { NULL,NULL},
/* 1F2E8 */ { NULL,NULL},
/* 1F2E9 */ { NULL,NULL},
/* 1F2EA */ { NULL,NULL},
/* 1F2EB */ { NULL,NULL},
/* 1F2EC */ { NULL,NULL},
/* 1F2ED */ { NULL,NULL},
/* 1F2EE */ { NULL,NULL},
/* 1F2EF */ { NULL,NULL},
/* 1F2F0 */ { NULL,NULL},
/* 1F2F1 */ { NULL,NULL},
/* 1F2F2 */ { NULL,NULL},
/* 1F2F3 */ { NULL,NULL},
/* 1F2F4 */ { NULL,NULL},
/* 1F2F5 */ { NULL,NULL},
/* 1F2F6 */ { NULL,NULL},
/* 1F2F7 */ { NULL,NULL},
/* 1F2F8 */ { NULL,NULL},
/* 1F2F9 */ { NULL,NULL},
/* 1F2FA */ { NULL,NULL},
/* 1F2FB */ { NULL,NULL},
/* 1F2FC */ { NULL,NULL},
/* 1F2FD */ { NULL,NULL},
/* 1F2FE */ { NULL,NULL},
/* 1F2FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F3[] = {
/* 1F300 */ { "CYCLONE","	= typhon, ouragan"},
/* 1F301 */ { "BRUMEUX","	x (brouillard - 1F32B)"},
/* 1F302 */ { "PARAPLUIE FERMÉ",NULL},
/* 1F303 */ { "NUIT ÉTOILÉE",NULL},
/* 1F304 */ { "LEVER DE SOLEIL DANS LES MONTAGNES",NULL},
/* 1F305 */ { "LEVER DE SOLEIL",NULL},
/* 1F306 */ { "PAYSAGE URBAIN AU CRÉPUSCULE","	x (paysage urbain - 1F3D9)"},
/* 1F307 */ { "COUCHER DE SOLEIL SUR LA VILLE",NULL},
/* 1F308 */ { "ARC-EN-CIEL",NULL},
/* 1F309 */ { "PONT DURANT LA NUIT",NULL},
/* 1F30A */ { "VAGUE D'EAU","	= tsunami, raz-de-marée"},
/* 1F30B */ { "VOLCAN",NULL},
/* 1F30C */ { "VOIE LACTÉE",NULL},
/* 1F30D */ { "GLOBE TERRESTRE EUROPE-AFRIQUE",NULL},
/* 1F30E */ { "GLOBE TERRESTRE AMÉRIQUES",NULL},
/* 1F30F */ { "GLOBE TERRESTRE ASIE-AUSTRALIE",NULL},
/* 1F310 */ { "GLOBE AVEC MÉRIDIENS","	* indique la possibilité de paramétrer différentes langues du monde ou l'heure du fuseau de son choix, notamment"},
/* 1F311 */ { "SYMBOLE DE LA NOUVELLE LUNE","	x (cercle noir - 25CF)"},
/* 1F312 */ { "SYMBOLE DU PREMIER CROISSANT DE LUNE",NULL},
/* 1F313 */ { "SYMBOLE DU PREMIER QUARTIER DE LUNE","	= demi-lune\n"
	"	x (cercle à moitié gauche noire - 25D0)\n"
	"	x (premier quartier de lune - 263D)"},
/* 1F314 */ { "SYMBOLE DE LA LUNE GIBBEUSE CROISSANTE",NULL},
/* 1F315 */ { "SYMBOLE DE LA PLEINE LUNE","	x (cercle blanc - 25CB)"},
/* 1F316 */ { "SYMBOLE DE LA LUNE GIBBEUSE DÉCROISSANTE",NULL},
/* 1F317 */ { "SYMBOLE DU DERNIER QUARTIER DE LUNE","	x (cercle à moitié droite noire - 25D1)\n"
	"	x (dernier quartier de lune - 263E)"},
/* 1F318 */ { "SYMBOLE DU DERNIER CROISSANT DE LUNE",NULL},
/* 1F319 */ { "CROISSANT DE LUNE","	* peut indiquer aussi bien le premier que le dernier quartier de lune\n"
	"	x (premier quartier de lune - 263D)\n"
	"	x (dernier quartier de lune - 263E)"},
/* 1F31A */ { "NOUVELLE LUNE AVEC VISAGE",NULL},
/* 1F31B */ { "PREMIER QUARTIER AVEC VISAGE",NULL},
/* 1F31C */ { "DERNIER QUARTIER AVEC VISAGE",NULL},
/* 1F31D */ { "PLEINE LUNE AVEC VISAGE",NULL},
/* 1F31E */ { "SOLEIL AVEC VISAGE",NULL},
/* 1F31F */ { "ÉTOILE BRILLANTE","	x (étoile blanche - 2606)"},
/* 1F320 */ { "ÉTOILE FILANTE",NULL},
/* 1F321 */ { "THERMOMÈTRE","	= température, chaud"},
/* 1F322 */ { "GOUTTELETTE NOIRE","	= gouttelette\n"
	"	x (gouttelette - 1F4A7)"},
/* 1F323 */ { "SOLEIL BLANC","	= ensoleillé\n"
	"	x (soleil noir avec rayons - 2600)\n"
	"	x (soleil blanc avec rayons - 263C)"},
/* 1F324 */ { "SOLEIL BLANC AVEC PETIT NUAGE","	= principalement ensoleillé\n"
	"	x (soleil derrière un nuage - 26C5)"},
/* 1F325 */ { "SOLEIL BLANC DERRIÈRE UN NUAGE","	= principalement nuageux"},
/* 1F326 */ { "SOLEIL BLANC DERRIÈRE UN NUAGE AVEC PLUIE","	= averses"},
/* 1F327 */ { "NUAGE AVEC PLUIE","	= pluie\n"
	"	x (parapluie - 2602)"},
/* 1F328 */ { "NUAGE AVEC NEIGE","	= neige, chutes de neige"},
/* 1F329 */ { "NUAGE AVEC ÉCLAIR","	= orage\n"
	"	x (nuage orageux et pluie - 26C8)"},
/* 1F32A */ { "NUAGE AVEC TORNADE","	= tornade"},
/* 1F32B */ { "BROUILLARD","	x (brumeux - 1F301)"},
/* 1F32C */ { "VISAGE SOUFFLANT","	= vent"},
/* 1F32D */ { "HOT-DOG",NULL},
/* 1F32E */ { "TACO",NULL},
/* 1F32F */ { "BURRITO",NULL},
/* 1F330 */ { "CHÂTAIGNE",NULL},
/* 1F331 */ { "JEUNE PLANT",NULL},
/* 1F332 */ { "ARBRE SEMPERVIRENT","	x (parc national - 1F3DE)"},
/* 1F333 */ { "ARBRE CADUCIFOLIÉ","	x (symbole arbre - 1CEBC)"},
/* 1F334 */ { "PALMIER","	x (île déserte - 1F3DD)"},
/* 1F335 */ { "CACTUS","	x (désert - 1F3DC)"},
/* 1F336 */ { "PIMENT","	= épicé"},
/* 1F337 */ { "TULIPE","	x (fleur - 2698)"},
/* 1F338 */ { "FLEUR DE CERISIER",NULL},
/* 1F339 */ { "ROSE","	x (fleur fanée - 1F940)"},
/* 1F33A */ { "HIBISCUS",NULL},
/* 1F33B */ { "TOURNESOL",NULL},
/* 1F33C */ { "MARGUERITE",NULL},
/* 1F33D */ { "ÉPI DE MAÏS",NULL},
/* 1F33E */ { "ÉPI DE RIZ",NULL},
/* 1F33F */ { "HERBE",NULL},
/* 1F340 */ { "TRÈFLE À QUATRE FEUILLES","	x (trèfle irlandais - 2618)"},
/* 1F341 */ { "FEUILLE D'ÉRABLE",NULL},
/* 1F342 */ { "FEUILLE MORTE",NULL},
/* 1F343 */ { "FEUILLE VOLETANT AU VENT",NULL},
/* 1F344 */ { "CHAMPIGNON",NULL},
/* 1F345 */ { "TOMATE",NULL},
/* 1F346 */ { "AUBERGINE",NULL},
/* 1F347 */ { "RAISINS",NULL},
/* 1F348 */ { "MELON",NULL},
/* 1F349 */ { "PASTÈQUE",NULL},
/* 1F34A */ { "MANDARINE",NULL},
/* 1F34B */ { "CITRON",NULL},
/* 1F34C */ { "BANANE",NULL},
/* 1F34D */ { "ANANAS",NULL},
/* 1F34E */ { "POMME ROUGE","	x (symbole pomme - 1CEBD)"},
/* 1F34F */ { "POMME VERTE",NULL},
/* 1F350 */ { "POIRE",NULL},
/* 1F351 */ { "PÊCHE",NULL},
/* 1F352 */ { "CERISES","	x (symbole cerise - 1CEBE)"},
/* 1F353 */ { "FRAISE","	x (symbole fraise - 1CEBF)"},
/* 1F354 */ { "HAMBURGER","	= établissement de restauration rapide"},
/* 1F355 */ { "PART DE PIZZA",NULL},
/* 1F356 */ { "VIANDE À L'OS",NULL},
/* 1F357 */ { "CUISSE DE VOLAILLE",NULL},
/* 1F358 */ { "GALETTE DE RIZ",NULL},
/* 1F359 */ { "BOULE DE RIZ",NULL},
/* 1F35A */ { "RIZ CUIT","	= bol de riz"},
/* 1F35B */ { "RIZ AU CURRY",NULL},
/* 1F35C */ { "BOL FUMANT DE CHALEUR","	= nouilles ramen"},
/* 1F35D */ { "SPAGHETTI",NULL},
/* 1F35E */ { "PAIN",NULL},
/* 1F35F */ { "FRITES",NULL},
/* 1F360 */ { "PATATE DOUCE RÔTIE",NULL},
/* 1F361 */ { "DANGO","	= boulettes de mochi en brochette"},
/* 1F362 */ { "ODEN","	= pot-au-feu japonais, ragoût de Kanto"},
/* 1F363 */ { "SUSHI",NULL},
/* 1F364 */ { "CREVETTE FRITE",NULL},
/* 1F365 */ { "PÂTÉ DE POISSON AVEC MOTIF EN SPIRALE",NULL},
/* 1F366 */ { "GLACE À L'ITALIENNE",NULL},
/* 1F367 */ { "GRANITÉ",NULL},
/* 1F368 */ { "GLACE",NULL},
/* 1F369 */ { "BEIGNET","	= beigne (Canada)"},
/* 1F36A */ { "BISCUIT SEC",NULL},
/* 1F36B */ { "BARRE DE CHOCOLAT",NULL},
/* 1F36C */ { "BONBON",NULL},
/* 1F36D */ { "SUCETTE",NULL},
/* 1F36E */ { "CRÈME ANGLAISE",NULL},
/* 1F36F */ { "POT DE MIEL",NULL},
/* 1F370 */ { "GÂTEAU",NULL},
/* 1F371 */ { "BOÎTE À BENTO",NULL},
/* 1F372 */ { "MARMITE DE NOURRITURE",NULL},
/* 1F373 */ { "CUISSON","	= ustensile de cuisine"},
/* 1F374 */ { "FOURCHETTE ET COUTEAU","	= restaurant, repas\n"
	"	* le glyphe peut représenter une fourchette et une cuillère\n"
	"	* le glyphe peut représenter un couteau et une fourchette croisés\n"
	"	x (couvert - 1F37D)\n"
	"	x (cuillère - 1F944)"},
/* 1F375 */ { "TASSE À THÉ SANS ANSE","	x (boisson chaude - 2615)\n"
	"	x (tasse sur carré noir - 26FE)"},
/* 1F376 */ { "BOUTEILLE DE SAKÉ ET GOBELET",NULL},
/* 1F377 */ { "VERRE À VIN","	x (symbole fragile - 1CEBA)"},
/* 1F378 */ { "VERRE À COCKTAIL","	= verre à coquetel (Canada)\n"
	"	= bar\n"
	"	x (divan et lampe - 1F6CB)\n"
	"	x (verre à fond plat - 1F943)"},
/* 1F379 */ { "COCKTAIL TROPICAL","	= coquetel tropical (Canada)"},
/* 1F37A */ { "CHOPE",NULL},
/* 1F37B */ { "CHOPES S'ENTRECHOQUANT","	= « À votre santé ! », « À ta santé ! »\n"
	"	x (verres tintants - 1F942)"},
/* 1F37C */ { "BIBERON",NULL},
/* 1F37D */ { "COUVERT","	= dîner\n"
	"	x (fourchette et couteau - 1F374)"},
/* 1F37E */ { "BOUTEILLE AU BOUCHON QUI SAUTE",NULL},
/* 1F37F */ { "POPCORN","	= maïs soufflé"},
/* 1F380 */ { "RUBAN",NULL},
/* 1F381 */ { "CADEAU EMBALLÉ","	x (paquet-cadeau - 1F4E6)"},
/* 1F382 */ { "GÂTEAU D'ANNIVERSAIRE",NULL},
/* 1F383 */ { "CITROUILLE-LANTERNE","	= halloween"},
/* 1F384 */ { "ARBRE DE NOËL",NULL},
/* 1F385 */ { "PÈRE NOËL","	x (mère noël - 1F936)"},
/* 1F386 */ { "FEUX D'ARTIFICE",NULL},
/* 1F387 */ { "CIERGE MAGIQUE","	* long feu d'artifice en forme de bâtonnet ressemblant à un bâton d'encens allumé"},
/* 1F388 */ { "BALLON",NULL},
/* 1F389 */ { "BOMBE DE TABLE",NULL},
/* 1F38A */ { "BOULE DE CONFETTIS","	= félicitations"},
/* 1F38B */ { "ARBRE DE TANABATA",NULL},
/* 1F38C */ { "DRAPEAUX CROISÉS","	* fête nationale japonaise"},
/* 1F38D */ { "DÉCORATION DE PIN","	* décoration de porte pour le Nouvel An japonais"},
/* 1F38E */ { "POUPÉES JAPONAISES","	* Hina matsuri (« fête des poupées »)"},
/* 1F38F */ { "SERPENTINS À CARPES",NULL},
/* 1F390 */ { "CARILLON À VENT",NULL},
/* 1F391 */ { "FÊTE AUTOMNALE DE LA PLEINE LUNE","	* fête des moissons Otsukimi japonaise"},
/* 1F392 */ { "CARTABLE SCOLAIRE","	* cérémonie japonaise de la rentrée scolaire"},
/* 1F393 */ { "CHAPEAU DE DIPLÔMÉ","	= instruction\n"
	"	* cérémonie de remise des diplômes"},
/* 1F394 */ { "CŒUR AVEC POINTE À GAUCHE","	= favori, favorite\n"
	"	x (enseigne de cœur noire - 2665)"},
/* 1F395 */ { "BOUQUET DE FLEURS","	= occasion\n"
	"	x (bouquet - 1F490)"},
/* 1F396 */ { "DÉCORATION MILITAIRE",NULL},
/* 1F397 */ { "RUBAN DE RAPPEL",NULL},
/* 1F398 */ { "CLAVIER MUSICAL AVEC CÂBLES","	= MIDI, clavier MIDI, clavier maître avec fiches\n"
	"	x (clavier musical - 1F3B9)"},
/* 1F399 */ { "MICROPHONE DE STUDIO","	x (microphone - 1F3A4)"},
/* 1F39A */ { "CURSEUR DE NIVEAU","	= régulateur de niveau"},
/* 1F39B */ { "BOUTONS DE COMMANDE",NULL},
/* 1F39C */ { "NOTES DE MUSIQUE ASCENDANTES RAMÉES","	= performance musicale\n"
	"	= musique, musique de fond\n"
	"	* toujours ascendantes, contrairement à 266C\n"
	"	x (deux doubles croches ramées - 266C)"},
/* 1F39D */ { "NOTES DE MUSIQUE DESCENDANTES RAMÉES","	* toujours descendantes, contrairement à 266C\n"
	"	x (deux croches ramées - 266B)"},
/* 1F39E */ { "TRAMES DE FILM","	= séquence de film\n"
	"	x (caméra - 1F3A5)"},
/* 1F39F */ { "BILLETS D'ENTRÉE","	x (billet - 1F3AB)"},
/* 1F3A0 */ { "CHEVAL DE CARROUSEL","	= parc d'attractions"},
/* 1F3A1 */ { "GRANDE ROUE","	= parc d'attractions"},
/* 1F3A2 */ { "MONTAGNES RUSSES",NULL},
/* 1F3A3 */ { "CANNE À PÊCHE ET POISSON","	= pêche"},
/* 1F3A4 */ { "MICROPHONE","	= karaoké\n"
	"	x (microphone de studio - 1F399)"},
/* 1F3A5 */ { "CAMÉRA","	= film, cinéma\n"
	"	x (trames de film - 1F39E)"},
/* 1F3A6 */ { "CINÉMA","	= salle de cinéma, projecteur cinématogaphique\n"
	"	x (projecteur de cinéma - 1F4FD)"},
/* 1F3A7 */ { "CASQUE À ÉCOUTEURS","	= musique"},
/* 1F3A8 */ { "PALETTE DE PEINTRE","	= art"},
/* 1F3A9 */ { "HAUT-DE-FORME","	= art dramatique, arts du spectacle, théâtre"},
/* 1F3AA */ { "TENTE DE CIRQUE","	= événement"},
/* 1F3AB */ { "BILLET","	* indique un événement\n"
	"	x (billets d'entrée - 1F39F)"},
/* 1F3AC */ { "CLAQUETTE","	= film"},
/* 1F3AD */ { "ARTS DU SPECTACLE","	= masques de théâtre, théâtre"},
/* 1F3AE */ { "JEU VIDÉO","	= commande de jeu vidéo"},
/* 1F3AF */ { "COUP DIRECT","	= cible de tir à l'arc, frapper la cible\n"
	"	x (deux cercles concentriques - 25CE)"},
/* 1F3B0 */ { "MACHINE À SOUS",NULL},
/* 1F3B1 */ { "BILLARD","	= boule magique 8"},
/* 1F3B2 */ { "DÉ À JOUER",NULL},
/* 1F3B3 */ { "BOWLING","	= jeu de quilles"},
/* 1F3B4 */ { "CARTES À FLEURS",NULL},
/* 1F3B5 */ { "NOTE DE MUSIQUE","	= musique, bonne humeur\n"
	"	x (note croche - 266A)"},
/* 1F3B6 */ { "NOTES DE MUSIQUE MULTIPLES","	= ambiance, mélodie\n"
	"	x (deux croches ramées - 266B)"},
/* 1F3B7 */ { "SAXOPHONE",NULL},
/* 1F3B8 */ { "GUITARE",NULL},
/* 1F3B9 */ { "CLAVIER MUSICAL","	x (clavier musical avec câbles - 1F398)"},
/* 1F3BA */ { "TROMPETTE",NULL},
/* 1F3BB */ { "VIOLON",NULL},
/* 1F3BC */ { "PARTITION MUSICALE","	x (symbole musical clé de sol - 1D11E)"},
/* 1F3BD */ { "MAILLOT DE COURSE AVEC ÉCHARPE","	= relais ekiden (japonais)\n"
	"	* un maillot de course avec une écharpe isolée renvoie au relais longue distance\n"
	"	* symbole générique représentant l'athlétisme\n"
	"	* le glyphe peut être représenté avec une écharpe, une rayure, ou sans l'une ni l'autre"},
/* 1F3BE */ { "TENNIS",NULL},
/* 1F3BF */ { "SKI ET BOTTE DE SKI","	x (skieur - 26F7)"},
/* 1F3C0 */ { "BASKET-BALL",NULL},
/* 1F3C1 */ { "DRAPEAU EN DAMIER","	= sports moteurs"},
/* 1F3C2 */ { "NIVOPLANCHISTE","	= surfeur des neiges, surfeuse des neiges (Canada)\n"
	"	* « snowboardeur » et « snowboardeuse » sont des formes dont l'emploi est à éviter"},
/* 1F3C3 */ { "COUREUR","	= course, marathon, athlétisme\n"
	"	x (moitié gauche de coureur - 1FBB2)"},
/* 1F3C4 */ { "SURFEUR","	= surf"},
/* 1F3C5 */ { "MÉDAILLE SPORTIVE","	x (médaille d'or - 1F947)"},
/* 1F3C6 */ { "TROPHÉE",NULL},
/* 1F3C7 */ { "COURSE DE CHEVAUX",NULL},
/* 1F3C8 */ { "FOOTBALL AMÉRICAIN",NULL},
/* 1F3C9 */ { "RUGBY",NULL},
/* 1F3CA */ { "NAGEUR",NULL},
/* 1F3CB */ { "HALTÉROPHILE","	= santé"},
/* 1F3CC */ { "GOLFEUR",NULL},
/* 1F3CD */ { "MOTOCYCLETTE DE COURSE","	* peut représenter une motocyclette ordinaire, en particulier quand il s'agit d'un émoji"},
/* 1F3CE */ { "VOITURE DE COURSE",NULL},
/* 1F3CF */ { "BATTE ET BALLE DE CRICKET",NULL},
/* 1F3D0 */ { "VOLLEY-BALL",NULL},
/* 1F3D1 */ { "CROSSE ET BALLE DE HOCKEY SUR GAZON",NULL},
/* 1F3D2 */ { "BÂTON ET RONDELLE DE HOCKEY SUR GLACE",NULL},
/* 1F3D3 */ { "RAQUETTE ET BALLE DE TENNIS DE TABLE",NULL},
/* 1F3D4 */ { "CIME ENNEIGÉE","	x (montagne - 26F0)"},
/* 1F3D5 */ { "CAMPING","	x (tente - 26FA)"},
/* 1F3D6 */ { "PLAGE AVEC PARASOL","	x (parapluie au sol - 26F1)"},
/* 1F3D7 */ { "CONSTRUCTION D'IMMEUBLE","	= en construction\n"
	"	x (panneau indicateur de construction - 1F6A7)"},
/* 1F3D8 */ { "MAISONS","	= ville, village\n"
	"	x (maison d'habitation et jardin - 1F3E1)"},
/* 1F3D9 */ { "PAYSAGE URBAIN","	= métropole, ville\n"
	"	x (paysage urbain au crépuscule - 1F306)"},
/* 1F3DA */ { "MAISON ABANDONNÉE","	= site à l'abandon"},
/* 1F3DB */ { "BÂTIMENT CLASSIQUE","	= bâtiment public"},
/* 1F3DC */ { "DÉSERT","	= zone désertique\n"
	"	x (cactus - 1F335)"},
/* 1F3DD */ { "ÎLE DÉSERTE","	= île\n"
	"	x (palmier - 1F334)"},
/* 1F3DE */ { "PARC NATIONAL","	* par extension, il a pris la valeur d'un symbole représentant la préservation des arbres et s'utilise donc aussi comme un symbole indiquant « n'imprimez pas ceci (courriel, document) »\n"
	"	x (arbre sempervirent - 1F332)"},
/* 1F3DF */ { "STADE",NULL},
/* 1F3E0 */ { "MAISON D'HABITATION",NULL},
/* 1F3E1 */ { "MAISON D'HABITATION ET JARDIN","	= pavillon\n"
	"	x (maisons - 1F3D8)"},
/* 1F3E2 */ { "IMMEUBLE DE BUREAUX","	x (symbole immeuble de bureaux - 1CEBB)"},
/* 1F3E3 */ { "BUREAU DE POSTE JAPONAIS","	x (marque postale - 3012)"},
/* 1F3E4 */ { "BUREAU DE POSTE EUROPÉEN",NULL},
/* 1F3E5 */ { "HÔPITAL","	x (croix noire sur bouclier - 26E8)"},
/* 1F3E6 */ { "BANQUE","	x (lettre majuscule latine b encadrée - 1F131)"},
/* 1F3E7 */ { "GUICHET AUTOMATIQUE BANCAIRE","	= distributeur automatique de billets"},
/* 1F3E8 */ { "HÔTEL","	x (lettre majuscule latine h cerclée noir au blanc - 1F157)\n"
	"	x (centre d'hébergement - 1F6CC)"},
/* 1F3E9 */ { "LOVE HOTEL",NULL},
/* 1F3EA */ { "DÉPANNEUR",NULL},
/* 1F3EB */ { "ÉCOLE",NULL},
/* 1F3EC */ { "GRAND MAGASIN",NULL},
/* 1F3ED */ { "USINE","	= site de production industrielle\n"
	"	= date de fabrication\n"
	"	x (roue d'engrenage sans moyeu - 26ED)"},
/* 1F3EE */ { "ENSEIGNE-LANTERNE D'IZAKAYA","	= restaurant izakaya japonais"},
/* 1F3EF */ { "CHÂTEAU JAPONAIS",NULL},
/* 1F3F0 */ { "CHÂTEAU EUROPÉEN","	x (château - 26EB)"},
/* 1F3F1 */ { "FANION BLANC","	x (fanion triangulaire de localisation - 1F6A9)"},
/* 1F3F2 */ { "FANION NOIR",NULL},
/* 1F3F3 */ { "DRAPEAU BLANC BATTANT AU VENT","	= drapeau\n"
	"	x (drapeau blanc - 2690)"},
/* 1F3F4 */ { "DRAPEAU NOIR BATTANT AU VENT",NULL},
/* 1F3F5 */ { "ROSETTE","	x (fleuron blanc - 2740)"},
/* 1F3F6 */ { "ROSETTE NOIRE","	x (fleuron noir à contour à huit pétales - 2741)"},
/* 1F3F7 */ { "ÉTIQUETTE","	= prix, étiquette de prix\n"
	"	x (signet - 1F516)"},
/* 1F3F8 */ { "RAQUETTE ET VOLANT DE BADMINTON",NULL},
/* 1F3F9 */ { "ARC ET FLÈCHE","	= tir à l'arc\n"
	"	* s'utilise aussi pour le signe du Sagittaire\n"
	"	x (sagittaire - 2650)"},
/* 1F3FA */ { "AMPHORE","	* s'utilise pour le signe du Verseau\n"
	"	x (verseau - 2652)\n"
	"	x (idéogramme linéaire b vase b209 - 100E8)"},
/* 1F3FB */ { "MODIFICATEUR D'ÉMOJI PHOTOTYPE-1-2",NULL},
/* 1F3FC */ { "MODIFICATEUR D'ÉMOJI PHOTOTYPE-3",NULL},
/* 1F3FD */ { "MODIFICATEUR D'ÉMOJI PHOTOTYPE-4",NULL},
/* 1F3FE */ { "MODIFICATEUR D'ÉMOJI PHOTOTYPE-5",NULL},
/* 1F3FF */ { "MODIFICATEUR D'ÉMOJI PHOTOTYPE-6",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F4[] = {
/* 1F400 */ { "RAT","	* premier signe du zodiaque asiatique"},
/* 1F401 */ { "SOURIS","	* premier signe du zodiaque asiatique utilisé en Perse"},
/* 1F402 */ { "BŒUF","	* deuxième signe du zodiaque asiatique"},
/* 1F403 */ { "BUFFLE D'ASIE","	* deuxième signe du zodiaque asiatique utilisé au Viêt Nam"},
/* 1F404 */ { "VACHE","	= bœuf (sur la carte des menus)\n"
	"	* deuxième signe du zodiaque asiatique utilisé en Perse"},
/* 1F405 */ { "TIGRE","	* troisième signe du zodiaque asiatique"},
/* 1F406 */ { "LÉOPARD","	* troisième signe du zodiaque asiatique utilisé en Perse"},
/* 1F407 */ { "LAPIN","	* quatrième signe du zodiaque asiatique"},
/* 1F408 */ { "CHAT","	* quatrième signe du zodiaque asiatique utilisé au Viêt Nam"},
/* 1F409 */ { "DRAGON","	* cinquième signe du zodiaque asiatique"},
/* 1F40A */ { "CROCODILE","	* cinquième signe du zodiaque asiatique utilisé en Perse"},
/* 1F40B */ { "BALEINE","	* cinquième signe du zodiaque asiatique utilisé en Perse"},
/* 1F40C */ { "ESCARGOT","	* cinquième signe du zodiaque asiatique utilisé au Kazakhstan"},
/* 1F40D */ { "SERPENT","	* sixième signe du zodiaque asiatique\n"
	"	x (symbole serpent - 1CCFA)"},
/* 1F40E */ { "CHEVAL","	= sports équestres\n"
	"	* septième signe du zodiaque asiatique"},
/* 1F40F */ { "BOUC","	* huitième signe du zodiaque asiatique\n"
	"	x (bélier - 2648)"},
/* 1F410 */ { "CHÈVRE","	* huitième signe du zodiaque asiatique utilisé au Viêt Nam"},
/* 1F411 */ { "MOUTON","	* huitième signe du zodiaque asiatique utilisé en Perse"},
/* 1F412 */ { "SINGE","	* neuvième signe du zodiaque asiatique"},
/* 1F413 */ { "COQ","	* dixième signe du zodiaque asiatique"},
/* 1F414 */ { "POULE","	= poulet, volaille (sur la carte des menus)\n"
	"	* dixième signe du zodiaque asiatique utilisé en Perse"},
/* 1F415 */ { "CHIEN","	* onzième signe du zodiaque asiatique"},
/* 1F416 */ { "COCHON","	= porc (sur la carte des menus)\n"
	"	* douzième signe du zodiaque asiatique"},
/* 1F417 */ { "SANGLIER","	* douzième signe du zodiaque asiatique utilisé au Japon"},
/* 1F418 */ { "ÉLÉPHANT","	* douzième signe du zodiaque asiatique utilisé en Thaïlande"},
/* 1F419 */ { "PIEUVRE",NULL},
/* 1F41A */ { "COQUILLE DE GASTÉROPODE",NULL},
/* 1F41B */ { "BESTIOLE",NULL},
/* 1F41C */ { "FOURMI",NULL},
/* 1F41D */ { "ABEILLE",NULL},
/* 1F41E */ { "COCCINELLE","	= bête à bon Dieu"},
/* 1F41F */ { "POISSON",NULL},
/* 1F420 */ { "POISSON TROPICAL",NULL},
/* 1F421 */ { "POISSON GLOBE",NULL},
/* 1F422 */ { "TORTUE",NULL},
/* 1F423 */ { "POUSSIN À L'ÉCLOSION",NULL},
/* 1F424 */ { "POUSSIN",NULL},
/* 1F425 */ { "POUSSIN VU DE FACE",NULL},
/* 1F426 */ { "OISEAU",NULL},
/* 1F427 */ { "PINGOUIN",NULL},
/* 1F428 */ { "KOALA",NULL},
/* 1F429 */ { "CANICHE",NULL},
/* 1F42A */ { "DROMADAIRE","	* a une seule bosse"},
/* 1F42B */ { "CHAMEAU DE BACTRIANE","	* a deux bosses"},
/* 1F42C */ { "DAUPHIN",NULL},
/* 1F42D */ { "FACE DE SOURIS",NULL},
/* 1F42E */ { "FACE DE VACHE",NULL},
/* 1F42F */ { "FACE DE TIGRE",NULL},
/* 1F430 */ { "FACE DE LAPIN",NULL},
/* 1F431 */ { "FACE DE CHAT","	x (face de chat souriant la bouche ouverte - 1F63A)"},
/* 1F432 */ { "FACE DE DRAGON",NULL},
/* 1F433 */ { "BALEINE SOUFFLANTE",NULL},
/* 1F434 */ { "FACE DE CHEVAL",NULL},
/* 1F435 */ { "FACE DE SINGE",NULL},
/* 1F436 */ { "FACE DE CHIEN",NULL},
/* 1F437 */ { "FACE DE COCHON",NULL},
/* 1F438 */ { "FACE DE GRENOUILLE",NULL},
/* 1F439 */ { "FACE DE HAMSTER",NULL},
/* 1F43A */ { "FACE DE LOUP",NULL},
/* 1F43B */ { "FACE D'OURS",NULL},
/* 1F43C */ { "FACE DE PANDA",NULL},
/* 1F43D */ { "NEZ DE COCHON",NULL},
/* 1F43E */ { "EMPREINTES DE PATTES","	x (empreintes de pieds - 1F463)"},
/* 1F43F */ { "TAMIA","	* également utilisé pour représenter un écureuil"},
/* 1F440 */ { "YEUX",NULL},
/* 1F441 */ { "ŒIL","	= vue"},
/* 1F442 */ { "OREILLE",NULL},
/* 1F443 */ { "NEZ","	x (symbole nez - 1CCFC)"},
/* 1F444 */ { "BOUCHE",NULL},
/* 1F445 */ { "LANGUE",NULL},
/* 1F446 */ { "INDEX DE REVERS DE MAIN BLANC POINTANT VERS LE HAUT","	x (index blanc pointant vers le haut - 261D)\n"
	"	x (index de revers de main noir pointant vers le haut - 1F5A2)"},
/* 1F447 */ { "INDEX DE REVERS DE MAIN BLANC POINTANT VERS LE BAS","	x (index blanc pointant vers le bas - 261F)\n"
	"	x (index de la main gauche blanc pointant vers le bas - 1F597)\n"
	"	x (index de revers de main noir pointant vers le bas - 1F5A3)"},
/* 1F448 */ { "INDEX DE REVERS DE MAIN BLANC POINTANT VERS LA GAUCHE","	x (index blanc pointant vers la gauche - 261C)\n"
	"	x (index de revers de main noir pointant vers la gauche - 1F59C)\n"
	"	x (main vers la gauche - 1FAF2)"},
/* 1F449 */ { "INDEX DE REVERS DE MAIN BLANC POINTANT VERS LA DROITE","	x (index blanc pointant vers la droite - 261E)\n"
	"	x (index de revers de main noir pointant vers la droite - 1F59D)\n"
	"	x (main vers la droite - 1FAF1)"},
/* 1F44A */ { "SIGNE DU COUP DE POING","	= énergie\n"
	"	x (poing levé - 270A)"},
/* 1F44B */ { "SALUT DE LA MAIN","	x (main levée - 270B)"},
/* 1F44C */ { "SIGNE OK DE LA MAIN","	x (signe ok de la main tourné - 1F58F)"},
/* 1F44D */ { "SIGNE DU POUCE VERS LE HAUT","	x (signe du pouce vers le haut réfléchi - 1F592)"},
/* 1F44E */ { "SIGNE DU POUCE VERS LE BAS","	x (signe du pouce vers le bas réfléchi - 1F593)"},
/* 1F44F */ { "SIGNE D'APPLAUDISSEMENTS",NULL},
/* 1F450 */ { "SIGNE DES MAINS OUVERTES",NULL},
/* 1F451 */ { "COURONNE",NULL},
/* 1F452 */ { "CHAPEAU DE FEMME",NULL},
/* 1F453 */ { "LUNETTES",NULL},
/* 1F454 */ { "CRAVATE",NULL},
/* 1F455 */ { "TEE-SHIRT",NULL},
/* 1F456 */ { "JEAN",NULL},
/* 1F457 */ { "ROBE",NULL},
/* 1F458 */ { "KIMONO",NULL},
/* 1F459 */ { "BIKINI",NULL},
/* 1F45A */ { "VÊTEMENTS FÉMININS",NULL},
/* 1F45B */ { "PORTE-MONNAIE",NULL},
/* 1F45C */ { "SAC À MAIN",NULL},
/* 1F45D */ { "POCHETTE",NULL},
/* 1F45E */ { "CHAUSSURE D'HOMME",NULL},
/* 1F45F */ { "CHAUSSURE DE SPORT","	= chaussure de tennis, coureur"},
/* 1F460 */ { "CHAUSSURE À TALON HAUT",NULL},
/* 1F461 */ { "SANDALE DE FEMME",NULL},
/* 1F462 */ { "BOTTES DE FEMME",NULL},
/* 1F463 */ { "EMPREINTES DE PIEDS","	x (empreintes de pattes - 1F43E)"},
/* 1F464 */ { "BUSTE EN SILHOUETTE",NULL},
/* 1F465 */ { "BUSTES EN SILHOUETTE",NULL},
/* 1F466 */ { "GARÇON",NULL},
/* 1F467 */ { "FILLE","	x (enfant - 1F9D2)"},
/* 1F468 */ { "HOMME",NULL},
/* 1F469 */ { "FEMME","	x (adulte - 1F9D1)"},
/* 1F46A */ { "FAMILLE","	= classé pour la famille"},
/* 1F46B */ { "HOMME ET FEMME SE TENANT PAR LA MAIN","	x (salle de toilettes - 1F6BB)"},
/* 1F46C */ { "DEUX HOMMES SE TENANT PAR LA MAIN",NULL},
/* 1F46D */ { "DEUX FEMMES SE TENANT PAR LA MAIN",NULL},
/* 1F46E */ { "POLICIER",NULL},
/* 1F46F */ { "FEMME AVEC OREILLES DE LAPIN","	* glyphe communément représenté avec deux femmes dansant"},
/* 1F470 */ { "MARIÉE AVEC VOILE","	x (homme en smoking - 1F935)"},
/* 1F471 */ { "PERSONNE AUX CHEVEUX BLONDS",NULL},
/* 1F472 */ { "HOMME AVEC CALOTTE CHINOISE",NULL},
/* 1F473 */ { "HOMME AVEC TURBAN","	* peut être représenté avec ou sans barbe"},
/* 1F474 */ { "HOMME ÂGÉ",NULL},
/* 1F475 */ { "FEMME ÂGÉE","	x (adulte âgé - 1F9D3)"},
/* 1F476 */ { "BÉBÉ",NULL},
/* 1F477 */ { "OUVRIER DE LA CONSTRUCTION","	* l'éventuelle croix verte sur le casque rappelle la Sûreté japonaise\n"
	"	x (casque avec croix blanche - 26D1)"},
/* 1F478 */ { "PRINCESSE","	x (prince - 1F934)\n"
	"	x (tête couronnée - 1FAC5)"},
/* 1F479 */ { "OGRE JAPONAIS",NULL},
/* 1F47A */ { "GOBELIN JAPONAIS",NULL},
/* 1F47B */ { "FANTÔME",NULL},
/* 1F47C */ { "ANGELET",NULL},
/* 1F47D */ { "EXTRATERRESTRE","	x (soucoupe volante - 1F6F8)"},
/* 1F47E */ { "MONSTRE EXTRATERRESTRE","	x (face de robot - 1F916)"},
/* 1F47F */ { "DIABLOTIN","	* généralement représenté avec une mine froncée, version contraire de 1F608"},
/* 1F480 */ { "CRÂNE",NULL},
/* 1F481 */ { "PRÉPOSÉ À UN KIOSQUE D'INFORMATION","	* souvent utilisé pour signifier l'insolence ou l'insouciance"},
/* 1F482 */ { "GARDE",NULL},
/* 1F483 */ { "DANSEUSE","	* s'utilise aussi pour « faisons la fête »\n"
	"	x (homme dansant - 1F57A)"},
/* 1F484 */ { "BÂTON DE ROUGE À LÈVRES",NULL},
/* 1F485 */ { "VERNIS À ONGLES","	= manucure"},
/* 1F486 */ { "MASSAGE FACIAL",NULL},
/* 1F487 */ { "COUPE DE CHEVEUX","	* indique habituellement un salon de beauté"},
/* 1F488 */ { "ENSEIGNE DE COIFFEUR",NULL},
/* 1F489 */ { "SERINGUE",NULL},
/* 1F48A */ { "PILULE",NULL},
/* 1F48B */ { "MARQUE DE BAISER","	= lèvres\n"
	"	x (lèvres - 1F5E2)"},
/* 1F48C */ { "LETTRE D'AMOUR",NULL},
/* 1F48D */ { "ANNEAU","	= bijou"},
/* 1F48E */ { "PIERRE PRÉCIEUSE",NULL},
/* 1F48F */ { "BAISER","	= deux personnes échangeant un baiser"},
/* 1F490 */ { "BOUQUET","	x (bouquet de fleurs - 1F395)"},
/* 1F491 */ { "COUPLE AVEC CŒUR",NULL},
/* 1F492 */ { "MARIAGE","	x (symbole du mariage - 26AD)"},
/* 1F493 */ { "CŒUR BATTANT",NULL},
/* 1F494 */ { "CŒUR BRISÉ",NULL},
/* 1F495 */ { "DEUX CŒURS",NULL},
/* 1F496 */ { "CŒUR SCINTILLANT",NULL},
/* 1F497 */ { "CŒUR CROISSANT",NULL},
/* 1F498 */ { "CŒUR TRANSPERCÉ D'UNE FLÈCHE",NULL},
/* 1F499 */ { "CŒUR BLEU","	x (enseigne de cœur blanche - 2661)\n"
	"	x (enseigne de cœur noire - 2665)\n"
	"	x (cœur noir épais - 2764)\n"
	"	x (cœur blanc - 1F90D)\n"
	"	x (cœur orange - 1F9E1)\n"
	"	x (cœur bleu clair - 1FA75)"},
/* 1F49A */ { "CŒUR VERT",NULL},
/* 1F49B */ { "CŒUR JAUNE",NULL},
/* 1F49C */ { "CŒUR POURPRE",NULL},
/* 1F49D */ { "CŒUR ENRUBANNÉ",NULL},
/* 1F49E */ { "CŒURS TOURNANT EN CERCLE",NULL},
/* 1F49F */ { "CŒUR DÉCORATIF",NULL},
/* 1F4A0 */ { "FORME DE LOSANGE AVEC UN POINT INSCRIT","	= kawaii, mignon\n"
	"	* le sens de « mignon » repose sur l'association du glyphe avec la forme d'une fleur\n"
	"	x (losange blanc à point centré - 27D0)"},
/* 1F4A1 */ { "AMPOULE ÉLECTRIQUE","	= idée"},
/* 1F4A2 */ { "SYMBOLE DE LA COLÈRE",NULL},
/* 1F4A3 */ { "BOMBE",NULL},
/* 1F4A4 */ { "SYMBOLE DU SOMMEIL",NULL},
/* 1F4A5 */ { "SYMBOLE DE LA COLLISION","	x (phylactère d'humeur - 1F5F0)"},
/* 1F4A6 */ { "SYMBOLE DE GOUTTES DE SUEUR",NULL},
/* 1F4A7 */ { "GOUTTELETTE","	* représente une goutte de sueur ou une goutte d'eau\n"
	"	x (gouttelette noire - 1F322)\n"
	"	x (goutte de sang - 1FA78)"},
/* 1F4A8 */ { "SYMBOLE DE MOUVEMENT RAPIDE","	= tiret de mouvement et tourbillon de poussière"},
/* 1F4A9 */ { "TAS DE CROTTE","	= crotte de chien\n"
	"	* peut être représenté avec ou sans visage souriant"},
/* 1F4AA */ { "BICEPS EN FLEXION","	= fort, musclé"},
/* 1F4AB */ { "SYMBOLE DU VERTIGE","	= étoiles tournant en cercle"},
/* 1F4AC */ { "PHYLACTÈRE DE PAROLE","	= bulle"},
/* 1F4AD */ { "PHYLACTÈRE DE PENSÉE","	x (phylactère de réflexion à droite - 1F5ED)"},
/* 1F4AE */ { "FLEUR BLANCHE","	= devoir brillant\n"
	"	x (fleuron blanc - 2740)"},
/* 1F4AF */ { "SYMBOLE CENT POINTS","	= résultat parfait"},
/* 1F4B0 */ { "SAC D'ARGENT","	* le glyphe peut représenter tout symbole monétaire, pas nécessairement celui du dollar"},
/* 1F4B1 */ { "CHANGE",NULL},
/* 1F4B2 */ { "GROS SYMBOLE DOLLAR","	x (symbole dollar - 0024)"},
/* 1F4B3 */ { "CARTE DE CRÉDIT",NULL},
/* 1F4B4 */ { "BILLET DE BANQUE AVEC SYMBOLE YEN",NULL},
/* 1F4B5 */ { "BILLET DE BANQUE AVEC SYMBOLE DOLLAR",NULL},
/* 1F4B6 */ { "BILLET DE BANQUE AVEC SYMBOLE EURO",NULL},
/* 1F4B7 */ { "BILLET DE BANQUE AVEC SYMBOLE LIVRE",NULL},
/* 1F4B8 */ { "LIASSE D'ARGENT AILÉE",NULL},
/* 1F4B9 */ { "COURBE ASCENDANTE ET SYMBOLE YEN",NULL},
/* 1F4BA */ { "SIÈGE","	* doit désigner un siège réservé ou pour lequel un billet a été émis : avion, train ou théâtre"},
/* 1F4BB */ { "ORDINATEUR PERSONNEL","	x (ordinateur personnel ancien - 1F5B3)"},
/* 1F4BC */ { "PORTE-DOCUMENTS",NULL},
/* 1F4BD */ { "MINIDISQUE",NULL},
/* 1F4BE */ { "DISQUETTE","	x (disquette rigide noire - 1F5AA)"},
/* 1F4BF */ { "DISQUE OPTIQUE","	x (icône disque optique - 1F5B8)"},
/* 1F4C0 */ { "DVD","	= disque vidéo numérique"},
/* 1F4C1 */ { "DOSSIER","	x (répertoire - 1F5C0)"},
/* 1F4C2 */ { "DOSSIER OUVERT","	x (répertoire ouvert - 1F5C1)"},
/* 1F4C3 */ { "PAGE BOUCLÉE","	x (page - 1F5CF)"},
/* 1F4C4 */ { "PAGE AU RECTO","	x (document - 1F5CE)"},
/* 1F4C5 */ { "CALENDRIER","	x (bloc-notes à spirale - 1F5D2)"},
/* 1F4C6 */ { "ÉPHÉMÉRIDE","	x (bloc calendrier à spirale - 1F5D3)"},
/* 1F4C7 */ { "FICHIER","	x (séparateurs à index - 1F5C2)"},
/* 1F4C8 */ { "COURBE ASCENDANTE","	x (diagramme boursier - 1F5E0)"},
/* 1F4C9 */ { "COURBE DÉCROISSANTE",NULL},
/* 1F4CA */ { "HISTOGRAMME",NULL},
/* 1F4CB */ { "PRESSE-PAPIERS",NULL},
/* 1F4CC */ { "PUNAISE","	x (punaise noire - 1F588)"},
/* 1F4CD */ { "PUNAISE RONDE",NULL},
/* 1F4CE */ { "TROMBONE","	x (trombones entrelacés - 1F587)"},
/* 1F4CF */ { "RÈGLE DROITE",NULL},
/* 1F4D0 */ { "RÈGLE TRIANGULAIRE",NULL},
/* 1F4D1 */ { "SIGNETS À ONGLET",NULL},
/* 1F4D2 */ { "GRAND LIVRE",NULL},
/* 1F4D3 */ { "CARNET",NULL},
/* 1F4D4 */ { "CARNET AVEC COUVERTURE DÉCORATIVE",NULL},
/* 1F4D5 */ { "LIVRE FERMÉ",NULL},
/* 1F4D6 */ { "LIVRE OUVERT","	= lire le guide d'utilisation\n"
	"	* semblable à ISO/CEI 7000-0790 « Lire le guide d'utilisation »\n"
	"	x (livre - 1F56E)"},
/* 1F4D7 */ { "LIVRE VERT",NULL},
/* 1F4D8 */ { "LIVRE BLEU",NULL},
/* 1F4D9 */ { "LIVRE ORANGE",NULL},
/* 1F4DA */ { "LIVRES",NULL},
/* 1F4DB */ { "PORTE-NOM",NULL},
/* 1F4DC */ { "ROULEAU",NULL},
/* 1F4DD */ { "MÉMO",NULL},
/* 1F4DE */ { "RÉCEPTEUR TÉLÉPHONIQUE","	* habituellement orienté vers la droite, de manière à pouvoir placer une émoticône de visage à droite\n"
	"	x (récepteur téléphonique main gauche - 1F57B)\n"
	"	x (récepteur téléphonique main droite - 1F57D)"},
/* 1F4DF */ { "TÉLÉAVERTISSEUR",NULL},
/* 1F4E0 */ { "TÉLÉCOPIEUR","	x (symbole télécopie - 213B)\n"
	"	x (récepteur téléphonique avec page - 1F57C)\n"
	"	x (imprimante - 1F5A8)\n"
	"	x (icône télécopieur - 1F5B7)"},
/* 1F4E1 */ { "ANTENNE SATELLITE","	= indicateur de position, informations"},
/* 1F4E2 */ { "HAUT-PARLEUR D'ANNONCE PUBLIQUE",NULL},
/* 1F4E3 */ { "MÉGAPHONE D'ACCLAMATION","	x (mégaphone avec ondes sonores - 1F56C)"},
/* 1F4E4 */ { "BOÎTE D'ENVOI",NULL},
/* 1F4E5 */ { "BOÎTE DE RÉCEPTION",NULL},
/* 1F4E6 */ { "PAQUET-CADEAU","	x (cadeau emballé - 1F381)"},
/* 1F4E7 */ { "SYMBOLE DU COURRIEL","	* le glyphe peut présenter un E plutôt que le symbole @\n"
	"	x (enveloppe avec éclair - 1F584)"},
/* 1F4E8 */ { "ENVELOPPE DE RÉCEPTION","	x (enveloppe - 2709)"},
/* 1F4E9 */ { "ENVELOPPE SOUS UNE FLÈCHE VERS LE BAS","	* envoi de courrier\n"
	"	x (enveloppe volante - 1F585)"},
/* 1F4EA */ { "BOÎTE AUX LETTRES RURALE FERMÉE AVEC FANION BAISSÉ","	= boîte aux lettres vide"},
/* 1F4EB */ { "BOÎTE AUX LETTRES RURALE FERMÉE AVEC FANION LEVÉ","	= boîte aux lettres contenant du courrier"},
/* 1F4EC */ { "BOÎTE AUX LETTRES RURALE OUVERTE AVEC FANION LEVÉ",NULL},
/* 1F4ED */ { "BOÎTE AUX LETTRES RURALE OUVERTE AVEC FANION BAISSÉ",NULL},
/* 1F4EE */ { "BOÎTE AUX LETTRES PUBLIQUE",NULL},
/* 1F4EF */ { "COR POSTAL",NULL},
/* 1F4F0 */ { "JOURNAL","	x (journal enroulé - 1F5DE)"},
/* 1F4F1 */ { "TÉLÉPHONE MOBILE","	x (téléphone portable à clapet - 1F581)"},
/* 1F4F2 */ { "TÉLÉPHONE MOBILE PRÉCÉDÉ D'UNE FLÈCHE POINTANT VERS LA DROITE","	* faire un appel téléphonique"},
/* 1F4F3 */ { "MODE VIBREUR",NULL},
/* 1F4F4 */ { "TÉLÉPHONE MOBILE FERMÉ",NULL},
/* 1F4F5 */ { "TÉLÉPHONES MOBILES INTERDITS",NULL},
/* 1F4F6 */ { "SYMBOLE D'ANTENNE AVEC BARRES","	= réception cellulaire"},
/* 1F4F7 */ { "APPAREIL-PHOTO",NULL},
/* 1F4F8 */ { "APPAREIL-PHOTO AVEC FLASH",NULL},
/* 1F4F9 */ { "CAMÉRA VIDÉO","	= vidéo"},
/* 1F4FA */ { "TÉLÉVISION",NULL},
/* 1F4FB */ { "RADIO",NULL},
/* 1F4FC */ { "CASSETTE VIDÉO",NULL},
/* 1F4FD */ { "PROJECTEUR DE CINÉMA","	= films\n"
	"	x (cinéma - 1F3A6)"},
/* 1F4FE */ { "CHAÎNE STÉRÉO PORTATIVE","	= stéréo"},
/* 1F4FF */ { "CHAPELET",NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F5[] = {
/* 1F500 */ { "FLÈCHES VERS LA DROITE S'ENTRECROISANT","	= brouiller"},
/* 1F501 */ { "FLÈCHES VERS LA DROITE ET VERS LA GAUCHE SENS HORAIRE EN CERCLE OUVERT","	= répéter\n"
	"	x (symbole de recyclage universel noir - 267B)"},
/* 1F502 */ { "FLÈCHES VERS LA DROITE ET VERS LA GAUCHE SENS HORAIRE EN CERCLE OUVERT RECOUVERT D'UN UN CERCLÉ","	= répéter une entrée"},
/* 1F503 */ { "FLÈCHES VERS LA BAS ET VERS LE HAUT SENS HORAIRE EN CERCLE OUVERT","	= recharger\n"
	"	x (flèches semi-circulaires sens horaire gauche et droite - 1F5D8)"},
/* 1F504 */ { "FLÈCHES VERS LA BAS ET VERS LE HAUT SENS ANTIHORAIRE EN CERCLE OUVERT","	= recharger"},
/* 1F505 */ { "SYMBOLE DE LA FAIBLE INTENSITÉ",NULL},
/* 1F506 */ { "SYMBOLE DE LA FORTE INTENSITÉ","	x (soleil noir avec rayons - 2600)\n"
	"	x (soleil blanc avec rayons - 263C)\n"
	"	x (roue d'engrenage sans moyeu - 26ED)"},
/* 1F507 */ { "HAUT-PARLEUR AVEC TRAIT D'ANNULATION",NULL},
/* 1F508 */ { "HAUT-PARLEUR","	x (haut-parleur droit - 1F568)\n"
	"	x (mégaphone - 1F56B)"},
/* 1F509 */ { "HAUT-PARLEUR AVEC UNE CRÊTE D'ONDE SONORE",NULL},
/* 1F50A */ { "HAUT-PARLEUR AVEC TROIS CRÊTES D'ONDE SONORE","	= son"},
/* 1F50B */ { "PILE","	x (batterie faible - 1FAAB)"},
/* 1F50C */ { "FICHE ÉLECTRIQUE",NULL},
/* 1F50D */ { "LOUPE POINTANT VERS LA GAUCHE","	= rechercher\n"
	"	x (mégaphone avec ondes sonores - 1F56C)"},
/* 1F50E */ { "LOUPE POINTANT VERS LA DROITE","	= obtenir plus d'informations"},
/* 1F50F */ { "CADENAS SOUS STYLO PLUME","	= confidentialité"},
/* 1F510 */ { "CADENAS FERMÉ ET CLÉ","	= sécurisé"},
/* 1F511 */ { "CLÉ","	x (clé encadrée - 26BF)\n"
	"	x (clé ancienne - 1F5DD)"},
/* 1F512 */ { "CADENAS","	= cadenas verrouillé"},
/* 1F513 */ { "CADENAS OUVERT",NULL},
/* 1F514 */ { "CLOCHE","	x (symbole tibétain dril bou - 0FC4)\n"
	"	x (symbole sonnerie - 237E)\n"
	"	x (symbole pour sonnerie - 2407)\n"
	"	x (sonnerie de cloche - 1F56D)\n"
	"	x (symbole de cloche d'alarme - 1FBFA)"},
/* 1F515 */ { "CLOCHE AVEC TRAIT D'ANNULATION",NULL},
/* 1F516 */ { "SIGNET","	* indique un signet, pas une étiquette de prix\n"
	"	x (étiquette - 1F3F7)"},
/* 1F517 */ { "SYMBOLE LIEN",NULL},
/* 1F518 */ { "BOUTON RADIO","	x (opérateur point cerclé - 2299)\n"
	"	x (cercle blanc évidé - 25C9)\n"
	"	x (deux cercles concentriques - 25CE)"},
/* 1F519 */ { "BACK AVEC FLÈCHE VERS LA GAUCHE SUSCRITE","	x (page précédente - 2397)"},
/* 1F51A */ { "END AVEC FLÈCHE VERS LA GAUCHE SUSCRITE",NULL},
/* 1F51B */ { "ON ET POINT D'EXCLAMATION AVEC FLÈCHE GAUCHE-DROITE SUSCRITE",NULL},
/* 1F51C */ { "SOON AVEC FLÈCHE VERS LA DROITE SUSCRITE",NULL},
/* 1F51D */ { "TOP AVEC FLÈCHE VERS LE HAUT SUSCRITE","	= haut de la page"},
/* 1F51E */ { "SYMBOLE D'INTERDICTION AUX MOINS DE DIX-HUIT ANS",NULL},
/* 1F51F */ { "DESSUS DE TOUCHE DIX","	x (diacritique touche englobante - 20E3)"},
/* 1F520 */ { "SYMBOLE DE SAISIE DE LETTRES MAJUSCULES LATINES",NULL},
/* 1F521 */ { "SYMBOLE DE SAISIE DE LETTRES MINUSCULES LATINES",NULL},
/* 1F522 */ { "SYMBOLE DE SAISIE DE NOMBRES",NULL},
/* 1F523 */ { "SYMBOLE DE SAISIE DE SYMBOLES",NULL},
/* 1F524 */ { "SYMBOLE DE SAISIE DE LETTRES LATINES",NULL},
/* 1F525 */ { "FEU",NULL},
/* 1F526 */ { "LAMPE TORCHE","	= lampe de poche"},
/* 1F527 */ { "CLEF ANGLAISE",NULL},
/* 1F528 */ { "MARTEAU",NULL},
/* 1F529 */ { "ÉCROU ET BOULON",NULL},
/* 1F52A */ { "HOCHO","	= couteau de cuisine japonais\n"
	"	x (dague - 1F5E1)"},
/* 1F52B */ { "PISTOLET","	= arme de poing"},
/* 1F52C */ { "MICROSCOPE",NULL},
/* 1F52D */ { "TÉLESCOPE",NULL},
/* 1F52E */ { "BOULE DE CRISTAL",NULL},
/* 1F52F */ { "ÉTOILE À SIX BRANCHES AVEC POINT MÉDIAN","	x (étoile de david - 2721)"},
/* 1F530 */ { "SYMBOLE JAPONAIS DU DÉBUTANT",NULL},
/* 1F531 */ { "EMBLÈME DU TRIDENT",NULL},
/* 1F532 */ { "BOUTON CARRÉ NOIR",NULL},
/* 1F533 */ { "BOUTON CARRÉ BLANC",NULL},
/* 1F534 */ { "GRAND CERCLE ROUGE","	x (cercle noir pour enregistrement - 23FA)\n"
	"	x (cercle noir - 25CF)\n"
	"	x (grand cercle - 25EF)\n"
	"	x (grand cercle noir - 2B24)\n"
	"	x (grand cercle épais - 2B55)\n"
	"	x (grand cercle orange - 1F7E0)"},
/* 1F535 */ { "GRAND CERCLE BLEU",NULL},
/* 1F536 */ { "GRAND LOSANGE ORANGE","	x (losange noir - 25C6)"},
/* 1F537 */ { "GRAND LOSANGE BLEU",NULL},
/* 1F538 */ { "PETIT LOSANGE ORANGE","	x (petit losange noir - 2B29)"},
/* 1F539 */ { "PETIT LOSANGE BLEU",NULL},
/* 1F53A */ { "TRIANGLE ROUGE POINTANT VERS LE HAUT","	x (triangle noir pointant vers le haut - 25B2)"},
/* 1F53B */ { "TRIANGLE ROUGE POINTANT VERS LE BAS","	x (triangle noir pointant vers le bas - 25BC)"},
/* 1F53C */ { "PETIT TRIANGLE ROUGE POINTANT VERS LE HAUT","	= flèche de lecture vers le haut\n"
	"	x (petit triangle noir pointant vers le haut - 25B4)"},
/* 1F53D */ { "PETIT TRIANGLE ROUGE POINTANT VERS LE BAS","	= flèche de lecture vers le bas\n"
	"	x (petit triangle noir pointant vers le bas - 25BE)"},
/* 1F53E */ { "CERCLE BLANC OMBRÉ EN BAS À DROITE","	x (cercle blanc ombré - 274D)"},
/* 1F53F */ { "CERCLE BLANC OMBRÉ EN HAUT À DROITE",NULL},
/* 1F540 */ { "CROIX À POMMES CERCLÉE","	* symbole du typikon orthodoxe pour une fête majeure"},
/* 1F541 */ { "CROIX À POMMES ET À DEMI-CERCLE SOUSCRIT","	* symbole du typikon orthodoxe pour les vigiles"},
/* 1F542 */ { "CROIX À POMMES","	* symbole du typikon orthodoxe pour le Polyéléos\n"
	"	x (croix larmée - 2722)"},
/* 1F543 */ { "DEMI-CERCLE ENCOCHÉ À GAUCHE AVEC TROIS POINTS","	* symbole du typikon orthodoxe pour une fête ordinaire"},
/* 1F544 */ { "DEMI-CERCLE ENCOCHÉ À DROITE AVEC TROIS POINTS","	* symbole du typikon orthodoxe pour une fête ordinaire"},
/* 1F545 */ { "SYMBOLE MARQUANT LES PASSAGES DIFFICILES","	* symbole du typikon orthodoxe"},
/* 1F546 */ { "CROIX LATINE BLANCHE","	= contour de croix\n"
	"	x (croix latine blanche ombrée - 271E)"},
/* 1F547 */ { "CROIX LATINE ÉPAISSE",NULL},
/* 1F548 */ { "CROIX CELTE",NULL},
/* 1F549 */ { "SYMBOLE OM","	* symbole générique indépendant des polices dévanâgarî\n"
	"	x (om dévanâgarî - 0950)"},
/* 1F54A */ { "COLOMBE DE LA PAIX","	= paix"},
/* 1F54B */ { "KAABA",NULL},
/* 1F54C */ { "MOSQUÉE",NULL},
/* 1F54D */ { "SYNAGOGUE",NULL},
/* 1F54E */ { "CHANDELIER À NEUF BRANCHES","	= hanoukkia"},
/* 1F54F */ { "COUPE D'HYGIE","	x (bâton serpentaire d'esculape - 2695)"},
/* 1F550 */ { "CADRAN D'HORLOGE À UNE HEURE","	x (montre - 231A)\n"
	"	x (réveille-matin - 23F0)"},
/* 1F551 */ { "CADRAN D'HORLOGE À DEUX HEURES",NULL},
/* 1F552 */ { "CADRAN D'HORLOGE À TROIS HEURES",NULL},
/* 1F553 */ { "CADRAN D'HORLOGE À QUATRE HEURES",NULL},
/* 1F554 */ { "CADRAN D'HORLOGE À CINQ HEURES",NULL},
/* 1F555 */ { "CADRAN D'HORLOGE À SIX HEURES",NULL},
/* 1F556 */ { "CADRAN D'HORLOGE À SEPT HEURES",NULL},
/* 1F557 */ { "CADRAN D'HORLOGE À HUIT HEURES",NULL},
/* 1F558 */ { "CADRAN D'HORLOGE À NEUF HEURES",NULL},
/* 1F559 */ { "CADRAN D'HORLOGE À DIX HEURES",NULL},
/* 1F55A */ { "CADRAN D'HORLOGE À ONZE HEURES",NULL},
/* 1F55B */ { "CADRAN D'HORLOGE À DOUZE HEURES",NULL},
/* 1F55C */ { "CADRAN D'HORLOGE À UNE HEURE TRENTE",NULL},
/* 1F55D */ { "CADRAN D'HORLOGE À DEUX HEURES TRENTE",NULL},
/* 1F55E */ { "CADRAN D'HORLOGE À TROIS HEURES TRENTE",NULL},
/* 1F55F */ { "CADRAN D'HORLOGE À QUATRE HEURES TRENTE",NULL},
/* 1F560 */ { "CADRAN D'HORLOGE À CINQ HEURES TRENTE",NULL},
/* 1F561 */ { "CADRAN D'HORLOGE À SIX HEURES TRENTE",NULL},
/* 1F562 */ { "CADRAN D'HORLOGE À SEPT HEURES TRENTE",NULL},
/* 1F563 */ { "CADRAN D'HORLOGE À HUIT HEURES TRENTE",NULL},
/* 1F564 */ { "CADRAN D'HORLOGE À NEUF HEURES TRENTE",NULL},
/* 1F565 */ { "CADRAN D'HORLOGE À DIX HEURES TRENTE",NULL},
/* 1F566 */ { "CADRAN D'HORLOGE À ONZE HEURES TRENTE",NULL},
/* 1F567 */ { "CADRAN D'HORLOGE À DOUZE HEURES TRENTE",NULL},
/* 1F568 */ { "HAUT-PARLEUR DROIT","	x (haut-parleur - 1F508)"},
/* 1F569 */ { "HAUT-PARLEUR DROIT AVEC UNE CRÊTE D'ONDE SONORE",NULL},
/* 1F56A */ { "HAUT-PARLEUR DROIT AVEC TROIS CRÊTES D'ONDE SONORE",NULL},
/* 1F56B */ { "MÉGAPHONE","	= insonore\n"
	"	x (haut-parleur - 1F508)"},
/* 1F56C */ { "MÉGAPHONE AVEC ONDES SONORES","	= sonore\n"
	"	x (mégaphone d'acclamation - 1F4E3)\n"
	"	x (haut-parleur avec trois crêtes d'onde sonore - 1F50A)"},
/* 1F56D */ { "SONNERIE DE CLOCHE","	x (cloche - 1F514)"},
/* 1F56E */ { "LIVRE","	x (livre ouvert - 1F4D6)"},
/* 1F56F */ { "CHANDELLE",NULL},
/* 1F570 */ { "HORLOGE DE CHEMINÉE","	= horloge\n"
	"	x (réveille-matin - 23F0)"},
/* 1F571 */ { "TÊTE DE MORT NOIRE","	x (tête de mort - 2620)"},
/* 1F572 */ { "PIRATAGE INTERDIT",NULL},
/* 1F573 */ { "TROU",NULL},
/* 1F574 */ { "HOMME LÉVITANT EN COSTUME D'AFFAIRES","	= saut"},
/* 1F575 */ { "DÉTECTIVE OU ESPION","	= enquêter"},
/* 1F576 */ { "LUNETTES DE SOLEIL FONCÉES","	= décontracté"},
/* 1F577 */ { "ARAIGNÉE",NULL},
/* 1F578 */ { "TOILE D'ARAIGNÉE",NULL},
/* 1F579 */ { "MANETTE DE JEU",NULL},
/* 1F57A */ { "HOMME DANSANT","	* peut former une paire avec 1F483\n"
	"	x (danseuse - 1F483)"},
/* 1F57B */ { "RÉCEPTEUR TÉLÉPHONIQUE MAIN GAUCHE","	x (récepteur téléphonique - 1F4DE)"},
/* 1F57C */ { "RÉCEPTEUR TÉLÉPHONIQUE AVEC PAGE","	= télécopieur\n"
	"	x (télécopieur - 1F4E0)"},
/* 1F57D */ { "RÉCEPTEUR TÉLÉPHONIQUE MAIN DROITE",NULL},
/* 1F57E */ { "TÉLÉPHONE À CLAVIER BLANC","	x (téléphone blanc - 260F)"},
/* 1F57F */ { "TÉLÉPHONE À CLAVIER NOIR","	x (téléphone noir - 260E)"},
/* 1F580 */ { "TÉLÉPHONE PAR-DESSUS UN MODEM","	= modem"},
/* 1F581 */ { "TÉLÉPHONE PORTABLE À CLAPET","	= téléphone cellulaire, téléphone mobile\n"
	"	x (téléphone mobile - 1F4F1)"},
/* 1F582 */ { "DOS D'ENVELOPPE","	* contraste avec 2709, qui présente un cachet de cire\n"
	"	x (enveloppe - 2709)"},
/* 1F583 */ { "ENVELOPPE TIMBRÉE","	= courrier"},
/* 1F584 */ { "ENVELOPPE AVEC ÉCLAIR","	= courriel, courrier électronique\n"
	"	x (symbole du courriel - 1F4E7)"},
/* 1F585 */ { "ENVELOPPE VOLANTE","	= envoi d'un message\n"
	"	x (enveloppe sous une flèche vers le bas - 1F4E9)"},
/* 1F586 */ { "STYLO SUR ENVELOPPE TIMBRÉE",NULL},
/* 1F587 */ { "TROMBONES ENTRELACÉS","	= liens\n"
	"	x (trombone - 1F4CE)"},
/* 1F588 */ { "PUNAISE NOIRE","	= marqueur\n"
	"	x (punaise - 1F4CC)"},
/* 1F589 */ { "CRAYON VERS LE BAS À GAUCHE","	= crayon\n"
	"	x (crayon vers le bas à droite - 270E)"},
/* 1F58A */ { "STYLO À BILLE VERS LE BAS À GAUCHE","	= stylo à bille"},
/* 1F58B */ { "STYLO PLUME VERS LE BAS À GAUCHE","	= stylo plume, stylo à encre\n"
	"	x (bec de plume blanc - 2711)"},
/* 1F58C */ { "PINCEAU VERS LE BAS À GAUCHE","	= pinceau"},
/* 1F58D */ { "CRAYON DE COULEUR VERS LE BAS À GAUCHE","	= crayon de couleur"},
/* 1F58E */ { "MAIN GAUCHE ÉCRIVANT","	x (main écrivant - 270D)"},
/* 1F58F */ { "SIGNE OK DE LA MAIN TOURNÉ","	x (signe ok de la main - 1F44C)"},
/* 1F590 */ { "MAIN LEVÉE AVEC DOIGTS ÉCARTÉS","	= halte\n"
	"	x (main levée - 270B)"},
/* 1F591 */ { "MAIN LEVÉE AVEC DOIGTS ÉCARTÉS RÉFLÉCHIE",NULL},
/* 1F592 */ { "SIGNE DU POUCE VERS LE HAUT RÉFLÉCHI","	x (signe du pouce vers le haut - 1F44D)"},
/* 1F593 */ { "SIGNE DU POUCE VERS LE BAS RÉFLÉCHI","	x (signe du pouce vers le bas - 1F44E)"},
/* 1F594 */ { "MAIN DE DOS FAISANT LE SIGNE DE LA VICTOIRE","	x (main de la victoire - 270C)"},
/* 1F595 */ { "MAIN DE DOS AVEC MAJEUR POINTÉ",NULL},
/* 1F596 */ { "MAIN LEVÉE AVEC ÉCART ENTRE LE MAJEUR ET L'ANNULAIRE","	= salut vulcain"},
/* 1F597 */ { "INDEX DE LA MAIN GAUCHE BLANC POINTANT VERS LE BAS","	x (index blanc pointant vers le bas - 261F)\n"
	"	x (index de revers de main blanc pointant vers le bas - 1F447)"},
/* 1F598 */ { "INDEX BLANC POINTANT VERS LA GAUCHE COUCHÉ","	x (index blanc pointant vers la gauche - 261C)"},
/* 1F599 */ { "INDEX BLANC POINTANT VERS LA DROITE COUCHÉ","	x (index blanc pointant vers la droite - 261E)"},
/* 1F59A */ { "INDEX NOIR POINTANT VERS LA GAUCHE COUCHÉ",NULL},
/* 1F59B */ { "INDEX NOIR POINTANT VERS LA DROITE COUCHÉ",NULL},
/* 1F59C */ { "INDEX DE REVERS DE MAIN NOIR POINTANT VERS LA GAUCHE","	x (index de revers de main blanc pointant vers la gauche - 1F448)"},
/* 1F59D */ { "INDEX DE REVERS DE MAIN NOIR POINTANT VERS LA DROITE","	x (index de revers de main blanc pointant vers la droite - 1F449)"},
/* 1F59E */ { "INDEX BLANC POINTANT VERS LE HAUT COUCHÉ","	x (index blanc pointant vers le haut - 261D)"},
/* 1F59F */ { "INDEX BLANC POINTANT VERS LE BAS COUCHÉ","	x (index blanc pointant vers le bas - 261F)"},
/* 1F5A0 */ { "INDEX NOIR POINTANT VERS LE HAUT COUCHÉ",NULL},
/* 1F5A1 */ { "INDEX NOIR POINTANT VERS LE BAS COUCHÉ",NULL},
/* 1F5A2 */ { "INDEX DE REVERS DE MAIN NOIR POINTANT VERS LE HAUT","	x (index de revers de main blanc pointant vers le haut - 1F446)"},
/* 1F5A3 */ { "INDEX DE REVERS DE MAIN NOIR POINTANT VERS LE BAS","	x (index de revers de main blanc pointant vers le bas - 1F447)"},
/* 1F5A4 */ { "CŒUR NOIR","	* représenté en noir, sans équivoque, dans toutes les variantes\n"
	"	x (enseigne de cœur noire - 2665)\n"
	"	x (cœur blanc - 1F90D)"},
/* 1F5A5 */ { "ORDINATEUR DE BUREAU","	= tour"},
/* 1F5A6 */ { "CLAVIER ET SOURIS","	x (clavier - 2328)"},
/* 1F5A7 */ { "TROIS ORDINATEURS EN RÉSEAU","	= réseau d'ordinateurs"},
/* 1F5A8 */ { "IMPRIMANTE","	x (télécopieur - 1F4E0)"},
/* 1F5A9 */ { "CALCULETTE","	= calculatrice"},
/* 1F5AA */ { "DISQUETTE RIGIDE NOIRE","	= disquette\n"
	"	x (disquette - 1F4BE)"},
/* 1F5AB */ { "DISQUETTE RIGIDE BLANCHE",NULL},
/* 1F5AC */ { "DISQUETTE SOUPLE",NULL},
/* 1F5AD */ { "CARTOUCHE À BANDE",NULL},
/* 1F5AE */ { "CLAVIER FILAIRE","	= clavier\n"
	"	x (clavier - 2328)"},
/* 1F5AF */ { "SOURIS À UN BOUTON",NULL},
/* 1F5B0 */ { "SOURIS À DEUX BOUTONS",NULL},
/* 1F5B1 */ { "SOURIS À TROIS BOUTONS",NULL},
/* 1F5B2 */ { "BOULE DE COMMANDE",NULL},
/* 1F5B3 */ { "ORDINATEUR PERSONNEL ANCIEN","	= ordinateur personnel, PC\n"
	"	x (ordinateur personnel - 1F4BB)"},
/* 1F5B4 */ { "DISQUE DUR",NULL},
/* 1F5B5 */ { "ÉCRAN","	= moniteur\n"
	"	x (diacritique écran englobant - 20E2)"},
/* 1F5B6 */ { "ICÔNE IMPRIMANTE","	x (imprimante - 1F5A8)"},
/* 1F5B7 */ { "ICÔNE TÉLÉCOPIEUR","	x (télécopieur - 1F4E0)"},
/* 1F5B8 */ { "ICÔNE DISQUE OPTIQUE","	= disque compact\n"
	"	x (disque optique - 1F4BF)"},
/* 1F5B9 */ { "DOCUMENT COMPORTANT DU TEXTE",NULL},
/* 1F5BA */ { "DOCUMENT COMPORTANT DU TEXTE ET DES IMAGES",NULL},
/* 1F5BB */ { "DOCUMENT COMPORTANT DES IMAGES","	= document graphique"},
/* 1F5BC */ { "CADRE AVEC IMAGE","	= art"},
/* 1F5BD */ { "CADRE AVEC TUILES","	= cadres"},
/* 1F5BE */ { "CADRE AVEC X","	= pas de cadres, pas d'image"},
/* 1F5BF */ { "DOSSIER NOIR",NULL},
/* 1F5C0 */ { "RÉPERTOIRE","	= dossier\n"
	"	x (dossier - 1F4C1)\n"
	"	x (moitié gauche de dossier - 1FBB9)"},
/* 1F5C1 */ { "RÉPERTOIRE OUVERT","	x (dossier ouvert - 1F4C2)"},
/* 1F5C2 */ { "SÉPARATEURS À INDEX","	x (fichier - 1F4C7)"},
/* 1F5C3 */ { "BOÎTE DE FICHES","	= archives"},
/* 1F5C4 */ { "CLASSEUR",NULL},
/* 1F5C5 */ { "NOTE VIDE",NULL},
/* 1F5C6 */ { "PAGE DE NOTES VIDE",NULL},
/* 1F5C7 */ { "BLOC-NOTES VIDE",NULL},
/* 1F5C8 */ { "NOTE",NULL},
/* 1F5C9 */ { "PAGE DE NOTES",NULL},
/* 1F5CA */ { "BLOC-NOTES",NULL},
/* 1F5CB */ { "DOCUMENT VIDE",NULL},
/* 1F5CC */ { "PAGE VIDE",NULL},
/* 1F5CD */ { "PAGES VIDES",NULL},
/* 1F5CE */ { "DOCUMENT","	x (page au recto - 1F4C4)"},
/* 1F5CF */ { "PAGE","	x (page bouclée - 1F4C3)"},
/* 1F5D0 */ { "PAGES",NULL},
/* 1F5D1 */ { "CORBEILLE","	= poubelle"},
/* 1F5D2 */ { "BLOC-NOTES À SPIRALE","	= note, calendrier vide\n"
	"	x (calendrier - 1F4C5)"},
/* 1F5D3 */ { "BLOC CALENDRIER À SPIRALE","	= calendrier, jour 1\n"
	"	x (éphéméride - 1F4C6)"},
/* 1F5D4 */ { "FENÊTRE DU BUREAU",NULL},
/* 1F5D5 */ { "MINIMISER",NULL},
/* 1F5D6 */ { "MAXIMISER",NULL},
/* 1F5D7 */ { "SUPERPOSER","	= superposition de fenêtres décalées"},
/* 1F5D8 */ { "FLÈCHES SEMI-CIRCULAIRES SENS HORAIRE GAUCHE ET DROITE","	= rafraîchir\n"
	"	x (flèches vers la bas et vers le haut sens horaire en cercle ouvert - 1F503)"},
/* 1F5D9 */ { "X D'ANNULATION","	= fermer\n"
	"	x (signe en forme de croix - 274C)"},
/* 1F5DA */ { "SYMBOLE D'AUGMENTATION DE TAILLE DE POLICE",NULL},
/* 1F5DB */ { "SYMBOLE DE DIMINUTION DE TAILLE DE POLICE",NULL},
/* 1F5DC */ { "COMPRESSION","	* le symbole dépeint une presse à main enserrant une boîte"},
/* 1F5DD */ { "CLÉ ANCIENNE","	= chiffrement, cryptage\n"
	"	x (clé - 1F511)"},
/* 1F5DE */ { "JOURNAL ENROULÉ","	= informations\n"
	"	x (journal - 1F4F0)"},
/* 1F5DF */ { "PAGE AVEC TEXTE ENCERCLÉ","	= petite annonce"},
/* 1F5E0 */ { "DIAGRAMME BOURSIER","	= finance\n"
	"	x (courbe ascendante - 1F4C8)"},
/* 1F5E1 */ { "DAGUE","	= classé pour la violence\n"
	"	= haine\n"
	"	x (hocho - 1F52A)"},
/* 1F5E2 */ { "LÈVRES","	= classé pour le sexe\n"
	"	= baiser\n"
	"	x (marque de baiser - 1F48B)\n"
	"	x (lèvre mordue - 1FAE6)"},
/* 1F5E3 */ { "SILHOUETTE PARLANTE","	= classé pour les écarts de langage"},
/* 1F5E4 */ { "TROIS RAYONS VERS LE HAUT",NULL},
/* 1F5E5 */ { "TROIS RAYONS VERS LE BAS",NULL},
/* 1F5E6 */ { "TROIS RAYONS VERS LA GAUCHE","	x (trois lignes convergentes vers la droite - 269E)"},
/* 1F5E7 */ { "TROIS RAYONS VERS LA DROITE","	x (trois lignes convergentes vers la gauche - 269F)"},
/* 1F5E8 */ { "PHYLACTÈRE À GAUCHE",NULL},
/* 1F5E9 */ { "PHYLACTÈRE À DROITE",NULL},
/* 1F5EA */ { "DEUX PHYLACTÈRES","	= conversation, bavardage"},
/* 1F5EB */ { "TROIS PHYLACTÈRES","	= conférence"},
/* 1F5EC */ { "PHYLACTÈRE DE RÉFLEXION À GAUCHE",NULL},
/* 1F5ED */ { "PHYLACTÈRE DE RÉFLEXION À DROITE","	x (phylactère de pensée - 1F4AD)"},
/* 1F5EE */ { "PHYLACTÈRE DE COLÈRE À GAUCHE","	= cri à gauche"},
/* 1F5EF */ { "PHYLACTÈRE DE COLÈRE À DROITE","	= cri à droite"},
/* 1F5F0 */ { "PHYLACTÈRE D'HUMEUR","	= nouveau\n"
	"	x (symbole de la collision - 1F4A5)"},
/* 1F5F1 */ { "PHYLACTÈRE D'HUMEUR DE FOUDRE","	= actualisé"},
/* 1F5F2 */ { "HUMEUR DE FOUDRE","	= éclair\n"
	"	x (signal de haute tension - 26A1)"},
/* 1F5F3 */ { "URNE AVEC BULLETIN","	= vote\n"
	"	x (case de bulletin marquée d'un x - 2612)"},
/* 1F5F4 */ { "X CURSIF DE VOTE","	= marque en x\n"
	"	x (x de vote - 2717)"},
/* 1F5F5 */ { "CASE DE BULLETIN MARQUÉE D'UN X CURSIF","	x (case de bulletin marquée d'un x - 2612)"},
/* 1F5F6 */ { "X CURSIF DE VOTE GRAS","	x (x de vote épais - 2718)"},
/* 1F5F7 */ { "CASE DE BULLETIN MARQUÉE D'UN X CURSIF GRAS",NULL},
/* 1F5F8 */ { "COCHE MINCE","	= coche\n"
	"	x (coche - 2713)"},
/* 1F5F9 */ { "CASE DE BULLETIN MARQUÉE D'UNE COCHE GRASSE","	x (case de bulletin marquée d'une coche - 2611)"},
/* 1F5FA */ { "PLANISPHÈRE",NULL},
/* 1F5FB */ { "MONT FUJI",NULL},
/* 1F5FC */ { "TOUR DE TOKYO",NULL},
/* 1F5FD */ { "STATUE DE LA LIBERTÉ",NULL},
/* 1F5FE */ { "SILHOUETTE DU JAPON",NULL},
/* 1F5FF */ { "MOYAI","	* statue de pierre japonaise, semblable aux statues monumentales (moaï) de l'île de Pâques"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F6[] = {
/* 1F600 */ { "VISAGE RIEUR",NULL},
/* 1F601 */ { "VISAGE RIEUR AUX YEUX RÉJOUIS",NULL},
/* 1F602 */ { "VISAGE AVEC LARMES DE JOIE",NULL},
/* 1F603 */ { "VISAGE SOURIANT LA BOUCHE OUVERTE","	x (visage blanc souriant - 263A)"},
/* 1F604 */ { "VISAGE SOURIANT LA BOUCHE OUVERTE ET LES YEUX RÉJOUIS",NULL},
/* 1F605 */ { "VISAGE SOURIANT LA BOUCHE OUVERTE AVEC SUEURS FROIDES",NULL},
/* 1F606 */ { "VISAGE SOURIANT LA BOUCHE OUVERTE ET LES YEUX TRÈS FERMÉS",NULL},
/* 1F607 */ { "VISAGE SOURIANT AURÉOLÉ",NULL},
/* 1F608 */ { "VISAGE CORNU SOURIANT","	* généralement représenté avec un sourire malicieux, version contraire de 1F47F"},
/* 1F609 */ { "VISAGE FAISANT UN CLIN D'ŒIL",NULL},
/* 1F60A */ { "VISAGE SOURIANT AUX YEUX RÉJOUIS",NULL},
/* 1F60B */ { "VISAGE SAVOURANT UNE NOURRITURE DÉLICIEUSE",NULL},
/* 1F60C */ { "VISAGE SOULAGÉ","	* indique le soulagement, pas le sommeil"},
/* 1F60D */ { "VISAGE SOURIANT AUX YEUX EN FORME DE CŒURS",NULL},
/* 1F60E */ { "VISAGE SOURIANT AVEC LUNETTES DE SOLEIL",NULL},
/* 1F60F */ { "VISAGE AVEC SOURIRE NARQUOIS",NULL},
/* 1F610 */ { "VISAGE NEUTRE","	* s'utilise pour le vent d'ouest sur certaines tuiles de majong"},
/* 1F611 */ { "VISAGE SANS EXPRESSION",NULL},
/* 1F612 */ { "VISAGE CONTRARIÉ",NULL},
/* 1F613 */ { "VISAGE AVEC SUEURS FROIDES",NULL},
/* 1F614 */ { "VISAGE SONGEUR",NULL},
/* 1F615 */ { "VISAGE CONFUS",NULL},
/* 1F616 */ { "VISAGE DÉCONCERTÉ",NULL},
/* 1F617 */ { "VISAGE EMBRASSANT",NULL},
/* 1F618 */ { "VISAGE LANÇANT UN BAISER",NULL},
/* 1F619 */ { "VISAGE EMBRASSANT AUX YEUX RÉJOUIS",NULL},
/* 1F61A */ { "VISAGE EMBRASSANT LES YEUX FERMÉS",NULL},
/* 1F61B */ { "VISAGE TIRANT LA LANGUE",NULL},
/* 1F61C */ { "VISAGE FAISANT UN CLIN D'ŒIL ET TIRANT LA LANGUE","	* en plaisantant"},
/* 1F61D */ { "VISAGE TIRANT LA LANGUE LES YEUX TRÈS FERMÉS","	* en plaisantant"},
/* 1F61E */ { "VISAGE DÉÇU","	x (visage blanc grimaçant - 2639)"},
/* 1F61F */ { "VISAGE INQUIET",NULL},
/* 1F620 */ { "VISAGE FÂCHÉ",NULL},
/* 1F621 */ { "VISAGE FAISANT LA MOUE","	* dépeint la moue plutôt que la colère"},
/* 1F622 */ { "VISAGE EN PLEURS",NULL},
/* 1F623 */ { "VISAGE TENACE",NULL},
/* 1F624 */ { "VISAGE À L'AIR DE TRIOMPHE","	* indique le triomphe, pas la colère"},
/* 1F625 */ { "VISAGE DÉÇU MAIS SOULAGÉ",NULL},
/* 1F626 */ { "VISAGE RENFROGNÉ À LA BOUCHE OUVERTE","	* froncé, pas choqué ou surpris"},
/* 1F627 */ { "VISAGE ANGOISSÉ",NULL},
/* 1F628 */ { "VISAGE CRAINTIF",NULL},
/* 1F629 */ { "VISAGE LAS",NULL},
/* 1F62A */ { "VISAGE ENDORMI",NULL},
/* 1F62B */ { "VISAGE FATIGUÉ",NULL},
/* 1F62C */ { "VISAGE GRIMAÇANT","	* ne devrait pas être représenté avec une bouche en forme de fermeture à glissière\n"
	"	x (visage à la bouche zippée - 1F910)"},
/* 1F62D */ { "VISAGE PLEURANT BRUYAMMENT",NULL},
/* 1F62E */ { "VISAGE À LA BOUCHE OUVERTE",NULL},
/* 1F62F */ { "VISAGE FEUTRÉ",NULL},
/* 1F630 */ { "VISAGE À LA BOUCHE OUVERTE AVEC SUEURS FROIDES",NULL},
/* 1F631 */ { "VISAGE HURLANT DE PEUR",NULL},
/* 1F632 */ { "VISAGE ÉTONNÉ",NULL},
/* 1F633 */ { "VISAGE ROUGISSANT","	* embarrassé"},
/* 1F634 */ { "VISAGE DORMANT",NULL},
/* 1F635 */ { "VISAGE PRIS DE VERTIGE",NULL},
/* 1F636 */ { "VISAGE SANS BOUCHE","	x (cercle blanc avec deux points - 2687)"},
/* 1F637 */ { "VISAGE AVEC MASQUE CHIRURGICAL",NULL},
/* 1F638 */ { "FACE DE CHAT RIEUR AUX YEUX RÉJOUIS",NULL},
/* 1F639 */ { "FACE DE CHAT AVEC LARMES DE JOIE",NULL},
/* 1F63A */ { "FACE DE CHAT SOURIANT LA BOUCHE OUVERTE",NULL},
/* 1F63B */ { "FACE DE CHAT SOURIANT LES YEUX EN FORME DE CŒURS",NULL},
/* 1F63C */ { "FACE DE CHAT AVEC SOURIRE SARCASTIQUE",NULL},
/* 1F63D */ { "FACE DE CHAT EMBRASSANT LES YEUX FERMÉS",NULL},
/* 1F63E */ { "FACE DE CHAT FAISANT LA MOUE","	* dépeint la moue plutôt que la colère"},
/* 1F63F */ { "FACE DE CHAT EN PLEURS",NULL},
/* 1F640 */ { "FACE DE CHAT LASSE","	* indique la fatigue, pas l'effroi"},
/* 1F641 */ { "VISAGE LÉGÈREMENT GRIMAÇANT","	x (visage blanc grimaçant - 2639)"},
/* 1F642 */ { "VISAGE LÉGÈREMENT SOURIANT","	x (visage blanc souriant - 263A)"},
/* 1F643 */ { "VISAGE À L'ENVERS",NULL},
/* 1F644 */ { "VISAGE AUX YEUX QUI ROULENT",NULL},
/* 1F645 */ { "VISAGE AVEC SIGNE DE DÉSAPPROBATION","	* transmet l'idée d'un désaccord, pas la colère ; le contraire de 1F646"},
/* 1F646 */ { "VISAGE AVEC SIGNE D'APPROBATION",NULL},
/* 1F647 */ { "PERSONNE PROFONDÉMENT INCLINÉE","	* la représentation commune se réfère au dogeza japonais"},
/* 1F648 */ { "SINGE DE LA SAGESSE NE VOYANT RIEN DE MAL",NULL},
/* 1F649 */ { "SINGE DE LA SAGESSE N'ENTENDANT RIEN DE MAL",NULL},
/* 1F64A */ { "SINGE DE LA SAGESSE NE DISANT RIEN DE MAL",NULL},
/* 1F64B */ { "PERSONNE HEUREUSE UNE MAIN EN L'AIR",NULL},
/* 1F64C */ { "PERSONNE EN FÊTE LEVANT LES DEUX MAINS","	= « Banzai ! »"},
/* 1F64D */ { "PERSONNE FRONÇANT LES SOURCILS",NULL},
/* 1F64E */ { "PERSONNE FAISANT LA MOUE","	* dépeint la moue plutôt que la colère"},
/* 1F64F */ { "PERSONNE LES MAINS JOINTES","	* peut désigner le chagrin, la peine ou le regret\n"
	"	* peut sussi désigner l'imploration, la prière, la prosternation ou le remerciement"},
/* 1F650 */ { "FEUILLE NORD-OUEST",NULL},
/* 1F651 */ { "FEUILLE SUD-OUEST",NULL},
/* 1F652 */ { "FEUILLE NORD-EST",NULL},
/* 1F653 */ { "FEUILLE SUD-EST",NULL},
/* 1F654 */ { "FEUILLE NORD-OUEST CULBUTÉE",NULL},
/* 1F655 */ { "FEUILLE SUD-OUEST CULBUTÉE",NULL},
/* 1F656 */ { "FEUILLE NORD-EST CULBUTÉE",NULL},
/* 1F657 */ { "FEUILLE SUD-EST CULBUTÉE",NULL},
/* 1F658 */ { "FEUILLE DE VIGNE NORD-OUEST",NULL},
/* 1F659 */ { "FEUILLE DE VIGNE SUD-OUEST","	x (cœur floral couché à droite - 2619)"},
/* 1F65A */ { "FEUILLE DE VIGNE NORD-EST",NULL},
/* 1F65B */ { "FEUILLE DE VIGNE SUD-EST","	x (cœur floral couché - 2767)"},
/* 1F65C */ { "FEUILLE DE VIGNE NORD-OUEST AU TRAIT FORT",NULL},
/* 1F65D */ { "FEUILLE DE VIGNE SUD-OUEST AU TRAIT FORT",NULL},
/* 1F65E */ { "FEUILLE DE VIGNE NORD-EST AU TRAIT FORT",NULL},
/* 1F65F */ { "FEUILLE DE VIGNE SUD-EST AU TRAIT FORT",NULL},
/* 1F660 */ { "BOURGEON NORD-OUEST",NULL},
/* 1F661 */ { "BOURGEON SUD-OUEST",NULL},
/* 1F662 */ { "BOURGEON NORD-EST",NULL},
/* 1F663 */ { "BOURGEON SUD-EST",NULL},
/* 1F664 */ { "BOURGEON NORD-OUEST AU TRAIT FORT",NULL},
/* 1F665 */ { "BOURGEON SUD-OUEST AU TRAIT FORT",NULL},
/* 1F666 */ { "BOURGEON NORD-EST AU TRAIT FORT",NULL},
/* 1F667 */ { "BOURGEON SUD-EST AU TRAIT FORT",NULL},
/* 1F668 */ { "ORNEMENT CARRÉ DE COURTEPOINTE CREUX",NULL},
/* 1F669 */ { "ORNEMENT CARRÉ DE COURTEPOINTE CREUX INSCRIT DANS UN CARRÉ NOIR",NULL},
/* 1F66A */ { "ORNEMENT CARRÉ DE COURTEPOINTE PLEIN","	= ornement de quadruple nœud"},
/* 1F66B */ { "ORNEMENT CARRÉ DE COURTEPOINTE PLEIN INSCRIT DANS UN CARRÉ NOIR","	= ornement de quadruple nœud noir au blanc"},
/* 1F66C */ { "FUSÉE VERS LA GAUCHE","	x (fusée - 1F680)"},
/* 1F66D */ { "FUSÉE VERS LE HAUT",NULL},
/* 1F66E */ { "FUSÉE VERS LA DROITE",NULL},
/* 1F66F */ { "FUSÉE VERS LE BAS",NULL},
/* 1F670 */ { "ORNEMENT LIGATURE ET CURSIF","	= perluète italique minuscule\n"
	"	x (note tironienne et - 204A)"},
/* 1F671 */ { "ORNEMENT LIGATURE ET CURSIF AU TRAIT FORT",NULL},
/* 1F672 */ { "ORNEMENT LIGATURE ET OUVERT",NULL},
/* 1F673 */ { "ORNEMENT LIGATURE ET OUVERT AU TRAIT FORT",NULL},
/* 1F674 */ { "ORNEMENT PERLUÈTE AU TRAIT FORT","	x (perluète - 0026)"},
/* 1F675 */ { "ORNEMENT PERLUÈTE À PARAPHE","	= perluète italique"},
/* 1F676 */ { "GUILLEMET DE FANTAISIE EN FORME DE GROSSE VIRGULE DOUBLE CULBUTÉE SANS EMPATTEMENT","	x (guillemet de fantaisie en forme de grosse virgule double culbutée - 275D)"},
/* 1F677 */ { "GUILLEMET DE FANTAISIE EN FORME DE GROSSE VIRGULE DOUBLE SANS EMPATTEMENT","	x (guillemet de fantaisie en forme de grosse virgule double - 275E)"},
/* 1F678 */ { "GUILLEMET INFÉRIEUR DE FANTAISIE EN FORME DE GROSSE VIRGULE DOUBLE SANS EMPATTEMENT","	x (guillemet inférieur de fantaisie en forme de grosse virgule double - 2760)"},
/* 1F679 */ { "ORNEMENT POINT EXCLARROGATIF AU TRAIT FORT","	x (point exclarrogatif - 203D)"},
/* 1F67A */ { "ORNEMENT POINT EXCLARROGATIF SANS EMPATTEMENT",NULL},
/* 1F67B */ { "ORNEMENT POINT EXCLARROGATIF SANS EMPATTEMENT AU TRAIT FORT",NULL},
/* 1F67C */ { "BARRE OBLIQUE TRÈS ÉPAISSE",NULL},
/* 1F67D */ { "BARRE OBLIQUE INVERSÉE TRÈS ÉPAISSE",NULL},
/* 1F67E */ { "DAMIER","	x (quartiers supérieur droit et inférieur gauche - 259E)"},
/* 1F67F */ { "DAMIER INVERSÉ","	x (quartiers supérieur gauche et inférieur droit - 259A)"},
/* 1F680 */ { "FUSÉE","	x (fusée vers la gauche - 1F66C)"},
/* 1F681 */ { "HÉLICOPTÈRE","	x (avion - 2708)"},
/* 1F682 */ { "LOCOMOTIVE À VAPEUR","	x (locomotive diesel - 1F6F2)"},
/* 1F683 */ { "WAGON DE CHEMIN DE FER",NULL},
/* 1F684 */ { "TRAIN À GRANDE VITESSE",NULL},
/* 1F685 */ { "TRAIN À GRANDE VITESSE AU NEZ ROND",NULL},
/* 1F686 */ { "TRAIN","	= train interrégional, train interurbain"},
/* 1F687 */ { "MÉTRO","	= train du chemin de fer métropolitain"},
/* 1F688 */ { "TRAIN LÉGER",NULL},
/* 1F689 */ { "GARE","	= gare de chemin de fer, station de métro"},
/* 1F68A */ { "TRAM",NULL},
/* 1F68B */ { "WAGON DE TRAM",NULL},
/* 1F68C */ { "AUTOBUS",NULL},
/* 1F68D */ { "AUTOBUS À L'APPROCHE",NULL},
/* 1F68E */ { "TROLLEYBUS",NULL},
/* 1F68F */ { "ARRÊT D'AUTOBUS",NULL},
/* 1F690 */ { "MINIBUS",NULL},
/* 1F691 */ { "AMBULANCE",NULL},
/* 1F692 */ { "CAMION DE POMPIERS","	x (camion de pompiers à l'approche - 1F6F1)"},
/* 1F693 */ { "VOITURE DE POLICE",NULL},
/* 1F694 */ { "VOITURE DE POLICE À L'APPROCHE",NULL},
/* 1F695 */ { "TAXI",NULL},
/* 1F696 */ { "TAXI À L'APPROCHE",NULL},
/* 1F697 */ { "AUTOMOBILE",NULL},
/* 1F698 */ { "AUTOMOBILE À L'APPROCHE",NULL},
/* 1F699 */ { "VÉHICULE RÉCRÉATIF",NULL},
/* 1F69A */ { "CAMION DE LIVRAISON","	x (camion noir - 26DF)"},
/* 1F69B */ { "CAMION ARTICULÉ",NULL},
/* 1F69C */ { "TRACTEUR",NULL},
/* 1F69D */ { "MONORAIL",NULL},
/* 1F69E */ { "TRAIN DE MONTAGNE",NULL},
/* 1F69F */ { "TRAIN SUSPENDU",NULL},
/* 1F6A0 */ { "TÉLÉPHÉRIQUE",NULL},
/* 1F6A1 */ { "TÉLÉCABINE",NULL},
/* 1F6A2 */ { "NAVIRE","	= croisière\n"
	"	x (bac - 26F4)\n"
	"	x (paquebot - 1F6F3)"},
/* 1F6A3 */ { "CANOT À RAMES","	= barque\n"
	"	x (voilier - 26F5)"},
/* 1F6A4 */ { "HORS-BORD","	x (bateau à moteur - 1F6E5)"},
/* 1F6A5 */ { "FEU DE CIRCULATION HORIZONTAL",NULL},
/* 1F6A6 */ { "FEU DE CIRCULATION VERTICAL",NULL},
/* 1F6A7 */ { "PANNEAU INDICATEUR DE CONSTRUCTION","	x (pioche - 26CF)\n"
	"	x (construction d'immeuble - 1F3D7)"},
/* 1F6A8 */ { "GYROPHARE DE VOITURE DE POLICE",NULL},
/* 1F6A9 */ { "FANION TRIANGULAIRE DE LOCALISATION","	= information d'emplacement\n"
	"	x (fanion dans un trou - 26F3)\n"
	"	x (fanion blanc - 1F3F1)"},
/* 1F6AA */ { "PORTE",NULL},
/* 1F6AB */ { "PANNEAU ENTRÉE INTERDITE","	x (diacritique cercle englobant et barre oblique inversée - 20E0)\n"
	"	x (entrée interdite - 26D4)\n"
	"	x (symbole d'interdiction - 1F6C7)"},
/* 1F6AC */ { "SYMBOLE FUMEURS",NULL},
/* 1F6AD */ { "SYMBOLE INTERDICTION DE FUMER",NULL},
/* 1F6AE */ { "SYMBOLE INVITANT À JETER LES DÉCHETS DANS LA POUBELLE",NULL},
/* 1F6AF */ { "SYMBOLE INTERDICTION DE JETER LES DÉCHETS",NULL},
/* 1F6B0 */ { "SYMBOLE EAU POTABLE",NULL},
/* 1F6B1 */ { "SYMBOLE EAU NON POTABLE",NULL},
/* 1F6B2 */ { "BICYCLETTE",NULL},
/* 1F6B3 */ { "BICYCLETTES INTERDITES",NULL},
/* 1F6B4 */ { "CYCLISTE",NULL},
/* 1F6B5 */ { "CYCLISTE DE MONTAGNE",NULL},
/* 1F6B6 */ { "PIÉTON","	= marche, randonnée"},
/* 1F6B7 */ { "PIÉTONS INTERDITS",NULL},
/* 1F6B8 */ { "PASSAGE D'ENFANTS",NULL},
/* 1F6B9 */ { "SYMBOLE HOMMES","	= toilettes pour hommes\n"
	"	x (bonhomme allumette - 1FBC5)"},
/* 1F6BA */ { "SYMBOLE FEMMES","	= toilettes pour femmes\n"
	"	x (bonhomme allumette avec robe - 1FBC9)"},
/* 1F6BB */ { "SALLE DE TOILETTES","	= toilettes unisexe\n"
	"	x (homme et femme se tenant par la main - 1F46B)"},
/* 1F6BC */ { "SYMBOLE BÉBÉ","	= bébé à bord, salle à langer"},
/* 1F6BD */ { "TOILETTES",NULL},
/* 1F6BE */ { "W-C","	x (wc encadré - 1F14F)\n"
	"	x (wc encadré noir au blanc - 1F18F)"},
/* 1F6BF */ { "DOUCHE",NULL},
/* 1F6C0 */ { "BAIN",NULL},
/* 1F6C1 */ { "BAIGNOIRE",NULL},
/* 1F6C2 */ { "CONTRÔLE DE PASSEPORTS",NULL},
/* 1F6C3 */ { "DOUANE",NULL},
/* 1F6C4 */ { "RETRAIT DES BAGAGES",NULL},
/* 1F6C5 */ { "CONSIGNE DE BAGAGES",NULL},
/* 1F6C6 */ { "TRIANGLE AUX COINS ARRONDIS","	= attention\n"
	"	x (triangle blanc pointant vers le haut - 25B3)"},
/* 1F6C7 */ { "SYMBOLE D'INTERDICTION","	x (diacritique cercle englobant et barre oblique inversée - 20E0)\n"
	"	x (panneau entrée interdite - 1F6AB)"},
/* 1F6C8 */ { "SYMBOLE SOURCE D'INFORMATION CERCLÉ","	= information\n"
	"	x (source d'information - 2139)"},
/* 1F6C9 */ { "SYMBOLE GARÇONS",NULL},
/* 1F6CA */ { "SYMBOLE FILLES",NULL},
/* 1F6CB */ { "DIVAN ET LAMPE","	= ameublement, modes de vie"},
/* 1F6CC */ { "CENTRE D'HÉBERGEMENT","	= hôtel, chambres d'hôte\n"
	"	x (hôtel - 1F3E8)"},
/* 1F6CD */ { "SACS À PROVISIONS","	= shopping, chalandage\n"
	"	= magasinage (Canada)"},
/* 1F6CE */ { "CLOCHE DE TABLE","	= réception, prestations de services"},
/* 1F6CF */ { "LIT",NULL},
/* 1F6D0 */ { "LIEU DE CULTE",NULL},
/* 1F6D1 */ { "PANNEAU OCTOGONAL","	= panneau stop\n"
	"	* le glyphe peut porter un mot signifiant « stop »\n"
	"	x (signal de danger - 26A0)\n"
	"	x (triangle épais blanc pointant vers le bas - 26DB)\n"
	"	x (octogone noir horizontal - 2BC3)"},
/* 1F6D2 */ { "CADDIE","	= chariot"},
/* 1F6D3 */ { "STUPA",NULL},
/* 1F6D4 */ { "PAGODE",NULL},
/* 1F6D5 */ { "TEMPLE HINDOU","	= mandir"},
/* 1F6D6 */ { "HUTTE",NULL},
/* 1F6D7 */ { "ASCENSEUR",NULL},
/* 1F6D8 */ { "GLISSEMENT DE TERRAIN","	= avalanche, danger, catastrophe"},
/* 1F6D9 */ { NULL,NULL},
/* 1F6DA */ { NULL,NULL},
/* 1F6DB */ { NULL,NULL},
/* 1F6DC */ { "SANS FIL",NULL},
/* 1F6DD */ { "TOBOGGAN","	= glissoire\n"
	"	= glissade (Canada)"},
/* 1F6DE */ { "ROUE",NULL},
/* 1F6DF */ { "BOUÉE ANNULAIRE",NULL},
/* 1F6E0 */ { "MARTEAU ET CLÉ À ÉCROUS","	= outillage, atelier de réparation\n"
	"	x (marteau et pioche - 2692)"},
/* 1F6E1 */ { "BOUCLIER","	= autoroute reliant les États américains"},
/* 1F6E2 */ { "BARIL DE PÉTROLE",NULL},
/* 1F6E3 */ { "AUTOROUTE",NULL},
/* 1F6E4 */ { "VOIE DE CHEMIN DE FER","	= voie ferrée"},
/* 1F6E5 */ { "BATEAU À MOTEUR","	= bateau\n"
	"	x (hors-bord - 1F6A4)"},
/* 1F6E6 */ { "AVION MILITAIRE POINTANT VERS LE HAUT","	= aéroport militaire"},
/* 1F6E7 */ { "AVION POINTANT VERS LE HAUT","	= aéroport civil\n"
	"	x (avion - 2708)"},
/* 1F6E8 */ { "PETIT AVION POINTANT VERS LE HAUT","	= aérodrome"},
/* 1F6E9 */ { "PETIT AVION",NULL},
/* 1F6EA */ { "AVION POINTANT AU NORD-EST",NULL},
/* 1F6EB */ { "AVION AU DÉCOLLAGE","	= départs"},
/* 1F6EC */ { "AVION À L'ATTERRISSAGE","	= arrivées"},
/* 1F6ED */ { NULL,NULL},
/* 1F6EE */ { NULL,NULL},
/* 1F6EF */ { NULL,NULL},
/* 1F6F0 */ { "SATELLITE",NULL},
/* 1F6F1 */ { "CAMION DE POMPIERS À L'APPROCHE","	= incendie\n"
	"	x (camion de pompiers - 1F692)"},
/* 1F6F2 */ { "LOCOMOTIVE DIESEL","	= train\n"
	"	x (locomotive à vapeur - 1F682)\n"
	"	x (train - 1F686)"},
/* 1F6F3 */ { "PAQUEBOT","	= croisière\n"
	"	x (navire - 1F6A2)"},
/* 1F6F4 */ { "TROTTINETTE",NULL},
/* 1F6F5 */ { "SCOOTER",NULL},
/* 1F6F6 */ { "CANOË",NULL},
/* 1F6F7 */ { "LUGE","	= traîneau"},
/* 1F6F8 */ { "SOUCOUPE VOLANTE","	= ovni (objet volant non identifié)\n"
	"	x (symbole soucoupe volante - 1CCFB)\n"
	"	x (extraterrestre - 1F47D)"},
/* 1F6F9 */ { "PLANCHE À ROULETTES",NULL},
/* 1F6FA */ { "RICKSHAW MOTORISÉ","	= tuk-tuk\n"
	"	= remorque (Cambodge)"},
/* 1F6FB */ { "CAMIONNETTE",NULL},
/* 1F6FC */ { "PATIN À ROULETTES",NULL},
/* 1F6FD */ { NULL,NULL},
/* 1F6FE */ { NULL,NULL},
/* 1F6FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F7[] = {
/* 1F700 */ { "SYMBOLE ALCHIMIQUE DE LA QUINTESSENCE",NULL},
/* 1F701 */ { "SYMBOLE ALCHIMIQUE DE L'AIR",NULL},
/* 1F702 */ { "SYMBOLE ALCHIMIQUE DU FEU","	x (triangle blanc pointant vers le haut - 25B3)"},
/* 1F703 */ { "SYMBOLE ALCHIMIQUE DE LA TERRE","	x (terre - 2641)"},
/* 1F704 */ { "SYMBOLE ALCHIMIQUE DE L'EAU","	x (triangle blanc pointant vers le bas - 25BD)"},
/* 1F705 */ { "SYMBOLE ALCHIMIQUE DE L'EAU-FORTE",NULL},
/* 1F706 */ { "SYMBOLE ALCHIMIQUE DE L'EAU RÉGALE",NULL},
/* 1F707 */ { "SYMBOLE ALCHIMIQUE DE L'EAU RÉGALE-2","	= balneum arenae (bain de sable), lapis armenus (pierre d'Arménie)"},
/* 1F708 */ { "SYMBOLE ALCHIMIQUE DE L'EAU-DE-VIE","	= spiritus vini"},
/* 1F709 */ { "SYMBOLE ALCHIMIQUE DE L'EAU-DE-VIE-2",NULL},
/* 1F70A */ { "SYMBOLE ALCHIMIQUE DU VINAIGRE","	= creuset ; acide ; distiller ; atrament ; vitriol ; soufre rouge ; borax ; vin ; sel alcalin ; mercure\n"
	"	x (croix de jérusalem - 2629)"},
/* 1F70B */ { "SYMBOLE ALCHIMIQUE DU VINAIGRE-2","	= vinaigre distillé"},
/* 1F70C */ { "SYMBOLE ALCHIMIQUE DU VINAIGRE-3",NULL},
/* 1F70D */ { "SYMBOLE ALCHIMIQUE DU SOUFRE",NULL},
/* 1F70E */ { "SYMBOLE ALCHIMIQUE DU SOUFRE PHILOSOPHIQUE",NULL},
/* 1F70F */ { "SYMBOLE ALCHIMIQUE DU SOUFRE NOIR","	= sulfur nigra, colorant"},
/* 1F710 */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ DE MERCURE","	x (mercure - 263F)\n"
	"	x (symbole alchimique sublimer - 1F75E)"},
/* 1F711 */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ DE MERCURE-2",NULL},
/* 1F712 */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ DE MERCURE-3",NULL},
/* 1F713 */ { "SYMBOLE ALCHIMIQUE DU CINABRE",NULL},
/* 1F714 */ { "SYMBOLE ALCHIMIQUE DU SEL","	x (carré blanc - 25A1)\n"
	"	x (moins cerclé - 2296)"},
/* 1F715 */ { "SYMBOLE ALCHIMIQUE DU SALPÊTRE","	x (barre verticale cerclée - 29B6)"},
/* 1F716 */ { "SYMBOLE ALCHIMIQUE DU VITRIOL",NULL},
/* 1F717 */ { "SYMBOLE ALCHIMIQUE DU VITRIOL-2",NULL},
/* 1F718 */ { "SYMBOLE ALCHIMIQUE DU SEL GEMME","	= sal gemmae"},
/* 1F719 */ { "SYMBOLE ALCHIMIQUE DU SEL GEMME-2",NULL},
/* 1F71A */ { "SYMBOLE ALCHIMIQUE DE L'OR","	x (soleil - 2609)"},
/* 1F71B */ { "SYMBOLE ALCHIMIQUE DE L'ARGENT","	x (premier quartier de lune - 263D)\n"
	"	x (dernier quartier de lune - 263E)"},
/* 1F71C */ { "SYMBOLE ALCHIMIQUE DU MINERAI DE FER","	x (signe mâle - 2642)"},
/* 1F71D */ { "SYMBOLE ALCHIMIQUE DU MINERAI DE FER-2",NULL},
/* 1F71E */ { "SYMBOLE ALCHIMIQUE DU CROCUS MARTIS","	= poudre de fer calcinée rouge ou jaune\n"
	"	x (signe mâle à trait - 26A6)"},
/* 1F71F */ { "SYMBOLE ALCHIMIQUE DU RÉGULE DE FER","	= regulus martis, scorie du raffinage de l'antimoine avec du fer"},
/* 1F720 */ { "SYMBOLE ALCHIMIQUE DU MINERAI CUIVRE","	x (signe femelle - 2640)"},
/* 1F721 */ { "SYMBOLE ALCHIMIQUE DU MINERAI DE FER-CUIVRE","	x (signe mâle et femelle - 26A5)"},
/* 1F722 */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ DE CUIVRE","	x (symbole alchimique du sel ammoniac - 1F739)"},
/* 1F723 */ { "SYMBOLE ALCHIMIQUE DU CROCUS VENERIS","	= aes ustum"},
/* 1F724 */ { "SYMBOLE ALCHIMIQUE DU CROCUS VENERIS-2",NULL},
/* 1F725 */ { "SYMBOLE ALCHIMIQUE DE L'ANTIMONIATE DE CUIVRE","	= crocus de cuivre, crocus veneris, lapis haematites\n"
	"	x (terre - 2641)"},
/* 1F726 */ { "SYMBOLE ALCHIMIQUE DU SEL D'ANTIMONIATE DE CUIVRE","	x (symbole alchimique du sel - 1F714)"},
/* 1F727 */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ DE SEL DE CUIVRE","	x (symbole alchimique du sel ammoniac - 1F739)"},
/* 1F728 */ { "SYMBOLE ALCHIMIQUE DU VERT-DE-GRIS","	= aes viride, sous-acétate de cuivre\n"
	"	= symbole astronomique de la Terre\n"
	"	x (plus cerclé - 2295)\n"
	"	x (terre - 2641)"},
/* 1F729 */ { "SYMBOLE ALCHIMIQUE DU MINERAI D'ÉTAIN","	x (jupiter - 2643)"},
/* 1F72A */ { "SYMBOLE ALCHIMIQUE DU MINERAI DE PLOMB","	x (saturne - 2644)"},
/* 1F72B */ { "SYMBOLE ALCHIMIQUE DU MINERAI D'ANTIMOINE","	= stibine\n"
	"	x (terre - 2641)"},
/* 1F72C */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ D'ANTIMOINE","	x (symbole alchimique du sel ammoniac - 1F739)"},
/* 1F72D */ { "SYMBOLE ALCHIMIQUE DU SEL D'ANTIMOINE","	= cinabre\n"
	"	x (symbole alchimique du sel - 1F714)"},
/* 1F72E */ { "SYMBOLE ALCHIMIQUE DU SUBLIMÉ DE SEL D'ANTIMOINE",NULL},
/* 1F72F */ { "SYMBOLE ALCHIMIQUE DU VINAIGRE D'ANTIMOINE",NULL},
/* 1F730 */ { "SYMBOLE ALCHIMIQUE DU RÉGULE D'ANTIMOINE","	= métal d'antimoine"},
/* 1F731 */ { "SYMBOLE ALCHIMIQUE DU RÉGULE D'ANTIMOINE-2",NULL},
/* 1F732 */ { "SYMBOLE ALCHIMIQUE DU RÉGULE",NULL},
/* 1F733 */ { "SYMBOLE ALCHIMIQUE DU RÉGULE-2",NULL},
/* 1F734 */ { "SYMBOLE ALCHIMIQUE DU RÉGULE-3",NULL},
/* 1F735 */ { "SYMBOLE ALCHIMIQUE DU RÉGULE-4",NULL},
/* 1F736 */ { "SYMBOLE ALCHIMIQUE DE L'ALCALI","	= sal alkali"},
/* 1F737 */ { "SYMBOLE ALCHIMIQUE DE L'ALCALI-2",NULL},
/* 1F738 */ { "SYMBOLE ALCHIMIQUE DE LA MARCASSITE","	= pyrite, disulfure de fer"},
/* 1F739 */ { "SYMBOLE ALCHIMIQUE DU SEL AMMONIAC","	= chlorure d'ammonium\n"
	"	x (astérisque - 002A)\n"
	"	x (sextile - 26B9)\n"
	"	x (astérisque à huit branches - 2733)"},
/* 1F73A */ { "SYMBOLE ALCHIMIQUE DE L'ARSENIC","	x (multijection à deux têtes - 29DF)"},
/* 1F73B */ { "SYMBOLE ALCHIMIQUE DU RÉALGAR","	= sulfure d'arsenic"},
/* 1F73C */ { "SYMBOLE ALCHIMIQUE DU RÉALGAR-2","	= sulfure d'arsenic"},
/* 1F73D */ { "SYMBOLE ALCHIMIQUE DE L'ORPIMENT","	= trisulfure d'arsenic"},
/* 1F73E */ { "SYMBOLE ALCHIMIQUE DU MINERAI DE BISMUTH","	= étain de glace\n"
	"	x (neptune - 2646)"},
/* 1F73F */ { "SYMBOLE ALCHIMIQUE DU TARTRE","	= tartrate de potassium impur"},
/* 1F740 */ { "SYMBOLE ALCHIMIQUE DU TARTRE-2","	= tartrate de potassium impur"},
/* 1F741 */ { "SYMBOLE ALCHIMIQUE DE LA CHAUX VIVE","	= calx viva\n"
	"	= oxyde de calcium"},
/* 1F742 */ { "SYMBOLE ALCHIMIQUE DU BORAX",NULL},
/* 1F743 */ { "SYMBOLE ALCHIMIQUE DU BORAX-2",NULL},
/* 1F744 */ { "SYMBOLE ALCHIMIQUE DU BORAX-3",NULL},
/* 1F745 */ { "SYMBOLE ALCHIMIQUE DE L'ALUN",NULL},
/* 1F746 */ { "SYMBOLE ALCHIMIQUE DE L'HUILE","	x (signe tibétain rdel dkar gsoum - 0F1C)"},
/* 1F747 */ { "SYMBOLE ALCHIMIQUE DE L'ESPRIT",NULL},
/* 1F748 */ { "SYMBOLE ALCHIMIQUE DE LA TEINTURE",NULL},
/* 1F749 */ { "SYMBOLE ALCHIMIQUE DE LA GOMME",NULL},
/* 1F74A */ { "SYMBOLE ALCHIMIQUE DE LA CIRE","	= cera"},
/* 1F74B */ { "SYMBOLE ALCHIMIQUE DE LA POUDRE","	= pulvis"},
/* 1F74C */ { "SYMBOLE ALCHIMIQUE DE LA CHAUX MÉTALLIQUE","	= calcinare\n"
	"	= résidu d'oxyde, oxyde de calcium"},
/* 1F74D */ { "SYMBOLE ALCHIMIQUE DE LA TUTIE","	= oxyde de zinc cru sublimé\n"
	"	= aes viride"},
/* 1F74E */ { "SYMBOLE ALCHIMIQUE DE LA TÊTE MORTE","	= résidu sans valeur de la sublimation ou de la distillation"},
/* 1F74F */ { "SYMBOLE ALCHIMIQUE DU SCEPTRE DE JUPITER",NULL},
/* 1F750 */ { "SYMBOLE ALCHIMIQUE DE LA CADUCÉE","	x (caducée - 2624)"},
/* 1F751 */ { "SYMBOLE ALCHIMIQUE DU TRIDENT",NULL},
/* 1F752 */ { "SYMBOLE ALCHIMIQUE DU TRIDENT ÉTOILÉ",NULL},
/* 1F753 */ { "SYMBOLE ALCHIMIQUE DE L'AIMANT","	= magnes"},
/* 1F754 */ { "SYMBOLE ALCHIMIQUE DU SAVON","	x (rhombe - 25CA)\n"
	"	x (losange moyen blanc - 2B26)"},
/* 1F755 */ { "SYMBOLE ALCHIMIQUE DE L'URINE","	x (opérateur point encadré - 22A1)"},
/* 1F756 */ { "SYMBOLE ALCHIMIQUE DU FUMIER DE CHEVAL","	= fimus equinus"},
/* 1F757 */ { "SYMBOLE ALCHIMIQUE DE LA CENDRE","	= cineres"},
/* 1F758 */ { "SYMBOLE ALCHIMIQUE DE LA CENDRE GRAVELÉE","	= cineres clavellati, alumen"},
/* 1F759 */ { "SYMBOLE ALCHIMIQUE DE LA BRIQUE",NULL},
/* 1F75A */ { "SYMBOLE ALCHIMIQUE DE LA BRIQUE PULVÉRISÉE","	= later cibratus, farina laterum"},
/* 1F75B */ { "SYMBOLE ALCHIMIQUE DE L'AMALGAME",NULL},
/* 1F75C */ { "SYMBOLE ALCHIMIQUE DU STRATUM SUPER STRATUM",NULL},
/* 1F75D */ { "SYMBOLE ALCHIMIQUE DU STRATUM SUPER STRATUM-2",NULL},
/* 1F75E */ { "SYMBOLE ALCHIMIQUE SUBLIMER","	x (nœud ascendant - 260A)\n"
	"	x (balance - 264E)"},
/* 1F75F */ { "SYMBOLE ALCHIMIQUE PRÉCIPITER",NULL},
/* 1F760 */ { "SYMBOLE ALCHIMIQUE DISTILLER","	= sublimer"},
/* 1F761 */ { "SYMBOLE ALCHIMIQUE DISSOUDRE","	x (lettre minuscule latine f hameçon - 0192)\n"
	"	x (intégrale à partie finie - 2A0D)"},
/* 1F762 */ { "SYMBOLE ALCHIMIQUE DISSOUDRE-2","	= eau, aqua"},
/* 1F763 */ { "SYMBOLE ALCHIMIQUE PURIFIER","	x (nœud descendant - 260B)"},
/* 1F764 */ { "SYMBOLE ALCHIMIQUE PUTRÉFIER",NULL},
/* 1F765 */ { "SYMBOLE ALCHIMIQUE DU CREUSET","	= tigillum\n"
	"	x (symbole alchimique du vinaigre - 1F70A)"},
/* 1F766 */ { "SYMBOLE ALCHIMIQUE DU CREUSET-2",NULL},
/* 1F767 */ { "SYMBOLE ALCHIMIQUE DU CREUSET-3",NULL},
/* 1F768 */ { "SYMBOLE ALCHIMIQUE DU CREUSET-4","	x (lettre majuscule latine t barré - 0166)"},
/* 1F769 */ { "SYMBOLE ALCHIMIQUE DU CREUSET-5",NULL},
/* 1F76A */ { "SYMBOLE ALCHIMIQUE DE L'ALAMBIC",NULL},
/* 1F76B */ { "SYMBOLE ALCHIMIQUE DU BAIN-MARIE","	= balneum mariae"},
/* 1F76C */ { "SYMBOLE ALCHIMIQUE DU BAIN DE VAPEUR","	= balneum vaporis"},
/* 1F76D */ { "SYMBOLE ALCHIMIQUE DE LA CORNUE","	x (alambic - 2697)"},
/* 1F76E */ { "SYMBOLE ALCHIMIQUE DE L'HEURE","	x (sablier - 231B)\n"
	"	x (sablier blanc - 29D6)"},
/* 1F76F */ { "SYMBOLE ALCHIMIQUE DE LA NUIT",NULL},
/* 1F770 */ { "SYMBOLE ALCHIMIQUE JOUR-NUIT",NULL},
/* 1F771 */ { "SYMBOLE ALCHIMIQUE DU MOIS","	= mensis\n"
	"	x (multiplié par encadré - 22A0)"},
/* 1F772 */ { "SYMBOLE ALCHIMIQUE DU DEMI-GROS","	= drachma semis\n"
	"	* ligature manuscrite de 0292 + 00DF, habituellement représentée par ʒss\n"
	"	x (lettre minuscule latine ej - 0292)"},
/* 1F773 */ { "SYMBOLE ALCHIMIQUE DE LA DEMI-ONCE","	= uncia semis\n"
	"	* ligature manuscrite de 2125 + 00DF, habituellement représentée par 2125 ss\n"
	"	x (symbole once - 2125)"},
/* 1F774 */ { "PART DE FORTUNE","	= pars fortunae\n"
	"	x (multiplié par cerclé - 2297)"},
/* 1F775 */ { "OCCULTATION","	x (conjonction - 260C)"},
/* 1F776 */ { "ÉCLIPSE LUNAIRE","	x (opposition - 260D)"},
/* 1F777 */ { "VESTA FORME DEUX","	x (vesta - 26B6)"},
/* 1F778 */ { "ASTRÉE FORME DEUX","	x (astrée - 2BD9)"},
/* 1F779 */ { "HYGIE FORME DEUX","	x (hygie - 2BDA)"},
/* 1F77A */ { "PARTHÉNOPE FORME DEUX","	= Lyre\n"
	"	x (parthénope - 1CEC4)"},
/* 1F77B */ { "HAUMÉA",NULL},
/* 1F77C */ { "MAKÉMAKÉ",NULL},
/* 1F77D */ { "GONGGONG",NULL},
/* 1F77E */ { "QUAOAR",NULL},
/* 1F77F */ { "ORCUS",NULL},
/* 1F780 */ { "TRIANGLE ISOCÈLE DROIT NOIR POINTANT VERS LA GAUCHE","	x (triangle noir moyen pointant vers la gauche - 23F4)"},
/* 1F781 */ { "TRIANGLE ISOCÈLE DROIT NOIR POINTANT VERS LE HAUT","	x (triangle noir moyen pointant vers le haut - 23F6)"},
/* 1F782 */ { "TRIANGLE ISOCÈLE DROIT NOIR POINTANT VERS LA DROITE","	x (triangle noir moyen pointant vers la droite - 23F5)"},
/* 1F783 */ { "TRIANGLE ISOCÈLE DROIT NOIR POINTANT VERS LE BAS","	x (triangle noir moyen pointant vers le bas - 23F7)"},
/* 1F784 */ { "CERCLE NOIR LÉGÈREMENT PETIT",NULL},
/* 1F785 */ { "CERCLE BLANC MOYENNEMENT GRAS","	x (cercle blanc moyen - 26AA)"},
/* 1F786 */ { "CERCLE BLANC GRAS",NULL},
/* 1F787 */ { "CERCLE BLANC ÉPAIS",NULL},
/* 1F788 */ { "CERCLE BLANC TRÈS ÉPAIS",NULL},
/* 1F789 */ { "CERCLE BLANC EXTRÊMEMENT ÉPAIS",NULL},
/* 1F78A */ { "CERCLE BLANC CONTENANT UN PETIT CERCLE NOIR",NULL},
/* 1F78B */ { "CIBLE RONDE","	x (deux cercles concentriques - 25CE)\n"
	"	x (puce blanche cerclée - 29BE)\n"
	"	x (cercle épais avec cercle inscrit - 2B57)"},
/* 1F78C */ { "CARRÉ NOIR MINUSCULE",NULL},
/* 1F78D */ { "CARRÉ NOIR LÉGÈREMENT PETIT",NULL},
/* 1F78E */ { "CARRÉ BLANC FIN",NULL},
/* 1F78F */ { "CARRÉ BLANC DEMI-GRAS",NULL},
/* 1F790 */ { "CARRÉ BLANC GRAS","	= carré blanc épais"},
/* 1F791 */ { "CARRÉ BLANC ÉPAIS",NULL},
/* 1F792 */ { "CARRÉ BLANC TRÈS ÉPAIS",NULL},
/* 1F793 */ { "CARRÉ BLANC EXTRÊMEMENT ÉPAIS",NULL},
/* 1F794 */ { "CARRÉ BLANC CONTENANT UN TRÈS PETIT CARRÉ NOIR",NULL},
/* 1F795 */ { "CARRÉ BLANC CONTENANT UN CARRÉ MOYEN NOIR",NULL},
/* 1F796 */ { "CIBLE CARRÉE",NULL},
/* 1F797 */ { "MINUSCULE LOSANGE NOIR",NULL},
/* 1F798 */ { "TRÈS PETIT LOSANGE NOIR",NULL},
/* 1F799 */ { "LOSANGE NOIR MODÉRÉMENT PETIT",NULL},
/* 1F79A */ { "LOSANGE BLANC CONTENANT UN TRÈS PETIT LOSANGE NOIR",NULL},
/* 1F79B */ { "LOSANGE BLANC CONTENANT UN LOSANGE MOYEN NOIR",NULL},
/* 1F79C */ { "CIBLE EN LOSANGE",NULL},
/* 1F79D */ { "MINUSCULE RHOMBE NOIR",NULL},
/* 1F79E */ { "TRÈS PETIT RHOMBE NOIR",NULL},
/* 1F79F */ { "RHOMBE NOIR MODÉRÉMENT PETIT",NULL},
/* 1F7A0 */ { "RHOMBE BLANC CONTENANT UN PETIT RHOMBE NOIR",NULL},
/* 1F7A1 */ { "CROIX GRECQUE MINCE",NULL},
/* 1F7A2 */ { "CROIX GRECQUE FINE",NULL},
/* 1F7A3 */ { "CROIX GRECQUE DEMI-GRASSE",NULL},
/* 1F7A4 */ { "CROIX GRECQUE GRASSE",NULL},
/* 1F7A5 */ { "CROIX GRECQUE TRÈS GRASSE","	x (croix grecque épaisse - 271A)"},
/* 1F7A6 */ { "CROIX GRECQUE TRÈS ÉPAISSE",NULL},
/* 1F7A7 */ { "CROIX GRECQUE EXTRÊMEMENT ÉPAISSE",NULL},
/* 1F7A8 */ { "SAUTOIR MINCE","	x (x de multiplication - 2715)"},
/* 1F7A9 */ { "SAUTOIR FIN","	x (sautoir - 2613)"},
/* 1F7AA */ { "SAUTOIR DEMI-GRAS",NULL},
/* 1F7AB */ { "SAUTOIR GRAS",NULL},
/* 1F7AC */ { "SAUTOIR ÉPAIS",NULL},
/* 1F7AD */ { "SAUTOIR TRÈS ÉPAIS",NULL},
/* 1F7AE */ { "SAUTOIR EXTRÊMEMENT ÉPAIS","	x (x de multiplication épais - 2716)"},
/* 1F7AF */ { "ASTÉRISQUE À CINQ BRANCHES FIN",NULL},
/* 1F7B0 */ { "ASTÉRISQUE À CINQ BRANCHES DEMI-GRAS",NULL},
/* 1F7B1 */ { "ASTÉRISQUE À CINQ BRANCHES GRAS",NULL},
/* 1F7B2 */ { "ASTÉRISQUE À CINQ BRANCHES ÉPAIS",NULL},
/* 1F7B3 */ { "ASTÉRISQUE À CINQ BRANCHES TRÈS ÉPAIS",NULL},
/* 1F7B4 */ { "ASTÉRISQUE À CINQ BRANCHES EXTRÊMEMENT ÉPAIS",NULL},
/* 1F7B5 */ { "ASTÉRISQUE À SIX BRANCHES FIN",NULL},
/* 1F7B6 */ { "ASTÉRISQUE À SIX BRANCHES DEMI-GRAS","	* peut représenter le symbole « étoile » décrit dans la recommandation ITU-T E.161 pour une utilisation sur des appareils téléphoniques"},
/* 1F7B7 */ { "ASTÉRISQUE À SIX BRANCHES GRAS",NULL},
/* 1F7B8 */ { "ASTÉRISQUE À SIX BRANCHES ÉPAIS","	x (gros astérisque - 2731)"},
/* 1F7B9 */ { "ASTÉRISQUE À SIX BRANCHES TRÈS ÉPAIS",NULL},
/* 1F7BA */ { "ASTÉRISQUE À SIX BRANCHES EXTRÊMEMENT ÉPAIS",NULL},
/* 1F7BB */ { "ASTÉRISQUE À HUIT BRANCHES FIN","	x (astérisque à huit branches - 2733)"},
/* 1F7BC */ { "ASTÉRISQUE À HUIT BRANCHES DEMI-GRAS",NULL},
/* 1F7BD */ { "ASTÉRISQUE À HUIT BRANCHES GRAS",NULL},
/* 1F7BE */ { "ASTÉRISQUE À HUIT BRANCHES ÉPAIS",NULL},
/* 1F7BF */ { "ASTÉRISQUE À HUIT BRANCHES TRÈS ÉPAIS",NULL},
/* 1F7C0 */ { "ÉTOILE NOIRE À TROIS BRANCHES FINE",NULL},
/* 1F7C1 */ { "ÉTOILE NOIRE À TROIS BRANCHES DEMI-GRASSE",NULL},
/* 1F7C2 */ { "ÉTOILE NOIRE À TROIS BRANCHES",NULL},
/* 1F7C3 */ { "ÉTOILE EN MOULINET À TROIS BRANCHES DEMI-GRASSE",NULL},
/* 1F7C4 */ { "ÉTOILE NOIRE À QUATRE BRANCHES FINE",NULL},
/* 1F7C5 */ { "ÉTOILE NOIRE À QUATRE BRANCHES DEMI-GRASSE",NULL},
/* 1F7C6 */ { "ÉTOILE NOIRE À QUATRE BRANCHES","	* 2726 est une forme cuspidale\n"
	"	x (étoile à quatre branches noire - 2726)"},
/* 1F7C7 */ { "ÉTOILE EN MOULINET À QUATRE BRANCHES DEMI-GRASSE",NULL},
/* 1F7C8 */ { "ÉTOILE EN MOULINET À QUATRE BRANCHES INVERSÉE FINE","	= naviguer"},
/* 1F7C9 */ { "ÉTOILE NOIRE À CINQ BRANCHES FINE",NULL},
/* 1F7CA */ { "ÉTOILE NOIRE À CINQ BRANCHES ÉPAISSE",NULL},
/* 1F7CB */ { "ÉTOILE NOIRE À SIX BRANCHES DEMI-GRASSE",NULL},
/* 1F7CC */ { "ÉTOILE NOIRE À SIX BRANCHES ÉPAISSE",NULL},
/* 1F7CD */ { "ÉTOILE EN MOULINET À SIX BRANCHES",NULL},
/* 1F7CE */ { "ÉTOILE NOIRE À HUIT BRANCHES DEMI-GRASSE","	x (étoile rectiligne à huit branches - 2737)"},
/* 1F7CF */ { "ÉTOILE NOIRE À HUIT BRANCHES ÉPAISSE","	x (grosse étoile rectiligne à huit branches - 2738)"},
/* 1F7D0 */ { "ÉTOILE NOIRE À HUIT BRANCHES TRÈS ÉPAISSE",NULL},
/* 1F7D1 */ { "ÉTOILE EN MOULINET À HUIT BRANCHES ÉPAISSE","	x (étoile en moulinet à huit branches - 2735)"},
/* 1F7D2 */ { "ÉTOILE NOIRE À DOUZE BRANCHES FINE",NULL},
/* 1F7D3 */ { "ÉTOILE NOIRE À DOUZE BRANCHES ÉPAISSE",NULL},
/* 1F7D4 */ { "ÉTOILE EN MOULINET À DOUZE BRANCHES ÉPAISSE",NULL},
/* 1F7D5 */ { "TRIANGLE CERCLÉ",NULL},
/* 1F7D6 */ { "TRIANGLE CERCLÉ NOIR AU BLANC",NULL},
/* 1F7D7 */ { "CARRÉ CERCLÉ",NULL},
/* 1F7D8 */ { "CARRÉ CERCLÉ NOIR AU BLANC",NULL},
/* 1F7D9 */ { "ÉTOILE BLANCHE À NEUF BRANCHES","	* utilisée communément par les membres de la communauté religieuse bahaïe"},
/* 1F7DA */ { NULL,NULL},
/* 1F7DB */ { NULL,NULL},
/* 1F7DC */ { NULL,NULL},
/* 1F7DD */ { NULL,NULL},
/* 1F7DE */ { NULL,NULL},
/* 1F7DF */ { NULL,NULL},
/* 1F7E0 */ { "GRAND CERCLE ORANGE",NULL},
/* 1F7E1 */ { "GRAND CERCLE JAUNE",NULL},
/* 1F7E2 */ { "GRAND CERCLE VERT",NULL},
/* 1F7E3 */ { "GRAND CERCLE POURPRE",NULL},
/* 1F7E4 */ { "GRAND CERCLE BRUN",NULL},
/* 1F7E5 */ { "GRAND CARRÉ ROUGE",NULL},
/* 1F7E6 */ { "GRAND CARRÉ BLEU",NULL},
/* 1F7E7 */ { "GRAND CARRÉ ORANGE",NULL},
/* 1F7E8 */ { "GRAND CARRÉ JAUNE",NULL},
/* 1F7E9 */ { "GRAND CARRÉ VERT",NULL},
/* 1F7EA */ { "GRAND CARRÉ POURPRE",NULL},
/* 1F7EB */ { "GRAND CARRÉ BRUN",NULL},
/* 1F7EC */ { NULL,NULL},
/* 1F7ED */ { NULL,NULL},
/* 1F7EE */ { NULL,NULL},
/* 1F7EF */ { NULL,NULL},
/* 1F7F0 */ { "SIGNE ÉGAL ÉPAIS","	* symbole d'égalité\n"
	"	x (signe égal - 003D)\n"
	"	x (x de multiplication épais - 2716)\n"
	"	x (signe plus épais - 2795)\n"
	"	x (signe geta - 3013)\n"
	"	x (symbole romain sextant - 10190)"},
/* 1F7F1 */ { NULL,NULL},
/* 1F7F2 */ { NULL,NULL},
/* 1F7F3 */ { NULL,NULL},
/* 1F7F4 */ { NULL,NULL},
/* 1F7F5 */ { NULL,NULL},
/* 1F7F6 */ { NULL,NULL},
/* 1F7F7 */ { NULL,NULL},
/* 1F7F8 */ { NULL,NULL},
/* 1F7F9 */ { NULL,NULL},
/* 1F7FA */ { NULL,NULL},
/* 1F7FB */ { NULL,NULL},
/* 1F7FC */ { NULL,NULL},
/* 1F7FD */ { NULL,NULL},
/* 1F7FE */ { NULL,NULL},
/* 1F7FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F8[] = {
/* 1F800 */ { "FLÈCHE À PETITE TÊTE TRIANGULAIRE VERS LA GAUCHE",NULL},
/* 1F801 */ { "FLÈCHE À PETITE TÊTE TRIANGULAIRE VERS LE HAUT",NULL},
/* 1F802 */ { "FLÈCHE À PETITE TÊTE TRIANGULAIRE VERS LA DROITE",NULL},
/* 1F803 */ { "FLÈCHE À PETITE TÊTE TRIANGULAIRE VERS LE BAS",NULL},
/* 1F804 */ { "FLÈCHE À TÊTE MOYENNE TRIANGULAIRE VERS LA GAUCHE",NULL},
/* 1F805 */ { "FLÈCHE À TÊTE MOYENNE TRIANGULAIRE VERS LE HAUT",NULL},
/* 1F806 */ { "FLÈCHE À TÊTE MOYENNE TRIANGULAIRE VERS LA DROITE",NULL},
/* 1F807 */ { "FLÈCHE À TÊTE MOYENNE TRIANGULAIRE VERS LE BAS",NULL},
/* 1F808 */ { "FLÈCHE À LARGE TÊTE TRIANGULAIRE VERS LA GAUCHE",NULL},
/* 1F809 */ { "FLÈCHE À LARGE TÊTE TRIANGULAIRE VERS LE HAUT",NULL},
/* 1F80A */ { "FLÈCHE À LARGE TÊTE TRIANGULAIRE VERS LA DROITE",NULL},
/* 1F80B */ { "FLÈCHE À LARGE TÊTE TRIANGULAIRE VERS LE BAS",NULL},
/* 1F80C */ { NULL,NULL},
/* 1F80D */ { NULL,NULL},
/* 1F80E */ { NULL,NULL},
/* 1F80F */ { NULL,NULL},
/* 1F810 */ { "FLÈCHE À PETITE TÊTE ÉQUILATÉRALE VERS LA GAUCHE",NULL},
/* 1F811 */ { "FLÈCHE À PETITE TÊTE ÉQUILATÉRALE VERS LE HAUT",NULL},
/* 1F812 */ { "FLÈCHE À PETITE TÊTE ÉQUILATÉRALE VERS LA DROITE",NULL},
/* 1F813 */ { "FLÈCHE À PETITE TÊTE ÉQUILATÉRALE VERS LE BAS",NULL},
/* 1F814 */ { "FLÈCHE À TÊTE ÉQUILATÉRALE VERS LA GAUCHE",NULL},
/* 1F815 */ { "FLÈCHE À TÊTE ÉQUILATÉRALE VERS LE HAUT",NULL},
/* 1F816 */ { "FLÈCHE À TÊTE ÉQUILATÉRALE VERS LA DROITE",NULL},
/* 1F817 */ { "FLÈCHE À TÊTE ÉQUILATÉRALE VERS LE BAS",NULL},
/* 1F818 */ { "FLÈCHE ÉPAISSE À TÊTE ÉQUILATÉRALE VERS LA GAUCHE",NULL},
/* 1F819 */ { "FLÈCHE ÉPAISSE À TÊTE ÉQUILATÉRALE VERS LE HAUT",NULL},
/* 1F81A */ { "FLÈCHE ÉPAISSE À TÊTE ÉQUILATÉRALE VERS LA DROITE",NULL},
/* 1F81B */ { "FLÈCHE ÉPAISSE À TÊTE ÉQUILATÉRALE VERS LE BAS",NULL},
/* 1F81C */ { "FLÈCHE ÉPAISSE À LARGE TÊTE ÉQUILATÉRALE VERS LA GAUCHE",NULL},
/* 1F81D */ { "FLÈCHE ÉPAISSE À LARGE TÊTE ÉQUILATÉRALE VERS LE HAUT",NULL},
/* 1F81E */ { "FLÈCHE ÉPAISSE À LARGE TÊTE ÉQUILATÉRALE VERS LA DROITE",NULL},
/* 1F81F */ { "FLÈCHE ÉPAISSE À LARGE TÊTE ÉQUILATÉRALE VERS LE BAS",NULL},
/* 1F820 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE FINE VERS LA GAUCHE",NULL},
/* 1F821 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE FINE VERS LE HAUT",NULL},
/* 1F822 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE FINE VERS LA DROITE",NULL},
/* 1F823 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE FINE VERS LE BAS",NULL},
/* 1F824 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE DEMI-GRASSE VERS LA GAUCHE",NULL},
/* 1F825 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE DEMI-GRASSE VERS LE HAUT",NULL},
/* 1F826 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE DEMI-GRASSE VERS LA DROITE",NULL},
/* 1F827 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE DEMI-GRASSE VERS LE BAS",NULL},
/* 1F828 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE GRASSE VERS LA GAUCHE",NULL},
/* 1F829 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE GRASSE VERS LE HAUT",NULL},
/* 1F82A */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE GRASSE VERS LA DROITE",NULL},
/* 1F82B */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE GRASSE VERS LE BAS",NULL},
/* 1F82C */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE ÉPAISSE VERS LA GAUCHE",NULL},
/* 1F82D */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE ÉPAISSE VERS LE HAUT",NULL},
/* 1F82E */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE ÉPAISSE VERS LA DROITE",NULL},
/* 1F82F */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE ÉPAISSE VERS LE BAS",NULL},
/* 1F830 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE TRÈS ÉPAISSE VERS LA GAUCHE",NULL},
/* 1F831 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE TRÈS ÉPAISSE VERS LE HAUT",NULL},
/* 1F832 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE TRÈS ÉPAISSE VERS LA DROITE",NULL},
/* 1F833 */ { "FLÈCHE À TÊTE TRIANGULAIRE ET TIGE TRÈS ÉPAISSE VERS LE BAS",NULL},
/* 1F834 */ { "FLÈCHE SIGNALISATRICE VERS LA GAUCHE",NULL},
/* 1F835 */ { "FLÈCHE SIGNALISATRICE VERS LE HAUT",NULL},
/* 1F836 */ { "FLÈCHE SIGNALISATRICE VERS LA DROITE",NULL},
/* 1F837 */ { "FLÈCHE SIGNALISATRICE VERS LE BAS",NULL},
/* 1F838 */ { "FLÈCHE CARRÉE VERS LA GAUCHE",NULL},
/* 1F839 */ { "FLÈCHE CARRÉE VERS LE HAUT",NULL},
/* 1F83A */ { "FLÈCHE CARRÉE VERS LA DROITE",NULL},
/* 1F83B */ { "FLÈCHE CARRÉE VERS LE BAS",NULL},
/* 1F83C */ { "FLÈCHE COMPRIMÉE VERS LA GAUCHE",NULL},
/* 1F83D */ { "FLÈCHE COMPRIMÉE VERS LE HAUT",NULL},
/* 1F83E */ { "FLÈCHE COMPRIMÉE VERS LA DROITE",NULL},
/* 1F83F */ { "FLÈCHE COMPRIMÉE VERS LE BAS",NULL},
/* 1F840 */ { "FLÈCHE COMPRIMÉE ÉPAISSE VERS LA GAUCHE",NULL},
/* 1F841 */ { "FLÈCHE COMPRIMÉE ÉPAISSE VERS LE HAUT",NULL},
/* 1F842 */ { "FLÈCHE COMPRIMÉE ÉPAISSE VERS LA DROITE","	x (flèche noire trapue vers la droite - 27A7)"},
/* 1F843 */ { "FLÈCHE COMPRIMÉE ÉPAISSE VERS LE BAS",NULL},
/* 1F844 */ { "FLÈCHE ÉPAISSE VERS LA GAUCHE",NULL},
/* 1F845 */ { "FLÈCHE ÉPAISSE VERS LE HAUT",NULL},
/* 1F846 */ { "FLÈCHE ÉPAISSE VERS LA DROITE",NULL},
/* 1F847 */ { "FLÈCHE ÉPAISSE VERS LE BAS",NULL},
/* 1F848 */ { NULL,NULL},
/* 1F849 */ { NULL,NULL},
/* 1F84A */ { NULL,NULL},
/* 1F84B */ { NULL,NULL},
/* 1F84C */ { NULL,NULL},
/* 1F84D */ { NULL,NULL},
/* 1F84E */ { NULL,NULL},
/* 1F84F */ { NULL,NULL},
/* 1F850 */ { "FLÈCHE SANS EMPATTEMENT VERS LA GAUCHE","	x (flèche vers la gauche - 2190)"},
/* 1F851 */ { "FLÈCHE SANS EMPATTEMENT VERS LE HAUT","	x (flèche vers le haut - 2191)"},
/* 1F852 */ { "FLÈCHE SANS EMPATTEMENT VERS LA DROITE","	x (flèche vers la droite - 2192)"},
/* 1F853 */ { "FLÈCHE SANS EMPATTEMENT VERS LE BAS","	x (flèche vers le bas - 2193)"},
/* 1F854 */ { "FLÈCHE SANS EMPATTEMENT NORD-OUEST","	x (flèche nord-ouest - 2196)"},
/* 1F855 */ { "FLÈCHE SANS EMPATTEMENT NORD-EST","	x (flèche nord-est - 2197)"},
/* 1F856 */ { "FLÈCHE SANS EMPATTEMENT SUD-EST","	x (flèche sud-est - 2198)"},
/* 1F857 */ { "FLÈCHE SANS EMPATTEMENT SUD-OUEST","	x (flèche sud-ouest - 2199)"},
/* 1F858 */ { "FLÈCHE SANS EMPATTEMENT GAUCHE-DROITE","	x (flèche gauche-droite - 2194)"},
/* 1F859 */ { "FLÈCHE SANS EMPATTEMENT HAUT-BAS","	x (flèche haut-bas - 2195)"},
/* 1F85A */ { NULL,NULL},
/* 1F85B */ { NULL,NULL},
/* 1F85C */ { NULL,NULL},
/* 1F85D */ { NULL,NULL},
/* 1F85E */ { NULL,NULL},
/* 1F85F */ { NULL,NULL},
/* 1F860 */ { "FLÈCHE FINE À POINTE LARGE VERS LA GAUCHE",NULL},
/* 1F861 */ { "FLÈCHE FINE À POINTE LARGE VERS LE HAUT",NULL},
/* 1F862 */ { "FLÈCHE FINE À POINTE LARGE VERS LA DROITE",NULL},
/* 1F863 */ { "FLÈCHE FINE À POINTE LARGE VERS LE BAS",NULL},
/* 1F864 */ { "FLÈCHE FINE À POINTE LARGE NORD-OUEST",NULL},
/* 1F865 */ { "FLÈCHE FINE À POINTE LARGE NORD-EST",NULL},
/* 1F866 */ { "FLÈCHE FINE À POINTE LARGE SUD-EST",NULL},
/* 1F867 */ { "FLÈCHE FINE À POINTE LARGE SUD-OUEST",NULL},
/* 1F868 */ { "FLÈCHE À POINTE LARGE VERS LA GAUCHE",NULL},
/* 1F869 */ { "FLÈCHE À POINTE LARGE VERS LE HAUT",NULL},
/* 1F86A */ { "FLÈCHE À POINTE LARGE VERS LA DROITE",NULL},
/* 1F86B */ { "FLÈCHE À POINTE LARGE VERS LE BAS",NULL},
/* 1F86C */ { "FLÈCHE À POINTE LARGE NORD-OUEST",NULL},
/* 1F86D */ { "FLÈCHE À POINTE LARGE NORD-EST",NULL},
/* 1F86E */ { "FLÈCHE À POINTE LARGE SUD-EST",NULL},
/* 1F86F */ { "FLÈCHE À POINTE LARGE SUD-OUEST",NULL},
/* 1F870 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE VERS LA GAUCHE",NULL},
/* 1F871 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE VERS LE HAUT",NULL},
/* 1F872 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE VERS LA DROITE","	x (flèche vers la droite épaisse à pointe large - 2794)"},
/* 1F873 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE VERS LE BAS",NULL},
/* 1F874 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE NORD-OUEST",NULL},
/* 1F875 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE NORD-EST",NULL},
/* 1F876 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE SUD-EST",NULL},
/* 1F877 */ { "FLÈCHE DEMI-GRASSE À POINTE LARGE SUD-OUEST",NULL},
/* 1F878 */ { "FLÈCHE ÉPAISSE À POINTE LARGE VERS LA GAUCHE",NULL},
/* 1F879 */ { "FLÈCHE ÉPAISSE À POINTE LARGE VERS LE HAUT",NULL},
/* 1F87A */ { "FLÈCHE ÉPAISSE À POINTE LARGE VERS LA DROITE",NULL},
/* 1F87B */ { "FLÈCHE ÉPAISSE À POINTE LARGE VERS LE BAS",NULL},
/* 1F87C */ { "FLÈCHE ÉPAISSE À POINTE LARGE NORD-OUEST",NULL},
/* 1F87D */ { "FLÈCHE ÉPAISSE À POINTE LARGE NORD-EST",NULL},
/* 1F87E */ { "FLÈCHE ÉPAISSE À POINTE LARGE SUD-EST",NULL},
/* 1F87F */ { "FLÈCHE ÉPAISSE À POINTE LARGE SUD-OUEST",NULL},
/* 1F880 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE VERS LA GAUCHE",NULL},
/* 1F881 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE VERS LE HAUT",NULL},
/* 1F882 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE VERS LA DROITE",NULL},
/* 1F883 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE VERS LE BAS",NULL},
/* 1F884 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE NORD-OUEST",NULL},
/* 1F885 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE NORD-EST",NULL},
/* 1F886 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE SUD-EST",NULL},
/* 1F887 */ { "FLÈCHE TRÈS ÉPAISSE À POINTE LARGE SUD-OUEST",NULL},
/* 1F888 */ { NULL,NULL},
/* 1F889 */ { NULL,NULL},
/* 1F88A */ { NULL,NULL},
/* 1F88B */ { NULL,NULL},
/* 1F88C */ { NULL,NULL},
/* 1F88D */ { NULL,NULL},
/* 1F88E */ { NULL,NULL},
/* 1F88F */ { NULL,NULL},
/* 1F890 */ { "POINTE DE FLÈCHE EN TRIANGLE VERS LA GAUCHE",NULL},
/* 1F891 */ { "POINTE DE FLÈCHE EN TRIANGLE VERS LE HAUT",NULL},
/* 1F892 */ { "POINTE DE FLÈCHE EN TRIANGLE VERS LA DROITE",NULL},
/* 1F893 */ { "POINTE DE FLÈCHE EN TRIANGLE VERS LE BAS",NULL},
/* 1F894 */ { "FLÈCHE BLANCHE VERS LA GAUCHE INSCRITE DANS UNE POINTE DE FLÈCHE EN TRIANGLE",NULL},
/* 1F895 */ { "FLÈCHE BLANCHE VERS LE HAUT INSCRITE DANS UNE POINTE DE FLÈCHE EN TRIANGLE",NULL},
/* 1F896 */ { "FLÈCHE BLANCHE VERS LA DROITE INSCRITE DANS UNE POINTE DE FLÈCHE EN TRIANGLE",NULL},
/* 1F897 */ { "FLÈCHE BLANCHE VERS LE BAS INSCRITE DANS UNE POINTE DE FLÈCHE EN TRIANGLE",NULL},
/* 1F898 */ { "FLÈCHE VERS LA GAUCHE À TALON ENCOCHÉ",NULL},
/* 1F899 */ { "FLÈCHE VERS LE HAUT À TALON ENCOCHÉ",NULL},
/* 1F89A */ { "FLÈCHE VERS LA DROITE À TALON ENCOCHÉ","	x (flèche encochée blanche vers la droite ombrée à l'avant et par-dessous - 27AF)"},
/* 1F89B */ { "FLÈCHE VERS LE BAS À TALON ENCOCHÉ",NULL},
/* 1F89C */ { "TIGE DE FLÈCHE ÉPAISSE DE LARGEUR UN",NULL},
/* 1F89D */ { "TIGE DE FLÈCHE ÉPAISSE DE LARGEUR DEUX TIERS",NULL},
/* 1F89E */ { "TIGE DE FLÈCHE ÉPAISSE DE LARGEUR UN DEMI",NULL},
/* 1F89F */ { "TIGE DE FLÈCHE ÉPAISSE DE LARGEUR UN TIERS",NULL},
/* 1F8A0 */ { "FLÈCHE BLANCHE OMBRÉE EN BAS VERS LA GAUCHE",NULL},
/* 1F8A1 */ { "FLÈCHE BLANCHE OMBRÉE EN BAS VERS LA DROITE",NULL},
/* 1F8A2 */ { "FLÈCHE BLANCHE OMBRÉE EN HAUT VERS LA GAUCHE",NULL},
/* 1F8A3 */ { "FLÈCHE BLANCHE OMBRÉE EN HAUT VERS LA DROITE",NULL},
/* 1F8A4 */ { "FLÈCHE BLANCHE OMBRÉE À GAUCHE VERS LA GAUCHE",NULL},
/* 1F8A5 */ { "FLÈCHE BLANCHE OMBRÉE À DROITE VERS LA DROITE","	x (flèche blanche vers la droite ombrée à l'avant - 27A9)"},
/* 1F8A6 */ { "FLÈCHE BLANCHE OMBRÉE À DROITE VERS LA GAUCHE",NULL},
/* 1F8A7 */ { "FLÈCHE BLANCHE OMBRÉE À GAUCHE VERS LA DROITE","	x (flèche blanche vers la droite ombrée à l'arrière - 27AA)"},
/* 1F8A8 */ { "FLÈCHE BLANCHE OMBRÉE VERS LA GAUCHE PENCHÉE VERS L'ARRIÈRE",NULL},
/* 1F8A9 */ { "FLÈCHE BLANCHE OMBRÉE VERS LA DROITE PENCHÉE VERS L'ARRIÈRE","	x (flèche blanche vers la droite penchée vers l'arrière et ombrée - 27AB)"},
/* 1F8AA */ { "FLÈCHE BLANCHE OMBRÉE VERS LA GAUCHE PENCHÉE VERS L'AVANT",NULL},
/* 1F8AB */ { "FLÈCHE BLANCHE OMBRÉE VERS LA DROITE PENCHÉE VERS L'AVANT","	x (flèche blanche vers la droite penchée vers l'avant et ombrée - 27AC)"},
/* 1F8AC */ { "TIGE DE FLÈCHE BLANCHE DE LARGEUR UN",NULL},
/* 1F8AD */ { "TIGE DE FLÈCHE BLANCHE DE LARGEUR DEUX TIERS",NULL},
/* 1F8AE */ { NULL,NULL},
/* 1F8AF */ { NULL,NULL},
/* 1F8B0 */ { "FLÈCHE POINTANT VERS LE HAUT PUIS VERS LE NORD-OUEST",NULL},
/* 1F8B1 */ { "FLÈCHE POINTANT VERS LA DROITE PUIS TOURNANT VERS LE SUD-OUEST",NULL},
/* 1F8B2 */ { "FLÈCHE VERS LA DROITE À CROCHET INFÉRIEUR",NULL},
/* 1F8B3 */ { "FLÈCHE NOIRE VERS LE BAS JUSQU'À UN TAQUET",NULL},
/* 1F8B4 */ { "FLÈCHE VERS LA GAUCHE ENCADRÉE NOIR AU BLANC",NULL},
/* 1F8B5 */ { "FLÈCHE VERS LE HAUT ENCADRÉE NOIR AU BLANC",NULL},
/* 1F8B6 */ { "FLÈCHE VERS LA DROITE ENCADRÉE NOIR AU BLANC",NULL},
/* 1F8B7 */ { "FLÈCHE VERS LE BAS ENCADRÉE NOIR AU BLANC",NULL},
/* 1F8B8 */ { "FLÈCHE NORD-OUEST DEPUIS UN TAQUET",NULL},
/* 1F8B9 */ { "FLÈCHE NORD-EST DEPUIS UN TAQUET",NULL},
/* 1F8BA */ { "FLÈCHE SUD-EST DEPUIS UN TAQUET",NULL},
/* 1F8BB */ { "FLÈCHE SUD-OUEST DEPUIS UN TAQUET",NULL},
/* 1F8BC */ { NULL,NULL},
/* 1F8BD */ { NULL,NULL},
/* 1F8BE */ { NULL,NULL},
/* 1F8BF */ { NULL,NULL},
/* 1F8C0 */ { "FLÈCHE VERS LA GAUCHE DEPUIS UNE FLÈCHE VERS LE BAS","	* indique l'écriture en colonnes, les hiéroglyphes orientés vers la gauche (direction de lecture de gauche à droite)"},
/* 1F8C1 */ { "FLÈCHE VERS LA DROITE DEPUIS UNE FLÈCHE VERS LE BAS","	* indique l'écriture en colonnes, les hiéroglyphes orientés vers la droite (direction de lecture de droite à gauche)"},
/* 1F8C2 */ { NULL,NULL},
/* 1F8C3 */ { NULL,NULL},
/* 1F8C4 */ { NULL,NULL},
/* 1F8C5 */ { NULL,NULL},
/* 1F8C6 */ { NULL,NULL},
/* 1F8C7 */ { NULL,NULL},
/* 1F8C8 */ { NULL,NULL},
/* 1F8C9 */ { NULL,NULL},
/* 1F8CA */ { NULL,NULL},
/* 1F8CB */ { NULL,NULL},
/* 1F8CC */ { NULL,NULL},
/* 1F8CD */ { NULL,NULL},
/* 1F8CE */ { NULL,NULL},
/* 1F8CF */ { NULL,NULL},
/* 1F8D0 */ { "FLÈCHE LONGUE VERS LA DROITE SUR FLÈCHE LONGUE VERS LA GAUCHE","	x (flèche vers la droite sur flèche vers la gauche - 21C4)"},
/* 1F8D1 */ { "HARPON LONG VERS LA DROITE SUR HARPON LONG VERS LA GAUCHE","	x (harpon vers la droite sur harpon vers la gauche - 21CC)"},
/* 1F8D2 */ { "HARPON LONG VERS LA DROITE SUR HARPON COURT VERS LA GAUCHE",NULL},
/* 1F8D3 */ { "HARPON COURT VERS LA DROITE SUR HARPON LONG VERS LA GAUCHE",NULL},
/* 1F8D4 */ { "HARPON LONG VERS LA GAUCHE SUR HARPON COURT VERS LA DROITE","	x (harpon vers la gauche sur harpon vers la droite - 21CB)"},
/* 1F8D5 */ { "HARPON COURT VERS LA GAUCHE SUR HARPON LONG VERS LA DROITE",NULL},
/* 1F8D6 */ { "FLÈCHE LONGUE VERS LA DROITE TRAVERSANT UN X",NULL},
/* 1F8D7 */ { "FLÈCHE LONGUE VERS LA DROITE À DOUBLE BARRE OBLIQUE",NULL},
/* 1F8D8 */ { "FLÈCHE LONGUE GAUCHE-DROITE À LOBE DÉPENDANT","	* indique que les deux côtés ont la même disposition des lobes électroniques"},
/* 1F8D9 */ { NULL,NULL},
/* 1F8DA */ { NULL,NULL},
/* 1F8DB */ { NULL,NULL},
/* 1F8DC */ { NULL,NULL},
/* 1F8DD */ { NULL,NULL},
/* 1F8DE */ { NULL,NULL},
/* 1F8DF */ { NULL,NULL},
/* 1F8E0 */ { NULL,NULL},
/* 1F8E1 */ { NULL,NULL},
/* 1F8E2 */ { NULL,NULL},
/* 1F8E3 */ { NULL,NULL},
/* 1F8E4 */ { NULL,NULL},
/* 1F8E5 */ { NULL,NULL},
/* 1F8E6 */ { NULL,NULL},
/* 1F8E7 */ { NULL,NULL},
/* 1F8E8 */ { NULL,NULL},
/* 1F8E9 */ { NULL,NULL},
/* 1F8EA */ { NULL,NULL},
/* 1F8EB */ { NULL,NULL},
/* 1F8EC */ { NULL,NULL},
/* 1F8ED */ { NULL,NULL},
/* 1F8EE */ { NULL,NULL},
/* 1F8EF */ { NULL,NULL},
/* 1F8F0 */ { NULL,NULL},
/* 1F8F1 */ { NULL,NULL},
/* 1F8F2 */ { NULL,NULL},
/* 1F8F3 */ { NULL,NULL},
/* 1F8F4 */ { NULL,NULL},
/* 1F8F5 */ { NULL,NULL},
/* 1F8F6 */ { NULL,NULL},
/* 1F8F7 */ { NULL,NULL},
/* 1F8F8 */ { NULL,NULL},
/* 1F8F9 */ { NULL,NULL},
/* 1F8FA */ { NULL,NULL},
/* 1F8FB */ { NULL,NULL},
/* 1F8FC */ { NULL,NULL},
/* 1F8FD */ { NULL,NULL},
/* 1F8FE */ { NULL,NULL},
/* 1F8FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_F9[] = {
/* 1F900 */ { "CROIX PATTÉE CERCLÉE AVEC QUATRE POINTS",NULL},
/* 1F901 */ { "CROIX PATTÉE CERCLÉE AVEC DEUX POINTS",NULL},
/* 1F902 */ { "CROIX PATTÉE CERCLÉE","	x (croix de malte - 2720)"},
/* 1F903 */ { "DEMI-CERCLE GAUCHE AVEC QUATRE POINTS",NULL},
/* 1F904 */ { "DEMI-CERCLE GAUCHE AVEC TROIS POINTS",NULL},
/* 1F905 */ { "DEMI-CERCLE GAUCHE AVEC DEUX POINTS",NULL},
/* 1F906 */ { "DEMI-CERCLE GAUCHE AVEC POINT",NULL},
/* 1F907 */ { "DEMI-CERCLE GAUCHE",NULL},
/* 1F908 */ { "CROCHET TOURNÉ VERS LE BAS",NULL},
/* 1F909 */ { "CROCHET CRANTÉ TOURNÉ VERS LE BAS",NULL},
/* 1F90A */ { "CROCHET TOURNÉ VERS LE BAS AVEC POINT",NULL},
/* 1F90B */ { "CROCHET CRANTÉ TOURNÉ VERS LE BAS AVEC POINT",NULL},
/* 1F90C */ { "DOIGTS RÉUNIS EN POINTE",NULL},
/* 1F90D */ { "CŒUR BLANC",NULL},
/* 1F90E */ { "CŒUR BRUN",NULL},
/* 1F90F */ { "POUCE ET INDEX RAPPROCHÉS",NULL},
/* 1F910 */ { "VISAGE À LA BOUCHE ZIPPÉE",NULL},
/* 1F911 */ { "VISAGE AVEC SYMBOLES DOLLAR",NULL},
/* 1F912 */ { "VISAGE AVEC THERMOMÈTRE",NULL},
/* 1F913 */ { "VISAGE D'INTELLO",NULL},
/* 1F914 */ { "VISAGE PENSIF",NULL},
/* 1F915 */ { "VISAGE À LA TÊTE BANDÉE",NULL},
/* 1F916 */ { "FACE DE ROBOT","	x (monstre extraterrestre - 1F47E)"},
/* 1F917 */ { "VISAGE ENLAÇANT",NULL},
/* 1F918 */ { "SIGNE DES CORNES",NULL},
/* 1F919 */ { "SIGNE APPELEZ-MOI",NULL},
/* 1F91A */ { "DOS DE MAIN LEVÉE",NULL},
/* 1F91B */ { "POING VERS LA GAUCHE","	x (main vers la gauche - 1FAF2)"},
/* 1F91C */ { "POING VERS LA DROITE","	x (main vers la droite - 1FAF1)"},
/* 1F91D */ { "POIGNÉE DE MAIN",NULL},
/* 1F91E */ { "MAIN AVEC INDEX ET MAJEUR CROISÉS","	x (main avec index et pouce croisés - 1FAF0)"},
/* 1F91F */ { "SIGNE DE LA MAIN JE T'AIME","	* peut s'abréger « JTM » ou « je t'M »"},
/* 1F920 */ { "VISAGE AVEC CHAPEAU DE COWBOY",NULL},
/* 1F921 */ { "VISAGE DE CLOWN",NULL},
/* 1F922 */ { "VISAGE NAUSÉEUX",NULL},
/* 1F923 */ { "ROULANT SUR LE SOL EN RIANT",NULL},
/* 1F924 */ { "VISAGE BAVANT",NULL},
/* 1F925 */ { "VISAGE MENTANT",NULL},
/* 1F926 */ { "PAUME AU VISAGE","	= frustration, incrédulité"},
/* 1F927 */ { "VISAGE ÉTERNUANT","	= « À tes souhaits », « À tes amours »\n"
	"	= « À vos souhaits », « À vos amours »"},
/* 1F928 */ { "VISAGE AVEC UN SOURCIL LEVÉ",NULL},
/* 1F929 */ { "VISAGE RIEUR AUX YEUX EN FORME D'ÉTOILES",NULL},
/* 1F92A */ { "VISAGE RIEUR AVEC UN GRAND ŒIL ET UN PETIT ŒIL",NULL},
/* 1F92B */ { "VISAGE AVEC UN DOIGT COUVRANT LES LÈVRES CLOSES",NULL},
/* 1F92C */ { "VISAGE GRAVE AVEC DES SYMBOLES COUVRANT LA BOUCHE",NULL},
/* 1F92D */ { "VISAGE SOURIANT AUX YEUX RÉJOUIS ET LES MAINS COUVRANT LA BOUCHE",NULL},
/* 1F92E */ { "VISAGE À LA BOUCHE OUVERTE VOMISSANT",NULL},
/* 1F92F */ { "VISAGE CHOQUÉ AVEC LA TÊTE QUI ÉCLATE",NULL},
/* 1F930 */ { "FEMME ENCEINTE","	x (personne enceinte - 1FAC4)"},
/* 1F931 */ { "ALLAITEMENT MATERNEL",NULL},
/* 1F932 */ { "PAUMES DRESSÉES ENSEMBLE","	* symbole utilisé pour la prière dans certaines cultures"},
/* 1F933 */ { "ÉGOPORTRAIT","	* souvent utilisé avec une figure (visage, personne) sur la gauche"},
/* 1F934 */ { "PRINCE","	x (princesse - 1F478)"},
/* 1F935 */ { "HOMME EN SMOKING","	= homme en tenue de soirée\n"
	"	* apparence du jeune marié, peut être jumelé avec 1F470\n"
	"	x (mariée avec voile - 1F470)"},
/* 1F936 */ { "MÈRE NOËL","	x (père noël - 1F385)"},
/* 1F937 */ { "HAUSSEMENT D'ÉPAULES",NULL},
/* 1F938 */ { "PERSONNE FAISANT LA ROUE","	= gymnastique"},
/* 1F939 */ { "JONGLAGE","	= jonglerie"},
/* 1F93A */ { "ESCRIMEUR","	= escrime\n"
	"	x (épées croisées - 2694)"},
/* 1F93B */ { "PENTATHLON MODERNE",NULL},
/* 1F93C */ { "LUTTEURS","	= lutte"},
/* 1F93D */ { "WATER-POLO",NULL},
/* 1F93E */ { "HANDBALL",NULL},
/* 1F93F */ { "MASQUE DE PLONGÉE",NULL},
/* 1F940 */ { "FLEUR FANÉE","	x (rose - 1F339)"},
/* 1F941 */ { "TAMBOUR AVEC BAGUETTES",NULL},
/* 1F942 */ { "VERRES TINTANTS","	= célébration, cérémonie\n"
	"	x (chopes s'entrechoquant - 1F37B)"},
/* 1F943 */ { "VERRE À FOND PLAT","	= whisky\n"
	"	* couramment représenté avec des glaçons\n"
	"	x (verre à cocktail - 1F378)"},
/* 1F944 */ { "CUILLÈRE","	x (fourchette et couteau - 1F374)"},
/* 1F945 */ { "FILET DE BUT",NULL},
/* 1F946 */ { "FUSIL","	= adresse au tir, tir, chasse"},
/* 1F947 */ { "MÉDAILLE D'OR","	x (médaille sportive - 1F3C5)"},
/* 1F948 */ { "MÉDAILLE D'ARGENT",NULL},
/* 1F949 */ { "MÉDAILLE DE BRONZE",NULL},
/* 1F94A */ { "GANT DE BOXE","	= boxe"},
/* 1F94B */ { "UNIFORME D'ARTS MARTIAUX","	= judo, karaté, taekwondo"},
/* 1F94C */ { "PIERRE DE CURLING",NULL},
/* 1F94D */ { "CROSSE ET BALLE DE LACROSSE",NULL},
/* 1F94E */ { "SOFTBALL","	= balle-molle ou balle molle (Canada)"},
/* 1F94F */ { "DISQUE-VOLANT","	= discoplane (Belgique)\n"
	"	* appelé plus usuellement « frisbee » (à l'origine, une marque déposée)"},
/* 1F950 */ { "CROISSANT",NULL},
/* 1F951 */ { "AVOCAT",NULL},
/* 1F952 */ { "CONCOMBRE","	= cornichon"},
/* 1F953 */ { "BACON","	= lard"},
/* 1F954 */ { "POMME DE TERRE",NULL},
/* 1F955 */ { "CAROTTE",NULL},
/* 1F956 */ { "BAGUETTE DE PAIN","	= pain français"},
/* 1F957 */ { "SALADE VERTE",NULL},
/* 1F958 */ { "POÊLÉE D'ALIMENTS","	= poêle à frire, sauteuse"},
/* 1F959 */ { "PAIN PLAT FARCI","	= döner kebab, falafel, gyros, shawarma"},
/* 1F95A */ { "ŒUF","	= œuf de poule"},
/* 1F95B */ { "VERRE DE LAIT","	= lait\n"
	"	x (verser un liquide - 1FAD7)"},
/* 1F95C */ { "ARACHIDES",NULL},
/* 1F95D */ { "KIWI",NULL},
/* 1F95E */ { "CRÊPES","	= blini\n"
	"	* sucrées ou salées"},
/* 1F95F */ { "RAVIOLE","	= gyooza, jiaozi, pierogi, empanada"},
/* 1F960 */ { "BISCUIT CHINOIS","	= beignet chinois\n"
	"	* confiserie à pâte mince repliée autour d'un petit morceau de papier sur lequel figure une maxime ou une prédiction"},
/* 1F961 */ { "BOÎTE D'ALIMENTS À EMPORTER",NULL},
/* 1F962 */ { "BAGUETTES",NULL},
/* 1F963 */ { "BOL AVEC CUILLÈRE","	* peut symboliser le petit-déjeuner, des céréales, une bouillie de riz, etc."},
/* 1F964 */ { "GOBELET AVEC PAILLE","	* peut symboliser une boisson gazeuse, un jus, etc."},
/* 1F965 */ { "NOIX DE COCO",NULL},
/* 1F966 */ { "BROCOLI",NULL},
/* 1F967 */ { "TARTE","	= tourte\n"
	"	* peut être sucrée ou salée"},
/* 1F968 */ { "BRETZEL","	* peut symboliser la torsion, l'intrication"},
/* 1F969 */ { "PIÈCE DE VIANDE","	= côtelette de porc, côtelette, bifteck"},
/* 1F96A */ { "SANDWICH",NULL},
/* 1F96B */ { "BOÎTE DE CONSERVE",NULL},
/* 1F96C */ { "LÉGUME-FEUILLE","	* destiné à représenter des légumes verts cuits tels que le chou de Chine, le kale, etc."},
/* 1F96D */ { "MANGUE",NULL},
/* 1F96E */ { "GÂTEAU DE LUNE","	* pâtisserie chinoise en forme de lune"},
/* 1F96F */ { "BAGUEL",NULL},
/* 1F970 */ { "VISAGE SOURIANT AUX YEUX RÉJOUIS AVEC TROIS CŒURS",NULL},
/* 1F971 */ { "VISAGE BÂILLANT",NULL},
/* 1F972 */ { "VISAGE SOURIANT AVEC UNE LARME",NULL},
/* 1F973 */ { "VISAGE AVEC SANS-GÊNE ET CHAPEAU DE COTILLON",NULL},
/* 1F974 */ { "VISAGE AUX YEUX INÉGAUX ET À LA BOUCHE ONDULÉE",NULL},
/* 1F975 */ { "VISAGE EN SURCHAUFFE",NULL},
/* 1F976 */ { "VISAGE EN CONGÉLATION",NULL},
/* 1F977 */ { "NINJA",NULL},
/* 1F978 */ { "VISAGE MASQUÉ",NULL},
/* 1F979 */ { "VISAGE RETENANT DES LARMES",NULL},
/* 1F97A */ { "VISAGE AUX YEUX IMPLORANT",NULL},
/* 1F97B */ { "SARI",NULL},
/* 1F97C */ { "BLOUSE DE LABORATOIRE",NULL},
/* 1F97D */ { "LUNETTES PROTECTRICES","	= lunettes à coques"},
/* 1F97E */ { "CHAUSSURE DE RANDONNÉE",NULL},
/* 1F97F */ { "CHAUSSURE PLATE",NULL},
/* 1F980 */ { "CRABE","	* s'utilise pour le signe du Cancer\n"
	"	x (cancer - 264B)"},
/* 1F981 */ { "FACE DE LION","	* s'utilise pour le signe du Lion\n"
	"	x (lion - 264C)"},
/* 1F982 */ { "SYMBOLE SCORPION","	* s'utilise pour le signe du Scorpion\n"
	"	x (scorpion - 264F)"},
/* 1F983 */ { "DINDE",NULL},
/* 1F984 */ { "FACE DE LICORNE",NULL},
/* 1F985 */ { "AIGLE",NULL},
/* 1F986 */ { "CANARD",NULL},
/* 1F987 */ { "CHAUVE-SOURIS",NULL},
/* 1F988 */ { "REQUIN",NULL},
/* 1F989 */ { "HIBOU",NULL},
/* 1F98A */ { "FACE DE RENARD",NULL},
/* 1F98B */ { "PAPILLON",NULL},
/* 1F98C */ { "CERF",NULL},
/* 1F98D */ { "GORILLE",NULL},
/* 1F98E */ { "LÉZARD",NULL},
/* 1F98F */ { "RHINOCÉROS",NULL},
/* 1F990 */ { "CREVETTE",NULL},
/* 1F991 */ { "CALAMAR",NULL},
/* 1F992 */ { "FACE DE GIRAFE",NULL},
/* 1F993 */ { "FACE DE ZÈBRE",NULL},
/* 1F994 */ { "HÉRISSON",NULL},
/* 1F995 */ { "SAUROPODE","	* inclut le brontosaure, le diplodocus, le brachiosaure"},
/* 1F996 */ { "TYRANNOSAURE","	= Tyrannosaurus rex, T. rex, T-Rex (véhiculaire)"},
/* 1F997 */ { "CRIQUET",NULL},
/* 1F998 */ { "KANGOUROU",NULL},
/* 1F999 */ { "LAMA",NULL},
/* 1F99A */ { "PAON",NULL},
/* 1F99B */ { "HIPPOPOTAME",NULL},
/* 1F99C */ { "PERROQUET",NULL},
/* 1F99D */ { "RATON LAVEUR",NULL},
/* 1F99E */ { "HOMARD",NULL},
/* 1F99F */ { "MOUSTIQUE",NULL},
/* 1F9A0 */ { "MICROBE","	* micro-organisme ; destiné à englober les bactéries, les virus, les amibes, etc."},
/* 1F9A1 */ { "BLAIREAU",NULL},
/* 1F9A2 */ { "CYGNE",NULL},
/* 1F9A3 */ { "MAMMOUTH","	* désigne une grande taille"},
/* 1F9A4 */ { "DODO","	= dronte de Maurice\n"
	"	* désigne l'extinction"},
/* 1F9A5 */ { "PARESSEUX","	= aï, bradype, paresseux tridactyle\n"
	"	= unau, paresseux didactyle"},
/* 1F9A6 */ { "LOUTRE",NULL},
/* 1F9A7 */ { "ORANG-OUTAN",NULL},
/* 1F9A8 */ { "MOUFETTE",NULL},
/* 1F9A9 */ { "FLAMANT ROSE",NULL},
/* 1F9AA */ { "HUÎTRE",NULL},
/* 1F9AB */ { "CASTOR",NULL},
/* 1F9AC */ { "BISON",NULL},
/* 1F9AD */ { "PHOQUE",NULL},
/* 1F9AE */ { "CHIEN GUIDE",NULL},
/* 1F9AF */ { "CANNE BLANCHE",NULL},
/* 1F9B0 */ { "ÉLÉMENT D'ÉMOJI CHEVEUX ROUX",NULL},
/* 1F9B1 */ { "ÉLÉMENT D'ÉMOJI CHEVEUX BOUCLÉS",NULL},
/* 1F9B2 */ { "ÉLÉMENT D'ÉMOJI CHAUVE",NULL},
/* 1F9B3 */ { "ÉLÉMENT D'ÉMOJI CHEVEUX BLANCS",NULL},
/* 1F9B4 */ { "OS",NULL},
/* 1F9B5 */ { "JAMBE",NULL},
/* 1F9B6 */ { "PIED",NULL},
/* 1F9B7 */ { "DENT",NULL},
/* 1F9B8 */ { "SUPER-HÉROS","	= super-héroïne"},
/* 1F9B9 */ { "SUPER-MÉCHANT","	= super-méchante"},
/* 1F9BA */ { "GILET DE SÉCURITÉ",NULL},
/* 1F9BB */ { "OREILLE AVEC APPAREIL AUDITIF",NULL},
/* 1F9BC */ { "FAUTEUIL ROULANT MOTORISÉ",NULL},
/* 1F9BD */ { "FAUTEUIL ROULANT MANUEL",NULL},
/* 1F9BE */ { "BRAS MÉCANIQUE",NULL},
/* 1F9BF */ { "JAMBE MÉCANIQUE",NULL},
/* 1F9C0 */ { "POINTE DE FROMAGE",NULL},
/* 1F9C1 */ { "CUPCAKE","	= petit gâteau (Canada)"},
/* 1F9C2 */ { "SALIÈRE",NULL},
/* 1F9C3 */ { "BOISSON EN BRIQUE",NULL},
/* 1F9C4 */ { "AIL",NULL},
/* 1F9C5 */ { "OIGNON",NULL},
/* 1F9C6 */ { "FALAFEL",NULL},
/* 1F9C7 */ { "GAUFFRE",NULL},
/* 1F9C8 */ { "BEURRE",NULL},
/* 1F9C9 */ { "MATÉ","	* en français, le maté est aussi désigné par les locutions « thé des jésuites », « thé du Paraguay » et « thé du Brésil »"},
/* 1F9CA */ { "GLAÇON","	= cube de glace"},
/* 1F9CB */ { "THÉ AUX PERLES","	= zenzou"},
/* 1F9CC */ { "TROLL",NULL},
/* 1F9CD */ { "PERSONNE EN POSITION DEBOUT",NULL},
/* 1F9CE */ { "PERSONNE AGENOUILLÉE",NULL},
/* 1F9CF */ { "PERSONNE SOURDE",NULL},
/* 1F9D0 */ { "VISAGE AVEC MONOCLE",NULL},
/* 1F9D1 */ { "ADULTE","	* le genre n'est pas spécifié\n"
	"	x (homme - 1F468)\n"
	"	x (femme - 1F469)"},
/* 1F9D2 */ { "ENFANT","	* le genre n'est pas spécifié\n"
	"	x (garçon - 1F466)\n"
	"	x (fille - 1F467)"},
/* 1F9D3 */ { "ADULTE ÂGÉ","	* le genre n'est pas spécifié\n"
	"	x (homme âgé - 1F474)\n"
	"	x (femme âgée - 1F475)"},
/* 1F9D4 */ { "PERSONNE BARBUE",NULL},
/* 1F9D5 */ { "PERSONNE AVEC FOULARD","	= voile, hijab"},
/* 1F9D6 */ { "PERSONNE DANS UNE PIÈCE HUMIDE","	= sauna, hammam"},
/* 1F9D7 */ { "ALPINISTE",NULL},
/* 1F9D8 */ { "PERSONNE DANS LA POSITION DU LOTUS","	= yoga, méditation"},
/* 1F9D9 */ { "MAGE","	= magicien, magicienne, sorcier, sorcière"},
/* 1F9DA */ { "FÉE",NULL},
/* 1F9DB */ { "VAMPIRE",NULL},
/* 1F9DC */ { "CRÉATURE MI-HOMME MI-POISSON","	= sirène, Triton"},
/* 1F9DD */ { "ELFE",NULL},
/* 1F9DE */ { "GÉNIE","	= djinn"},
/* 1F9DF */ { "ZOMBIE","	= mort-vivant"},
/* 1F9E0 */ { "CERVEAU",NULL},
/* 1F9E1 */ { "CŒUR ORANGE","	x (cœur bleu - 1F499)\n"
	"	x (cœur blanc - 1F90D)"},
/* 1F9E2 */ { "CASQUETTE À VISIÈRE","	= casquette de baseball"},
/* 1F9E3 */ { "ÉCHARPE",NULL},
/* 1F9E4 */ { "GANTS",NULL},
/* 1F9E5 */ { "MANTEAU",NULL},
/* 1F9E6 */ { "CHAUSSETTES",NULL},
/* 1F9E7 */ { "ENVELOPPE-CADEAU ROUGE","	= enveloppe rouge chinoise\n"
	"	= paquet rouge\n"
	"	* contient un don d'argent en Asie de l'Est et du Sud-Est"},
/* 1F9E8 */ { "PÉTARD",NULL},
/* 1F9E9 */ { "PIÈCE DE PUZZLE",NULL},
/* 1F9EA */ { "TUBE À ESSAI",NULL},
/* 1F9EB */ { "BOÎTE DE PETRI",NULL},
/* 1F9EC */ { "DOUBLE HÉLICE D'ADN",NULL},
/* 1F9ED */ { "BOUSSOLE",NULL},
/* 1F9EE */ { "ABAQUE",NULL},
/* 1F9EF */ { "EXTINCTEUR",NULL},
/* 1F9F0 */ { "BOÎTE À OUTILS",NULL},
/* 1F9F1 */ { "BRIQUE",NULL},
/* 1F9F2 */ { "AIMANT",NULL},
/* 1F9F3 */ { "BAGAGE",NULL},
/* 1F9F4 */ { "BOUTEILLE À LOTION",NULL},
/* 1F9F5 */ { "BOBINE DE FIL",NULL},
/* 1F9F6 */ { "PELOTE DE LAINE",NULL},
/* 1F9F7 */ { "ÉPINGLE DE SÛRETÉ","	= épingle à nourrice, épingle de nourrice"},
/* 1F9F8 */ { "OURS EN PELUCHE",NULL},
/* 1F9F9 */ { "BALAI",NULL},
/* 1F9FA */ { "PANIER",NULL},
/* 1F9FB */ { "ROULEAU DE PAPIER",NULL},
/* 1F9FC */ { "PAIN DE SAVON",NULL},
/* 1F9FD */ { "ÉPONGE",NULL},
/* 1F9FE */ { "REÇU",NULL},
/* 1F9FF */ { "AMULETTE DU MAUVAIS ŒIL","	= nazar boncuk, amulette de nazar\n"
	"	= œil turc"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_FA[] = {
/* 1FA00 */ { "ROI NEUTRE DU JEU D'ÉCHECS","	x (roi blanc du jeu d'échecs - 2654)"},
/* 1FA01 */ { "DAME NEUTRE DU JEU D'ÉCHECS",NULL},
/* 1FA02 */ { "TOUR NEUTRE DU JEU D'ÉCHECS",NULL},
/* 1FA03 */ { "FOU NEUTRE DU JEU D'ÉCHECS",NULL},
/* 1FA04 */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS",NULL},
/* 1FA05 */ { "PION NEUTRE DU JEU D'ÉCHECS",NULL},
/* 1FA06 */ { "CAVALIER BLANC DU JEU D'ÉCHECS PIVOTÉ DE QUARANTE-CINQ DEGRÉS",NULL},
/* 1FA07 */ { "CAVALIER NOIR DU JEU D'ÉCHECS PIVOTÉ DE QUARANTE-CINQ DEGRÉS",NULL},
/* 1FA08 */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE QUARANTE-CINQ DEGRÉS",NULL},
/* 1FA09 */ { "ROI BLANC DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= roi blanc du jeu d'échecs pivoté de nonante degrés"},
/* 1FA0A */ { "DAME BLANCHE DU JEU D'ÉCHECS PIVOTÉE DE QUATRE-VINGT-DIX DEGRÉS","	= dame blanche du jeu d'échecs pivotée de nonante degrés"},
/* 1FA0B */ { "TOUR BLANCHE DU JEU D'ÉCHECS PIVOTÉE DE QUATRE-VINGT-DIX DEGRÉS","	= tour blanche du jeu d'échecs pivotée de nonante degrés"},
/* 1FA0C */ { "FOU BLANC DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= fou blanc du jeu d'échecs pivoté de nonante degrés"},
/* 1FA0D */ { "CAVALIER BLANC DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= cavalier blanc du jeu d'échecs pivoté de nonante degrés"},
/* 1FA0E */ { "PION BLANC DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= pion blanc du jeu d'échecs pivoté de nonante degrés"},
/* 1FA0F */ { "ROI NOIR DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= roi noir du jeu d'échecs pivoté de nonante degrés"},
/* 1FA10 */ { "DAME NOIRE DU JEU D'ÉCHECS PIVOTÉE DE QUATRE-VINGT-DIX DEGRÉS","	= dame noire du jeu d'échecs pivotée de nonante degrés"},
/* 1FA11 */ { "TOUR NOIRE DU JEU D'ÉCHECS PIVOTÉE DE QUATRE-VINGT-DIX DEGRÉS","	= tour noire du jeu d'échecs pivotée de nonante degrés"},
/* 1FA12 */ { "FOU NOIR DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= fou noir du jeu d'échecs pivoté de nonante degrés"},
/* 1FA13 */ { "CAVALIER NOIR DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= cavalier noir du jeu d'échecs pivoté de nonante degrés"},
/* 1FA14 */ { "PION NOIR DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= pion noir du jeu d'échecs pivoté de nonante degrés"},
/* 1FA15 */ { "ROI NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= roi neutre du jeu d'échecs pivoté de nonante degrés"},
/* 1FA16 */ { "DAME NEUTRE DU JEU D'ÉCHECS PIVOTÉE DE QUATRE-VINGT-DIX DEGRÉS","	= dame neutre du jeu d'échecs pivotée de nonante degrés"},
/* 1FA17 */ { "TOUR NEUTRE DU JEU D'ÉCHECS PIVOTÉE DE QUATRE-VINGT-DIX DEGRÉS","	= tour neutre du jeu d'échecs pivotée de nonante degrés"},
/* 1FA18 */ { "FOU NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= fou neutre du jeu d'échecs pivoté de nonante degrés"},
/* 1FA19 */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= cavalier neutre du jeu d'échecs pivoté de nonante degrés"},
/* 1FA1A */ { "PION NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= pion neutre du jeu d'échecs pivoté de nonante degrés"},
/* 1FA1B */ { "CAVALIER BLANC DU JEU D'ÉCHECS PIVOTÉ DE CENT TRENTE-CINQ DEGRÉS",NULL},
/* 1FA1C */ { "CAVALIER NOIR DU JEU D'ÉCHECS PIVOTÉ DE CENT TRENTE-CINQ DEGRÉS",NULL},
/* 1FA1D */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE CENT TRENTE-CINQ DEGRÉS",NULL},
/* 1FA1E */ { "ROI BLANC DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA1F */ { "DAME BLANCHE DU JEU D'ÉCHECS CULBUTÉE","	= sauterelle blanche"},
/* 1FA20 */ { "TOUR BLANCHE DU JEU D'ÉCHECS CULBUTÉE",NULL},
/* 1FA21 */ { "FOU BLANC DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA22 */ { "CAVALIER BLANC DU JEU D'ÉCHECS CULBUTÉ","	= noctambule blanc, cavalier de la nuit blanc"},
/* 1FA23 */ { "PION BLANC DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA24 */ { "ROI NOIR DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA25 */ { "DAME NOIRE DU JEU D'ÉCHECS CULBUTÉE","	= sauterelle noire"},
/* 1FA26 */ { "TOUR NOIRE DU JEU D'ÉCHECS CULBUTÉE",NULL},
/* 1FA27 */ { "FOU NOIR DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA28 */ { "CAVALIER NOIR DU JEU D'ÉCHECS CULBUTÉ","	= noctambule noir, cavalier de la nuit noir"},
/* 1FA29 */ { "PION NOIR DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA2A */ { "ROI NEUTRE DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA2B */ { "DAME NEUTRE DU JEU D'ÉCHECS CULBUTÉE","	= sauterelle neutre"},
/* 1FA2C */ { "TOUR NEUTRE DU JEU D'ÉCHECS CULBUTÉE",NULL},
/* 1FA2D */ { "FOU NEUTRE DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA2E */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS CULBUTÉ","	= noctambule neutre, cavalier de la nuit neutre"},
/* 1FA2F */ { "PION NEUTRE DU JEU D'ÉCHECS CULBUTÉ",NULL},
/* 1FA30 */ { "CAVALIER BLANC DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT VINGT-CINQ DEGRÉS",NULL},
/* 1FA31 */ { "CAVALIER NOIR DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT VINGT-CINQ DEGRÉS",NULL},
/* 1FA32 */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT VINGT-CINQ DEGRÉS",NULL},
/* 1FA33 */ { "ROI BLANC DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= roi blanc du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA34 */ { "DAME BLANCHE DU JEU D'ÉCHECS TOURNÉE DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= dame blanche du jeu d'échecs pivotée de deux cent septante degrés"},
/* 1FA35 */ { "TOUR BLANCHE DU JEU D'ÉCHECS TOURNÉE DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= tour blanche du jeu d'échecs pivotée de deux cent septante degrés"},
/* 1FA36 */ { "FOU BLANC DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= fou blanc du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA37 */ { "CAVALIER BLANC DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= cavalier blanc du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA38 */ { "PION BLANC DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= pion blanc du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA39 */ { "ROI NOIR DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= roi noir du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA3A */ { "DAME NOIRE DU JEU D'ÉCHECS TOURNÉE DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= dame noire du jeu d'échecs tournée de deux cent septante degrés"},
/* 1FA3B */ { "TOUR NOIRE DU JEU D'ÉCHECS TOURNÉE DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= tour noire du jeu d'échecs tournée de deux cent septante degrés"},
/* 1FA3C */ { "FOU NOIR DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= fou noir du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA3D */ { "CAVALIER NOIR DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= cavalier noir du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA3E */ { "PION NOIR DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= pion noir du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA3F */ { "ROI NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= roi neutre du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA40 */ { "DAME NEUTRE DU JEU D'ÉCHECS TOURNÉE DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= dame neutre du jeu d'échecs pivotée de deux cent septante degrés"},
/* 1FA41 */ { "TOUR NEUTRE DU JEU D'ÉCHECS TOURNÉE DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= tour neutre du jeu d'échecs pivotée de deux cent septante degrés"},
/* 1FA42 */ { "FOU NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= fou neutre du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA43 */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= cavalier neutre du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA44 */ { "PION NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE DEUX CENT SOIXANTE-DIX DEGRÉS","	= pion neutre du jeu d'échecs pivoté de deux cent septante degrés"},
/* 1FA45 */ { "CAVALIER BLANC DU JEU D'ÉCHECS PIVOTÉ DE TROIS CENT QUINZE DEGRÉS",NULL},
/* 1FA46 */ { "CAVALIER NOIR DU JEU D'ÉCHECS PIVOTÉ DE TROIS CENT QUINZE DEGRÉS",NULL},
/* 1FA47 */ { "CAVALIER NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE TROIS CENT QUINZE DEGRÉS",NULL},
/* 1FA48 */ { "ÉQUISAUTEUR BLANC DU JEU D'ÉCHECS",NULL},
/* 1FA49 */ { "ÉQUISAUTEUR NOIR DU JEU D'ÉCHECS",NULL},
/* 1FA4A */ { "ÉQUISAUTEUR NEUTRE DU JEU D'ÉCHECS",NULL},
/* 1FA4B */ { "ÉQUISAUTEUR BLANC DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= équisauteur blanc du jeu d'échecs pivoté de nonante degrés\n"
	"	x (sablier - 231B)"},
/* 1FA4C */ { "ÉQUISAUTEUR NOIR DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= équisauteur noir du jeu d'échecs pivoté de nonante degrés"},
/* 1FA4D */ { "ÉQUISAUTEUR NEUTRE DU JEU D'ÉCHECS PIVOTÉ DE QUATRE-VINGT-DIX DEGRÉS","	= équisauteur neutre du jeu d'échecs pivoté de nonante degrés"},
/* 1FA4E */ { "CAVALIER-DAME BLANC DU JEU D'ÉCHECS","	= amazone, terreur, reine omnipotente"},
/* 1FA4F */ { "CAVALIER-TOUR BLANC DU JEU D'ÉCHECS","	= chancelier, impératrice"},
/* 1FA50 */ { "CAVALIER-FOU BLANC DU JEU D'ÉCHECS","	= cardinal, princesse, centaure\n"
	"	* peut prendre la forme d'une mitre ou d'une barrette"},
/* 1FA51 */ { "CAVALIER-DAME NOIR DU JEU D'ÉCHECS",NULL},
/* 1FA52 */ { "CAVALIER-TOUR NOIR DU JEU D'ÉCHECS",NULL},
/* 1FA53 */ { "CAVALIER-FOU NOIR DU JEU D'ÉCHECS",NULL},
/* 1FA54 */ { "FERZ BLANC DU JEU D'ÉCHECS",NULL},
/* 1FA55 */ { "ALFIL BLANC DU JEU D'ÉCHECS","	= éléphant blanc"},
/* 1FA56 */ { "FERZ NOIR DU JEU D'ÉCHECS",NULL},
/* 1FA57 */ { "ALFIL NOIR DU JEU D'ÉCHECS","	= éléphant noir"},
/* 1FA58 */ { NULL,NULL},
/* 1FA59 */ { NULL,NULL},
/* 1FA5A */ { NULL,NULL},
/* 1FA5B */ { NULL,NULL},
/* 1FA5C */ { NULL,NULL},
/* 1FA5D */ { NULL,NULL},
/* 1FA5E */ { NULL,NULL},
/* 1FA5F */ { NULL,NULL},
/* 1FA60 */ { "GÉNÉRAL ROUGE DU XIANGQI","	= hóng shuài\n"
	"	* le motif montre généralement 5E25 ou 5E05\n"
	"	* le motif montre parfois 5C07 (dynastie Yuan)"},
/* 1FA61 */ { "MANDARIN ROUGE DU XIANGQI","	= hóng shì\n"
	"	* le motif montre généralement 4ED5\n"
	"	* le motif montre parfois 58EB"},
/* 1FA62 */ { "ÉLÉPHANT ROUGE DU XIANGQI","	= hóng xiàng\n"
	"	* le motif montre généralement 76F8\n"
	"	* le motif montre parfois 8C61 (dynastie Yuan)"},
/* 1FA63 */ { "CHEVAL ROUGE DU XIANGQI","	= hóng mǎ\n"
	"	* le motif montre généralement 99AC ou 9A6C\n"
	"	* le motif montre parfois 508C"},
/* 1FA64 */ { "CHARIOT ROUGE DU XIANGQI","	= hóng jū\n"
	"	* le motif montre généralement 8ECA ou 8F66\n"
	"	* le motif montre parfois 4FE5"},
/* 1FA65 */ { "CANON ROUGE DU XIANGQI","	= hóng pào\n"
	"	* le motif montre généralement 70AE ou 792E\n"
	"	* le motif montre parfois 7832\n"
	"	* le motif montre parfois 5305 (dynastie Ming)"},
/* 1FA66 */ { "SOLDAT ROUGE DU XIANGQI","	= hóng bīng\n"
	"	* le motif montre généralement 5175\n"
	"	* le motif montre parfois 5352 (dynasties Yuan et Ming)"},
/* 1FA67 */ { "GÉNÉRAL NOIR DU XIANGQI","	= hēi jiàng\n"
	"	* le motif montre généralement 5C07 ou 5C06"},
/* 1FA68 */ { "MANDARIN NOIR DU XIANGQI","	= hēi shì\n"
	"	* le motif montre généralement 58EB"},
/* 1FA69 */ { "ÉLÉPHANT NOIR DU XIANGQI","	= hēi xiàng\n"
	"	* le motif montre généralement 8C61"},
/* 1FA6A */ { "CHEVAL NOIR DU XIANGQI","	= hēi mǎ\n"
	"	* le motif montre généralement 99AC ou 9A6C"},
/* 1FA6B */ { "CHARIOT NOIR DU XIANGQI","	= hēi jū\n"
	"	* le motif montre généralement 8ECA ou 8F66"},
/* 1FA6C */ { "CANON NOIR DU XIANGQI","	= hēi pào\n"
	"	* le motif montre généralement 7832\n"
	"	* le motif montre parfois 70AE"},
/* 1FA6D */ { "SOLDAT NOIR DU XIANGQI","	= hēi zú\n"
	"	* le motif montre généralement 5352\n"
	"	* le motif montre parfois 5175 (dynasties Yuan et Ming)"},
/* 1FA6E */ { NULL,NULL},
/* 1FA6F */ { NULL,NULL},
/* 1FA70 */ { "CHAUSSONS DE DANSE CLASSIQUE","	= pointes, demi-pointes"},
/* 1FA71 */ { "MAILLOT DE BAIN UNE PIÈCE",NULL},
/* 1FA72 */ { "SLIP",NULL},
/* 1FA73 */ { "SHORT",NULL},
/* 1FA74 */ { "TONG","	= sandale d'été\n"
	"	= gougoune (Canada)\n"
	"	= claquette (France d'outre-mer)"},
/* 1FA75 */ { "CŒUR BLEU CLAIR",NULL},
/* 1FA76 */ { "CŒUR GRIS",NULL},
/* 1FA77 */ { "CŒUR ROSE",NULL},
/* 1FA78 */ { "GOUTTE DE SANG","	x (gouttelette - 1F4A7)"},
/* 1FA79 */ { "PANSEMENT ADHÉSIF","	= sparadrap"},
/* 1FA7A */ { "STÉTHOSCOPE",NULL},
/* 1FA7B */ { "RAYON X",NULL},
/* 1FA7C */ { "BÉQUILLE",NULL},
/* 1FA7D */ { NULL,NULL},
/* 1FA7E */ { NULL,NULL},
/* 1FA7F */ { NULL,NULL},
/* 1FA80 */ { "YO-YO",NULL},
/* 1FA81 */ { "CERF-VOLANT",NULL},
/* 1FA82 */ { "PARACHUTE",NULL},
/* 1FA83 */ { "BOOMERANG",NULL},
/* 1FA84 */ { "BAGUETTE MAGIQUE",NULL},
/* 1FA85 */ { "PIÑATA",NULL},
/* 1FA86 */ { "POUPÉES RUSSES",NULL},
/* 1FA87 */ { "MARACAS",NULL},
/* 1FA88 */ { "FLÛTE",NULL},
/* 1FA89 */ { "HARPE",NULL},
/* 1FA8A */ { "TROMBONE À COULISSE",NULL},
/* 1FA8B */ { NULL,NULL},
/* 1FA8C */ { NULL,NULL},
/* 1FA8D */ { NULL,NULL},
/* 1FA8E */ { "COFFRE AU TRÉSOR",NULL},
/* 1FA8F */ { "PELLE",NULL},
/* 1FA90 */ { "PLANÈTE À ANNEAUX",NULL},
/* 1FA91 */ { "CHAISE",NULL},
/* 1FA92 */ { "RASOIR",NULL},
/* 1FA93 */ { "HACHE",NULL},
/* 1FA94 */ { "DIYA","	* lampe à huile originaire de l'Inde"},
/* 1FA95 */ { "BANJO",NULL},
/* 1FA96 */ { "CASQUE MILITAIRE",NULL},
/* 1FA97 */ { "ACCORDÉON",NULL},
/* 1FA98 */ { "TAMBOUR À LONG FÛT","	= conga, djembé"},
/* 1FA99 */ { "PIÈCE DE MONNAIE",NULL},
/* 1FA9A */ { "SCIE DE CHARPENTIER",NULL},
/* 1FA9B */ { "TOURNEVIS",NULL},
/* 1FA9C */ { "ÉCHELLE",NULL},
/* 1FA9D */ { "CROCHET",NULL},
/* 1FA9E */ { "MIROIR",NULL},
/* 1FA9F */ { "FENÊTRE",NULL},
/* 1FAA0 */ { "VENTOUSE","	= déboucheur"},
/* 1FAA1 */ { "AIGUILLE À COUDRE",NULL},
/* 1FAA2 */ { "NŒUD",NULL},
/* 1FAA3 */ { "SEAU",NULL},
/* 1FAA4 */ { "PIÈGE À SOURIS",NULL},
/* 1FAA5 */ { "BROSSE À DENTS",NULL},
/* 1FAA6 */ { "PIERRE TOMBALE",NULL},
/* 1FAA7 */ { "PANCARTE",NULL},
/* 1FAA8 */ { "ROC","	= rocher, roche, pierre, caillou"},
/* 1FAA9 */ { "BOULE À FACETTES","	= boule à miroirs"},
/* 1FAAA */ { "CARTE D'IDENTITÉ",NULL},
/* 1FAAB */ { "BATTERIE FAIBLE","	x (pile - 1F50B)"},
/* 1FAAC */ { "KHAMSA","	= tafust\n"
	"	= main de Fatma, main de Fatima"},
/* 1FAAD */ { "ÉVENTAIL PLIABLE",NULL},
/* 1FAAE */ { "PEIGNE À LONGUES DENTS",NULL},
/* 1FAAF */ { "KHANDA","	x (âdi çakti - 262C)"},
/* 1FAB0 */ { "MOUCHE",NULL},
/* 1FAB1 */ { "VER",NULL},
/* 1FAB2 */ { "COLÉOPTÈRE",NULL},
/* 1FAB3 */ { "CANCRELAT","	= cafard, blatte"},
/* 1FAB4 */ { "PLANTE EN POT",NULL},
/* 1FAB5 */ { "BOIS",NULL},
/* 1FAB6 */ { "PLUME",NULL},
/* 1FAB7 */ { "LOTUS",NULL},
/* 1FAB8 */ { "CORAIL",NULL},
/* 1FAB9 */ { "NID VIDE",NULL},
/* 1FABA */ { "NID CONTENANT DES ŒUFS",NULL},
/* 1FABB */ { "JACINTHE",NULL},
/* 1FABC */ { "MÉDUSE",NULL},
/* 1FABD */ { "AILE",NULL},
/* 1FABE */ { "ARBRE SANS FEUILLES",NULL},
/* 1FABF */ { "OIE",NULL},
/* 1FAC0 */ { "CŒUR ANATOMIQUE",NULL},
/* 1FAC1 */ { "POUMONS",NULL},
/* 1FAC2 */ { "PERSONNES S'ÉTREIGNANT",NULL},
/* 1FAC3 */ { "HOMME ENCEINT",NULL},
/* 1FAC4 */ { "PERSONNE ENCEINTE","	x (femme enceinte - 1F930)"},
/* 1FAC5 */ { "TÊTE COURONNÉE","	x (princesse - 1F478)"},
/* 1FAC6 */ { "EMPREINTE DIGITALE",NULL},
/* 1FAC7 */ { NULL,NULL},
/* 1FAC8 */ { "CRÉATURE POILUE",NULL},
/* 1FAC9 */ { NULL,NULL},
/* 1FACA */ { NULL,NULL},
/* 1FACB */ { NULL,NULL},
/* 1FACC */ { NULL,NULL},
/* 1FACD */ { "ORQUE",NULL},
/* 1FACE */ { "ORIGNAL","	= élan\n"
	"	* l'animal est appelé « élan » en Europe et « orignal » en Amérique du Nord"},
/* 1FACF */ { "ÂNE","	= bourricot"},
/* 1FAD0 */ { "MYRTILLES","	= bleuets (Canada)"},
/* 1FAD1 */ { "POIVRON",NULL},
/* 1FAD2 */ { "OLIVE",NULL},
/* 1FAD3 */ { "PAIN PLAT",NULL},
/* 1FAD4 */ { "TAMAL","	= humita, huminta, hallaca, etc."},
/* 1FAD5 */ { "FONDUE",NULL},
/* 1FAD6 */ { "THÉIÈRE",NULL},
/* 1FAD7 */ { "VERSER UN LIQUIDE","	x (verre de lait - 1F95B)"},
/* 1FAD8 */ { "LÉGUMES SECS","	= grains, fèves, haricots"},
/* 1FAD9 */ { "POT","	= récipient, bocal"},
/* 1FADA */ { "RACINE DE GINGEMBRE",NULL},
/* 1FADB */ { "POIS MANGE-TOUT","	= pois gourmand, pois sans parchemin"},
/* 1FADC */ { "LÉGUME-RACINE",NULL},
/* 1FADD */ { NULL,NULL},
/* 1FADE */ { NULL,NULL},
/* 1FADF */ { "ÉCLABOUSSURE",NULL},
/* 1FAE0 */ { "VISAGE FONDANT",NULL},
/* 1FAE1 */ { "VISAGE SALUANT",NULL},
/* 1FAE2 */ { "VISAGE AVEC LES YEUX OUVERTS ET UNE MAIN SUR LA BOUCHE",NULL},
/* 1FAE3 */ { "VISAGE AVEC UN ŒIL QUI REGARDE",NULL},
/* 1FAE4 */ { "VISAGE AVEC LA BOUCHE EN BIAIS",NULL},
/* 1FAE5 */ { "VISAGE EN POINTILLÉ",NULL},
/* 1FAE6 */ { "LÈVRE MORDUE","	x (lèvres - 1F5E2)"},
/* 1FAE7 */ { "BULLES",NULL},
/* 1FAE8 */ { "VISAGE TREMBLANT",NULL},
/* 1FAE9 */ { "VISAGE AVEC DES POCHES SOUS LES YEUX",NULL},
/* 1FAEA */ { "VISAGE DÉFORMÉ",NULL},
/* 1FAEB */ { NULL,NULL},
/* 1FAEC */ { NULL,NULL},
/* 1FAED */ { NULL,NULL},
/* 1FAEE */ { NULL,NULL},
/* 1FAEF */ { "NUAGE DE BAGARRE",NULL},
/* 1FAF0 */ { "MAIN AVEC INDEX ET POUCE CROISÉS","	x (main avec index et majeur croisés - 1F91E)"},
/* 1FAF1 */ { "MAIN VERS LA DROITE",NULL},
/* 1FAF2 */ { "MAIN VERS LA GAUCHE",NULL},
/* 1FAF3 */ { "PAUME DE MAIN VERS LE BAS",NULL},
/* 1FAF4 */ { "PAUME DE MAIN VERS LE HAUT",NULL},
/* 1FAF5 */ { "INDEX POINTANT VERS LE SPECTATEUR",NULL},
/* 1FAF6 */ { "MAINS FORMANT UN CŒUR","	= cœur avec les mains, mains en cœur"},
/* 1FAF7 */ { "MAIN POUSSANT VERS LA GAUCHE",NULL},
/* 1FAF8 */ { "MAIN POUSSANT VERS LA DROITE",NULL},
/* 1FAF9 */ { NULL,NULL},
/* 1FAFA */ { NULL,NULL},
/* 1FAFB */ { NULL,NULL},
/* 1FAFC */ { NULL,NULL},
/* 1FAFD */ { NULL,NULL},
/* 1FAFE */ { NULL,NULL},
/* 1FAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_01_FB[] = {
/* 1FB00 */ { "SIXIÈME DE PAVÉ-1",NULL},
/* 1FB01 */ { "SIXIÈME DE PAVÉ-2",NULL},
/* 1FB02 */ { "SIXIÈME DE PAVÉ-12","	* tiers supérieur de pavé"},
/* 1FB03 */ { "SIXIÈME DE PAVÉ-3",NULL},
/* 1FB04 */ { "SIXIÈME DE PAVÉ-13",NULL},
/* 1FB05 */ { "SIXIÈME DE PAVÉ-23",NULL},
/* 1FB06 */ { "SIXIÈME DE PAVÉ-123",NULL},
/* 1FB07 */ { "SIXIÈME DE PAVÉ-4",NULL},
/* 1FB08 */ { "SIXIÈME DE PAVÉ-14",NULL},
/* 1FB09 */ { "SIXIÈME DE PAVÉ-24",NULL},
/* 1FB0A */ { "SIXIÈME DE PAVÉ-124",NULL},
/* 1FB0B */ { "SIXIÈME DE PAVÉ-34","	* tiers central de pavé"},
/* 1FB0C */ { "SIXIÈME DE PAVÉ-134",NULL},
/* 1FB0D */ { "SIXIÈME DE PAVÉ-234",NULL},
/* 1FB0E */ { "SIXIÈME DE PAVÉ-1234","	* deux tiers supérieurs de pavé"},
/* 1FB0F */ { "SIXIÈME DE PAVÉ-5",NULL},
/* 1FB10 */ { "SIXIÈME DE PAVÉ-15",NULL},
/* 1FB11 */ { "SIXIÈME DE PAVÉ-25",NULL},
/* 1FB12 */ { "SIXIÈME DE PAVÉ-125",NULL},
/* 1FB13 */ { "SIXIÈME DE PAVÉ-35",NULL},
/* 1FB14 */ { "SIXIÈME DE PAVÉ-235",NULL},
/* 1FB15 */ { "SIXIÈME DE PAVÉ-1235",NULL},
/* 1FB16 */ { "SIXIÈME DE PAVÉ-45",NULL},
/* 1FB17 */ { "SIXIÈME DE PAVÉ-145",NULL},
/* 1FB18 */ { "SIXIÈME DE PAVÉ-245",NULL},
/* 1FB19 */ { "SIXIÈME DE PAVÉ-1245",NULL},
/* 1FB1A */ { "SIXIÈME DE PAVÉ-345",NULL},
/* 1FB1B */ { "SIXIÈME DE PAVÉ-1345",NULL},
/* 1FB1C */ { "SIXIÈME DE PAVÉ-2345",NULL},
/* 1FB1D */ { "SIXIÈME DE PAVÉ-12345",NULL},
/* 1FB1E */ { "SIXIÈME DE PAVÉ-6",NULL},
/* 1FB1F */ { "SIXIÈME DE PAVÉ-16",NULL},
/* 1FB20 */ { "SIXIÈME DE PAVÉ-26",NULL},
/* 1FB21 */ { "SIXIÈME DE PAVÉ-126",NULL},
/* 1FB22 */ { "SIXIÈME DE PAVÉ-36",NULL},
/* 1FB23 */ { "SIXIÈME DE PAVÉ-136",NULL},
/* 1FB24 */ { "SIXIÈME DE PAVÉ-236",NULL},
/* 1FB25 */ { "SIXIÈME DE PAVÉ-1236",NULL},
/* 1FB26 */ { "SIXIÈME DE PAVÉ-46",NULL},
/* 1FB27 */ { "SIXIÈME DE PAVÉ-146",NULL},
/* 1FB28 */ { "SIXIÈME DE PAVÉ-1246",NULL},
/* 1FB29 */ { "SIXIÈME DE PAVÉ-346",NULL},
/* 1FB2A */ { "SIXIÈME DE PAVÉ-1346",NULL},
/* 1FB2B */ { "SIXIÈME DE PAVÉ-2346",NULL},
/* 1FB2C */ { "SIXIÈME DE PAVÉ-12346",NULL},
/* 1FB2D */ { "SIXIÈME DE PAVÉ-56","	* tiers inférieur de pavé"},
/* 1FB2E */ { "SIXIÈME DE PAVÉ-156",NULL},
/* 1FB2F */ { "SIXIÈME DE PAVÉ-256",NULL},
/* 1FB30 */ { "SIXIÈME DE PAVÉ-1256","	* tiers supérieur et tiers inférieur de pavé"},
/* 1FB31 */ { "SIXIÈME DE PAVÉ-356",NULL},
/* 1FB32 */ { "SIXIÈME DE PAVÉ-1356",NULL},
/* 1FB33 */ { "SIXIÈME DE PAVÉ-2356",NULL},
/* 1FB34 */ { "SIXIÈME DE PAVÉ-12356",NULL},
/* 1FB35 */ { "SIXIÈME DE PAVÉ-456",NULL},
/* 1FB36 */ { "SIXIÈME DE PAVÉ-1456",NULL},
/* 1FB37 */ { "SIXIÈME DE PAVÉ-2456",NULL},
/* 1FB38 */ { "SIXIÈME DE PAVÉ-12456",NULL},
/* 1FB39 */ { "SIXIÈME DE PAVÉ-3456","	* deux tiers inférieurs de pavé"},
/* 1FB3A */ { "SIXIÈME DE PAVÉ-13456",NULL},
/* 1FB3B */ { "SIXIÈME DE PAVÉ-23456",NULL},
/* 1FB3C */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FB3D */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU COIN INFÉRIEUR DROIT",NULL},
/* 1FB3E */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FB3F */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU COIN INFÉRIEUR DROIT",NULL},
/* 1FB40 */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU COIN SUPÉRIEUR GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FB41 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU CENTRE SUPÉRIEUR",NULL},
/* 1FB42 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FB43 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU CENTRE SUPÉRIEUR",NULL},
/* 1FB44 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FB45 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU COIN INFÉRIEUR DROIT AU CENTRE SUPÉRIEUR",NULL},
/* 1FB46 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB47 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU CENTRE INFÉRIEUR AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB48 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU COIN INFÉRIEUR GAUCHE AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB49 */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU CENTRE INFÉRIEUR AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB4A */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU COIN INFÉRIEUR GAUCHE AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB4B */ { "PAVÉ INFÉRIEUR DROIT À DIAGONALE DU CENTRE INFÉRIEUR AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FB4C */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU CENTRE SUPÉRIEUR AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB4D */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU COIN SUPÉRIEUR GAUCHE AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB4E */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU CENTRE SUPÉRIEUR AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB4F */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU COIN SUPÉRIEUR GAUCHE AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB50 */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU CENTRE SUPÉRIEUR AU COIN INFÉRIEUR DROIT",NULL},
/* 1FB51 */ { "PAVÉ INFÉRIEUR GAUCHE À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB52 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FB53 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU COIN INFÉRIEUR DROIT",NULL},
/* 1FB54 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FB55 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU COIN INFÉRIEUR DROIT",NULL},
/* 1FB56 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU COIN GAUCHE SUPÉRIEUR AU CENTRE INFÉRIEUR",NULL},
/* 1FB57 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU CENTRE SUPÉRIEUR",NULL},
/* 1FB58 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FB59 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU CENTRE SUPÉRIEUR",NULL},
/* 1FB5A */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FB5B */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU GAUCHE INFÉRIEURE AU CENTRE SUPÉRIEUR",NULL},
/* 1FB5C */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU INFÉRIEUR GAUCHE AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB5D */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU CENTRE INFÉRIEUR AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB5E */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU COIN INFÉRIEUR GAUCHE AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB5F */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU CENTRE INFÉRIEUR AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB60 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU COIN INFÉRIEUR GAUCHE AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB61 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU CENTRE INFÉRIEUR AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FB62 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU CENTRE SUPÉRIEUR AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB63 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU COIN GAUCHE SUPÉRIEUR AU MILIEU SUPÉRIEUR DROIT",NULL},
/* 1FB64 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU CENTRE SUPÉRIEUR AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB65 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU COIN GAUCHE SUPÉRIEUR AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB66 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU CENTRE SUPÉRIEUR AU COIN INFÉRIEUR DROIT",NULL},
/* 1FB67 */ { "PAVÉ SUPÉRIEUR DROIT À DIAGONALE DU MILIEU SUPÉRIEUR GAUCHE AU MILIEU INFÉRIEUR DROIT",NULL},
/* 1FB68 */ { "QUARTIERS TRIANGULAIRES SUPÉRIEUR ET DROIT ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FB69 */ { "QUARTIERS TRIANGULAIRES GAUCHE ET INFÉRIEUR ET DROIT DE PAVÉ",NULL},
/* 1FB6A */ { "QUARTIERS TRIANGULAIRES SUPÉRIEUR ET GAUCHE ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FB6B */ { "QUARTIERS TRIANGULAIRES GAUCHE ET SUPÉRIEUR ET DROIT DE PAVÉ",NULL},
/* 1FB6C */ { "QUARTIER TRIANGULAIRE GAUCHE DE PAVÉ",NULL},
/* 1FB6D */ { "QUARTIER TRIANGULAIRE SUPÉRIEUR DE PAVÉ",NULL},
/* 1FB6E */ { "QUARTIER TRIANGULAIRE DROIT DE PAVÉ",NULL},
/* 1FB6F */ { "QUARTIER TRIANGULAIRE INFÉRIEUR DE PAVÉ",NULL},
/* 1FB70 */ { "HUITIÈME VERTICAL DE PAVÉ-2","	x (un huitième gauche de pavé - 258F)"},
/* 1FB71 */ { "HUITIÈME VERTICAL DE PAVÉ-3",NULL},
/* 1FB72 */ { "HUITIÈME VERTICAL DE PAVÉ-4",NULL},
/* 1FB73 */ { "HUITIÈME VERTICAL DE PAVÉ-5",NULL},
/* 1FB74 */ { "HUITIÈME VERTICAL DE PAVÉ-6",NULL},
/* 1FB75 */ { "HUITIÈME VERTICAL DE PAVÉ-7","	x (un huitième droit de pavé - 2595)"},
/* 1FB76 */ { "HUITIÈME HORIZONTAL DE PAVÉ-2","	x (un huitième supérieur de pavé - 2594)"},
/* 1FB77 */ { "HUITIÈME HORIZONTAL DE PAVÉ-3",NULL},
/* 1FB78 */ { "HUITIÈME HORIZONTAL DE PAVÉ-4",NULL},
/* 1FB79 */ { "HUITIÈME HORIZONTAL DE PAVÉ-5",NULL},
/* 1FB7A */ { "HUITIÈME HORIZONTAL DE PAVÉ-6",NULL},
/* 1FB7B */ { "HUITIÈME HORIZONTAL DE PAVÉ-7","	x (un huitième inférieur de pavé - 2581)"},
/* 1FB7C */ { "HUITIÈMES GAUCHE ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FB7D */ { "HUITIÈMES GAUCHE ET SUPÉRIEUR DE PAVÉ",NULL},
/* 1FB7E */ { "HUITIÈMES DROIT ET SUPÉRIEUR DE PAVÉ",NULL},
/* 1FB7F */ { "HUITIÈMES DROIT ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FB80 */ { "HUITIÈMES SUPÉRIEUR ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FB81 */ { "HUITIÈME HORIZONTAL DE PAVÉ-1358",NULL},
/* 1FB82 */ { "UN QUART SUPÉRIEUR DE PAVÉ","	x (un quart inférieur de pavé - 2582)"},
/* 1FB83 */ { "TROIS HUITIÈMES SUPÉRIEURS DE PAVÉ","	x (trois huitièmes inférieurs de pavé - 2583)"},
/* 1FB84 */ { "CINQ HUITIÈMES SUPÉRIEURS DE PAVÉ","	x (cinq huitièmes inférieurs de pavé - 2585)"},
/* 1FB85 */ { "TROIS QUARTS SUPÉRIEURS DE PAVÉ","	x (trois quarts inférieurs de pavé - 2586)"},
/* 1FB86 */ { "SEPT HUITIÈMES SUPÉRIEURS DE PAVÉ","	x (sept huitièmes inférieurs de pavé - 2587)"},
/* 1FB87 */ { "UN QUART DROIT DE PAVÉ","	x (un quart gauche de pavé - 258E)"},
/* 1FB88 */ { "TROIS HUITIÈMES DROITS DE PAVÉ","	x (trois huitièmes gauches de pavé - 258D)"},
/* 1FB89 */ { "CINQ HUITIÈMES DROITS DE PAVÉ","	x (cinq huitièmes gauches de pavé - 258B)"},
/* 1FB8A */ { "TROIS QUARTS DROITS DE PAVÉ","	x (trois quarts gauches de pavé - 258A)"},
/* 1FB8B */ { "SEPT HUITIÈMES DROITS DE PAVÉ","	x (sept huitièmes gauches de pavé - 2589)"},
/* 1FB8C */ { "MOITIÉ GAUCHE D'OMBRE MOYENNE",NULL},
/* 1FB8D */ { "MOITIÉ DROITE D'OMBRE MOYENNE",NULL},
/* 1FB8E */ { "MOITIÉ SUPÉRIEURE D'OMBRE MOYENNE",NULL},
/* 1FB8F */ { "MOITIÉ INFÉRIEURE D'OMBRE MOYENNE",NULL},
/* 1FB90 */ { "OMBRE MOYENNE INVERSÉE","	x (ombre moyenne - 2592)"},
/* 1FB91 */ { "MOITIÉ SUPÉRIEURE DE PAVÉ ET MOITIÉ INFÉRIEURE D'OMBRE MOYENNE INVERSÉE",NULL},
/* 1FB92 */ { "MOITIÉ SUPÉRIEURE D'OMBRE MOYENNE INVERSÉE ET MOITIÉ INFÉRIEURE DE PAVÉ",NULL},
/* 1FB93 */ { NULL,NULL},
/* 1FB94 */ { "MOITIÉ GAUCHE D'OMBRE MOYENNE INVERSÉE ET MOITIÉ DROITE DE PAVÉ",NULL},
/* 1FB95 */ { "REMPLISSAGE ÉCHIQUETÉ","	= remplissage en damier\n"
	"	x (quartiers supérieur gauche et inférieur droit - 259A)\n"
	"	x (damier inversé - 1F67F)"},
/* 1FB96 */ { "REMPLISSAGE ÉCHIQUETÉ INVERSÉ","	= remplissage en damier inversé\n"
	"	x (quartiers supérieur droit et inférieur gauche - 259E)\n"
	"	x (damier - 1F67E)"},
/* 1FB97 */ { "REMPLISSAGE HORIZONTAL ÉPAIS","	* quart central supérieur et quart inférieur de pavé\n"
	"	x (signe geta - 3013)\n"
	"	x (huitième de pavé-3478 - 1CDB7)"},
/* 1FB98 */ { "REMPLISSAGE À RAYURES OBLIQUES DESCENDANT DE GAUCHE À DROITE","	x (carré à rayures obliques descendant de gauche à droite - 25A7)"},
/* 1FB99 */ { "REMPLISSAGE À RAYURES OBLIQUES DESCENDANT DE DROITE À GAUCHE","	x (carré à rayures obliques descendant de droite à gauche - 25A8)"},
/* 1FB9A */ { "MOITIÉS DE PAVÉ TRIANGULAIRES SUPÉRIEURE ET INFÉRIEURE","	x (sablier noir - 29D7)"},
/* 1FB9B */ { "MOITIÉS DE PAVÉ TRIANGULAIRES GAUCHE ET DROITE","	x (nœud papillon noir - 29D3)"},
/* 1FB9C */ { "OMBRE MOYENNE TRIANGULAIRE SUPÉRIEURE GAUCHE","	x (coin triangulaire noir supérieur gauche - 25E4)"},
/* 1FB9D */ { "OMBRE MOYENNE TRIANGULAIRE SUPÉRIEURE DROITE","	x (coin triangulaire noir supérieur droit - 25E5)"},
/* 1FB9E */ { "OMBRE MOYENNE TRIANGULAIRE INFÉRIEURE DROITE","	x (coin triangulaire noir inférieur droit - 25E2)"},
/* 1FB9F */ { "OMBRE MOYENNE TRIANGULAIRE INFÉRIEURE GAUCHE","	x (coin triangulaire noir inférieur gauche - 25E3)"},
/* 1FBA0 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU GAUCHE",NULL},
/* 1FBA1 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU DROIT",NULL},
/* 1FBA2 */ { "FILET FIN DIAGONAL DU MILIEU GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FBA3 */ { "FILET FIN DIAGONAL DU MILIEU DROIT AU CENTRE INFÉRIEUR",NULL},
/* 1FBA4 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FBA5 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU DROIT AU CENTRE INFÉRIEUR",NULL},
/* 1FBA6 */ { "FILET FIN DIAGONAL DU MILIEU GAUCHE AU CENTRE INFÉRIEUR AU MILIEU DROIT",NULL},
/* 1FBA7 */ { "FILET FIN DIAGONAL DU MILIEU GAUCHE AU CENTRE SUPÉRIEUR AU MILIEU DROIT",NULL},
/* 1FBA8 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU GAUCHE ET DU MILIEU DROIT AU CENTRE INFÉRIEUR",NULL},
/* 1FBA9 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU DROIT ET DU CENTRE GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FBAA */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU DROIT AU CENTRE INFÉRIEUR AU MILIEU GAUCHE",NULL},
/* 1FBAB */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU MILIEU GAUCHE AU CENTRE INFÉRIEUR AU MILIEU DROIT",NULL},
/* 1FBAC */ { "FILET FIN DIAGONAL DU MILIEU GAUCHE AU CENTRE SUPÉRIEUR AU MILIEU DROIT AU CENTRE INFÉRIEUR",NULL},
/* 1FBAD */ { "FILET FIN DIAGONAL DU MILIEU DROIT AU CENTRE SUPÉRIEUR AU CENTRE GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FBAE */ { "FILET FIN TRACÉ EN LOSANGE","	x (losange blanc - 25C7)"},
/* 1FBAF */ { "FILET FIN HORIZONTAL À BARRE VERTICALE","	x (filet fin horizontal - 2500)"},
/* 1FBB0 */ { "POINTEUR EN FORME DE TÊTE DE FLÈCHE","	x (pointe de flèche noire vers la droite - 27A4)"},
/* 1FBB1 */ { "COCHE NOIR AU BLANC","	x (coche - 2713)"},
/* 1FBB2 */ { "MOITIÉ GAUCHE DE COUREUR","	* jumelé à 1FBB3, orienté vers la droite\n"
	"	* « Running Man » (« Coureur ») dans la documentation d'Apple II\n"
	"	x (coureur - 1F3C3)"},
/* 1FBB3 */ { "MOITIÉ DROITE DE COUREUR",NULL},
/* 1FBB4 */ { "FLÈCHE VERS LE BAS À POINTE VERS LA GAUCHE NOIR AU BLANC","	x (flèche vers le bas à pointe vers la gauche - 21B2)\n"
	"	x (flèche vers le bas avec coin vers la gauche - 21B5)"},
/* 1FBB5 */ { "FLÈCHE VERS LA GAUCHE ET HUITIÈMES SUPÉRIEUR ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FBB6 */ { "FLÈCHE VERS LA DROITE ET HUITIÈMES SUPÉRIEUR ET INFÉRIEUR DE PAVÉ",NULL},
/* 1FBB7 */ { "FLÈCHE VERS LE BAS ET HUITIÈME DROIT DE PAVÉ",NULL},
/* 1FBB8 */ { "FLÈCHE VERS LE HAUT ET HUITIÈME DROIT DE PAVÉ",NULL},
/* 1FBB9 */ { "MOITIÉ GAUCHE DE DOSSIER","	* jumelé à 1FBBA\n"
	"	x (dossier - 1F4C1)\n"
	"	x (répertoire - 1F5C0)"},
/* 1FBBA */ { "MOITIÉ DROITE DE DOSSIER",NULL},
/* 1FBBB */ { "CROIX GRECQUE ÉVIDÉE","	x (croisillon - 0023)\n"
	"	x (filet double vertical et horizontal - 256C)\n"
	"	x (croix grecque avec contour - 2719)\n"
	"	x (croix grecque épaisse - 271A)\n"
	"	x (croix grecque demi-grasse - 1F7A3)"},
/* 1FBBC */ { "POINT DROIT PARTIELLEMENT ENCADRÉ","	x (opérateur point encadré - 22A1)"},
/* 1FBBD */ { "DIAGONALES BLANCHES TRACÉES EN CROIX","	* les diagonales s'étendent au-delà des coins de la cellule, contrairement à 274E\n"
	"	x (filet fin diagonal en croix - 2573)\n"
	"	x (signe en forme de croix encadré noir au blanc - 274E)"},
/* 1FBBE */ { "DIAGONALE BLANCHE DU MILIEU DROIT AU CENTRE INFÉRIEUR",NULL},
/* 1FBBF */ { "DIAGONALES BLANCHES TRACÉES EN LOSANGE",NULL},
/* 1FBC0 */ { "SAUTOIR BLANC ÉPAIS À COINS ARRONDIS","	x (signe en forme de croix - 274C)\n"
	"	x (x d'annulation - 1F5D9)\n"
	"	x (sautoir épais - 1F7AC)"},
/* 1FBC1 */ { "TIERS GAUCHE D'INDEX BLANC POINTANT VERS LA DROITE","	* partie de glyphe, jumelée à 1FBC2 et 1FBC3\n"
	"	x (index blanc pointant vers la droite - 261E)"},
/* 1FBC2 */ { "TIERS CENTRAL D'INDEX BLANC POINTANT VERS LA DROITE",NULL},
/* 1FBC3 */ { "TIERS DROIT D'INDEX BLANC POINTANT VERS LA DROITE",NULL},
/* 1FBC4 */ { "POINT D'INTERROGATION ENCADRÉ NOIR AU BLANC","	* le glyphe ne s'étend pas nécessairement jusqu'aux bords de la cellule du caractère\n"
	"	x (point d'interrogation - 003F)\n"
	"	x (signe d'incertitude - 2BD1)\n"
	"	x (caractère de remplacement - FFFD)"},
/* 1FBC5 */ { "BONHOMME ALLUMETTE","	x (symbole hommes - 1F6B9)"},
/* 1FBC6 */ { "BONHOMME ALLUMETTE AUX BRAS LEVÉS",NULL},
/* 1FBC7 */ { "BONHOMME ALLUMETTE PENCHÉ À GAUCHE",NULL},
/* 1FBC8 */ { "BONHOMME ALLUMETTE PENCHÉ À DROITE",NULL},
/* 1FBC9 */ { "BONHOMME ALLUMETTE AVEC ROBE","	x (symbole femmes - 1F6BA)"},
/* 1FBCA */ { "CHEVRON BLANC POINTANT VERS LE HAUT","	x (flèche blanche vers le haut - 21E7)\n"
	"	x (maison - 2302)\n"
	"	x (flèche signalisatrice vers le haut - 1F835)"},
/* 1FBCB */ { "SIGNE EN FORME DE CROIX BLANCHE",NULL},
/* 1FBCC */ { "PETIT CROCHET GAUCHE ÉLEVÉ",NULL},
/* 1FBCD */ { "PETIT CHEVRON NOIR POINTANT VERS LE HAUT",NULL},
/* 1FBCE */ { "DEUX TIERS GAUCHES DE PAVÉ",NULL},
/* 1FBCF */ { "UN TIERS GAUCHE DE PAVÉ",NULL},
/* 1FBD0 */ { "FILET FIN DIAGONAL DU MILIEU DROIT AU COIN INFÉRIEUR GAUCHE",NULL},
/* 1FBD1 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR DROIT AU MILIEU GAUCHE",NULL},
/* 1FBD2 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU MILIEU DROIT",NULL},
/* 1FBD3 */ { "FILET FIN DIAGONAL DU MILIEU GAUCHE AU COIN INFÉRIEUR DROIT",NULL},
/* 1FBD4 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU CENTRE INFÉRIEUR",NULL},
/* 1FBD5 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU COIN INFÉRIEUR DROIT",NULL},
/* 1FBD6 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR DROIT AU CENTRE INFÉRIEUR",NULL},
/* 1FBD7 */ { "FILET FIN DIAGONAL DU CENTRE SUPÉRIEUR AU COIN INFÉRIEUR GAUCHE",NULL},
/* 1FBD8 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU CENTRE DU MILIEU PUIS AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FBD9 */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR DROIT AU CENTRE DU MILIEU PUIS AU COIN INFÉRIEUR DROIT",NULL},
/* 1FBDA */ { "FILET FIN DIAGONAL DU COIN INFÉRIEUR GAUCHE AU CENTRE DU MILIEU PUIS AU COIN INFÉRIEUR DROIT",NULL},
/* 1FBDB */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU CENTRE DU MILIEU PUIS AU COIN INFÉRIEUR GAUCHE",NULL},
/* 1FBDC */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU CENTRE INFÉRIEUR PUIS AU COIN SUPÉRIEUR DROIT",NULL},
/* 1FBDD */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR DROIT AU MILIEU GAUCHE PUIS AU COIN INFÉRIEUR DROIT",NULL},
/* 1FBDE */ { "FILET FIN DIAGONAL DU COIN INFÉRIEUR GAUCHE AU CENTRE SUPÉRIEUR PUIS AU COIN INFÉRIEUR DROIT",NULL},
/* 1FBDF */ { "FILET FIN DIAGONAL DU COIN SUPÉRIEUR GAUCHE AU CENTRE DROIT PUIS AU COIN INFÉRIEUR GAUCHE",NULL},
/* 1FBE0 */ { "MOITIÉ INFÉRIEURE DE CERCLE BLANC ALIGNÉE EN HAUT",NULL},
/* 1FBE1 */ { "MOITIÉ GAUCHE DE CERCLE BLANC ALIGNÉE À DROITE",NULL},
/* 1FBE2 */ { "MOITIÉ SUPÉRIEURE DE CERCLE BLANC ALIGNÉE EN BAS",NULL},
/* 1FBE3 */ { "MOITIÉ DROITE DE CERCLE BLANC ALIGNÉE À GAUCHE",NULL},
/* 1FBE4 */ { "UN QUART SUPÉRIEUR CENTRAL DE PAVÉ",NULL},
/* 1FBE5 */ { "UN QUART INFÉRIEUR CENTRAL DE PAVÉ",NULL},
/* 1FBE6 */ { "UN QUART MILIEU GAUCHE DE PAVÉ",NULL},
/* 1FBE7 */ { "UN QUART MILIEU DROIT DE PAVÉ",NULL},
/* 1FBE8 */ { "MOITIÉ INFÉRIEURE DE CERCLE NOIR ALIGNÉE EN HAUT",NULL},
/* 1FBE9 */ { "MOITIÉ GAUCHE DE CERCLE NOIR ALIGNÉE À DROITE",NULL},
/* 1FBEA */ { "MOITIÉ SUPÉRIEURE DE CERCLE NOIR ALIGNÉE EN BAS",NULL},
/* 1FBEB */ { "MOITIÉ DROITE DE CERCLE NOIR ALIGNÉE À GAUCHE",NULL},
/* 1FBEC */ { "QUART INFÉRIEUR GAUCHE DE CERCLE NOIR ALIGNÉ EN HAUT À DROITE",NULL},
/* 1FBED */ { "QUART SUPÉRIEUR DROIT DE CERCLE NOIR ALIGNÉ EN BAS À GAUCHE",NULL},
/* 1FBEE */ { "QUART SUPÉRIEUR GAUCHE DE CERCLE NOIR ALIGNÉ EN BAS À DROITE",NULL},
/* 1FBEF */ { "QUART INFÉRIEUR DROIT DE CERCLE NOIR ALIGNÉ EN HAUT À GAUCHE",NULL},
/* 1FBF0 */ { "CHIFFRE À BARRES ZÉRO","	# <police> 0030 chiffre zéro"},
/* 1FBF1 */ { "CHIFFRE À BARRES UN","	# <police> 0031 chiffre un"},
/* 1FBF2 */ { "CHIFFRE À BARRES DEUX","	# <police> 0032 chiffre deux"},
/* 1FBF3 */ { "CHIFFRE À BARRES TROIS","	# <police> 0033 chiffre trois"},
/* 1FBF4 */ { "CHIFFRE À BARRES QUATRE","	# <police> 0034 chiffre quatre"},
/* 1FBF5 */ { "CHIFFRE À BARRES CINQ","	# <police> 0035 chiffre cinq"},
/* 1FBF6 */ { "CHIFFRE À BARRES SIX","	# <police> 0036 chiffre six"},
/* 1FBF7 */ { "CHIFFRE À BARRES SEPT","	# <police> 0037 chiffre sept"},
/* 1FBF8 */ { "CHIFFRE À BARRES HUIT","	# <police> 0038 chiffre huit"},
/* 1FBF9 */ { "CHIFFRE À BARRES NEUF","	# <police> 0039 chiffre neuf"},
/* 1FBFA */ { "SYMBOLE DE CLOCHE D'ALARME","	x (symbole sonnerie - 237E)\n"
	"	x (cloche - 1F514)"},
/* 1FBFB */ { NULL,NULL},
/* 1FBFC */ { NULL,NULL},
/* 1FBFD */ { NULL,NULL},
/* 1FBFE */ { NULL,NULL},
/* 1FBFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_02_F8[] = {
/* 2F800 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F800","	: 4E3D"},
/* 2F801 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F801","	: 4E38"},
/* 2F802 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F802","	: 4E41"},
/* 2F803 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F803","	: 20122"},
/* 2F804 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F804","	: 4F60"},
/* 2F805 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F805","	: 4FAE"},
/* 2F806 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F806","	: 4FBB"},
/* 2F807 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F807","	: 5002"},
/* 2F808 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F808","	: 507A"},
/* 2F809 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F809","	: 5099"},
/* 2F80A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F80A","	: 50E7"},
/* 2F80B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F80B","	: 50CF"},
/* 2F80C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F80C","	: 349E"},
/* 2F80D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F80D","	x 5145\n"
	"	: 2063A"},
/* 2F80E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F80E","	: 514D"},
/* 2F80F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F80F","	: 5154"},
/* 2F810 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F810","	: 5164"},
/* 2F811 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F811","	: 5177"},
/* 2F812 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F812","	: 2051C"},
/* 2F813 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F813","	: 34B9"},
/* 2F814 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F814","	x 5185\n"
	"	: 5167"},
/* 2F815 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F815","	: 518D"},
/* 2F816 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F816","	: 2054B"},
/* 2F817 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F817","	: 5197"},
/* 2F818 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F818","	: 51A4"},
/* 2F819 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F819","	: 4ECC"},
/* 2F81A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F81A","	: 51AC"},
/* 2F81B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F81B","	: 51B5"},
/* 2F81C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F81C","	: 291DF"},
/* 2F81D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F81D","	: 51F5"},
/* 2F81E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F81E","	: 5203"},
/* 2F81F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F81F","	: 34DF"},
/* 2F820 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F820","	: 523B"},
/* 2F821 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F821","	: 5246"},
/* 2F822 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F822","	: 5272"},
/* 2F823 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F823","	: 5277"},
/* 2F824 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F824","	: 3515"},
/* 2F825 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F825","	: 52C7"},
/* 2F826 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F826","	: 52C9"},
/* 2F827 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F827","	: 52E4"},
/* 2F828 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F828","	: 52FA"},
/* 2F829 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F829","	: 5305"},
/* 2F82A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F82A","	: 5306"},
/* 2F82B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F82B","	: 5317"},
/* 2F82C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F82C","	x 20984\n"
	"	: 5349"},
/* 2F82D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F82D","	: 5351"},
/* 2F82E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F82E","	: 535A"},
/* 2F82F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F82F","	: 5373"},
/* 2F830 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F830","	: 537D"},
/* 2F831 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F831","	: 537F"},
/* 2F832 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F832","	: 537F"},
/* 2F833 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F833","	: 537F"},
/* 2F834 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F834","	: 20A2C"},
/* 2F835 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F835","	: 7070"},
/* 2F836 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F836","	: 53CA"},
/* 2F837 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F837","	: 53DF"},
/* 2F838 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F838","	: 20B63"},
/* 2F839 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F839","	: 53EB"},
/* 2F83A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F83A","	: 53F1"},
/* 2F83B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F83B","	x 4DB8\n"
	"	: 5406"},
/* 2F83C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F83C","	: 549E"},
/* 2F83D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F83D","	: 5438"},
/* 2F83E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F83E","	: 5448"},
/* 2F83F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F83F","	: 5468"},
/* 2F840 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F840","	: 54A2"},
/* 2F841 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F841","	: 54F6"},
/* 2F842 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F842","	: 5510"},
/* 2F843 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F843","	: 5553"},
/* 2F844 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F844","	: 5563"},
/* 2F845 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F845","	: 5584"},
/* 2F846 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F846","	: 5584"},
/* 2F847 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F847","	: 5599"},
/* 2F848 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F848","	: 55AB"},
/* 2F849 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F849","	: 55B3"},
/* 2F84A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F84A","	: 55C2"},
/* 2F84B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F84B","	: 5716"},
/* 2F84C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F84C","	: 5606"},
/* 2F84D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F84D","	: 5717"},
/* 2F84E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F84E","	: 5651"},
/* 2F84F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F84F","	: 5674"},
/* 2F850 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F850","	: 5207"},
/* 2F851 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F851","	: 58EE"},
/* 2F852 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F852","	: 57CE"},
/* 2F853 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F853","	: 57F4"},
/* 2F854 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F854","	: 580D"},
/* 2F855 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F855","	: 578B"},
/* 2F856 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F856","	: 5832"},
/* 2F857 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F857","	: 5831"},
/* 2F858 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F858","	: 58AC"},
/* 2F859 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F859","	: 214E4"},
/* 2F85A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F85A","	x 58F3\n"
	"	: 58F2"},
/* 2F85B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F85B","	x 21533\n"
	"	: 58F7"},
/* 2F85C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F85C","	: 5906"},
/* 2F85D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F85D","	: 591A"},
/* 2F85E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F85E","	: 5922"},
/* 2F85F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F85F","	: 5962"},
/* 2F860 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F860","	x 216A7\n"
	"	: 216A8"},
/* 2F861 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F861","	: 216EA"},
/* 2F862 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F862","	: 59EC"},
/* 2F863 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F863","	: 5A1B"},
/* 2F864 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F864","	: 5A27"},
/* 2F865 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F865","	: 59D8"},
/* 2F866 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F866","	: 5A66"},
/* 2F867 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F867","	: 36EE"},
/* 2F868 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F868","	: 36FC"},
/* 2F869 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F869","	: 5B08"},
/* 2F86A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F86A","	: 5B3E"},
/* 2F86B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F86B","	: 5B3E"},
/* 2F86C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F86C","	: 219C8"},
/* 2F86D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F86D","	: 5BC3"},
/* 2F86E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F86E","	: 5BD8"},
/* 2F86F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F86F","	: 5BE7"},
/* 2F870 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F870","	: 5BF3"},
/* 2F871 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F871","	: 21B18"},
/* 2F872 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F872","	: 5BFF"},
/* 2F873 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F873","	: 5C06"},
/* 2F874 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F874","	x 22450\n"
	"	: 5F53"},
/* 2F875 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F875","	: 5C22"},
/* 2F876 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F876","	: 3781"},
/* 2F877 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F877","	: 5C60"},
/* 2F878 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F878","	x 4DB9\n"
	"	: 5C6E"},
/* 2F879 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F879","	: 5CC0"},
/* 2F87A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F87A","	: 5C8D"},
/* 2F87B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F87B","	: 21DE4"},
/* 2F87C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F87C","	: 5D43"},
/* 2F87D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F87D","	: 21DE6"},
/* 2F87E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F87E","	: 5D6E"},
/* 2F87F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F87F","	: 5D6B"},
/* 2F880 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F880","	: 5D7C"},
/* 2F881 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F881","	: 5DE1"},
/* 2F882 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F882","	: 5DE2"},
/* 2F883 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F883","	: 382F"},
/* 2F884 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F884","	: 5DFD"},
/* 2F885 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F885","	: 5E28"},
/* 2F886 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F886","	: 5E3D"},
/* 2F887 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F887","	: 5E69"},
/* 2F888 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F888","	: 3862"},
/* 2F889 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F889","	: 22183"},
/* 2F88A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F88A","	: 387C"},
/* 2F88B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F88B","	: 5EB0"},
/* 2F88C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F88C","	: 5EB3"},
/* 2F88D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F88D","	: 5EB6"},
/* 2F88E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F88E","	: 5ECA"},
/* 2F88F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F88F","	: 2A392"},
/* 2F890 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F890","	: 5EFE"},
/* 2F891 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F891","	: 22331"},
/* 2F892 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F892","	: 22331"},
/* 2F893 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F893","	: 8201"},
/* 2F894 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F894","	: 5F22"},
/* 2F895 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F895","	: 5F22"},
/* 2F896 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F896","	: 38C7"},
/* 2F897 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F897","	: 232B8"},
/* 2F898 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F898","	: 261DA"},
/* 2F899 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F899","	: 5F62"},
/* 2F89A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F89A","	: 5F6B"},
/* 2F89B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F89B","	: 38E3"},
/* 2F89C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F89C","	x 22505\n"
	"	: 5F9A"},
/* 2F89D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F89D","	: 5FCD"},
/* 2F89E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F89E","	: 5FD7"},
/* 2F89F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F89F","	: 5FF9"},
/* 2F8A0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A0","	: 6081"},
/* 2F8A1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A1","	: 393A"},
/* 2F8A2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A2","	: 391C"},
/* 2F8A3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A3","	: 6094"},
/* 2F8A4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A4","	: 226D4"},
/* 2F8A5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A5","	: 60C7"},
/* 2F8A6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A6","	: 6148"},
/* 2F8A7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A7","	: 614C"},
/* 2F8A8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A8","	: 614E"},
/* 2F8A9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8A9","	: 614C"},
/* 2F8AA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8AA","	: 617A"},
/* 2F8AB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8AB","	: 618E"},
/* 2F8AC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8AC","	: 61B2"},
/* 2F8AD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8AD","	: 61A4"},
/* 2F8AE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8AE","	: 61AF"},
/* 2F8AF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8AF","	: 61DE"},
/* 2F8B0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B0","	: 61F2"},
/* 2F8B1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B1","	: 61F6"},
/* 2F8B2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B2","	: 6210"},
/* 2F8B3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B3","	: 621B"},
/* 2F8B4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B4","	: 625D"},
/* 2F8B5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B5","	: 62B1"},
/* 2F8B6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B6","	: 62D4"},
/* 2F8B7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B7","	: 6350"},
/* 2F8B8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B8","	: 22B0C"},
/* 2F8B9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8B9","	: 633D"},
/* 2F8BA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8BA","	: 62FC"},
/* 2F8BB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8BB","	: 6368"},
/* 2F8BC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8BC","	: 6383"},
/* 2F8BD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8BD","	: 63E4"},
/* 2F8BE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8BE","	: 22BF1"},
/* 2F8BF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8BF","	: 6422"},
/* 2F8C0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C0","	: 63C5"},
/* 2F8C1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C1","	: 63A9"},
/* 2F8C2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C2","	: 3A2E"},
/* 2F8C3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C3","	: 6469"},
/* 2F8C4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C4","	: 647E"},
/* 2F8C5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C5","	: 649D"},
/* 2F8C6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C6","	: 6477"},
/* 2F8C7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C7","	: 3A6C"},
/* 2F8C8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C8","	: 654F"},
/* 2F8C9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8C9","	: 656C"},
/* 2F8CA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8CA","	: 2300A"},
/* 2F8CB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8CB","	: 65E3"},
/* 2F8CC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8CC","	: 66F8"},
/* 2F8CD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8CD","	: 6649"},
/* 2F8CE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8CE","	: 3B19"},
/* 2F8CF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8CF","	: 6691"},
/* 2F8D0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D0","	: 3B08"},
/* 2F8D1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D1","	: 3AE4"},
/* 2F8D2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D2","	: 5192"},
/* 2F8D3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D3","	: 5195"},
/* 2F8D4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D4","	: 6700"},
/* 2F8D5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D5","	: 669C"},
/* 2F8D6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D6","	: 80AD"},
/* 2F8D7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D7","	: 43D9"},
/* 2F8D8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D8","	: 6717"},
/* 2F8D9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8D9","	: 671B"},
/* 2F8DA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8DA","	: 6721"},
/* 2F8DB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8DB","	: 675E"},
/* 2F8DC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8DC","	: 6753"},
/* 2F8DD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8DD","	: 233C3"},
/* 2F8DE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8DE","	: 3B49"},
/* 2F8DF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8DF","	: 67FA"},
/* 2F8E0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E0","	: 6785"},
/* 2F8E1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E1","	: 6852"},
/* 2F8E2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E2","	: 6885"},
/* 2F8E3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E3","	: 2346D"},
/* 2F8E4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E4","	: 688E"},
/* 2F8E5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E5","	: 681F"},
/* 2F8E6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E6","	: 6914"},
/* 2F8E7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E7","	: 3B9D"},
/* 2F8E8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E8","	: 6942"},
/* 2F8E9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8E9","	: 69A3"},
/* 2F8EA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8EA","	: 69EA"},
/* 2F8EB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8EB","	: 6AA8"},
/* 2F8EC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8EC","	: 236A3"},
/* 2F8ED */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8ED","	: 6ADB"},
/* 2F8EE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8EE","	: 3C18"},
/* 2F8EF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8EF","	: 6B21"},
/* 2F8F0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F0","	x 4DBE\n"
	"	: 238A7"},
/* 2F8F1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F1","	: 6B54"},
/* 2F8F2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F2","	: 3C4E"},
/* 2F8F3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F3","	: 6B72"},
/* 2F8F4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F4","	: 6B9F"},
/* 2F8F5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F5","	: 6BBA"},
/* 2F8F6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F6","	: 6BBB"},
/* 2F8F7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F7","	: 23A8D"},
/* 2F8F8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F8","	: 21D0B"},
/* 2F8F9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8F9","	: 23AFA"},
/* 2F8FA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8FA","	: 6C4E"},
/* 2F8FB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8FB","	: 23CBC"},
/* 2F8FC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8FC","	: 6CBF"},
/* 2F8FD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8FD","	x 2DC09\n"
	"	: 6CCD"},
/* 2F8FE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8FE","	: 6C67"},
/* 2F8FF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F8FF","	: 6D16"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_02_F9[] = {
/* 2F900 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F900","	: 6D3E"},
/* 2F901 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F901","	: 6D77"},
/* 2F902 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F902","	: 6D41"},
/* 2F903 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F903","	: 6D69"},
/* 2F904 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F904","	: 6D78"},
/* 2F905 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F905","	x 23D40\n"
	"	: 6D85"},
/* 2F906 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F906","	: 23D1E"},
/* 2F907 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F907","	: 6D34"},
/* 2F908 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F908","	: 6E2F"},
/* 2F909 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F909","	: 6E6E"},
/* 2F90A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F90A","	: 3D33"},
/* 2F90B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F90B","	: 6ECB"},
/* 2F90C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F90C","	: 6EC7"},
/* 2F90D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F90D","	: 23ED1"},
/* 2F90E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F90E","	x 23F1C\n"
	"	: 6DF9"},
/* 2F90F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F90F","	: 6F6E"},
/* 2F910 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F910","	: 23F5E"},
/* 2F911 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F911","	: 23F8E"},
/* 2F912 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F912","	: 6FC6"},
/* 2F913 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F913","	: 7039"},
/* 2F914 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F914","	: 701E"},
/* 2F915 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F915","	: 701B"},
/* 2F916 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F916","	: 3D96"},
/* 2F917 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F917","	: 704A"},
/* 2F918 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F918","	: 707D"},
/* 2F919 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F919","	: 7077"},
/* 2F91A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F91A","	: 70AD"},
/* 2F91B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F91B","	: 20525"},
/* 2F91C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F91C","	x 242B3\n"
	"	: 7145"},
/* 2F91D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F91D","	: 24263"},
/* 2F91E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F91E","	: 719C"},
/* 2F91F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F91F","	: 243AB"},
/* 2F920 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F920","	: 7228"},
/* 2F921 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F921","	: 7235"},
/* 2F922 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F922","	: 7250"},
/* 2F923 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F923","	: 24608"},
/* 2F924 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F924","	: 7280"},
/* 2F925 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F925","	: 7295"},
/* 2F926 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F926","	: 24735"},
/* 2F927 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F927","	x 2AEC5\n"
	"	: 24814"},
/* 2F928 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F928","	: 737A"},
/* 2F929 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F929","	: 738B"},
/* 2F92A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F92A","	: 3EAC"},
/* 2F92B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F92B","	: 73A5"},
/* 2F92C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F92C","	: 3EB8"},
/* 2F92D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F92D","	: 3EB8"},
/* 2F92E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F92E","	: 7447"},
/* 2F92F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F92F","	: 745C"},
/* 2F930 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F930","	: 7471"},
/* 2F931 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F931","	: 7485"},
/* 2F932 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F932","	: 74CA"},
/* 2F933 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F933","	: 3F1B"},
/* 2F934 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F934","	: 7524"},
/* 2F935 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F935","	: 24C36"},
/* 2F936 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F936","	: 753E"},
/* 2F937 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F937","	: 24C92"},
/* 2F938 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F938","	: 7570"},
/* 2F939 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F939","	: 2219F"},
/* 2F93A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F93A","	: 7610"},
/* 2F93B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F93B","	: 24FA1"},
/* 2F93C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F93C","	: 24FB8"},
/* 2F93D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F93D","	: 25044"},
/* 2F93E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F93E","	: 3FFC"},
/* 2F93F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F93F","	: 4008"},
/* 2F940 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F940","	: 76F4"},
/* 2F941 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F941","	: 250F3"},
/* 2F942 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F942","	: 250F2"},
/* 2F943 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F943","	x 2511A\n"
	"	: 25119"},
/* 2F944 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F944","	: 25133"},
/* 2F945 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F945","	: 771E"},
/* 2F946 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F946","	: 771F"},
/* 2F947 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F947","	: 771F"},
/* 2F948 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F948","	: 774A"},
/* 2F949 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F949","	: 4039"},
/* 2F94A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F94A","	: 778B"},
/* 2F94B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F94B","	x 25271\n"
	"	: 4046"},
/* 2F94C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F94C","	: 4096"},
/* 2F94D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F94D","	: 2541D"},
/* 2F94E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F94E","	: 784E"},
/* 2F94F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F94F","	: 788C"},
/* 2F950 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F950","	: 78CC"},
/* 2F951 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F951","	: 40E3"},
/* 2F952 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F952","	: 25626"},
/* 2F953 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F953","	: 7956"},
/* 2F954 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F954","	: 2569A"},
/* 2F955 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F955","	: 256C5"},
/* 2F956 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F956","	: 798F"},
/* 2F957 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F957","	: 79EB"},
/* 2F958 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F958","	: 412F"},
/* 2F959 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F959","	: 7A40"},
/* 2F95A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F95A","	: 7A4A"},
/* 2F95B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F95B","	: 7A4F"},
/* 2F95C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F95C","	: 2597C"},
/* 2F95D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F95D","	: 25AA7"},
/* 2F95E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F95E","	: 25AA7"},
/* 2F95F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F95F","	: 7AEE"},
/* 2F960 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F960","	: 4202"},
/* 2F961 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F961","	: 25BAB"},
/* 2F962 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F962","	: 7BC6"},
/* 2F963 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F963","	: 7BC9"},
/* 2F964 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F964","	: 4227"},
/* 2F965 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F965","	: 25C80"},
/* 2F966 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F966","	: 7CD2"},
/* 2F967 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F967","	: 42A0"},
/* 2F968 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F968","	: 7CE8"},
/* 2F969 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F969","	: 7CE3"},
/* 2F96A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F96A","	: 7D00"},
/* 2F96B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F96B","	: 25F86"},
/* 2F96C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F96C","	: 7D63"},
/* 2F96D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F96D","	: 4301"},
/* 2F96E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F96E","	: 7DC7"},
/* 2F96F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F96F","	: 7E02"},
/* 2F970 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F970","	: 7E45"},
/* 2F971 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F971","	: 4334"},
/* 2F972 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F972","	: 26228"},
/* 2F973 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F973","	: 26247"},
/* 2F974 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F974","	: 4359"},
/* 2F975 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F975","	: 262D9"},
/* 2F976 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F976","	: 7F7A"},
/* 2F977 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F977","	: 2633E"},
/* 2F978 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F978","	: 7F95"},
/* 2F979 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F979","	: 7FFA"},
/* 2F97A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F97A","	: 8005"},
/* 2F97B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F97B","	: 264DA"},
/* 2F97C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F97C","	: 26523"},
/* 2F97D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F97D","	: 8060"},
/* 2F97E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F97E","	: 265A8"},
/* 2F97F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F97F","	: 8070"},
/* 2F980 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F980","	: 2335F"},
/* 2F981 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F981","	: 43D5"},
/* 2F982 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F982","	: 80B2"},
/* 2F983 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F983","	: 8103"},
/* 2F984 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F984","	: 440B"},
/* 2F985 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F985","	: 813E"},
/* 2F986 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F986","	: 5AB5"},
/* 2F987 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F987","	: 267A7"},
/* 2F988 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F988","	: 267B5"},
/* 2F989 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F989","	: 23393"},
/* 2F98A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F98A","	: 2339C"},
/* 2F98B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F98B","	: 8201"},
/* 2F98C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F98C","	: 8204"},
/* 2F98D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F98D","	: 8F9E"},
/* 2F98E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F98E","	: 446B"},
/* 2F98F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F98F","	: 8291"},
/* 2F990 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F990","	: 828B"},
/* 2F991 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F991","	: 829D"},
/* 2F992 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F992","	: 52B3"},
/* 2F993 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F993","	: 82B1"},
/* 2F994 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F994","	: 82B3"},
/* 2F995 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F995","	: 82BD"},
/* 2F996 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F996","	: 82E6"},
/* 2F997 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F997","	: 26B3C"},
/* 2F998 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F998","	: 82E5"},
/* 2F999 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F999","	: 831D"},
/* 2F99A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F99A","	: 8363"},
/* 2F99B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F99B","	: 83AD"},
/* 2F99C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F99C","	: 8323"},
/* 2F99D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F99D","	: 83BD"},
/* 2F99E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F99E","	: 83E7"},
/* 2F99F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F99F","	: 8457"},
/* 2F9A0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A0","	: 8353"},
/* 2F9A1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A1","	: 83CA"},
/* 2F9A2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A2","	: 83CC"},
/* 2F9A3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A3","	: 83DC"},
/* 2F9A4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A4","	: 26C36"},
/* 2F9A5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A5","	: 26D6B"},
/* 2F9A6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A6","	: 26CD5"},
/* 2F9A7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A7","	: 452B"},
/* 2F9A8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A8","	: 84F1"},
/* 2F9A9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9A9","	: 84F3"},
/* 2F9AA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9AA","	: 8516"},
/* 2F9AB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9AB","	: 273CA"},
/* 2F9AC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9AC","	: 8564"},
/* 2F9AD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9AD","	: 26F2C"},
/* 2F9AE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9AE","	: 455D"},
/* 2F9AF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9AF","	: 4561"},
/* 2F9B0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B0","	: 26FB1"},
/* 2F9B1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B1","	: 270D2"},
/* 2F9B2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B2","	x 5914\n"
	"	x 270CD\n"
	"	x 270F0\n"
	"	: 456B"},
/* 2F9B3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B3","	: 8650"},
/* 2F9B4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B4","	: 865C"},
/* 2F9B5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B5","	: 8667"},
/* 2F9B6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B6","	x 27205\n"
	"	: 8669"},
/* 2F9B7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B7","	: 86A9"},
/* 2F9B8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B8","	: 8688"},
/* 2F9B9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9B9","	: 870E"},
/* 2F9BA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9BA","	: 86E2"},
/* 2F9BB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9BB","	: 8779"},
/* 2F9BC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9BC","	: 8728"},
/* 2F9BD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9BD","	: 876B"},
/* 2F9BE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9BE","	: 8786"},
/* 2F9BF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9BF","	: 45D7"},
/* 2F9C0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C0","	: 87E1"},
/* 2F9C1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C1","	: 8801"},
/* 2F9C2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C2","	: 45F9"},
/* 2F9C3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C3","	: 8860"},
/* 2F9C4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C4","	: 8863"},
/* 2F9C5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C5","	: 27667"},
/* 2F9C6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C6","	: 88D7"},
/* 2F9C7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C7","	: 88DE"},
/* 2F9C8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C8","	: 4635"},
/* 2F9C9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9C9","	: 88FA"},
/* 2F9CA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9CA","	: 34BB"},
/* 2F9CB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9CB","	x 4695\n"
	"	: 278AE"},
/* 2F9CC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9CC","	: 27966"},
/* 2F9CD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9CD","	: 46BE"},
/* 2F9CE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9CE","	: 46C7"},
/* 2F9CF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9CF","	: 8AA0"},
/* 2F9D0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D0","	: 8AED"},
/* 2F9D1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D1","	: 8B8A"},
/* 2F9D2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D2","	: 8C55"},
/* 2F9D3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D3","	: 27CA8"},
/* 2F9D4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D4","	: 8CAB"},
/* 2F9D5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D5","	: 8CC1"},
/* 2F9D6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D6","	x 25AD4\n"
	"	: 8D1B"},
/* 2F9D7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D7","	: 8D77"},
/* 2F9D8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D8","	: 27F2F"},
/* 2F9D9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9D9","	: 20804"},
/* 2F9DA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9DA","	: 8DCB"},
/* 2F9DB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9DB","	: 8DBC"},
/* 2F9DC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9DC","	: 8DF0"},
/* 2F9DD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9DD","	: 208DE"},
/* 2F9DE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9DE","	: 8ED4"},
/* 2F9DF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9DF","	: 8F38"},
/* 2F9E0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E0","	: 285D2"},
/* 2F9E1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E1","	: 285ED"},
/* 2F9E2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E2","	: 9094"},
/* 2F9E3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E3","	: 90F1"},
/* 2F9E4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E4","	: 9111"},
/* 2F9E5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E5","	: 2872E"},
/* 2F9E6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E6","	: 911B"},
/* 2F9E7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E7","	: 9238"},
/* 2F9E8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E8","	: 92D7"},
/* 2F9E9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9E9","	: 92D8"},
/* 2F9EA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9EA","	: 927C"},
/* 2F9EB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9EB","	: 93F9"},
/* 2F9EC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9EC","	: 9415"},
/* 2F9ED */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9ED","	: 28BFA"},
/* 2F9EE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9EE","	: 958B"},
/* 2F9EF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9EF","	: 4995"},
/* 2F9F0 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F0","	: 95B7"},
/* 2F9F1 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F1","	: 28D77"},
/* 2F9F2 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F2","	: 49E6"},
/* 2F9F3 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F3","	: 96C3"},
/* 2F9F4 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F4","	: 5DB2"},
/* 2F9F5 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F5","	: 9723"},
/* 2F9F6 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F6","	: 29145"},
/* 2F9F7 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F7","	: 2921A"},
/* 2F9F8 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F8","	: 4A6E"},
/* 2F9F9 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9F9","	: 4A76"},
/* 2F9FA */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9FA","	: 97E0"},
/* 2F9FB */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9FB","	: 2940A"},
/* 2F9FC */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9FC","	: 4AB2"},
/* 2F9FD */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9FD","	: 29496"},
/* 2F9FE */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9FE","	: 980B"},
/* 2F9FF */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2F9FF","	: 980B"}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_02_FA[] = {
/* 2FA00 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA00","	: 9829"},
/* 2FA01 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA01","	: 295B6"},
/* 2FA02 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA02","	: 98E2"},
/* 2FA03 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA03","	: 4B33"},
/* 2FA04 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA04","	: 9929"},
/* 2FA05 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA05","	: 99A7"},
/* 2FA06 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA06","	: 99C2"},
/* 2FA07 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA07","	: 99FE"},
/* 2FA08 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA08","	: 4BCE"},
/* 2FA09 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA09","	: 29B30"},
/* 2FA0A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA0A","	: 9B12"},
/* 2FA0B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA0B","	: 9C40"},
/* 2FA0C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA0C","	: 9CFD"},
/* 2FA0D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA0D","	: 4CCE"},
/* 2FA0E */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA0E","	: 4CED"},
/* 2FA0F */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA0F","	: 9D67"},
/* 2FA10 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA10","	: 2A0CE"},
/* 2FA11 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA11","	: 4CF8"},
/* 2FA12 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA12","	: 2A105"},
/* 2FA13 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA13","	: 2A20E"},
/* 2FA14 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA14","	: 2A291"},
/* 2FA15 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA15","	: 9EBB"},
/* 2FA16 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA16","	: 4D56"},
/* 2FA17 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA17","	: 9EF9"},
/* 2FA18 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA18","	: 9EFE"},
/* 2FA19 */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA19","	: 9F05"},
/* 2FA1A */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA1A","	: 9F0F"},
/* 2FA1B */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA1B","	: 9F16"},
/* 2FA1C */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA1C","	: 9F3B"},
/* 2FA1D */ { "IDÉOGRAMME DE COMPATIBILITÉ CJC-2FA1D","	: 2A600"},
/* 2FA1E */ { NULL,NULL},
/* 2FA1F */ { NULL,NULL},
/* 2FA20 */ { NULL,NULL},
/* 2FA21 */ { NULL,NULL},
/* 2FA22 */ { NULL,NULL},
/* 2FA23 */ { NULL,NULL},
/* 2FA24 */ { NULL,NULL},
/* 2FA25 */ { NULL,NULL},
/* 2FA26 */ { NULL,NULL},
/* 2FA27 */ { NULL,NULL},
/* 2FA28 */ { NULL,NULL},
/* 2FA29 */ { NULL,NULL},
/* 2FA2A */ { NULL,NULL},
/* 2FA2B */ { NULL,NULL},
/* 2FA2C */ { NULL,NULL},
/* 2FA2D */ { NULL,NULL},
/* 2FA2E */ { NULL,NULL},
/* 2FA2F */ { NULL,NULL},
/* 2FA30 */ { NULL,NULL},
/* 2FA31 */ { NULL,NULL},
/* 2FA32 */ { NULL,NULL},
/* 2FA33 */ { NULL,NULL},
/* 2FA34 */ { NULL,NULL},
/* 2FA35 */ { NULL,NULL},
/* 2FA36 */ { NULL,NULL},
/* 2FA37 */ { NULL,NULL},
/* 2FA38 */ { NULL,NULL},
/* 2FA39 */ { NULL,NULL},
/* 2FA3A */ { NULL,NULL},
/* 2FA3B */ { NULL,NULL},
/* 2FA3C */ { NULL,NULL},
/* 2FA3D */ { NULL,NULL},
/* 2FA3E */ { NULL,NULL},
/* 2FA3F */ { NULL,NULL},
/* 2FA40 */ { NULL,NULL},
/* 2FA41 */ { NULL,NULL},
/* 2FA42 */ { NULL,NULL},
/* 2FA43 */ { NULL,NULL},
/* 2FA44 */ { NULL,NULL},
/* 2FA45 */ { NULL,NULL},
/* 2FA46 */ { NULL,NULL},
/* 2FA47 */ { NULL,NULL},
/* 2FA48 */ { NULL,NULL},
/* 2FA49 */ { NULL,NULL},
/* 2FA4A */ { NULL,NULL},
/* 2FA4B */ { NULL,NULL},
/* 2FA4C */ { NULL,NULL},
/* 2FA4D */ { NULL,NULL},
/* 2FA4E */ { NULL,NULL},
/* 2FA4F */ { NULL,NULL},
/* 2FA50 */ { NULL,NULL},
/* 2FA51 */ { NULL,NULL},
/* 2FA52 */ { NULL,NULL},
/* 2FA53 */ { NULL,NULL},
/* 2FA54 */ { NULL,NULL},
/* 2FA55 */ { NULL,NULL},
/* 2FA56 */ { NULL,NULL},
/* 2FA57 */ { NULL,NULL},
/* 2FA58 */ { NULL,NULL},
/* 2FA59 */ { NULL,NULL},
/* 2FA5A */ { NULL,NULL},
/* 2FA5B */ { NULL,NULL},
/* 2FA5C */ { NULL,NULL},
/* 2FA5D */ { NULL,NULL},
/* 2FA5E */ { NULL,NULL},
/* 2FA5F */ { NULL,NULL},
/* 2FA60 */ { NULL,NULL},
/* 2FA61 */ { NULL,NULL},
/* 2FA62 */ { NULL,NULL},
/* 2FA63 */ { NULL,NULL},
/* 2FA64 */ { NULL,NULL},
/* 2FA65 */ { NULL,NULL},
/* 2FA66 */ { NULL,NULL},
/* 2FA67 */ { NULL,NULL},
/* 2FA68 */ { NULL,NULL},
/* 2FA69 */ { NULL,NULL},
/* 2FA6A */ { NULL,NULL},
/* 2FA6B */ { NULL,NULL},
/* 2FA6C */ { NULL,NULL},
/* 2FA6D */ { NULL,NULL},
/* 2FA6E */ { NULL,NULL},
/* 2FA6F */ { NULL,NULL},
/* 2FA70 */ { NULL,NULL},
/* 2FA71 */ { NULL,NULL},
/* 2FA72 */ { NULL,NULL},
/* 2FA73 */ { NULL,NULL},
/* 2FA74 */ { NULL,NULL},
/* 2FA75 */ { NULL,NULL},
/* 2FA76 */ { NULL,NULL},
/* 2FA77 */ { NULL,NULL},
/* 2FA78 */ { NULL,NULL},
/* 2FA79 */ { NULL,NULL},
/* 2FA7A */ { NULL,NULL},
/* 2FA7B */ { NULL,NULL},
/* 2FA7C */ { NULL,NULL},
/* 2FA7D */ { NULL,NULL},
/* 2FA7E */ { NULL,NULL},
/* 2FA7F */ { NULL,NULL},
/* 2FA80 */ { NULL,NULL},
/* 2FA81 */ { NULL,NULL},
/* 2FA82 */ { NULL,NULL},
/* 2FA83 */ { NULL,NULL},
/* 2FA84 */ { NULL,NULL},
/* 2FA85 */ { NULL,NULL},
/* 2FA86 */ { NULL,NULL},
/* 2FA87 */ { NULL,NULL},
/* 2FA88 */ { NULL,NULL},
/* 2FA89 */ { NULL,NULL},
/* 2FA8A */ { NULL,NULL},
/* 2FA8B */ { NULL,NULL},
/* 2FA8C */ { NULL,NULL},
/* 2FA8D */ { NULL,NULL},
/* 2FA8E */ { NULL,NULL},
/* 2FA8F */ { NULL,NULL},
/* 2FA90 */ { NULL,NULL},
/* 2FA91 */ { NULL,NULL},
/* 2FA92 */ { NULL,NULL},
/* 2FA93 */ { NULL,NULL},
/* 2FA94 */ { NULL,NULL},
/* 2FA95 */ { NULL,NULL},
/* 2FA96 */ { NULL,NULL},
/* 2FA97 */ { NULL,NULL},
/* 2FA98 */ { NULL,NULL},
/* 2FA99 */ { NULL,NULL},
/* 2FA9A */ { NULL,NULL},
/* 2FA9B */ { NULL,NULL},
/* 2FA9C */ { NULL,NULL},
/* 2FA9D */ { NULL,NULL},
/* 2FA9E */ { NULL,NULL},
/* 2FA9F */ { NULL,NULL},
/* 2FAA0 */ { NULL,NULL},
/* 2FAA1 */ { NULL,NULL},
/* 2FAA2 */ { NULL,NULL},
/* 2FAA3 */ { NULL,NULL},
/* 2FAA4 */ { NULL,NULL},
/* 2FAA5 */ { NULL,NULL},
/* 2FAA6 */ { NULL,NULL},
/* 2FAA7 */ { NULL,NULL},
/* 2FAA8 */ { NULL,NULL},
/* 2FAA9 */ { NULL,NULL},
/* 2FAAA */ { NULL,NULL},
/* 2FAAB */ { NULL,NULL},
/* 2FAAC */ { NULL,NULL},
/* 2FAAD */ { NULL,NULL},
/* 2FAAE */ { NULL,NULL},
/* 2FAAF */ { NULL,NULL},
/* 2FAB0 */ { NULL,NULL},
/* 2FAB1 */ { NULL,NULL},
/* 2FAB2 */ { NULL,NULL},
/* 2FAB3 */ { NULL,NULL},
/* 2FAB4 */ { NULL,NULL},
/* 2FAB5 */ { NULL,NULL},
/* 2FAB6 */ { NULL,NULL},
/* 2FAB7 */ { NULL,NULL},
/* 2FAB8 */ { NULL,NULL},
/* 2FAB9 */ { NULL,NULL},
/* 2FABA */ { NULL,NULL},
/* 2FABB */ { NULL,NULL},
/* 2FABC */ { NULL,NULL},
/* 2FABD */ { NULL,NULL},
/* 2FABE */ { NULL,NULL},
/* 2FABF */ { NULL,NULL},
/* 2FAC0 */ { NULL,NULL},
/* 2FAC1 */ { NULL,NULL},
/* 2FAC2 */ { NULL,NULL},
/* 2FAC3 */ { NULL,NULL},
/* 2FAC4 */ { NULL,NULL},
/* 2FAC5 */ { NULL,NULL},
/* 2FAC6 */ { NULL,NULL},
/* 2FAC7 */ { NULL,NULL},
/* 2FAC8 */ { NULL,NULL},
/* 2FAC9 */ { NULL,NULL},
/* 2FACA */ { NULL,NULL},
/* 2FACB */ { NULL,NULL},
/* 2FACC */ { NULL,NULL},
/* 2FACD */ { NULL,NULL},
/* 2FACE */ { NULL,NULL},
/* 2FACF */ { NULL,NULL},
/* 2FAD0 */ { NULL,NULL},
/* 2FAD1 */ { NULL,NULL},
/* 2FAD2 */ { NULL,NULL},
/* 2FAD3 */ { NULL,NULL},
/* 2FAD4 */ { NULL,NULL},
/* 2FAD5 */ { NULL,NULL},
/* 2FAD6 */ { NULL,NULL},
/* 2FAD7 */ { NULL,NULL},
/* 2FAD8 */ { NULL,NULL},
/* 2FAD9 */ { NULL,NULL},
/* 2FADA */ { NULL,NULL},
/* 2FADB */ { NULL,NULL},
/* 2FADC */ { NULL,NULL},
/* 2FADD */ { NULL,NULL},
/* 2FADE */ { NULL,NULL},
/* 2FADF */ { NULL,NULL},
/* 2FAE0 */ { NULL,NULL},
/* 2FAE1 */ { NULL,NULL},
/* 2FAE2 */ { NULL,NULL},
/* 2FAE3 */ { NULL,NULL},
/* 2FAE4 */ { NULL,NULL},
/* 2FAE5 */ { NULL,NULL},
/* 2FAE6 */ { NULL,NULL},
/* 2FAE7 */ { NULL,NULL},
/* 2FAE8 */ { NULL,NULL},
/* 2FAE9 */ { NULL,NULL},
/* 2FAEA */ { NULL,NULL},
/* 2FAEB */ { NULL,NULL},
/* 2FAEC */ { NULL,NULL},
/* 2FAED */ { NULL,NULL},
/* 2FAEE */ { NULL,NULL},
/* 2FAEF */ { NULL,NULL},
/* 2FAF0 */ { NULL,NULL},
/* 2FAF1 */ { NULL,NULL},
/* 2FAF2 */ { NULL,NULL},
/* 2FAF3 */ { NULL,NULL},
/* 2FAF4 */ { NULL,NULL},
/* 2FAF5 */ { NULL,NULL},
/* 2FAF6 */ { NULL,NULL},
/* 2FAF7 */ { NULL,NULL},
/* 2FAF8 */ { NULL,NULL},
/* 2FAF9 */ { NULL,NULL},
/* 2FAFA */ { NULL,NULL},
/* 2FAFB */ { NULL,NULL},
/* 2FAFC */ { NULL,NULL},
/* 2FAFD */ { NULL,NULL},
/* 2FAFE */ { NULL,NULL},
/* 2FAFF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_0E_00[] = {
/* E0000 */ { NULL,NULL},
/* E0001 */ { "ÉTIQUETTE DE LANGUE","	* ce caractère est obsolète et son utilisation est fortement déconseillée"},
/* E0002 */ { NULL,NULL},
/* E0003 */ { NULL,NULL},
/* E0004 */ { NULL,NULL},
/* E0005 */ { NULL,NULL},
/* E0006 */ { NULL,NULL},
/* E0007 */ { NULL,NULL},
/* E0008 */ { NULL,NULL},
/* E0009 */ { NULL,NULL},
/* E000A */ { NULL,NULL},
/* E000B */ { NULL,NULL},
/* E000C */ { NULL,NULL},
/* E000D */ { NULL,NULL},
/* E000E */ { NULL,NULL},
/* E000F */ { NULL,NULL},
/* E0010 */ { NULL,NULL},
/* E0011 */ { NULL,NULL},
/* E0012 */ { NULL,NULL},
/* E0013 */ { NULL,NULL},
/* E0014 */ { NULL,NULL},
/* E0015 */ { NULL,NULL},
/* E0016 */ { NULL,NULL},
/* E0017 */ { NULL,NULL},
/* E0018 */ { NULL,NULL},
/* E0019 */ { NULL,NULL},
/* E001A */ { NULL,NULL},
/* E001B */ { NULL,NULL},
/* E001C */ { NULL,NULL},
/* E001D */ { NULL,NULL},
/* E001E */ { NULL,NULL},
/* E001F */ { NULL,NULL},
/* E0020 */ { "ÉTIQUETTE ESPACE",NULL},
/* E0021 */ { "ÉTIQUETTE POINT D'EXCLAMATION",NULL},
/* E0022 */ { "ÉTIQUETTE GUILLEMET ANGLAIS",NULL},
/* E0023 */ { "ÉTIQUETTE CROISILLON",NULL},
/* E0024 */ { "ÉTIQUETTE SYMBOLE DOLLAR",NULL},
/* E0025 */ { "ÉTIQUETTE SYMBOLE POUR CENT",NULL},
/* E0026 */ { "ÉTIQUETTE PERLUÈTE",NULL},
/* E0027 */ { "ÉTIQUETTE APOSTROPHE",NULL},
/* E0028 */ { "ÉTIQUETTE PARENTHÈSE GAUCHE",NULL},
/* E0029 */ { "ÉTIQUETTE PARENTHÈSE DROITE",NULL},
/* E002A */ { "ÉTIQUETTE ASTÉRISQUE",NULL},
/* E002B */ { "ÉTIQUETTE SIGNE PLUS",NULL},
/* E002C */ { "ÉTIQUETTE VIRGULE",NULL},
/* E002D */ { "ÉTIQUETTE TRAIT D'UNION-SIGNE MOINS",NULL},
/* E002E */ { "ÉTIQUETTE POINT",NULL},
/* E002F */ { "ÉTIQUETTE BARRE OBLIQUE",NULL},
/* E0030 */ { "ÉTIQUETTE CHIFFRE ZÉRO",NULL},
/* E0031 */ { "ÉTIQUETTE CHIFFRE UN",NULL},
/* E0032 */ { "ÉTIQUETTE CHIFFRE DEUX",NULL},
/* E0033 */ { "ÉTIQUETTE CHIFFRE TROIS",NULL},
/* E0034 */ { "ÉTIQUETTE CHIFFRE QUATRE",NULL},
/* E0035 */ { "ÉTIQUETTE CHIFFRE CINQ",NULL},
/* E0036 */ { "ÉTIQUETTE CHIFFRE SIX",NULL},
/* E0037 */ { "ÉTIQUETTE CHIFFRE SEPT",NULL},
/* E0038 */ { "ÉTIQUETTE CHIFFRE HUIT",NULL},
/* E0039 */ { "ÉTIQUETTE CHIFFRE NEUF",NULL},
/* E003A */ { "ÉTIQUETTE DEUX-POINTS",NULL},
/* E003B */ { "ÉTIQUETTE POINT-VIRGULE",NULL},
/* E003C */ { "ÉTIQUETTE SIGNE INFÉRIEUR À",NULL},
/* E003D */ { "ÉTIQUETTE SIGNE ÉGAL",NULL},
/* E003E */ { "ÉTIQUETTE SIGNE SUPÉRIEUR À",NULL},
/* E003F */ { "ÉTIQUETTE POINT D'INTERROGATION",NULL},
/* E0040 */ { "ÉTIQUETTE ARROBE",NULL},
/* E0041 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE A",NULL},
/* E0042 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE B",NULL},
/* E0043 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE C",NULL},
/* E0044 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE D",NULL},
/* E0045 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE E",NULL},
/* E0046 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE F",NULL},
/* E0047 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE G",NULL},
/* E0048 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE H",NULL},
/* E0049 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE I",NULL},
/* E004A */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE J",NULL},
/* E004B */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE K",NULL},
/* E004C */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE L",NULL},
/* E004D */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE M",NULL},
/* E004E */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE N",NULL},
/* E004F */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE O",NULL},
/* E0050 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE P",NULL},
/* E0051 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE Q",NULL},
/* E0052 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE R",NULL},
/* E0053 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE S",NULL},
/* E0054 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE T",NULL},
/* E0055 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE U",NULL},
/* E0056 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE V",NULL},
/* E0057 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE W",NULL},
/* E0058 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE X",NULL},
/* E0059 */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE Y",NULL},
/* E005A */ { "ÉTIQUETTE LETTRE MAJUSCULE LATINE Z",NULL},
/* E005B */ { "ÉTIQUETTE CROCHET GAUCHE",NULL},
/* E005C */ { "ÉTIQUETTE BARRE OBLIQUE INVERSÉE",NULL},
/* E005D */ { "ÉTIQUETTE CROCHET DROIT",NULL},
/* E005E */ { "ÉTIQUETTE ACCENT CIRCONFLEXE",NULL},
/* E005F */ { "ÉTIQUETTE TIRET BAS",NULL},
/* E0060 */ { "ÉTIQUETTE ACCENT GRAVE",NULL},
/* E0061 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE A",NULL},
/* E0062 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE B",NULL},
/* E0063 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE C",NULL},
/* E0064 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE D",NULL},
/* E0065 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE E",NULL},
/* E0066 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE F",NULL},
/* E0067 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE G",NULL},
/* E0068 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE H",NULL},
/* E0069 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE I",NULL},
/* E006A */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE J",NULL},
/* E006B */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE K",NULL},
/* E006C */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE L",NULL},
/* E006D */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE M",NULL},
/* E006E */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE N",NULL},
/* E006F */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE O",NULL},
/* E0070 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE P",NULL},
/* E0071 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE Q",NULL},
/* E0072 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE R",NULL},
/* E0073 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE S",NULL},
/* E0074 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE T",NULL},
/* E0075 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE U",NULL},
/* E0076 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE V",NULL},
/* E0077 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE W",NULL},
/* E0078 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE X",NULL},
/* E0079 */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE Y",NULL},
/* E007A */ { "ÉTIQUETTE LETTRE MINUSCULE LATINE Z",NULL},
/* E007B */ { "ÉTIQUETTE ACCOLADE GAUCHE",NULL},
/* E007C */ { "ÉTIQUETTE BARRE VERTICALE",NULL},
/* E007D */ { "ÉTIQUETTE ACCOLADE DROITE",NULL},
/* E007E */ { "ÉTIQUETTE TILDE",NULL},
/* E007F */ { "ÉTIQUETTE D'ANNULATION",NULL},
/* E0080 */ { NULL,NULL},
/* E0081 */ { NULL,NULL},
/* E0082 */ { NULL,NULL},
/* E0083 */ { NULL,NULL},
/* E0084 */ { NULL,NULL},
/* E0085 */ { NULL,NULL},
/* E0086 */ { NULL,NULL},
/* E0087 */ { NULL,NULL},
/* E0088 */ { NULL,NULL},
/* E0089 */ { NULL,NULL},
/* E008A */ { NULL,NULL},
/* E008B */ { NULL,NULL},
/* E008C */ { NULL,NULL},
/* E008D */ { NULL,NULL},
/* E008E */ { NULL,NULL},
/* E008F */ { NULL,NULL},
/* E0090 */ { NULL,NULL},
/* E0091 */ { NULL,NULL},
/* E0092 */ { NULL,NULL},
/* E0093 */ { NULL,NULL},
/* E0094 */ { NULL,NULL},
/* E0095 */ { NULL,NULL},
/* E0096 */ { NULL,NULL},
/* E0097 */ { NULL,NULL},
/* E0098 */ { NULL,NULL},
/* E0099 */ { NULL,NULL},
/* E009A */ { NULL,NULL},
/* E009B */ { NULL,NULL},
/* E009C */ { NULL,NULL},
/* E009D */ { NULL,NULL},
/* E009E */ { NULL,NULL},
/* E009F */ { NULL,NULL},
/* E00A0 */ { NULL,NULL},
/* E00A1 */ { NULL,NULL},
/* E00A2 */ { NULL,NULL},
/* E00A3 */ { NULL,NULL},
/* E00A4 */ { NULL,NULL},
/* E00A5 */ { NULL,NULL},
/* E00A6 */ { NULL,NULL},
/* E00A7 */ { NULL,NULL},
/* E00A8 */ { NULL,NULL},
/* E00A9 */ { NULL,NULL},
/* E00AA */ { NULL,NULL},
/* E00AB */ { NULL,NULL},
/* E00AC */ { NULL,NULL},
/* E00AD */ { NULL,NULL},
/* E00AE */ { NULL,NULL},
/* E00AF */ { NULL,NULL},
/* E00B0 */ { NULL,NULL},
/* E00B1 */ { NULL,NULL},
/* E00B2 */ { NULL,NULL},
/* E00B3 */ { NULL,NULL},
/* E00B4 */ { NULL,NULL},
/* E00B5 */ { NULL,NULL},
/* E00B6 */ { NULL,NULL},
/* E00B7 */ { NULL,NULL},
/* E00B8 */ { NULL,NULL},
/* E00B9 */ { NULL,NULL},
/* E00BA */ { NULL,NULL},
/* E00BB */ { NULL,NULL},
/* E00BC */ { NULL,NULL},
/* E00BD */ { NULL,NULL},
/* E00BE */ { NULL,NULL},
/* E00BF */ { NULL,NULL},
/* E00C0 */ { NULL,NULL},
/* E00C1 */ { NULL,NULL},
/* E00C2 */ { NULL,NULL},
/* E00C3 */ { NULL,NULL},
/* E00C4 */ { NULL,NULL},
/* E00C5 */ { NULL,NULL},
/* E00C6 */ { NULL,NULL},
/* E00C7 */ { NULL,NULL},
/* E00C8 */ { NULL,NULL},
/* E00C9 */ { NULL,NULL},
/* E00CA */ { NULL,NULL},
/* E00CB */ { NULL,NULL},
/* E00CC */ { NULL,NULL},
/* E00CD */ { NULL,NULL},
/* E00CE */ { NULL,NULL},
/* E00CF */ { NULL,NULL},
/* E00D0 */ { NULL,NULL},
/* E00D1 */ { NULL,NULL},
/* E00D2 */ { NULL,NULL},
/* E00D3 */ { NULL,NULL},
/* E00D4 */ { NULL,NULL},
/* E00D5 */ { NULL,NULL},
/* E00D6 */ { NULL,NULL},
/* E00D7 */ { NULL,NULL},
/* E00D8 */ { NULL,NULL},
/* E00D9 */ { NULL,NULL},
/* E00DA */ { NULL,NULL},
/* E00DB */ { NULL,NULL},
/* E00DC */ { NULL,NULL},
/* E00DD */ { NULL,NULL},
/* E00DE */ { NULL,NULL},
/* E00DF */ { NULL,NULL},
/* E00E0 */ { NULL,NULL},
/* E00E1 */ { NULL,NULL},
/* E00E2 */ { NULL,NULL},
/* E00E3 */ { NULL,NULL},
/* E00E4 */ { NULL,NULL},
/* E00E5 */ { NULL,NULL},
/* E00E6 */ { NULL,NULL},
/* E00E7 */ { NULL,NULL},
/* E00E8 */ { NULL,NULL},
/* E00E9 */ { NULL,NULL},
/* E00EA */ { NULL,NULL},
/* E00EB */ { NULL,NULL},
/* E00EC */ { NULL,NULL},
/* E00ED */ { NULL,NULL},
/* E00EE */ { NULL,NULL},
/* E00EF */ { NULL,NULL},
/* E00F0 */ { NULL,NULL},
/* E00F1 */ { NULL,NULL},
/* E00F2 */ { NULL,NULL},
/* E00F3 */ { NULL,NULL},
/* E00F4 */ { NULL,NULL},
/* E00F5 */ { NULL,NULL},
/* E00F6 */ { NULL,NULL},
/* E00F7 */ { NULL,NULL},
/* E00F8 */ { NULL,NULL},
/* E00F9 */ { NULL,NULL},
/* E00FA */ { NULL,NULL},
/* E00FB */ { NULL,NULL},
/* E00FC */ { NULL,NULL},
/* E00FD */ { NULL,NULL},
/* E00FE */ { NULL,NULL},
/* E00FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot unaFR_0E_01[] = {
/* E0100 */ { "SÉLECTEUR DE VARIANTE-17","	* ces caractères ont pour abréviation VS17, VS18, et ainsi de suite"},
/* E0101 */ { "SÉLECTEUR DE VARIANTE-18",NULL},
/* E0102 */ { "SÉLECTEUR DE VARIANTE-19",NULL},
/* E0103 */ { "SÉLECTEUR DE VARIANTE-20",NULL},
/* E0104 */ { "SÉLECTEUR DE VARIANTE-21",NULL},
/* E0105 */ { "SÉLECTEUR DE VARIANTE-22",NULL},
/* E0106 */ { "SÉLECTEUR DE VARIANTE-23",NULL},
/* E0107 */ { "SÉLECTEUR DE VARIANTE-24",NULL},
/* E0108 */ { "SÉLECTEUR DE VARIANTE-25",NULL},
/* E0109 */ { "SÉLECTEUR DE VARIANTE-26",NULL},
/* E010A */ { "SÉLECTEUR DE VARIANTE-27",NULL},
/* E010B */ { "SÉLECTEUR DE VARIANTE-28",NULL},
/* E010C */ { "SÉLECTEUR DE VARIANTE-29",NULL},
/* E010D */ { "SÉLECTEUR DE VARIANTE-30",NULL},
/* E010E */ { "SÉLECTEUR DE VARIANTE-31",NULL},
/* E010F */ { "SÉLECTEUR DE VARIANTE-32",NULL},
/* E0110 */ { "SÉLECTEUR DE VARIANTE-33",NULL},
/* E0111 */ { "SÉLECTEUR DE VARIANTE-34",NULL},
/* E0112 */ { "SÉLECTEUR DE VARIANTE-35",NULL},
/* E0113 */ { "SÉLECTEUR DE VARIANTE-36",NULL},
/* E0114 */ { "SÉLECTEUR DE VARIANTE-37",NULL},
/* E0115 */ { "SÉLECTEUR DE VARIANTE-38",NULL},
/* E0116 */ { "SÉLECTEUR DE VARIANTE-39",NULL},
/* E0117 */ { "SÉLECTEUR DE VARIANTE-40",NULL},
/* E0118 */ { "SÉLECTEUR DE VARIANTE-41",NULL},
/* E0119 */ { "SÉLECTEUR DE VARIANTE-42",NULL},
/* E011A */ { "SÉLECTEUR DE VARIANTE-43",NULL},
/* E011B */ { "SÉLECTEUR DE VARIANTE-44",NULL},
/* E011C */ { "SÉLECTEUR DE VARIANTE-45",NULL},
/* E011D */ { "SÉLECTEUR DE VARIANTE-46",NULL},
/* E011E */ { "SÉLECTEUR DE VARIANTE-47",NULL},
/* E011F */ { "SÉLECTEUR DE VARIANTE-48",NULL},
/* E0120 */ { "SÉLECTEUR DE VARIANTE-49",NULL},
/* E0121 */ { "SÉLECTEUR DE VARIANTE-50",NULL},
/* E0122 */ { "SÉLECTEUR DE VARIANTE-51",NULL},
/* E0123 */ { "SÉLECTEUR DE VARIANTE-52",NULL},
/* E0124 */ { "SÉLECTEUR DE VARIANTE-53",NULL},
/* E0125 */ { "SÉLECTEUR DE VARIANTE-54",NULL},
/* E0126 */ { "SÉLECTEUR DE VARIANTE-55",NULL},
/* E0127 */ { "SÉLECTEUR DE VARIANTE-56",NULL},
/* E0128 */ { "SÉLECTEUR DE VARIANTE-57",NULL},
/* E0129 */ { "SÉLECTEUR DE VARIANTE-58",NULL},
/* E012A */ { "SÉLECTEUR DE VARIANTE-59",NULL},
/* E012B */ { "SÉLECTEUR DE VARIANTE-60",NULL},
/* E012C */ { "SÉLECTEUR DE VARIANTE-61",NULL},
/* E012D */ { "SÉLECTEUR DE VARIANTE-62",NULL},
/* E012E */ { "SÉLECTEUR DE VARIANTE-63",NULL},
/* E012F */ { "SÉLECTEUR DE VARIANTE-64",NULL},
/* E0130 */ { "SÉLECTEUR DE VARIANTE-65",NULL},
/* E0131 */ { "SÉLECTEUR DE VARIANTE-66",NULL},
/* E0132 */ { "SÉLECTEUR DE VARIANTE-67",NULL},
/* E0133 */ { "SÉLECTEUR DE VARIANTE-68",NULL},
/* E0134 */ { "SÉLECTEUR DE VARIANTE-69",NULL},
/* E0135 */ { "SÉLECTEUR DE VARIANTE-70",NULL},
/* E0136 */ { "SÉLECTEUR DE VARIANTE-71",NULL},
/* E0137 */ { "SÉLECTEUR DE VARIANTE-72",NULL},
/* E0138 */ { "SÉLECTEUR DE VARIANTE-73",NULL},
/* E0139 */ { "SÉLECTEUR DE VARIANTE-74",NULL},
/* E013A */ { "SÉLECTEUR DE VARIANTE-75",NULL},
/* E013B */ { "SÉLECTEUR DE VARIANTE-76",NULL},
/* E013C */ { "SÉLECTEUR DE VARIANTE-77",NULL},
/* E013D */ { "SÉLECTEUR DE VARIANTE-78",NULL},
/* E013E */ { "SÉLECTEUR DE VARIANTE-79",NULL},
/* E013F */ { "SÉLECTEUR DE VARIANTE-80",NULL},
/* E0140 */ { "SÉLECTEUR DE VARIANTE-81",NULL},
/* E0141 */ { "SÉLECTEUR DE VARIANTE-82",NULL},
/* E0142 */ { "SÉLECTEUR DE VARIANTE-83",NULL},
/* E0143 */ { "SÉLECTEUR DE VARIANTE-84",NULL},
/* E0144 */ { "SÉLECTEUR DE VARIANTE-85",NULL},
/* E0145 */ { "SÉLECTEUR DE VARIANTE-86",NULL},
/* E0146 */ { "SÉLECTEUR DE VARIANTE-87",NULL},
/* E0147 */ { "SÉLECTEUR DE VARIANTE-88",NULL},
/* E0148 */ { "SÉLECTEUR DE VARIANTE-89",NULL},
/* E0149 */ { "SÉLECTEUR DE VARIANTE-90",NULL},
/* E014A */ { "SÉLECTEUR DE VARIANTE-91",NULL},
/* E014B */ { "SÉLECTEUR DE VARIANTE-92",NULL},
/* E014C */ { "SÉLECTEUR DE VARIANTE-93",NULL},
/* E014D */ { "SÉLECTEUR DE VARIANTE-94",NULL},
/* E014E */ { "SÉLECTEUR DE VARIANTE-95",NULL},
/* E014F */ { "SÉLECTEUR DE VARIANTE-96",NULL},
/* E0150 */ { "SÉLECTEUR DE VARIANTE-97",NULL},
/* E0151 */ { "SÉLECTEUR DE VARIANTE-98",NULL},
/* E0152 */ { "SÉLECTEUR DE VARIANTE-99",NULL},
/* E0153 */ { "SÉLECTEUR DE VARIANTE-100",NULL},
/* E0154 */ { "SÉLECTEUR DE VARIANTE-101",NULL},
/* E0155 */ { "SÉLECTEUR DE VARIANTE-102",NULL},
/* E0156 */ { "SÉLECTEUR DE VARIANTE-103",NULL},
/* E0157 */ { "SÉLECTEUR DE VARIANTE-104",NULL},
/* E0158 */ { "SÉLECTEUR DE VARIANTE-105",NULL},
/* E0159 */ { "SÉLECTEUR DE VARIANTE-106",NULL},
/* E015A */ { "SÉLECTEUR DE VARIANTE-107",NULL},
/* E015B */ { "SÉLECTEUR DE VARIANTE-108",NULL},
/* E015C */ { "SÉLECTEUR DE VARIANTE-109",NULL},
/* E015D */ { "SÉLECTEUR DE VARIANTE-110",NULL},
/* E015E */ { "SÉLECTEUR DE VARIANTE-111",NULL},
/* E015F */ { "SÉLECTEUR DE VARIANTE-112",NULL},
/* E0160 */ { "SÉLECTEUR DE VARIANTE-113",NULL},
/* E0161 */ { "SÉLECTEUR DE VARIANTE-114",NULL},
/* E0162 */ { "SÉLECTEUR DE VARIANTE-115",NULL},
/* E0163 */ { "SÉLECTEUR DE VARIANTE-116",NULL},
/* E0164 */ { "SÉLECTEUR DE VARIANTE-117",NULL},
/* E0165 */ { "SÉLECTEUR DE VARIANTE-118",NULL},
/* E0166 */ { "SÉLECTEUR DE VARIANTE-119",NULL},
/* E0167 */ { "SÉLECTEUR DE VARIANTE-120",NULL},
/* E0168 */ { "SÉLECTEUR DE VARIANTE-121",NULL},
/* E0169 */ { "SÉLECTEUR DE VARIANTE-122",NULL},
/* E016A */ { "SÉLECTEUR DE VARIANTE-123",NULL},
/* E016B */ { "SÉLECTEUR DE VARIANTE-124",NULL},
/* E016C */ { "SÉLECTEUR DE VARIANTE-125",NULL},
/* E016D */ { "SÉLECTEUR DE VARIANTE-126",NULL},
/* E016E */ { "SÉLECTEUR DE VARIANTE-127",NULL},
/* E016F */ { "SÉLECTEUR DE VARIANTE-128",NULL},
/* E0170 */ { "SÉLECTEUR DE VARIANTE-129",NULL},
/* E0171 */ { "SÉLECTEUR DE VARIANTE-130",NULL},
/* E0172 */ { "SÉLECTEUR DE VARIANTE-131",NULL},
/* E0173 */ { "SÉLECTEUR DE VARIANTE-132",NULL},
/* E0174 */ { "SÉLECTEUR DE VARIANTE-133",NULL},
/* E0175 */ { "SÉLECTEUR DE VARIANTE-134",NULL},
/* E0176 */ { "SÉLECTEUR DE VARIANTE-135",NULL},
/* E0177 */ { "SÉLECTEUR DE VARIANTE-136",NULL},
/* E0178 */ { "SÉLECTEUR DE VARIANTE-137",NULL},
/* E0179 */ { "SÉLECTEUR DE VARIANTE-138",NULL},
/* E017A */ { "SÉLECTEUR DE VARIANTE-139",NULL},
/* E017B */ { "SÉLECTEUR DE VARIANTE-140",NULL},
/* E017C */ { "SÉLECTEUR DE VARIANTE-141",NULL},
/* E017D */ { "SÉLECTEUR DE VARIANTE-142",NULL},
/* E017E */ { "SÉLECTEUR DE VARIANTE-143",NULL},
/* E017F */ { "SÉLECTEUR DE VARIANTE-144",NULL},
/* E0180 */ { "SÉLECTEUR DE VARIANTE-145",NULL},
/* E0181 */ { "SÉLECTEUR DE VARIANTE-146",NULL},
/* E0182 */ { "SÉLECTEUR DE VARIANTE-147",NULL},
/* E0183 */ { "SÉLECTEUR DE VARIANTE-148",NULL},
/* E0184 */ { "SÉLECTEUR DE VARIANTE-149",NULL},
/* E0185 */ { "SÉLECTEUR DE VARIANTE-150",NULL},
/* E0186 */ { "SÉLECTEUR DE VARIANTE-151",NULL},
/* E0187 */ { "SÉLECTEUR DE VARIANTE-152",NULL},
/* E0188 */ { "SÉLECTEUR DE VARIANTE-153",NULL},
/* E0189 */ { "SÉLECTEUR DE VARIANTE-154",NULL},
/* E018A */ { "SÉLECTEUR DE VARIANTE-155",NULL},
/* E018B */ { "SÉLECTEUR DE VARIANTE-156",NULL},
/* E018C */ { "SÉLECTEUR DE VARIANTE-157",NULL},
/* E018D */ { "SÉLECTEUR DE VARIANTE-158",NULL},
/* E018E */ { "SÉLECTEUR DE VARIANTE-159",NULL},
/* E018F */ { "SÉLECTEUR DE VARIANTE-160",NULL},
/* E0190 */ { "SÉLECTEUR DE VARIANTE-161",NULL},
/* E0191 */ { "SÉLECTEUR DE VARIANTE-162",NULL},
/* E0192 */ { "SÉLECTEUR DE VARIANTE-163",NULL},
/* E0193 */ { "SÉLECTEUR DE VARIANTE-164",NULL},
/* E0194 */ { "SÉLECTEUR DE VARIANTE-165",NULL},
/* E0195 */ { "SÉLECTEUR DE VARIANTE-166",NULL},
/* E0196 */ { "SÉLECTEUR DE VARIANTE-167",NULL},
/* E0197 */ { "SÉLECTEUR DE VARIANTE-168",NULL},
/* E0198 */ { "SÉLECTEUR DE VARIANTE-169",NULL},
/* E0199 */ { "SÉLECTEUR DE VARIANTE-170",NULL},
/* E019A */ { "SÉLECTEUR DE VARIANTE-171",NULL},
/* E019B */ { "SÉLECTEUR DE VARIANTE-172",NULL},
/* E019C */ { "SÉLECTEUR DE VARIANTE-173",NULL},
/* E019D */ { "SÉLECTEUR DE VARIANTE-174",NULL},
/* E019E */ { "SÉLECTEUR DE VARIANTE-175",NULL},
/* E019F */ { "SÉLECTEUR DE VARIANTE-176",NULL},
/* E01A0 */ { "SÉLECTEUR DE VARIANTE-177",NULL},
/* E01A1 */ { "SÉLECTEUR DE VARIANTE-178",NULL},
/* E01A2 */ { "SÉLECTEUR DE VARIANTE-179",NULL},
/* E01A3 */ { "SÉLECTEUR DE VARIANTE-180",NULL},
/* E01A4 */ { "SÉLECTEUR DE VARIANTE-181",NULL},
/* E01A5 */ { "SÉLECTEUR DE VARIANTE-182",NULL},
/* E01A6 */ { "SÉLECTEUR DE VARIANTE-183",NULL},
/* E01A7 */ { "SÉLECTEUR DE VARIANTE-184",NULL},
/* E01A8 */ { "SÉLECTEUR DE VARIANTE-185",NULL},
/* E01A9 */ { "SÉLECTEUR DE VARIANTE-186",NULL},
/* E01AA */ { "SÉLECTEUR DE VARIANTE-187",NULL},
/* E01AB */ { "SÉLECTEUR DE VARIANTE-188",NULL},
/* E01AC */ { "SÉLECTEUR DE VARIANTE-189",NULL},
/* E01AD */ { "SÉLECTEUR DE VARIANTE-190",NULL},
/* E01AE */ { "SÉLECTEUR DE VARIANTE-191",NULL},
/* E01AF */ { "SÉLECTEUR DE VARIANTE-192",NULL},
/* E01B0 */ { "SÉLECTEUR DE VARIANTE-193",NULL},
/* E01B1 */ { "SÉLECTEUR DE VARIANTE-194",NULL},
/* E01B2 */ { "SÉLECTEUR DE VARIANTE-195",NULL},
/* E01B3 */ { "SÉLECTEUR DE VARIANTE-196",NULL},
/* E01B4 */ { "SÉLECTEUR DE VARIANTE-197",NULL},
/* E01B5 */ { "SÉLECTEUR DE VARIANTE-198",NULL},
/* E01B6 */ { "SÉLECTEUR DE VARIANTE-199",NULL},
/* E01B7 */ { "SÉLECTEUR DE VARIANTE-200",NULL},
/* E01B8 */ { "SÉLECTEUR DE VARIANTE-201",NULL},
/* E01B9 */ { "SÉLECTEUR DE VARIANTE-202",NULL},
/* E01BA */ { "SÉLECTEUR DE VARIANTE-203",NULL},
/* E01BB */ { "SÉLECTEUR DE VARIANTE-204",NULL},
/* E01BC */ { "SÉLECTEUR DE VARIANTE-205",NULL},
/* E01BD */ { "SÉLECTEUR DE VARIANTE-206",NULL},
/* E01BE */ { "SÉLECTEUR DE VARIANTE-207",NULL},
/* E01BF */ { "SÉLECTEUR DE VARIANTE-208",NULL},
/* E01C0 */ { "SÉLECTEUR DE VARIANTE-209",NULL},
/* E01C1 */ { "SÉLECTEUR DE VARIANTE-210",NULL},
/* E01C2 */ { "SÉLECTEUR DE VARIANTE-211",NULL},
/* E01C3 */ { "SÉLECTEUR DE VARIANTE-212",NULL},
/* E01C4 */ { "SÉLECTEUR DE VARIANTE-213",NULL},
/* E01C5 */ { "SÉLECTEUR DE VARIANTE-214",NULL},
/* E01C6 */ { "SÉLECTEUR DE VARIANTE-215",NULL},
/* E01C7 */ { "SÉLECTEUR DE VARIANTE-216",NULL},
/* E01C8 */ { "SÉLECTEUR DE VARIANTE-217",NULL},
/* E01C9 */ { "SÉLECTEUR DE VARIANTE-218",NULL},
/* E01CA */ { "SÉLECTEUR DE VARIANTE-219",NULL},
/* E01CB */ { "SÉLECTEUR DE VARIANTE-220",NULL},
/* E01CC */ { "SÉLECTEUR DE VARIANTE-221",NULL},
/* E01CD */ { "SÉLECTEUR DE VARIANTE-222",NULL},
/* E01CE */ { "SÉLECTEUR DE VARIANTE-223",NULL},
/* E01CF */ { "SÉLECTEUR DE VARIANTE-224",NULL},
/* E01D0 */ { "SÉLECTEUR DE VARIANTE-225",NULL},
/* E01D1 */ { "SÉLECTEUR DE VARIANTE-226",NULL},
/* E01D2 */ { "SÉLECTEUR DE VARIANTE-227",NULL},
/* E01D3 */ { "SÉLECTEUR DE VARIANTE-228",NULL},
/* E01D4 */ { "SÉLECTEUR DE VARIANTE-229",NULL},
/* E01D5 */ { "SÉLECTEUR DE VARIANTE-230",NULL},
/* E01D6 */ { "SÉLECTEUR DE VARIANTE-231",NULL},
/* E01D7 */ { "SÉLECTEUR DE VARIANTE-232",NULL},
/* E01D8 */ { "SÉLECTEUR DE VARIANTE-233",NULL},
/* E01D9 */ { "SÉLECTEUR DE VARIANTE-234",NULL},
/* E01DA */ { "SÉLECTEUR DE VARIANTE-235",NULL},
/* E01DB */ { "SÉLECTEUR DE VARIANTE-236",NULL},
/* E01DC */ { "SÉLECTEUR DE VARIANTE-237",NULL},
/* E01DD */ { "SÉLECTEUR DE VARIANTE-238",NULL},
/* E01DE */ { "SÉLECTEUR DE VARIANTE-239",NULL},
/* E01DF */ { "SÉLECTEUR DE VARIANTE-240",NULL},
/* E01E0 */ { "SÉLECTEUR DE VARIANTE-241",NULL},
/* E01E1 */ { "SÉLECTEUR DE VARIANTE-242",NULL},
/* E01E2 */ { "SÉLECTEUR DE VARIANTE-243",NULL},
/* E01E3 */ { "SÉLECTEUR DE VARIANTE-244",NULL},
/* E01E4 */ { "SÉLECTEUR DE VARIANTE-245",NULL},
/* E01E5 */ { "SÉLECTEUR DE VARIANTE-246",NULL},
/* E01E6 */ { "SÉLECTEUR DE VARIANTE-247",NULL},
/* E01E7 */ { "SÉLECTEUR DE VARIANTE-248",NULL},
/* E01E8 */ { "SÉLECTEUR DE VARIANTE-249",NULL},
/* E01E9 */ { "SÉLECTEUR DE VARIANTE-250",NULL},
/* E01EA */ { "SÉLECTEUR DE VARIANTE-251",NULL},
/* E01EB */ { "SÉLECTEUR DE VARIANTE-252",NULL},
/* E01EC */ { "SÉLECTEUR DE VARIANTE-253",NULL},
/* E01ED */ { "SÉLECTEUR DE VARIANTE-254",NULL},
/* E01EE */ { "SÉLECTEUR DE VARIANTE-255",NULL},
/* E01EF */ { "SÉLECTEUR DE VARIANTE-256",NULL},
/* E01F0 */ { NULL,NULL},
/* E01F1 */ { NULL,NULL},
/* E01F2 */ { NULL,NULL},
/* E01F3 */ { NULL,NULL},
/* E01F4 */ { NULL,NULL},
/* E01F5 */ { NULL,NULL},
/* E01F6 */ { NULL,NULL},
/* E01F7 */ { NULL,NULL},
/* E01F8 */ { NULL,NULL},
/* E01F9 */ { NULL,NULL},
/* E01FA */ { NULL,NULL},
/* E01FB */ { NULL,NULL},
/* E01FC */ { NULL,NULL},
/* E01FD */ { NULL,NULL},
/* E01FE */ { NULL,NULL},
/* E01FF */ { NULL,NULL}
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const unaFR_00[] = {
	unaFR_00_00,
	unaFR_00_01,
	unaFR_00_02,
	unaFR_00_03,
	unaFR_00_04,
	unaFR_00_05,
	unaFR_00_06,
	unaFR_00_07,
	unaFR_00_08,
	unaFR_00_09,
	unaFR_00_0A,
	unaFR_00_0B,
	unaFR_00_0C,
	unaFR_00_0D,
	unaFR_00_0E,
	unaFR_00_0F,
	unaFR_00_10,
	unaFR_00_11,
	unaFR_00_12,
	unaFR_00_13,
	unaFR_00_14,
	unaFR_00_15,
	unaFR_00_16,
	unaFR_00_17,
	unaFR_00_18,
	unaFR_00_19,
	unaFR_00_1A,
	unaFR_00_1B,
	unaFR_00_1C,
	unaFR_00_1D,
	unaFR_00_1E,
	unaFR_00_1F,
	unaFR_00_20,
	unaFR_00_21,
	unaFR_00_22,
	unaFR_00_23,
	unaFR_00_24,
	unaFR_00_25,
	unaFR_00_26,
	unaFR_00_27,
	unaFR_00_28,
	unaFR_00_29,
	unaFR_00_2A,
	unaFR_00_2B,
	unaFR_00_2C,
	unaFR_00_2D,
	unaFR_00_2E,
	unaFR_00_2F,
	unaFR_00_30,
	unaFR_00_31,
	unaFR_00_32,
	unaFR_00_33,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_00_4D,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_00_A0,
	unaFR_00_A1,
	unaFR_00_A2,
	unaFR_00_A3,
	unaFR_00_A4,
	unaFR_00_A5,
	unaFR_00_A6,
	unaFR_00_A7,
	unaFR_00_A8,
	unaFR_00_A9,
	unaFR_00_AA,
	unaFR_00_AB,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_00_D7,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_00_F9,
	unaFR_00_FA,
	unaFR_00_FB,
	unaFR_00_FC,
	unaFR_00_FD,
	unaFR_00_FE,
	unaFR_00_FF
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const unaFR_01[] = {
	unaFR_01_00,
	unaFR_01_01,
	unaFR_01_02,
	unaFR_01_03,
	unaFR_01_04,
	unaFR_01_05,
	unaFR_01_06,
	unaFR_01_07,
	unaFR_01_08,
	unaFR_01_09,
	unaFR_01_0A,
	unaFR_01_0B,
	unaFR_01_0C,
	unaFR_01_0D,
	unaFR_01_0E,
	unaFR_01_0F,
	unaFR_01_10,
	unaFR_01_11,
	unaFR_01_12,
	unaFR_01_13,
	unaFR_01_14,
	unaFR_01_15,
	unaFR_01_16,
	unaFR_01_17,
	unaFR_01_18,
	unaFR_01_19,
	unaFR_01_1A,
	unaFR_01_1B,
	unaFR_01_1C,
	unaFR_01_1D,
	unaFR_01_1E,
	unaFR_01_1F,
	unaFR_01_20,
	unaFR_01_21,
	unaFR_01_22,
	unaFR_01_23,
	unaFR_01_24,
	unaFR_01_25,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_2F,
	unaFR_01_30,
	unaFR_01_31,
	unaFR_01_32,
	unaFR_01_33,
	unaFR_01_34,
	unaFR_01_35,
	unaFR_01_36,
	unaFR_01_37,
	unaFR_01_38,
	unaFR_01_39,
	unaFR_01_3A,
	unaFR_01_3B,
	unaFR_01_3C,
	unaFR_01_3D,
	unaFR_01_3E,
	unaFR_01_3F,
	unaFR_01_40,
	unaFR_01_41,
	unaFR_01_42,
	unaFR_01_43,
	unaFR_01_44,
	unaFR_01_45,
	unaFR_01_46,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_61,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_68,
	unaFR_01_69,
	unaFR_01_6A,
	unaFR_01_6B,
	nullarrayFR,
	unaFR_01_6D,
	unaFR_01_6E,
	unaFR_01_6F,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_88,
	unaFR_01_89,
	unaFR_01_8A,
	unaFR_01_8B,
	unaFR_01_8C,
	unaFR_01_8D,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_AF,
	unaFR_01_B0,
	unaFR_01_B1,
	unaFR_01_B2,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_BC,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_CC,
	unaFR_01_CD,
	unaFR_01_CE,
	unaFR_01_CF,
	unaFR_01_D0,
	unaFR_01_D1,
	unaFR_01_D2,
	unaFR_01_D3,
	unaFR_01_D4,
	unaFR_01_D5,
	unaFR_01_D6,
	unaFR_01_D7,
	unaFR_01_D8,
	unaFR_01_D9,
	unaFR_01_DA,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_DF,
	unaFR_01_E0,
	unaFR_01_E1,
	unaFR_01_E2,
	nullarrayFR,
	unaFR_01_E4,
	unaFR_01_E5,
	unaFR_01_E6,
	unaFR_01_E7,
	unaFR_01_E8,
	unaFR_01_E9,
	nullarrayFR,
	nullarrayFR,
	unaFR_01_EC,
	unaFR_01_ED,
	unaFR_01_EE,
	nullarrayFR,
	unaFR_01_F0,
	unaFR_01_F1,
	unaFR_01_F2,
	unaFR_01_F3,
	unaFR_01_F4,
	unaFR_01_F5,
	unaFR_01_F6,
	unaFR_01_F7,
	unaFR_01_F8,
	unaFR_01_F9,
	unaFR_01_FA,
	unaFR_01_FB,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarray2FR
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const unaFR_02[] = {
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	unaFR_02_F8,
	unaFR_02_F9,
	unaFR_02_FA,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarray2FR
};

UN_DLL_LOCAL
static const struct unicode_nameannot * const unaFR_0E[] = {
	unaFR_0E_00,
	unaFR_0E_01,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarrayFR,
	nullarray2FR
};

UN_DLL_EXPORT
const struct unicode_nameannot * const *const UnicodeNameAnnotFR[] = {
	unaFR_00,
	unaFR_01,
	unaFR_02,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	unaFR_0E,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR,
	nullnullarrayFR
};

